@@ -17,12 +17,11 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "accessibility/extended/AccessibleGridControlTable.hxx"
-#include "accessibility/extended/AccessibleGridControlTableCell.hxx"
+#include <extended/AccessibleGridControlTable.hxx>
+#include <extended/AccessibleGridControlTableCell.hxx>
 #include <svtools/accessibletable.hxx>
 
 
-
 using ::com::sun::star::uno::Reference;
 using ::com::sun::star::uno::Sequence;
 using ::com::sun::star::uno::Any;
@@ -36,12 +35,10 @@ using namespace ::svt::table;
 namespace accessibility {
 
 
-
 AccessibleGridControlTable::AccessibleGridControlTable(
         const Reference< XAccessible >& rxParent,
-        IAccessibleTable& rTable,
-        AccessibleTableControlObjType _eType) :
-    AccessibleGridControlTableBase( rxParent, rTable, _eType )
+        IAccessibleTable& rTable) :
+    AccessibleGridControlTableBase( rxParent, rTable, TCTYPE_TABLE )
         ,m_pCellVector( )
         ,m_pAccessCellVector( )
 {
@@ -55,21 +52,20 @@ AccessibleGridControlTable::~AccessibleGridControlTable()
 
 Reference< XAccessible > SAL_CALL
 AccessibleGridControlTable::getAccessibleChild( sal_Int32 nChildIndex )
-    throw ( lang::IndexOutOfBoundsException, uno::RuntimeException, std::exception )
 {
     SolarMutexGuard aSolarGuard;
 
     ensureIsAlive();
     ensureIsValidIndex( nChildIndex );
     sal_Int32 nCount = getAccessibleChildCount();
-    if(m_pAccessCellVector.size() == 0 || m_pAccessCellVector.size() != (unsigned)nCount)
+    if(m_pAccessCellVector.empty() || m_pAccessCellVector.size() != (unsigned)nCount)
     {
         m_pAccessCellVector.resize(nCount);
         m_pCellVector.resize(nCount);
     }
     if(!m_pAccessCellVector[nChildIndex].is())
     {
-        AccessibleGridControlTableCell* pCell = new AccessibleGridControlTableCell(this, m_aTable, nChildIndex/m_aTable.GetColumnCount(), nChildIndex%m_aTable.GetColumnCount(), TCTYPE_TABLECELL);
+        AccessibleGridControlTableCell* pCell = new AccessibleGridControlTableCell(this, m_aTable, nChildIndex/m_aTable.GetColumnCount(), nChildIndex%m_aTable.GetColumnCount());
         m_pCellVector[nChildIndex] = pCell;
         m_pAccessCellVector[nChildIndex] = pCell;
     }
@@ -77,7 +73,6 @@ AccessibleGridControlTable::getAccessibleChild( sal_Int32 nChildIndex )
 }
 
 sal_Int32 SAL_CALL AccessibleGridControlTable::getAccessibleIndexInParent()
-    throw ( uno::RuntimeException, std::exception )
 {
     ensureIsAlive();
     if(m_aTable.HasRowHeader() && m_aTable.HasColHeader())
@@ -92,7 +87,6 @@ sal_Int32 SAL_CALL AccessibleGridControlTable::getAccessibleIndexInParent()
 
 Reference< XAccessible > SAL_CALL
 AccessibleGridControlTable::getAccessibleAtPoint( const awt::Point& rPoint )
-    throw ( uno::RuntimeException, std::exception )
 {
     SolarMutexGuard aSolarGuard;
 
@@ -102,12 +96,11 @@ AccessibleGridControlTable::getAccessibleAtPoint( const awt::Point& rPoint )
     sal_Int32 nRow = 0;
     sal_Int32 nColumnPos = 0;
     if( m_aTable.ConvertPointToCellAddress( nRow, nColumnPos, VCLPoint( rPoint ) ) )
-        xChild = new AccessibleGridControlTableCell(this, m_aTable, nRow, nColumnPos, TCTYPE_TABLECELL);
+        xChild = new AccessibleGridControlTableCell(this, m_aTable, nRow, nColumnPos);
     return xChild;
 }
 
 void SAL_CALL AccessibleGridControlTable::grabFocus()
-    throw ( uno::RuntimeException, std::exception )
 {
     SolarMutexGuard aSolarGuard;
 
@@ -118,7 +111,6 @@ void SAL_CALL AccessibleGridControlTable::grabFocus()
 // XAccessibleTable -----------------------------------------------------------
 
 OUString SAL_CALL AccessibleGridControlTable::getAccessibleRowDescription( sal_Int32 nRow )
-    throw ( lang::IndexOutOfBoundsException, uno::RuntimeException, std::exception )
 {
     SolarMutexGuard aSolarGuard;
 
@@ -128,7 +120,6 @@ OUString SAL_CALL AccessibleGridControlTable::getAccessibleRowDescription( sal_I
 }
 
 OUString SAL_CALL AccessibleGridControlTable::getAccessibleColumnDescription( sal_Int32 nColumn )
-    throw ( lang::IndexOutOfBoundsException, uno::RuntimeException, std::exception )
 {
     SolarMutexGuard aSolarGuard;
 
@@ -138,7 +129,6 @@ OUString SAL_CALL AccessibleGridControlTable::getAccessibleColumnDescription( sa
 }
 
 Reference< XAccessibleTable > SAL_CALL AccessibleGridControlTable::getAccessibleRowHeaders()
-    throw ( uno::RuntimeException, std::exception )
 {
     SolarMutexGuard g;
 
@@ -150,7 +140,6 @@ Reference< XAccessibleTable > SAL_CALL AccessibleGridControlTable::getAccessible
 }
 
 Reference< XAccessibleTable > SAL_CALL AccessibleGridControlTable::getAccessibleColumnHeaders()
-    throw ( uno::RuntimeException, std::exception )
 {
     SolarMutexGuard g;
 
@@ -159,7 +148,6 @@ Reference< XAccessibleTable > SAL_CALL AccessibleGridControlTable::getAccessible
 }
 
 Sequence< sal_Int32 > SAL_CALL AccessibleGridControlTable::getSelectedAccessibleRows()
-    throw ( uno::RuntimeException, std::exception )
 {
     SolarMutexGuard aSolarGuard;
 
@@ -171,14 +159,12 @@ Sequence< sal_Int32 > SAL_CALL AccessibleGridControlTable::getSelectedAccessible
 
 //columns aren't selectable
 Sequence< sal_Int32 > SAL_CALL AccessibleGridControlTable::getSelectedAccessibleColumns()
-    throw ( uno::RuntimeException, std::exception )
 {
     Sequence< sal_Int32 > aSelSeq(0);
     return aSelSeq;
 }
 
 sal_Bool SAL_CALL AccessibleGridControlTable::isAccessibleRowSelected( sal_Int32 nRow )
-    throw ( lang::IndexOutOfBoundsException, uno::RuntimeException, std::exception )
 {
     SolarMutexGuard aSolarGuard;
 
@@ -198,16 +184,13 @@ sal_Bool SAL_CALL AccessibleGridControlTable::isAccessibleRowSelected( sal_Int32
 }
 
 //columns aren't selectable
-sal_Bool SAL_CALL AccessibleGridControlTable::isAccessibleColumnSelected( sal_Int32 nColumn )
-    throw ( lang::IndexOutOfBoundsException, uno::RuntimeException, std::exception )
+sal_Bool SAL_CALL AccessibleGridControlTable::isAccessibleColumnSelected( sal_Int32 )
 {
-    (void) nColumn;
-    return sal_False;
+    return false;
 }
 
 Reference< XAccessible > SAL_CALL AccessibleGridControlTable::getAccessibleCellAt(
         sal_Int32 nRow, sal_Int32 nColumn )
-    throw ( lang::IndexOutOfBoundsException, uno::RuntimeException, std::exception )
 {
     SolarMutexGuard aSolarGuard;
 
@@ -215,14 +198,14 @@ Reference< XAccessible > SAL_CALL AccessibleGridControlTable::getAccessibleCellA
     ensureIsValidAddress( nRow, nColumn );
     sal_Int32 nCount = getAccessibleChildCount();
     sal_Int32 nChildIndex = nRow*m_aTable.GetColumnCount() + nColumn;
-    if(m_pAccessCellVector.size() == 0 || m_pAccessCellVector.size() != (unsigned)nCount)
+    if(m_pAccessCellVector.empty() || m_pAccessCellVector.size() != (unsigned)nCount)
     {
         m_pAccessCellVector.resize(nCount);
         m_pCellVector.resize(nCount);
     }
     if(!m_pAccessCellVector[nChildIndex].is())
     {
-        AccessibleGridControlTableCell* pCell = new AccessibleGridControlTableCell(this, m_aTable, nRow, nColumn, TCTYPE_TABLECELL);
+        AccessibleGridControlTableCell* pCell = new AccessibleGridControlTableCell(this, m_aTable, nRow, nColumn);
         m_pCellVector[nChildIndex] = pCell;
         m_pAccessCellVector[nChildIndex] = pCell;
     }
@@ -231,18 +214,15 @@ Reference< XAccessible > SAL_CALL AccessibleGridControlTable::getAccessibleCellA
 
 sal_Bool SAL_CALL AccessibleGridControlTable::isAccessibleSelected(
         sal_Int32 nRow, sal_Int32 nColumn )
-    throw ( lang::IndexOutOfBoundsException, uno::RuntimeException, std::exception )
 {
     SolarMutexGuard aSolarGuard;
 
     ensureIsAlive();
     ensureIsValidAddress( nRow, nColumn );
-    (void) nColumn;
     //selection of single cells not possible, so if row is selected, the cell will be selected too
     return isAccessibleRowSelected(nRow);
 }
 void SAL_CALL AccessibleGridControlTable::selectAccessibleChild( sal_Int32 nChildIndex )
-    throw ( lang::IndexOutOfBoundsException, uno::RuntimeException, std::exception )
 {
     SolarMutexGuard aSolarGuard;
 
@@ -253,7 +233,6 @@ void SAL_CALL AccessibleGridControlTable::selectAccessibleChild( sal_Int32 nChil
     m_aTable.SelectRow( nRow, true );
 }
 sal_Bool SAL_CALL AccessibleGridControlTable::isAccessibleChildSelected( sal_Int32 nChildIndex )
-    throw ( lang::IndexOutOfBoundsException, uno::RuntimeException, std::exception )
 {
     SolarMutexGuard aSolarGuard;
 
@@ -264,7 +243,6 @@ sal_Bool SAL_CALL AccessibleGridControlTable::isAccessibleChildSelected( sal_Int
     return isAccessibleRowSelected(nRow);
 }
 void SAL_CALL AccessibleGridControlTable::clearAccessibleSelection()
-    throw ( uno::RuntimeException, std::exception )
 {
     SolarMutexGuard aSolarGuard;
 
@@ -272,17 +250,15 @@ void SAL_CALL AccessibleGridControlTable::clearAccessibleSelection()
     m_aTable.SelectAllRows( false );
 }
 void SAL_CALL AccessibleGridControlTable::selectAllAccessibleChildren()
-    throw ( uno::RuntimeException, std::exception )
 {
     SolarMutexGuard aSolarGuard;
 
     ensureIsAlive();
     Sequence< sal_Int32 > selectedRows = getSelectedAccessibleRows();
-    for(int i=0;i<m_aTable.GetRowCount();i++)
+    for(long i=0; i<m_aTable.GetRowCount(); i++)
         selectedRows[i]=i;
 }
 sal_Int32 SAL_CALL AccessibleGridControlTable::getSelectedAccessibleChildCount()
-    throw ( uno::RuntimeException, std::exception )
 {
     SolarMutexGuard aSolarGuard;
 
@@ -293,7 +269,6 @@ sal_Int32 SAL_CALL AccessibleGridControlTable::getSelectedAccessibleChildCount()
 }
 Reference< XAccessible > SAL_CALL
 AccessibleGridControlTable::getSelectedAccessibleChild( sal_Int32 nSelectedChildIndex )
-    throw ( lang::IndexOutOfBoundsException, uno::RuntimeException, std::exception )
 {
     SolarMutexGuard aSolarGuard;
 
@@ -301,26 +276,23 @@ AccessibleGridControlTable::getSelectedAccessibleChild( sal_Int32 nSelectedChild
     if(isAccessibleChildSelected(nSelectedChildIndex))
         return getAccessibleChild(nSelectedChildIndex);
     else
-        return NULL;
+        return nullptr;
 }
 //not implemented yet, because only row selection possible
 void SAL_CALL AccessibleGridControlTable::deselectAccessibleChild(
-        sal_Int32 nSelectedChildIndex )
-    throw ( lang::IndexOutOfBoundsException, uno::RuntimeException, std::exception )
+        sal_Int32 )
 {
     SolarMutexGuard aSolarGuard;
 
     ensureIsAlive();
-    (void)nSelectedChildIndex;
 }
 // XInterface -----------------------------------------------------------------
 
 Any SAL_CALL AccessibleGridControlTable::queryInterface( const uno::Type& rType )
-    throw ( uno::RuntimeException, std::exception )
 {
     Any aAny( AccessibleGridControlTableBase::queryInterface( rType ) );
     return aAny.hasValue() ?
-        aAny : AccessibleGridControlTableImplHelper1::queryInterface( rType );
+        aAny : AccessibleGridControlTableSelectionImplHelper::queryInterface( rType );
 }
 
 void SAL_CALL AccessibleGridControlTable::acquire() throw ()
@@ -335,42 +307,40 @@ void SAL_CALL AccessibleGridControlTable::release() throw ()
 // XServiceInfo ---------------------------------------------------------------
 
 OUString SAL_CALL AccessibleGridControlTable::getImplementationName()
-    throw ( uno::RuntimeException, std::exception )
 {
     return OUString( "com.sun.star.accessibility.AccessibleGridControlTable" );
 }
 
 // internal virtual methods ---------------------------------------------------
 
-Rectangle AccessibleGridControlTable::implGetBoundingBox()
+tools::Rectangle AccessibleGridControlTable::implGetBoundingBox()
 {
-    Window* pParent = m_aTable.GetAccessibleParentWindow();
+    vcl::Window* pParent = m_aTable.GetAccessibleParentWindow();
     DBG_ASSERT( pParent, "implGetBoundingBox - missing parent window" );
-    Rectangle aGridRect( m_aTable.GetWindowExtentsRelative( pParent ));
-    Rectangle aTableRect( m_aTable.calcTableRect() );
+    tools::Rectangle aGridRect( m_aTable.GetWindowExtentsRelative( pParent ));
+    tools::Rectangle aTableRect( m_aTable.calcTableRect() );
     long nX = aGridRect.Left() + aTableRect.Left();
     long nY = aGridRect.Top() + aTableRect.Top();
     long nWidth = aGridRect.GetSize().Width()-aTableRect.Left();
     long nHeight = aGridRect.GetSize().Height()-aTableRect.Top();
-    Rectangle aTable( Point( nX, nY ), Size( nWidth, nHeight ));
+    tools::Rectangle aTable( Point( nX, nY ), Size( nWidth, nHeight ));
     return aTable;
 }
 
-Rectangle AccessibleGridControlTable::implGetBoundingBoxOnScreen()
+tools::Rectangle AccessibleGridControlTable::implGetBoundingBoxOnScreen()
 {
-    Rectangle aGridRect( m_aTable.GetWindowExtentsRelative( NULL ));
-    Rectangle aTableRect( m_aTable.calcTableRect() );
+    tools::Rectangle aGridRect( m_aTable.GetWindowExtentsRelative( nullptr ));
+    tools::Rectangle aTableRect( m_aTable.calcTableRect() );
     long nX = aGridRect.Left() + aTableRect.Left();
     long nY = aGridRect.Top() + aTableRect.Top();
     long nWidth = aGridRect.GetSize().Width()-aTableRect.Left();
     long nHeight = aGridRect.GetSize().Height()-aTableRect.Top();
-    Rectangle aTable( Point( nX, nY ), Size( nWidth, nHeight ));
+    tools::Rectangle aTable( Point( nX, nY ), Size( nWidth, nHeight ));
     return aTable;
 }
 // internal helper methods ----------------------------------------------------
 Reference< XAccessibleTable > AccessibleGridControlTable::implGetHeaderBar(
         sal_Int32 nChildIndex )
-    throw ( uno::RuntimeException )
 {
     Reference< XAccessible > xRet;
     Reference< XAccessibleContext > xContext( m_xParent, uno::UNO_QUERY );
@@ -389,19 +359,8 @@ Reference< XAccessibleTable > AccessibleGridControlTable::implGetHeaderBar(
     return Reference< XAccessibleTable >( xRet, uno::UNO_QUERY );
 }
 
-std::vector< AccessibleGridControlTableCell* >& AccessibleGridControlTable::getCellVector()
-{
-    return m_pCellVector;
-}
-
-std::vector< Reference< XAccessible > >& AccessibleGridControlTable::getAccessibleCellVector()
-{
-    return m_pAccessCellVector;
-}
-
 
 } // namespace accessibility
 
 
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
