@@ -17,19 +17,21 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include <accessibility/standard/vclxaccessiblescrollbar.hxx>
+#include <standard/vclxaccessiblescrollbar.hxx>
 
 #include <toolkit/awt/vclxwindows.hxx>
-#include <accessibility/helper/accresmgr.hxx>
-#include <accessibility/helper/accessiblestrings.hrc>
+#include <helper/accresmgr.hxx>
+#include <strings.hrc>
 
 #include <unotools/accessiblestatesethelper.hxx>
 #include <com/sun/star/accessibility/AccessibleStateType.hpp>
 #include <com/sun/star/accessibility/AccessibleEventId.hpp>
 #include <com/sun/star/awt/ScrollBarOrientation.hpp>
+#include <com/sun/star/lang/IndexOutOfBoundsException.hpp>
 #include <cppuhelper/typeprovider.hxx>
 #include <comphelper/sequence.hxx>
 #include <vcl/scrbar.hxx>
+#include <strings.hxx>
 
 using namespace ::com::sun::star;
 using namespace ::com::sun::star::uno;
@@ -49,18 +51,16 @@ VCLXAccessibleScrollBar::VCLXAccessibleScrollBar( VCLXWindow* pVCLWindow )
 }
 
 
-
 VCLXAccessibleScrollBar::~VCLXAccessibleScrollBar()
 {
 }
 
 
-
 void VCLXAccessibleScrollBar::ProcessWindowEvent( const VclWindowEvent& rVclWindowEvent )
 {
     switch ( rVclWindowEvent.GetId() )
     {
-        case VCLEVENT_SCROLLBAR_SCROLL:
+        case VclEventId::ScrollbarScroll:
         {
             NotifyAccessibleEvent( AccessibleEventId::VALUE_CHANGED, Any(), Any() );
         }
@@ -71,7 +71,6 @@ void VCLXAccessibleScrollBar::ProcessWindowEvent( const VclWindowEvent& rVclWind
 }
 
 
-
 void VCLXAccessibleScrollBar::FillAccessibleStateSet( utl::AccessibleStateSetHelper& rStateSet )
 {
     VCLXAccessibleComponent::FillAccessibleStateSet( rStateSet );
@@ -104,52 +103,49 @@ IMPLEMENT_FORWARD_XTYPEPROVIDER2( VCLXAccessibleScrollBar, VCLXAccessibleCompone
 // XServiceInfo
 
 
-OUString VCLXAccessibleScrollBar::getImplementationName() throw (RuntimeException, std::exception)
+OUString VCLXAccessibleScrollBar::getImplementationName()
 {
     return OUString( "com.sun.star.comp.toolkit.AccessibleScrollBar" );
 }
 
 
-
-Sequence< OUString > VCLXAccessibleScrollBar::getSupportedServiceNames() throw (RuntimeException, std::exception)
+Sequence< OUString > VCLXAccessibleScrollBar::getSupportedServiceNames()
 {
-    Sequence< OUString > aNames(1);
-    aNames[0] = "com.sun.star.awt.AccessibleScrollBar";
-    return aNames;
+    return { "com.sun.star.awt.AccessibleScrollBar" };
 }
 
 
 // XAccessibleAction
 
+static constexpr sal_Int32 ACCESSIBLE_ACTION_COUNT=4;
 
-sal_Int32 VCLXAccessibleScrollBar::getAccessibleActionCount( ) throw (RuntimeException, std::exception)
+sal_Int32 VCLXAccessibleScrollBar::getAccessibleActionCount( )
 {
     OExternalLockGuard aGuard( this );
 
-    return 4;
+    return ACCESSIBLE_ACTION_COUNT;
 }
 
 
-
-sal_Bool VCLXAccessibleScrollBar::doAccessibleAction ( sal_Int32 nIndex ) throw (IndexOutOfBoundsException, RuntimeException, std::exception)
+sal_Bool VCLXAccessibleScrollBar::doAccessibleAction ( sal_Int32 nIndex )
 {
     OExternalLockGuard aGuard( this );
 
-    if ( nIndex < 0 || nIndex >= getAccessibleActionCount() )
+    if ( nIndex < 0 || nIndex >= ACCESSIBLE_ACTION_COUNT )
         throw IndexOutOfBoundsException();
 
     bool bReturn = false;
-    ScrollBar* pScrollBar = static_cast< ScrollBar* >( GetWindow() );
+    VclPtr< ScrollBar > pScrollBar = GetAs< ScrollBar >();
     if ( pScrollBar )
     {
         ScrollType eScrollType;
         switch ( nIndex )
         {
-            case 0:     eScrollType = SCROLL_LINEUP;    break;
-            case 1:     eScrollType = SCROLL_LINEDOWN;  break;
-            case 2:     eScrollType = SCROLL_PAGEUP;    break;
-            case 3:     eScrollType = SCROLL_PAGEDOWN;  break;
-            default:    eScrollType = SCROLL_DONTKNOW;  break;
+            case 0:     eScrollType = ScrollType::LineUp;    break;
+            case 1:     eScrollType = ScrollType::LineDown;  break;
+            case 2:     eScrollType = ScrollType::PageUp;    break;
+            case 3:     eScrollType = ScrollType::PageDown;  break;
+            default:    eScrollType = ScrollType::DontKnow;  break;
         }
         if ( pScrollBar->DoScrollAction( eScrollType ) )
             bReturn = true;
@@ -159,35 +155,33 @@ sal_Bool VCLXAccessibleScrollBar::doAccessibleAction ( sal_Int32 nIndex ) throw
 }
 
 
-
-OUString VCLXAccessibleScrollBar::getAccessibleActionDescription ( sal_Int32 nIndex ) throw (IndexOutOfBoundsException, RuntimeException, std::exception)
+OUString VCLXAccessibleScrollBar::getAccessibleActionDescription ( sal_Int32 nIndex )
 {
     OExternalLockGuard aGuard( this );
 
-    if ( nIndex < 0 || nIndex >= getAccessibleActionCount() )
+    if ( nIndex < 0 || nIndex >= ACCESSIBLE_ACTION_COUNT )
         throw IndexOutOfBoundsException();
 
     OUString sDescription;
 
     switch ( nIndex )
     {
-        case 0:     sDescription = OUString( TK_RES_STRING( RID_STR_ACC_ACTION_DECLINE ) );      break;
-        case 1:     sDescription = OUString( TK_RES_STRING( RID_STR_ACC_ACTION_INCLINE ) );      break;
-        case 2:     sDescription = OUString( TK_RES_STRING( RID_STR_ACC_ACTION_DECBLOCK ) );     break;
-        case 3:     sDescription = OUString( TK_RES_STRING( RID_STR_ACC_ACTION_INCBLOCK ) );     break;
-        default:                                                                                        break;
+        case 0:     sDescription = OUString(RID_STR_ACC_ACTION_DECLINE);      break;
+        case 1:     sDescription = OUString(RID_STR_ACC_ACTION_INCLINE);      break;
+        case 2:     sDescription = OUString(RID_STR_ACC_ACTION_DECBLOCK);     break;
+        case 3:     sDescription = OUString(RID_STR_ACC_ACTION_INCBLOCK);     break;
+        default:                                                              break;
     }
 
     return sDescription;
 }
 
 
-
-Reference< XAccessibleKeyBinding > VCLXAccessibleScrollBar::getAccessibleActionKeyBinding( sal_Int32 nIndex ) throw (IndexOutOfBoundsException, RuntimeException, std::exception)
+Reference< XAccessibleKeyBinding > VCLXAccessibleScrollBar::getAccessibleActionKeyBinding( sal_Int32 nIndex )
 {
     OExternalLockGuard aGuard( this );
 
-    if ( nIndex < 0 || nIndex >= getAccessibleActionCount() )
+    if ( nIndex < 0 || nIndex >= ACCESSIBLE_ACTION_COUNT )
         throw IndexOutOfBoundsException();
 
     return Reference< XAccessibleKeyBinding >();
@@ -197,7 +191,7 @@ Reference< XAccessibleKeyBinding > VCLXAccessibleScrollBar::getAccessibleActionK
 // XAccessibleValue
 
 
-Any VCLXAccessibleScrollBar::getCurrentValue(  ) throw (RuntimeException, std::exception)
+Any VCLXAccessibleScrollBar::getCurrentValue(  )
 {
     OExternalLockGuard aGuard( this );
 
@@ -205,14 +199,13 @@ Any VCLXAccessibleScrollBar::getCurrentValue(  ) throw (RuntimeException, std::e
 
     VCLXScrollBar* pVCLXScrollBar = static_cast< VCLXScrollBar* >( GetVCLXWindow() );
     if ( pVCLXScrollBar )
-        aValue <<= (sal_Int32) pVCLXScrollBar->getValue();
+        aValue <<=  pVCLXScrollBar->getValue();
 
     return aValue;
 }
 
 
-
-sal_Bool VCLXAccessibleScrollBar::setCurrentValue( const Any& aNumber ) throw (RuntimeException, std::exception)
+sal_Bool VCLXAccessibleScrollBar::setCurrentValue( const Any& aNumber )
 {
     OExternalLockGuard aGuard( this );
 
@@ -239,8 +232,7 @@ sal_Bool VCLXAccessibleScrollBar::setCurrentValue( const Any& aNumber ) throw (R
 }
 
 
-
-Any VCLXAccessibleScrollBar::getMaximumValue(  ) throw (RuntimeException, std::exception)
+Any VCLXAccessibleScrollBar::getMaximumValue(  )
 {
     OExternalLockGuard aGuard( this );
 
@@ -248,14 +240,13 @@ Any VCLXAccessibleScrollBar::getMaximumValue(  ) throw (RuntimeException, std::e
 
     VCLXScrollBar* pVCLXScrollBar = static_cast< VCLXScrollBar* >( GetVCLXWindow() );
     if ( pVCLXScrollBar )
-        aValue <<= (sal_Int32) pVCLXScrollBar->getMaximum();
+        aValue <<= pVCLXScrollBar->getMaximum();
 
     return aValue;
 }
 
 
-
-Any VCLXAccessibleScrollBar::getMinimumValue(  ) throw (RuntimeException, std::exception)
+Any VCLXAccessibleScrollBar::getMinimumValue(  )
 {
     OExternalLockGuard aGuard( this );
 
@@ -266,8 +257,7 @@ Any VCLXAccessibleScrollBar::getMinimumValue(  ) throw (RuntimeException, std::e
 }
 
 
-
-OUString VCLXAccessibleScrollBar::getAccessibleName(  ) throw (uno::RuntimeException, std::exception)
+OUString VCLXAccessibleScrollBar::getAccessibleName(  )
 {
     OExternalLockGuard aGuard( this );
 
@@ -276,9 +266,9 @@ OUString VCLXAccessibleScrollBar::getAccessibleName(  ) throw (uno::RuntimeExcep
     if ( pVCLXScrollBar )
     {
         if ( pVCLXScrollBar->getOrientation() == ScrollBarOrientation::HORIZONTAL )
-            aName = TK_RES_STRING( RID_STR_ACC_SCROLLBAR_NAME_HORIZONTAL );
+            aName = AccResId( RID_STR_ACC_SCROLLBAR_NAME_HORIZONTAL );
         else if ( pVCLXScrollBar->getOrientation() == ScrollBarOrientation::VERTICAL )
-            aName = TK_RES_STRING( RID_STR_ACC_SCROLLBAR_NAME_VERTICAL );
+            aName = AccResId( RID_STR_ACC_SCROLLBAR_NAME_VERTICAL );
     }
     return aName;
 }
