@@ -21,7 +21,7 @@
 #include "player.hxx"
 
 #include <tools/stream.hxx>
-#include <vcl/graphic.hxx>
+#include <vcl/graph.hxx>
 #include <vcl/cvtgrf.hxx>
 #include <unotools/localfilehelper.hxx>
 
@@ -29,15 +29,10 @@ using namespace ::com::sun::star;
 
 namespace avmedia { namespace macavf {
 
-// ----------------
-// - FrameGrabber -
-// ----------------
-
 FrameGrabber::FrameGrabber( const uno::Reference< lang::XMultiServiceFactory >& /*rxMgr*/ )
 :   mpImageGen( nullptr )
 {}
 
-// ------------------------------------------------------------------------------
 
 FrameGrabber::~FrameGrabber()
 {
@@ -45,7 +40,6 @@ FrameGrabber::~FrameGrabber()
         CFRelease( mpImageGen );
 }
 
-// ------------------------------------------------------------------------------
 
 bool FrameGrabber::create( const ::rtl::OUString& rURL )
 {
@@ -57,20 +51,19 @@ bool FrameGrabber::create( const ::rtl::OUString& rURL )
     AVAsset* pMovie = [AVURLAsset URLAssetWithURL:pNSURL options:nil];
     if( !pMovie )
     {
-        OSL_TRACE( "AVGrabber::create() cannot load url=\"%s\"", [pNSStr UTF8String] );
+        SAL_WARN("avmedia", "AVGrabber::create() cannot load url=" << [pNSStr UTF8String] );
         return false;
     }
 
     return create( pMovie );
 }
 
-// ------------------------------------------------------------------------------
 
 bool FrameGrabber::create( AVAsset* pMovie )
 {
     if( [[pMovie tracksWithMediaType:AVMediaTypeVideo] count] == 0)
     {
-        OSL_TRACE( "AVGrabber::create() found no video content!" );
+        SAL_WARN("avmedia", "AVGrabber::create() found no video content!" );
         return false;
     }
 
@@ -79,15 +72,12 @@ bool FrameGrabber::create( AVAsset* pMovie )
     return true;
 }
 
-// ------------------------------------------------------------------------------
 
 uno::Reference< graphic::XGraphic > SAL_CALL FrameGrabber::grabFrame( double fMediaTime )
-    throw (uno::RuntimeException)
 {
     uno::Reference< graphic::XGraphic > xRet;
     if( !mpImageGen )
         return xRet;
-    OSL_TRACE( "AVPlayer::grabFrame( %.3fsec)", fMediaTime );
 
     // get the requested image from the movie
     CGImage* pCGImage = [mpImageGen copyCGImageAtTime:CMTimeMakeWithSeconds(fMediaTime,1000) actualTime:nullptr error:nullptr];
@@ -112,30 +102,20 @@ uno::Reference< graphic::XGraphic > SAL_CALL FrameGrabber::grabFrame( double fMe
     return xRet;
 }
 
-// ------------------------------------------------------------------------------
 
 ::rtl::OUString SAL_CALL FrameGrabber::getImplementationName(  )
-    throw (uno::RuntimeException)
 {
-    return ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( AVMEDIA_MACAVF_FRAMEGRABBER_IMPLEMENTATIONNAME ) );
+    return ::rtl::OUString( AVMEDIA_MACAVF_FRAMEGRABBER_IMPLEMENTATIONNAME );
 }
 
-// ------------------------------------------------------------------------------
-
 sal_Bool SAL_CALL FrameGrabber::supportsService( const ::rtl::OUString& ServiceName )
-    throw (uno::RuntimeException)
 {
-    return ServiceName.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM ( AVMEDIA_MACAVF_FRAMEGRABBER_SERVICENAME ) );
+    return ServiceName == AVMEDIA_MACAVF_FRAMEGRABBER_SERVICENAME;
 }
 
-// ------------------------------------------------------------------------------
-
 uno::Sequence< ::rtl::OUString > SAL_CALL FrameGrabber::getSupportedServiceNames(  )
-    throw (uno::RuntimeException)
 {
-    uno::Sequence< ::rtl::OUString > aRet { AVMEDIA_MACAVF_FRAMEGRABBER_SERVICENAME };
-
-    return aRet;
+    return { AVMEDIA_MACAVF_FRAMEGRABBER_SERVICENAME };
 }
 
 } // namespace macavf
