@@ -24,7 +24,6 @@
 #include <objbase.h>
 #include <strmif.h>
 #include <control.h>
-#define STRSAFE_NO_DEPRECATE
 #include <dshow.h>
 #if defined _MSC_VER
 #pragma warning(pop)
@@ -42,48 +41,30 @@ using namespace ::com::sun::star;
 
 namespace avmedia { namespace win {
 
-static ::osl::Mutex& ImplGetOwnStaticMutex()
-{
-    static ::osl::Mutex* pMutex = NULL;
-
-    if( pMutex == NULL )
-    {
-        ::osl::MutexGuard aGuard( ::osl::Mutex::getGlobalMutex() );
-
-        if( pMutex == NULL )
-        {
-            static ::osl::Mutex aMutex;
-            pMutex = &aMutex;
-        }
-    }
-
-    return *pMutex;
-}
-
 LRESULT CALLBACK MediaPlayerWndProc( HWND hWnd,UINT nMsg, WPARAM nPar1, LPARAM nPar2 )
 {
-    Window* pWindow = (Window*) ::GetWindowLongPtr( hWnd, 0 );
+    Window* pWindow = reinterpret_cast<Window*>(GetWindowLongPtrW( hWnd, 0 ));
     bool    bProcessed = true;
 
     if( pWindow )
     {
         switch( nMsg )
         {
-            case( WM_SETCURSOR ):
+            case WM_SETCURSOR:
                 pWindow->updatePointer();
             break;
 
-            case( WM_GRAPHNOTIFY ):
+            case WM_GRAPHNOTIFY:
                 pWindow->processGraphEvent();
             break;
 
-            case( WM_MOUSEMOVE ):
-            case( WM_LBUTTONDOWN ):
-            case( WM_MBUTTONDOWN ):
-            case( WM_RBUTTONDOWN ):
-            case( WM_LBUTTONUP ):
-            case( WM_MBUTTONUP ):
-            case( WM_RBUTTONUP ):
+            case WM_MOUSEMOVE:
+            case WM_LBUTTONDOWN:
+            case WM_MBUTTONDOWN:
+            case WM_RBUTTONDOWN:
+            case WM_LBUTTONUP:
+            case WM_MBUTTONUP:
+            case WM_RBUTTONUP:
             {
                 awt::MouseEvent aUNOEvt;
                 POINT           aWinPoint;
@@ -140,7 +121,7 @@ LRESULT CALLBACK MediaPlayerWndProc( HWND hWnd,UINT nMsg, WPARAM nPar1, LPARAM n
             }
             break;
 
-            case( WM_SETFOCUS ):
+            case WM_SETFOCUS:
             {
                 const awt::FocusEvent aUNOEvt;
                 pWindow->fireSetFocusEvent( aUNOEvt );
@@ -155,41 +136,35 @@ LRESULT CALLBACK MediaPlayerWndProc( HWND hWnd,UINT nMsg, WPARAM nPar1, LPARAM n
     else
         bProcessed = false;
 
-    return( bProcessed ? 0 : DefWindowProc( hWnd, nMsg, nPar1, nPar2 ) );
+    return( bProcessed ? 0 : DefWindowProcW( hWnd, nMsg, nPar1, nPar2 ) );
 }
 
-WNDCLASS* lcl_getWndClass()
+WNDCLASSW* lcl_getWndClass()
 {
-    static WNDCLASS* s_pWndClass = NULL;
-    if ( !s_pWndClass )
-    {
-        s_pWndClass = new WNDCLASS;
+    WNDCLASSW* s_pWndClass = new WNDCLASSW;
 
-        memset( s_pWndClass, 0, sizeof( *s_pWndClass ) );
-        s_pWndClass->hInstance = GetModuleHandle( NULL );
-        s_pWndClass->cbWndExtra = sizeof( DWORD );
-        s_pWndClass->lpfnWndProc = MediaPlayerWndProc;
-        s_pWndClass->lpszClassName = "com_sun_star_media_PlayerWnd";
-        s_pWndClass->hbrBackground = (HBRUSH) ::GetStockObject( BLACK_BRUSH );
-        s_pWndClass->hCursor = ::LoadCursor( NULL, IDC_ARROW );
+    memset( s_pWndClass, 0, sizeof( *s_pWndClass ) );
+    s_pWndClass->hInstance = GetModuleHandleW( nullptr );
+    s_pWndClass->cbWndExtra = sizeof( DWORD );
+    s_pWndClass->lpfnWndProc = MediaPlayerWndProc;
+    s_pWndClass->lpszClassName = L"com_sun_star_media_PlayerWnd";
+    s_pWndClass->hbrBackground = static_cast<HBRUSH>(::GetStockObject( BLACK_BRUSH ));
+    s_pWndClass->hCursor = ::LoadCursor( nullptr, IDC_ARROW );
+
+    RegisterClassW( s_pWndClass );
 
-        ::RegisterClass( s_pWndClass );
-    }
     return s_pWndClass;
 }
 
 Window::Window( const uno::Reference< lang::XMultiServiceFactory >& rxMgr, Player& rPlayer ) :
     mxMgr( rxMgr ),
-    mrPlayer( rPlayer ),
-    meZoomLevel( media::ZoomLevel_NOT_AVAILABLE ),
-    mnParentWnd( 0 ),
-    mnFrameWnd( 0 ),
     maListeners( maMutex ),
+    meZoomLevel( media::ZoomLevel_NOT_AVAILABLE ),
+    mrPlayer( rPlayer ),
+    mnFrameWnd( nullptr ),
+    mnParentWnd( nullptr ),
     mnPointerType( awt::SystemPointer::ARROW )
 {
-    ::osl::MutexGuard aGuard( ImplGetOwnStaticMutex() );
-
-    lcl_getWndClass();
 }
 
 Window::~Window()
@@ -286,7 +261,7 @@ void Window::ImplLayoutVideoWindow()
 bool Window::create( const uno::Sequence< uno::Any >& rArguments )
 {
     IVideoWindow* pVideoWindow = const_cast< IVideoWindow* >( mrPlayer.getVideoWindow() );
-    WNDCLASS* mpWndClass = lcl_getWndClass();
+    static WNDCLASSW* mpWndClass = lcl_getWndClass();
 
     if( !mnFrameWnd && pVideoWindow && mpWndClass )
     {
@@ -298,27 +273,27 @@ bool Window::create( const uno::Sequence< uno::Any >& rArguments )
 
         mnParentWnd = reinterpret_cast<HWND>(nWnd);
 
-        mnFrameWnd = ::CreateWindow( mpWndClass->lpszClassName, NULL,
-                                           WS_VISIBLE | WS_CHILD | WS_CLIPSIBLINGS | WS_CLIPCHILDREN,
-                                           aRect.X, aRect.Y, aRect.Width, aRect.Height,
-                                           mnParentWnd, NULL, mpWndClass->hInstance, 0 );
+        mnFrameWnd = CreateWindowW( mpWndClass->lpszClassName, nullptr,
+                                    WS_VISIBLE | WS_CHILD | WS_CLIPSIBLINGS | WS_CLIPCHILDREN,
+                                    aRect.X, aRect.Y, aRect.Width, aRect.Height,
+                                    mnParentWnd, nullptr, mpWndClass->hInstance, nullptr );
 
         if( mnFrameWnd )
         {
-            ::SetWindowLongPtr( mnFrameWnd, 0, (LONG_PTR) this );
+            SetWindowLongPtrW( mnFrameWnd, 0, reinterpret_cast<LONG_PTR>(this) );
 
-                        pVideoWindow->put_Owner( (OAHWND) mnFrameWnd );
-                        pVideoWindow->put_MessageDrain( (OAHWND) mnFrameWnd );
-                        pVideoWindow->put_WindowStyle( WS_VISIBLE | WS_CHILD | WS_CLIPSIBLINGS | WS_CLIPCHILDREN );
+            pVideoWindow->put_Owner( reinterpret_cast<OAHWND>(mnFrameWnd) );
+            pVideoWindow->put_MessageDrain( reinterpret_cast<OAHWND>(mnFrameWnd) );
+            pVideoWindow->put_WindowStyle( WS_VISIBLE | WS_CHILD | WS_CLIPSIBLINGS | WS_CLIPCHILDREN );
 
-                        mrPlayer.setNotifyWnd( mnFrameWnd );
+            mrPlayer.setNotifyWnd( mnFrameWnd );
 
-                        meZoomLevel = media::ZoomLevel_FIT_TO_WINDOW;
-                        ImplLayoutVideoWindow();
+            meZoomLevel = media::ZoomLevel_FIT_TO_WINDOW;
+            ImplLayoutVideoWindow();
         }
     }
 
-    return( mnFrameWnd != 0 );
+    return( mnFrameWnd != nullptr );
 }
 
 void Window::processGraphEvent()
@@ -328,30 +303,28 @@ void Window::processGraphEvent()
 
 void Window::updatePointer()
 {
-    char* pCursorName;
+    LPCTSTR pCursorName;
 
     switch( mnPointerType )
     {
-        case( awt::SystemPointer::CROSS ): pCursorName = IDC_CROSS; break;
-        case( awt::SystemPointer::MOVE ): pCursorName = IDC_SIZEALL; break;
-        case( awt::SystemPointer::WAIT ): pCursorName = IDC_WAIT; break;
+        case awt::SystemPointer::CROSS: pCursorName = IDC_CROSS; break;
+        case awt::SystemPointer::MOVE: pCursorName = IDC_SIZEALL; break;
+        case awt::SystemPointer::WAIT: pCursorName = IDC_WAIT; break;
 
         default:
             pCursorName = IDC_ARROW;
         break;
     }
 
-    ::SetCursor( ::LoadCursor( NULL, pCursorName ) );
+    SetCursor( LoadCursor( nullptr, pCursorName ) );
 }
 
 void SAL_CALL Window::update(  )
-    throw (uno::RuntimeException)
 {
-    ::RedrawWindow( (HWND) mnFrameWnd, NULL, NULL, RDW_ALLCHILDREN | RDW_INVALIDATE | RDW_UPDATENOW | RDW_ERASE  );
+    ::RedrawWindow( mnFrameWnd, nullptr, nullptr, RDW_ALLCHILDREN | RDW_INVALIDATE | RDW_UPDATENOW | RDW_ERASE  );
 }
 
 sal_Bool SAL_CALL Window::setZoomLevel( media::ZoomLevel eZoomLevel )
-    throw (uno::RuntimeException)
 {
         boolean bRet = false;
 
@@ -371,19 +344,16 @@ sal_Bool SAL_CALL Window::setZoomLevel( media::ZoomLevel eZoomLevel )
 }
 
 media::ZoomLevel SAL_CALL Window::getZoomLevel(  )
-    throw (uno::RuntimeException)
 {
     return meZoomLevel;
 }
 
 void SAL_CALL Window::setPointerType( sal_Int32 nPointerType )
-    throw (uno::RuntimeException)
 {
     mnPointerType = nPointerType;
 }
 
 void SAL_CALL Window::setPosSize( sal_Int32 X, sal_Int32 Y, sal_Int32 Width, sal_Int32 Height, sal_Int16 )
-    throw (uno::RuntimeException)
 {
     if( mnFrameWnd )
     {
@@ -393,7 +363,6 @@ void SAL_CALL Window::setPosSize( sal_Int32 X, sal_Int32 Y, sal_Int32 Width, sal
 }
 
 awt::Rectangle SAL_CALL Window::getPosSize()
-    throw (uno::RuntimeException)
 {
     awt::Rectangle aRet;
 
@@ -414,7 +383,6 @@ awt::Rectangle SAL_CALL Window::getPosSize()
 }
 
 void SAL_CALL Window::setVisible( sal_Bool bVisible )
-    throw (uno::RuntimeException)
 {
     if( mnFrameWnd )
     {
@@ -428,104 +396,87 @@ void SAL_CALL Window::setVisible( sal_Bool bVisible )
 }
 
 void SAL_CALL Window::setEnable( sal_Bool bEnable )
-    throw (uno::RuntimeException)
 {
     if( mnFrameWnd )
         ::EnableWindow( mnFrameWnd, bEnable );
 }
 
 void SAL_CALL Window::setFocus(  )
-    throw (uno::RuntimeException)
 {
     if( mnFrameWnd )
         ::SetFocus( mnFrameWnd );
 }
 
 void SAL_CALL Window::addWindowListener( const uno::Reference< awt::XWindowListener >& xListener )
-    throw (uno::RuntimeException)
 {
     maListeners.addInterface( cppu::UnoType<decltype(xListener)>::get(), xListener );
 }
 
 void SAL_CALL Window::removeWindowListener( const uno::Reference< awt::XWindowListener >& xListener )
-    throw (uno::RuntimeException)
 {
     maListeners.removeInterface( cppu::UnoType<decltype(xListener)>::get(), xListener );
 }
 
 void SAL_CALL Window::addFocusListener( const uno::Reference< awt::XFocusListener >& xListener )
-    throw (uno::RuntimeException)
 {
     maListeners.addInterface( cppu::UnoType<decltype(xListener)>::get(), xListener );
 }
 
 void SAL_CALL Window::removeFocusListener( const uno::Reference< awt::XFocusListener >& xListener )
-    throw (uno::RuntimeException)
 {
     maListeners.removeInterface( cppu::UnoType<decltype(xListener)>::get(), xListener );
 }
 
 void SAL_CALL Window::addKeyListener( const uno::Reference< awt::XKeyListener >& xListener )
-    throw (uno::RuntimeException)
 {
     maListeners.addInterface( cppu::UnoType<decltype(xListener)>::get(), xListener );
 }
 
 void SAL_CALL Window::removeKeyListener( const uno::Reference< awt::XKeyListener >& xListener )
-    throw (uno::RuntimeException)
 {
     maListeners.removeInterface( cppu::UnoType<decltype(xListener)>::get(), xListener );
 }
 
 void SAL_CALL Window::addMouseListener( const uno::Reference< awt::XMouseListener >& xListener )
-    throw (uno::RuntimeException)
 {
     maListeners.addInterface( cppu::UnoType<decltype(xListener)>::get(), xListener );
 }
 
 void SAL_CALL Window::removeMouseListener( const uno::Reference< awt::XMouseListener >& xListener )
-    throw (uno::RuntimeException)
 {
     maListeners.removeInterface( cppu::UnoType<decltype(xListener)>::get(), xListener );
 }
 
 void SAL_CALL Window::addMouseMotionListener( const uno::Reference< awt::XMouseMotionListener >& xListener )
-    throw (uno::RuntimeException)
 {
     maListeners.addInterface( cppu::UnoType<decltype(xListener)>::get(), xListener );
 }
 
 void SAL_CALL Window::removeMouseMotionListener( const uno::Reference< awt::XMouseMotionListener >& xListener )
-    throw (uno::RuntimeException)
 {
     maListeners.removeInterface( cppu::UnoType<decltype(xListener)>::get(), xListener );
 }
 
 void SAL_CALL Window::addPaintListener( const uno::Reference< awt::XPaintListener >& xListener )
-    throw (uno::RuntimeException)
 {
     maListeners.addInterface( cppu::UnoType<decltype(xListener)>::get(), xListener );
 }
 
 void SAL_CALL Window::removePaintListener( const uno::Reference< awt::XPaintListener >& xListener )
-    throw (uno::RuntimeException)
 {
     maListeners.removeInterface( cppu::UnoType<decltype(xListener)>::get(), xListener );
 }
 
 void SAL_CALL Window::dispose(  )
-    throw (uno::RuntimeException)
 {
 }
 
 void SAL_CALL Window::addEventListener( const uno::Reference< lang::XEventListener >& xListener )
-    throw (uno::RuntimeException)
 {
     maListeners.addInterface( cppu::UnoType<decltype(xListener)>::get(), xListener );
 }
 
 void SAL_CALL Window::removeEventListener( const uno::Reference< lang::XEventListener >& xListener )
-    throw (uno::RuntimeException)
 {
     maListeners.removeInterface( cppu::UnoType<decltype(xListener)>::get(), xListener );
 }
@@ -583,23 +534,18 @@ void Window::fireSetFocusEvent( const css::awt::FocusEvent& rEvt )
 }
 
 OUString SAL_CALL Window::getImplementationName(  )
-    throw (uno::RuntimeException)
 {
     return OUString( AVMEDIA_WIN_WINDOW_IMPLEMENTATIONNAME );
 }
 
 sal_Bool SAL_CALL Window::supportsService( const OUString& ServiceName )
-    throw (uno::RuntimeException)
 {
     return cppu::supportsService(this, ServiceName);
 }
 
 uno::Sequence< OUString > SAL_CALL Window::getSupportedServiceNames(  )
-    throw (uno::RuntimeException)
 {
-    uno::Sequence<OUString> aRet { AVMEDIA_WIN_WINDOW_SERVICENAME };
-
-    return aRet;
+    return { AVMEDIA_WIN_WINDOW_SERVICENAME };
 }
 
 } // namespace win
