@@ -17,19 +17,21 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "basidesh.hrc"
-#include "helpid.hrc"
+#include <memory>
+#include <strings.hrc>
+#include <helpids.h>
 
 #include "baside2.hxx"
-#include "baside3.hxx"
-#include "docsignature.hxx"
-#include "iderdll.hxx"
+#include <baside3.hxx>
+#include <docsignature.hxx>
+#include <iderdll.hxx>
 #include "iderdll2.hxx"
-#include "localizationmgr.hxx"
-#include "managelang.hxx"
+#include <localizationmgr.hxx>
+#include <managelang.hxx>
 
 #include <basic/basmgr.hxx>
 #include <basic/sbmeth.hxx>
+#include <com/sun/star/script/ModuleType.hpp>
 #include <com/sun/star/script/XLibraryContainerPassword.hpp>
 #include <com/sun/star/frame/XLayoutManager.hpp>
 #include <sfx2/childwin.hxx>
@@ -39,6 +41,7 @@
 #include <sfx2/minfitem.hxx>
 #include <sfx2/printer.hxx>
 #include <sfx2/request.hxx>
+#include <svx/svxids.hrc>
 #include <svl/aeitem.hxx>
 #include <svl/intitem.hxx>
 #include <svl/srchitem.hxx>
@@ -97,7 +100,7 @@ void Shell::ExecuteCurrent( SfxRequest& rReq )
                         nActModWindows++;
                 }
 
-                if ( nActModWindows <= 1 || ( !rSearchItem.GetSelection() && ScopedVclPtr<QueryBox>::Create( pCurWin, WB_YES_NO|WB_DEF_YES, IDEResId(RID_STR_SEARCHALLMODULES).toString() )->Execute() == RET_YES ) )
+                if ( nActModWindows <= 1 || ( !rSearchItem.GetSelection() && ScopedVclPtrInstance<QueryBox>(pCurWin, MessBoxStyle::YesNo|MessBoxStyle::DefaultYes, IDEResId(RID_STR_SEARCHALLMODULES))->Execute() == RET_YES ) )
                 {
                     for (WindowTableIt it = aWindowTable.begin(); it != aWindowTable.end(); ++it)
                     {
@@ -108,9 +111,9 @@ void Shell::ExecuteCurrent( SfxRequest& rReq )
                 else
                     nFound = pCurWin->StartSearchAndReplace(rSearchItem);
 
-                OUString aReplStr(IDE_RESSTR(RID_STR_SEARCHREPLACES));
+                OUString aReplStr(IDEResId(RID_STR_SEARCHREPLACES));
                 aReplStr = aReplStr.replaceAll("XX", OUString::number(nFound));
-                ScopedVclPtr<InfoBox>::Create( pCurWin, aReplStr )->Execute();
+                ScopedVclPtrInstance<InfoBox>(pCurWin, aReplStr)->Execute();
             }
             else
             {
@@ -136,7 +139,7 @@ void Shell::ExecuteCurrent( SfxRequest& rReq )
                             SfxViewFrame* pViewFrame = GetViewFrame();
                             SfxChildWindow* pChildWin = pViewFrame ? pViewFrame->GetChildWindow( SID_SEARCH_DLG ) : nullptr;
                             vcl::Window* pParent = pChildWin ? pChildWin->GetWindow() : nullptr;
-                            ScopedVclPtrInstance< QueryBox > aQuery(pParent, WB_YES_NO|WB_DEF_YES, IDE_RESSTR(RID_STR_SEARCHFROMSTART));
+                            ScopedVclPtrInstance< QueryBox > aQuery(pParent, MessBoxStyle::YesNo|MessBoxStyle::DefaultYes, IDEResId(RID_STR_SEARCHFROMSTART));
                             if ( aQuery->Execute() == RET_YES )
                             {
                                 it = aWindowTable.begin();
@@ -177,7 +180,7 @@ void Shell::ExecuteCurrent( SfxRequest& rReq )
                         SetCurWindow( pWin, true );
                 }
                 if ( !nFound && !bCanceled )
-                    ScopedVclPtr<InfoBox>::Create( pCurWin, IDEResId(RID_STR_SEARCHNOTFOUND).toString() )->Execute();
+                    ScopedVclPtrInstance<InfoBox>(pCurWin, IDEResId(RID_STR_SEARCHNOTFOUND))->Execute();
             }
 
             rReq.Done();
@@ -238,7 +241,7 @@ void Shell::ExecuteGlobal( SfxRequest& rReq )
                         }
 
                         if ( xStatusIndicator.is() )
-                            rReq.AppendItem( SfxUnoAnyItem( SID_PROGRESS_STATUSBAR_CONTROL, uno::makeAny( xStatusIndicator ) ) );
+                            rReq.AppendItem( SfxUnoAnyItem( SID_PROGRESS_STATUSBAR_CONTROL, uno::Any( xStatusIndicator ) ) );
                     }
 
                     aDocument.saveDocument( xStatusIndicator );
@@ -266,7 +269,7 @@ void Shell::ExecuteGlobal( SfxRequest& rReq )
         break;
         case SID_BASICIDE_CHOOSEMACRO:
         {
-            ChooseMacro( nullptr, false, OUString() );
+            ChooseMacro( nullptr );
         }
         break;
         case SID_BASICIDE_CREATEMACRO:
@@ -275,11 +278,11 @@ void Shell::ExecuteGlobal( SfxRequest& rReq )
             DBG_ASSERT( rReq.GetArgs(), "arguments expected" );
             const SfxMacroInfoItem& rInfo = static_cast<const SfxMacroInfoItem&>(rReq.GetArgs()->Get(SID_BASICIDE_ARG_MACROINFO ));
             BasicManager* pBasMgr = const_cast<BasicManager*>(rInfo.GetBasicManager());
-            DBG_ASSERT( pBasMgr, "Nichts selektiert im Basic-Baum ?" );
+            DBG_ASSERT( pBasMgr, "Nothing selected in basic tree?" );
 
             ScriptDocument aDocument( ScriptDocument::getDocumentForBasicManager( pBasMgr ) );
 
-            StartListening( *pBasMgr, true /* log on only once */ );
+            StartListening(*pBasMgr, DuplicateHandling::Prevent /* log on only once */);
             OUString aLibName( rInfo.GetLib() );
             if ( aLibName.isEmpty() )
                 aLibName = "Standard" ;
@@ -302,26 +305,26 @@ void Shell::ExecuteGlobal( SfxRequest& rReq )
                 SbModule* pModule = pBasic->FindModule( rInfo.GetModule() );
                 if ( !pModule )
                 {
-                    if ( !rInfo.GetModule().isEmpty() || !pBasic->GetModules()->Count() )
+                    if ( !rInfo.GetModule().isEmpty() || pBasic->GetModules().empty() )
                     {
-                        OUString aModName = rInfo.GetModule();
+                        const OUString& aModName = rInfo.GetModule();
 
                         OUString sModuleCode;
                         if ( aDocument.createModule( aLibName, aModName, false, sModuleCode ) )
                             pModule = pBasic->FindModule( aModName );
                     }
                     else
-                        pModule = static_cast<SbModule*>( pBasic->GetModules()->Get(0) );
+                        pModule = pBasic->GetModules().front().get();
                 }
-                DBG_ASSERT( pModule, "Kein Modul!" );
-                if ( pModule && !pModule->GetMethods()->Find( rInfo.GetMethod(), SbxCLASS_METHOD ) )
+                DBG_ASSERT( pModule, "No Module!" );
+                if ( pModule && !pModule->GetMethods()->Find( rInfo.GetMethod(), SbxClassType::Method ) )
                     CreateMacro( pModule, rInfo.GetMethod() );
             }
             SfxViewFrame* pViewFrame = GetViewFrame();
             if ( pViewFrame )
                 pViewFrame->ToTop();
-            ModulWindow* pWin = FindBasWin( aDocument, aLibName, rInfo.GetModule(), true );
-            DBG_ASSERT( pWin, "Edit/Create Macro: Fenster wurde nicht erzeugt/gefunden!" );
+            VclPtr<ModulWindow> pWin = FindBasWin( aDocument, aLibName, rInfo.GetModule(), true );
+            DBG_ASSERT( pWin, "Edit/Create Macro: Window was not created/found!" );
             SetCurWindow( pWin, true );
             pWin->EditMacro( rInfo.GetMethod() );
         }
@@ -344,13 +347,13 @@ void Shell::ExecuteGlobal( SfxRequest& rReq )
             const SfxStringItem &rModName = static_cast<const SfxStringItem&>(rReq.GetArgs()->Get(SID_BASICIDE_ARG_MODULENAME ));
             if ( aWindowTable.find( rTabId.GetValue() ) !=  aWindowTable.end() )
             {
-                BaseWindow* pWin = aWindowTable[ rTabId.GetValue() ];
-                OUString aNewName( rModName.GetValue() );
+                VclPtr<BaseWindow> pWin = aWindowTable[ rTabId.GetValue() ];
+                const OUString& aNewName( rModName.GetValue() );
                 OUString aOldName( pWin->GetName() );
                 if ( aNewName != aOldName )
                 {
                     bool bRenameOk = false;
-                    if (ModulWindow* pModWin = dynamic_cast<ModulWindow*>(pWin))
+                    if (ModulWindow* pModWin = dynamic_cast<ModulWindow*>(pWin.get()))
                     {
                         OUString aLibName = pModWin->GetLibName();
                         ScriptDocument aDocument( pWin->GetDocument() );
@@ -365,7 +368,7 @@ void Shell::ExecuteGlobal( SfxRequest& rReq )
                         }
 
                     }
-                    else if (DialogWindow* pDlgWin = dynamic_cast<DialogWindow*>(pWin))
+                    else if (DialogWindow* pDlgWin = dynamic_cast<DialogWindow*>(pWin.get()))
                     {
                         bRenameOk = pDlgWin->RenameDialog( aNewName );
                     }
@@ -394,9 +397,9 @@ void Shell::ExecuteGlobal( SfxRequest& rReq )
             DBG_ASSERT( rReq.GetArgs(), "arguments expected" );
             const SfxMacroInfoItem& rInfo = static_cast<const SfxMacroInfoItem&>(rReq.GetArgs()->Get(SID_BASICIDE_ARG_MACROINFO ));
             BasicManager* pBasMgr = const_cast<BasicManager*>(rInfo.GetBasicManager());
-            DBG_ASSERT( pBasMgr, "Store source: Kein BasMgr?" );
+            DBG_ASSERT( pBasMgr, "Store source: No BasMgr?" );
             ScriptDocument aDocument( ScriptDocument::getDocumentForBasicManager( pBasMgr ) );
-            ModulWindow* pWin = FindBasWin( aDocument, rInfo.GetLib(), rInfo.GetModule(), false, true );
+            VclPtr<ModulWindow> pWin = FindBasWin( aDocument, rInfo.GetLib(), rInfo.GetModule(), false, true );
             if ( pWin )
             {
                 if ( rReq.GetSlot() == SID_BASICIDE_STOREMODULESOURCE )
@@ -431,7 +434,7 @@ void Shell::ExecuteGlobal( SfxRequest& rReq )
             uno::Reference< frame::XModel > xModel( rShellItem.GetValue(), UNO_QUERY );
             ScriptDocument aDocument( xModel.is() ? ScriptDocument( xModel ) : ScriptDocument::getApplicationScriptDocument() );
             const SfxStringItem& rLibNameItem = static_cast<const SfxStringItem&>(rReq.GetArgs()->Get( SID_BASICIDE_ARG_LIBNAME ));
-            OUString aLibName( rLibNameItem.GetValue() );
+            const OUString& aLibName( rLibNameItem.GetValue() );
 
             if ( nSlot == SID_BASICIDE_LIBSELECTED )
             {
@@ -467,7 +470,7 @@ void Shell::ExecuteGlobal( SfxRequest& rReq )
             {
                 if ( m_aCurLibName.isEmpty() || ( aDocument == m_aCurDocument && aLibName == m_aCurLibName ) )
                 {
-                    RemoveWindows( aDocument, aLibName, true );
+                    RemoveWindows( aDocument, aLibName );
                     if ( aDocument == m_aCurDocument && aLibName == m_aCurLibName )
                     {
                         m_aCurDocument = ScriptDocument::getApplicationScriptDocument();
@@ -485,14 +488,14 @@ void Shell::ExecuteGlobal( SfxRequest& rReq )
         case SID_BASICIDE_NEWMODULE:
         {
             VclPtr<ModulWindow> pWin = CreateBasWin( m_aCurDocument, m_aCurLibName, OUString() );
-            DBG_ASSERT( pWin, "New Module: Konnte Fenster nicht erzeugen!" );
+            DBG_ASSERT( pWin, "New Module: Could not create window!" );
             SetCurWindow( pWin, true );
         }
         break;
         case SID_BASICIDE_NEWDIALOG:
         {
             VclPtr<DialogWindow> pWin = CreateDlgWin( m_aCurDocument, m_aCurLibName, OUString() );
-            DBG_ASSERT( pWin, "New Module: Konnte Fenster nicht erzeugen!" );
+            DBG_ASSERT( pWin, "New Module: Could not create window!" );
             SetCurWindow( pWin, true );
         }
         break;
@@ -505,9 +508,9 @@ void Shell::ExecuteGlobal( SfxRequest& rReq )
         {
             DBG_ASSERT( rReq.GetArgs(), "arguments expected" );
             const SbxItem& rSbxItem = static_cast<const SbxItem&>(rReq.GetArgs()->Get(SID_BASICIDE_ARG_SBX ));
-            ScriptDocument aDocument( rSbxItem.GetDocument() );
-            OUString aLibName( rSbxItem.GetLibName() );
-            OUString aName( rSbxItem.GetName() );
+            const ScriptDocument& aDocument( rSbxItem.GetDocument() );
+            const OUString& aLibName( rSbxItem.GetLibName() );
+            const OUString& aName( rSbxItem.GetName() );
             if ( m_aCurLibName.isEmpty() || ( aDocument == m_aCurDocument && aLibName == m_aCurLibName ) )
             {
                 if ( rSbxItem.GetType() == TYPE_MODULE )
@@ -521,8 +524,8 @@ void Shell::ExecuteGlobal( SfxRequest& rReq )
         {
             DBG_ASSERT( rReq.GetArgs(), "arguments expected" );
             const SbxItem& rSbxItem = static_cast<const SbxItem&>(rReq.GetArgs()->Get(SID_BASICIDE_ARG_SBX ));
-            ScriptDocument aDocument( rSbxItem.GetDocument() );
-            BaseWindow* pWin = FindWindow( aDocument, rSbxItem.GetLibName(), rSbxItem.GetName(), rSbxItem.GetType(), true );
+            const ScriptDocument& aDocument( rSbxItem.GetDocument() );
+            VclPtr<BaseWindow> pWin = FindWindow( aDocument, rSbxItem.GetLibName(), rSbxItem.GetName(), rSbxItem.GetType(), true );
             if ( pWin )
                 RemoveWindow( pWin, true );
         }
@@ -531,9 +534,9 @@ void Shell::ExecuteGlobal( SfxRequest& rReq )
         {
             DBG_ASSERT( rReq.GetArgs(), "arguments expected" );
             const SbxItem& rSbxItem = static_cast<const SbxItem&>(rReq.GetArgs()->Get(SID_BASICIDE_ARG_SBX ));
-            ScriptDocument aDocument( rSbxItem.GetDocument() );
-            OUString aLibName( rSbxItem.GetLibName() );
-            OUString aName( rSbxItem.GetName() );
+            const ScriptDocument& aDocument( rSbxItem.GetDocument() );
+            const OUString& aLibName( rSbxItem.GetLibName() );
+            const OUString& aName( rSbxItem.GetName() );
             SetCurLib( aDocument, aLibName );
             BaseWindow* pWin = nullptr;
             if ( rSbxItem.GetType() == TYPE_DIALOG )
@@ -549,7 +552,7 @@ void Shell::ExecuteGlobal( SfxRequest& rReq )
                 pWin = FindBasWin( aDocument, aLibName, aName, true );
                 static_cast<ModulWindow*>(pWin)->EditMacro( rSbxItem.GetMethodName() );
             }
-            DBG_ASSERT( pWin, "Fenster wurde nicht erzeugt!" );
+            DBG_ASSERT( pWin, "Window was not created!" );
             SetCurWindow( pWin, true );
             pTabBar->MakeVisible( pTabBar->GetCurPageId() );
         }
@@ -589,7 +592,6 @@ void Shell::ExecuteGlobal( SfxRequest& rReq )
             {
                 OUString aName( pNameItem->GetValue() );
                 OUString aModType( "Module" );
-                OUString aDlgType( "Dialog" );
                 OUString aType( aModType );
                 const SfxStringItem* pTypeItem = rReq.GetArg<SfxStringItem>(SID_BASICIDE_ARG_TYPE);
                 if ( pTypeItem )
@@ -598,7 +600,7 @@ void Shell::ExecuteGlobal( SfxRequest& rReq )
                 BaseWindow* pWin = nullptr;
                 if ( aType == aModType )
                     pWin = FindBasWin( *pDocument, aLibName, aName );
-                else if ( aType == aDlgType )
+                else if ( aType == "Dialog" )
                     pWin = FindDlgWin( *pDocument, aLibName, aName );
 
                 if ( pWin )
@@ -636,7 +638,7 @@ void Shell::ExecuteGlobal( SfxRequest& rReq )
                                         long nMaxY = nTextHeight - nVisHeight;
                                         long nOldY = pTextView->GetStartDocPos().Y();
                                         long nNewY = nLine * pTextEngine->GetCharHeight() - nVisHeight / 2;
-                                        nNewY = ::std::min( nNewY, nMaxY );
+                                        nNewY = std::min( nNewY, nMaxY );
                                         pTextView->Scroll( 0, -( nNewY - nOldY ) );
                                         pTextView->ShowCursor( false );
                                         pModWin->GetEditVScrollBar().SetThumbPos( pTextView->GetStartDocPos().Y() );
@@ -693,7 +695,7 @@ void Shell::ExecuteGlobal( SfxRequest& rReq )
 void Shell::GetState(SfxItemSet &rSet)
 {
     SfxWhichIter aIter(rSet);
-    for ( sal_uInt16 nWh = aIter.FirstWhich(); 0 != nWh; nWh = aIter.NextWhich() )
+    for ( sal_uInt16 nWh = aIter.FirstWhich(); nWh != 0; nWh = aIter.NextWhich() )
     {
         switch ( nWh )
         {
@@ -805,6 +807,30 @@ void Shell::GetState(SfxItemSet &rSet)
             break;
             case SID_CHOOSE_CONTROLS:
             case SID_DIALOG_TESTMODE:
+            case SID_INSERT_SELECT:
+            case SID_INSERT_PUSHBUTTON:
+            case SID_INSERT_RADIOBUTTON:
+            case SID_INSERT_CHECKBOX:
+            case SID_INSERT_LISTBOX:
+            case SID_INSERT_COMBOBOX:
+            case SID_INSERT_GROUPBOX:
+            case SID_INSERT_EDIT:
+            case SID_INSERT_FIXEDTEXT:
+            case SID_INSERT_IMAGECONTROL:
+            case SID_INSERT_PROGRESSBAR:
+            case SID_INSERT_HSCROLLBAR:
+            case SID_INSERT_VSCROLLBAR:
+            case SID_INSERT_HFIXEDLINE:
+            case SID_INSERT_VFIXEDLINE:
+            case SID_INSERT_DATEFIELD:
+            case SID_INSERT_TIMEFIELD:
+            case SID_INSERT_NUMERICFIELD:
+            case SID_INSERT_CURRENCYFIELD:
+            case SID_INSERT_FORMATTEDFIELD:
+            case SID_INSERT_PATTERNFIELD:
+            case SID_INSERT_FILECONTROL:
+            case SID_INSERT_SPINBUTTON:
+            case SID_INSERT_TREECONTROL:
             case SID_INSERT_FORM_RADIO:
             case SID_INSERT_FORM_CHECK:
             case SID_INSERT_FORM_LIST:
@@ -817,12 +843,6 @@ void Shell::GetState(SfxItemSet &rSet)
                     rSet.DisableItem( nWh );
             }
             break;
-            case SID_SHOW_FORMS:
-            case SID_SHOW_HIDDEN:
-            {
-                rSet.DisableItem( nWh );
-            }
-            break;
             case SID_SEARCH_OPTIONS:
             {
                 SearchOptionFlags nOptions = SearchOptionFlags::NONE;
@@ -853,8 +873,7 @@ void Shell::GetState(SfxItemSet &rSet)
             break;
             case SID_BASICIDE_STAT_DATE:
             {
-                OUString aDate( "Datum?!" );
-                SfxStringItem aItem( SID_BASICIDE_STAT_DATE, aDate );
+                SfxStringItem aItem( SID_BASICIDE_STAT_DATE, "Datum?!" );
                 rSet.Put( aItem );
             }
             break;
@@ -922,9 +941,7 @@ void Shell::GetState(SfxItemSet &rSet)
                             else
                                 aLocale = pCurMgr->getStringResourceManager()->getDefaultLocale();
 
-                            aLangStr += aLocale.Language;
-                            aLangStr += aLocale.Country;
-                            aLangStr += aLocale.Variant;
+                            aLangStr += aLocale.Language + aLocale.Country + aLocale.Variant;
                         }
                         aItemStr = aLangStr;
                     }
@@ -951,6 +968,42 @@ void Shell::GetState(SfxItemSet &rSet)
                 }
                 break;
             }
+            case SID_BASICIDE_HIDECURPAGE:
+            {
+                if (pTabBar->GetPageCount() == 0)
+                    rSet.DisableItem(nWh);
+            }
+            break;
+            case SID_BASICIDE_DELETECURRENT:
+            case SID_BASICIDE_RENAMECURRENT:
+            {
+                if (pTabBar->GetPageCount() == 0 || StarBASIC::IsRunning())
+                    rSet.DisableItem(nWh);
+                else if (m_aCurDocument.isInVBAMode())
+                {
+                    // disable to delete or rename object modules in IDE
+                    BasicManager* pBasMgr = m_aCurDocument.getBasicManager();
+                    StarBASIC* pBasic = pBasMgr ? pBasMgr->GetLib(m_aCurLibName) : nullptr;
+                    if (pBasic && dynamic_cast<ModulWindow*>(pCurWin.get()))
+                    {
+                        SbModule* pActiveModule = pBasic->FindModule( pCurWin->GetName() );
+                        if ( pActiveModule && ( pActiveModule->GetModuleType() == script::ModuleType::DOCUMENT ) )
+                            rSet.DisableItem(nWh);
+                    }
+                }
+            }
+            SAL_FALLTHROUGH;
+
+            case SID_BASICIDE_NEWMODULE:
+            case SID_BASICIDE_NEWDIALOG:
+            {
+                Reference< script::XLibraryContainer2 > xModLibContainer( m_aCurDocument.getLibraryContainer( E_SCRIPTS ), UNO_QUERY );
+                Reference< script::XLibraryContainer2 > xDlgLibContainer( m_aCurDocument.getLibraryContainer( E_DIALOGS ), UNO_QUERY );
+                if ( ( xModLibContainer.is() && xModLibContainer->hasByName( m_aCurLibName ) && xModLibContainer->isLibraryReadOnly( m_aCurLibName ) ) ||
+                     ( xDlgLibContainer.is() && xDlgLibContainer->hasByName( m_aCurLibName ) && xDlgLibContainer->isLibraryReadOnly( m_aCurLibName ) ) )
+                    rSet.DisableItem(nWh);
+            }
+            break;
             default:
                 if (pLayout)
                     pLayout->GetState(rSet, nWh);
@@ -960,11 +1013,12 @@ void Shell::GetState(SfxItemSet &rSet)
         pCurWin->GetState( rSet );
 }
 
-bool Shell::HasUIFeature( sal_uInt32 nFeature )
+bool Shell::HasUIFeature(SfxShellFeature nFeature) const
 {
+    assert((nFeature & ~SfxShellFeature::BasicMask) == SfxShellFeature::NONE);
     bool bResult = false;
 
-    if ( (nFeature & BASICIDE_UI_FEATURE_SHOW_BROWSER) == BASICIDE_UI_FEATURE_SHOW_BROWSER )
+    if (nFeature & SfxShellFeature::BasicShowBrowser)
     {
         // fade out (in) property browser in module (dialog) windows
         if (dynamic_cast<DialogWindow*>(pCurWin.get()) && !pCurWin->IsReadOnly())
@@ -1034,6 +1088,7 @@ void Shell::SetCurWindow( BaseWindow* pNewWin, bool bUpdateTabBar, bool bRemembe
         aObjectCatalog->SetCurrentEntry(pCurWin);
         SetUndoManager( pCurWin ? pCurWin->GetUndoManager() : nullptr );
         InvalidateBasicIDESlots();
+        InvalidateControlSlots();
         EnableScrollbars(pCurWin != nullptr);
 
         if ( m_pCurLocalizationMgr )
@@ -1089,7 +1144,7 @@ void Shell::ManageToolbars()
 
 VclPtr<BaseWindow> Shell::FindApplicationWindow()
 {
-    return FindWindow( ScriptDocument::getApplicationScriptDocument() );
+    return FindWindow( ScriptDocument::getApplicationScriptDocument(), "", "", TYPE_UNKNOWN );
 }
 
 VclPtr<BaseWindow> Shell::FindWindow(
@@ -1107,19 +1162,19 @@ VclPtr<BaseWindow> Shell::FindWindow(
     return nullptr;
 }
 
-bool Shell::CallBasicErrorHdl( StarBASIC* pBasic )
+bool Shell::CallBasicErrorHdl( StarBASIC const * pBasic )
 {
     bool bRet = false;
-    ModulWindow* pModWin = ShowActiveModuleWindow( pBasic );
+    VclPtr<ModulWindow> pModWin = ShowActiveModuleWindow( pBasic );
     if ( pModWin )
         bRet = pModWin->BasicErrorHdl( pBasic );
     return bRet;
 }
 
-long Shell::CallBasicBreakHdl( StarBASIC* pBasic )
+BasicDebugFlags Shell::CallBasicBreakHdl( StarBASIC const * pBasic )
 {
-    long nRet = 0;
-    ModulWindow* pModWin = ShowActiveModuleWindow( pBasic );
+    BasicDebugFlags nRet = BasicDebugFlags::NONE;
+    VclPtr<ModulWindow> pModWin = ShowActiveModuleWindow( pBasic );
     if ( pModWin )
     {
         bool bAppWindowDisabled, bDispatcherLocked;
@@ -1128,7 +1183,7 @@ long Shell::CallBasicBreakHdl( StarBASIC* pBasic )
         BasicStopped( &bAppWindowDisabled, &bDispatcherLocked,
                                 &nWaitCount, &pSWActionCount, &pSWLockViewCount );
 
-        nRet = pModWin->BasicBreakHdl( pBasic );
+        nRet = pModWin->BasicBreakHdl();
 
         if ( StarBASIC::IsRunning() )   // if cancelled...
         {
@@ -1146,7 +1201,7 @@ long Shell::CallBasicBreakHdl( StarBASIC* pBasic )
     return nRet;
 }
 
-VclPtr<ModulWindow> Shell::ShowActiveModuleWindow( StarBASIC* pBasic )
+VclPtr<ModulWindow> Shell::ShowActiveModuleWindow( StarBASIC const * pBasic )
 {
     SetCurLib( ScriptDocument::getApplicationScriptDocument(), OUString(), false );
 
@@ -1154,7 +1209,7 @@ VclPtr<ModulWindow> Shell::ShowActiveModuleWindow( StarBASIC* pBasic )
     if (SbClassModuleObject* pCMO = dynamic_cast<SbClassModuleObject*>(pActiveModule))
         pActiveModule = pCMO->getClassModule();
 
-    DBG_ASSERT( pActiveModule, "Kein aktives Modul im ErrorHdl?!" );
+    DBG_ASSERT( pActiveModule, "No active module in ErrorHdl!?" );
     if ( pActiveModule )
     {
         VclPtr<ModulWindow> pWin;
@@ -1166,15 +1221,15 @@ VclPtr<ModulWindow> Shell::ShowActiveModuleWindow( StarBASIC* pBasic )
                 ScriptDocument aDocument( ScriptDocument::getDocumentForBasicManager( pBasMgr ) );
                 OUString aLibName = pLib->GetName();
                 pWin = FindBasWin( aDocument, aLibName, pActiveModule->GetName(), true );
-                DBG_ASSERT( pWin, "Error/Step-Hdl: Fenster wurde nicht erzeugt/gefunden!" );
+                DBG_ASSERT( pWin, "Error/Step-Hdl: Window was not created/found!" );
                 SetCurLib( aDocument, aLibName );
                 SetCurWindow( pWin, true );
             }
         }
         else
-            DBG_ASSERT(false, "No BASIC!");
+            SAL_WARN( "basctl.basicide", "No BASIC!");
         if (BasicManager* pBasicMgr = FindBasicManager(pBasic))
-            StartListening( *pBasicMgr, true /* log on only once */ );
+            StartListening(*pBasicMgr, DuplicateHandling::Prevent /* log on only once */);
         return pWin;
     }
     return nullptr;
@@ -1186,30 +1241,21 @@ void Shell::AdjustPosSizePixel( const Point &rPos, const Size &rSize )
     if ( GetViewFrame()->GetWindow().GetOutputSizePixel().Height() == 0 )
         return;
 
+    Size aTabBarSize;
+    aTabBarSize.Height() = GetViewFrame()->GetWindow().GetFont().GetFontHeight() + 4;
+    aTabBarSize.Width() = rSize.Width();
+
     Size aSz( rSize );
     Size aScrollBarBoxSz( aScrollBarBox->GetSizePixel() );
     aSz.Height() -= aScrollBarBoxSz.Height();
+    aSz.Height() -= aTabBarSize.Height();
 
     Size aOutSz( aSz );
     aSz.Width() -= aScrollBarBoxSz.Width();
     aScrollBarBox->SetPosPixel( Point( rSize.Width() - aScrollBarBoxSz.Width(), rSize.Height() - aScrollBarBoxSz.Height() ) );
     aVScrollBar->SetPosSizePixel( Point( rPos.X()+aSz.Width(), rPos.Y() ), Size( aScrollBarBoxSz.Width(), aSz.Height() ) );
-    if ( bTabBarSplitted )
-    {
-        // SplitSize is 0 at a resize!
-        long nSplitPos = pTabBar->GetSizePixel().Width();
-        if ( nSplitPos > aSz.Width() )
-            nSplitPos = aSz.Width();
-        pTabBar->SetPosSizePixel( Point( rPos.X(), rPos.Y()+aSz.Height() ), Size( nSplitPos, aScrollBarBoxSz.Height() ) );
-        long nScrlStart = rPos.X() + nSplitPos;
-        aHScrollBar->SetPosSizePixel( Point( nScrlStart, rPos.Y()+aSz.Height() ), Size( aSz.Width() - nScrlStart + 1, aScrollBarBoxSz.Height() ) );
-        aHScrollBar->Update();
-    }
-    else
-    {
-        aHScrollBar->SetPosSizePixel( Point( rPos.X()+ aSz.Width()/2 - 1, rPos.Y()+aSz.Height() ), Size( aSz.Width()/2 + 2, aScrollBarBoxSz.Height() ) );
-        pTabBar->SetPosSizePixel( Point( rPos.X(), rPos.Y()+aSz.Height() ), Size( aSz.Width()/2, aScrollBarBoxSz.Height() ) );
-    }
+    aHScrollBar->SetPosSizePixel( Point( rPos.X(), rPos.Y()+aSz.Height() ), Size( aSz.Width(), aScrollBarBoxSz.Height() ) );
+    pTabBar->SetPosSizePixel( Point( rPos.X(), rPos.Y()+aScrollBarBoxSz.Height()+aSz.Height()), aTabBarSize );
 
     if (pLayout)
         pLayout->SetPosSizePixel(rPos, dynamic_cast<DialogWindow*>(pCurWin.get()) ? aSz : aOutSz);
