@@ -17,31 +17,23 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "basobj.hxx"
-#include "iderdll.hxx"
+#include <iderdll.hxx>
 #include "iderdll2.hxx"
-#include "iderid.hxx"
 #include "macrodlg.hxx"
 #include "moduldlg.hxx"
-#include "basidesh.hxx"
-#include "basidesh.hrc"
+#include <strings.hrc>
 #include "baside2.hxx"
-#include "basicmod.hxx"
-#include "basdoc.hxx"
 
-#include <com/sun/star/document/XEmbeddedScripts.hpp>
 #include <com/sun/star/document/XScriptInvocationContext.hpp>
 
 #include <basic/sbmeth.hxx>
-#include <basic/sbx.hxx>
 #include <framework/documentundoguard.hxx>
 #include <tools/diagnose_ex.h>
 #include <unotools/moduleoptions.hxx>
-#include <vcl/msgbox.hxx>
 
+#include <memory>
 #include <vector>
 #include <algorithm>
-#include <memory>
 #include <basic/basmgr.hxx>
 namespace basctl
 {
@@ -50,15 +42,12 @@ using namespace ::com::sun::star;
 using namespace ::com::sun::star::uno;
 using namespace ::com::sun::star::container;
 
-
-//----------------------------------------------------------------------------
-
 extern "C" {
-    SAL_DLLPUBLIC_EXPORT rtl_uString* basicide_choose_macro( void* pOnlyInDocument_AsXModel, sal_Bool bChooseOnly, rtl_uString* pMacroDesc )
+    SAL_DLLPUBLIC_EXPORT rtl_uString* basicide_choose_macro( void* pOnlyInDocument_AsXModel, void* pDocFrame_AsXFrame, sal_Bool bChooseOnly )
     {
-        OUString aMacroDesc( pMacroDesc );
         Reference< frame::XModel > aDocument( static_cast< frame::XModel* >( pOnlyInDocument_AsXModel ) );
-        OUString aScriptURL = basctl::ChooseMacro( aDocument, bChooseOnly, aMacroDesc );
+        Reference< frame::XFrame > aDocFrame( static_cast< frame::XFrame* >( pDocFrame_AsXFrame ) );
+        OUString aScriptURL = basctl::ChooseMacro( aDocument, aDocFrame, bChooseOnly );
         rtl_uString* pScriptURL = aScriptURL.pData;
         rtl_uString_acquire( pScriptURL );
 
@@ -71,8 +60,6 @@ extern "C" {
     }
 }
 
-//----------------------------------------------------------------------------
-
 void Organize( sal_Int16 tabId )
 {
     EnsureIde();
@@ -82,15 +69,13 @@ void Organize( sal_Int16 tabId )
         if (BaseWindow* pCurWin = pShell->GetCurWindow())
             aDesc = pCurWin->CreateEntryDescriptor();
 
-    Window* pParent = Application::GetDefDialogParent();
-    OrganizeDialog(pParent, tabId, aDesc).Execute();
+    vcl::Window* pParent = Application::GetDefDialogParent();
+    ScopedVclPtrInstance<OrganizeDialog>(pParent, tabId, aDesc)->Execute();
 }
 
-//----------------------------------------------------------------------------
-
 bool IsValidSbxName( const OUString& rName )
 {
-    for ( sal_uInt16 nChar = 0; nChar < rName.getLength(); nChar++ )
+    for ( sal_Int32 nChar = 0; nChar < rName.getLength(); nChar++ )
     {
         sal_Unicode c = rName[nChar];
         bool bValid = (
@@ -110,12 +95,10 @@ static bool StringCompareLessThan( const OUString& rStr1, const OUString& rStr2
     return rStr1.compareToIgnoreAsciiCase( rStr2 ) < 0;
 }
 
-//----------------------------------------------------------------------------
-
 Sequence< OUString > GetMergedLibraryNames( const Reference< script::XLibraryContainer >& xModLibContainer, const Reference< script::XLibraryContainer >& xDlgLibContainer )
 {
     // create a sorted list of module library names
-    ::std::vector<OUString> aModLibList;
+    std::vector<OUString> aModLibList;
     if ( xModLibContainer.is() )
     {
         Sequence< OUString > aModLibNames = xModLibContainer->getElementNames();
@@ -123,11 +106,11 @@ Sequence< OUString > GetMergedLibraryNames( const Reference< script::XLibraryCon
         const OUString* pModLibNames = aModLibNames.getConstArray();
         for ( sal_Int32 i = 0 ; i < nModLibCount ; i++ )
             aModLibList.push_back( pModLibNames[ i ] );
-        ::std::sort( aModLibList.begin() , aModLibList.end() , StringCompareLessThan );
+        std::sort( aModLibList.begin() , aModLibList.end() , StringCompareLessThan );
     }
 
     // create a sorted list of dialog library names
-    ::std::vector<OUString> aDlgLibList;
+    std::vector<OUString> aDlgLibList;
     if ( xDlgLibContainer.is() )
     {
         Sequence< OUString > aDlgLibNames = xDlgLibContainer->getElementNames();
@@ -135,13 +118,13 @@ Sequence< OUString > GetMergedLibraryNames( const Reference< script::XLibraryCon
         const OUString* pDlgLibNames = aDlgLibNames.getConstArray();
         for ( sal_Int32 i = 0 ; i < nDlgLibCount ; i++ )
             aDlgLibList.push_back( pDlgLibNames[ i ] );
-        ::std::sort( aDlgLibList.begin() , aDlgLibList.end() , StringCompareLessThan );
+        std::sort( aDlgLibList.begin() , aDlgLibList.end() , StringCompareLessThan );
     }
 
     // merge both lists
-    ::std::vector<OUString> aLibList( aModLibList.size() + aDlgLibList.size() );
-    ::std::merge( aModLibList.begin(), aModLibList.end(), aDlgLibList.begin(), aDlgLibList.end(), aLibList.begin(), StringCompareLessThan );
-    ::std::vector<OUString>::iterator aIterEnd = ::std::unique( aLibList.begin(), aLibList.end() );  // move unique elements to the front
+    std::vector<OUString> aLibList( aModLibList.size() + aDlgLibList.size() );
+    std::merge( aModLibList.begin(), aModLibList.end(), aDlgLibList.begin(), aDlgLibList.end(), aLibList.begin(), StringCompareLessThan );
+    std::vector<OUString>::iterator aIterEnd = std::unique( aLibList.begin(), aLibList.end() );  // move unique elements to the front
     aLibList.erase( aIterEnd, aLibList.end() ); // remove duplicates
 
     // copy to sequence
@@ -153,10 +136,8 @@ Sequence< OUString > GetMergedLibraryNames( const Reference< script::XLibraryCon
     return aSeqLibNames;
 }
 
-//----------------------------------------------------------------------------
-
 bool RenameModule (
-    Window* pErrorParent,
+    vcl::Window* pErrorParent,
     const ScriptDocument& rDocument,
     const OUString& rLibName,
     const OUString& rOldName,
@@ -171,16 +152,16 @@ bool RenameModule (
 
     if ( rDocument.hasModule( rLibName, rNewName ) )
     {
-        ErrorBox aError( pErrorParent, WB_OK | WB_DEF_OK, IDE_RESSTR(RID_STR_SBXNAMEALLREADYUSED2) );
-        aError.Execute();
+        ScopedVclPtrInstance< MessageDialog > aError(pErrorParent, IDEResId(RID_STR_SBXNAMEALLREADYUSED2));
+        aError->Execute();
         return false;
     }
 
     // #i74440
     if ( rNewName.isEmpty() )
     {
-        ErrorBox aError( pErrorParent, WB_OK | WB_DEF_OK, IDE_RESSTR(RID_STR_BADSBXNAME) );
-        aError.Execute();
+        ScopedVclPtrInstance< MessageDialog > aError(pErrorParent, IDEResId(RID_STR_BADSBXNAME));
+        aError->Execute();
         return false;
     }
 
@@ -189,13 +170,13 @@ bool RenameModule (
 
     if (Shell* pShell = GetShell())
     {
-        if (ModulWindow* pWin = pShell->FindBasWin(rDocument, rLibName, rNewName, false, true))
+        if (VclPtr<ModulWindow> pWin = pShell->FindBasWin(rDocument, rLibName, rNewName, false, true))
         {
             // set new name in window
             pWin->SetName( rNewName );
 
             // set new module in module window
-            pWin->SetSbModule( (SbModule*)pWin->GetBasic()->FindModule( rNewName ) );
+            pWin->SetSbModule( pWin->GetBasic()->FindModule( rNewName ) );
 
             // update tabwriter
             sal_uInt16 nId = pShell->GetWindowId( pWin );
@@ -212,9 +193,6 @@ bool RenameModule (
     return true;
 }
 
-
-//----------------------------------------------------------------------------
-
 namespace
 {
     struct MacroExecutionData
@@ -224,7 +202,7 @@ namespace
 
         MacroExecutionData()
             :aDocument( ScriptDocument::NoDocument )
-            ,xMethod( NULL )
+            ,xMethod( nullptr )
         {
         }
     };
@@ -232,47 +210,41 @@ namespace
     class MacroExecution
     {
     public:
-        DECL_STATIC_LINK( MacroExecution, ExecuteMacroEvent, MacroExecutionData* );
+        DECL_STATIC_LINK( MacroExecution, ExecuteMacroEvent, void*, void );
     };
 
-
-    IMPL_STATIC_LINK( MacroExecution, ExecuteMacroEvent, MacroExecutionData*, i_pData )
+    IMPL_STATIC_LINK( MacroExecution, ExecuteMacroEvent, void*, p, void )
     {
-        (void)pThis;
-        ENSURE_OR_RETURN( i_pData, "wrong MacroExecutionData", 0L );
+        MacroExecutionData* i_pData = static_cast<MacroExecutionData*>(p);
+        ENSURE_OR_RETURN_VOID( i_pData, "wrong MacroExecutionData" );
         // take ownership of the data
-        ::std::auto_ptr< MacroExecutionData > pData( i_pData );
+        std::unique_ptr< MacroExecutionData > pData( i_pData );
 
-        SAL_WARN_IF( !(pData->xMethod->GetParent()->GetFlags() & SBX_EXTSEARCH), "basctl.basicide","No EXTSEARCH!" );
+        SAL_WARN_IF( (pData->xMethod->GetParent()->GetFlags() & SbxFlagBits::ExtSearch) == SbxFlagBits::NONE, "basctl.basicide","No EXTSEARCH!" );
 
         // in case this is a document-local macro, try to protect the document's Undo Manager from
         // flawed scripts
-        ::std::auto_ptr< ::framework::DocumentUndoGuard > pUndoGuard;
+        std::unique_ptr< ::framework::DocumentUndoGuard > pUndoGuard;
         if ( pData->aDocument.isDocument() )
             pUndoGuard.reset( new ::framework::DocumentUndoGuard( pData->aDocument.getDocument() ) );
 
-        RunMethod(pData->xMethod);
-
-        return 1L;
+        RunMethod( pData->xMethod.get() );
     }
 }
 
-//----------------------------------------------------------------------------
-
-OUString ChooseMacro( const uno::Reference< frame::XModel >& rxLimitToDocument, bool bChooseOnly, const OUString& rMacroDesc )
+OUString ChooseMacro( const uno::Reference< frame::XModel >& rxLimitToDocument,
+                      const uno::Reference< frame::XFrame >& xDocFrame,
+                      bool bChooseOnly )
 {
-    (void)rMacroDesc;
-
     EnsureIde();
 
     GetExtraData()->ChoosingMacro() = true;
 
     OUString aScriptURL;
-    bool bError = false;
-    SbMethod* pMethod = NULL;
+    SbMethod* pMethod = nullptr;
 
-    ::std::auto_ptr< MacroChooser > pChooser( new MacroChooser( NULL, true ) );
-    if ( bChooseOnly || !SvtModuleOptions().IsBasicIDE() )
+    ScopedVclPtrInstance< MacroChooser > pChooser( nullptr, xDocFrame, true );
+    if ( bChooseOnly || !SvtModuleOptions::IsBasicIDE() )
         pChooser->SetMode(MacroChooser::ChooseOnly);
 
     if ( !bChooseOnly && rxLimitToDocument.is() )
@@ -287,6 +259,8 @@ OUString ChooseMacro( const uno::Reference< frame::XModel >& rxLimitToDocument,
     {
         case Macro_OkRun:
         {
+            bool bError = false;
+
             pMethod = pChooser->GetMacro();
             if ( !pMethod && pChooser->GetMode() == MacroChooser::Recording )
                 pMethod = pChooser->CreateMacro();
@@ -316,15 +290,7 @@ OUString ChooseMacro( const uno::Reference< frame::XModel >& rxLimitToDocument,
             }
 
             // name
-            OUString aName;
-            aName += pBasic->GetName();
-            aName += ".";
-            aName += pModule->GetName();
-            aName += ".";
-            aName += pMethod->GetName();
-
-            // language
-            OUString aLanguage("Basic");
+            OUString aName = pBasic->GetName() + "." + pModule->GetName() + "." + pMethod->GetName();
 
             // location
             OUString aLocation;
@@ -359,7 +325,7 @@ OUString ChooseMacro( const uno::Reference< frame::XModel >& rxLimitToDocument,
                     {
                         // error
                         bError = true;
-                        ErrorBox( NULL, WB_OK | WB_DEF_OK, IDEResId(RID_STR_ERRORCHOOSEMACRO).toString() ).Execute();
+                        ScopedVclPtrInstance<MessageDialog>(nullptr, IDEResId(RID_STR_ERRORCHOOSEMACRO))->Execute();
                     }
                 }
             }
@@ -372,12 +338,7 @@ OUString ChooseMacro( const uno::Reference< frame::XModel >& rxLimitToDocument,
             // script URL
             if ( !bError )
             {
-                aScriptURL = "vnd.sun.star.script:" ;
-                aScriptURL += aName;
-                aScriptURL += "?language=" ;
-                aScriptURL += aLanguage;
-                aScriptURL += "&location=" ;
-                aScriptURL += aLocation;
+                aScriptURL = "vnd.sun.star.script:" + aName + "?language=Basic&location=" + aLocation;
             }
 
             if ( !rxLimitToDocument.is() )
@@ -385,7 +346,7 @@ OUString ChooseMacro( const uno::Reference< frame::XModel >& rxLimitToDocument,
                 MacroExecutionData* pExecData = new MacroExecutionData;
                 pExecData->aDocument = aDocument;
                 pExecData->xMethod = pMethod;   // keep alive until the event has been processed
-                Application::PostUserEvent( STATIC_LINK( NULL, MacroExecution, ExecuteMacroEvent ), pExecData );
+                Application::PostUserEvent( LINK( nullptr, MacroExecution, ExecuteMacroEvent ), pExecData );
             }
         }
         break;
@@ -394,10 +355,7 @@ OUString ChooseMacro( const uno::Reference< frame::XModel >& rxLimitToDocument,
     return aScriptURL;
 }
 
-//----------------------------------------------------------------------------
-
 Sequence< OUString > GetMethodNames( const ScriptDocument& rDocument, const OUString& rLibName, const OUString& rModName )
-    throw(NoSuchElementException )
 {
     Sequence< OUString > aSeqMethods;
 
@@ -406,24 +364,24 @@ Sequence< OUString > GetMethodNames( const ScriptDocument& rDocument, const OUSt
     if ( rDocument.getModule( rLibName, rModName, aOUSource ) )
     {
         BasicManager* pBasMgr = rDocument.getBasicManager();
-        StarBASIC* pSb = pBasMgr ? pBasMgr->GetLib( rLibName ) : NULL;
-        SbModule* pMod = pSb ? pSb->FindModule( rModName ) : NULL;
+        StarBASIC* pSb = pBasMgr ? pBasMgr->GetLib( rLibName ) : nullptr;
+        SbModule* pMod = pSb ? pSb->FindModule( rModName ) : nullptr;
 
         SbModuleRef xModule;
         // Only reparse modules if ScriptDocument source is out of sync
         // with basic's Module
-        if ( !pMod || ( pMod && pMod->GetSource() != aOUSource ) )
+        if ( !pMod || pMod->GetSource() != aOUSource )
         {
             xModule = new SbModule( rModName );
             xModule->SetSource32( aOUSource );
-            pMod = xModule;
+            pMod = xModule.get();
         }
 
         sal_uInt16 nCount = pMod->GetMethods()->Count();
         sal_uInt16 nRealCount = nCount;
         for ( sal_uInt16 i = 0; i < nCount; i++ )
         {
-            SbMethod* pMethod = (SbMethod*)pMod->GetMethods()->Get( i );
+            SbMethod* pMethod = static_cast<SbMethod*>(pMod->GetMethods()->Get( i ));
             if( pMethod->IsHidden() )
                 --nRealCount;
         }
@@ -432,7 +390,7 @@ Sequence< OUString > GetMethodNames( const ScriptDocument& rDocument, const OUSt
         sal_uInt16 iTarget = 0;
         for ( sal_uInt16 i = 0 ; i < nCount; ++i )
         {
-            SbMethod* pMethod = (SbMethod*)pMod->GetMethods()->Get( i );
+            SbMethod* pMethod = static_cast<SbMethod*>(pMod->GetMethods()->Get( i ));
             if( pMethod->IsHidden() )
                 continue;
             SAL_WARN_IF( !pMethod, "basctl.basicide","Method not found! (NULL)" );
@@ -443,8 +401,6 @@ Sequence< OUString > GetMethodNames( const ScriptDocument& rDocument, const OUSt
     return aSeqMethods;
 }
 
-//----------------------------------------------------------------------------
-
 bool HasMethod (
     ScriptDocument const& rDocument,
     OUString const& rLibName,
@@ -459,21 +415,21 @@ bool HasMethod (
     {
         // Check if we really need to scan the source ( again )
         BasicManager* pBasMgr = rDocument.getBasicManager();
-        StarBASIC* pSb = pBasMgr ? pBasMgr->GetLib( rLibName ) : NULL;
-        SbModule* pMod = pSb ? pSb->FindModule( rModName ) : NULL;
+        StarBASIC* pSb = pBasMgr ? pBasMgr->GetLib( rLibName ) : nullptr;
+        SbModule* pMod = pSb ? pSb->FindModule( rModName ) : nullptr;
         SbModuleRef xModule;
         // Only reparse modules if ScriptDocument source is out of sync
         // with basic's Module
-        if ( !pMod || ( pMod && pMod->GetSource() != aOUSource ))
+        if ( !pMod || pMod->GetSource() != aOUSource )
         {
             xModule = new SbModule( rModName );
             xModule->SetSource32( aOUSource );
-            pMod = xModule;
+            pMod = xModule.get();
         }
-        SbxArray* pMethods = pMod->GetMethods();
+        SbxArray* pMethods = pMod->GetMethods().get();
         if ( pMethods )
         {
-            SbMethod* pMethod = (SbMethod*)pMethods->Find( rMethName, SbxCLASS_METHOD );
+            SbMethod* pMethod = static_cast<SbMethod*>(pMethods->Find( rMethName, SbxClassType::Method ));
             if ( pMethod && !pMethod->IsHidden() )
                 bHasMethod = true;
         }
@@ -482,7 +438,6 @@ bool HasMethod (
     return bHasMethod;
 }
 
-//----------------------------------------------------------------------------
 } // namespace basctl
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
