@@ -17,16 +17,15 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "basidesh.hrc"
-#include "helpid.hrc"
+#include <strings.hrc>
+#include <helpids.h>
 
 #include "baside2.hxx"
-#include "baside3.hxx"
-#include "iderdll.hxx"
+#include <baside3.hxx>
+#include <iderdll.hxx>
 #include "iderdll2.hxx"
 
 #include <basic/basmgr.hxx>
-#include <com/sun/star/script/ModuleType.hpp>
 #include <com/sun/star/script/XLibraryContainerPassword.hpp>
 #include <sfx2/dispatch.hxx>
 #include <sfx2/passwd.hxx>
@@ -102,7 +101,7 @@ void BaseWindow::ExecuteGlobal (SfxRequest&)
 { }
 
 
-bool BaseWindow::Notify( NotifyEvent& rNEvt )
+bool BaseWindow::EventNotify( NotifyEvent& rNEvt )
 {
     bool bDone = false;
 
@@ -128,7 +127,7 @@ bool BaseWindow::Notify( NotifyEvent& rNEvt )
         }
     }
 
-    return bDone || Window::Notify( rNEvt );
+    return bDone || Window::EventNotify( rNEvt );
 }
 
 
@@ -210,9 +209,8 @@ SearchOptionFlags BaseWindow::GetSearchOptions()
     return SearchOptionFlags::NONE;
 }
 
-sal_uInt16 BaseWindow::StartSearchAndReplace (SvxSearchItem const&, bool bFromStart)
+sal_uInt16 BaseWindow::StartSearchAndReplace (SvxSearchItem const&, bool)
 {
-    static_cast<void>(bFromStart);
     return 0;
 }
 
@@ -284,7 +282,7 @@ void DockingWindow::dispose()
 // when the window is floating. Called by Layout.
 void DockingWindow::ResizeIfDocking (Point const& rPos, Size const& rSize)
 {
-    Rectangle const rRect(rPos, rSize);
+    tools::Rectangle const rRect(rPos, rSize);
     if (rRect != aDockingRect)
     {
         // saving the position and the size
@@ -332,7 +330,7 @@ void DockingWindow::Hide ()
     Show(false);
 }
 
-bool DockingWindow::Docking( const Point& rPos, Rectangle& rRect )
+bool DockingWindow::Docking( const Point& rPos, tools::Rectangle& rRect )
 {
     if (aDockingRect.IsInside(rPos))
     {
@@ -347,7 +345,7 @@ bool DockingWindow::Docking( const Point& rPos, Rectangle& rRect )
     }
 }
 
-void DockingWindow::EndDocking( const Rectangle& rRect, bool bFloatMode )
+void DockingWindow::EndDocking( const tools::Rectangle& rRect, bool bFloatMode )
 {
     if ( bFloatMode )
         ::DockingWindow::EndDocking( rRect, bFloatMode );
@@ -376,7 +374,7 @@ bool DockingWindow::PrepareToggleFloatingMode()
     if (IsFloatingMode())
     {
         // memorize position and size on the desktop...
-        aFloatingRect = Rectangle(
+        aFloatingRect = tools::Rectangle(
             GetParent()->OutputToScreenPixel(GetPosPixel()),
             GetSizePixel()
         );
@@ -388,7 +386,7 @@ void DockingWindow::StartDocking()
 {
     if (IsFloatingMode())
     {
-        aFloatingRect = Rectangle(
+        aFloatingRect = tools::Rectangle(
             GetParent()->OutputToScreenPixel(GetPosPixel()),
             GetSizePixel()
         );
@@ -410,7 +408,7 @@ void DockingWindow::DockThis ()
     {
         if (!IsFloatingMode() && GetParent() != pLayout)
             SetParent(pLayout);
-        pLayout->DockaWindow(this);
+        pLayout->ArrangeWindows();
     }
 }
 
@@ -425,7 +423,6 @@ ExtendedEdit::ExtendedEdit(vcl::Window* pParent, WinBits nStyle)
 IMPL_LINK_NOARG(ExtendedEdit, ImplGetFocusHdl, Control&, void)
 {
     Application::InsertAccel( &aAcc );
-    aLoseFocusHdl.Call( this );
 }
 
 IMPL_LINK_NOARG(ExtendedEdit, ImplLoseFocusHdl, Control&, void)
@@ -470,60 +467,8 @@ void TabBar::Command( const CommandEvent& rCEvt )
             MouseEvent aMouseEvent( aP, 1, MouseEventModifiers::SIMPLECLICK, MOUSE_LEFT );
             ::TabBar::MouseButtonDown( aMouseEvent ); // base class
         }
-
-        ScopedVclPtrInstance<PopupMenu> aPopup( IDEResId( RID_POPUP_TABBAR ) );
-        if ( GetPageCount() == 0 )
-        {
-            aPopup->EnableItem(SID_BASICIDE_DELETECURRENT, false);
-            aPopup->EnableItem(SID_BASICIDE_RENAMECURRENT, false);
-            aPopup->EnableItem(SID_BASICIDE_HIDECURPAGE, false);
-        }
-
-        if ( StarBASIC::IsRunning() )
-        {
-            aPopup->EnableItem(SID_BASICIDE_DELETECURRENT, false);
-            aPopup->EnableItem(SID_BASICIDE_RENAMECURRENT, false);
-            aPopup->EnableItem(SID_BASICIDE_MODULEDLG, false);
-        }
-
-        if (Shell* pShell = GetShell())
-        {
-            ScriptDocument aDocument( pShell->GetCurDocument() );
-            OUString       aOULibName( pShell->GetCurLibName() );
-            Reference< script::XLibraryContainer2 > xModLibContainer( aDocument.getLibraryContainer( E_SCRIPTS ), UNO_QUERY );
-            Reference< script::XLibraryContainer2 > xDlgLibContainer( aDocument.getLibraryContainer( E_DIALOGS ), UNO_QUERY );
-            if ( ( xModLibContainer.is() && xModLibContainer->hasByName( aOULibName ) && xModLibContainer->isLibraryReadOnly( aOULibName ) ) ||
-                 ( xDlgLibContainer.is() && xDlgLibContainer->hasByName( aOULibName ) && xDlgLibContainer->isLibraryReadOnly( aOULibName ) ) )
-            {
-                aPopup->EnableItem(aPopup->GetItemId( 0 ), false);
-                aPopup->EnableItem(SID_BASICIDE_DELETECURRENT, false);
-                aPopup->EnableItem(SID_BASICIDE_RENAMECURRENT, false);
-                aPopup->RemoveDisabledEntries();
-            }
-             if ( aDocument.isInVBAMode() )
-            {
-                // disable to delete or remove object modules in IDE
-                if (BasicManager* pBasMgr = aDocument.getBasicManager())
-                {
-                    if (StarBASIC* pBasic = pBasMgr->GetLib(aOULibName))
-                    {
-                        Shell::WindowTable& aWindowTable = pShell->GetWindowTable();
-                        Shell::WindowTableIt it = aWindowTable.find( GetCurPageId() );
-                        if (it != aWindowTable.end() && dynamic_cast<ModulWindow*>(it->second.get()))
-                        {
-                            SbModule* pActiveModule = pBasic->FindModule( it->second->GetName() );
-                            if( pActiveModule && ( pActiveModule->GetModuleType() == script::ModuleType::DOCUMENT ) )
-                            {
-                                aPopup->EnableItem(SID_BASICIDE_DELETECURRENT, false);
-                                aPopup->EnableItem(SID_BASICIDE_RENAMECURRENT, false);
-                            }
-                        }
-                    }
-                }
-            }
-        }
         if (SfxDispatcher* pDispatcher = GetDispatcher())
-            pDispatcher->Execute(aPopup->Execute(this, aPos));
+            pDispatcher->ExecutePopup("tabbar", this, &aPos);
     }
 }
 
@@ -585,7 +530,7 @@ void TabBar::Sort()
             sal_uInt16 nId = GetPageId( i );
             aTabBarSortHelper.nPageId = nId;
             aTabBarSortHelper.aPageText = GetPageText( nId );
-            BaseWindow* pWin = aWindowTable[ nId ];
+            BaseWindow* pWin = aWindowTable[ nId ].get();
 
             if (dynamic_cast<ModulWindow*>(pWin))
             {
@@ -598,8 +543,8 @@ void TabBar::Sort()
         }
 
         // sort module and dialog lists by page text
-        ::std::sort( aModuleList.begin() , aModuleList.end() );
-        ::std::sort( aDialogList.begin() , aDialogList.end() );
+        std::sort( aModuleList.begin() , aModuleList.end() );
+        std::sort( aDialogList.begin() , aDialogList.end() );
 
 
         sal_uInt16 nModules = sal::static_int_cast<sal_uInt16>( aModuleList.size() );
@@ -619,7 +564,7 @@ void TabBar::Sort()
     }
 }
 
-void CutLines( OUString& rStr, sal_Int32 nStartLine, sal_Int32 nLines, bool bEraseTrailingEmptyLines )
+void CutLines( OUString& rStr, sal_Int32 nStartLine, sal_Int32 nLines )
 {
     sal_Int32 nStartPos = 0;
     sal_Int32 nLine = 0;
@@ -632,7 +577,7 @@ void CutLines( OUString& rStr, sal_Int32 nStartLine, sal_Int32 nLines, bool bEra
         nLine++;
     }
 
-    SAL_WARN_IF( nStartPos == -1, "basctl.basicide", "CutLines: Startzeile nicht gefunden!" );
+    SAL_WARN_IF( nStartPos == -1, "basctl.basicide", "CutLines: Start line not found!" );
 
     if ( nStartPos == -1 )
         return;
@@ -651,7 +596,7 @@ void CutLines( OUString& rStr, sal_Int32 nStartLine, sal_Int32 nLines, bool bEra
     rStr = rStr.copy( 0, nStartPos );
     rStr += aEndStr;
 
-    if ( bEraseTrailingEmptyLines )
+    // erase trailing empty lines
     {
         sal_Int32 n = nStartPos;
         sal_Int32 nLen = rStr.getLength();
@@ -678,7 +623,7 @@ sal_uLong CalcLineCount( SvStream& rStream )
 
     rStream.Seek( 0 );
     rStream.ReadChar( c );
-    while ( !rStream.IsEof() )
+    while ( !rStream.eof() )
     {
         if ( c == '\n' )
             nLFs++;
@@ -712,7 +657,7 @@ void LibInfo::InsertInfo (
 {
     Key aKey(rDocument, rLibName);
     m_aMap.erase(aKey);
-    m_aMap.insert(Map::value_type(aKey, Item(rCurrentName, eCurrentType)));
+    m_aMap.emplace(aKey, Item(rCurrentName, eCurrentType));
 }
 
 void LibInfo::RemoveInfoFor (ScriptDocument const& rDocument)
@@ -761,14 +706,13 @@ LibInfo::Item::Item (
 LibInfo::Item::~Item ()
 { }
 
-bool QueryDel( const OUString& rName, const ResId& rId, vcl::Window* pParent )
+bool QueryDel(const OUString& rName, const OUString &rStr, vcl::Window* pParent)
 {
-    OUString aQuery(rId.toString());
     OUStringBuffer aNameBuf( rName );
     aNameBuf.append('\'');
     aNameBuf.insert(0, '\'');
-    aQuery = aQuery.replaceAll("XX", aNameBuf.makeStringAndClear());
-    ScopedVclPtrInstance< MessageDialog > aQueryBox(pParent, aQuery, VclMessageType::Question, VCL_BUTTONS_YES_NO);
+    OUString aQuery = rStr.replaceAll("XX", aNameBuf.makeStringAndClear());
+    ScopedVclPtrInstance< MessageDialog > aQueryBox(pParent, aQuery, VclMessageType::Question, VclButtonsType::YesNo);
     return ( aQueryBox->Execute() == RET_YES );
 }
 
@@ -811,7 +755,7 @@ bool QueryPassword( const Reference< script::XLibraryContainer >& xLibContainer,
         // set new title
         if ( bNewTitle )
         {
-            OUString aTitle(IDE_RESSTR(RID_STR_ENTERPASSWORD));
+            OUString aTitle(IDEResId(RID_STR_ENTERPASSWORD));
             aTitle = aTitle.replaceAll("XX", rLibName);
             aDlg->SetText( aTitle );
         }
@@ -833,7 +777,7 @@ bool QueryPassword( const Reference< script::XLibraryContainer >& xLibContainer,
 
                     if ( !bOK )
                     {
-                        ScopedVclPtrInstance< MessageDialog > aErrorBox(Application::GetDefDialogParent(), IDE_RESSTR(RID_STR_WRONGPASSWORD));
+                        ScopedVclPtrInstance< MessageDialog > aErrorBox(Application::GetDefDialogParent(), IDEResId(RID_STR_WRONGPASSWORD));
                         aErrorBox->Execute();
                     }
                 }
