@@ -17,52 +17,39 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include <memory>
-#include <vcl/msgbox.hxx>
 
-#include <macrodlg.hxx>
-#include <macrodlg.hrc>
-#include <basidesh.hrc>
+#include "macrodlg.hxx"
 #include <basidesh.hxx>
-#include <baside2.hrc>
-#include <basobj.hxx>
-#include <baside3.hxx>
+#include <strings.hrc>
 
 #include <iderdll.hxx>
-#include <iderdll2.hxx>
-#include <iderid.hxx>
+#include "iderdll2.hxx"
 
-#include <moduldlg.hxx>
+#include "moduldlg.hxx"
 #include <basic/basmgr.hxx>
 #include <basic/sbmeth.hxx>
 #include <basic/sbmod.hxx>
-#include <basic/sbx.hxx>
 
-#include <bastypes.hxx>
-#include <sbxitem.hxx>
-#include <sfx2/app.hxx>
 #include <sfx2/dispatch.hxx>
 #include <sfx2/minfitem.hxx>
 #include <sfx2/request.hxx>
 
-#include <com/sun/star/script/XLibraryContainer2.hpp>
-#include <com/sun/star/document/MacroExecMode.hpp>
 
 #include <map>
 
 namespace basctl
 {
 
-using ::std::map;
-using ::std::pair;
+using std::map;
 
 using namespace ::com::sun::star;
 using namespace ::com::sun::star::uno;
 
-MacroChooser::MacroChooser( Window* pParnt, bool bCreateEntries )
+MacroChooser::MacroChooser( vcl::Window* pParnt, const Reference< frame::XFrame >& xDocFrame, bool bCreateEntries )
     : SfxModalDialog(pParnt, "BasicMacroDialog", "modules/BasicIDE/ui/basicmacrodialog.ui")
+    , m_xDocumentFrame(xDocFrame)
     , bNewDelIsDel(true)
-    // the Sfx doesn't aske the BasicManger whether modified or not
+    // the Sfx doesn't ask the BasicManager whether modified or not
     // => start saving in case of a change without a into the BasicIDE.
     , bForceStoreBasic(false)
     , nMode(All)
@@ -83,7 +70,7 @@ MacroChooser::MacroChooser( Window* pParnt, bool bCreateEntries )
     get(m_pNewLibButton, "newlibrary");
     get(m_pNewModButton, "newmodule");
 
-    m_pMacroBox->SetSelectionMode( SINGLE_SELECTION );
+    m_pMacroBox->SetSelectionMode( SelectionMode::Single );
     m_pMacroBox->SetHighlightRange(); // select over the whole width
 
     m_pRunButton->SetClickHdl( LINK( this, MacroChooser, ButtonHdl ) );
@@ -109,7 +96,7 @@ MacroChooser::MacroChooser( Window* pParnt, bool bCreateEntries )
     m_pMacroBox->SetDoubleClickHdl( LINK( this, MacroChooser, MacroDoubleClickHdl ) );
     m_pMacroBox->SetSelectHdl( LINK( this, MacroChooser, MacroSelectHdl ) );
 
-    m_pBasicBox->SetMode( BROWSEMODE_MODULES );
+    m_pBasicBox->SetMode( BrowseMode::Modules );
     m_pBasicBox->SetStyle( WB_TABSTOP | WB_BORDER |
                         WB_HASLINES | WB_HASLINESATROOT |
                         WB_HASBUTTONS | WB_HASBUTTONSATROOT |
@@ -123,9 +110,32 @@ MacroChooser::MacroChooser( Window* pParnt, bool bCreateEntries )
 }
 
 MacroChooser::~MacroChooser()
+{
+    disposeOnce();
+}
+
+void MacroChooser::dispose()
 {
     if ( bForceStoreBasic )
-        SFX_APP()->SaveBasicAndDialogContainer();
+    {
+        SfxGetpApp()->SaveBasicAndDialogContainer();
+        bForceStoreBasic = false;
+    }
+    m_pMacroNameEdit.clear();
+    m_pMacroFromTxT.clear();
+    m_pMacrosSaveInTxt.clear();
+    m_pBasicBox.clear();
+    m_pMacrosInTxt.clear();
+    m_pMacroBox.clear();
+    m_pRunButton.clear();
+    m_pCloseButton.clear();
+    m_pAssignButton.clear();
+    m_pEditButton.clear();
+    m_pDelButton.clear();
+    m_pOrganizeButton.clear();
+    m_pNewLibButton.clear();
+    m_pNewModButton.clear();
+    SfxModalDialog::dispose();
 }
 
 void MacroChooser::StoreMacroDescription()
@@ -167,7 +177,7 @@ void MacroChooser::RestoreMacroDescription()
     if ( !aLastMacro.isEmpty() )
     {
         // find entry in macro box
-        SvTreeListEntry* pEntry = 0;
+        SvTreeListEntry* pEntry = nullptr;
         sal_uLong nPos = 0;
         SvTreeListEntry* pE = m_pMacroBox->GetEntry( nPos );
         while ( pE )
@@ -232,16 +242,9 @@ short MacroChooser::Execute()
     if ( StarBASIC::IsRunning() )
         m_pCloseButton->GrabFocus();
 
-    Window* pPrevDlgParent = Application::GetDefDialogParent();
-    Application::SetDefDialogParent( this );
-    short nRet = ModalDialog::Execute();
-    // #57314# If the BasicIDE has been activated, don't reset the DefModalDialogParent to the inactive document.
-    if ( Application::GetDefDialogParent() == this )
-        Application::SetDefDialogParent( pPrevDlgParent );
-    return nRet;
+    return ModalDialog::Execute();
 }
 
-
 void MacroChooser::EnableButton( Button& rButton, bool bEnable )
 {
     if ( bEnable )
@@ -256,11 +259,9 @@ void MacroChooser::EnableButton( Button& rButton, bool bEnable )
 }
 
 
-
-
 SbMethod* MacroChooser::GetMacro()
 {
-    SbMethod* pMethod = 0;
+    SbMethod* pMethod = nullptr;
     SbModule* pModule = m_pBasicBox->FindModule( m_pBasicBox->GetCurEntry() );
     if ( pModule )
     {
@@ -268,18 +269,17 @@ SbMethod* MacroChooser::GetMacro()
         if ( pEntry )
         {
             OUString aMacroName( m_pMacroBox->GetEntryText( pEntry ) );
-            pMethod = (SbMethod*)pModule->GetMethods()->Find( aMacroName, SbxCLASS_METHOD );
+            pMethod = pModule->FindMethod( aMacroName, SbxClassType::Method );
         }
     }
     return pMethod;
 }
 
 
-
 void MacroChooser::DeleteMacro()
 {
     SbMethod* pMethod = GetMacro();
-    DBG_ASSERT( pMethod, "DeleteMacro: Kein Macro !" );
+    DBG_ASSERT( pMethod, "DeleteMacro: No Macro !" );
     if ( pMethod && QueryDelMacro( pMethod->GetName(), this ) )
     {
         if (SfxDispatcher* pDispatcher = GetDispatcher())
@@ -287,7 +287,7 @@ void MacroChooser::DeleteMacro()
 
         // mark current doc as modified:
         StarBASIC* pBasic = FindBasic(pMethod);
-        DBG_ASSERT( pBasic, "Basic?!" );
+        assert(pBasic && "Basic?!");
         BasicManager* pBasMgr = FindBasicManager( pBasic );
         DBG_ASSERT( pBasMgr, "BasMgr?" );
         ScriptDocument aDocument( ScriptDocument::getDocumentForBasicManager( pBasMgr ) );
@@ -299,12 +299,12 @@ void MacroChooser::DeleteMacro()
         }
 
         SbModule* pModule = pMethod->GetModule();
-        DBG_ASSERT( pModule, "DeleteMacro: Kein Modul?!" );
+        assert(pModule && "DeleteMacro: No Module?!");
         OUString aSource( pModule->GetSource32() );
         sal_uInt16 nStart, nEnd;
         pMethod->GetLineRange( nStart, nEnd );
         pModule->GetMethods()->Remove( pMethod );
-        CutLines( aSource, nStart-1, nEnd-nStart+1, true );
+        CutLines( aSource, nStart-1, nEnd-nStart+1 );
         pModule->SetSource32( aSource );
 
         // update module in library
@@ -321,13 +321,13 @@ void MacroChooser::DeleteMacro()
 
 SbMethod* MacroChooser::CreateMacro()
 {
-    SbMethod* pMethod = 0;
+    SbMethod* pMethod = nullptr;
     SvTreeListEntry* pCurEntry = m_pBasicBox->GetCurEntry();
     EntryDescriptor aDesc = m_pBasicBox->GetEntryDescriptor(pCurEntry);
     ScriptDocument aDocument( aDesc.GetDocument() );
     OSL_ENSURE( aDocument.isAlive(), "MacroChooser::CreateMacro: no document!" );
     if ( !aDocument.isAlive() )
-        return NULL;
+        return nullptr;
 
     OUString aLibName( aDesc.GetLibName() );
 
@@ -345,33 +345,36 @@ SbMethod* MacroChooser::CreateMacro()
         xDlgLibContainer->loadLibrary( aOULibName );
 
     BasicManager* pBasMgr = aDocument.getBasicManager();
-    StarBASIC* pBasic = pBasMgr ? pBasMgr->GetLib( aLibName ) : 0;
+    StarBASIC* pBasic = pBasMgr ? pBasMgr->GetLib( aLibName ) : nullptr;
     if ( pBasic )
     {
-        SbModule* pModule = 0;
+        SbModule* pModule = nullptr;
         OUString aModName( aDesc.GetName() );
         if ( !aModName.isEmpty() )
         {
             // extract the module name from the string like "Sheet1 (Example1)"
-            if( aDesc.GetLibSubName() == IDE_RESSTR(RID_STR_DOCUMENT_OBJECTS) )
+            if( aDesc.GetLibSubName() == IDEResId(RID_STR_DOCUMENT_OBJECTS) )
             {
                 sal_Int32 nIndex = 0;
                 aModName = aModName.getToken( 0, ' ', nIndex );
             }
             pModule = pBasic->FindModule( aModName );
         }
-        else if ( pBasic->GetModules()->Count() )
-            pModule = (SbModule*)pBasic->GetModules()->Get( 0 );
+        else if ( !pBasic->GetModules().empty() )
+            pModule = pBasic->GetModules().front().get();
+
+        // Retain the desired macro name before the macro dialog box is forced to close
+        // by opening the module name dialog window when no module exists in the current library.
+        OUString aSubName = m_pMacroNameEdit->GetText();
 
         if ( !pModule )
         {
-            pModule = createModImpl( static_cast<Window*>( this ),
-                aDocument, *m_pBasicBox, aLibName, aModName );
+            pModule = createModImpl( static_cast<vcl::Window*>( this ),
+                aDocument, *m_pBasicBox, aLibName, aModName, false );
         }
 
-        OUString aSubName = m_pMacroNameEdit->GetText();
-        DBG_ASSERT( !pModule || !pModule->GetMethods()->Find( aSubName, SbxCLASS_METHOD ), "Macro existiert schon!" );
-        pMethod = pModule ? basctl::CreateMacro( pModule, aSubName ) : NULL;
+        DBG_ASSERT( !pModule || !pModule->FindMethod( aSubName, SbxClassType::Method ), "Macro exists already!" );
+        pMethod = pModule ? basctl::CreateMacro( pModule, aSubName ) : nullptr;
     }
 
     return pMethod;
@@ -415,7 +418,7 @@ void MacroChooser::CheckButtons()
     if (nMode != Recording)
     {
         // Run...
-        bool bEnable = pMethod ? true : false;
+        bool bEnable = pMethod != nullptr;
         if (nMode != ChooseOnly && StarBASIC::IsRunning())
             bEnable = false;
         EnableButton(*m_pRunButton, bEnable);
@@ -424,10 +427,10 @@ void MacroChooser::CheckButtons()
     // organising still possible?
 
     // Assign...
-    EnableButton(*m_pAssignButton, pMethod ? true : false);
+    EnableButton(*m_pAssignButton, pMethod != nullptr);
 
     // Edit...
-    EnableButton(*m_pEditButton, pMacroEntry ? true : false);
+    EnableButton(*m_pEditButton, pMacroEntry != nullptr);
 
     // Organizer...
     EnableButton(*m_pOrganizeButton, !StarBASIC::IsRunning() && nMode == All);
@@ -437,10 +440,10 @@ void MacroChooser::CheckButtons()
     bool bShare = ( aDesc.GetLocation() == LIBRARY_LOCATION_SHARE );
     EnableButton(*m_pDelButton, !StarBASIC::IsRunning() && nMode == All && !bProtected && !bReadOnly && !bShare);
     bool bPrev = bNewDelIsDel;
-    bNewDelIsDel = pMethod ? true : false;
+    bNewDelIsDel = pMethod != nullptr;
     if (bPrev != bNewDelIsDel && nMode == All)
     {
-        OUString aBtnText( bNewDelIsDel ? IDEResId(RID_STR_BTNDEL).toString() : IDEResId(RID_STR_BTNNEW).toString() );
+        OUString aBtnText( bNewDelIsDel ? IDEResId(RID_STR_BTNDEL) : IDEResId(RID_STR_BTNNEW) );
         m_pDelButton->SetText( aBtnText );
     }
 
@@ -456,23 +459,21 @@ void MacroChooser::CheckButtons()
 }
 
 
-
-IMPL_LINK_NOARG_INLINE_START(MacroChooser, MacroDoubleClickHdl)
+IMPL_LINK_NOARG(MacroChooser, MacroDoubleClickHdl, SvTreeListBox*, bool)
 {
     StoreMacroDescription();
     if (nMode == Recording)
     {
         SbMethod* pMethod = GetMacro();
         if ( pMethod && !QueryReplaceMacro( pMethod->GetName(), this ) )
-            return 0;
+            return false;
     }
 
     EndDialog(Macro_OkRun);
-    return 0;
+    return false;
 }
-IMPL_LINK_NOARG_INLINE_END(MacroChooser, MacroDoubleClickHdl)
 
-IMPL_LINK( MacroChooser, MacroSelectHdl, SvTreeListBox *, pBox )
+IMPL_LINK( MacroChooser, MacroSelectHdl, SvTreeListBox *, pBox, void )
 {
     // Is also called if deselected!
     // Two function calls in every SelectHdl because
@@ -483,28 +484,23 @@ IMPL_LINK( MacroChooser, MacroSelectHdl, SvTreeListBox *, pBox )
         UpdateFields();
         CheckButtons();
     }
-    return 0;
 }
 
-IMPL_LINK( MacroChooser, BasicSelectHdl, SvTreeListBox *, pBox )
+IMPL_LINK( MacroChooser, BasicSelectHdl, SvTreeListBox *, pBox, void )
 {
     // Is also called if deselected!
     // Two function calls in every SelectHdl because
     // there's no separate DeselectHDL.
     // So find out if select or deselect:
     if ( !pBox->IsSelected( pBox->GetHdlEntry() ) )
-        return 0;
+        return;
 
     SbModule* pModule = m_pBasicBox->FindModule( m_pBasicBox->GetCurEntry() );
 
     m_pMacroBox->Clear();
     if ( pModule )
     {
-        OUString aStr = m_aMacrosInTxtBaseStr;
-        aStr += " " ;
-        aStr += pModule->GetName();
-
-        m_pMacrosInTxt->SetText( aStr );
+        m_pMacrosInTxt->SetText( m_aMacrosInTxtBaseStr + " " + pModule->GetName() );
 
         // The macros should be called in the same order that they
         // are written down in the module.
@@ -513,13 +509,13 @@ IMPL_LINK( MacroChooser, BasicSelectHdl, SvTreeListBox *, pBox )
         size_t nMacroCount = pModule->GetMethods()->Count();
         for ( size_t iMeth = 0; iMeth  < nMacroCount; iMeth++ )
         {
-            SbMethod* pMethod = (SbMethod*)pModule->GetMethods()->Get( iMeth );
+            SbMethod* pMethod = static_cast<SbMethod*>(pModule->GetMethods()->Get( iMeth ));
             if( pMethod->IsHidden() )
                 continue;
-            DBG_ASSERT( pMethod, "Methode nicht gefunden! (NULL)" );
+            DBG_ASSERT( pMethod, "Method not found! (NULL)" );
             sal_uInt16 nStart, nEnd;
             pMethod->GetLineRange( nStart, nEnd );
-            aMacros.insert( map< sal_uInt16, SbMethod*>::value_type( nStart, pMethod ) );
+            aMacros.emplace( nStart, pMethod );
         }
 
         m_pMacroBox->SetUpdateMode(false);
@@ -537,16 +533,12 @@ IMPL_LINK( MacroChooser, BasicSelectHdl, SvTreeListBox *, pBox )
 
     UpdateFields();
     CheckButtons();
-    return 0;
 }
 
 
-
-IMPL_LINK( MacroChooser, EditModifyHdl, Edit *, pEdit )
+IMPL_LINK_NOARG( MacroChooser, EditModifyHdl, Edit&, void )
 {
-    (void)pEdit;
-
-    // select the module in which the macro is put at Neu (new),
+    // select the module in which the macro is put at "new",
     // if BasicManager or Lib is selecting
     SvTreeListEntry* pCurEntry = m_pBasicBox->GetCurEntry();
     if ( pCurEntry )
@@ -576,7 +568,7 @@ IMPL_LINK( MacroChooser, EditModifyHdl, Edit *, pEdit )
         {
             OUString aEdtText( m_pMacroNameEdit->GetText() );
             bool bFound = false;
-            for ( sal_uInt16 n = 0; n < m_pMacroBox->GetEntryCount(); n++ )
+            for ( sal_uLong n = 0; n < m_pMacroBox->GetEntryCount(); n++ )
             {
                 SvTreeListEntry* pEntry = m_pMacroBox->GetEntry( n );
                 DBG_ASSERT( pEntry, "Entry ?!" );
@@ -590,7 +582,7 @@ IMPL_LINK( MacroChooser, EditModifyHdl, Edit *, pEdit )
             if ( !bFound )
             {
                 SvTreeListEntry* pEntry = m_pMacroBox->FirstSelected();
-                // if the entry exists ->Select ->Desription...
+                // if the entry exists ->Select ->Description...
                 if ( pEntry )
                     m_pMacroBox->Select( pEntry, false );
             }
@@ -598,12 +590,10 @@ IMPL_LINK( MacroChooser, EditModifyHdl, Edit *, pEdit )
     }
 
     CheckButtons();
-    return 0;
 }
 
 
-
-IMPL_LINK( MacroChooser, ButtonHdl, Button *, pButton )
+IMPL_LINK( MacroChooser, ButtonHdl, Button *, pButton, void )
 {
     // apart from New/Record the Description is done by LoseFocus
     if (pButton == m_pRunButton)
@@ -614,16 +604,16 @@ IMPL_LINK( MacroChooser, ButtonHdl, Button *, pButton )
         if (nMode == All)
         {
             SbMethod* pMethod = GetMacro();
-            SbModule* pModule = pMethod ? pMethod->GetModule() : NULL;
-            StarBASIC* pBasic = pModule ? (StarBASIC*)pModule->GetParent() : NULL;
-            BasicManager* pBasMgr = pBasic ? FindBasicManager(pBasic) : NULL;
+            SbModule* pModule = pMethod ? pMethod->GetModule() : nullptr;
+            StarBASIC* pBasic = pModule ? static_cast<StarBASIC*>(pModule->GetParent()) : nullptr;
+            BasicManager* pBasMgr = pBasic ? FindBasicManager(pBasic) : nullptr;
             if ( pBasMgr )
             {
                 ScriptDocument aDocument( ScriptDocument::getDocumentForBasicManager( pBasMgr ) );
                 if ( aDocument.isDocument() && !aDocument.allowMacros() )
                 {
-                    WarningBox( this, WB_OK, IDEResId(RID_STR_CANNOTRUNMACRO).toString() ).Execute();
-                    return 0;
+                    ScopedVclPtrInstance<MessageDialog>(this, IDEResId(RID_STR_CANNOTRUNMACRO), VclMessageType::Warning)->Execute();
+                    return;
                 }
             }
         }
@@ -631,15 +621,15 @@ IMPL_LINK( MacroChooser, ButtonHdl, Button *, pButton )
         {
             if ( !IsValidSbxName(m_pMacroNameEdit->GetText()) )
             {
-                ErrorBox( this, WB_OK | WB_DEF_OK, IDEResId(RID_STR_BADSBXNAME).toString() ).Execute();
+                ScopedVclPtrInstance<MessageDialog>(this, IDEResId(RID_STR_BADSBXNAME))->Execute();
                 m_pMacroNameEdit->SetSelection( Selection( 0, m_pMacroNameEdit->GetText().getLength() ) );
                 m_pMacroNameEdit->GrabFocus();
-                return 0;
+                return;
             }
 
             SbMethod* pMethod = GetMacro();
             if ( pMethod && !QueryReplaceMacro( pMethod->GetName(), this ) )
-                return 0;
+                return;
         }
 
         EndDialog(Macro_OkRun);
@@ -656,12 +646,12 @@ IMPL_LINK( MacroChooser, ButtonHdl, Button *, pButton )
         ScriptDocument aDocument( aDesc.GetDocument() );
         DBG_ASSERT( aDocument.isAlive(), "MacroChooser::ButtonHdl: no document, or document is dead!" );
         if ( !aDocument.isAlive() )
-            return 0;
+            return;
         BasicManager* pBasMgr = aDocument.getBasicManager();
         OUString aLib( aDesc.GetLibName() );
         OUString aMod( aDesc.GetName() );
         // extract the module name from the string like "Sheet1 (Example1)"
-        if( aDesc.GetLibSubName() == IDE_RESSTR(RID_STR_DOCUMENT_OBJECTS) )
+        if( aDesc.GetLibSubName() == IDEResId(RID_STR_DOCUMENT_OBJECTS) )
         {
             sal_Int32 nIndex = 0;
             aMod = aMod.getToken( 0, ' ', nIndex );
@@ -674,12 +664,15 @@ IMPL_LINK( MacroChooser, ButtonHdl, Button *, pButton )
             if ( pEntry )
                 aInfoItem.SetMethod( m_pMacroBox->GetEntryText( pEntry ) );
             StoreMacroDescription();
-            SfxAllItemSet aArgs( SFX_APP()->GetPool() );
-            SfxRequest aRequest( SID_BASICIDE_APPEAR, SFX_CALLMODE_SYNCHRON, aArgs );
-            SFX_APP()->ExecuteSlot( aRequest );
+            SfxAllItemSet aArgs( SfxGetpApp()->GetPool() );
+            SfxRequest aRequest( SID_BASICIDE_APPEAR, SfxCallMode::SYNCHRON, aArgs );
+            SfxGetpApp()->ExecuteSlot( aRequest );
 
             if (SfxDispatcher* pDispatcher = GetDispatcher())
-                pDispatcher->Execute( SID_BASICIDE_EDITMACRO, SFX_CALLMODE_ASYNCHRON, &aInfoItem, 0L );
+            {
+                pDispatcher->ExecuteList(SID_BASICIDE_EDITMACRO,
+                        SfxCallMode::ASYNCHRON, { &aInfoItem });
+            }
             EndDialog(Macro_Edit);
         }
         else
@@ -688,8 +681,10 @@ IMPL_LINK( MacroChooser, ButtonHdl, Button *, pButton )
             {
                 DeleteMacro();
                 if (SfxDispatcher* pDispatcher = GetDispatcher())
-                    pDispatcher->Execute( SID_BASICIDE_UPDATEMODULESOURCE,
-                                          SFX_CALLMODE_SYNCHRON, &aInfoItem, 0L );
+                {
+                    pDispatcher->ExecuteList( SID_BASICIDE_UPDATEMODULESOURCE,
+                                  SfxCallMode::SYNCHRON, { &aInfoItem });
+                }
                 CheckButtons();
                 UpdateFields();
                 //if ( m_pMacroBox->GetCurEntry() )    // OV-Bug ?
@@ -699,10 +694,10 @@ IMPL_LINK( MacroChooser, ButtonHdl, Button *, pButton )
             {
                 if ( !IsValidSbxName(m_pMacroNameEdit->GetText()) )
                 {
-                    ErrorBox( this, WB_OK | WB_DEF_OK, IDEResId(RID_STR_BADSBXNAME).toString() ).Execute();
+                    ScopedVclPtrInstance<MessageDialog>(this, IDEResId(RID_STR_BADSBXNAME))->Execute();
                     m_pMacroNameEdit->SetSelection( Selection( 0, m_pMacroNameEdit->GetText().getLength() ) );
                     m_pMacroNameEdit->GrabFocus();
-                    return 1;
+                    return;
                 }
                 SbMethod* pMethod = CreateMacro();
                 if ( pMethod )
@@ -710,12 +705,15 @@ IMPL_LINK( MacroChooser, ButtonHdl, Button *, pButton )
                     aInfoItem.SetMethod( pMethod->GetName() );
                     aInfoItem.SetModule( pMethod->GetModule()->GetName() );
                     aInfoItem.SetLib( pMethod->GetModule()->GetParent()->GetName() );
-                    SfxAllItemSet aArgs( SFX_APP()->GetPool() );
-                    SfxRequest aRequest( SID_BASICIDE_APPEAR, SFX_CALLMODE_SYNCHRON, aArgs );
-                    SFX_APP()->ExecuteSlot( aRequest );
+                    SfxAllItemSet aArgs( SfxGetpApp()->GetPool() );
+                    SfxRequest aRequest( SID_BASICIDE_APPEAR, SfxCallMode::SYNCHRON, aArgs );
+                    SfxGetpApp()->ExecuteSlot( aRequest );
 
                     if (SfxDispatcher* pDispatcher = GetDispatcher())
-                        pDispatcher->Execute( SID_BASICIDE_EDITMACRO, SFX_CALLMODE_ASYNCHRON, &aInfoItem, 0L );
+                    {
+                        pDispatcher->ExecuteList(SID_BASICIDE_EDITMACRO,
+                                SfxCallMode::ASYNCHRON, { &aInfoItem });
+                    }
                     StoreMacroDescription();
                     EndDialog(Macro_New);
                 }
@@ -729,7 +727,7 @@ IMPL_LINK( MacroChooser, ButtonHdl, Button *, pButton )
         ScriptDocument aDocument( aDesc.GetDocument() );
         DBG_ASSERT( aDocument.isAlive(), "MacroChooser::ButtonHdl: no document, or document is dead!" );
         if ( !aDocument.isAlive() )
-            return 0;
+            return;
         BasicManager* pBasMgr = aDocument.getBasicManager();
         OUString aLib( aDesc.GetLibName() );
         OUString aMod( aDesc.GetName() );
@@ -739,17 +737,22 @@ IMPL_LINK( MacroChooser, ButtonHdl, Button *, pButton )
         DBG_ASSERT( pMethod, "Method?" );
         OUString aComment( GetInfo( pMethod ) );
         SfxMacroInfoItem aItem( SID_MACROINFO, pBasMgr, aLib, aMod, aSub, aComment );
-        SfxAllItemSet Args( SFX_APP()->GetPool() );
-        SfxRequest aRequest( SID_CONFIG, SFX_CALLMODE_SYNCHRON, Args );
+        SfxAllItemSet Args( SfxGetpApp()->GetPool() );
+
+        SfxAllItemSet aInternalSet(SfxGetpApp()->GetPool());
+        if (m_xDocumentFrame.is())
+            aInternalSet.Put(SfxUnoFrameItem(SID_FILLFRAME, m_xDocumentFrame));
+
+        SfxRequest aRequest(SID_CONFIG, SfxCallMode::SYNCHRON, Args, aInternalSet);
         aRequest.AppendItem( aItem );
-        SFX_APP()->ExecuteSlot( aRequest );
+        SfxGetpApp()->ExecuteSlot( aRequest );
     }
     else if (pButton == m_pNewLibButton)
     {
         SvTreeListEntry* pCurEntry = m_pBasicBox->GetCurEntry();
         EntryDescriptor aDesc = m_pBasicBox->GetEntryDescriptor(pCurEntry);
         ScriptDocument aDocument( aDesc.GetDocument() );
-        createLibImpl( static_cast<Window*>( this ), aDocument, NULL, m_pBasicBox );
+        createLibImpl( static_cast<vcl::Window*>( this ), aDocument, nullptr, m_pBasicBox );
     }
     else if (pButton == m_pNewModButton)
     {
@@ -757,23 +760,22 @@ IMPL_LINK( MacroChooser, ButtonHdl, Button *, pButton )
         EntryDescriptor aDesc = m_pBasicBox->GetEntryDescriptor(pCurEntry);
         ScriptDocument aDocument( aDesc.GetDocument() );
         OUString aLibName( aDesc.GetLibName() );
-        OUString aModName;
-        createModImpl( static_cast<Window*>( this ), aDocument,
-            *m_pBasicBox, aLibName, aModName, true );
+        createModImpl( static_cast<vcl::Window*>( this ), aDocument,
+            *m_pBasicBox, aLibName, OUString(), true );
     }
     else if (pButton == m_pOrganizeButton)
     {
         StoreMacroDescription();
 
         EntryDescriptor aDesc = m_pBasicBox->GetEntryDescriptor(m_pBasicBox->FirstSelected());
-        OrganizeDialog* pDlg = new OrganizeDialog( this, 0, aDesc );
+        VclPtrInstance< OrganizeDialog > pDlg( this, 0, aDesc );
         sal_uInt16 nRet = pDlg->Execute();
-        delete pDlg;
+        pDlg.reset();
 
         if ( nRet ) // not only closed
         {
             EndDialog(Macro_Edit);
-            return 0;
+            return;
         }
 
         Shell* pShell = GetShell();
@@ -782,17 +784,14 @@ IMPL_LINK( MacroChooser, ButtonHdl, Button *, pButton )
 
         m_pBasicBox->UpdateEntries();
     }
-    return 0;
 }
 
 
-
 void MacroChooser::UpdateFields()
 {
     SvTreeListEntry*    pMacroEntry = m_pMacroBox->GetCurEntry();
-    OUString            aEmptyStr;
 
-    m_pMacroNameEdit->SetText( aEmptyStr );
+    m_pMacroNameEdit->SetText( "" );
     if ( pMacroEntry )
         m_pMacroNameEdit->SetText( m_pMacroBox->GetEntryText( pMacroEntry ) );
 }
@@ -804,7 +803,7 @@ void MacroChooser::SetMode (Mode nM)
     {
         case All:
         {
-            m_pRunButton->SetText(IDEResId(RID_STR_RUN).toString());
+            m_pRunButton->SetText(IDEResId(RID_STR_RUN));
             EnableButton(*m_pDelButton, true);
             EnableButton(*m_pOrganizeButton, true);
             break;
@@ -812,7 +811,7 @@ void MacroChooser::SetMode (Mode nM)
 
         case ChooseOnly:
         {
-            m_pRunButton->SetText(IDEResId(RID_STR_CHOOSE).toString());
+            m_pRunButton->SetText(IDEResId(RID_STR_CHOOSE));
             EnableButton(*m_pDelButton, false);
             EnableButton(*m_pOrganizeButton, false);
             break;
@@ -820,7 +819,7 @@ void MacroChooser::SetMode (Mode nM)
 
         case Recording:
         {
-            m_pRunButton->SetText(IDEResId(RID_STR_RECORD).toString());
+            m_pRunButton->SetText(IDEResId(RID_STR_RECORD));
             EnableButton(*m_pDelButton, false);
             EnableButton(*m_pOrganizeButton, false);
 
@@ -844,7 +843,7 @@ OUString MacroChooser::GetInfo( SbxVariable* pVar )
 {
     OUString aComment;
     SbxInfoRef xInfo = pVar->GetInfo();
-    if ( xInfo.Is() )
+    if ( xInfo.is() )
         aComment = xInfo->GetComment();
     return aComment;
 }
