@@ -17,10 +17,10 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "objdlg.hrc"
+#include <strings.hrc>
 
-#include "objdlg.hxx"
-#include "helpid.hrc"
+#include <objdlg.hxx>
+#include <helpids.h>
 
 #include <svl/itemset.hxx>
 #include <vcl/taskpanelist.hxx>
@@ -28,16 +28,16 @@
 namespace basctl
 {
 
-ObjectCatalog::ObjectCatalog (vcl::Window* pParent) :
-    DockingWindow(pParent),
-    aTitle(VclPtr<FixedText>::Create(this)),
-    aTree(VclPtr<TreeListBox>::Create(this, IDEResId(RID_TLB_MACROS)))
+ObjectCatalog::ObjectCatalog (vcl::Window* pParent)
+    : DockingWindow(pParent)
+    , aTitle(VclPtr<FixedText>::Create(this))
+    , aTree(VclPtr<TreeListBox>::Create(this, WB_TABSTOP))
 {
     SetHelpId("basctl:FloatingWindow:RID_BASICIDE_OBJCAT");
-    SetText(IDEResId(RID_BASICIDE_OBJCAT).toString());
+    SetText(IDEResId(RID_BASICIDE_OBJCAT));
 
     // title
-    aTitle->SetText(IDEResId(RID_BASICIDE_OBJCAT).toString());
+    aTitle->SetText(IDEResId(RID_BASICIDE_OBJCAT));
     aTitle->SetStyle(WB_CENTER);
 
     // tree list
@@ -47,7 +47,7 @@ ObjectCatalog::ObjectCatalog (vcl::Window* pParent) :
         WB_HASLINES | WB_HASLINESATROOT |
         WB_HASBUTTONS | WB_HASBUTTONSATROOT
     );
-    aTree->SetAccessibleName(IDEResId(RID_STR_TLB_MACROS).toString());
+    aTree->SetAccessibleName(IDEResId(RID_STR_TLB_MACROS));
     aTree->SetHelpId(HID_BASICIDE_OBJECTCAT);
     aTree->ScanAllEntries();
     aTree->GrabFocus();
@@ -112,15 +112,15 @@ void ObjectCatalog::ArrangeWindows()
         aTitle->Hide();
     else
     {
-        Size aTitleSize = LogicToPixel(Size(3, 10), MAP_APPFONT);
+        Size aTitleSize = LogicToPixel(Size(3, 10), MapMode(MapUnit::MapAppFont));
         aTitleSize.Width() = aSize.Width() - 2*aTitleSize.Width();
-        aTitle->SetPosPixel(LogicToPixel(Point(3, 3), MAP_APPFONT));
+        aTitle->SetPosPixel(LogicToPixel(Point(3, 3), MapMode(MapUnit::MapAppFont)));
         aTitle->SetSizePixel(aTitleSize);
         aTitle->Show();
     }
 
     // tree
-    Point const aTreePos = LogicToPixel(Point(3, bFloating ? 3 : 16), MAP_APPFONT);
+    Point const aTreePos = LogicToPixel(Point(3, bFloating ? 3 : 16), MapMode(MapUnit::MapAppFont));
     long const nMargin = aTreePos.X();
     Size const aTreeSize(
         aSize.Width() - 2*nMargin,
