@@ -23,7 +23,6 @@
 #include <basegfx/vector/b2dvector.hxx>
 #include <basegfx/matrix/b2dhommatrix.hxx>
 #include <basegfx/curve/b2dcubicbezier.hxx>
-#include <rtl/instance.hxx>
 #include <basegfx/polygon/b2dpolygontools.hxx>
 #include <algorithm>
 #include <memory>
@@ -62,11 +61,6 @@ public:
     {
     }
 
-    explicit CoordinateDataArray2D(const CoordinateDataArray2D& rOriginal)
-    :   maVector(rOriginal.maVector)
-    {
-    }
-
     CoordinateDataArray2D(const CoordinateDataArray2D& rOriginal, sal_uInt32 nIndex, sal_uInt32 nCount)
     :   maVector(rOriginal.maVector.begin() + nIndex, rOriginal.maVector.begin() + (nIndex + nCount))
     {
@@ -483,7 +477,7 @@ public:
     {
         if(!mpDefaultSubdivision)
         {
-            const_cast< ImplBufferedData* >(this)->mpDefaultSubdivision.reset(new basegfx::B2DPolygon(basegfx::tools::adaptiveSubdivideByAngle(rSource)));
+            const_cast< ImplBufferedData* >(this)->mpDefaultSubdivision.reset(new basegfx::B2DPolygon(basegfx::utils::adaptiveSubdivideByAngle(rSource)));
         }
 
         return *mpDefaultSubdivision;
@@ -637,7 +631,24 @@ public:
         }
     }
 
-    ImplB2DPolygon& operator=( const ImplB2DPolygon& ) = delete;
+    ImplB2DPolygon& operator=(const ImplB2DPolygon& rOther)
+    {
+        if (this != &rOther)
+        {
+            mpControlVector.reset();
+            mpBufferedData.reset();
+            maPoints = rOther.maPoints;
+            mbIsClosed = rOther.mbIsClosed;
+            if (rOther.mpControlVector && rOther.mpControlVector->isUsed())
+            {
+                mpControlVector.reset( new ControlVectorArray2D(*rOther.mpControlVector) );
+
+                if(!mpControlVector->isUsed())
+                    mpControlVector.reset();
+            }
+        }
+        return *this;
+    }
 
     sal_uInt32 count() const
     {
@@ -1096,17 +1107,12 @@ public:
 
 namespace basegfx
 {
-    namespace
-    {
-        struct DefaultPolygon: public rtl::Static<B2DPolygon::ImplType, DefaultPolygon> {};
-    }
-
     B2DPolygon::B2DPolygon()
-    :   mpPolygon(DefaultPolygon::get())
+        : mpPolygon()
     {}
 
     B2DPolygon::B2DPolygon(std::initializer_list<basegfx::B2DPoint> aPoints)
-        : mpPolygon(DefaultPolygon::get())
+        : mpPolygon()
     {
         for (const basegfx::B2DPoint& rPoint : aPoints)
         {
@@ -1437,7 +1443,7 @@ namespace basegfx
 
     void B2DPolygon::clear()
     {
-        mpPolygon = DefaultPolygon::get();
+        *mpPolygon = ImplB2DPolygon();
     }
 
     bool B2DPolygon::isClosed() const
