@@ -24,64 +24,82 @@ namespace basegfx
 {
     namespace internal
     {
-        void lcl_skipSpaces(sal_Int32&              io_rPos,
-                            const OUString&  rStr,
-                            const sal_Int32         nLen)
+        void skipSpaces(sal_Int32&      io_rPos,
+                        const OUString& rStr,
+                        const sal_Int32 nLen)
         {
             while( io_rPos < nLen &&
-                    ' ' == rStr[io_rPos] )
+                    rStr[io_rPos] == ' ' )
             {
                 ++io_rPos;
             }
         }
 
-        void lcl_skipSpacesAndCommas(sal_Int32&             io_rPos,
-                                        const OUString& rStr,
-                                        const sal_Int32         nLen)
+        void skipSpacesAndCommas(sal_Int32&      io_rPos,
+                                 const OUString& rStr,
+                                 const sal_Int32 nLen)
         {
             while(io_rPos < nLen
-                    && (' ' == rStr[io_rPos] || ',' == rStr[io_rPos]))
+                    && (rStr[io_rPos] == ' ' || rStr[io_rPos] == ','))
             {
                 ++io_rPos;
             }
         }
 
-        bool lcl_getDoubleChar(double&                  o_fRetval,
-                                sal_Int32&              io_rPos,
-                                const OUString&  rStr)
+        bool getDoubleChar(double&         o_fRetval,
+                           sal_Int32&      io_rPos,
+                           const OUString& rStr)
         {
-            sal_Unicode aChar( rStr[io_rPos] );
+            sal_Unicode aChar = io_rPos < rStr.getLength() ? rStr[io_rPos] : 0;
             OUStringBuffer sNumberString;
-            bool separator_seen=false;
 
-            if('+' == aChar || '-' == aChar)
+            // sign
+            if(aChar == '+' || aChar == '-')
             {
                 sNumberString.append(rStr[io_rPos]);
                 aChar = rStr[++io_rPos];
             }
 
-            while(('0' <= aChar && '9' >= aChar)
-                     || (!separator_seen && '.' == aChar))
+            // numbers before point
+            while('0' <= aChar && '9' >= aChar)
             {
-                if ('.' == aChar) separator_seen = true;
                 sNumberString.append(rStr[io_rPos]);
                 io_rPos++;
                 aChar = io_rPos < rStr.getLength() ? rStr[io_rPos] : 0;
             }
 
-            if('e' == aChar || 'E' == aChar)
+            // point
+            if(aChar == '.')
+            {
+                sNumberString.append(rStr[io_rPos]);
+                io_rPos++;
+                aChar = io_rPos < rStr.getLength() ? rStr[io_rPos] : 0;
+            }
+
+            // numbers after point
+            while ('0' <= aChar && '9' >= aChar)
+            {
+                sNumberString.append(rStr[io_rPos]);
+                io_rPos++;
+                aChar = io_rPos < rStr.getLength() ? rStr[io_rPos] : 0;
+            }
+
+            // 'e'
+            if(aChar == 'e' || aChar == 'E')
             {
                 sNumberString.append(rStr[io_rPos]);
                 io_rPos++;
                 aChar = io_rPos < rStr.getLength() ? rStr[io_rPos] : 0;
 
-                if('+' == aChar || '-' == aChar)
+                // sign for 'e'
+                if(aChar == '+' || aChar == '-')
                 {
                     sNumberString.append(rStr[io_rPos]);
                     io_rPos++;
                     aChar = io_rPos < rStr.getLength() ? rStr[io_rPos] : 0;
                 }
 
+                // number for 'e'
                 while('0' <= aChar && '9' >= aChar)
                 {
                     sNumberString.append(rStr[io_rPos]);
@@ -96,40 +114,39 @@ namespace basegfx
                 o_fRetval = ::rtl::math::stringToDouble( sNumberString.makeStringAndClear(),
                                                             '.',
                                                             ',',
-                                                            &eStatus,
-                                                            NULL );
+                                                            &eStatus );
                 return ( eStatus == rtl_math_ConversionStatus_Ok );
             }
 
             return false;
         }
 
-        bool lcl_importDoubleAndSpaces( double&                 o_fRetval,
-                                        sal_Int32&              io_rPos,
-                                        const OUString&  rStr,
-                                        const sal_Int32         nLen )
+        bool importDoubleAndSpaces(double&         o_fRetval,
+                                   sal_Int32&      io_rPos,
+                                   const OUString& rStr,
+                                   const sal_Int32 nLen )
         {
-            if( !lcl_getDoubleChar(o_fRetval, io_rPos, rStr) )
+            if( !getDoubleChar(o_fRetval, io_rPos, rStr) )
                 return false;
 
-            lcl_skipSpacesAndCommas(io_rPos, rStr, nLen);
+            skipSpacesAndCommas(io_rPos, rStr, nLen);
 
             return true;
         }
 
-        bool lcl_importFlagAndSpaces(sal_Int32&         o_nRetval,
-                                     sal_Int32&         io_rPos,
-                                     const OUString&    rStr,
-                                     const sal_Int32    nLen)
+        bool importFlagAndSpaces(sal_Int32&      o_nRetval,
+                                 sal_Int32&      io_rPos,
+                                 const OUString& rStr,
+                                 const sal_Int32 nLen)
         {
             sal_Unicode aChar( rStr[io_rPos] );
 
-            if('0' == aChar)
+            if(aChar == '0')
             {
                 o_nRetval = 0;
                 ++io_rPos;
             }
-            else if ('1' == aChar)
+            else if (aChar == '1')
             {
                 o_nRetval = 1;
                 ++io_rPos;
@@ -137,15 +154,15 @@ namespace basegfx
             else
                 return false;
 
-            lcl_skipSpacesAndCommas(io_rPos, rStr, nLen);
+            skipSpacesAndCommas(io_rPos, rStr, nLen);
 
             return true;
         }
 
-        void lcl_putNumberCharWithSpace( OUStringBuffer& rStr,
-                                            double              fValue,
-                                            double              fOldValue,
-                                            bool                    bUseRelativeCoordinates )
+        void putNumberCharWithSpace(OUStringBuffer& rStr,
+                                    double          fValue,
+                                    double          fOldValue,
+                                    bool            bUseRelativeCoordinates )
         {
             if( bUseRelativeCoordinates )
                 fValue -= fOldValue;
@@ -153,16 +170,15 @@ namespace basegfx
             const sal_Int32 aLen( rStr.getLength() );
             if(aLen)
             {
-                if( lcl_isOnNumberChar(rStr[aLen - 1], false) &&
+                if( isOnNumberChar(rStr[aLen - 1], false) &&
                     fValue >= 0.0 )
                 {
                     rStr.append( ' ' );
                 }
             }
 
-            lcl_putNumberChar(rStr, fValue);
+            rStr.append(fValue);
         }
-
     } // namespace internal
 }
 
