@@ -17,10 +17,14 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "basiccharclass.hxx"
-#include "scanner.hxx"
-#include "sbintern.hxx"
+#include <basiccharclass.hxx>
+#include <scanner.hxx>
+#include <sbintern.hxx>
+#include <runtime.hxx>
 
+#include <i18nlangtag/lang.h>
+#include <comphelper/processfactory.hxx>
+#include <svl/zforlist.hxx>
 #include <vcl/svapp.hxx>
 
 SbiScanner::SbiScanner( const OUString& rBuf, StarBASIC* p ) : aBuf( rBuf )
@@ -31,7 +35,6 @@ SbiScanner::SbiScanner( const OUString& rBuf, StarBASIC* p ) : aBuf( rBuf )
     eScanType = SbxVARIANT;
     nErrors  = 0;
     nBufPos  = 0;
-    nCurCol1 = 0;
     nSavedCol1 = 0;
     nColLock = 0;
     nLine    = 0;
@@ -66,7 +69,7 @@ void SbiScanner::UnlockColumn()
         nColLock--;
 }
 
-void SbiScanner::GenError( SbError code )
+void SbiScanner::GenError( ErrCode code )
 {
     if( GetSbData()->bBlockCompilerError )
     {
@@ -83,15 +86,14 @@ void SbiScanner::GenError( SbError code )
             // in case of EXPECTED or UNEXPECTED it always refers
             // to the last token, so take the Col1 over
             sal_Int32 nc = nColLock ? nSavedCol1 : nCol1;
-            switch( code )
+            if ( code.anyOf(
+                    ERRCODE_BASIC_EXPECTED,
+                    ERRCODE_BASIC_UNEXPECTED,
+                    ERRCODE_BASIC_SYMBOL_EXPECTED,
+                    ERRCODE_BASIC_LABEL_EXPECTED) )
             {
-                case ERRCODE_BASIC_EXPECTED:
-                case ERRCODE_BASIC_UNEXPECTED:
-                case ERRCODE_BASIC_SYMBOL_EXPECTED:
-                case ERRCODE_BASIC_LABEL_EXPECTED:
                     nc = nCol1;
                     if( nc > nCol2 ) nCol2 = nc;
-                    break;
             }
             bRes = pBasic->CError( code, aError, nLine, nc, nCol2 );
         }
@@ -119,19 +121,19 @@ static SbxDataType GetSuffixType( sal_Unicode c )
     switch (c)
     {
     case '%':
-        return SbxDataType(SbxINTEGER);
+        return SbxINTEGER;
     case '&':
-        return SbxDataType(SbxLONG);
+        return SbxLONG;
     case '!':
-        return SbxDataType(SbxSINGLE);
+        return SbxSINGLE;
     case '#':
-        return SbxDataType(SbxDOUBLE);
+        return SbxDOUBLE;
     case '@':
-        return SbxDataType(SbxCURRENCY);
+        return SbxCURRENCY;
     case '$':
-        return SbxDataType(SbxSTRING);
+        return SbxSTRING;
     default:
-        return SbxDataType(SbxVARIANT);
+        return SbxVARIANT;
     }
 }
 
@@ -213,6 +215,7 @@ bool SbiScanner::NextSym()
     eScanType = SbxVARIANT;
     aSym.clear();
     bHash = bSymbol = bNumber = bSpaces = false;
+    bool bCompilerDirective = false;
 
     // read in line?
     if( !pLine )
@@ -245,9 +248,22 @@ bool SbiScanner::NextSym()
 
     if(nCol < aLine.getLength() && aLine[nCol] == '#')
     {
-        ++pLine;
-        ++nCol;
-        bHash = true;
+        const sal_Unicode* pLineTemp = pLine;
+        do
+        {
+            pLineTemp++;
+        } while (*pLineTemp && !BasicCharClass::isWhitespace(*pLineTemp) && *pLineTemp != '#');
+        // leave it if it is a date literal - it will be handled later
+        if (*pLineTemp != '#')
+        {
+            ++pLine;
+            ++nCol;
+            //ignore compiler directives (# is first non-space character)
+            if (nOldCol2 == 0)
+                bCompilerDirective = true;
+            else
+                bHash = true;
+        }
     }
 
     // copy character if symbol
@@ -360,7 +376,7 @@ bool SbiScanner::NextSym()
         aSym = p; bNumber = true;
 
         // For bad characters, scan and parse errors generate only one error.
-        SbError nError = 0;
+        ErrCode nError = ERRCODE_NONE;
         if (bScanError)
         {
             --pLine;
@@ -422,7 +438,7 @@ bool SbiScanner::NextSym()
     }
 
     // Hex/octal number? Read in and convert:
-    else if(nCol < aLine.getLength() && aLine[nCol] == '&')
+    else if(aLine.getLength() - nCol > 1 && aLine[nCol] == '&')
     {
         ++pLine; ++nCol;
         sal_Unicode base = 16;
@@ -517,7 +533,7 @@ bool SbiScanner::NextSym()
                     }
                     aSym = aSymBuf.makeStringAndClear();
                     if( cSep != ']' )
-                        eScanType = ( cSep == '#' ) ? SbxDATE : SbxSTRING;
+                        eScanType = SbxSTRING;
                     break;
                 }
             }
@@ -528,6 +544,54 @@ bool SbiScanner::NextSym()
             }
         }
     }
+
+    // Date:
+    else if( *pLine == '#' )
+    {
+        sal_Int32 n = nCol + 1;
+        do
+        {
+            pLine++;
+            nCol++;
+        }
+        while( *pLine && ( *pLine != '#' ) );
+        if( *pLine == '#' )
+        {
+            pLine++; nCol++;
+            aSym = aLine.copy( n, nCol - n - 1 );
+
+            // parse date literal
+            std::shared_ptr<SvNumberFormatter> pFormatter;
+            if (GetSbData()->pInst)
+            {
+                pFormatter = GetSbData()->pInst->GetNumberFormatter();
+            }
+            else
+            {
+                sal_uInt32 nDummy;
+                pFormatter = SbiInstance::PrepareNumberFormatter( nDummy, nDummy, nDummy );
+            }
+            sal_uInt32 nIndex = pFormatter->GetStandardIndex( LANGUAGE_ENGLISH_US);
+            bool bSuccess = pFormatter->IsNumberFormat(aSym, nIndex, nVal);
+            if( bSuccess )
+            {
+                short nType_ = pFormatter->GetType(nIndex);
+                if( !(nType_ & css::util::NumberFormat::DATE) )
+                    bSuccess = false;
+            }
+
+            if (!bSuccess)
+                GenError( ERRCODE_BASIC_CONVERSION );
+
+            bNumber = true;
+            eScanType = SbxDOUBLE;
+        }
+        else
+        {
+            aError = OUString('#');
+            GenError( ERRCODE_BASIC_EXPECTED );
+        }
+    }
     // invalid characters:
     else if( *pLine >= 0x7F )
     {
@@ -552,7 +616,9 @@ bool SbiScanner::NextSym()
 PrevLineCommentLbl:
 
     if( bPrevLineExtentsComment || (eScanType != SbxSTRING &&
-                                    ( aSym.startsWith("'") || aSym.equalsIgnoreAsciiCase( "REM" ) ) ) )
+                                    ( bCompilerDirective ||
+                                      aSym.startsWith("'") ||
+                                      aSym.equalsIgnoreAsciiCase( "REM" ) ) ) )
     {
         bPrevLineExtentsComment = false;
         aSym = "REM";
@@ -570,12 +636,11 @@ eoln:
     {
         pLine = nullptr;
         bool bRes = NextSym();
-        if( bVBASupportOn && aSym[0] == '.' )
+        if( aSym.startsWith(".") )
         {
             // object _
             //    .Method
             // ^^^  <- spaces is legal in MSO VBA
-            OSL_TRACE("*** resetting bSpaces***");
             bSpaces = false;
         }
         return bRes;
