@@ -17,22 +17,26 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "sal/config.h"
+#include <sal/config.h>
 
 #include <algorithm>
 #include <cassert>
+#include <exception>
 
-#include "com/sun/star/connection/XConnection.hpp"
-#include "com/sun/star/uno/Exception.hpp"
-#include "com/sun/star/uno/Reference.hxx"
-#include "com/sun/star/uno/RuntimeException.hpp"
-#include "com/sun/star/uno/XComponentContext.hpp"
-#include "com/sun/star/uno/XInterface.hpp"
-#include "cppuhelper/factory.hxx"
-#include "cppuhelper/implementationentry.hxx"
+#include <com/sun/star/bridge/BridgeExistsException.hpp>
+#include <com/sun/star/connection/XConnection.hpp>
+#include <com/sun/star/lang/IllegalArgumentException.hpp>
+#include <com/sun/star/uno/Exception.hpp>
+#include <com/sun/star/uno/Reference.hxx>
+#include <com/sun/star/uno/RuntimeException.hpp>
+#include <com/sun/star/uno/XComponentContext.hpp>
+#include <com/sun/star/uno/XInterface.hpp>
+#include <cppuhelper/factory.hxx>
+#include <cppuhelper/implementationentry.hxx>
 #include <cppuhelper/supportsservice.hxx>
-#include "rtl/ref.hxx"
-#include "sal/types.h"
+#include <rtl/ref.hxx>
+#include <sal/log.hxx>
+#include <sal/types.h>
 
 #include "bridge.hxx"
 #include "bridgefactory.hxx"
@@ -40,10 +44,9 @@
 namespace binaryurp {
 
 css::uno::Reference< css::uno::XInterface > BridgeFactory::static_create(
-    css::uno::Reference< css::uno::XComponentContext > const & xContext)
-    SAL_THROW((css::uno::Exception))
+    css::uno::Reference< css::uno::XComponentContext > const & /*xContext*/)
 {
-    return static_cast< cppu::OWeakObject * >(new BridgeFactory(xContext));
+    return static_cast< cppu::OWeakObject * >(new BridgeFactory);
 }
 
 OUString BridgeFactory::static_getImplementationName() {
@@ -52,8 +55,7 @@ OUString BridgeFactory::static_getImplementationName() {
 
 css::uno::Sequence< OUString >
 BridgeFactory::static_getSupportedServiceNames() {
-    OUString name("com.sun.star.bridge.BridgeFactory");
-    return css::uno::Sequence< OUString >(&name, 1);
+    return css::uno::Sequence<OUString>{ "com.sun.star.bridge.BridgeFactory" };
 }
 
 void BridgeFactory::removeBridge(
@@ -61,44 +63,37 @@ void BridgeFactory::removeBridge(
 {
     assert(bridge.is());
     OUString n(bridge->getName());
-    osl::MutexGuard g(*this);
-    if (n.isEmpty()) {
-        BridgeList::iterator i(
-            std::find(unnamed_.begin(), unnamed_.end(), bridge));
-        if (i != unnamed_.end()) {
-            unnamed_.erase(i);
-        }
-    } else {
+    osl::MutexGuard g(m_aMutex);
+    if (n.isEmpty())
+    {
+        unnamed_.erase(std::remove(unnamed_.begin(), unnamed_.end(), bridge), unnamed_.end());
+    }
+    else
+    {
         BridgeMap::iterator i(named_.find(n));
-        if (i != named_.end() && i->second == bridge) {
+        if (i != named_.end() && i->second == bridge)
             named_.erase(i);
-        }
     }
 }
 
-BridgeFactory::BridgeFactory(
-    css::uno::Reference< css::uno::XComponentContext > const & context):
-    BridgeFactoryBase(*static_cast< osl::Mutex * >(this)), context_(context)
+BridgeFactory::BridgeFactory():
+    BridgeFactoryBase(m_aMutex)
 {
-    assert(context.is());
 }
 
 BridgeFactory::~BridgeFactory() {}
 
 OUString BridgeFactory::getImplementationName()
-    throw (css::uno::RuntimeException)
 {
     return static_getImplementationName();
 }
 
 sal_Bool BridgeFactory::supportsService(OUString const & ServiceName)
-    throw (css::uno::RuntimeException)
 {
     return cppu::supportsService(this, ServiceName);
 }
 
 css::uno::Sequence< OUString > BridgeFactory::getSupportedServiceNames()
-    throw (css::uno::RuntimeException)
 {
     return static_getSupportedServiceNames();
 }
@@ -108,13 +103,15 @@ css::uno::Reference< css::bridge::XBridge > BridgeFactory::createBridge(
     css::uno::Reference< css::connection::XConnection > const & aConnection,
     css::uno::Reference< css::bridge::XInstanceProvider > const &
         anInstanceProvider)
-    throw (
-        css::bridge::BridgeExistsException, css::lang::IllegalArgumentException,
-        css::uno::RuntimeException)
 {
     rtl::Reference< Bridge > b;
     {
-        osl::MutexGuard g(*this);
+        osl::MutexGuard g(m_aMutex);
+        if (rBHelper.bDisposed) {
+            throw css::lang::DisposedException(
+                "BridgeFactory disposed",
+                static_cast< cppu::OWeakObject * >(this));
+        }
         if (named_.find(sName) != named_.end()) {
             throw css::bridge::BridgeExistsException(
                 sName, static_cast< cppu::OWeakObject * >(this));
@@ -127,8 +124,7 @@ css::uno::Reference< css::bridge::XBridge > BridgeFactory::createBridge(
         }
         b.set(new Bridge(this, sName, aConnection, anInstanceProvider));
         if (sName.isEmpty()) {
-            unnamed_.push_back(
-                css::uno::Reference< css::bridge::XBridge >(b.get()));
+            unnamed_.emplace_back(b.get());
         } else {
             named_[sName] = b.get();
         }
@@ -138,17 +134,17 @@ css::uno::Reference< css::bridge::XBridge > BridgeFactory::createBridge(
 }
 
 css::uno::Reference< css::bridge::XBridge > BridgeFactory::getBridge(
-    OUString const & sName) throw (css::uno::RuntimeException)
+    OUString const & sName)
 {
-    osl::MutexGuard g(*this);
+    osl::MutexGuard g(m_aMutex);
     BridgeMap::iterator i(named_.find(sName));
     return i == named_.end()
         ? css::uno::Reference< css::bridge::XBridge >() : i->second;
 }
 
 css::uno::Sequence< css::uno::Reference< css::bridge::XBridge > >
-BridgeFactory::getExistingBridges() throw (css::uno::RuntimeException) {
-    osl::MutexGuard g(*this);
+BridgeFactory::getExistingBridges() {
+    osl::MutexGuard g(m_aMutex);
     if (unnamed_.size() > SAL_MAX_INT32) {
         throw css::uno::RuntimeException(
             "BridgeFactory::getExistingBridges: too many",
@@ -163,15 +159,43 @@ BridgeFactory::getExistingBridges() throw (css::uno::RuntimeException) {
     n = static_cast< sal_Int32 >(n + named_.size());
     css::uno::Sequence< css::uno::Reference< css::bridge::XBridge > > s(n);
     sal_Int32 i = 0;
-    for (BridgeList::iterator j(unnamed_.begin()); j != unnamed_.end(); ++j) {
-        s[i++] = *j;
-    }
-    for (BridgeMap::iterator j(named_.begin()); j != named_.end(); ++j) {
-        s[i++] = j->second;
-    }
+    for (auto const& item : unnamed_)
+        s[i++] = item;
+
+    for (auto const& item : named_)
+        s[i++] = item.second;
+
     return s;
 }
 
+void BridgeFactory::disposing() {
+    BridgeVector l1;
+    BridgeMap l2;
+    {
+        osl::MutexGuard g(m_aMutex);
+        l1.swap(unnamed_);
+        l2.swap(named_);
+    }
+    for (auto const& item : l1)
+    {
+        try {
+            css::uno::Reference<css::lang::XComponent>(
+                item, css::uno::UNO_QUERY_THROW)->dispose();
+        } catch (css::uno::Exception & e) {
+            SAL_WARN("binaryurp", "ignoring " << e);
+        }
+    }
+    for (auto const& item : l2)
+    {
+        try {
+            css::uno::Reference<css::lang::XComponent>(
+                item.second, css::uno::UNO_QUERY_THROW)->dispose();
+        } catch (css::uno::Exception & e) {
+            SAL_WARN("binaryurp", "ignoring " << e);
+        }
+    }
+}
+
 }
 
 namespace {
@@ -180,8 +204,8 @@ static cppu::ImplementationEntry const services[] = {
     { &binaryurp::BridgeFactory::static_create,
       &binaryurp::BridgeFactory::static_getImplementationName,
       &binaryurp::BridgeFactory::static_getSupportedServiceNames,
-      &cppu::createOneInstanceComponentFactory, 0, 0 },
-    { 0, 0, 0, 0, 0, 0 }
+      &cppu::createOneInstanceComponentFactory, nullptr, 0 },
+    { nullptr, nullptr, nullptr, nullptr, nullptr, 0 }
 };
 
 }
