@@ -24,10 +24,10 @@
 #include "com/sun/star/uno/RuntimeException.hpp"
 #include <uno/data.h>
 
-#include <bridges/cpp_uno/shared/bridge.hxx>
-#include <bridges/cpp_uno/shared/types.hxx>
-#include <bridges/cpp_uno/shared/unointerfaceproxy.hxx>
-#include <bridges/cpp_uno/shared/vtables.hxx>
+#include <bridge.hxx>
+#include <types.hxx>
+#include <unointerfaceproxy.hxx>
+#include <vtables.hxx>
 
 #include "share.hxx"
 
@@ -497,10 +497,10 @@ void unoInterfaceProxyDispatch(
         default:
         {
             ::com::sun::star::uno::RuntimeException aExc(
-                OUString("illegal member type description!"),
+                "illegal member type description!",
                 ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface >() );
 
-            Type const & rExcType = ::getCppuType( &aExc );
+            Type const & rExcType = cppu::UnoType<decltype(aExc)>::get();
             // binary identical null reference
             ::uno_type_any_construct( *ppException, &aExc, rExcType.getTypeLibType(), 0 );
         }
