@@ -23,25 +23,23 @@
 
 #include <rtl/alloc.h>
 #include <sal/log.hxx>
-#include <osl/mutex.hxx>
 
 #include <com/sun/star/uno/genfunc.hxx>
-#include "com/sun/star/uno/RuntimeException.hpp"
+#include <com/sun/star/uno/RuntimeException.hpp>
 #include <config_options.h>
 #include <uno/data.h>
 #include <typelib/typedescription.hxx>
 
-#include "bridges/cpp_uno/shared/bridge.hxx"
-#include "bridges/cpp_uno/shared/cppinterfaceproxy.hxx"
-#include "bridges/cpp_uno/shared/types.hxx"
-#include "bridges/cpp_uno/shared/vtablefactory.hxx"
+#include <bridge.hxx>
+#include <cppinterfaceproxy.hxx>
+#include <types.hxx>
+#include <vtablefactory.hxx>
 
 #include "abi.hxx"
 #include "call.hxx"
 #include "rtti.hxx"
 #include "share.hxx"
 
-using namespace ::osl;
 using namespace ::com::sun::star::uno;
 
 // Perform the UNO call
@@ -68,12 +66,12 @@ static typelib_TypeClass cpp2uno_call(
     unsigned int nr_fpr = 0; //number of fpr registers used
 
     // return
-    typelib_TypeDescription * pReturnTypeDescr = 0;
+    typelib_TypeDescription * pReturnTypeDescr = nullptr;
     if (pReturnTypeRef)
         TYPELIB_DANGER_GET( &pReturnTypeDescr, pReturnTypeRef );
 
-    void * pUnoReturn = 0;
-    void * pCppReturn = 0; // complex return ptr: if != 0 && != pUnoReturn, reconversion need
+    void * pUnoReturn = nullptr;
+    void * pCppReturn = nullptr; // complex return ptr: if != 0 && != pUnoReturn, reconversion need
 
     if ( pReturnTypeDescr )
     {
@@ -140,7 +138,7 @@ static typelib_TypeClass cpp2uno_call(
         }
         else // struct <= 16 bytes || ptr to complex value || ref
         {
-            typelib_TypeDescription * pParamTypeDescr = 0;
+            typelib_TypeDescription * pParamTypeDescr = nullptr;
             TYPELIB_DANGER_GET( &pParamTypeDescr, rParam.pTypeRef );
 
             void *pCppStack;
@@ -194,7 +192,7 @@ static typelib_TypeClass cpp2uno_call(
             sal_Int32 nIndex = pTempIndices[nTempIndices];
 
             if (pParams[nIndex].bIn) // is in/inout => was constructed
-                uno_destructData( pUnoArgs[nIndex], ppTempParamTypeDescr[nTempIndices], 0 );
+                uno_destructData( pUnoArgs[nIndex], ppTempParamTypeDescr[nTempIndices], nullptr );
             TYPELIB_DANGER_RELEASE( ppTempParamTypeDescr[nTempIndices] );
         }
         if (pReturnTypeDescr)
@@ -220,7 +218,7 @@ static typelib_TypeClass cpp2uno_call(
                                         pThis->getBridge()->getUno2Cpp() );
             }
             // destroy temp uno param
-            uno_destructData( pUnoArgs[nIndex], pParamTypeDescr, 0 );
+            uno_destructData( pUnoArgs[nIndex], pParamTypeDescr, nullptr );
 
             TYPELIB_DANGER_RELEASE( pParamTypeDescr );
         }
@@ -232,14 +230,14 @@ static typelib_TypeClass cpp2uno_call(
                 uno_copyAndConvertData( pCppReturn, pUnoReturn, pReturnTypeDescr,
                                         pThis->getBridge()->getUno2Cpp() );
                 // destroy temp uno return
-                uno_destructData( pUnoReturn, pReturnTypeDescr, 0 );
+                uno_destructData( pUnoReturn, pReturnTypeDescr, nullptr );
             }
             // complex return ptr is set to return reg
             *reinterpret_cast<void **>(pRegisterReturn) = pCppReturn;
         }
         if ( pReturnTypeDescr )
         {
-            typelib_TypeClass eRet = (typelib_TypeClass)pReturnTypeDescr->eTypeClass;
+            typelib_TypeClass eRet = pReturnTypeDescr->eTypeClass;
             TYPELIB_DANGER_RELEASE( pReturnTypeDescr );
             return eRet;
         }
@@ -306,7 +304,7 @@ typelib_TypeClass cpp_vtable_call(
             {
                 // is GET method
                 eRet = cpp2uno_call( pCppI, aMemberDescr.get(), pAttrTypeRef,
-                        0, 0, // no params
+                        0, nullptr, // no params
                         gpreg, fpreg, ovrflw, pRegisterReturn );
             }
             else
@@ -314,11 +312,11 @@ typelib_TypeClass cpp_vtable_call(
                 // is SET method
                 typelib_MethodParameter aParam;
                 aParam.pTypeRef = pAttrTypeRef;
-                aParam.bIn      = sal_True;
-                aParam.bOut     = sal_False;
+                aParam.bIn      = true;
+                aParam.bOut     = false;
 
                 eRet = cpp2uno_call( pCppI, aMemberDescr.get(),
-                        0, // indicates void return
+                        nullptr, // indicates void return
                         1, &aParam,
                         gpreg, fpreg, ovrflw, pRegisterReturn );
             }
@@ -339,11 +337,11 @@ typelib_TypeClass cpp_vtable_call(
                     break;
                 case 0: // queryInterface() opt
                 {
-                    typelib_TypeDescription * pTD = 0;
+                    typelib_TypeDescription * pTD = nullptr;
                     TYPELIB_DANGER_GET( &pTD, static_cast<Type *>( gpreg[2] )->getTypeLibType() );
                     if ( pTD )
                     {
-                        XInterface * pInterface = 0;
+                        XInterface * pInterface = nullptr;
                         (*pCppI->getBridge()->getCppEnv()->getRegisteredInterface)
                             ( pCppI->getBridge()->getCppEnv(),
                               reinterpret_cast<void **>(&pInterface),
@@ -364,7 +362,8 @@ typelib_TypeClass cpp_vtable_call(
                         }
                         TYPELIB_DANGER_RELEASE( pTD );
                     }
-                } // else perform queryInterface()
+                    SAL_FALLTHROUGH; // else perform queryInterface()
+                }
                 default:
                 {
                     typelib_InterfaceMethodTypeDescription *pMethodTD =
@@ -443,7 +442,7 @@ bridges::cpp_uno::shared::VtableFactory::mapBlockToVtable(void * block)
     return static_cast< Slot * >(block) + 2;
 }
 
-sal_Size bridges::cpp_uno::shared::VtableFactory::getBlockSize(
+std::size_t bridges::cpp_uno::shared::VtableFactory::getBlockSize(
     sal_Int32 slotCount)
 {
     return (slotCount + 2) * sizeof (Slot) + slotCount * codeSnippetSize;
@@ -457,7 +456,7 @@ bridges::cpp_uno::shared::VtableFactory::initializeBlock(
     Slot * slots = mapBlockToVtable(block);
     slots[-2].fn = reinterpret_cast<void *>(-(vtableNumber * sizeof (void *)));
 #if ENABLE_RUNTIME_OPTIMIZATIONS
-    slots[-1].fn = 0;
+    slots[-1].fn = nullptr;
     (void)type;
 #else
     slots[-1].fn = x86_64::getRtti(type->aBase);
@@ -466,7 +465,6 @@ bridges::cpp_uno::shared::VtableFactory::initializeBlock(
 }
 
 
-
 unsigned char * bridges::cpp_uno::shared::VtableFactory::addLocalFunctions(
     Slot ** slots, unsigned char * code, sal_PtrDiff writetoexecdiff,
     typelib_InterfaceTypeDescription const * type, sal_Int32 nFunctionOffset,
@@ -476,12 +474,12 @@ unsigned char * bridges::cpp_uno::shared::VtableFactory::addLocalFunctions(
     Slot * s = *slots;
     for ( sal_Int32 nPos = 0; nPos < type->nMembers; ++nPos )
     {
-        typelib_TypeDescription * pTD = 0;
+        typelib_TypeDescription * pTD = nullptr;
 
         TYPELIB_DANGER_GET( &pTD, type->ppMembers[ nPos ] );
         assert(pTD);
 
-        if ( typelib_TypeClass_INTERFACE_ATTRIBUTE == pTD->eTypeClass )
+        if ( pTD->eTypeClass == typelib_TypeClass_INTERFACE_ATTRIBUTE )
         {
             typelib_InterfaceAttributeTypeDescription *pAttrTD =
                 reinterpret_cast<typelib_InterfaceAttributeTypeDescription *>( pTD );
@@ -498,7 +496,7 @@ unsigned char * bridges::cpp_uno::shared::VtableFactory::addLocalFunctions(
                 code = codeSnippet( code, nFunctionOffset++, nVtableOffset, false );
             }
         }
-        else if ( typelib_TypeClass_INTERFACE_METHOD == pTD->eTypeClass )
+        else if ( pTD->eTypeClass == typelib_TypeClass_INTERFACE_METHOD )
         {
             typelib_InterfaceMethodTypeDescription *pMethodTD =
                 reinterpret_cast<typelib_InterfaceMethodTypeDescription *>( pTD );
