@@ -17,23 +17,20 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-
-#include <canvas/debug.hxx>
-#include <tools/diagnose_ex.h>
-#include <canvas/verbosetrace.hxx>
-#include <canvas/canvastools.hxx>
-
-#include <rtl/math.hxx>
+#include <sal/config.h>
 
 #include <basegfx/matrix/b2dhommatrix.hxx>
+#include <basegfx/numeric/ftools.hxx>
 #include <basegfx/point/b2dpoint.hxx>
-#include <basegfx/tools/canvastools.hxx>
 #include <basegfx/polygon/b2dpolygon.hxx>
 #include <basegfx/polygon/b2dpolygontools.hxx>
 #include <basegfx/polygon/b2dpolypolygontools.hxx>
-#include <basegfx/numeric/ftools.hxx>
+#include <basegfx/utils/canvastools.hxx>
+#include <rtl/math.hxx>
+#include <tools/diagnose_ex.h>
 
 #include <canvas/base/canvascustomspritehelper.hxx>
+#include <canvas/canvastools.hxx>
 
 using namespace ::com::sun::star;
 
@@ -62,7 +59,7 @@ namespace canvas
             // clip which is about to be set, expressed as a
             // b2drectangle
             const ::basegfx::B2DRectangle& rClipBounds(
-                ::basegfx::tools::getRange( aClipPath ) );
+                ::basegfx::utils::getRange( aClipPath ) );
 
             const ::basegfx::B2DRectangle aBounds( 0.0, 0.0,
                                                    maSize.getX(),
@@ -92,7 +89,7 @@ namespace canvas
                 // new clip could be a single rectangle - check
                 // that now:
                 const bool bNewClipIsRect(
-                    ::basegfx::tools::isRectangle( aClipPath.getB2DPolygon(0) ) );
+                    ::basegfx::utils::isRectangle( aClipPath.getB2DPolygon(0) ) );
 
                 // both new and old clip are truly rectangles
                 // - can now take the optimized path
@@ -110,7 +107,7 @@ namespace canvas
                 {
                     // aClipBoundsB = maCurrClipBounds, i.e. last
                     // clip, intersected with sprite area
-                    typedef ::std::vector< ::basegfx::B2DRectangle > VectorOfRects;
+                    typedef std::vector< ::basegfx::B2DRectangle > VectorOfRects;
                     VectorOfRects aClipDifferences;
 
                     // get all rectangles covered by exactly one
@@ -126,17 +123,14 @@ namespace canvas
                     // translate this area to the final position,
                     // coordinates need to be relative to the
                     // spritecanvas.
-                    VectorOfRects::const_iterator       aCurr( aClipDifferences.begin() );
-                    const VectorOfRects::const_iterator aEnd( aClipDifferences.end() );
-                    while( aCurr != aEnd )
+                    for( const auto& rClipDiff : aClipDifferences )
                     {
                         mpSpriteCanvas->updateSprite(
                             rSprite,
                             maPosition,
                             ::basegfx::B2DRectangle(
-                                maPosition + aCurr->getMinimum(),
-                                maPosition + aCurr->getMaximum() ) );
-                        ++aCurr;
+                                maPosition + rClipDiff.getMinimum(),
+                                maPosition + rClipDiff.getMaximum() ) );
                     }
 
                     // update calls all done
@@ -177,11 +171,11 @@ namespace canvas
                           "CanvasCustomSpriteHelper::init(): Invalid owning sprite canvas" );
 
         mpSpriteCanvas = rOwningSpriteCanvas;
-        maSize.setX( ::std::max( 1.0,
+        maSize.setX( std::max( 1.0,
                                  ceil( rSpriteSize.Width ) ) ); // round up to nearest int,
                                                                  // enforce sprite to have at
                                                                  // least (1,1) pixel size
-        maSize.setY( ::std::max( 1.0,
+        maSize.setY( std::max( 1.0,
                                  ceil( rSpriteSize.Height ) ) );
     }
 
@@ -270,7 +264,10 @@ namespace canvas
 
         if( aPoint != maPosition )
         {
-            const ::basegfx::B2DRectangle&  rBounds( getFullSpriteRect() );
+            const ::basegfx::B2DRectangle&  rBounds
+                = getUpdateArea( ::basegfx::B2DRectangle( 0.0, 0.0,
+                                                          maSize.getX(),
+                                                          maSize.getY() ) );
 
             if( mbActive )
             {
@@ -407,7 +404,6 @@ namespace canvas
         }
     }
 
-    // Sprite interface
     bool CanvasCustomSpriteHelper::isAreaUpdateOpaque( const ::basegfx::B2DRange& rUpdateArea ) const
     {
         if( !mbIsCurrClipRectangle ||
@@ -430,16 +426,6 @@ namespace canvas
         }
     }
 
-    ::basegfx::B2DPoint CanvasCustomSpriteHelper::getPosPixel() const
-    {
-        return maPosition;
-    }
-
-    ::basegfx::B2DVector CanvasCustomSpriteHelper::getSizePixel() const
-    {
-        return maSize;
-    }
-
     ::basegfx::B2DRange CanvasCustomSpriteHelper::getUpdateArea( const ::basegfx::B2DRange& rBounds ) const
     {
         // Internal! Only call with locked object mutex!
@@ -470,19 +456,6 @@ namespace canvas
                 maPosition + maCurrClipBounds.getMinimum(),
                 maPosition + maCurrClipBounds.getMaximum() );
     }
-
-    double CanvasCustomSpriteHelper::getPriority() const
-    {
-        return mfPriority;
-    }
-
-    ::basegfx::B2DRange CanvasCustomSpriteHelper::getFullSpriteRect() const
-    {
-        // Internal! Only call with locked object mutex!
-        return getUpdateArea( ::basegfx::B2DRectangle( 0.0, 0.0,
-                                                       maSize.getX(),
-                                                       maSize.getY() ) );
-    }
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
