@@ -19,7 +19,7 @@
 
 #include <sal/config.h>
 
-#include <boost/tuple/tuple.hpp>
+#include <tuple>
 
 #include <basegfx/matrix/b2dhommatrix.hxx>
 #include <basegfx/numeric/ftools.hxx>
@@ -29,10 +29,10 @@
 #include <basegfx/polygon/b2dpolygontools.hxx>
 #include <basegfx/polygon/b2dpolypolygontools.hxx>
 #include <basegfx/range/b2drectangle.hxx>
-#include <basegfx/tools/canvastools.hxx>
-#include <basegfx/tools/keystoplerp.hxx>
-#include <basegfx/tools/lerp.hxx>
-#include <basegfx/tools/tools.hxx>
+#include <basegfx/utils/canvastools.hxx>
+#include <basegfx/utils/keystoplerp.hxx>
+#include <basegfx/utils/lerp.hxx>
+#include <basegfx/utils/tools.hxx>
 #include <basegfx/vector/b2dsize.hxx>
 #include <com/sun/star/rendering/PathCapType.hpp>
 #include <com/sun/star/rendering/PathJoinType.hpp>
@@ -43,7 +43,7 @@
 #include <tools/diagnose_ex.h>
 #include <tools/poly.hxx>
 #include <vcl/bitmapex.hxx>
-#include <vcl/bmpacc.hxx>
+#include <vcl/bitmapaccess.hxx>
 #include <vcl/canvastools.hxx>
 #include <vcl/virdev.hxx>
 #include <vcl/window.hxx>
@@ -106,7 +106,7 @@ namespace vclcanvas
          */
         void fillLinearGradient( OutputDevice&                                  rOutDev,
                                  const ::basegfx::B2DHomMatrix&                 rTextureTransform,
-                                 const ::Rectangle&                             rBounds,
+                                 const ::tools::Rectangle&                             rBounds,
                                  unsigned int                                   nStepCount,
                                  const ::canvas::ParametricPolyPolygon::Values& rValues,
                                  const std::vector< ::Color >&                  rColors )
@@ -143,7 +143,7 @@ namespace vclcanvas
             // now, we potentially have to enlarge our gradient area
             // atop and below the transformed [0,1]x[0,1] unit rect,
             // for the gradient to fill the complete bound rect.
-            ::basegfx::tools::infiniteLineFromParallelogram( aLeftTop,
+            ::basegfx::utils::infiniteLineFromParallelogram( aLeftTop,
                                                              aLeftBottom,
                                                              aRightTop,
                                                              aRightBottom,
@@ -197,7 +197,7 @@ namespace vclcanvas
 
             rOutDev.SetLineColor();
 
-            basegfx::tools::KeyStopLerp aLerper(rValues.maStops);
+            basegfx::utils::KeyStopLerp aLerper(rValues.maStops);
 
             // only iterate nStepCount-1 steps, as the last strip is
             // explicitly painted below
@@ -205,12 +205,12 @@ namespace vclcanvas
             {
                 std::ptrdiff_t nIndex;
                 double fAlpha;
-                boost::tuples::tie(nIndex,fAlpha)=aLerper.lerp(double(i)/nStepCount);
+                std::tie(nIndex,fAlpha)=aLerper.lerp(double(i)/nStepCount);
 
                 rOutDev.SetFillColor(
-                    Color( (sal_uInt8)(basegfx::tools::lerp(rColors[nIndex].GetRed(),rColors[nIndex+1].GetRed(),fAlpha)),
-                           (sal_uInt8)(basegfx::tools::lerp(rColors[nIndex].GetGreen(),rColors[nIndex+1].GetGreen(),fAlpha)),
-                           (sal_uInt8)(basegfx::tools::lerp(rColors[nIndex].GetBlue(),rColors[nIndex+1].GetBlue(),fAlpha)) ));
+                    Color( (sal_uInt8)(basegfx::utils::lerp(rColors[nIndex].GetRed(),rColors[nIndex+1].GetRed(),fAlpha)),
+                           (sal_uInt8)(basegfx::utils::lerp(rColors[nIndex].GetGreen(),rColors[nIndex+1].GetGreen(),fAlpha)),
+                           (sal_uInt8)(basegfx::utils::lerp(rColors[nIndex].GetBlue(),rColors[nIndex+1].GetBlue(),fAlpha)) ));
 
                 // copy right egde of polygon to left edge (and also
                 // copy the closing point)
@@ -264,7 +264,7 @@ namespace vclcanvas
 
         void fillPolygonalGradient( OutputDevice&                                  rOutDev,
                                     const ::basegfx::B2DHomMatrix&                 rTextureTransform,
-                                    const ::Rectangle&                             rBounds,
+                                    const ::tools::Rectangle&                             rBounds,
                                     unsigned int                                   nStepCount,
                                     bool                                           bFillNonOverlapping,
                                     const ::canvas::ParametricPolyPolygon::Values& rValues,
@@ -285,7 +285,7 @@ namespace vclcanvas
             // subdivide polygon _before_ rendering, would otherwise have
             // to be performed on every loop turn.
             if( aOuterPoly.areControlPointsUsed() )
-                aOuterPoly = ::basegfx::tools::adaptiveSubdivideByAngle(aOuterPoly);
+                aOuterPoly = ::basegfx::utils::adaptiveSubdivideByAngle(aOuterPoly);
 
             aInnerPoly = aOuterPoly;
 
@@ -354,7 +354,7 @@ namespace vclcanvas
 
             rOutDev.SetLineColor();
 
-            basegfx::tools::KeyStopLerp aLerper(rValues.maStops);
+            basegfx::utils::KeyStopLerp aLerper(rValues.maStops);
 
             if( !bFillNonOverlapping )
             {
@@ -371,13 +371,13 @@ namespace vclcanvas
 
                     std::ptrdiff_t nIndex;
                     double fAlpha;
-                    boost::tuples::tie(nIndex,fAlpha)=aLerper.lerp(fT);
+                    std::tie(nIndex,fAlpha)=aLerper.lerp(fT);
 
                     // lerp color
                     rOutDev.SetFillColor(
-                        Color( (sal_uInt8)(basegfx::tools::lerp(rColors[nIndex].GetRed(),rColors[nIndex+1].GetRed(),fAlpha)),
-                               (sal_uInt8)(basegfx::tools::lerp(rColors[nIndex].GetGreen(),rColors[nIndex+1].GetGreen(),fAlpha)),
-                               (sal_uInt8)(basegfx::tools::lerp(rColors[nIndex].GetBlue(),rColors[nIndex+1].GetBlue(),fAlpha)) ));
+                        Color( (sal_uInt8)(basegfx::utils::lerp(rColors[nIndex].GetRed(),rColors[nIndex+1].GetRed(),fAlpha)),
+                               (sal_uInt8)(basegfx::utils::lerp(rColors[nIndex].GetGreen(),rColors[nIndex+1].GetGreen(),fAlpha)),
+                               (sal_uInt8)(basegfx::utils::lerp(rColors[nIndex].GetBlue(),rColors[nIndex+1].GetBlue(),fAlpha)) ));
 
                     // scale and render polygon, by interpolating between
                     // outer and inner polygon.
@@ -429,15 +429,15 @@ namespace vclcanvas
 
                     std::ptrdiff_t nIndex;
                     double fAlpha;
-                    boost::tuples::tie(nIndex,fAlpha)=aLerper.lerp(fT);
+                    std::tie(nIndex,fAlpha)=aLerper.lerp(fT);
 
                     // lerp color
                     rOutDev.SetFillColor(
-                        Color( (sal_uInt8)(basegfx::tools::lerp(rColors[nIndex].GetRed(),rColors[nIndex+1].GetRed(),fAlpha)),
-                               (sal_uInt8)(basegfx::tools::lerp(rColors[nIndex].GetGreen(),rColors[nIndex+1].GetGreen(),fAlpha)),
-                               (sal_uInt8)(basegfx::tools::lerp(rColors[nIndex].GetBlue(),rColors[nIndex+1].GetBlue(),fAlpha)) ));
+                        Color( (sal_uInt8)(basegfx::utils::lerp(rColors[nIndex].GetRed(),rColors[nIndex+1].GetRed(),fAlpha)),
+                               (sal_uInt8)(basegfx::utils::lerp(rColors[nIndex].GetGreen(),rColors[nIndex+1].GetGreen(),fAlpha)),
+                               (sal_uInt8)(basegfx::utils::lerp(rColors[nIndex].GetBlue(),rColors[nIndex+1].GetBlue(),fAlpha)) ));
 
-#if OSL_DEBUG_LEVEL > 2
+#if OSL_DEBUG_LEVEL > 0
                     if( i && !(i % 10) )
                         rOutDev.SetFillColor( COL_RED );
 #endif
@@ -488,13 +488,12 @@ namespace vclcanvas
                              const ::canvas::ParametricPolyPolygon::Values& rValues,
                              const std::vector< ::Color >&                  rColors,
                              const ::basegfx::B2DHomMatrix&                 rTextureTransform,
-                             const ::Rectangle&                             rBounds,
-                             unsigned int                                   nStepCount,
-                             bool                                           bFillNonOverlapping )
+                             const ::tools::Rectangle&                      rBounds,
+                             unsigned int                                   nStepCount )
         {
             switch( rValues.meType )
             {
-                case ::canvas::ParametricPolyPolygon::GRADIENT_LINEAR:
+                case ::canvas::ParametricPolyPolygon::GradientType::Linear:
                     fillLinearGradient( rOutDev,
                                         rTextureTransform,
                                         rBounds,
@@ -503,14 +502,14 @@ namespace vclcanvas
                                         rColors );
                     break;
 
-                case ::canvas::ParametricPolyPolygon::GRADIENT_ELLIPTICAL:
+                case ::canvas::ParametricPolyPolygon::GradientType::Elliptical:
                     // FALLTHROUGH intended
-                case ::canvas::ParametricPolyPolygon::GRADIENT_RECTANGULAR:
+                case ::canvas::ParametricPolyPolygon::GradientType::Rectangular:
                     fillPolygonalGradient( rOutDev,
                                            rTextureTransform,
                                            rBounds,
                                            nStepCount,
-                                           bFillNonOverlapping,
+                                           false/*bFillNonOverlapping*/,
                                            rValues,
                                            rColors );
                     break;
@@ -523,9 +522,9 @@ namespace vclcanvas
 
         int numColorSteps( const ::Color& rColor1, const ::Color& rColor2 )
         {
-            return ::std::max(
+            return std::max(
                 labs( rColor1.GetRed() - rColor2.GetRed() ),
-                ::std::max(
+                std::max(
                     labs( rColor1.GetGreen() - rColor2.GetGreen() ),
                     labs( rColor1.GetBlue()  - rColor2.GetBlue() ) ) );
         }
@@ -563,7 +562,7 @@ namespace vclcanvas
 
             // determine maximal bound rect of texture-filled
             // polygon
-            const ::Rectangle aPolygonDeviceRectOrig(
+            const ::tools::Rectangle aPolygonDeviceRectOrig(
                 rPoly.GetBoundRect() );
 
             if( tools::isRectangle( rPoly ) )
@@ -585,8 +584,7 @@ namespace vclcanvas
                                 rColors,
                                 aTotalTransform,
                                 aPolygonDeviceRectOrig,
-                                nStepCount,
-                                false );
+                                nStepCount );
                 rOutDev.Pop();
 
                 if( p2ndOutDev && nTransparency < 253 )
@@ -604,15 +602,14 @@ namespace vclcanvas
                 const vcl::Region aPolyClipRegion( rPoly );
 
                 rOutDev.Push( PushFlags::CLIPREGION );
-                rOutDev.SetClipRegion( aPolyClipRegion );
+                rOutDev.IntersectClipRegion( aPolyClipRegion );
 
                 doGradientFill( rOutDev,
                                 rValues,
                                 rColors,
                                 aTotalTransform,
                                 aPolygonDeviceRectOrig,
-                                nStepCount,
-                                false );
+                                nStepCount );
                 rOutDev.Pop();
 
                 if( p2ndOutDev && nTransparency < 253 )
@@ -626,7 +623,7 @@ namespace vclcanvas
                 }
             }
 
-#if OSL_DEBUG_LEVEL > 3
+#ifdef DEBUG_CANVAS_CANVASHELPER_TEXTUREFILL
             // extra-verbosity
             {
                 ::basegfx::B2DRectangle aRect(0.0, 0.0, 1.0, 1.0);
@@ -734,7 +731,7 @@ namespace vclcanvas
 
                 // determine maximal bound rect of texture-filled
                 // polygon
-                const ::Rectangle aPolygonDeviceRect(
+                const ::tools::Rectangle aPolygonDeviceRect(
                     aPolyPoly.GetBoundRect() );
 
 
@@ -760,7 +757,7 @@ namespace vclcanvas
                                                             aRect,
                                                             aTotalTransform );
 
-                const ::Rectangle aIntegerTextureDeviceRect(
+                const ::tools::Rectangle aIntegerTextureDeviceRect(
                     vcl::unotools::rectangleFromB2DRectangle( aTextureDeviceRect ) );
 
                 if( bRectangularPolygon &&
@@ -857,9 +854,7 @@ namespace vclcanvas
                         // complex transformation, use generic affine bitmap
                         // transformation
                         aBmpEx = tools::transformBitmap( aBmpEx,
-                                                         aTotalTransform,
-                                                         uno::Sequence< double >(),
-                                                         tools::MODULATE_NONE);
+                                                         aTotalTransform);
 
                         pGrfObj.reset( new GraphicObject( aBmpEx ) );
 
@@ -873,7 +868,7 @@ namespace vclcanvas
                     // =================================
 
                     // calc device space direction vectors. We employ
-                    // the followin approach for tiled output: the
+                    // the following approach for tiled output: the
                     // texture bitmap is output in texture space
                     // x-major order, i.e. tile neighbors in texture
                     // space x direction are rendered back-to-back in
@@ -1066,7 +1061,7 @@ namespace vclcanvas
                             const vcl::Region aPolyClipRegion( aPolyPoly );
 
                             rOutDev.Push( PushFlags::CLIPREGION );
-                            rOutDev.SetClipRegion( aPolyClipRegion );
+                            rOutDev.IntersectClipRegion( aPolyClipRegion );
 
                             textureFill( rOutDev,
                                          *pGrfObj,
@@ -1084,7 +1079,7 @@ namespace vclcanvas
                                 OutputDevice& r2ndOutDev( mp2ndOutDev->getOutDev() );
                                 r2ndOutDev.Push( PushFlags::CLIPREGION );
 
-                                r2ndOutDev.SetClipRegion( aPolyClipRegion );
+                                r2ndOutDev.IntersectClipRegion( aPolyClipRegion );
                                 textureFill( r2ndOutDev,
                                              *pGrfObj,
                                              aPt,
