@@ -18,17 +18,16 @@
  */
 
 #include "tp_ChartType.hxx"
-#include "Strings.hrc"
-#include "ResId.hxx"
-#include "ChartModelHelper.hxx"
-#include "DiagramHelper.hxx"
+#include <strings.hrc>
+#include <ResId.hxx>
+#include <ChartModelHelper.hxx>
+#include <DiagramHelper.hxx>
 #include "res_BarGeometry.hxx"
-#include "ControllerLockGuard.hxx"
-#include "macros.hxx"
+#include <ControllerLockGuard.hxx>
 #include "GL3DBarChartDialogController.hxx"
 #include <unonames.hxx>
 
-#include <svtools/controldims.hrc>
+#include <svtools/controldims.hxx>
 #include <svtools/miscopt.hxx>
 
 #include <vcl/layout.hxx>
@@ -55,8 +54,8 @@ public:
     void fillParameter( ChartTypeParameter& rParameter );
 
 private:
-    DECL_LINK_TYPED( Dim3DLookCheckHdl, CheckBox&, void );
-    DECL_LINK_TYPED( SelectSchemeHdl, ListBox&, void );
+    DECL_LINK( Dim3DLookCheckHdl, CheckBox&, void );
+    DECL_LINK( SelectSchemeHdl, ListBox&, void );
 
 private:
     VclPtr<CheckBox> m_pCB_3DLook;
@@ -95,22 +94,22 @@ void Dim3DLookResourceGroup::fillControls( const ChartTypeParameter& rParameter
 void Dim3DLookResourceGroup::fillParameter( ChartTypeParameter& rParameter )
 {
     rParameter.b3DLook = m_pCB_3DLook->IsChecked();
-    const sal_Int32 nPos = m_pLB_Scheme->GetSelectEntryPos();
-    if( POS_3DSCHEME_SIMPLE == nPos )
+    const sal_Int32 nPos = m_pLB_Scheme->GetSelectedEntryPos();
+    if( nPos == POS_3DSCHEME_SIMPLE )
         rParameter.eThreeDLookScheme = ThreeDLookScheme_Simple;
-    else if( POS_3DSCHEME_REALISTIC == nPos )
+    else if( nPos == POS_3DSCHEME_REALISTIC )
         rParameter.eThreeDLookScheme = ThreeDLookScheme_Realistic;
     else
         rParameter.eThreeDLookScheme = ThreeDLookScheme_Unknown;
 }
 
-IMPL_LINK_NOARG_TYPED(Dim3DLookResourceGroup, Dim3DLookCheckHdl, CheckBox&, void)
+IMPL_LINK_NOARG(Dim3DLookResourceGroup, Dim3DLookCheckHdl, CheckBox&, void)
 {
     if(m_pChangeListener)
         m_pChangeListener->stateChanged(this);
 }
 
-IMPL_LINK_NOARG_TYPED(Dim3DLookResourceGroup, SelectSchemeHdl, ListBox&, void)
+IMPL_LINK_NOARG(Dim3DLookResourceGroup, SelectSchemeHdl, ListBox&, void)
 {
     if(m_pChangeListener)
         m_pChangeListener->stateChanged(this);
@@ -127,7 +126,7 @@ public:
     void fillParameter( ChartTypeParameter& rParameter );
 
 private:
-    DECL_LINK_TYPED( SortByXValuesCheckHdl, CheckBox&, void );
+    DECL_LINK( SortByXValuesCheckHdl, CheckBox&, void );
 
 private:
     VclPtr<CheckBox> m_pCB_XValueSorting;
@@ -155,7 +154,7 @@ void SortByXValuesResourceGroup::fillParameter( ChartTypeParameter& rParameter )
     rParameter.bSortByXValues = m_pCB_XValueSorting->IsChecked();
 }
 
-IMPL_LINK_NOARG_TYPED(SortByXValuesResourceGroup, SortByXValuesCheckHdl, CheckBox&, void)
+IMPL_LINK_NOARG(SortByXValuesResourceGroup, SortByXValuesCheckHdl, CheckBox&, void)
 {
     if(m_pChangeListener)
         m_pChangeListener->stateChanged(this);
@@ -172,21 +171,18 @@ public:
     void fillParameter( ChartTypeParameter& rParameter );
 
 private:
-    DECL_LINK_TYPED( StackingChangeHdl, RadioButton&, void );
-    DECL_LINK_TYPED( StackingEnableHdl, CheckBox&, void );
+    DECL_LINK( StackingChangeHdl, RadioButton&, void );
+    DECL_LINK( StackingEnableHdl, CheckBox&, void );
 
 private:
     VclPtr<CheckBox>    m_pCB_Stacked;
     VclPtr<RadioButton> m_pRB_Stack_Y;
     VclPtr<RadioButton> m_pRB_Stack_Y_Percent;
     VclPtr<RadioButton> m_pRB_Stack_Z;
-
-    bool m_bShowDeepStacking;
 };
 
 StackingResourceGroup::StackingResourceGroup(VclBuilderContainer* pWindow)
         : ChangingResource()
-        , m_bShowDeepStacking(true)
 {
     pWindow->get(m_pCB_Stacked, "stack");
     pWindow->get(m_pRB_Stack_Y, "ontop");
@@ -201,7 +197,6 @@ StackingResourceGroup::StackingResourceGroup(VclBuilderContainer* pWindow)
 
 void StackingResourceGroup::showControls( bool bShow, bool bShowDeepStacking )
 {
-    m_bShowDeepStacking = bShowDeepStacking;
     m_pCB_Stacked->Show(bShow);
     m_pRB_Stack_Y->Show(bShow);
     m_pRB_Stack_Y_Percent->Show(bShow);
@@ -250,7 +245,7 @@ void StackingResourceGroup::fillParameter( ChartTypeParameter& rParameter )
     else if(m_pRB_Stack_Z->IsChecked())
         rParameter.eStackMode = GlobalStackMode_STACK_Z;
 }
-IMPL_LINK_TYPED( StackingResourceGroup, StackingChangeHdl, RadioButton&, rRadio, void )
+IMPL_LINK( StackingResourceGroup, StackingChangeHdl, RadioButton&, rRadio, void )
 {
     //for each radio click there are coming two change events
     //first uncheck of previous button -> ignore that call
@@ -258,7 +253,7 @@ IMPL_LINK_TYPED( StackingResourceGroup, StackingChangeHdl, RadioButton&, rRadio,
     if( m_pChangeListener && rRadio.IsChecked() )
         m_pChangeListener->stateChanged(this);
 }
-IMPL_LINK_NOARG_TYPED(StackingResourceGroup, StackingEnableHdl, CheckBox&, void)
+IMPL_LINK_NOARG(StackingResourceGroup, StackingEnableHdl, CheckBox&, void)
 {
     if( m_pChangeListener )
         m_pChangeListener->stateChanged(this);
@@ -274,7 +269,7 @@ public:
     void fillParameter( ChartTypeParameter& rParam );
 
 private:
-    DECL_LINK_TYPED( SettingChangedHdl, CheckBox&, void );
+    DECL_LINK( SettingChangedHdl, CheckBox&, void );
 private:
     VclPtr<CheckBox> m_pCB_RoundedEdge;
 };
@@ -300,7 +295,7 @@ void GL3DResourceGroup::fillParameter( ChartTypeParameter& rParam )
     rParam.mbRoundedEdge = m_pCB_RoundedEdge->IsChecked();
 }
 
-IMPL_LINK_NOARG_TYPED( GL3DResourceGroup, SettingChangedHdl, CheckBox&, void )
+IMPL_LINK_NOARG( GL3DResourceGroup, SettingChangedHdl, CheckBox&, void )
 {
     if (m_pChangeListener)
         m_pChangeListener->stateChanged(this);
@@ -310,16 +305,14 @@ class SplinePropertiesDialog : public ModalDialog
 {
 public:
     explicit SplinePropertiesDialog( vcl::Window* pParent );
-    virtual ~SplinePropertiesDialog() { disposeOnce(); }
+    virtual ~SplinePropertiesDialog() override { disposeOnce(); }
     virtual void dispose() override;
 
     void fillControls( const ChartTypeParameter& rParameter );
     void fillParameter( ChartTypeParameter& rParameter, bool bSmoothLines );
 
-    virtual void StateChanged( StateChangedType nType ) override;
-
 private:
-    DECL_LINK_TYPED( SplineTypeListBoxHdl, ListBox&, void );
+    DECL_LINK( SplineTypeListBoxHdl, ListBox&, void );
 
 private:
     VclPtr<ListBox>      m_pLB_Spline_Type;
@@ -340,7 +333,7 @@ SplinePropertiesDialog::SplinePropertiesDialog( vcl::Window* pParent )
     get(m_pFT_SplineOrder, "PolynomialsLabel");
     get(m_pMF_SplineOrder, "PolynomialsSpinButton");
 
-    this->SetText( SCH_RESSTR( STR_DLG_SMOOTH_LINE_PROPERTIES ) );
+    SetText( SchResId( STR_DLG_SMOOTH_LINE_PROPERTIES ) );
 
     m_pLB_Spline_Type->SetSelectHdl( LINK (this, SplinePropertiesDialog, SplineTypeListBoxHdl ) );
 }
@@ -354,11 +347,6 @@ void SplinePropertiesDialog::dispose()
     ModalDialog::dispose();
 }
 
-void SplinePropertiesDialog::StateChanged( StateChangedType nType )
-{
-    Dialog::StateChanged( nType );
-}
-
 void SplinePropertiesDialog::fillControls( const ChartTypeParameter& rParameter )
 {
     switch(rParameter.eCurveStyle)
@@ -377,41 +365,37 @@ void SplinePropertiesDialog::fillControls( const ChartTypeParameter& rParameter
     m_pMF_SplineResolution->SetValue( rParameter.nCurveResolution );
 
     //dis/enabling
-    m_pFT_SplineOrder->Enable(B_SPLINE_POS == m_pLB_Spline_Type->GetSelectEntryPos());
-    m_pMF_SplineOrder->Enable(B_SPLINE_POS == m_pLB_Spline_Type->GetSelectEntryPos());
+    m_pFT_SplineOrder->Enable(m_pLB_Spline_Type->GetSelectedEntryPos() == B_SPLINE_POS);
+    m_pMF_SplineOrder->Enable(m_pLB_Spline_Type->GetSelectedEntryPos() == B_SPLINE_POS);
 }
 void SplinePropertiesDialog::fillParameter( ChartTypeParameter& rParameter, bool bSmoothLines )
 {
     if(!bSmoothLines)
         rParameter.eCurveStyle=CurveStyle_LINES;
-    else if(CUBIC_SPLINE_POS == m_pLB_Spline_Type->GetSelectEntryPos())
+    else if(m_pLB_Spline_Type->GetSelectedEntryPos() == CUBIC_SPLINE_POS)
         rParameter.eCurveStyle=CurveStyle_CUBIC_SPLINES;
-    else if(B_SPLINE_POS == m_pLB_Spline_Type->GetSelectEntryPos())
+    else if(m_pLB_Spline_Type->GetSelectedEntryPos() == B_SPLINE_POS)
         rParameter.eCurveStyle=CurveStyle_B_SPLINES;
 
     rParameter.nCurveResolution = static_cast< sal_Int32 >( m_pMF_SplineResolution->GetValue());
     rParameter.nSplineOrder = static_cast< sal_Int32 >( m_pMF_SplineOrder->GetValue());
 }
-IMPL_LINK_NOARG_TYPED(SplinePropertiesDialog, SplineTypeListBoxHdl, ListBox&, void)
+IMPL_LINK_NOARG(SplinePropertiesDialog, SplineTypeListBoxHdl, ListBox&, void)
 {
-    m_pFT_SplineOrder->Enable(B_SPLINE_POS == m_pLB_Spline_Type->GetSelectEntryPos());
-    m_pMF_SplineOrder->Enable(B_SPLINE_POS == m_pLB_Spline_Type->GetSelectEntryPos());
+    m_pFT_SplineOrder->Enable(m_pLB_Spline_Type->GetSelectedEntryPos() == B_SPLINE_POS);
+    m_pMF_SplineOrder->Enable(m_pLB_Spline_Type->GetSelectedEntryPos() == B_SPLINE_POS);
 }
 
 class SteppedPropertiesDialog : public ModalDialog
 {
 public:
     explicit SteppedPropertiesDialog( vcl::Window* pParent );
-    virtual ~SteppedPropertiesDialog() { disposeOnce(); }
+    virtual ~SteppedPropertiesDialog() override { disposeOnce(); }
     virtual void dispose() override;
 
     void fillControls( const ChartTypeParameter& rParameter );
     void fillParameter( ChartTypeParameter& rParameter, bool bSteppedLines );
 
-    virtual void StateChanged( StateChangedType nType ) override;
-
-private:
-
 private:
     VclPtr<RadioButton> m_pRB_Start;
     VclPtr<RadioButton> m_pRB_End;
@@ -427,7 +411,7 @@ SteppedPropertiesDialog::SteppedPropertiesDialog( vcl::Window* pParent )
     get(m_pRB_CenterX, "step_center_x_rb");
     get(m_pRB_CenterY, "step_center_y_rb");
 
-    SetText(SCH_RESSTR(STR_DLG_STEPPED_LINE_PROPERTIES));
+    SetText(SchResId(STR_DLG_STEPPED_LINE_PROPERTIES));
 }
 
 void SteppedPropertiesDialog::dispose()
@@ -439,11 +423,6 @@ void SteppedPropertiesDialog::dispose()
     ModalDialog::dispose();
 }
 
-void SteppedPropertiesDialog::StateChanged( StateChangedType nType )
-{
-    Dialog::StateChanged( nType );
-}
-
 void SteppedPropertiesDialog::fillControls( const ChartTypeParameter& rParameter )
 {
     switch(rParameter.eCurveStyle)
@@ -491,9 +470,9 @@ public:
     void fillParameter( ChartTypeParameter& rParameter );
 
 private:
-    DECL_LINK_TYPED( LineTypeChangeHdl, ListBox&, void );
-    DECL_LINK_TYPED( SplineDetailsDialogHdl, Button*, void );
-    DECL_LINK_TYPED( SteppedDetailsDialogHdl, Button*, void );
+    DECL_LINK( LineTypeChangeHdl, ListBox&, void );
+    DECL_LINK( SplineDetailsDialogHdl, Button*, void );
+    DECL_LINK( SteppedDetailsDialogHdl, Button*, void );
     SplinePropertiesDialog& getSplinePropertiesDialog();
     SteppedPropertiesDialog& getSteppedPropertiesDialog();
 
@@ -551,7 +530,7 @@ void SplineResourceGroup::fillControls( const ChartTypeParameter& rParameter )
             m_pLB_LineType->SelectEntryPos(POS_LINETYPE_SMOOTH);
             m_pPB_DetailsDialog->Enable();
             m_pPB_DetailsDialog->SetClickHdl( LINK( this, SplineResourceGroup, SplineDetailsDialogHdl ) );
-            m_pPB_DetailsDialog->SetQuickHelpText( SCH_RESSTR(STR_DLG_SMOOTH_LINE_PROPERTIES) );
+            m_pPB_DetailsDialog->SetQuickHelpText( SchResId(STR_DLG_SMOOTH_LINE_PROPERTIES) );
             getSplinePropertiesDialog().fillControls( rParameter );
             break;
         case CurveStyle_STEP_START:
@@ -561,7 +540,7 @@ void SplineResourceGroup::fillControls( const ChartTypeParameter& rParameter )
             m_pLB_LineType->SelectEntryPos(POS_LINETYPE_STEPPED);
             m_pPB_DetailsDialog->Enable();
             m_pPB_DetailsDialog->SetClickHdl( LINK( this, SplineResourceGroup, SteppedDetailsDialogHdl ) );
-            m_pPB_DetailsDialog->SetQuickHelpText( SCH_RESSTR(STR_DLG_STEPPED_LINE_PROPERTIES) );
+            m_pPB_DetailsDialog->SetQuickHelpText( SchResId(STR_DLG_STEPPED_LINE_PROPERTIES) );
             getSteppedPropertiesDialog().fillControls( rParameter );
             break;
         default:
@@ -571,7 +550,7 @@ void SplineResourceGroup::fillControls( const ChartTypeParameter& rParameter )
 }
 void SplineResourceGroup::fillParameter( ChartTypeParameter& rParameter )
 {
-    switch (m_pLB_LineType->GetSelectEntryPos())
+    switch (m_pLB_LineType->GetSelectedEntryPos())
     {
         case POS_LINETYPE_SMOOTH:
             getSplinePropertiesDialog().fillParameter( rParameter, true );
@@ -584,20 +563,20 @@ void SplineResourceGroup::fillParameter( ChartTypeParameter& rParameter )
             break;
     }
 }
-IMPL_LINK_NOARG_TYPED(SplineResourceGroup, LineTypeChangeHdl, ListBox&, void)
+IMPL_LINK_NOARG(SplineResourceGroup, LineTypeChangeHdl, ListBox&, void)
 {
     if( m_pChangeListener )
         m_pChangeListener->stateChanged(this);
 }
-IMPL_LINK_NOARG_TYPED(SplineResourceGroup, SplineDetailsDialogHdl, Button*, void)
+IMPL_LINK_NOARG(SplineResourceGroup, SplineDetailsDialogHdl, Button*, void)
 {
 
     ChartTypeParameter aOldParameter;
-    getSplinePropertiesDialog().fillParameter( aOldParameter, POS_LINETYPE_SMOOTH == m_pLB_LineType->GetSelectEntryPos() );
+    getSplinePropertiesDialog().fillParameter( aOldParameter, m_pLB_LineType->GetSelectedEntryPos() == POS_LINETYPE_SMOOTH );
 
-    const sal_Int32 iOldLineTypePos = m_pLB_LineType->GetSelectEntryPos();
+    const sal_Int32 iOldLineTypePos = m_pLB_LineType->GetSelectedEntryPos();
     m_pLB_LineType->SelectEntryPos(POS_LINETYPE_SMOOTH);
-    if( RET_OK == getSplinePropertiesDialog().Execute() )
+    if( getSplinePropertiesDialog().Execute() == RET_OK )
     {
         if( m_pChangeListener )
             m_pChangeListener->stateChanged(this);
@@ -609,15 +588,15 @@ IMPL_LINK_NOARG_TYPED(SplineResourceGroup, SplineDetailsDialogHdl, Button*, void
         getSplinePropertiesDialog().fillControls( aOldParameter );
     }
 }
-IMPL_LINK_NOARG_TYPED(SplineResourceGroup, SteppedDetailsDialogHdl, Button*, void)
+IMPL_LINK_NOARG(SplineResourceGroup, SteppedDetailsDialogHdl, Button*, void)
 {
 
     ChartTypeParameter aOldParameter;
-    getSteppedPropertiesDialog().fillParameter( aOldParameter, POS_LINETYPE_STEPPED == m_pLB_LineType->GetSelectEntryPos() );
+    getSteppedPropertiesDialog().fillParameter( aOldParameter, m_pLB_LineType->GetSelectedEntryPos() == POS_LINETYPE_STEPPED );
 
-    const sal_Int32 iOldLineTypePos = m_pLB_LineType->GetSelectEntryPos();
+    const sal_Int32 iOldLineTypePos = m_pLB_LineType->GetSelectedEntryPos();
     m_pLB_LineType->SelectEntryPos(POS_LINETYPE_STEPPED);
-    if( RET_OK == getSteppedPropertiesDialog().Execute() )
+    if( getSteppedPropertiesDialog().Execute() == RET_OK )
     {
         if( m_pChangeListener )
             m_pChangeListener->stateChanged(this);
@@ -641,7 +620,7 @@ public:
     void fillParameter( ChartTypeParameter& rParameter );
 
 private:
-    DECL_LINK_TYPED( GeometryChangeHdl, ListBox&, void );
+    DECL_LINK( GeometryChangeHdl, ListBox&, void );
 
 private:
     BarGeometryResources m_aGeometryResources;
@@ -669,11 +648,11 @@ void GeometryResourceGroup::fillControls( const ChartTypeParameter& rParameter )
 void GeometryResourceGroup::fillParameter( ChartTypeParameter& rParameter )
 {
     rParameter.nGeometry3D = 1;
-    if( m_aGeometryResources.GetSelectEntryCount() )
-        rParameter.nGeometry3D = m_aGeometryResources.GetSelectEntryPos();
+    if( m_aGeometryResources.GetSelectedEntryCount() )
+        rParameter.nGeometry3D = m_aGeometryResources.GetSelectedEntryPos();
 }
 
-IMPL_LINK_NOARG_TYPED(GeometryResourceGroup, GeometryChangeHdl, ListBox&, void)
+IMPL_LINK_NOARG(GeometryResourceGroup, GeometryChangeHdl, ListBox&, void)
 {
     if( m_pChangeListener )
         m_pChangeListener->stateChanged(this);
@@ -681,8 +660,7 @@ IMPL_LINK_NOARG_TYPED(GeometryResourceGroup, GeometryChangeHdl, ListBox&, void)
 
 ChartTypeTabPage::ChartTypeTabPage(vcl::Window* pParent
         , const uno::Reference< XChartDocument >& xChartModel
-        , const uno::Reference< uno::XComponentContext >& xContext
-        , bool bDoLiveUpdate, bool bShowDescription)
+        , bool bShowDescription)
         : OWizardPage(pParent, "tp_ChartType",
             "modules/schart/ui/tp_ChartType.ui")
         , m_pDim3DLookResourceGroup( new Dim3DLookResourceGroup(this) )
@@ -692,17 +670,15 @@ ChartTypeTabPage::ChartTypeTabPage(vcl::Window* pParent
         , m_pSortByXValuesResourceGroup( new SortByXValuesResourceGroup( this ) )
         , m_pGL3DResourceGroup(new GL3DResourceGroup(this))
         , m_xChartModel( xChartModel )
-        , m_xCC( xContext )
         , m_aChartTypeDialogControllerList(0)
         , m_pCurrentMainType(nullptr)
         , m_nChangingCalls(0)
-        , m_bDoLiveUpdate(bDoLiveUpdate)
         , m_aTimerTriggeredControllerLock( uno::Reference< frame::XModel >( m_xChartModel, uno::UNO_QUERY ) )
 {
     get(m_pFT_ChooseType, "FT_CAPTION_FOR_WIZARD");
     get(m_pMainTypeList, "charttype");
     get(m_pSubTypeList, "subtype");
-    Size aSize(m_pSubTypeList->LogicToPixel(Size(150, 50), MAP_APPFONT));
+    Size aSize(m_pSubTypeList->LogicToPixel(Size(150, 50), MapMode(MapUnit::MapAppFont)));
     m_pSubTypeList->set_width_request(aSize.Width());
     m_pSubTypeList->set_height_request(aSize.Height());
 
@@ -715,7 +691,7 @@ ChartTypeTabPage::ChartTypeTabPage(vcl::Window* pParent
         m_pFT_ChooseType->SetStyle(m_pFT_ChooseType->GetStyle() | WB_NOLABEL);
     }
 
-    this->SetText( SCH_RESSTR(STR_PAGE_CHARTTYPE) );
+    SetText( SchResId(STR_PAGE_CHARTTYPE) );
 
     m_pMainTypeList->SetStyle(m_pMainTypeList->GetStyle() | WB_ITEMBORDER | WB_DOUBLEBORDER | WB_FLATVALUESET | WB_3DLOOK );
     m_pMainTypeList->SetSelectHdl( LINK( this, ChartTypeTabPage, SelectMainTypeHdl ) );
@@ -736,7 +712,7 @@ ChartTypeTabPage::ChartTypeTabPage(vcl::Window* pParent
         }
         catch( const uno::Exception& e )
         {
-            ASSERT_EXCEPTION( e );
+            SAL_WARN("chart2", "Exception caught. " << e );
         }
     }
 
@@ -756,14 +732,13 @@ ChartTypeTabPage::ChartTypeTabPage(vcl::Window* pParent
         m_aChartTypeDialogControllerList.push_back(new StockChartDialogController() );
     }
     m_aChartTypeDialogControllerList.push_back(new CombiColumnLineChartDialogController() );
-#if ENABLE_GL3D_BARCHART
+
     SvtMiscOptions aOpts;
     if ( aOpts.IsExperimentalMode() )
         m_aChartTypeDialogControllerList.push_back(new GL3DBarChartDialogController());
-#endif
 
-    ::std::vector< ChartTypeDialogController* >::const_iterator       aIter = m_aChartTypeDialogControllerList.begin();
-    const ::std::vector< ChartTypeDialogController* >::const_iterator aEnd  = m_aChartTypeDialogControllerList.end();
+    std::vector< ChartTypeDialogController* >::const_iterator       aIter = m_aChartTypeDialogControllerList.begin();
+    const std::vector< ChartTypeDialogController* >::const_iterator aEnd  = m_aChartTypeDialogControllerList.end();
     for( ; aIter != aEnd; ++aIter )
     {
         m_pMainTypeList->InsertEntry( (*aIter)->getName(), (*aIter)->getImage() );
@@ -786,8 +761,8 @@ ChartTypeTabPage::~ChartTypeTabPage()
 void ChartTypeTabPage::dispose()
 {
     //delete all dialog controller
-    ::std::vector< ChartTypeDialogController* >::const_iterator       aIter = m_aChartTypeDialogControllerList.begin();
-    const ::std::vector< ChartTypeDialogController* >::const_iterator aEnd  = m_aChartTypeDialogControllerList.end();
+    std::vector< ChartTypeDialogController* >::const_iterator       aIter = m_aChartTypeDialogControllerList.begin();
+    const std::vector< ChartTypeDialogController* >::const_iterator aEnd  = m_aChartTypeDialogControllerList.end();
     for( ; aIter != aEnd; ++aIter )
     {
         delete *aIter;
@@ -825,29 +800,29 @@ ChartTypeParameter ChartTypeTabPage::getCurrentParamter() const
     m_pGL3DResourceGroup->fillParameter(aParameter);
     return aParameter;
 }
+
 void ChartTypeTabPage::commitToModel( const ChartTypeParameter& rParameter )
 {
     if( !m_pCurrentMainType )
         return;
 
     m_aTimerTriggeredControllerLock.startTimer();
-    ControllerLockGuardUNO aLockedControllers( uno::Reference< frame::XModel >( m_xChartModel, uno::UNO_QUERY ) );
     m_pCurrentMainType->commitToModel( rParameter, m_xChartModel );
 }
+
 void ChartTypeTabPage::stateChanged( ChangingResource* /*pResource*/ )
 {
     if(m_nChangingCalls)
         return;
     m_nChangingCalls++;
 
-    ChartTypeParameter aParameter( this->getCurrentParamter() );
+    ChartTypeParameter aParameter( getCurrentParamter() );
     if( m_pCurrentMainType )
     {
         m_pCurrentMainType->adjustParameterToSubType( aParameter );
         m_pCurrentMainType->adjustSubTypeAndEnableControls( aParameter );
     }
-    if( m_bDoLiveUpdate )
-        commitToModel( aParameter );
+    commitToModel( aParameter );
 
     //detect the new ThreeDLookScheme
     uno::Reference<XDiagram> xDiagram = ChartModelHelper::findDiagram(m_xChartModel);
@@ -859,42 +834,43 @@ void ChartTypeTabPage::stateChanged( ChangingResource* /*pResource*/ )
     }
     catch ( const uno::Exception& ex )
     {
-        ASSERT_EXCEPTION(ex);
+        SAL_WARN("chart2", "Exception caught. " << ex);
     }
     //the controls have to be enabled/disabled accordingly
-    this->fillAllControls( aParameter );
+    fillAllControls( aParameter );
 
     m_nChangingCalls--;
 }
+
 ChartTypeDialogController* ChartTypeTabPage::getSelectedMainType()
 {
     ChartTypeDialogController* pTypeController = nullptr;
-    ::std::vector< ChartTypeDialogController* >::size_type nM = static_cast< ::std::vector< ChartTypeDialogController* >::size_type >(
-        m_pMainTypeList->GetSelectEntryPos() );
+    std::vector< ChartTypeDialogController* >::size_type nM = static_cast< std::vector< ChartTypeDialogController* >::size_type >(
+        m_pMainTypeList->GetSelectedEntryPos() );
     if( nM<m_aChartTypeDialogControllerList.size() )
         pTypeController = m_aChartTypeDialogControllerList[nM];
     return pTypeController;
 }
-IMPL_LINK_NOARG_TYPED(ChartTypeTabPage, SelectSubTypeHdl, ValueSet*, void)
+
+IMPL_LINK_NOARG(ChartTypeTabPage, SelectSubTypeHdl, ValueSet*, void)
 {
     if( m_pCurrentMainType )
     {
-        ChartTypeParameter aParameter( this->getCurrentParamter() );
+        ChartTypeParameter aParameter( getCurrentParamter() );
         m_pCurrentMainType->adjustParameterToSubType( aParameter );
-        this->fillAllControls( aParameter, false );
-        if( m_bDoLiveUpdate )
-            commitToModel( aParameter );
+        fillAllControls( aParameter, false );
+        commitToModel( aParameter );
     }
 }
 
-IMPL_LINK_NOARG_TYPED(ChartTypeTabPage, SelectMainTypeHdl, ListBox&, void)
+IMPL_LINK_NOARG(ChartTypeTabPage, SelectMainTypeHdl, ListBox&, void)
 {
     selectMainType();
 }
 
 void ChartTypeTabPage::selectMainType()
 {
-    ChartTypeParameter aParameter( this->getCurrentParamter() );
+    ChartTypeParameter aParameter( getCurrentParamter() );
 
     if( m_pCurrentMainType )
     {
@@ -902,14 +878,13 @@ void ChartTypeTabPage::selectMainType()
         m_pCurrentMainType->hideExtraControls();
     }
 
-    m_pCurrentMainType = this->getSelectedMainType();
+    m_pCurrentMainType = getSelectedMainType();
     if( m_pCurrentMainType )
     {
-        this->showAllControls(*m_pCurrentMainType);
+        showAllControls(*m_pCurrentMainType);
 
         m_pCurrentMainType->adjustParameterToMainType( aParameter );
-        if( m_bDoLiveUpdate )
-            commitToModel( aParameter );
+        commitToModel( aParameter );
         //detect the new ThreeDLookScheme
         aParameter.eThreeDLookScheme = ThreeDHelper::detectScheme( ChartModelHelper::findDiagram( m_xChartModel ) );
         if(!aParameter.b3DLook && aParameter.eThreeDLookScheme!=ThreeDLookScheme_Realistic )
@@ -923,11 +898,11 @@ void ChartTypeTabPage::selectMainType()
         }
         catch ( const uno::Exception& ex )
         {
-            ASSERT_EXCEPTION(ex);
+            SAL_WARN("chart2", "Exception caught. " << ex);
         }
 
-        this->fillAllControls( aParameter );
-        uno::Reference< beans::XPropertySet > xTemplateProps( this->getCurrentTemplate(), uno::UNO_QUERY );
+        fillAllControls( aParameter );
+        uno::Reference< beans::XPropertySet > xTemplateProps( getCurrentTemplate(), uno::UNO_QUERY );
         m_pCurrentMainType->fillExtraControls(aParameter,m_xChartModel,xTemplateProps);
     }
 }
@@ -982,8 +957,8 @@ void ChartTypeTabPage::initializePage()
 
     bool bFound = false;
 
-    ::std::vector< ChartTypeDialogController* >::iterator             aIter = m_aChartTypeDialogControllerList.begin();
-    const ::std::vector< ChartTypeDialogController* >::const_iterator aEnd  = m_aChartTypeDialogControllerList.end();
+    std::vector< ChartTypeDialogController* >::iterator             aIter = m_aChartTypeDialogControllerList.begin();
+    const std::vector< ChartTypeDialogController* >::const_iterator aEnd  = m_aChartTypeDialogControllerList.end();
     for( sal_uInt16 nM=0; aIter != aEnd; ++aIter, ++nM )
     {
         if( (*aIter)->isSubType(aServiceName) )
@@ -991,10 +966,10 @@ void ChartTypeTabPage::initializePage()
             bFound = true;
 
             m_pMainTypeList->SelectEntryPos( nM );
-            this->showAllControls( **aIter );
+            showAllControls( **aIter );
             uno::Reference< beans::XPropertySet > xTemplateProps( aTemplate.first, uno::UNO_QUERY );
             ChartTypeParameter aParameter = (*aIter)->getChartTypeParameterForService( aServiceName, xTemplateProps );
-            m_pCurrentMainType = this->getSelectedMainType();
+            m_pCurrentMainType = getSelectedMainType();
 
             //set ThreeDLookScheme
             aParameter.eThreeDLookScheme = ThreeDHelper::detectScheme( xDiagram );
@@ -1008,10 +983,10 @@ void ChartTypeTabPage::initializePage()
             }
             catch (const uno::Exception& ex)
             {
-                ASSERT_EXCEPTION(ex);
+                SAL_WARN("chart2", "Exception caught. " << ex);
             }
 
-            this->fillAllControls( aParameter );
+            fillAllControls( aParameter );
             if( m_pCurrentMainType )
                 m_pCurrentMainType->fillExtraControls(aParameter,m_xChartModel,xTemplateProps);
             break;
@@ -1032,14 +1007,6 @@ void ChartTypeTabPage::initializePage()
 
 bool ChartTypeTabPage::commitPage( ::svt::WizardTypes::CommitPageReason /*eReason*/ )
 {
-    //commit changes to model
-    if( !m_bDoLiveUpdate && m_pCurrentMainType )
-    {
-        ChartTypeParameter aParameter( this->getCurrentParamter() );
-        m_pCurrentMainType->adjustParameterToSubType( aParameter );
-        commitToModel( aParameter );
-    }
-
     return true; // return false if this page should not be left
 }
 
@@ -1047,7 +1014,7 @@ uno::Reference< XChartTypeTemplate > ChartTypeTabPage::getCurrentTemplate() cons
 {
     if( m_pCurrentMainType && m_xChartModel.is() )
     {
-        ChartTypeParameter aParameter( this->getCurrentParamter() );
+        ChartTypeParameter aParameter( getCurrentParamter() );
         m_pCurrentMainType->adjustParameterToSubType( aParameter );
         uno::Reference< lang::XMultiServiceFactory > xTemplateManager( m_xChartModel->getChartTypeManager(), uno::UNO_QUERY );
         return m_pCurrentMainType->getCurrentTemplate( aParameter, xTemplateManager );
