@@ -18,9 +18,9 @@
  */
 
 #include "tp_ErrorBars.hxx"
-#include "ResId.hxx"
-#include "ResourceIds.hrc"
-#include "TabPageNotifiable.hxx"
+#include <ResId.hxx>
+#include "TabPageIds.h"
+#include <TabPageNotifiable.hxx>
 #include <vcl/settings.hxx>
 
 using namespace ::com::sun::star;
