@@ -19,27 +19,19 @@
 
 #include "tp_Scale.hxx"
 
-#include "ResId.hxx"
-#include "Strings.hrc"
-#include "chartview/ChartSfxItemIds.hxx"
-#include "AxisHelper.hxx"
+#include <ResId.hxx>
+#include <strings.hrc>
+#include <chartview/ChartSfxItemIds.hxx>
+#include <AxisHelper.hxx>
 
 #include <svx/svxids.hrc>
 #include <rtl/math.hxx>
-// header for class SvxDoubleItem
 #include <svx/chrtitem.hxx>
-// header for class SfxBoolItem
 #include <svl/eitem.hxx>
-// header for SfxInt32Item
 #include <svl/intitem.hxx>
-
-// header for class WarningBox
 #include <vcl/msgbox.hxx>
-
-// header for class SvNumberformat
 #include <svl/zformat.hxx>
-
-#include <svtools/controldims.hrc>
+#include <svtools/controldims.hxx>
 
 #include <com/sun/star/chart2/AxisType.hpp>
 
@@ -59,11 +51,11 @@ void lcl_setValue( FormattedField& rFmtField, double fValue )
 
 }
 
-ScaleTabPage::ScaleTabPage(Window* pWindow,const SfxItemSet& rInAttrs) :
+ScaleTabPage::ScaleTabPage(vcl::Window* pWindow,const SfxItemSet& rInAttrs) :
     SfxTabPage(pWindow
                , "tp_Scale"
                , "modules/schart/ui/tp_Scale.ui"
-               , rInAttrs),
+               , &rInAttrs),
     fMin(0.0),
     fMax(0.0),
     fStepMain(0.0),
@@ -74,7 +66,7 @@ ScaleTabPage::ScaleTabPage(Window* pWindow,const SfxItemSet& rInAttrs) :
     m_nHelpTimeUnit(1),
     m_nAxisType(chart2::AxisType::REALNUMBER),
     m_bAllowDateAxis(false),
-    pNumFormatter(NULL),
+    pNumFormatter(nullptr),
     m_bShowAxisOrigin(false)
 {
     get(m_pCbxReverse, "CBX_REVERSE");
@@ -92,13 +84,12 @@ ScaleTabPage::ScaleTabPage(Window* pWindow,const SfxItemSet& rInAttrs) :
     get(m_pLB_TimeResolution, "LB_TIME_RESOLUTION");
     get(m_pCbx_AutoTimeResolution, "CBX_AUTO_TIME_RESOLUTION");
 
-    get(m_pBxMain, "boxMAIN");
+    get(m_pTxtMain, "TXT_STEP_MAIN");
     get(m_pFmtFldStepMain, "EDT_STEP_MAIN");
     get(m_pMt_MainDateStep, "MT_MAIN_DATE_STEP");
     get(m_pLB_MainTimeUnit, "LB_MAIN_TIME_UNIT");
     get(m_pCbxAutoStepMain, "CBX_AUTO_STEP_MAIN");
 
-    get(m_pBxMinor, "boxMINOR");
     get(m_pMtStepHelp, "MT_STEPHELP");
     get(m_pLB_HelpTimeUnit, "LB_HELP_TIME_UNIT");
     get(m_pCbxAutoStepHelp, "CBX_AUTO_STEP_HELP");
@@ -131,37 +122,70 @@ ScaleTabPage::ScaleTabPage(Window* pWindow,const SfxItemSet& rInAttrs) :
     HideAllControls();
 }
 
-IMPL_LINK( ScaleTabPage, FmtFieldModifiedHdl, FormattedField*, pFmtFied )
+ScaleTabPage::~ScaleTabPage()
 {
-    if( pFmtFied )
-        pFmtFied->SetDefaultValue( pFmtFied->GetValue() );
-    return 0;
+    disposeOnce();
 }
 
-void ScaleTabPage::StateChanged( StateChangedType nType )
+void ScaleTabPage::dispose()
 {
-    TabPage::StateChanged( nType );
+    m_pCbxReverse.clear();
+    m_pCbxLogarithm.clear();
+    m_pBxType.clear();
+    m_pLB_AxisType.clear();
+    m_pBxMinMax.clear();
+    m_pFmtFldMin.clear();
+    m_pCbxAutoMin.clear();
+    m_pFmtFldMax.clear();
+    m_pCbxAutoMax.clear();
+    m_pBxResolution.clear();
+    m_pLB_TimeResolution.clear();
+    m_pCbx_AutoTimeResolution.clear();
+    m_pTxtMain.clear();
+    m_pFmtFldStepMain.clear();
+    m_pMt_MainDateStep.clear();
+    m_pLB_MainTimeUnit.clear();
+    m_pCbxAutoStepMain.clear();
+    m_pTxtHelpCount.clear();
+    m_pTxtHelp.clear();
+    m_pMtStepHelp.clear();
+    m_pLB_HelpTimeUnit.clear();
+    m_pCbxAutoStepHelp.clear();
+    m_pFmtFldOrigin.clear();
+    m_pCbxAutoOrigin.clear();
+    m_pBxOrigin.clear();
+    SfxTabPage::dispose();
+}
+
+IMPL_STATIC_LINK(
+    ScaleTabPage, FmtFieldModifiedHdl, Edit&, rEdit, void )
+{
+    FormattedField& rFmtField = static_cast<FormattedField&>(rEdit);
+    rFmtField.SetDefaultValue( rFmtField.GetValue() );
 }
 
 void ScaleTabPage::EnableControls()
 {
-    bool bValueAxis = chart2::AxisType::REALNUMBER == m_nAxisType
-                   || chart2::AxisType::PERCENT == m_nAxisType
-                   || chart2::AxisType::DATE == m_nAxisType;
-    bool bDateAxis = chart2::AxisType::DATE == m_nAxisType;
+    bool bValueAxis = m_nAxisType == chart2::AxisType::REALNUMBER
+                   || m_nAxisType == chart2::AxisType::PERCENT
+                   || m_nAxisType == chart2::AxisType::DATE;
+    bool bDateAxis = m_nAxisType == chart2::AxisType::DATE;
 
     m_pBxType->Show(m_bAllowDateAxis);
 
     m_pCbxLogarithm->Show( bValueAxis && !bDateAxis );
 
     m_pBxMinMax->Show(bValueAxis);
-    m_pBxMain->Show( bValueAxis );
-    m_pBxMinor->Show( bValueAxis );
-    m_pBxOrigin->Show( m_bShowAxisOrigin && bValueAxis );
+
+    m_pTxtMain->Show( bValueAxis );
+    m_pCbxAutoStepMain->Show( bValueAxis );
 
     m_pTxtHelpCount->Show( bValueAxis && !bDateAxis );
     m_pTxtHelp->Show( bDateAxis );
+    m_pMtStepHelp->Show( bValueAxis );
+    m_pCbxAutoStepHelp->Show( bValueAxis );
 
+    m_pBxOrigin->Show( m_bShowAxisOrigin && bValueAxis );
     m_pBxResolution->Show( bDateAxis );
 
     bool bWasDateAxis = m_pMt_MainDateStep->IsVisible();
@@ -173,6 +197,7 @@ void ScaleTabPage::EnableControls()
         else
             m_pMt_MainDateStep->SetValue( static_cast<sal_Int32>(m_pFmtFldStepMain->GetValue()) );
     }
+
     m_pFmtFldStepMain->Show( bValueAxis && !bDateAxis );
     m_pMt_MainDateStep->Show( bDateAxis );
 
@@ -187,8 +212,9 @@ void ScaleTabPage::EnableControls()
     EnableValueHdl(m_pCbx_AutoTimeResolution);
 }
 
-IMPL_LINK( ScaleTabPage, EnableValueHdl, CheckBox *, pCbx )
+IMPL_LINK( ScaleTabPage, EnableValueHdl, Button *, pButton, void )
 {
+    CheckBox * pCbx = static_cast<CheckBox*>(pButton);
     bool bEnable = pCbx && !pCbx->IsChecked() && pCbx->IsEnabled();
     if (pCbx == m_pCbxAutoMin)
     {
@@ -217,7 +243,6 @@ IMPL_LINK( ScaleTabPage, EnableValueHdl, CheckBox *, pCbx )
     {
         m_pFmtFldOrigin->Enable( bEnable );
     }
-    return 0;
 }
 
 enum AxisTypeListBoxEntry
@@ -227,79 +252,78 @@ enum AxisTypeListBoxEntry
     TYPE_DATE=2
 };
 
-IMPL_LINK_NOARG(ScaleTabPage, SelectAxisTypeHdl)
+IMPL_LINK_NOARG(ScaleTabPage, SelectAxisTypeHdl, ListBox&, void)
 {
-    sal_uInt16 nPos = m_pLB_AxisType->GetSelectEntryPos();
+    const sal_Int32 nPos = m_pLB_AxisType->GetSelectedEntryPos();
     if( nPos==TYPE_DATE )
         m_nAxisType = chart2::AxisType::DATE;
     else
         m_nAxisType = chart2::AxisType::CATEGORY;
-    if( chart2::AxisType::DATE == m_nAxisType )
+    if( m_nAxisType == chart2::AxisType::DATE )
         m_pCbxLogarithm->Check(false);
     EnableControls();
     SetNumFormat();
-    return 0;
 }
 
-SfxTabPage* ScaleTabPage::Create(Window* pWindow,const SfxItemSet& rOutAttrs)
+VclPtr<SfxTabPage> ScaleTabPage::Create(vcl::Window* pWindow,const SfxItemSet* rOutAttrs)
 {
-    return new ScaleTabPage(pWindow, rOutAttrs);
+    return VclPtr<ScaleTabPage>::Create(pWindow, *rOutAttrs);
 }
 
-sal_Bool ScaleTabPage::FillItemSet(SfxItemSet& rOutAttrs)
+bool ScaleTabPage::FillItemSet(SfxItemSet* rOutAttrs)
 {
     OSL_PRECOND( pNumFormatter, "No NumberFormatter available" );
 
-    rOutAttrs.Put(SfxInt32Item(SCHATTR_AXISTYPE, m_nAxisType));
+    rOutAttrs->Put(SfxInt32Item(SCHATTR_AXISTYPE, m_nAxisType));
     if(m_bAllowDateAxis)
-        rOutAttrs.Put(SfxBoolItem(SCHATTR_AXIS_AUTO_DATEAXIS, TYPE_AUTO==m_pLB_AxisType->GetSelectEntryPos()));
+        rOutAttrs->Put(SfxBoolItem(SCHATTR_AXIS_AUTO_DATEAXIS, m_pLB_AxisType->GetSelectedEntryPos()==TYPE_AUTO));
 
     bool bAutoScale = false;
     if( m_nAxisType==chart2::AxisType::CATEGORY )
         bAutoScale = true;//reset scaling for category charts
 
-    rOutAttrs.Put(SfxBoolItem(SCHATTR_AXIS_AUTO_MIN      ,bAutoScale || m_pCbxAutoMin->IsChecked()));
-    rOutAttrs.Put(SfxBoolItem(SCHATTR_AXIS_AUTO_MAX      ,bAutoScale || m_pCbxAutoMax->IsChecked()));
-    rOutAttrs.Put(SfxBoolItem(SCHATTR_AXIS_AUTO_STEP_HELP,bAutoScale || m_pCbxAutoStepHelp->IsChecked()));
-    rOutAttrs.Put(SfxBoolItem(SCHATTR_AXIS_AUTO_ORIGIN   ,bAutoScale || m_pCbxAutoOrigin->IsChecked()));
-    rOutAttrs.Put(SfxBoolItem(SCHATTR_AXIS_LOGARITHM     ,m_pCbxLogarithm->IsChecked()));
-    rOutAttrs.Put(SfxBoolItem(SCHATTR_AXIS_REVERSE       ,m_pCbxReverse->IsChecked()));
-    rOutAttrs.Put(SvxDoubleItem(fMax     , SCHATTR_AXIS_MAX));
-    rOutAttrs.Put(SvxDoubleItem(fMin     , SCHATTR_AXIS_MIN));
-    rOutAttrs.Put(SfxInt32Item(SCHATTR_AXIS_STEP_HELP, nStepHelp));
-    rOutAttrs.Put(SvxDoubleItem(fOrigin  , SCHATTR_AXIS_ORIGIN));
+    rOutAttrs->Put(SfxBoolItem(SCHATTR_AXIS_AUTO_MIN      ,bAutoScale || m_pCbxAutoMin->IsChecked()));
+    rOutAttrs->Put(SfxBoolItem(SCHATTR_AXIS_AUTO_MAX      ,bAutoScale || m_pCbxAutoMax->IsChecked()));
+    rOutAttrs->Put(SfxBoolItem(SCHATTR_AXIS_AUTO_STEP_HELP,bAutoScale || m_pCbxAutoStepHelp->IsChecked()));
+    rOutAttrs->Put(SfxBoolItem(SCHATTR_AXIS_AUTO_ORIGIN   ,bAutoScale || m_pCbxAutoOrigin->IsChecked()));
+    rOutAttrs->Put(SfxBoolItem(SCHATTR_AXIS_LOGARITHM     ,m_pCbxLogarithm->IsChecked()));
+    rOutAttrs->Put(SfxBoolItem(SCHATTR_AXIS_REVERSE       ,m_pCbxReverse->IsChecked()));
+    rOutAttrs->Put(SvxDoubleItem(fMax     , SCHATTR_AXIS_MAX));
+    rOutAttrs->Put(SvxDoubleItem(fMin     , SCHATTR_AXIS_MIN));
+    rOutAttrs->Put(SfxInt32Item(SCHATTR_AXIS_STEP_HELP, nStepHelp));
+    rOutAttrs->Put(SvxDoubleItem(fOrigin  , SCHATTR_AXIS_ORIGIN));
 
-    rOutAttrs.Put(SfxBoolItem(SCHATTR_AXIS_AUTO_STEP_MAIN,bAutoScale || m_pCbxAutoStepMain->IsChecked()));
-    rOutAttrs.Put(SvxDoubleItem(fStepMain,SCHATTR_AXIS_STEP_MAIN));
+    rOutAttrs->Put(SfxBoolItem(SCHATTR_AXIS_AUTO_STEP_MAIN,bAutoScale || m_pCbxAutoStepMain->IsChecked()));
+    rOutAttrs->Put(SvxDoubleItem(fStepMain,SCHATTR_AXIS_STEP_MAIN));
 
-    rOutAttrs.Put(SfxBoolItem(SCHATTR_AXIS_AUTO_TIME_RESOLUTION,bAutoScale || m_pCbx_AutoTimeResolution->IsChecked()));
-    rOutAttrs.Put(SfxInt32Item(SCHATTR_AXIS_TIME_RESOLUTION,m_nTimeResolution));
+    rOutAttrs->Put(SfxBoolItem(SCHATTR_AXIS_AUTO_TIME_RESOLUTION,bAutoScale || m_pCbx_AutoTimeResolution->IsChecked()));
+    rOutAttrs->Put(SfxInt32Item(SCHATTR_AXIS_TIME_RESOLUTION,m_nTimeResolution));
 
-    rOutAttrs.Put(SfxInt32Item(SCHATTR_AXIS_MAIN_TIME_UNIT,m_nMainTimeUnit));
-    rOutAttrs.Put(SfxInt32Item(SCHATTR_AXIS_HELP_TIME_UNIT,m_nHelpTimeUnit));
+    rOutAttrs->Put(SfxInt32Item(SCHATTR_AXIS_MAIN_TIME_UNIT,m_nMainTimeUnit));
+    rOutAttrs->Put(SfxInt32Item(SCHATTR_AXIS_HELP_TIME_UNIT,m_nHelpTimeUnit));
 
-    return sal_True;
+    return true;
 }
 
-void ScaleTabPage::Reset(const SfxItemSet& rInAttrs)
+void ScaleTabPage::Reset(const SfxItemSet* rInAttrs)
 {
     OSL_PRECOND( pNumFormatter, "No NumberFormatter available" );
     if(!pNumFormatter)
         return;
 
-    const SfxPoolItem *pPoolItem = NULL;
-    if (rInAttrs.GetItemState(SCHATTR_AXIS_ALLOW_DATEAXIS, sal_True, &pPoolItem) == SFX_ITEM_SET)
-        m_bAllowDateAxis = (bool) ((const SfxBoolItem*)pPoolItem)->GetValue();
+    const SfxPoolItem *pPoolItem = nullptr;
+    if (rInAttrs->GetItemState(SCHATTR_AXIS_ALLOW_DATEAXIS, true, &pPoolItem) == SfxItemState::SET)
+        m_bAllowDateAxis = static_cast<const SfxBoolItem*>(pPoolItem)->GetValue();
     m_nAxisType=chart2::AxisType::REALNUMBER;
-    if (rInAttrs.GetItemState(SCHATTR_AXISTYPE, sal_True, &pPoolItem) == SFX_ITEM_SET)
-        m_nAxisType = (int) ((const SfxInt32Item*)pPoolItem)->GetValue();
+    if (rInAttrs->GetItemState(SCHATTR_AXISTYPE, true, &pPoolItem) == SfxItemState::SET)
+        m_nAxisType = (int) static_cast<const SfxInt32Item*>(pPoolItem)->GetValue();
     if( m_nAxisType==chart2::AxisType::DATE && !m_bAllowDateAxis )
         m_nAxisType=chart2::AxisType::CATEGORY;
     if( m_bAllowDateAxis )
     {
         bool bAutoDateAxis = false;
-        if (rInAttrs.GetItemState(SCHATTR_AXIS_AUTO_DATEAXIS, sal_True, &pPoolItem) == SFX_ITEM_SET)
-            bAutoDateAxis = (bool) ((const SfxBoolItem*)pPoolItem)->GetValue();
+        if (rInAttrs->GetItemState(SCHATTR_AXIS_AUTO_DATEAXIS, true, &pPoolItem) == SfxItemState::SET)
+            bAutoDateAxis = static_cast<const SfxBoolItem*>(pPoolItem)->GetValue();
 
         sal_uInt16 nPos = 0;
         if( m_nAxisType==chart2::AxisType::DATE )
@@ -311,75 +335,75 @@ void ScaleTabPage::Reset(const SfxItemSet& rInAttrs)
         m_pLB_AxisType->SelectEntryPos( nPos );
     }
 
-    m_pCbxAutoMin->Check( true );
-    m_pCbxAutoMax->Check( true );
-    m_pCbxAutoStepMain->Check( true );
-    m_pCbxAutoStepHelp->Check( true );
-    m_pCbxAutoOrigin->Check( true );
-    m_pCbx_AutoTimeResolution->Check( true );
+    m_pCbxAutoMin->Check();
+    m_pCbxAutoMax->Check();
+    m_pCbxAutoStepMain->Check();
+    m_pCbxAutoStepHelp->Check();
+    m_pCbxAutoOrigin->Check();
+    m_pCbx_AutoTimeResolution->Check();
 
-    if (rInAttrs.GetItemState(SCHATTR_AXIS_AUTO_MIN,sal_True,&pPoolItem) == SFX_ITEM_SET)
-        m_pCbxAutoMin->Check(((const SfxBoolItem*)pPoolItem)->GetValue());
+    if (rInAttrs->GetItemState(SCHATTR_AXIS_AUTO_MIN,true,&pPoolItem) == SfxItemState::SET)
+        m_pCbxAutoMin->Check(static_cast<const SfxBoolItem*>(pPoolItem)->GetValue());
 
-    if (rInAttrs.GetItemState(SCHATTR_AXIS_MIN,sal_True, &pPoolItem) == SFX_ITEM_SET)
+    if (rInAttrs->GetItemState(SCHATTR_AXIS_MIN,true, &pPoolItem) == SfxItemState::SET)
     {
-        fMin = ((const SvxDoubleItem*)pPoolItem)->GetValue();
+        fMin = static_cast<const SvxDoubleItem*>(pPoolItem)->GetValue();
         lcl_setValue( *m_pFmtFldMin, fMin );
     }
 
-    if (rInAttrs.GetItemState(SCHATTR_AXIS_AUTO_MAX,sal_True, &pPoolItem) == SFX_ITEM_SET)
-        m_pCbxAutoMax->Check(((const SfxBoolItem*)pPoolItem)->GetValue());
+    if (rInAttrs->GetItemState(SCHATTR_AXIS_AUTO_MAX,true, &pPoolItem) == SfxItemState::SET)
+        m_pCbxAutoMax->Check(static_cast<const SfxBoolItem*>(pPoolItem)->GetValue());
 
-    if (rInAttrs.GetItemState(SCHATTR_AXIS_MAX,sal_True, &pPoolItem) == SFX_ITEM_SET)
+    if (rInAttrs->GetItemState(SCHATTR_AXIS_MAX,true, &pPoolItem) == SfxItemState::SET)
     {
-        fMax = ((const SvxDoubleItem*)pPoolItem)->GetValue();
+        fMax = static_cast<const SvxDoubleItem*>(pPoolItem)->GetValue();
         lcl_setValue( *m_pFmtFldMax, fMax );
     }
 
-    if (rInAttrs.GetItemState(SCHATTR_AXIS_AUTO_STEP_MAIN,sal_True, &pPoolItem) == SFX_ITEM_SET)
-        m_pCbxAutoStepMain->Check(((const SfxBoolItem*)pPoolItem)->GetValue());
+    if (rInAttrs->GetItemState(SCHATTR_AXIS_AUTO_STEP_MAIN,true, &pPoolItem) == SfxItemState::SET)
+        m_pCbxAutoStepMain->Check(static_cast<const SfxBoolItem*>(pPoolItem)->GetValue());
 
-    if (rInAttrs.GetItemState(SCHATTR_AXIS_STEP_MAIN,sal_True, &pPoolItem) == SFX_ITEM_SET)
+    if (rInAttrs->GetItemState(SCHATTR_AXIS_STEP_MAIN,true, &pPoolItem) == SfxItemState::SET)
     {
-        fStepMain = ((const SvxDoubleItem*)pPoolItem)->GetValue();
+        fStepMain = static_cast<const SvxDoubleItem*>(pPoolItem)->GetValue();
         lcl_setValue( *m_pFmtFldStepMain, fStepMain );
         m_pMt_MainDateStep->SetValue( static_cast<sal_Int32>(fStepMain) );
     }
-    if (rInAttrs.GetItemState(SCHATTR_AXIS_AUTO_STEP_HELP,sal_True, &pPoolItem) == SFX_ITEM_SET)
-        m_pCbxAutoStepHelp->Check(((const SfxBoolItem*)pPoolItem)->GetValue());
-    if (rInAttrs.GetItemState(SCHATTR_AXIS_LOGARITHM,sal_True, &pPoolItem) == SFX_ITEM_SET)
-        m_pCbxLogarithm->Check(((const SfxBoolItem*)pPoolItem)->GetValue());
-    if (rInAttrs.GetItemState(SCHATTR_AXIS_REVERSE,sal_True, &pPoolItem) == SFX_ITEM_SET)
-        m_pCbxReverse->Check(((const SfxBoolItem*)pPoolItem)->GetValue());
-    if (rInAttrs.GetItemState(SCHATTR_AXIS_STEP_HELP,sal_True, &pPoolItem) == SFX_ITEM_SET)
+    if (rInAttrs->GetItemState(SCHATTR_AXIS_AUTO_STEP_HELP,true, &pPoolItem) == SfxItemState::SET)
+        m_pCbxAutoStepHelp->Check(static_cast<const SfxBoolItem*>(pPoolItem)->GetValue());
+    if (rInAttrs->GetItemState(SCHATTR_AXIS_LOGARITHM,true, &pPoolItem) == SfxItemState::SET)
+        m_pCbxLogarithm->Check(static_cast<const SfxBoolItem*>(pPoolItem)->GetValue());
+    if (rInAttrs->GetItemState(SCHATTR_AXIS_REVERSE,true, &pPoolItem) == SfxItemState::SET)
+        m_pCbxReverse->Check(static_cast<const SfxBoolItem*>(pPoolItem)->GetValue());
+    if (rInAttrs->GetItemState(SCHATTR_AXIS_STEP_HELP,true, &pPoolItem) == SfxItemState::SET)
     {
-        nStepHelp = ((const SfxInt32Item*)pPoolItem)->GetValue();
+        nStepHelp = static_cast<const SfxInt32Item*>(pPoolItem)->GetValue();
         m_pMtStepHelp->SetValue( nStepHelp );
     }
-    if (rInAttrs.GetItemState(SCHATTR_AXIS_AUTO_ORIGIN,sal_True, &pPoolItem) == SFX_ITEM_SET)
-        m_pCbxAutoOrigin->Check(((const SfxBoolItem*)pPoolItem)->GetValue());
-    if (rInAttrs.GetItemState(SCHATTR_AXIS_ORIGIN,sal_True, &pPoolItem) == SFX_ITEM_SET)
+    if (rInAttrs->GetItemState(SCHATTR_AXIS_AUTO_ORIGIN,true, &pPoolItem) == SfxItemState::SET)
+        m_pCbxAutoOrigin->Check(static_cast<const SfxBoolItem*>(pPoolItem)->GetValue());
+    if (rInAttrs->GetItemState(SCHATTR_AXIS_ORIGIN,true, &pPoolItem) == SfxItemState::SET)
     {
-        fOrigin = ((const SvxDoubleItem*)pPoolItem)->GetValue();
+        fOrigin = static_cast<const SvxDoubleItem*>(pPoolItem)->GetValue();
         lcl_setValue( *m_pFmtFldOrigin, fOrigin );
     }
 
-    if (rInAttrs.GetItemState(SCHATTR_AXIS_AUTO_TIME_RESOLUTION,sal_True, &pPoolItem) == SFX_ITEM_SET)
-        m_pCbx_AutoTimeResolution->Check(((const SfxBoolItem*)pPoolItem)->GetValue());
-    if (rInAttrs.GetItemState(SCHATTR_AXIS_TIME_RESOLUTION,sal_True, &pPoolItem) == SFX_ITEM_SET)
+    if (rInAttrs->GetItemState(SCHATTR_AXIS_AUTO_TIME_RESOLUTION,true, &pPoolItem) == SfxItemState::SET)
+        m_pCbx_AutoTimeResolution->Check(static_cast<const SfxBoolItem*>(pPoolItem)->GetValue());
+    if (rInAttrs->GetItemState(SCHATTR_AXIS_TIME_RESOLUTION,true, &pPoolItem) == SfxItemState::SET)
     {
-        m_nTimeResolution = ((const SfxInt32Item*)pPoolItem)->GetValue();
+        m_nTimeResolution = static_cast<const SfxInt32Item*>(pPoolItem)->GetValue();
         m_pLB_TimeResolution->SelectEntryPos( m_nTimeResolution );
     }
 
-    if (rInAttrs.GetItemState(SCHATTR_AXIS_MAIN_TIME_UNIT,sal_True, &pPoolItem) == SFX_ITEM_SET)
+    if (rInAttrs->GetItemState(SCHATTR_AXIS_MAIN_TIME_UNIT,true, &pPoolItem) == SfxItemState::SET)
     {
-        m_nMainTimeUnit = ((const SfxInt32Item*)pPoolItem)->GetValue();
+        m_nMainTimeUnit = static_cast<const SfxInt32Item*>(pPoolItem)->GetValue();
         m_pLB_MainTimeUnit->SelectEntryPos( m_nMainTimeUnit );
     }
-    if (rInAttrs.GetItemState(SCHATTR_AXIS_HELP_TIME_UNIT,sal_True, &pPoolItem) == SFX_ITEM_SET)
+    if (rInAttrs->GetItemState(SCHATTR_AXIS_HELP_TIME_UNIT,true, &pPoolItem) == SfxItemState::SET)
     {
-        m_nHelpTimeUnit = ((const SfxInt32Item*)pPoolItem)->GetValue();
+        m_nHelpTimeUnit = static_cast<const SfxInt32Item*>(pPoolItem)->GetValue();
         m_pLB_HelpTimeUnit->SelectEntryPos( m_nHelpTimeUnit );
     }
 
@@ -387,26 +411,26 @@ void ScaleTabPage::Reset(const SfxItemSet& rInAttrs)
     SetNumFormat();
 }
 
-int ScaleTabPage::DeactivatePage(SfxItemSet* pItemSet)
+DeactivateRC ScaleTabPage::DeactivatePage(SfxItemSet* pItemSet)
 {
     if( !pNumFormatter )
     {
         OSL_FAIL( "No NumberFormatter available" );
-        return LEAVE_PAGE;
+        return DeactivateRC::LeavePage;
     }
 
-    bool bDateAxis = chart2::AxisType::DATE == m_nAxisType;
+    bool bDateAxis = m_nAxisType == chart2::AxisType::DATE;
 
     sal_uInt32 nMinMaxOriginFmt = m_pFmtFldMax->GetFormatKey();
-    if ((pNumFormatter->GetType(nMinMaxOriginFmt) &~ NUMBERFORMAT_DEFINED) == NUMBERFORMAT_TEXT)
+    if (pNumFormatter->GetType(nMinMaxOriginFmt) == css::util::NumberFormat::TEXT)
         nMinMaxOriginFmt = 0;
     // numberformat_text cause numbers to fail being numbers...  Shouldn't happen, but can.
     sal_uInt32 nStepFmt = m_pFmtFldStepMain->GetFormatKey();
-    if ((pNumFormatter->GetType(nStepFmt) &~NUMBERFORMAT_DEFINED) == NUMBERFORMAT_TEXT)
+    if (pNumFormatter->GetType(nStepFmt) == css::util::NumberFormat::TEXT)
         nStepFmt = 0;
 
-    Control* pControl = NULL;
-    sal_uInt16 nErrStrId = 0;
+    Control* pControl = nullptr;
+    const char* pErrStrId = nullptr;
     double fDummy;
 
     fMax = m_pFmtFldMax->GetValue();
@@ -414,11 +438,11 @@ int ScaleTabPage::DeactivatePage(SfxItemSet* pItemSet)
     fOrigin = m_pFmtFldOrigin->GetValue();
     fStepMain = bDateAxis ? m_pMt_MainDateStep->GetValue() : m_pFmtFldStepMain->GetValue();
     nStepHelp = static_cast< sal_Int32 >( m_pMtStepHelp->GetValue());
-    m_nTimeResolution = m_pLB_TimeResolution->GetSelectEntryPos();
-    m_nMainTimeUnit = m_pLB_MainTimeUnit->GetSelectEntryPos();
-    m_nHelpTimeUnit = m_pLB_HelpTimeUnit->GetSelectEntryPos();
+    m_nTimeResolution = m_pLB_TimeResolution->GetSelectedEntryPos();
+    m_nMainTimeUnit = m_pLB_MainTimeUnit->GetSelectedEntryPos();
+    m_nHelpTimeUnit = m_pLB_HelpTimeUnit->GetSelectedEntryPos();
 
-    if( chart2::AxisType::REALNUMBER != m_nAxisType )
+    if( m_nAxisType != chart2::AxisType::REALNUMBER )
         m_pCbxLogarithm->Show( false );
 
     //check which entries need user action
@@ -428,7 +452,7 @@ int ScaleTabPage::DeactivatePage(SfxItemSet* pItemSet)
              || ( !m_pCbxAutoMax->IsChecked() && fMax <= 0.0 ) ) )
     {
         pControl = m_pFmtFldMin;
-        nErrStrId = STR_BAD_LOGARITHM;
+        pErrStrId = STR_BAD_LOGARITHM;
     }
     // check for entries that cannot be parsed for the current number format
     else if ( m_pFmtFldMin->IsModified()
@@ -436,38 +460,38 @@ int ScaleTabPage::DeactivatePage(SfxItemSet* pItemSet)
               && !pNumFormatter->IsNumberFormat( m_pFmtFldMin->GetText(), nMinMaxOriginFmt, fDummy))
     {
         pControl = m_pFmtFldMin;
-        nErrStrId = STR_INVALID_NUMBER;
+        pErrStrId = STR_INVALID_NUMBER;
     }
     else if ( m_pFmtFldMax->IsModified()
               && !m_pCbxAutoMax->IsChecked()
               && !pNumFormatter->IsNumberFormat( m_pFmtFldMax->GetText(), nMinMaxOriginFmt, fDummy))
     {
         pControl = m_pFmtFldMax;
-        nErrStrId = STR_INVALID_NUMBER;
+        pErrStrId = STR_INVALID_NUMBER;
     }
     else if ( !bDateAxis && m_pFmtFldStepMain->IsModified()
               && !m_pCbxAutoStepMain->IsChecked()
               && !pNumFormatter->IsNumberFormat( m_pFmtFldStepMain->GetText(), nStepFmt, fDummy))
     {
         pControl = m_pFmtFldStepMain;
-        nErrStrId = STR_INVALID_NUMBER;
+        pErrStrId = STR_INVALID_NUMBER;
     }
     else if (m_pFmtFldOrigin->IsModified() && !m_pCbxAutoOrigin->IsChecked() &&
              !pNumFormatter->IsNumberFormat( m_pFmtFldOrigin->GetText(), nMinMaxOriginFmt, fDummy))
     {
         pControl = m_pFmtFldOrigin;
-        nErrStrId = STR_INVALID_NUMBER;
+        pErrStrId = STR_INVALID_NUMBER;
     }
     else if (!m_pCbxAutoStepMain->IsChecked() && fStepMain <= 0.0)
     {
         pControl = m_pFmtFldStepMain;
-        nErrStrId = STR_STEP_GT_ZERO;
+        pErrStrId = STR_STEP_GT_ZERO;
     }
     else if (!m_pCbxAutoMax->IsChecked() && !m_pCbxAutoMin->IsChecked() &&
              fMin >= fMax)
     {
         pControl = m_pFmtFldMin;
-        nErrStrId = STR_MIN_GREATER_MAX;
+        pErrStrId = STR_MIN_GREATER_MAX;
     }
     else if( bDateAxis )
     {
@@ -476,15 +500,15 @@ int ScaleTabPage::DeactivatePage(SfxItemSet* pItemSet)
             if( m_nHelpTimeUnit > m_nMainTimeUnit )
             {
                 pControl = m_pLB_MainTimeUnit;
-                nErrStrId = STR_INVALID_INTERVALS;
+                pErrStrId = STR_INVALID_INTERVALS;
             }
             else if( m_nHelpTimeUnit == m_nMainTimeUnit && nStepHelp > fStepMain )
             {
                 pControl = m_pLB_MainTimeUnit;
-                nErrStrId = STR_INVALID_INTERVALS;
+                pErrStrId = STR_INVALID_INTERVALS;
             }
         }
-        if( !nErrStrId && !m_pCbx_AutoTimeResolution->IsChecked() )
+        if( !pErrStrId && !m_pCbx_AutoTimeResolution->IsChecked() )
         {
             if( (!m_pCbxAutoStepMain->IsChecked() && m_nTimeResolution > m_nMainTimeUnit )
                 ||
@@ -492,18 +516,18 @@ int ScaleTabPage::DeactivatePage(SfxItemSet* pItemSet)
                 )
             {
                 pControl = m_pLB_TimeResolution;
-                nErrStrId = STR_INVALID_TIME_UNIT;
+                pErrStrId = STR_INVALID_TIME_UNIT;
             }
         }
     }
 
-    if( ShowWarning( nErrStrId, pControl ) )
-        return KEEP_PAGE;
+    if( ShowWarning( pErrStrId, pControl ) )
+        return DeactivateRC::KeepPage;
 
     if( pItemSet )
-        FillItemSet( *pItemSet );
+        FillItemSet( pItemSet );
 
-    return LEAVE_PAGE;
+    return DeactivateRC::LeavePage;
 }
 
 void ScaleTabPage::SetNumFormatter( SvNumberFormatter* pFormatter )
@@ -528,11 +552,11 @@ void ScaleTabPage::SetNumFormatter( SvNumberFormatter* pFormatter )
 
 void ScaleTabPage::SetNumFormat()
 {
-    const SfxPoolItem *pPoolItem = NULL;
+    const SfxPoolItem *pPoolItem = nullptr;
 
-    if( GetItemSet().GetItemState( SID_ATTR_NUMBERFORMAT_VALUE, sal_True, &pPoolItem ) == SFX_ITEM_SET )
+    if( GetItemSet().GetItemState( SID_ATTR_NUMBERFORMAT_VALUE, true, &pPoolItem ) == SfxItemState::SET )
     {
-        sal_uLong nFmt = (sal_uLong)((const SfxInt32Item*)pPoolItem)->GetValue();
+        sal_uLong nFmt = (sal_uLong)static_cast<const SfxInt32Item*>(pPoolItem)->GetValue();
 
         m_pFmtFldMax->SetFormatKey( nFmt );
         m_pFmtFldMin->SetFormatKey( nFmt );
@@ -541,7 +565,7 @@ void ScaleTabPage::SetNumFormat()
         if( pNumFormatter )
         {
             short eType = pNumFormatter->GetType( nFmt );
-            if( eType == NUMBERFORMAT_DATE )
+            if( eType == css::util::NumberFormat::DATE )
             {
                 // for intervals use standard format for dates (so you can enter a number of days)
                 const SvNumberformat* pFormat = pNumFormatter->GetEntry( nFmt );
@@ -550,23 +574,23 @@ void ScaleTabPage::SetNumFormat()
                 else
                     nFmt = pNumFormatter->GetStandardIndex();
             }
-            else if( eType == NUMBERFORMAT_DATETIME )
+            else if( eType == css::util::NumberFormat::DATETIME )
             {
                 // for intervals use time format for date times
                 const SvNumberformat* pFormat = pNumFormatter->GetEntry( nFmt );
                 if( pFormat )
-                    nFmt = pNumFormatter->GetStandardFormat( NUMBERFORMAT_TIME, pFormat->GetLanguage() );
+                    nFmt = pNumFormatter->GetStandardFormat( css::util::NumberFormat::TIME, pFormat->GetLanguage() );
                 else
-                    nFmt = pNumFormatter->GetStandardFormat( NUMBERFORMAT_TIME );
+                    nFmt = pNumFormatter->GetStandardFormat( css::util::NumberFormat::TIME );
             }
 
-            if( chart2::AxisType::DATE == m_nAxisType && ( eType != NUMBERFORMAT_DATE && eType != NUMBERFORMAT_DATETIME) )
+            if( m_nAxisType == chart2::AxisType::DATE && ( eType != css::util::NumberFormat::DATE && eType != css::util::NumberFormat::DATETIME) )
             {
                 const SvNumberformat* pFormat = pNumFormatter->GetEntry( nFmt );
                 if( pFormat )
-                    nFmt = pNumFormatter->GetStandardFormat( NUMBERFORMAT_DATE, pFormat->GetLanguage() );
+                    nFmt = pNumFormatter->GetStandardFormat( css::util::NumberFormat::DATE, pFormat->GetLanguage() );
                 else
-                    nFmt = pNumFormatter->GetStandardFormat( NUMBERFORMAT_DATE );
+                    nFmt = pNumFormatter->GetStandardFormat( css::util::NumberFormat::DATE );
 
                 m_pFmtFldMax->SetFormatKey( nFmt );
                 m_pFmtFldMin->SetFormatKey( nFmt );
@@ -585,12 +609,12 @@ void ScaleTabPage::ShowAxisOrigin( bool bShowOrigin )
         m_bShowAxisOrigin = true;
 }
 
-bool ScaleTabPage::ShowWarning( sal_uInt16 nResIdMessage, Control* pControl /* = NULL */ )
+bool ScaleTabPage::ShowWarning(const char* pResIdMessage, Control* pControl /* = NULL */ )
 {
-    if( nResIdMessage == 0 )
+    if (pResIdMessage == nullptr)
         return false;
 
-    WarningBox( this, WinBits( WB_OK ), SCH_RESSTR( nResIdMessage ) ).Execute();
+    ScopedVclPtrInstance<WarningBox>(this, MessBoxStyle::Ok, SchResId(pResIdMessage))->Execute();
     if( pControl )
     {
         pControl->GrabFocus();
@@ -611,8 +635,15 @@ void ScaleTabPage::HideAllControls()
     m_pBxType->Hide();
     m_pCbxLogarithm->Hide();
     m_pBxMinMax->Hide();
-    m_pBxMain->Hide();
-    m_pBxMinor->Hide();
+    m_pTxtMain->Hide();
+    m_pFmtFldStepMain->Hide();
+    m_pMt_MainDateStep->Hide();
+    m_pLB_MainTimeUnit->Hide();
+    m_pCbxAutoStepMain->Hide();
+    m_pTxtHelpCount->Hide();
+    m_pTxtHelp->Hide();
+    m_pMtStepHelp->Hide();
+    m_pCbxAutoStepHelp->Hide();
     m_pBxOrigin->Hide();
     m_pBxResolution->Hide();
 }
