@@ -17,12 +17,11 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "LegendItemConverter.hxx"
+#include <LegendItemConverter.hxx>
 #include "SchWhichPairs.hxx"
-#include "macros.hxx"
-#include "ItemPropertyMap.hxx"
-#include "GraphicPropertyItemConverter.hxx"
-#include "CharacterPropertyItemConverter.hxx"
+#include <ItemPropertyMap.hxx>
+#include <GraphicPropertyItemConverter.hxx>
+#include <CharacterPropertyItemConverter.hxx>
 #include <com/sun/star/chart2/XLegend.hpp>
 #include <com/sun/star/chart2/LegendPosition.hpp>
 #include <com/sun/star/chart/ChartLegendExpansion.hpp>
@@ -32,8 +31,7 @@
 
 #include <functional>
 #include <algorithm>
-
-#include <boost/checked_delete.hpp>
+#include <memory>
 
 using namespace ::com::sun::star;
 
@@ -43,8 +41,7 @@ namespace wrapper
 {
 
 LegendItemConverter::LegendItemConverter(
-    const ::com::sun::star::uno::Reference<
-    ::com::sun::star::beans::XPropertySet > & rPropertySet,
+    const css::uno::Reference< css::beans::XPropertySet > & rPropertySet,
     SfxItemPool& rItemPool,
     SdrModel& rDrawModel,
     const uno::Reference< lang::XMultiServiceFactory > & xNamedPropertyContainerFactory,
@@ -53,7 +50,7 @@ LegendItemConverter::LegendItemConverter(
 {
     m_aConverters.push_back( new GraphicPropertyItemConverter(
                                  rPropertySet, rItemPool, rDrawModel, xNamedPropertyContainerFactory,
-                                 GraphicPropertyItemConverter::LINE_AND_FILL_PROPERTIES ));
+                                 GraphicObjectType::LineAndFillProperties ));
     m_aConverters.push_back( new CharacterPropertyItemConverter(
                                  rPropertySet, rItemPool, pRefSize,
                                  "ReferencePageSize" ));
@@ -61,13 +58,13 @@ LegendItemConverter::LegendItemConverter(
 
 LegendItemConverter::~LegendItemConverter()
 {
-    ::std::for_each( m_aConverters.begin(), m_aConverters.end(), boost::checked_deleter<ItemConverter>());
+    std::for_each( m_aConverters.begin(), m_aConverters.end(), std::default_delete<ItemConverter>());
 }
 
 void LegendItemConverter::FillItemSet( SfxItemSet & rOutItemSet ) const
 {
-    ::std::for_each( m_aConverters.begin(), m_aConverters.end(),
-                     FillItemSetFunc( rOutItemSet ));
+    for( const auto& pConv : m_aConverters )
+        pConv->FillItemSet( rOutItemSet );
 
     // own items
     ItemConverter::FillItemSet( rOutItemSet );
@@ -77,8 +74,8 @@ bool LegendItemConverter::ApplyItemSet( const SfxItemSet & rItemSet )
 {
     bool bResult = false;
 
-    ::std::for_each( m_aConverters.begin(), m_aConverters.end(),
-                     ApplyItemSetFunc( rItemSet, bResult ));
+    for( const auto& pConv : m_aConverters )
+        bResult = pConv->ApplyItemSet( rItemSet ) || bResult;
 
     // own items
     return ItemConverter::ApplyItemSet( rItemSet ) || bResult;
@@ -97,7 +94,6 @@ bool LegendItemConverter::GetItemProperty( tWhichIdType /*nWhichId*/, tPropertyN
 }
 
 bool LegendItemConverter::ApplySpecialItem( sal_uInt16 nWhichId, const SfxItemSet& rInItemSet )
-    throw( uno::Exception )
 {
     bool bChanged = false;
 
@@ -105,7 +101,7 @@ bool LegendItemConverter::ApplySpecialItem( sal_uInt16 nWhichId, const SfxItemSe
     {
         case SCHATTR_LEGEND_SHOW:
         {
-            const SfxPoolItem* pPoolItem = NULL;
+            const SfxPoolItem* pPoolItem = nullptr;
             if( rInItemSet.GetItemState( SCHATTR_LEGEND_SHOW, true, &pPoolItem ) == SfxItemState::SET )
             {
                 bool bShow = static_cast< const SfxBoolItem * >( pPoolItem )->GetValue();
@@ -113,7 +109,7 @@ bool LegendItemConverter::ApplySpecialItem( sal_uInt16 nWhichId, const SfxItemSe
                 if( ! (GetPropertySet()->getPropertyValue( "Show" ) >>= bWasShown) ||
                     ( bWasShown != bShow ))
                 {
-                    GetPropertySet()->setPropertyValue( "Show" , uno::makeAny( bShow ));
+                    GetPropertySet()->setPropertyValue( "Show" , uno::Any( bShow ));
                     bChanged = true;
                 }
             }
@@ -122,21 +118,21 @@ bool LegendItemConverter::ApplySpecialItem( sal_uInt16 nWhichId, const SfxItemSe
         break;
         case SCHATTR_LEGEND_POS:
         {
-            const SfxPoolItem* pPoolItem = NULL;
+            const SfxPoolItem* pPoolItem = nullptr;
             if( rInItemSet.GetItemState( SCHATTR_LEGEND_POS, true, &pPoolItem ) == SfxItemState::SET )
             {
                 chart2::LegendPosition eNewPos = static_cast<chart2::LegendPosition>(static_cast<const SfxInt32Item*>(pPoolItem)->GetValue());
 
-                ::com::sun::star::chart::ChartLegendExpansion eExpansion = ::com::sun::star::chart::ChartLegendExpansion_HIGH;
+                css::chart::ChartLegendExpansion eExpansion = css::chart::ChartLegendExpansion_HIGH;
                 switch( eNewPos )
                 {
                     case chart2::LegendPosition_LINE_START:
                     case chart2::LegendPosition_LINE_END:
-                        eExpansion = ::com::sun::star::chart::ChartLegendExpansion_HIGH;
+                        eExpansion = css::chart::ChartLegendExpansion_HIGH;
                         break;
                     case chart2::LegendPosition_PAGE_START:
                     case chart2::LegendPosition_PAGE_END:
-                        eExpansion = ::com::sun::star::chart::ChartLegendExpansion_WIDE;
+                        eExpansion = css::chart::ChartLegendExpansion_WIDE;
                         break;
                     default:
                         break;
@@ -148,15 +144,15 @@ bool LegendItemConverter::ApplySpecialItem( sal_uInt16 nWhichId, const SfxItemSe
                     if( ! ( GetPropertySet()->getPropertyValue( "AnchorPosition" ) >>= eOldPos ) ||
                         ( eOldPos != eNewPos ))
                     {
-                        GetPropertySet()->setPropertyValue( "AnchorPosition" , uno::makeAny( eNewPos ));
-                        GetPropertySet()->setPropertyValue( "Expansion" , uno::makeAny( eExpansion ));
+                        GetPropertySet()->setPropertyValue( "AnchorPosition" , uno::Any( eNewPos ));
+                        GetPropertySet()->setPropertyValue( "Expansion" , uno::Any( eExpansion ));
                         GetPropertySet()->setPropertyValue( "RelativePosition" , uno::Any());
                         bChanged = true;
                     }
                 }
                 catch( const uno::Exception & ex )
                 {
-                    ASSERT_EXCEPTION( ex );
+                    SAL_WARN("chart2", "Exception caught. " << ex );
                 }
             }
         }
@@ -168,7 +164,6 @@ bool LegendItemConverter::ApplySpecialItem( sal_uInt16 nWhichId, const SfxItemSe
 
 void LegendItemConverter::FillSpecialItem(
     sal_uInt16 nWhichId, SfxItemSet & rOutItemSet ) const
-    throw( uno::Exception )
 {
     switch( nWhichId )
     {
@@ -183,7 +178,7 @@ void LegendItemConverter::FillSpecialItem(
         {
             chart2::LegendPosition eLegendPos( chart2::LegendPosition_LINE_END );
             GetPropertySet()->getPropertyValue( "AnchorPosition" ) >>= eLegendPos;
-            rOutItemSet.Put( SfxInt32Item(SCHATTR_LEGEND_POS, eLegendPos ) );
+            rOutItemSet.Put( SfxInt32Item(SCHATTR_LEGEND_POS, (sal_Int32)eLegendPos ) );
         }
         break;
    }
