@@ -18,18 +18,18 @@
  */
 
 #include "ControllerCommandDispatch.hxx"
-#include "ChartModelHelper.hxx"
-#include "DiagramHelper.hxx"
-#include "AxisHelper.hxx"
-#include "TitleHelper.hxx"
-#include "LegendHelper.hxx"
-#include "ObjectIdentifier.hxx"
-#include "macros.hxx"
-#include "ChartTypeHelper.hxx"
-#include "ChartController.hxx"
-#include "RegressionCurveHelper.hxx"
-#include "DataSeriesHelper.hxx"
-#include "StatisticsHelper.hxx"
+#include <ChartModelHelper.hxx>
+#include <ChartModel.hxx>
+#include <DiagramHelper.hxx>
+#include <AxisHelper.hxx>
+#include <TitleHelper.hxx>
+#include <LegendHelper.hxx>
+#include <ObjectIdentifier.hxx>
+#include <ChartTypeHelper.hxx>
+#include <ChartController.hxx>
+#include <RegressionCurveHelper.hxx>
+#include <DataSeriesHelper.hxx>
+#include <StatisticsHelper.hxx>
 #include "ShapeController.hxx"
 
 #include <vcl/svapp.hxx>
@@ -62,7 +62,7 @@ bool lcl_isStatusBarVisible( const Reference< frame::XController > & xController
         Reference< beans::XPropertySet > xPropSet( xController->getFrame(), uno::UNO_QUERY );
         if( xPropSet.is() )
         {
-            uno::Reference< ::com::sun::star::frame::XLayoutManager > xLayoutManager;
+            uno::Reference< css::frame::XLayoutManager > xLayoutManager;
             xPropSet->getPropertyValue( "LayoutManager" ) >>= xLayoutManager;
             if ( xLayoutManager.is() )
                 bIsStatusBarVisible = xLayoutManager->isElementVisible( "private:resource/statusbar/statusbar" );
@@ -184,12 +184,12 @@ void ControllerState::update(
 
         ObjectType aObjectType(ObjectIdentifier::getObjectType( aSelObjCID ));
 
-        bIsPositionableObject = (OBJECTTYPE_DATA_POINT != aObjectType) && aSelOID.isDragableObject();
-        bIsTextObject = OBJECTTYPE_TITLE == aObjectType;
+        bIsPositionableObject = (aObjectType != OBJECTTYPE_DATA_POINT) && aSelOID.isDragableObject();
+        bIsTextObject = aObjectType == OBJECTTYPE_TITLE;
 
         uno::Reference< chart2::XDiagram > xDiagram( ChartModelHelper::findDiagram( xModel ));
         bIsFormateableObjectSelected = bHasSelectedObject && aSelOID.isAutoGeneratedObject();
-        if( OBJECTTYPE_DIAGRAM==aObjectType || OBJECTTYPE_DIAGRAM_WALL==aObjectType || OBJECTTYPE_DIAGRAM_FLOOR==aObjectType )
+        if( aObjectType==OBJECTTYPE_DIAGRAM || aObjectType==OBJECTTYPE_DIAGRAM_WALL || aObjectType==OBJECTTYPE_DIAGRAM_FLOOR )
             bIsFormateableObjectSelected = DiagramHelper::isSupportingFloorAndWall( xDiagram );
 
         uno::Reference< chart2::XDataSeries > xGivenDataSeries(
@@ -198,12 +198,12 @@ void ControllerState::update(
 
         bIsDeleteableObjectSelected = ChartController::isObjectDeleteable( aSelObj );
 
-        bMayMoveSeriesForward = (OBJECTTYPE_DATA_POINT!=aObjectType) && DiagramHelper::isSeriesMoveable(
+        bMayMoveSeriesForward = (aObjectType!=OBJECTTYPE_DATA_POINT) && DiagramHelper::isSeriesMoveable(
             ChartModelHelper::findDiagram( xModel ),
             xGivenDataSeries,
             MOVE_SERIES_FORWARD );
 
-        bMayMoveSeriesBackward = (OBJECTTYPE_DATA_POINT!=aObjectType) && DiagramHelper::isSeriesMoveable(
+        bMayMoveSeriesBackward = (aObjectType!=OBJECTTYPE_DATA_POINT) && DiagramHelper::isSeriesMoveable(
             ChartModelHelper::findDiagram( xModel ),
             xGivenDataSeries,
             MOVE_SERIES_BACKWARD );
@@ -236,7 +236,7 @@ void ControllerState::update(
                     DataSeriesHelper::getChartTypeOfSeries( xGivenDataSeries, xDiagram ));
 
                 // trend lines/mean value line
-                if( (OBJECTTYPE_DATA_SERIES == aObjectType || OBJECTTYPE_DATA_POINT == aObjectType)
+                if( (aObjectType == OBJECTTYPE_DATA_SERIES || aObjectType == OBJECTTYPE_DATA_POINT)
                     && ChartTypeHelper::isSupportingRegressionProperties( xFirstChartType, nDimensionCount ))
                 {
                     uno::Reference< chart2::XRegressionCurveContainer > xRegCurveCnt( xGivenDataSeries, uno::UNO_QUERY );
@@ -252,7 +252,7 @@ void ControllerState::update(
                 }
 
                 // error bars
-                if( (OBJECTTYPE_DATA_SERIES == aObjectType || OBJECTTYPE_DATA_POINT == aObjectType)
+                if( (aObjectType == OBJECTTYPE_DATA_SERIES || aObjectType == OBJECTTYPE_DATA_POINT)
                     && ChartTypeHelper::isSupportingStatisticProperties( xFirstChartType, nDimensionCount ))
                 {
                     bMayFormatXErrorBars = bMayDeleteXErrorBars = StatisticsHelper::hasErrorBars( xGivenDataSeries, false );
@@ -296,7 +296,7 @@ void ControllerState::update(
                 }
                 catch(const uno::RuntimeException& e)
                 {
-                    ASSERT_EXCEPTION( e );
+                    SAL_WARN("chart2", "Exception caught. " << e );
                 }
                 bMayAddR2Value = !bHasR2Value;
                 bMayDeleteR2Value = bHasR2Value;
@@ -329,6 +329,7 @@ struct ModelState
     bool bIsReadOnly;
     bool bIsThreeD;
     bool bHasOwnData;
+    bool bHasDataFromPivotTable;
 
     bool bHasMainTitle;
     bool bHasSubTitle;
@@ -361,34 +362,34 @@ struct ModelState
 };
 
 ModelState::ModelState() :
-        bIsReadOnly( true ),
-        bIsThreeD( false ),
-        bHasOwnData( false ),
-        bHasMainTitle( false ),
-        bHasSubTitle( false ),
-        bHasXAxisTitle( false ),
-        bHasYAxisTitle( false ),
-        bHasZAxisTitle( false ),
-        bHasSecondaryXAxisTitle( false ),
-        bHasSecondaryYAxisTitle( false ),
-        bHasXAxis( false ),
-        bHasYAxis( false ),
-        bHasZAxis( false ),
-        bHasAAxis( false ),
-        bHasBAxis( false ),
-        bHasMainXGrid( false ),
-        bHasMainYGrid( false ),
-        bHasMainZGrid( false ),
-        bHasHelpXGrid( false ),
-        bHasHelpYGrid( false ),
-        bHasHelpZGrid( false ),
-        bHasAutoScaledText( false ),
-        bHasLegend( false ),
-        bHasWall( false ),
-        bHasFloor( false ),
-        bSupportsStatistics( false ),
-        bSupportsAxes( false )
-
+        bIsReadOnly(true),
+        bIsThreeD(false),
+        bHasOwnData(false),
+        bHasDataFromPivotTable(false),
+        bHasMainTitle(false),
+        bHasSubTitle(false),
+        bHasXAxisTitle(false),
+        bHasYAxisTitle(false),
+        bHasZAxisTitle(false),
+        bHasSecondaryXAxisTitle(false),
+        bHasSecondaryYAxisTitle(false),
+        bHasXAxis(false),
+        bHasYAxis(false),
+        bHasZAxis(false),
+        bHasAAxis(false),
+        bHasBAxis(false),
+        bHasMainXGrid(false),
+        bHasMainYGrid(false),
+        bHasMainZGrid(false),
+        bHasHelpXGrid(false),
+        bHasHelpYGrid(false),
+        bHasHelpZGrid(false),
+        bHasAutoScaledText(false),
+        bHasLegend(false),
+        bHasWall(false),
+        bHasFloor(false),
+        bSupportsStatistics(false),
+        bSupportsAxes(false)
 {}
 
 void ModelState::update( const Reference< frame::XModel > & xModel )
@@ -408,7 +409,12 @@ void ModelState::update( const Reference< frame::XModel > & xModel )
     bSupportsAxes = ChartTypeHelper::isSupportingMainAxis( xFirstChartType, nDimensionCount, 0 );
 
     bIsThreeD = (nDimensionCount == 3);
-    bHasOwnData = (xChartDoc.is() && xChartDoc->hasInternalDataProvider());
+    if (xChartDoc.is())
+    {
+        ChartModel& rModel = dynamic_cast<ChartModel&>(*xChartDoc.get());
+        bHasOwnData = rModel.hasInternalDataProvider();
+        bHasDataFromPivotTable = !bHasOwnData && rModel.isDataFromPivotTable();
+    }
 
     bHasMainTitle =  TitleHelper::getTitle( TitleHelper::MAIN_TITLE, xModel ).is();
     bHasSubTitle =   TitleHelper::getTitle( TitleHelper::SUB_TITLE, xModel ).is();
@@ -462,8 +468,7 @@ ControllerCommandDispatch::ControllerCommandDispatch(
     const Reference< uno::XComponentContext > & xContext,
     ChartController* pController, CommandDispatchContainer* pContainer ) :
         impl::ControllerCommandDispatch_Base( xContext ),
-        m_pChartController( pController ),
-        m_xController( Reference< frame::XController >( pController ) ),
+        m_xChartController( pController ),
         m_xSelectionSupplier( Reference< view::XSelectionSupplier >( pController ) ),
         m_xDispatch( Reference< frame::XDispatch >( pController ) ),
         m_apModelState( new impl::ModelState() ),
@@ -478,9 +483,9 @@ ControllerCommandDispatch::~ControllerCommandDispatch()
 
 void ControllerCommandDispatch::initialize()
 {
-    if( m_xController.is())
+    if( m_xChartController.is())
     {
-        Reference< frame::XModel > xModel( m_xController->getModel());
+        Reference< frame::XModel > xModel( m_xChartController->getModel());
         Reference< util::XModifyBroadcaster > xModifyBroadcaster( xModel, uno::UNO_QUERY );
         OSL_ASSERT( xModifyBroadcaster.is());
         if( xModifyBroadcaster.is())
@@ -494,7 +499,7 @@ void ControllerCommandDispatch::initialize()
             m_apModelState->update( xModel );
 
         if( m_apControllerState.get() && xModel.is())
-            m_apControllerState->update( m_xController, xModel );
+            m_apControllerState->update( m_xChartController.get(), xModel );
 
         updateCommandAvailability();
     }
@@ -504,7 +509,7 @@ void ControllerCommandDispatch::fireStatusEventForURLImpl(
     const OUString & rURL,
     const Reference< frame::XStatusListener > & xSingleListener )
 {
-    ::std::map< OUString, uno::Any >::const_iterator aArgIt( m_aCommandArguments.find( rURL ));
+    std::map< OUString, uno::Any >::const_iterator aArgIt( m_aCommandArguments.find( rURL ));
     if( aArgIt != m_aCommandArguments.end())
         fireStatusEventForURL( rURL, aArgIt->second, commandAvailable( rURL ), xSingleListener );
     else
@@ -521,16 +526,12 @@ void ControllerCommandDispatch::updateCommandAvailability()
 
     // read-only
     bool bIsWritable = bModelStateIsValid && (! m_apModelState->bIsReadOnly);
-    // paste is available
-    // @todo: determine correctly
-    bool bHasSuitableClipboardContent = true;
-
-    bool bShapeContext = m_pChartController && m_pChartController->isShapeContext();
+    bool bShapeContext = m_xChartController.is() && m_xChartController->isShapeContext();
 
     bool bEnableDataTableDialog = false;
-    if ( m_xController.is() )
+    if ( m_xChartController.is() )
     {
-        Reference< beans::XPropertySet > xProps( m_xController->getModel(), uno::UNO_QUERY );
+        Reference< beans::XPropertySet > xProps( m_xChartController->getModel(), uno::UNO_QUERY );
         if ( xProps.is() )
         {
             try
@@ -539,7 +540,7 @@ void ControllerCommandDispatch::updateCommandAvailability()
             }
             catch( const uno::Exception& e )
             {
-                ASSERT_EXCEPTION( e );
+                SAL_WARN("chart2", "Exception caught. " << e );
             }
         }
     }
@@ -547,16 +548,16 @@ void ControllerCommandDispatch::updateCommandAvailability()
     // edit commands
     m_aCommandAvailability[ ".uno:Cut" ] = bIsWritable && bControllerStateIsValid && m_apControllerState->bIsDeleteableObjectSelected;
     m_aCommandAvailability[ ".uno:Copy" ] = bControllerStateIsValid && m_apControllerState->bHasSelectedObject;
-    m_aCommandAvailability[ ".uno:Paste" ] = bIsWritable && bHasSuitableClipboardContent;
+    m_aCommandAvailability[ ".uno:Paste" ] = bIsWritable;
 
     // toolbar commands
     m_aCommandAvailability[ ".uno:ToggleGridHorizontal" ] = bIsWritable;
-    m_aCommandArguments[ ".uno:ToggleGridHorizontal" ] = uno::makeAny( m_apModelState->bHasMainYGrid );
+    m_aCommandArguments[ ".uno:ToggleGridHorizontal" ] <<= m_apModelState->bHasMainYGrid;
     m_aCommandAvailability[ ".uno:ToggleGridVertical" ] = bIsWritable;
-    m_aCommandArguments[ ".uno:ToggleGridVertical" ] = uno::makeAny( m_apModelState->bHasMainXGrid );
+    m_aCommandArguments[ ".uno:ToggleGridVertical" ] <<= m_apModelState->bHasMainXGrid;
 
     m_aCommandAvailability[ ".uno:ToggleLegend" ] = bIsWritable;
-    m_aCommandArguments[ ".uno:ToggleLegend" ] = uno::makeAny( m_apModelState->bHasLegend );
+    m_aCommandArguments[ ".uno:ToggleLegend" ] <<= m_apModelState->bHasLegend;
 
     m_aCommandAvailability[ ".uno:NewArrangement" ] = bIsWritable;
     m_aCommandAvailability[ ".uno:Update" ] = bIsWritable;
@@ -607,14 +608,15 @@ void ControllerCommandDispatch::updateCommandAvailability()
     m_aCommandAvailability[ ".uno:View3D" ] = bIsWritable && bModelStateIsValid && m_apModelState->bIsThreeD;
     m_aCommandAvailability[ ".uno:DiagramFloor" ] = bIsWritable && bModelStateIsValid && m_apModelState->bHasFloor;
 
-    //some mor format commands with different ui text
+    //some more format commands with different ui text
     m_aCommandAvailability[ ".uno:FormatWall" ] = m_aCommandAvailability[ ".uno:DiagramWall" ];
     m_aCommandAvailability[ ".uno:FormatFloor" ] = m_aCommandAvailability[ ".uno:DiagramFloor" ];
     m_aCommandAvailability[ ".uno:FormatChartArea" ] = m_aCommandAvailability[ ".uno:DiagramArea" ];
     m_aCommandAvailability[ ".uno:FormatLegend" ] = m_aCommandAvailability[ ".uno:Legend" ];
 
     // depending on own data
-    m_aCommandAvailability[ ".uno:DataRanges" ] = bIsWritable && bModelStateIsValid && (! m_apModelState->bHasOwnData);
+    m_aCommandAvailability[ ".uno:DataRanges" ] = bIsWritable && bModelStateIsValid &&
+                                                  (!m_apModelState->bHasOwnData) && (!m_apModelState->bHasDataFromPivotTable);
     m_aCommandAvailability[ ".uno:DiagramData" ] = bIsWritable && bModelStateIsValid &&  m_apModelState->bHasOwnData && bEnableDataTableDialog;
 
     // titles
@@ -629,7 +631,7 @@ void ControllerCommandDispatch::updateCommandAvailability()
 
     // text
     m_aCommandAvailability[ ".uno:ScaleText" ] = bIsWritable && bModelStateIsValid ;
-    m_aCommandArguments[ ".uno:ScaleText" ] = uno::makeAny( m_apModelState->bHasAutoScaledText );
+    m_aCommandArguments[ ".uno:ScaleText" ] <<= m_apModelState->bHasAutoScaledText;
 
     // axes
     m_aCommandAvailability[ ".uno:DiagramAxisX" ] = bIsWritable && bModelStateIsValid && m_apModelState->bHasXAxis;
@@ -691,7 +693,7 @@ void ControllerCommandDispatch::updateCommandAvailability()
 
 bool ControllerCommandDispatch::commandAvailable( const OUString & rCommand )
 {
-    ::std::map< OUString, bool >::const_iterator aIt( m_aCommandAvailability.find( rCommand ));
+    std::map< OUString, bool >::const_iterator aIt( m_aCommandAvailability.find( rCommand ));
     if( aIt != m_aCommandAvailability.end())
         return aIt->second;
     OSL_FAIL( "commandAvailable: command not in availability map" );
@@ -722,12 +724,12 @@ void ControllerCommandDispatch::fireStatusEvent(
     if( rURL.isEmpty() || bIsChartSelectorURL )
     {
         uno::Any aArg;
-        aArg <<= m_xController;
+        aArg <<= Reference< frame::XController >(m_xChartController.get());
         fireStatusEventForURL( ".uno:ChartElementSelector", aArg, true, xSingleListener );
     }
 
     if( rURL.isEmpty() )
-        for( ::std::map< OUString, bool >::const_iterator aIt( m_aCommandAvailability.begin());
+        for( std::map< OUString, bool >::const_iterator aIt( m_aCommandAvailability.begin());
              aIt != m_aCommandAvailability.end(); ++aIt )
             fireStatusEventForURLImpl( aIt->first, xSingleListener );
     else if( !bIsChartSelectorURL )
@@ -737,8 +739,8 @@ void ControllerCommandDispatch::fireStatusEvent(
     // @todo: remove if Issue 68864 is fixed
     if( rURL.isEmpty() || rURL == ".uno:StatusBarVisible" )
     {
-        bool bIsStatusBarVisible( lcl_isStatusBarVisible( m_xController ));
-        fireStatusEventForURL( ".uno:StatusBarVisible", uno::makeAny( bIsStatusBarVisible ), true, xSingleListener );
+        bool bIsStatusBarVisible( lcl_isStatusBarVisible( m_xChartController.get() ));
+        fireStatusEventForURL( ".uno:StatusBarVisible", uno::Any( bIsStatusBarVisible ), true, xSingleListener );
     }
 }
 
@@ -746,7 +748,6 @@ void ControllerCommandDispatch::fireStatusEvent(
 void SAL_CALL ControllerCommandDispatch::dispatch(
     const util::URL& URL,
     const Sequence< beans::PropertyValue >& Arguments )
-    throw (uno::RuntimeException, std::exception)
 {
     if( commandAvailable( URL.Complete ))
         m_xDispatch->dispatch( URL, Arguments );
@@ -756,37 +757,35 @@ void SAL_CALL ControllerCommandDispatch::dispatch(
 /// is called when this is disposed
 void SAL_CALL ControllerCommandDispatch::disposing()
 {
-    m_xController.clear();
+    m_xChartController.clear();
     m_xDispatch.clear();
     m_xSelectionSupplier.clear();
 }
 
 // ____ XEventListener (base of XModifyListener) ____
 void SAL_CALL ControllerCommandDispatch::disposing( const lang::EventObject& /* Source */ )
-    throw (uno::RuntimeException, std::exception)
 {
-    m_xController.clear();
+    m_xChartController.clear();
     m_xDispatch.clear();
     m_xSelectionSupplier.clear();
 }
 
 // ____ XModifyListener ____
 void SAL_CALL ControllerCommandDispatch::modified( const lang::EventObject& aEvent )
-    throw (uno::RuntimeException, std::exception)
 {
     bool bUpdateCommandAvailability = false;
 
     // Update the "ModelState" Struct.
-    if( m_apModelState.get() && m_xController.is())
+    if( m_apModelState.get() && m_xChartController.is())
     {
-        m_apModelState->update( m_xController->getModel());
+        m_apModelState->update( m_xChartController->getModel());
         bUpdateCommandAvailability = true;
     }
 
     // Update the "ControllerState" Struct.
-    if( m_apControllerState.get() && m_xController.is())
+    if( m_apControllerState.get() && m_xChartController.is())
     {
-        m_apControllerState->update( m_xController, m_xController->getModel());
+        m_apControllerState->update( m_xChartController.get(), m_xChartController->getModel());
         bUpdateCommandAvailability = true;
     }
 
@@ -798,12 +797,11 @@ void SAL_CALL ControllerCommandDispatch::modified( const lang::EventObject& aEve
 
 // ____ XSelectionChangeListener ____
 void SAL_CALL ControllerCommandDispatch::selectionChanged( const lang::EventObject& aEvent )
-    throw (uno::RuntimeException, std::exception)
 {
     // Update the "ControllerState" Struct.
-    if( m_apControllerState.get() && m_xController.is())
+    if( m_apControllerState.get() && m_xChartController.is())
     {
-        m_apControllerState->update( m_xController, m_xController->getModel());
+        m_apControllerState->update( m_xChartController.get(), m_xChartController->getModel());
         updateCommandAvailability();
     }
 
