@@ -18,17 +18,17 @@
  */
 
 #include "DrawCommandDispatch.hxx"
-#include "DrawCommandDispatch.hrc"
-#include "ChartController.hxx"
-#include "DrawViewWrapper.hxx"
-#include "chartview/DrawModelWrapper.hxx"
-#include "macros.hxx"
+#include "DrawCommandDispatch.h"
+#include <ChartController.hxx>
+#include <DrawViewWrapper.hxx>
+#include <chartview/DrawModelWrapper.hxx>
 
-#include <osl/mutex.hxx>
+#include <com/sun/star/frame/CommandGroup.hpp>
 #include <vcl/svapp.hxx>
 #include <svl/itempool.hxx>
 #include <editeng/adjustitem.hxx>
 #include <svx/dialogs.hrc>
+#include <svx/strings.hrc>
 #include <svx/dialmgr.hxx>
 #include <svx/fmmodel.hxx>
 #include <svx/gallery.hxx>
@@ -43,7 +43,7 @@
 #include <svx/xtable.hxx>
 #include <basegfx/polygon/b2dpolygon.hxx>
 
-#include <boost/ref.hpp>
+#include <functional>
 
 using namespace ::com::sun::star;
 using namespace ::com::sun::star::frame;
@@ -51,19 +51,6 @@ using namespace ::com::sun::star::frame;
 using ::com::sun::star::uno::Reference;
 using ::com::sun::star::uno::Sequence;
 
-namespace
-{
-
-    // comparing two PropertyValue instances
-    struct PropertyValueCompare : public ::std::binary_function< beans::PropertyValue, OUString, bool >
-    {
-        bool operator() ( const beans::PropertyValue& rPropValue, const OUString& rName ) const
-        {
-            return rPropValue.Name.equals( rName );
-        }
-    };
-
-} // anonymous namespace
 
 namespace chart
 {
@@ -79,11 +66,6 @@ DrawCommandDispatch::~DrawCommandDispatch()
 {
 }
 
-void DrawCommandDispatch::initialize()
-{
-    FeatureCommandDispatchBase::initialize();
-}
-
 bool DrawCommandDispatch::isFeatureSupported( const OUString& rCommandURL )
 {
     sal_uInt16 nFeatureId = 0;
@@ -92,17 +74,17 @@ bool DrawCommandDispatch::isFeatureSupported( const OUString& rCommandURL )
     return parseCommandURL( rCommandURL, &nFeatureId, &aBaseCommand, &aCustomShapeType );
 }
 
-::basegfx::B2DPolyPolygon getPolygon( sal_uInt16 nResId, SdrModel& rModel )
+::basegfx::B2DPolyPolygon getPolygon(const char* pResId, SdrModel const & rModel)
 {
     ::basegfx::B2DPolyPolygon aReturn;
     XLineEndListRef pLineEndList = rModel.GetLineEndList();
     if ( pLineEndList.is() )
     {
-        OUString aName( SVX_RESSTR( nResId ) );
+        OUString aName(SvxResId(pResId));
         long nCount = pLineEndList->Count();
         for ( long nIndex = 0; nIndex < nCount; ++nIndex )
         {
-            XLineEndEntry* pEntry = pLineEndList->GetLineEnd( nIndex );
+            const XLineEndEntry* pEntry = pLineEndList->GetLineEnd(nIndex);
             if ( pEntry->GetName() == aName )
             {
                 aReturn = pEntry->GetLineEnd();
@@ -124,10 +106,10 @@ void DrawCommandDispatch::setAttributes( SdrObject* pObj )
             bool bAttributesAppliedFromGallery = false;
             if ( GalleryExplorer::GetSdrObjCount( GALLERY_THEME_POWERPOINT ) )
             {
-                ::std::vector< OUString > aObjList;
+                std::vector< OUString > aObjList;
                 if ( GalleryExplorer::FillObjListTitle( GALLERY_THEME_POWERPOINT, aObjList ) )
                 {
-                    for ( sal_uInt16 i = 0; i < aObjList.size(); ++i )
+                    for ( size_t i = 0; i < aObjList.size(); ++i )
                     {
                         if ( aObjList[ i ].equalsIgnoreAsciiCase( m_aCustomShapeType ) )
                         {
@@ -140,20 +122,22 @@ void DrawCommandDispatch::setAttributes( SdrObject* pObj )
                                 if ( pSourceObj )
                                 {
                                     const SfxItemSet& rSource = pSourceObj->GetMergedItemSet();
-                                    SfxItemSet aDest( pObj->GetModel()->GetItemPool(),          // ranges from SdrAttrObj
-                                        SDRATTR_START, SDRATTR_SHADOW_LAST,
-                                        SDRATTR_MISC_FIRST, SDRATTR_MISC_LAST,
-                                        SDRATTR_TEXTDIRECTION, SDRATTR_TEXTDIRECTION,
-                                        // Graphic Attributes
-                                        SDRATTR_GRAF_FIRST, SDRATTR_GRAF_LAST,
-                                        // 3d Properties
-                                        SDRATTR_3D_FIRST, SDRATTR_3D_LAST,
-                                        // CustomShape properties
-                                        SDRATTR_CUSTOMSHAPE_FIRST, SDRATTR_CUSTOMSHAPE_LAST,
-                                        // range from SdrTextObj
-                                        EE_ITEMS_START, EE_ITEMS_END,
-                                        // end
-                                        0, 0);
+                                    SfxItemSet aDest(
+                                        pObj->GetModel()->GetItemPool(),
+                                        svl::Items<
+                                            // Ranges from SdrAttrObj:
+                                            SDRATTR_START, SDRATTR_SHADOW_LAST,
+                                            SDRATTR_MISC_FIRST,
+                                                SDRATTR_MISC_LAST,
+                                            SDRATTR_TEXTDIRECTION,
+                                                SDRATTR_TEXTDIRECTION,
+                                            // Graphic attributes, 3D
+                                            // properties, CustomShape
+                                            // properties:
+                                            SDRATTR_GRAF_FIRST,
+                                                SDRATTR_CUSTOMSHAPE_LAST,
+                                            // Range from SdrTextObj:
+                                            EE_ITEMS_START, EE_ITEMS_END>{});
                                     aDest.Set( rSource );
                                     pObj->SetMergedItemSet( aDest );
                                     sal_Int32 nAngle = pSourceObj->GetRotateAngle();
@@ -172,10 +156,10 @@ void DrawCommandDispatch::setAttributes( SdrObject* pObj )
             }
             if ( !bAttributesAppliedFromGallery )
             {
-                pObj->SetMergedItem( SvxAdjustItem( SVX_ADJUST_CENTER, 0 ) );
+                pObj->SetMergedItem( SvxAdjustItem( SvxAdjust::Center, 0 ) );
                 pObj->SetMergedItem( SdrTextVertAdjustItem( SDRTEXTVERTADJUST_CENTER ) );
                 pObj->SetMergedItem( SdrTextHorzAdjustItem( SDRTEXTHORZADJUST_BLOCK ) );
-                pObj->SetMergedItem( SdrTextAutoGrowHeightItem( false ) );
+                pObj->SetMergedItem( makeSdrTextAutoGrowHeightItem( false ) );
 
                 SdrObjCustomShape* pShape(dynamic_cast< SdrObjCustomShape* >( pObj ));
                 assert(pShape);
@@ -211,16 +195,16 @@ void DrawCommandDispatch::setLineEnds( SfxItemSet& rAttr )
             pDrawViewWrapper->GetAttributes( aSet );
 
             long nWidth = 300; // (1/100th mm)
-            if ( aSet.GetItemState( XATTR_LINEWIDTH ) != SFX_ITEM_DONTCARE )
+            if ( aSet.GetItemState( XATTR_LINEWIDTH ) != SfxItemState::DONTCARE )
             {
-                long nValue = ( ( const XLineWidthItem& ) aSet.Get( XATTR_LINEWIDTH ) ).GetValue();
+                long nValue = aSet.Get( XATTR_LINEWIDTH ).GetValue();
                 if ( nValue > 0 )
                 {
                     nWidth = nValue * 3;
                 }
             }
 
-            rAttr.Put( XLineEndItem( SVX_RESSTR( RID_SVXSTR_ARROW ), aArrow ) );
+            rAttr.Put( XLineEndItem( SvxResId( RID_SVXSTR_ARROW ), aArrow ) );
             rAttr.Put( XLineEndWidthItem( nWidth ) );
         }
     }
@@ -233,7 +217,6 @@ void DrawCommandDispatch::disposing()
 
 // XEventListener
 void DrawCommandDispatch::disposing( const lang::EventObject& /* Source */ )
-    throw (uno::RuntimeException, std::exception)
 {
 }
 
@@ -283,17 +266,15 @@ FeatureState DrawCommandDispatch::getState( const OUString& rCommand )
 
 void DrawCommandDispatch::execute( const OUString& rCommand, const Sequence< beans::PropertyValue>& rArgs )
 {
-    (void)rArgs;
-
     ChartDrawMode eDrawMode = CHARTDRAW_SELECT;
     SdrObjKind eKind = OBJ_NONE;
-    bool bCreate = false;
 
     sal_uInt16 nFeatureId = 0;
     OUString aBaseCommand;
     OUString aCustomShapeType;
     if ( parseCommandURL( rCommand, &nFeatureId, &aBaseCommand, &aCustomShapeType ) )
     {
+        bool bCreate = false;
         m_nFeatureId = nFeatureId;
         m_aCustomShapeType = aCustomShapeType;
 
@@ -378,10 +359,11 @@ void DrawCommandDispatch::execute( const OUString& rCommand, const Sequence< bea
                 const OUString sKeyModifier( "KeyModifier" );
                 const beans::PropertyValue* pIter = rArgs.getConstArray();
                 const beans::PropertyValue* pEnd  = pIter + rArgs.getLength();
-                const beans::PropertyValue* pKeyModifier = ::std::find_if(
-                    pIter, pEnd, ::std::bind2nd( PropertyValueCompare(), boost::cref( sKeyModifier ) ) );
+                const beans::PropertyValue* pKeyModifier = std::find_if(pIter, pEnd,
+                                                                [&sKeyModifier](const beans::PropertyValue& lhs)
+                                                                {return lhs.Name == sKeyModifier;} );
                 sal_Int16 nKeyModifier = 0;
-                if ( pKeyModifier && ( pKeyModifier->Value >>= nKeyModifier ) && nKeyModifier == KEY_MOD1 )
+                if ( pKeyModifier != pEnd && ( pKeyModifier->Value >>= nKeyModifier ) && nKeyModifier == KEY_MOD1 )
                 {
                     if ( eDrawMode == CHARTDRAW_INSERT )
                     {
@@ -390,12 +372,7 @@ void DrawCommandDispatch::execute( const OUString& rCommand, const Sequence< bea
                         {
                             SdrPageView* pPageView = pDrawViewWrapper->GetSdrPageView();
                             pDrawViewWrapper->InsertObjectAtView( pObj, *pPageView );
-                            Reference< drawing::XShape > xShape( pObj->getUnoShape(), uno::UNO_QUERY );
-                            if ( xShape.is() )
-                            {
-                                m_pChartController->m_aSelection.setSelection( xShape );
-                                m_pChartController->m_aSelection.applySelection( pDrawViewWrapper );
-                            }
+                            m_pChartController->SetAndApplySelection(Reference<drawing::XShape>(pObj->getUnoShape(), uno::UNO_QUERY));
                             if ( nFeatureId == COMMAND_ID_DRAW_TEXT )
                             {
                                 m_pChartController->StartTextEdit();
@@ -428,7 +405,7 @@ void DrawCommandDispatch::describeSupportedFeatures()
 
 void DrawCommandDispatch::setInsertObj( sal_uInt16 eObj )
 {
-    DrawViewWrapper* pDrawViewWrapper = ( m_pChartController ? m_pChartController->GetDrawViewWrapper() : NULL );
+    DrawViewWrapper* pDrawViewWrapper = ( m_pChartController ? m_pChartController->GetDrawViewWrapper() : nullptr );
     if ( pDrawViewWrapper )
     {
         pDrawViewWrapper->SetCurrentObj( eObj /*, Inventor */);
@@ -437,9 +414,9 @@ void DrawCommandDispatch::setInsertObj( sal_uInt16 eObj )
 
 SdrObject* DrawCommandDispatch::createDefaultObject( const sal_uInt16 nID )
 {
-    SdrObject* pObj = NULL;
-    DrawViewWrapper* pDrawViewWrapper = ( m_pChartController ? m_pChartController->GetDrawViewWrapper() : NULL );
-    DrawModelWrapper* pDrawModelWrapper = ( m_pChartController ? m_pChartController->GetDrawModelWrapper() : NULL );
+    SdrObject* pObj = nullptr;
+    DrawViewWrapper* pDrawViewWrapper = ( m_pChartController ? m_pChartController->GetDrawViewWrapper() : nullptr );
+    DrawModelWrapper* pDrawModelWrapper = ( m_pChartController ? m_pChartController->GetDrawModelWrapper() : nullptr );
 
     if ( pDrawViewWrapper && pDrawModelWrapper )
     {
@@ -452,21 +429,19 @@ SdrObject* DrawCommandDispatch::createDefaultObject( const sal_uInt16 nID )
                 pDrawViewWrapper->GetCurrentObjIdentifier(), pPage );
             if ( pObj )
             {
-                long nDefaultObjectSizeWidth = 4000;
-                long nDefaultObjectSizeHeight = 2500;
-                Size aObjectSize( nDefaultObjectSizeWidth, nDefaultObjectSizeHeight );
-                Rectangle aPageRect( Rectangle( Point( 0, 0 ), pPage->GetSize() ) );
+                Size aObjectSize( 4000, 2500 );
+                tools::Rectangle aPageRect( tools::Rectangle( Point( 0, 0 ), pPage->GetSize() ) );
                 Point aObjectPos = aPageRect.Center();
                 aObjectPos.X() -= aObjectSize.Width() / 2;
                 aObjectPos.Y() -= aObjectSize.Height() / 2;
-                Rectangle aRect( aObjectPos, aObjectSize );
+                tools::Rectangle aRect( aObjectPos, aObjectSize );
 
                 switch ( nID )
                 {
                     case COMMAND_ID_DRAW_LINE:
                     case COMMAND_ID_LINE_ARROW_END:
                         {
-                            if ( pObj->ISA( SdrPathObj ) )
+                            if ( dynamic_cast<const SdrPathObj*>( pObj) !=  nullptr )
                             {
                                 Point aStart = aRect.TopLeft();
                                 Point aEnd = aRect.BottomRight();
@@ -474,7 +449,7 @@ SdrObject* DrawCommandDispatch::createDefaultObject( const sal_uInt16 nID )
                                 basegfx::B2DPolygon aPoly;
                                 aPoly.append( basegfx::B2DPoint( aStart.X(), nYMiddle ) );
                                 aPoly.append( basegfx::B2DPoint( aEnd.X(), nYMiddle ) );
-                                ( dynamic_cast< SdrPathObj* >( pObj ) )->SetPathPoly( basegfx::B2DPolyPolygon( aPoly ) );
+                                dynamic_cast<SdrPathObj&>(*pObj).SetPathPoly(basegfx::B2DPolyPolygon(aPoly));
                                 SfxItemSet aSet( pDrawModelWrapper->GetItemPool() );
                                 setLineEnds( aSet );
                                 pObj->SetMergedItemSet( aSet );
@@ -483,7 +458,7 @@ SdrObject* DrawCommandDispatch::createDefaultObject( const sal_uInt16 nID )
                         break;
                     case COMMAND_ID_DRAW_FREELINE_NOFILL:
                         {
-                            if ( pObj->ISA( SdrPathObj ) )
+                            if ( dynamic_cast<const SdrPathObj*>( pObj) !=  nullptr )
                             {
                                 basegfx::B2DPolygon aInnerPoly;
                                 aInnerPoly.append( basegfx::B2DPoint( aRect.Left(), aRect.Bottom() ) );
@@ -497,14 +472,14 @@ SdrObject* DrawCommandDispatch::createDefaultObject( const sal_uInt16 nID )
                                     basegfx::B2DPoint( aRect.Right(), aRect.Top() ) );
                                 basegfx::B2DPolyPolygon aPoly;
                                 aPoly.append( aInnerPoly );
-                                ( dynamic_cast< SdrPathObj* >( pObj ) )->SetPathPoly( aPoly );
+                                dynamic_cast<SdrPathObj&>(*pObj).SetPathPoly(aPoly);
                             }
                         }
                         break;
                     case COMMAND_ID_DRAW_TEXT:
                     case COMMAND_ID_DRAW_TEXT_VERTICAL:
                         {
-                            if ( pObj->ISA( SdrTextObj ) )
+                            if ( dynamic_cast<const SdrTextObj*>( pObj) !=  nullptr )
                             {
                                 SdrTextObj* pTextObj = dynamic_cast< SdrTextObj* >( pObj );
                                 if ( pTextObj )
@@ -515,8 +490,8 @@ SdrObject* DrawCommandDispatch::createDefaultObject( const sal_uInt16 nID )
                                     if ( bVertical )
                                     {
                                         SfxItemSet aSet( pDrawModelWrapper->GetItemPool() );
-                                        aSet.Put( SdrTextAutoGrowWidthItem( true ) );
-                                        aSet.Put( SdrTextAutoGrowHeightItem( false ) );
+                                        aSet.Put( makeSdrTextAutoGrowWidthItem( true ) );
+                                        aSet.Put( makeSdrTextAutoGrowHeightItem( false ) );
                                         aSet.Put( SdrTextVertAdjustItem( SDRTEXTVERTADJUST_TOP ) );
                                         aSet.Put( SdrTextHorzAdjustItem( SDRTEXTHORZADJUST_RIGHT ) );
                                         pTextObj->SetMergedItemSet( aSet );
@@ -528,9 +503,9 @@ SdrObject* DrawCommandDispatch::createDefaultObject( const sal_uInt16 nID )
                     case COMMAND_ID_DRAW_CAPTION:
                     case COMMAND_ID_DRAW_CAPTION_VERTICAL:
                         {
-                            if ( pObj->ISA( SdrCaptionObj ) )
+                            if ( dynamic_cast<const SdrCaptionObj*>( pObj) !=  nullptr )
                             {
-                                bool bIsVertical( COMMAND_ID_DRAW_CAPTION_VERTICAL == nID );
+                                bool bIsVertical( nID == COMMAND_ID_DRAW_CAPTION_VERTICAL );
                                 SdrTextObj* pTextObj = dynamic_cast< SdrTextObj* >( pObj );
                                 if ( pTextObj )
                                 {
