@@ -17,10 +17,8 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "XMLFilter.hxx"
-#include "macros.hxx"
-#include "MediaDescriptorHelper.hxx"
-#include "ContainerHelper.hxx"
+#include <XMLFilter.hxx>
+#include <MediaDescriptorHelper.hxx>
 
 #include <svtools/sfxecode.hxx>
 #include <unotools/saveopt.hxx>
@@ -61,24 +59,7 @@ namespace
 char const sXML_metaStreamName[] = "meta.xml";
 char const sXML_styleStreamName[] = "styles.xml";
 char const sXML_contentStreamName[] = "content.xml";
-char const sXML_oldContentStreamName[] = "Content.xml";
 
-// soffice 6/7
-char const sXML_export_chart_styles_service[] = "com.sun.star.comp.Chart.XMLStylesExporter";
-char const sXML_export_chart_content_service[] = "com.sun.star.comp.Chart.XMLContentExporter";
-
-char const sXML_import_chart_styles_service[] = "com.sun.star.comp.Chart.XMLStylesImporter";
-char const sXML_import_chart_content_service[] = "com.sun.star.comp.Chart.XMLContentImporter";
-char const sXML_import_chart_old_content_service[] = "com.sun.star.office.sax.importer.Chart";
-
-// Oasis
-char const sXML_export_chart_oasis_styles_service[] = "com.sun.star.comp.Chart.XMLOasisStylesExporter";
-char const sXML_export_chart_oasis_content_service[] = "com.sun.star.comp.Chart.XMLOasisContentExporter";
-char const sXML_export_chart_oasis_meta_service[] = "com.sun.star.comp.Chart.XMLOasisMetaExporter";
-
-char const sXML_import_chart_oasis_styles_service[] = "com.sun.star.comp.Chart.XMLOasisStylesImporter";
-char const sXML_import_chart_oasis_content_service[] = "com.sun.star.comp.Chart.XMLOasisContentImporter";
-char const sXML_import_chart_oasis_meta_service[] = "com.sun.star.comp.Chart.XMLOasisMetaImporter";
 
 uno::Reference< embed::XStorage > lcl_getWriteStorage(
     const Sequence< beans::PropertyValue >& rMediaDescriptor,
@@ -96,7 +77,7 @@ uno::Reference< embed::XStorage > lcl_getWriteStorage(
         {
             Reference< lang::XSingleServiceFactory > xStorageFact( embed::StorageFactory::create( xContext ) );
 
-            ::std::vector< beans::PropertyValue > aPropertiesForStorage;
+            std::vector< beans::PropertyValue > aPropertiesForStorage;
 
             for( sal_Int32 i=rMediaDescriptor.getLength(); i--; )
             {
@@ -133,12 +114,12 @@ uno::Reference< embed::XStorage > lcl_getWriteStorage(
              ! ( xProp->getPropertyValue( "MediaType") >>= aMediaType ) ||
              ( aMediaType.isEmpty() ))
         {
-            xProp->setPropertyValue( "MediaType", uno::makeAny( _sMediaType ));
+            xProp->setPropertyValue( "MediaType", uno::Any( _sMediaType ));
         }
     }
     catch (const uno::Exception& ex)
     {
-        ASSERT_EXCEPTION( ex );
+        SAL_WARN("chart2", "Exception caught. " << ex );
     }
     return xStorage;
 }
@@ -160,7 +141,7 @@ uno::Reference< embed::XStorage > lcl_getReadStorage(
         {
             // get XStream from MediaDescriptor
             uno::Reference< io::XInputStream > xStream;
-            ::std::vector< beans::PropertyValue > aPropertiesForStorage;
+            std::vector< beans::PropertyValue > aPropertiesForStorage;
             for( sal_Int32 i=rMediaDescriptor.getLength(); i--; )
             {
                 if( rMediaDescriptor[i].Name == "InputStream" )
@@ -191,7 +172,7 @@ uno::Reference< embed::XStorage > lcl_getReadStorage(
     }
     catch (const uno::Exception& ex)
     {
-        ASSERT_EXCEPTION( ex );
+        SAL_WARN("chart2", "Exception caught. " << ex );
     }
 
     return xStorage;
@@ -213,7 +194,6 @@ XMLFilter::~XMLFilter()
 // ____ XFilter ____
 sal_Bool SAL_CALL XMLFilter::filter(
     const Sequence< beans::PropertyValue >& aDescriptor )
-    throw (uno::RuntimeException, std::exception)
 {
     bool bResult = false;
 
@@ -228,7 +208,7 @@ sal_Bool SAL_CALL XMLFilter::filter(
     {
         OSL_ENSURE( ! m_xTargetDoc.is(), "source doc is set -> target document should not be set" );
         if( impl_Export( m_xSourceDoc,
-                         aDescriptor ) == 0 )
+                         aDescriptor ) == ERRCODE_NONE )
         {
             m_xSourceDoc = nullptr;
             bResult = true;
@@ -237,7 +217,7 @@ sal_Bool SAL_CALL XMLFilter::filter(
     else if( m_xTargetDoc.is())
     {
         if( impl_Import( m_xTargetDoc,
-                         aDescriptor ) == 0 )
+                         aDescriptor ) == ERRCODE_NONE )
         {
             m_xTargetDoc = nullptr;
             bResult = true;
@@ -252,7 +232,6 @@ sal_Bool SAL_CALL XMLFilter::filter(
 }
 
 void SAL_CALL XMLFilter::cancel()
-    throw (uno::RuntimeException, std::exception)
 {
     // if mutex is locked set "cancel state"
     // note: is currently ignored in filter-method
@@ -265,8 +244,6 @@ void SAL_CALL XMLFilter::cancel()
 // ____ XImporter ____
 void SAL_CALL XMLFilter::setTargetDocument(
     const Reference< lang::XComponent >& Document )
-    throw (lang::IllegalArgumentException,
-           uno::RuntimeException, std::exception)
 {
     MutexGuard aGuard( m_aMutex );
     OSL_ENSURE( ! m_xSourceDoc.is(), "Setting target doc while source doc is set" );
@@ -277,8 +254,6 @@ void SAL_CALL XMLFilter::setTargetDocument(
 // ____ XExporter ____
 void SAL_CALL XMLFilter::setSourceDocument(
     const Reference< lang::XComponent >& Document )
-    throw (lang::IllegalArgumentException,
-           uno::RuntimeException, std::exception)
 {
     MutexGuard aGuard( m_aMutex );
     OSL_ENSURE( ! m_xTargetDoc.is(), "Setting source doc while target doc is set" );
@@ -286,11 +261,11 @@ void SAL_CALL XMLFilter::setSourceDocument(
     m_xSourceDoc = Document;
 }
 
-sal_Int32 XMLFilter::impl_Import(
+ErrCode XMLFilter::impl_Import(
     const Reference< lang::XComponent > & xDocumentComp,
     const Sequence< beans::PropertyValue > & rMediaDescriptor )
 {
-    sal_Int32 nWarning = 0;
+    ErrCode nWarning = ERRCODE_NONE;
 
     OSL_ENSURE( xDocumentComp.is(), "Import: No Model" );
     OSL_ENSURE( m_xContext.is(), "Import: No ComponentContext" );
@@ -338,24 +313,14 @@ sal_Int32 XMLFilter::impl_Import(
         comphelper::PropertyMapEntry const aImportInfoMap[] =
         {
             // necessary properties for XML progress bar at load time
-            { OUString("ProgressRange"),   0, ::cppu::UnoType<sal_Int32>::get(), ::com::sun::star::beans::PropertyAttribute::MAYBEVOID, 0},
-            { OUString("ProgressMax"),     0, ::cppu::UnoType<sal_Int32>::get(), ::com::sun::star::beans::PropertyAttribute::MAYBEVOID, 0},
-            { OUString("ProgressCurrent"), 0, ::cppu::UnoType<sal_Int32>::get(), ::com::sun::star::beans::PropertyAttribute::MAYBEVOID, 0},
-            { OUString("PrivateData"), 0,
-                cppu::UnoType<XInterface>::get(),
-                ::com::sun::star::beans::PropertyAttribute::MAYBEVOID, 0 },
-            { OUString("BaseURI"), 0,
-                ::cppu::UnoType<OUString>::get(),
-                ::com::sun::star::beans::PropertyAttribute::MAYBEVOID, 0 },
-            { OUString("StreamRelPath"), 0,
-                ::cppu::UnoType<OUString>::get(),
-                ::com::sun::star::beans::PropertyAttribute::MAYBEVOID, 0 },
-            { OUString("StreamName"), 0,
-                ::cppu::UnoType<OUString>::get(),
-                ::com::sun::star::beans::PropertyAttribute::MAYBEVOID, 0 },
-            { OUString("BuildId"), 0,
-                ::cppu::UnoType<OUString>::get(),
-                ::com::sun::star::beans::PropertyAttribute::MAYBEVOID, 0 },
+            { OUString("ProgressRange"),   0, cppu::UnoType<sal_Int32>::get(),  css::beans::PropertyAttribute::MAYBEVOID, 0},
+            { OUString("ProgressMax"),     0, cppu::UnoType<sal_Int32>::get(),  css::beans::PropertyAttribute::MAYBEVOID, 0},
+            { OUString("ProgressCurrent"), 0, cppu::UnoType<sal_Int32>::get(),  css::beans::PropertyAttribute::MAYBEVOID, 0},
+            { OUString("PrivateData"),     0, cppu::UnoType<XInterface>::get(), css::beans::PropertyAttribute::MAYBEVOID, 0 },
+            { OUString("BaseURI"),         0, cppu::UnoType<OUString>::get(),   css::beans::PropertyAttribute::MAYBEVOID, 0 },
+            { OUString("StreamRelPath"),   0, cppu::UnoType<OUString>::get(),   css::beans::PropertyAttribute::MAYBEVOID, 0 },
+            { OUString("StreamName"),      0, cppu::UnoType<OUString>::get(),   css::beans::PropertyAttribute::MAYBEVOID, 0 },
+            { OUString("BuildId"),         0, cppu::UnoType<OUString>::get(),   css::beans::PropertyAttribute::MAYBEVOID, 0 },
             { OUString(), 0, css::uno::Type(), 0, 0 }
         };
         uno::Reference< beans::XPropertySet > xImportInfo(
@@ -364,7 +329,7 @@ sal_Int32 XMLFilter::impl_Import(
 
         // Set base URI and Hierarchical Name
         OUString aHierarchName, aBaseUri;
-        // why retrieve this from the model when it's availabe as rMediaDescriptor?
+        // why retrieve this from the model when it's available as rMediaDescriptor?
         uno::Reference<frame::XModel> const xModel(m_xTargetDoc, uno::UNO_QUERY);
         if( xModel.is() )
         {
@@ -383,48 +348,51 @@ sal_Int32 XMLFilter::impl_Import(
             }
         }
 
+        // needed for relative URLs, but in clipboard copy/paste there may be none
+        SAL_INFO_IF(aBaseUri.isEmpty(), "chart2", "chart::XMLFilter: no base URL");
         if( !aBaseUri.isEmpty() )
-            xImportInfo->setPropertyValue( "BaseURI", uno::makeAny( aBaseUri ) );
+            xImportInfo->setPropertyValue( "BaseURI", uno::Any( aBaseUri ) );
 
         if( !aHierarchName.isEmpty() )
-            xImportInfo->setPropertyValue( "StreamRelPath", uno::makeAny( aHierarchName ) );
+            xImportInfo->setPropertyValue( "StreamRelPath", uno::Any( aHierarchName ) );
 
         // import meta information
         if( bOasis )
-            nWarning |= impl_ImportStream(
+            nWarning = impl_ImportStream(
                 sXML_metaStreamName,
-                sXML_import_chart_oasis_meta_service,
+                "com.sun.star.comp.Chart.XMLOasisMetaImporter",
                 xStorage, xSaxParser, xFactory, xGraphicObjectResolver, xImportInfo );
 
         // import styles
-        nWarning |= impl_ImportStream(
+        ErrCode nTmpErr = impl_ImportStream(
             sXML_styleStreamName,
             bOasis
-            ? OUString(sXML_import_chart_oasis_styles_service)
-            : OUString(sXML_import_chart_styles_service),
+            ? OUString("com.sun.star.comp.Chart.XMLOasisStylesImporter")
+            : OUString("com.sun.star.comp.Chart.XMLStylesImporter"),
             xStorage, xSaxParser, xFactory, xGraphicObjectResolver, xImportInfo );
+        nWarning = nWarning != ERRCODE_NONE ? nWarning : nTmpErr;
 
         // import content
-        sal_Int32 nContentWarning = impl_ImportStream(
+        ErrCode nContentWarning = impl_ImportStream(
             sXML_contentStreamName,
             bOasis
-            ? OUString(sXML_import_chart_oasis_content_service)
-            : OUString(sXML_import_chart_content_service),
+            ? OUString("com.sun.star.comp.Chart.XMLOasisContentImporter")
+            : OUString("com.sun.star.comp.Chart.XMLContentImporter"),
             xStorage, xSaxParser, xFactory, xGraphicObjectResolver, xImportInfo );
-        nWarning |= nContentWarning;
+        nWarning = nWarning != ERRCODE_NONE ? nWarning : nContentWarning;
 
         // import of "content.xml" didn't work - try old "Content.xml" stream
-        if( nContentWarning != 0 )
+        if( nContentWarning != ERRCODE_NONE )
         {
             nWarning = impl_ImportStream(
-                sXML_oldContentStreamName,
-                sXML_import_chart_old_content_service,
+                "Content.xml", // old content stream name
+                "com.sun.star.office.sax.importer.Chart",
                 xStorage, xSaxParser, xFactory, xGraphicObjectResolver, xImportInfo );
         }
     }
     catch (const uno::Exception& ex)
     {
-        ASSERT_EXCEPTION( ex );
+        SAL_WARN("chart2", "Exception caught. " << ex );
 
         // something went awry
         nWarning = ERRCODE_SFX_GENERAL;
@@ -433,24 +401,24 @@ sal_Int32 XMLFilter::impl_Import(
     return nWarning;
 }
 
-sal_Int32 XMLFilter::impl_ImportStream(
+ErrCode XMLFilter::impl_ImportStream(
     const OUString & rStreamName,
     const OUString & rServiceName,
     const Reference< embed::XStorage > & xStorage,
     const Reference< xml::sax::XParser > & xParser,
     const Reference< lang::XMultiComponentFactory > & xFactory,
     const Reference< document::XGraphicObjectResolver > & xGraphicObjectResolver,
-    uno::Reference< beans::XPropertySet >& xImportInfo )
+    uno::Reference< beans::XPropertySet > const & xImportInfo )
 {
-    sal_Int32 nWarning = ERRCODE_SFX_GENERAL;
+    ErrCode nWarning = ERRCODE_SFX_GENERAL;
 
     Reference< container::XNameAccess > xNameAcc( xStorage, uno::UNO_QUERY );
     if( ! (xNameAcc.is() &&
            xNameAcc->hasByName( rStreamName )))
-        return 0;
+        return ERRCODE_NONE;
 
     if( xImportInfo.is() )
-        xImportInfo->setPropertyValue( "StreamName", uno::makeAny( rStreamName ) );
+        xImportInfo->setPropertyValue( "StreamName", uno::Any( rStreamName ) );
 
     if( xStorage.is() &&
         xStorage->isStreamElement( rStreamName ) )
@@ -515,7 +483,7 @@ sal_Int32 XMLFilter::impl_ImportStream(
             }
 
             // load was successful
-            nWarning = 0;
+            nWarning = ERRCODE_NONE;
         }
         catch (const xml::sax::SAXParseException&)
         {
@@ -534,21 +502,21 @@ sal_Int32 XMLFilter::impl_ImportStream(
         }
         catch (const uno::Exception& rEx)
         {
-            ASSERT_EXCEPTION(rEx);
+            SAL_WARN("chart2", "Exception caught. " << rEx);
         }
     }
 
     return nWarning;
 }
 
-sal_Int32 XMLFilter::impl_Export(
+ErrCode XMLFilter::impl_Export(
     const Reference< lang::XComponent > & xDocumentComp,
     const Sequence< beans::PropertyValue > & rMediaDescriptor )
 {
     m_aMediaDescriptor = rMediaDescriptor;
     //save
 
-    sal_Int32 nWarning = 0;
+    ErrCode nWarning = ERRCODE_NONE;
 
     OSL_ENSURE( xDocumentComp.is(), "Export: No Model" );
     OSL_ENSURE( m_xContext.is(), "Export: No ComponentContext" );
@@ -625,11 +593,10 @@ sal_Int32 XMLFilter::impl_Export(
             comphelper::GenericPropertySet_CreateInstance( new comphelper::PropertySetInfo( aExportInfoMap ) );
 
         SvtSaveOptions aSaveOpt;
-        OUString sUsePrettyPrinting( "UsePrettyPrinting" );
         bool bUsePrettyPrinting( aSaveOpt.IsPrettyPrinting() );
-        xInfoSet->setPropertyValue( sUsePrettyPrinting, uno::makeAny( bUsePrettyPrinting ) );
+        xInfoSet->setPropertyValue( "UsePrettyPrinting", uno::Any( bUsePrettyPrinting ) );
         if( ! bOasis )
-            xInfoSet->setPropertyValue( "ExportTableNumberList", uno::makeAny( true ));
+            xInfoSet->setPropertyValue( "ExportTableNumberList", uno::Any( true ));
 
         sal_Int32 nArgs = 2;
         if( xGraphicObjectResolver.is())
@@ -646,27 +613,28 @@ sal_Int32 XMLFilter::impl_Export(
 
         // export meta information
         if( bOasis )
-            nWarning |= impl_ExportStream(
+            nWarning = impl_ExportStream(
                 sXML_metaStreamName,
-                sXML_export_chart_oasis_meta_service,
+                "com.sun.star.comp.Chart.XMLOasisMetaExporter",
                 xStorage, xSaxWriter, xServiceFactory, aFilterProperties );
 
         // export styles
-        nWarning |= impl_ExportStream(
+        ErrCode nTmp = impl_ExportStream(
             sXML_styleStreamName,
             bOasis
-            ? OUString(sXML_export_chart_oasis_styles_service)
-            : OUString(sXML_export_chart_styles_service),
+            ? OUString("com.sun.star.comp.Chart.XMLOasisStylesExporter")
+            : OUString("com.sun.star.comp.Chart.XMLStylesExporter"), // soffice 6/7
             xStorage, xSaxWriter, xServiceFactory, aFilterProperties );
+        nWarning = nWarning != ERRCODE_NONE ? nWarning : nTmp;
 
         // export content
-        sal_Int32 nContentWarning = impl_ExportStream(
+        ErrCode nContentWarning = impl_ExportStream(
             sXML_contentStreamName,
             bOasis
-            ? OUString(sXML_export_chart_oasis_content_service)
-            : OUString(sXML_export_chart_content_service),
+            ? OUString("com.sun.star.comp.Chart.XMLOasisContentExporter")
+            : OUString("com.sun.star.comp.Chart.XMLContentExporter"),
             xStorage, xSaxWriter, xServiceFactory, aFilterProperties );
-        nWarning |= nContentWarning;
+        nWarning = nWarning != ERRCODE_NONE ? nWarning : nContentWarning;
 
         Reference< lang::XComponent > xComp( xGraphicObjectResolver, uno::UNO_QUERY );
         if( xComp.is())
@@ -678,7 +646,7 @@ sal_Int32 XMLFilter::impl_Export(
     }
     catch (const uno::Exception& ex)
     {
-        ASSERT_EXCEPTION( ex );
+        SAL_WARN("chart2", "Exception caught. " << ex );
 
         // something went awry
         nWarning = ERRCODE_SFX_GENERAL;
@@ -687,7 +655,7 @@ sal_Int32 XMLFilter::impl_Export(
     return nWarning;
 }
 
-sal_Int32 XMLFilter::impl_ExportStream(
+ErrCode XMLFilter::impl_ExportStream(
     const OUString & rStreamName,
     const OUString & rServiceName,
     const Reference< embed::XStorage > & xStorage,
@@ -695,8 +663,6 @@ sal_Int32 XMLFilter::impl_ExportStream(
     const Reference< lang::XMultiServiceFactory >& xServiceFactory,
     const Sequence< uno::Any > & rFilterProperties )
 {
-    sal_Int32 nWarning = 0;
-
     try
     {
         if( !xServiceFactory.is() )
@@ -717,13 +683,13 @@ sal_Int32 XMLFilter::impl_ExportStream(
         uno::Reference< beans::XPropertySet > xStreamProp( xOutputStream, uno::UNO_QUERY );
         if(xStreamProp.is()) try
         {
-            xStreamProp->setPropertyValue( "MediaType", uno::makeAny( OUString("text/xml") ) );
-            xStreamProp->setPropertyValue( "Compressed", uno::makeAny( sal_True ) );//@todo?
-            xStreamProp->setPropertyValue( "UseCommonStoragePasswordEncryption", uno::makeAny( sal_True ) );
+            xStreamProp->setPropertyValue( "MediaType", uno::Any( OUString("text/xml") ) );
+            xStreamProp->setPropertyValue( "Compressed", uno::Any( true ) );//@todo?
+            xStreamProp->setPropertyValue( "UseCommonStoragePasswordEncryption", uno::Any( true ) );
         }
         catch (const uno::Exception& rEx)
         {
-            ASSERT_EXCEPTION( rEx );
+            SAL_WARN("chart2", "Exception caught. " << rEx );
         }
 
         xActiveDataSource->setOutputStream(xOutputStream);
@@ -735,7 +701,7 @@ sal_Int32 XMLFilter::impl_ExportStream(
                 rFilterProperties.getConstArray()[0] >>= xInfoSet;
             OSL_ENSURE( xInfoSet.is(), "missing infoset for export" );
             if( xInfoSet.is() )
-                xInfoSet->setPropertyValue( "StreamName", uno::makeAny( rStreamName ) );
+                xInfoSet->setPropertyValue( "StreamName", uno::Any( rStreamName ) );
         }
 
         Reference< XExporter > xExporter( xServiceFactory->createInstanceWithArguments(
@@ -753,20 +719,9 @@ sal_Int32 XMLFilter::impl_ExportStream(
     }
     catch (const uno::Exception& rEx)
     {
-        ASSERT_EXCEPTION( rEx );
+        SAL_WARN("chart2", "Exception caught. " << rEx );
     }
-    return nWarning;
-}
-
-Sequence< OUString > XMLFilter::getSupportedServiceNames_Static()
-{
-    Sequence< OUString > aServices( 2 );
-    aServices[ 0 ] = "com.sun.star.document.ImportFilter";
-    aServices[ 1 ] = "com.sun.star.document.ExportFilter";
-
-    // todo: services are incomplete.  Missing:
-    // XInitialization, XNamed
-    return aServices;
+    return ERRCODE_NONE;
 }
 
 void XMLFilter::isOasisFormat(const Sequence< beans::PropertyValue >& _rMediaDescriptor, bool & rOutOASIS )
@@ -781,26 +736,23 @@ OUString XMLFilter::getMediaType(bool _bOasis)
 }
 
 OUString SAL_CALL XMLFilter::getImplementationName()
-    throw( css::uno::RuntimeException, std::exception )
-{
-    return getImplementationName_Static();
-}
-
-OUString XMLFilter::getImplementationName_Static()
 {
     return OUString("com.sun.star.comp.chart2.XMLFilter");
 }
 
 sal_Bool SAL_CALL XMLFilter::supportsService( const OUString& rServiceName )
-    throw( css::uno::RuntimeException, std::exception )
 {
     return cppu::supportsService(this, rServiceName);
 }
 
 css::uno::Sequence< OUString > SAL_CALL XMLFilter::getSupportedServiceNames()
-    throw( css::uno::RuntimeException, std::exception )
 {
-    return getSupportedServiceNames_Static();
+    return {
+        "com.sun.star.document.ImportFilter",
+        "com.sun.star.document.ExportFilter"
+    };
+    // todo: services are incomplete.  Missing:
+    // XInitialization, XNamed
 }
 
 void XMLReportFilterHelper::isOasisFormat(const Sequence< beans::PropertyValue >& _rMediaDescriptor, bool & rOutOASIS )
