@@ -17,12 +17,10 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "ChartTypeManager.hxx"
-#include "macros.hxx"
-#include "StackMode.hxx"
-#include "ContainerHelper.hxx"
+#include <ChartTypeManager.hxx>
+#include <StackMode.hxx>
 
-#include "CartesianCoordinateSystem.hxx"
+#include <CartesianCoordinateSystem.hxx>
 
 #include "LineChartTypeTemplate.hxx"
 #include "BarChartTypeTemplate.hxx"
@@ -33,10 +31,12 @@
 #include "StockChartTypeTemplate.hxx"
 #include "NetChartTypeTemplate.hxx"
 #include "BubbleChartTypeTemplate.hxx"
+#include <config_features.h>
+#if HAVE_FEATURE_OPENGL
 #include "GL3DBarChartTypeTemplate.hxx"
+#endif
 #include <cppuhelper/component_context.hxx>
 #include <cppuhelper/supportsservice.hxx>
-#include <comphelper/InlineContainer.hxx>
 #include <com/sun/star/container/XContentEnumerationAccess.hpp>
 #include <com/sun/star/lang/XServiceName.hpp>
 #include <com/sun/star/chart/ChartSolidType.hpp>
@@ -46,13 +46,11 @@
 #include <iterator>
 #include <functional>
 #include <o3tl/functional.hxx>
+#include <map>
 
 using namespace ::com::sun::star;
 
 using ::com::sun::star::uno::Sequence;
-using ::com::sun::star::uno::Reference;
-using ::com::sun::star::uno::Any;
-using ::osl::MutexGuard;
 
 namespace
 {
@@ -130,82 +128,80 @@ enum TemplateId
     TEMPLATE_NOT_FOUND = 0xffff
 };
 
-typedef ::std::map< OUString, TemplateId > tTemplateMapType;
+typedef std::map< OUString, TemplateId > tTemplateMapType;
 
 const tTemplateMapType & lcl_DefaultChartTypeMap()
 {
-    static const tTemplateMapType aMap = tTemplateMapType(
-        ::comphelper::MakeMap< tTemplateMapType::key_type, tTemplateMapType::mapped_type >
-        ( "com.sun.star.chart2.template.Symbol",                         TEMPLATE_SYMBOL )
-        ( "com.sun.star.chart2.template.StackedSymbol",                  TEMPLATE_STACKEDSYMBOL )
-        ( "com.sun.star.chart2.template.PercentStackedSymbol",           TEMPLATE_PERCENTSTACKEDSYMBOL )
-        ( "com.sun.star.chart2.template.Line",                           TEMPLATE_LINE )
-        ( "com.sun.star.chart2.template.StackedLine",                    TEMPLATE_STACKEDLINE )
-        ( "com.sun.star.chart2.template.PercentStackedLine",             TEMPLATE_PERCENTSTACKEDLINE )
-        ( "com.sun.star.chart2.template.LineSymbol",                     TEMPLATE_LINESYMBOL )
-        ( "com.sun.star.chart2.template.StackedLineSymbol",              TEMPLATE_STACKEDLINESYMBOL )
-        ( "com.sun.star.chart2.template.PercentStackedLineSymbol",       TEMPLATE_PERCENTSTACKEDLINESYMBOL )
-        ( "com.sun.star.chart2.template.ThreeDLine",                     TEMPLATE_THREEDLINE )
-        ( "com.sun.star.chart2.template.StackedThreeDLine",              TEMPLATE_STACKEDTHREEDLINE )
-        ( "com.sun.star.chart2.template.PercentStackedThreeDLine",       TEMPLATE_PERCENTSTACKEDTHREEDLINE )
-        ( "com.sun.star.chart2.template.ThreeDLineDeep",                 TEMPLATE_THREEDLINEDEEP )
-        ( "com.sun.star.chart2.template.Column",                         TEMPLATE_COLUMN )
-        ( "com.sun.star.chart2.template.StackedColumn",                  TEMPLATE_STACKEDCOLUMN )
-        ( "com.sun.star.chart2.template.PercentStackedColumn",           TEMPLATE_PERCENTSTACKEDCOLUMN )
-        ( "com.sun.star.chart2.template.Bar",                            TEMPLATE_BAR )
-        ( "com.sun.star.chart2.template.StackedBar",                     TEMPLATE_STACKEDBAR )
-        ( "com.sun.star.chart2.template.PercentStackedBar",              TEMPLATE_PERCENTSTACKEDBAR )
-        ( "com.sun.star.chart2.template.ThreeDColumnDeep",               TEMPLATE_THREEDCOLUMNDEEP )
-        ( "com.sun.star.chart2.template.ThreeDColumnFlat",               TEMPLATE_THREEDCOLUMNFLAT )
-        ( "com.sun.star.chart2.template.StackedThreeDColumnFlat",        TEMPLATE_STACKEDTHREEDCOLUMNFLAT )
-        ( "com.sun.star.chart2.template.PercentStackedThreeDColumnFlat", TEMPLATE_PERCENTSTACKEDTHREEDCOLUMNFLAT )
-        ( "com.sun.star.chart2.template.ThreeDBarDeep",                  TEMPLATE_THREEDBARDEEP )
-        ( "com.sun.star.chart2.template.ThreeDBarFlat",                  TEMPLATE_THREEDBARFLAT )
-        ( "com.sun.star.chart2.template.StackedThreeDBarFlat",           TEMPLATE_STACKEDTHREEDBARFLAT )
-        ( "com.sun.star.chart2.template.PercentStackedThreeDBarFlat",    TEMPLATE_PERCENTSTACKEDTHREEDBARFLAT )
-        ( "com.sun.star.chart2.template.ColumnWithLine",                 TEMPLATE_COLUMNWITHLINE )
-        ( "com.sun.star.chart2.template.StackedColumnWithLine",          TEMPLATE_STACKEDCOLUMNWITHLINE )
-        ( "com.sun.star.chart2.template.Area",                           TEMPLATE_AREA )
-        ( "com.sun.star.chart2.template.StackedArea",                    TEMPLATE_STACKEDAREA )
-        ( "com.sun.star.chart2.template.PercentStackedArea",             TEMPLATE_PERCENTSTACKEDAREA )
-        ( "com.sun.star.chart2.template.ThreeDArea",                     TEMPLATE_THREEDAREA )
-        ( "com.sun.star.chart2.template.StackedThreeDArea",              TEMPLATE_STACKEDTHREEDAREA )
-        ( "com.sun.star.chart2.template.PercentStackedThreeDArea",       TEMPLATE_PERCENTSTACKEDTHREEDAREA )
-        ( "com.sun.star.chart2.template.Pie",                            TEMPLATE_PIE )
-        ( "com.sun.star.chart2.template.PieAllExploded",                 TEMPLATE_PIEALLEXPLODED )
-        ( "com.sun.star.chart2.template.Donut",                          TEMPLATE_DONUT )
-        ( "com.sun.star.chart2.template.DonutAllExploded",               TEMPLATE_DONUTALLEXPLODED )
-        ( "com.sun.star.chart2.template.ThreeDPie",                      TEMPLATE_THREEDPIE )
-        ( "com.sun.star.chart2.template.ThreeDPieAllExploded",           TEMPLATE_THREEDPIEALLEXPLODED )
-        ( "com.sun.star.chart2.template.ThreeDDonut",                    TEMPLATE_THREEDDONUT )
-        ( "com.sun.star.chart2.template.ThreeDDonutAllExploded",         TEMPLATE_THREEDDONUTALLEXPLODED )
-        ( "com.sun.star.chart2.template.ScatterLineSymbol",              TEMPLATE_SCATTERLINESYMBOL )
-        ( "com.sun.star.chart2.template.ScatterLine",                    TEMPLATE_SCATTERLINE )
-        ( "com.sun.star.chart2.template.ScatterSymbol",                  TEMPLATE_SCATTERSYMBOL )
-        ( "com.sun.star.chart2.template.ThreeDScatter",                  TEMPLATE_THREEDSCATTER )
-        ( "com.sun.star.chart2.template.Net",                            TEMPLATE_NET )
-        ( "com.sun.star.chart2.template.NetSymbol",                      TEMPLATE_NETSYMBOL )
-        ( "com.sun.star.chart2.template.NetLine",                        TEMPLATE_NETLINE )
-        ( "com.sun.star.chart2.template.StackedNet",                     TEMPLATE_STACKEDNET )
-        ( "com.sun.star.chart2.template.StackedNetSymbol",               TEMPLATE_STACKEDNETSYMBOL )
-        ( "com.sun.star.chart2.template.StackedNetLine",                 TEMPLATE_STACKEDNETLINE )
-        ( "com.sun.star.chart2.template.PercentStackedNet",              TEMPLATE_PERCENTSTACKEDNET )
-        ( "com.sun.star.chart2.template.PercentStackedNetSymbol",        TEMPLATE_PERCENTSTACKEDNETSYMBOL )
-        ( "com.sun.star.chart2.template.PercentStackedNetLine",          TEMPLATE_PERCENTSTACKEDNETLINE )
-        ( "com.sun.star.chart2.template.FilledNet",                      TEMPLATE_FILLEDNET )
-        ( "com.sun.star.chart2.template.StackedFilledNet",               TEMPLATE_STACKEDFILLEDNET )
-        ( "com.sun.star.chart2.template.PercentStackedFilledNet",        TEMPLATE_PERCENTSTACKEDFILLEDNET )
-        ( "com.sun.star.chart2.template.StockLowHighClose",              TEMPLATE_STOCKLOWHIGHCLOSE )
-        ( "com.sun.star.chart2.template.StockOpenLowHighClose",          TEMPLATE_STOCKOPENLOWHIGHCLOSE )
-        ( "com.sun.star.chart2.template.StockVolumeLowHighClose",        TEMPLATE_STOCKVOLUMELOWHIGHCLOSE )
-        ( "com.sun.star.chart2.template.StockVolumeOpenLowHighClose",    TEMPLATE_STOCKVOLUMEOPENLOWHIGHCLOSE )
-        ( "com.sun.star.chart2.template.Bubble",                         TEMPLATE_BUBBLE )
-        ( "com.sun.star.chart2.template.GL3DBar",                        TEMPLATE_GL3DBAR )
-        ( "com.sun.star.chart2.template.GL3DBarRoundedRectangle",        TEMPLATE_GL3DBAR_ROUNDED_RECTANGLE )
-//      ( "com.sun.star.chart2.template.Surface",                        TEMPLATE_SURFACE )
-//      ( "com.sun.star.chart2.template.Addin",                          TEMPLATE_ADDIN )
-        );
-
+    static const tTemplateMapType aMap{
+        {"com.sun.star.chart2.template.Symbol",                         TEMPLATE_SYMBOL},
+        {"com.sun.star.chart2.template.StackedSymbol",                  TEMPLATE_STACKEDSYMBOL},
+        {"com.sun.star.chart2.template.PercentStackedSymbol",           TEMPLATE_PERCENTSTACKEDSYMBOL},
+        {"com.sun.star.chart2.template.Line",                           TEMPLATE_LINE},
+        {"com.sun.star.chart2.template.StackedLine",                    TEMPLATE_STACKEDLINE},
+        {"com.sun.star.chart2.template.PercentStackedLine",             TEMPLATE_PERCENTSTACKEDLINE},
+        {"com.sun.star.chart2.template.LineSymbol",                     TEMPLATE_LINESYMBOL},
+        {"com.sun.star.chart2.template.StackedLineSymbol",              TEMPLATE_STACKEDLINESYMBOL},
+        {"com.sun.star.chart2.template.PercentStackedLineSymbol",       TEMPLATE_PERCENTSTACKEDLINESYMBOL},
+        {"com.sun.star.chart2.template.ThreeDLine",                     TEMPLATE_THREEDLINE},
+        {"com.sun.star.chart2.template.StackedThreeDLine",              TEMPLATE_STACKEDTHREEDLINE},
+        {"com.sun.star.chart2.template.PercentStackedThreeDLine",       TEMPLATE_PERCENTSTACKEDTHREEDLINE},
+        {"com.sun.star.chart2.template.ThreeDLineDeep",                 TEMPLATE_THREEDLINEDEEP},
+        {"com.sun.star.chart2.template.Column",                         TEMPLATE_COLUMN},
+        {"com.sun.star.chart2.template.StackedColumn",                  TEMPLATE_STACKEDCOLUMN},
+        {"com.sun.star.chart2.template.PercentStackedColumn",           TEMPLATE_PERCENTSTACKEDCOLUMN},
+        {"com.sun.star.chart2.template.Bar",                            TEMPLATE_BAR},
+        {"com.sun.star.chart2.template.StackedBar",                     TEMPLATE_STACKEDBAR},
+        {"com.sun.star.chart2.template.PercentStackedBar",              TEMPLATE_PERCENTSTACKEDBAR},
+        {"com.sun.star.chart2.template.ThreeDColumnDeep",               TEMPLATE_THREEDCOLUMNDEEP},
+        {"com.sun.star.chart2.template.ThreeDColumnFlat",               TEMPLATE_THREEDCOLUMNFLAT},
+        {"com.sun.star.chart2.template.StackedThreeDColumnFlat",        TEMPLATE_STACKEDTHREEDCOLUMNFLAT},
+        {"com.sun.star.chart2.template.PercentStackedThreeDColumnFlat", TEMPLATE_PERCENTSTACKEDTHREEDCOLUMNFLAT},
+        {"com.sun.star.chart2.template.ThreeDBarDeep",                  TEMPLATE_THREEDBARDEEP},
+        {"com.sun.star.chart2.template.ThreeDBarFlat",                  TEMPLATE_THREEDBARFLAT},
+        {"com.sun.star.chart2.template.StackedThreeDBarFlat",           TEMPLATE_STACKEDTHREEDBARFLAT},
+        {"com.sun.star.chart2.template.PercentStackedThreeDBarFlat",    TEMPLATE_PERCENTSTACKEDTHREEDBARFLAT},
+        {"com.sun.star.chart2.template.ColumnWithLine",                 TEMPLATE_COLUMNWITHLINE},
+        {"com.sun.star.chart2.template.StackedColumnWithLine",          TEMPLATE_STACKEDCOLUMNWITHLINE},
+        {"com.sun.star.chart2.template.Area",                           TEMPLATE_AREA},
+        {"com.sun.star.chart2.template.StackedArea",                    TEMPLATE_STACKEDAREA},
+        {"com.sun.star.chart2.template.PercentStackedArea",             TEMPLATE_PERCENTSTACKEDAREA},
+        {"com.sun.star.chart2.template.ThreeDArea",                     TEMPLATE_THREEDAREA},
+        {"com.sun.star.chart2.template.StackedThreeDArea",              TEMPLATE_STACKEDTHREEDAREA},
+        {"com.sun.star.chart2.template.PercentStackedThreeDArea",       TEMPLATE_PERCENTSTACKEDTHREEDAREA},
+        {"com.sun.star.chart2.template.Pie",                            TEMPLATE_PIE},
+        {"com.sun.star.chart2.template.PieAllExploded",                 TEMPLATE_PIEALLEXPLODED},
+        {"com.sun.star.chart2.template.Donut",                          TEMPLATE_DONUT},
+        {"com.sun.star.chart2.template.DonutAllExploded",               TEMPLATE_DONUTALLEXPLODED},
+        {"com.sun.star.chart2.template.ThreeDPie",                      TEMPLATE_THREEDPIE},
+        {"com.sun.star.chart2.template.ThreeDPieAllExploded",           TEMPLATE_THREEDPIEALLEXPLODED},
+        {"com.sun.star.chart2.template.ThreeDDonut",                    TEMPLATE_THREEDDONUT},
+        {"com.sun.star.chart2.template.ThreeDDonutAllExploded",         TEMPLATE_THREEDDONUTALLEXPLODED},
+        {"com.sun.star.chart2.template.ScatterLineSymbol",              TEMPLATE_SCATTERLINESYMBOL},
+        {"com.sun.star.chart2.template.ScatterLine",                    TEMPLATE_SCATTERLINE},
+        {"com.sun.star.chart2.template.ScatterSymbol",                  TEMPLATE_SCATTERSYMBOL},
+        {"com.sun.star.chart2.template.ThreeDScatter",                  TEMPLATE_THREEDSCATTER},
+        {"com.sun.star.chart2.template.Net",                            TEMPLATE_NET},
+        {"com.sun.star.chart2.template.NetSymbol",                      TEMPLATE_NETSYMBOL},
+        {"com.sun.star.chart2.template.NetLine",                        TEMPLATE_NETLINE},
+        {"com.sun.star.chart2.template.StackedNet",                     TEMPLATE_STACKEDNET},
+        {"com.sun.star.chart2.template.StackedNetSymbol",               TEMPLATE_STACKEDNETSYMBOL},
+        {"com.sun.star.chart2.template.StackedNetLine",                 TEMPLATE_STACKEDNETLINE},
+        {"com.sun.star.chart2.template.PercentStackedNet",              TEMPLATE_PERCENTSTACKEDNET},
+        {"com.sun.star.chart2.template.PercentStackedNetSymbol",        TEMPLATE_PERCENTSTACKEDNETSYMBOL},
+        {"com.sun.star.chart2.template.PercentStackedNetLine",          TEMPLATE_PERCENTSTACKEDNETLINE},
+        {"com.sun.star.chart2.template.FilledNet",                      TEMPLATE_FILLEDNET},
+        {"com.sun.star.chart2.template.StackedFilledNet",               TEMPLATE_STACKEDFILLEDNET},
+        {"com.sun.star.chart2.template.PercentStackedFilledNet",        TEMPLATE_PERCENTSTACKEDFILLEDNET},
+        {"com.sun.star.chart2.template.StockLowHighClose",              TEMPLATE_STOCKLOWHIGHCLOSE},
+        {"com.sun.star.chart2.template.StockOpenLowHighClose",          TEMPLATE_STOCKOPENLOWHIGHCLOSE},
+        {"com.sun.star.chart2.template.StockVolumeLowHighClose",        TEMPLATE_STOCKVOLUMELOWHIGHCLOSE},
+        {"com.sun.star.chart2.template.StockVolumeOpenLowHighClose",    TEMPLATE_STOCKVOLUMEOPENLOWHIGHCLOSE},
+        {"com.sun.star.chart2.template.Bubble",                         TEMPLATE_BUBBLE},
+        {"com.sun.star.chart2.template.GL3DBar",                        TEMPLATE_GL3DBAR},
+        {"com.sun.star.chart2.template.GL3DBarRoundedRectangle",        TEMPLATE_GL3DBAR_ROUNDED_RECTANGLE},
+//      {"com.sun.star.chart2.template.Surface",                        TEMPLATE_SURFACE},
+//      {"com.sun.star.chart2.template.Addin",                          TEMPLATE_ADDIN},
+        };
     return aMap;
 }
 
@@ -238,8 +234,6 @@ ChartTypeManager::~ChartTypeManager()
 // ____ XMultiServiceFactory ____
 uno::Reference< uno::XInterface > SAL_CALL ChartTypeManager::createInstance(
     const OUString& aServiceSpecifier )
-    throw (uno::Exception,
-           uno::RuntimeException, std::exception)
 {
     uno::Reference< uno::XInterface > xResult;
     TemplateId nId = lcl_GetTemplateIdForService( aServiceSpecifier );
@@ -259,7 +253,7 @@ uno::Reference< uno::XInterface > SAL_CALL ChartTypeManager::createInstance(
             // As XMultiServiceFactory does not specify, what to do in case
             // createInstance is called with an unknown service-name, this
             // function will just return an empty XInterface.
-            ASSERT_EXCEPTION( ex );
+            SAL_WARN("chart2", "Exception caught. " << ex );
             SAL_WARN("chart2", "Couldn't instantiate service: "<< aServiceSpecifier );
             xResult.set( nullptr );
         }
@@ -272,114 +266,114 @@ uno::Reference< uno::XInterface > SAL_CALL ChartTypeManager::createInstance(
             // Point (category x axis)
             case TEMPLATE_SYMBOL:
                 xTemplate.set( new LineChartTypeTemplate( m_xContext, aServiceSpecifier,
-                    StackMode_NONE, true, false ));
+                    StackMode::NONE, true, false ));
                 break;
             case TEMPLATE_STACKEDSYMBOL:
                 xTemplate.set( new LineChartTypeTemplate( m_xContext, aServiceSpecifier,
-                    StackMode_Y_STACKED, true, false ));
+                    StackMode::YStacked, true, false ));
                 break;
             case TEMPLATE_PERCENTSTACKEDSYMBOL:
                 xTemplate.set( new LineChartTypeTemplate( m_xContext, aServiceSpecifier,
-                    StackMode_Y_STACKED_PERCENT, true, false ));
+                    StackMode::YStackedPercent, true, false ));
                 break;
             // Line (category x axis)
             case TEMPLATE_LINE:
                 xTemplate.set( new LineChartTypeTemplate( m_xContext, aServiceSpecifier,
-                    StackMode_NONE, false ));
+                    StackMode::NONE, false ));
                 break;
             case TEMPLATE_STACKEDLINE:
                 xTemplate.set( new LineChartTypeTemplate( m_xContext, aServiceSpecifier,
-                    StackMode_Y_STACKED, false ));
+                    StackMode::YStacked, false ));
                 break;
             case TEMPLATE_PERCENTSTACKEDLINE:
                 xTemplate.set( new LineChartTypeTemplate( m_xContext, aServiceSpecifier,
-                    StackMode_Y_STACKED_PERCENT, false ));
+                    StackMode::YStackedPercent, false ));
                 break;
             case TEMPLATE_LINESYMBOL:
                 xTemplate.set( new LineChartTypeTemplate( m_xContext, aServiceSpecifier,
-                    StackMode_NONE, true ));
+                    StackMode::NONE, true ));
                 break;
             case TEMPLATE_STACKEDLINESYMBOL:
                 xTemplate.set( new LineChartTypeTemplate( m_xContext, aServiceSpecifier,
-                    StackMode_Y_STACKED, true ));
+                    StackMode::YStacked, true ));
                 break;
             case TEMPLATE_PERCENTSTACKEDLINESYMBOL:
                 xTemplate.set( new LineChartTypeTemplate( m_xContext, aServiceSpecifier,
-                    StackMode_Y_STACKED_PERCENT, true ));
+                    StackMode::YStackedPercent, true ));
                 break;
             case TEMPLATE_THREEDLINE:
                 xTemplate.set( new LineChartTypeTemplate( m_xContext, aServiceSpecifier,
-                    StackMode_NONE, false, true, 3 ));
+                    StackMode::NONE, false, true, 3 ));
                 break;
             case TEMPLATE_STACKEDTHREEDLINE:
                 xTemplate.set( new LineChartTypeTemplate( m_xContext, aServiceSpecifier,
-                    StackMode_Y_STACKED, false, true, 3 ));
+                    StackMode::YStacked, false, true, 3 ));
                 break;
             case TEMPLATE_PERCENTSTACKEDTHREEDLINE:
                 xTemplate.set( new LineChartTypeTemplate( m_xContext, aServiceSpecifier,
-                    StackMode_Y_STACKED_PERCENT, false, true, 3 ));
+                    StackMode::YStackedPercent, false, true, 3 ));
                 break;
             case TEMPLATE_THREEDLINEDEEP:
                 xTemplate.set( new LineChartTypeTemplate( m_xContext, aServiceSpecifier,
-                    StackMode_Z_STACKED, false, true, 3 ));
+                    StackMode::ZStacked, false, true, 3 ));
                 break;
 
             // Bar/Column
             case TEMPLATE_COLUMN:
                 xTemplate.set( new BarChartTypeTemplate( m_xContext, aServiceSpecifier,
-                    StackMode_NONE, BarChartTypeTemplate::VERTICAL ));
+                    StackMode::NONE, BarChartTypeTemplate::VERTICAL ));
                 break;
             case TEMPLATE_STACKEDCOLUMN:
                 xTemplate.set( new BarChartTypeTemplate( m_xContext, aServiceSpecifier,
-                    StackMode_Y_STACKED, BarChartTypeTemplate::VERTICAL ));
+                    StackMode::YStacked, BarChartTypeTemplate::VERTICAL ));
                 break;
             case TEMPLATE_PERCENTSTACKEDCOLUMN:
                 xTemplate.set( new BarChartTypeTemplate( m_xContext, aServiceSpecifier,
-                    StackMode_Y_STACKED_PERCENT, BarChartTypeTemplate::VERTICAL ));
+                    StackMode::YStackedPercent, BarChartTypeTemplate::VERTICAL ));
                 break;
             case TEMPLATE_BAR:
                 xTemplate.set( new BarChartTypeTemplate( m_xContext, aServiceSpecifier,
-                    StackMode_NONE, BarChartTypeTemplate::HORIZONTAL ));
+                    StackMode::NONE, BarChartTypeTemplate::HORIZONTAL ));
                 break;
             case TEMPLATE_STACKEDBAR:
                 xTemplate.set( new BarChartTypeTemplate( m_xContext, aServiceSpecifier,
-                    StackMode_Y_STACKED, BarChartTypeTemplate::HORIZONTAL ));
+                    StackMode::YStacked, BarChartTypeTemplate::HORIZONTAL ));
                 break;
             case TEMPLATE_PERCENTSTACKEDBAR:
                 xTemplate.set( new BarChartTypeTemplate( m_xContext, aServiceSpecifier,
-                    StackMode_Y_STACKED_PERCENT, BarChartTypeTemplate::HORIZONTAL ));
+                    StackMode::YStackedPercent, BarChartTypeTemplate::HORIZONTAL ));
                 break;
             case TEMPLATE_THREEDCOLUMNDEEP:
                 xTemplate.set( new BarChartTypeTemplate( m_xContext, aServiceSpecifier,
-                    StackMode_Z_STACKED, BarChartTypeTemplate::VERTICAL, 3 ));
+                    StackMode::ZStacked, BarChartTypeTemplate::VERTICAL, 3 ));
                 break;
             case TEMPLATE_THREEDCOLUMNFLAT:
                 xTemplate.set( new BarChartTypeTemplate( m_xContext, aServiceSpecifier,
-                    StackMode_NONE, BarChartTypeTemplate::VERTICAL, 3 ));
+                    StackMode::NONE, BarChartTypeTemplate::VERTICAL, 3 ));
                 break;
             case TEMPLATE_STACKEDTHREEDCOLUMNFLAT:
                 xTemplate.set( new BarChartTypeTemplate( m_xContext, aServiceSpecifier,
-                    StackMode_Y_STACKED, BarChartTypeTemplate::VERTICAL, 3 ));
+                    StackMode::YStacked, BarChartTypeTemplate::VERTICAL, 3 ));
                 break;
             case TEMPLATE_PERCENTSTACKEDTHREEDCOLUMNFLAT:
                 xTemplate.set( new BarChartTypeTemplate( m_xContext, aServiceSpecifier,
-                    StackMode_Y_STACKED_PERCENT, BarChartTypeTemplate::VERTICAL, 3 ));
+                    StackMode::YStackedPercent, BarChartTypeTemplate::VERTICAL, 3 ));
                 break;
             case TEMPLATE_THREEDBARDEEP:
                 xTemplate.set( new BarChartTypeTemplate( m_xContext, aServiceSpecifier,
-                    StackMode_Z_STACKED, BarChartTypeTemplate::HORIZONTAL, 3 ));
+                    StackMode::ZStacked, BarChartTypeTemplate::HORIZONTAL, 3 ));
                 break;
             case TEMPLATE_THREEDBARFLAT:
                 xTemplate.set( new BarChartTypeTemplate( m_xContext, aServiceSpecifier,
-                    StackMode_NONE, BarChartTypeTemplate::HORIZONTAL, 3 ));
+                    StackMode::NONE, BarChartTypeTemplate::HORIZONTAL, 3 ));
                 break;
             case TEMPLATE_STACKEDTHREEDBARFLAT:
                 xTemplate.set( new BarChartTypeTemplate( m_xContext, aServiceSpecifier,
-                    StackMode_Y_STACKED, BarChartTypeTemplate::HORIZONTAL, 3 ));
+                    StackMode::YStacked, BarChartTypeTemplate::HORIZONTAL, 3 ));
                 break;
             case TEMPLATE_PERCENTSTACKEDTHREEDBARFLAT:
                 xTemplate.set( new BarChartTypeTemplate( m_xContext, aServiceSpecifier,
-                    StackMode_Y_STACKED_PERCENT, BarChartTypeTemplate::HORIZONTAL, 3 ));
+                    StackMode::YStackedPercent, BarChartTypeTemplate::HORIZONTAL, 3 ));
                 break;
 
             // Combi-Chart Line/Column
@@ -387,8 +381,8 @@ uno::Reference< uno::XInterface > SAL_CALL ChartTypeManager::createInstance(
             case TEMPLATE_STACKEDCOLUMNWITHLINE:
             {
                 StackMode eMode = ( nId == TEMPLATE_COLUMNWITHLINE )
-                    ? StackMode_NONE
-                    : StackMode_Y_STACKED;
+                    ? StackMode::NONE
+                    : StackMode::YStacked;
 
                 xTemplate.set( new ColumnLineChartTypeTemplate( m_xContext, aServiceSpecifier, eMode, 1 ));
             }
@@ -396,22 +390,22 @@ uno::Reference< uno::XInterface > SAL_CALL ChartTypeManager::createInstance(
 
             // Area
             case TEMPLATE_AREA:
-                xTemplate.set( new AreaChartTypeTemplate( m_xContext, aServiceSpecifier, StackMode_NONE ));
+                xTemplate.set( new AreaChartTypeTemplate( m_xContext, aServiceSpecifier, StackMode::NONE ));
                 break;
             case TEMPLATE_STACKEDAREA:
-                xTemplate.set( new AreaChartTypeTemplate( m_xContext, aServiceSpecifier, StackMode_Y_STACKED ));
+                xTemplate.set( new AreaChartTypeTemplate( m_xContext, aServiceSpecifier, StackMode::YStacked ));
                 break;
             case TEMPLATE_PERCENTSTACKEDAREA:
-                xTemplate.set( new AreaChartTypeTemplate( m_xContext, aServiceSpecifier, StackMode_Y_STACKED_PERCENT ));
+                xTemplate.set( new AreaChartTypeTemplate( m_xContext, aServiceSpecifier, StackMode::YStackedPercent ));
                 break;
             case TEMPLATE_THREEDAREA:
-                xTemplate.set( new AreaChartTypeTemplate( m_xContext, aServiceSpecifier, StackMode_Z_STACKED, 3 ));
+                xTemplate.set( new AreaChartTypeTemplate( m_xContext, aServiceSpecifier, StackMode::ZStacked, 3 ));
                 break;
             case TEMPLATE_STACKEDTHREEDAREA:
-                xTemplate.set( new AreaChartTypeTemplate( m_xContext, aServiceSpecifier, StackMode_Y_STACKED, 3 ));
+                xTemplate.set( new AreaChartTypeTemplate( m_xContext, aServiceSpecifier, StackMode::YStacked, 3 ));
                 break;
             case TEMPLATE_PERCENTSTACKEDTHREEDAREA:
-                xTemplate.set( new AreaChartTypeTemplate( m_xContext, aServiceSpecifier, StackMode_Y_STACKED_PERCENT, 3 ));
+                xTemplate.set( new AreaChartTypeTemplate( m_xContext, aServiceSpecifier, StackMode::YStackedPercent, 3 ));
                 break;
 
             case TEMPLATE_PIE:
@@ -463,54 +457,54 @@ uno::Reference< uno::XInterface > SAL_CALL ChartTypeManager::createInstance(
             // NetChart
             case TEMPLATE_NET:
                 xTemplate.set( new NetChartTypeTemplate( m_xContext, aServiceSpecifier,
-                    StackMode_NONE, true ));
+                    StackMode::NONE, true ));
                 break;
             case TEMPLATE_NETSYMBOL:
                 xTemplate.set( new NetChartTypeTemplate( m_xContext, aServiceSpecifier,
-                    StackMode_NONE, true, false ));
+                    StackMode::NONE, true, false ));
                 break;
             case TEMPLATE_NETLINE:
                 xTemplate.set( new NetChartTypeTemplate( m_xContext, aServiceSpecifier,
-                    StackMode_NONE, false ));
+                    StackMode::NONE, false ));
                 break;
 
             case TEMPLATE_STACKEDNET:
                 xTemplate.set( new NetChartTypeTemplate( m_xContext, aServiceSpecifier,
-                    StackMode_Y_STACKED, true ));
+                    StackMode::YStacked, true ));
                 break;
             case TEMPLATE_STACKEDNETSYMBOL:
                 xTemplate.set( new NetChartTypeTemplate( m_xContext, aServiceSpecifier,
-                    StackMode_Y_STACKED, true, false ));
+                    StackMode::YStacked, true, false ));
                 break;
             case TEMPLATE_STACKEDNETLINE:
                 xTemplate.set( new NetChartTypeTemplate( m_xContext, aServiceSpecifier,
-                    StackMode_Y_STACKED, false, true ));
+                    StackMode::YStacked, false, true ));
                 break;
 
             case TEMPLATE_PERCENTSTACKEDNET:
                 xTemplate.set( new NetChartTypeTemplate( m_xContext, aServiceSpecifier,
-                    StackMode_Y_STACKED_PERCENT, true ));
+                    StackMode::YStackedPercent, true ));
                 break;
             case TEMPLATE_PERCENTSTACKEDNETSYMBOL:
                 xTemplate.set( new NetChartTypeTemplate( m_xContext, aServiceSpecifier,
-                    StackMode_Y_STACKED_PERCENT, true, false ));
+                    StackMode::YStackedPercent, true, false ));
                 break;
             case TEMPLATE_PERCENTSTACKEDNETLINE:
                 xTemplate.set( new NetChartTypeTemplate( m_xContext, aServiceSpecifier,
-                    StackMode_Y_STACKED_PERCENT, false, true ));
+                    StackMode::YStackedPercent, false, true ));
                 break;
 
             case TEMPLATE_FILLEDNET:
                 xTemplate.set( new NetChartTypeTemplate( m_xContext, aServiceSpecifier,
-                    StackMode_NONE, false, false, true ));
+                    StackMode::NONE, false, false, true ));
                 break;
             case TEMPLATE_STACKEDFILLEDNET:
                 xTemplate.set( new NetChartTypeTemplate( m_xContext, aServiceSpecifier,
-                    StackMode_Y_STACKED, false, false, true ));
+                    StackMode::YStacked, false, false, true ));
                 break;
             case TEMPLATE_PERCENTSTACKEDFILLEDNET:
                 xTemplate.set( new NetChartTypeTemplate( m_xContext, aServiceSpecifier,
-                    StackMode_Y_STACKED_PERCENT, false, false, true ));
+                    StackMode::YStackedPercent, false, false, true ));
                 break;
 
             case TEMPLATE_STOCKLOWHIGHCLOSE:
@@ -534,14 +528,16 @@ uno::Reference< uno::XInterface > SAL_CALL ChartTypeManager::createInstance(
             case TEMPLATE_BUBBLE:
                 xTemplate.set( new BubbleChartTypeTemplate( m_xContext, aServiceSpecifier ));
                 break;
-
+#if HAVE_FEATURE_OPENGL
             case TEMPLATE_GL3DBAR:
                 xTemplate.set(new GL3DBarChartTypeTemplate(m_xContext, aServiceSpecifier));
                 break;
             case TEMPLATE_GL3DBAR_ROUNDED_RECTANGLE:
                 xTemplate.set(new GL3DBarChartTypeTemplate(m_xContext, aServiceSpecifier));
                 break;
-
+#else
+            default: break;
+#endif
 //            case TEMPLATE_SURFACE:
 //            case TEMPLATE_ADDIN:
 //               break;
@@ -559,22 +555,19 @@ uno::Reference< uno::XInterface > SAL_CALL ChartTypeManager::createInstance(
 uno::Reference< uno::XInterface > SAL_CALL ChartTypeManager::createInstanceWithArguments(
     const OUString& ServiceSpecifier,
     const uno::Sequence< uno::Any >& /* Arguments */ )
-    throw (uno::Exception,
-           uno::RuntimeException, std::exception)
 {
     OSL_FAIL( "createInstanceWithArguments: No arguments supported" );
     return createInstance( ServiceSpecifier );
 }
 
 uno::Sequence< OUString > SAL_CALL ChartTypeManager::getAvailableServiceNames()
-    throw (uno::RuntimeException, std::exception)
 {
-    ::std::vector< OUString > aServices;
+    std::vector< OUString > aServices;
     const tTemplateMapType & rMap = lcl_DefaultChartTypeMap();
     aServices.reserve( rMap.size());
 
     // get own default templates
-    ::std::transform( rMap.begin(), rMap.end(), ::std::back_inserter( aServices ),
+    std::transform( rMap.begin(), rMap.end(), std::back_inserter( aServices ),
             ::o3tl::select1st< tTemplateMapType::value_type >() );
 
     // add components that were registered in the context's factory
@@ -604,36 +597,21 @@ uno::Sequence< OUString > SAL_CALL ChartTypeManager::getAvailableServiceNames()
 }
 
 // ____ XServiceInfo ____
-Sequence< OUString > ChartTypeManager::getSupportedServiceNames_Static()
-{
-    Sequence< OUString > aServices( 2 );
-    aServices[ 0 ] = "com.sun.star.chart2.ChartTypeManager";
-    aServices[ 1 ] = "com.sun.star.lang.MultiServiceFactory";
-    return aServices;
-}
-
-// implement XServiceInfo methods basing upon getSupportedServiceNames_Static
 OUString SAL_CALL ChartTypeManager::getImplementationName()
-    throw( css::uno::RuntimeException, std::exception )
-{
-    return getImplementationName_Static();
-}
-
-OUString ChartTypeManager::getImplementationName_Static()
 {
     return OUString("com.sun.star.comp.chart.ChartTypeManager");
 }
 
 sal_Bool SAL_CALL ChartTypeManager::supportsService( const OUString& rServiceName )
-    throw( css::uno::RuntimeException, std::exception )
 {
     return cppu::supportsService(this, rServiceName);
 }
 
 css::uno::Sequence< OUString > SAL_CALL ChartTypeManager::getSupportedServiceNames()
-    throw( css::uno::RuntimeException, std::exception )
 {
-    return getSupportedServiceNames_Static();
+    return {
+        "com.sun.star.chart2.ChartTypeManager",
+        "com.sun.star.lang.MultiServiceFactory" };
 }
 
 } //  namespace chart
