@@ -20,14 +20,13 @@
 #include "Tickmarks_Dates.hxx"
 #include "DateScaling.hxx"
 #include <rtl/math.hxx>
-#include "DateHelper.hxx"
+#include <DateHelper.hxx>
 
 namespace chart
 {
 using namespace ::com::sun::star;
 using namespace ::com::sun::star::chart2;
 using namespace ::rtl::math;
-using ::basegfx::B2DVector;
 using ::com::sun::star::chart::TimeUnit::DAY;
 using ::com::sun::star::chart::TimeUnit::MONTH;
 using ::com::sun::star::chart::TimeUnit::YEAR;
@@ -69,8 +68,8 @@ void DateTickFactory::getAllTicks( TickInfoArraysType& rAllTickInfos, bool bShif
 
     Date aNull(m_aScale.NullDate);
 
-    Date aDate = aNull + static_cast<long>(::rtl::math::approxFloor(m_aScale.Minimum));
-    Date aMaxDate = aNull + static_cast<long>(::rtl::math::approxFloor(m_aScale.Maximum));
+    Date aDate = aNull + static_cast<sal_Int32>(::rtl::math::approxFloor(m_aScale.Minimum));
+    Date aMaxDate = aNull + static_cast<sal_Int32>(::rtl::math::approxFloor(m_aScale.Maximum));
 
     uno::Reference< chart2::XScaling > xScaling(m_aScale.Scaling);
     uno::Reference< chart2::XScaling > xInverseScaling(m_xInverseScaling);
@@ -99,7 +98,7 @@ void DateTickFactory::getAllTicks( TickInfoArraysType& rAllTickInfos, bool bShif
         switch( m_aIncrement.MajorTimeInterval.TimeUnit )
         {
         case DAY:
-            aDate += m_aIncrement.MajorTimeInterval.Number;
+            aDate.AddDays( m_aIncrement.MajorTimeInterval.Number );
             break;
         case YEAR:
             aDate = DateHelper::GetDateSomeYearsAway( aDate, m_aIncrement.MajorTimeInterval.Number );
@@ -112,7 +111,7 @@ void DateTickFactory::getAllTicks( TickInfoArraysType& rAllTickInfos, bool bShif
     }
 
     //create minor date tickinfos
-    aDate = aNull + static_cast<long>(::rtl::math::approxFloor(m_aScale.Minimum));
+    aDate = aNull + static_cast<sal_Int32>(::rtl::math::approxFloor(m_aScale.Minimum));
     while( aDate<= aMaxDate )
     {
         if( bShifted && aDate==aMaxDate )
@@ -130,7 +129,7 @@ void DateTickFactory::getAllTicks( TickInfoArraysType& rAllTickInfos, bool bShif
         switch( m_aIncrement.MinorTimeInterval.TimeUnit )
         {
         case DAY:
-            aDate += m_aIncrement.MinorTimeInterval.Number;
+            aDate.AddDays( m_aIncrement.MinorTimeInterval.Number );
             break;
         case YEAR:
             aDate = DateHelper::GetDateSomeYearsAway( aDate, m_aIncrement.MinorTimeInterval.Number );
