@@ -17,29 +17,29 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "VCoordinateSystem.hxx"
+#include <VCoordinateSystem.hxx>
 #include "VCartesianCoordinateSystem.hxx"
 #include "VPolarCoordinateSystem.hxx"
-#include "ScaleAutomatism.hxx"
-#include "VSeriesPlotter.hxx"
-#include "AbstractShapeFactory.hxx"
-#include "servicenames_coosystems.hxx"
-#include "macros.hxx"
-#include "AxisIndexDefines.hxx"
-#include "ObjectIdentifier.hxx"
-#include "ExplicitCategoriesProvider.hxx"
-#include "AxisHelper.hxx"
-#include "ContainerHelper.hxx"
+#include <ScaleAutomatism.hxx>
+#include <VSeriesPlotter.hxx>
+#include <AbstractShapeFactory.hxx>
+#include <servicenames_coosystems.hxx>
+#include <AxisIndexDefines.hxx>
+#include <ObjectIdentifier.hxx>
+#include <ExplicitCategoriesProvider.hxx>
+#include <AxisHelper.hxx>
+#include <ContainerHelper.hxx>
 #include "VAxisBase.hxx"
-#include "ViewDefines.hxx"
-#include "DataSeriesHelper.hxx"
-#include "defines.hxx"
-#include "chartview/ExplicitValueProvider.hxx"
+#include <ViewDefines.hxx>
+#include <DataSeriesHelper.hxx>
+#include <defines.hxx>
+#include <chartview/ExplicitValueProvider.hxx>
 #include <com/sun/star/chart2/AxisType.hpp>
 #include <com/sun/star/chart2/XChartTypeContainer.hpp>
 #include <com/sun/star/chart2/XDataSeriesContainer.hpp>
 #include <comphelper/sequence.hxx>
 
+#include <algorithm>
 #include <rtl/math.hxx>
 
 namespace chart
@@ -98,7 +98,6 @@ void VCoordinateSystem::initPlottingTargets(  const Reference< drawing::XShapes
        , const Reference< drawing::XShapes >& xFinalTarget
        , const Reference< lang::XMultiServiceFactory >& xShapeFactory
        , Reference< drawing::XShapes >& xLogicTargetForSeriesBehindAxis )
-            throw (uno::RuntimeException, std::exception)
 {
     OSL_PRECOND(xLogicTarget.is()&&xFinalTarget.is()&&xShapeFactory.is(),"no proper initialization parameters");
     //is only allowed to be called once
@@ -142,7 +141,7 @@ void VCoordinateSystem::setTransformationSceneToScreen(
         VAxisBase* pVAxis = aIt->second.get();
         if( pVAxis )
         {
-            if(2==pVAxis->getDimensionCount())
+            if(pVAxis->getDimensionCount()==2)
                 pVAxis->setTransformationSceneToScreen( m_aMatrixSceneToScreen );
         }
     }
@@ -152,11 +151,9 @@ void VCoordinateSystem::setTransformationSceneToScreen(
 uno::Sequence< sal_Int32 > VCoordinateSystem::getCoordinateSystemResolution(
             const awt::Size& rPageSize, const awt::Size& rPageResolution )
 {
-    uno::Sequence< sal_Int32 > aResolution(2);
+    uno::Sequence<sal_Int32> aResolution(
+        std::max<sal_Int32>(m_xCooSysModel->getDimension(), 2));
 
-    sal_Int32 nDimensionCount = m_xCooSysModel->getDimension();
-    if(nDimensionCount>2)
-        aResolution.realloc(nDimensionCount);
     sal_Int32 nN = 0;
     for( nN = 0 ;nN<aResolution.getLength(); nN++ )
         aResolution[nN]=1000;
@@ -165,8 +162,8 @@ uno::Sequence< sal_Int32 > VCoordinateSystem::getCoordinateSystemResolution(
         BaseGFXHelper::HomogenMatrixToB3DHomMatrix(
             m_aMatrixSceneToScreen ) ) );
 
-    double fCoosysWidth = static_cast< double >( fabs(aScale.getX()*FIXED_SIZE_FOR_3D_CHART_VOLUME));
-    double fCoosysHeight = static_cast< double >( fabs(aScale.getY()*FIXED_SIZE_FOR_3D_CHART_VOLUME));
+    double fCoosysWidth = fabs(aScale.getX()*FIXED_SIZE_FOR_3D_CHART_VOLUME);
+    double fCoosysHeight = fabs(aScale.getY()*FIXED_SIZE_FOR_3D_CHART_VOLUME);
 
     double fPageWidth = rPageSize.Width;
     double fPageHeight = rPageSize.Height;
@@ -180,11 +177,11 @@ uno::Sequence< sal_Int32 > VCoordinateSystem::getCoordinateSystemResolution(
     if( nYResolution < 10 )
         nYResolution = 10;
 
-    if( this->getPropertySwapXAndYAxis() )
+    if( getPropertySwapXAndYAxis() )
         std::swap(nXResolution,nYResolution);
 
     //2D
-    if( 2 == aResolution.getLength() )
+    if( aResolution.getLength() == 2 )
     {
         aResolution[0]=nXResolution;
         aResolution[1]=nYResolution;
@@ -234,7 +231,7 @@ void VCoordinateSystem::impl_adjustDimensionAndIndex( sal_Int32& rDimensionIndex
 {
     impl_adjustDimension( rDimensionIndex );
 
-    if( rAxisIndex < 0 || rAxisIndex > this->getMaximumAxisIndexByDimension(rDimensionIndex) )
+    if( rAxisIndex < 0 || rAxisIndex > getMaximumAxisIndexByDimension(rDimensionIndex) )
         rAxisIndex = 0;
 }
 
@@ -253,7 +250,7 @@ std::vector< ExplicitScaleData > VCoordinateSystem::getExplicitScales( sal_Int32
     std::vector< ExplicitScaleData > aRet(m_aExplicitScales);
 
     impl_adjustDimensionAndIndex( nDimensionIndex, nAxisIndex );
-    aRet[nDimensionIndex]=this->getExplicitScale( nDimensionIndex, nAxisIndex );
+    aRet[nDimensionIndex]=getExplicitScale( nDimensionIndex, nAxisIndex );
 
     return aRet;
 }
@@ -263,7 +260,7 @@ std::vector< ExplicitIncrementData > VCoordinateSystem::getExplicitIncrements( s
     std::vector< ExplicitIncrementData > aRet(m_aExplicitIncrements);
 
     impl_adjustDimensionAndIndex( nDimensionIndex, nAxisIndex );
-    aRet[nDimensionIndex]=this->getExplicitIncrement( nDimensionIndex, nAxisIndex );
+    aRet[nDimensionIndex]=getExplicitIncrement( nDimensionIndex, nAxisIndex );
 
     return aRet;
 }
@@ -314,12 +311,12 @@ ExplicitIncrementData VCoordinateSystem::getExplicitIncrement( sal_Int32 nDimens
     return aRet;
 }
 
-OUString VCoordinateSystem::createCIDForAxis( const Reference< chart2::XAxis >& /* xAxis */, sal_Int32 nDimensionIndex, sal_Int32 nAxisIndex )
+OUString VCoordinateSystem::createCIDForAxis( sal_Int32 nDimensionIndex, sal_Int32 nAxisIndex )
 {
     OUString aAxisParticle( ObjectIdentifier::createParticleForAxis( nDimensionIndex, nAxisIndex ) );
     return ObjectIdentifier::createClassifiedIdentifierForParticles( m_aCooSysParticle, aAxisParticle );
 }
-OUString VCoordinateSystem::createCIDForGrid( const Reference< chart2::XAxis >& /* xAxis */, sal_Int32 nDimensionIndex, sal_Int32 nAxisIndex )
+OUString VCoordinateSystem::createCIDForGrid( sal_Int32 nDimensionIndex, sal_Int32 nAxisIndex )
 {
     OUString aGridParticle( ObjectIdentifier::createParticleForGrid( nDimensionIndex, nAxisIndex ) );
     return ObjectIdentifier::createClassifiedIdentifierForParticles( m_aCooSysParticle, aGridParticle );
@@ -346,6 +343,7 @@ void VCoordinateSystem::createVAxisList(
               const uno::Reference<chart2::XChartDocument> & /* xChartDoc */
             , const awt::Size& /* rFontReferenceSize */
             , const awt::Rectangle& /* rMaximumSpaceForLabels */
+            , bool /* bLimitSpaceForLabels */
             )
 {
 }
@@ -362,7 +360,7 @@ void VCoordinateSystem::prepareAutomaticAxisScaling( ScaleAutomatism& rScaleAuto
     if( rScaleAutomatism.getScale().AxisType==AxisType::DATE && nDimIndex==0 )
     {
         // This is a date X dimension.  Determine proper time resolution.
-        sal_Int32 nTimeResolution = ::com::sun::star::chart::TimeUnit::MONTH;
+        sal_Int32 nTimeResolution = css::chart::TimeUnit::MONTH;
         if( !(rScaleAutomatism.getScale().TimeIncrement.TimeResolution >>= nTimeResolution) )
         {
             nTimeResolution = m_aMergedMinMaxSupplier.calculateTimeResolutionOnXAxis();
@@ -375,20 +373,20 @@ void VCoordinateSystem::prepareAutomaticAxisScaling( ScaleAutomatism& rScaleAuto
     double fMax = 0.0;
     ::rtl::math::setInf(&fMin, false);
     ::rtl::math::setInf(&fMax, true);
-    if( 0 == nDimIndex )
+    if( nDimIndex == 0 )
     {
         // x dimension
         fMin = m_aMergedMinMaxSupplier.getMinimumX();
         fMax = m_aMergedMinMaxSupplier.getMaximumX();
     }
-    else if( 1 == nDimIndex )
+    else if( nDimIndex == 1 )
     {
         // y dimension
         ExplicitScaleData aScale = getExplicitScale( 0, 0 );
         fMin = m_aMergedMinMaxSupplier.getMinimumYInRange(aScale.Minimum,aScale.Maximum, nAxisIndex);
         fMax = m_aMergedMinMaxSupplier.getMaximumYInRange(aScale.Minimum,aScale.Maximum, nAxisIndex);
     }
-    else if( 2 == nDimIndex )
+    else if( nDimIndex == 2 )
     {
         // z dimension
         fMin = m_aMergedMinMaxSupplier.getMinimumZ();
@@ -459,7 +457,7 @@ void VCoordinateSystem::createMaximumAxesLabels()
         VAxisBase* pVAxis = aIt->second.get();
         if( pVAxis )
         {
-            if(2==pVAxis->getDimensionCount())
+            if(pVAxis->getDimensionCount()==2)
                 pVAxis->setTransformationSceneToScreen( m_aMatrixSceneToScreen );
             pVAxis->createMaximumLabels();
         }
@@ -474,7 +472,7 @@ void VCoordinateSystem::createAxesLabels()
         VAxisBase* pVAxis = aIt->second.get();
         if( pVAxis )
         {
-            if(2==pVAxis->getDimensionCount())
+            if(pVAxis->getDimensionCount()==2)
                 pVAxis->setTransformationSceneToScreen( m_aMatrixSceneToScreen );
             pVAxis->createLabels();
         }
@@ -490,7 +488,7 @@ void VCoordinateSystem::updatePositions()
         VAxisBase* pVAxis = aIt->second.get();
         if( pVAxis )
         {
-            if(2==pVAxis->getDimensionCount())
+            if(pVAxis->getDimensionCount()==2)
                 pVAxis->setTransformationSceneToScreen( m_aMatrixSceneToScreen );
             pVAxis->updatePositions();
         }
@@ -506,7 +504,7 @@ void VCoordinateSystem::createAxesShapes()
         VAxisBase* pVAxis = aIt->second.get();
         if( pVAxis )
         {
-            if(2==pVAxis->getDimensionCount())
+            if(pVAxis->getDimensionCount()==2)
                 pVAxis->setTransformationSceneToScreen( m_aMatrixSceneToScreen );
 
             tFullAxisIndex aFullAxisIndex = aIt->first;
@@ -514,13 +512,13 @@ void VCoordinateSystem::createAxesShapes()
             {
                 if( aFullAxisIndex.first == 0 )
                 {
-                    if( AxisType::CATEGORY!=m_aExplicitScales[1].AxisType )
+                    if( m_aExplicitScales[1].AxisType!=AxisType::CATEGORY )
                         pVAxis->setExtraLinePositionAtOtherAxis(
                             m_aExplicitScales[1].Origin );
                 }
                 else if( aFullAxisIndex.first == 1 )
                 {
-                    if( AxisType::CATEGORY!=m_aExplicitScales[0].AxisType )
+                    if( m_aExplicitScales[0].AxisType!=AxisType::CATEGORY )
                         pVAxis->setExtraLinePositionAtOtherAxis(
                             m_aExplicitScales[0].Origin );
                 }
@@ -558,7 +556,7 @@ bool VCoordinateSystem::getPropertySwapXAndYAxis() const
     }
     catch( const uno::Exception& e )
     {
-        ASSERT_EXCEPTION( e );
+        SAL_WARN("chart2", "Exception caught. " << e );
     }
     return bSwapXAndY;
 }
