@@ -41,9 +41,7 @@ sal_Bool SAL_CALL component_writeInfo(
     {
         try
         {
-            OUString aImpl( "/" );
-            aImpl += SampleAddIn::getImplementationName_Static();
-            aImpl += "/UNO/SERVICES";
+            OUString aImpl = "/"  + SampleAddIn::getImplementationName_Static() + "/UNO/SERVICES";
 
             uno::Reference< registry::XRegistryKey> xNewKey(
                 reinterpret_cast<registry::XRegistryKey*>( pRegistryKey )->createKey( aImpl ) );
@@ -160,14 +158,12 @@ OUString SampleAddIn::getImplementationName_Static()
 
 uno::Sequence< OUString > SampleAddIn::getSupportedServiceNames_Static()
 {
-    uno::Sequence< OUString > aSeq( 4 );
-
-    aSeq[ 0 ] = "com.sun.star.chart.ChartAxisXSupplier";
-    aSeq[ 1 ] = "com.sun.star.chart.ChartAxisYSupplier";
-    aSeq[ 2 ] = "com.sun.star.chart.Diagram";
-    aSeq[ 3 ] = "com.sun.star.chart.SampleAddIn";
-
-    return aSeq;
+    return {
+        "com.sun.star.chart.ChartAxisXSupplier",
+        "com.sun.star.chart.ChartAxisYSupplier",
+        "com.sun.star.chart.Diagram",
+        "com.sun.star.chart.SampleAddIn"
+    };
 }
 
 uno::Reference< uno::XInterface > SAL_CALL SampleAddIn_CreateInstance(
@@ -350,9 +346,7 @@ void SAL_CALL SampleAddIn::refresh() throw( uno::RuntimeException )
                     uno::Reference< beans::XPropertySet > xShapeProp( mxMyRedLine, uno::UNO_QUERY );
                     if( xShapeProp.is())
                     {
-                        uno::Any aAny;
-                        aAny <<= aPtSeq;
-                        xShapeProp->setPropertyValue( "PolyPolygon" , aAny );
+                        xShapeProp->setPropertyValue( "PolyPolygon" , Any(aPtSeq) );
                     }
                 }
                 if( mxMyText.is())
@@ -468,7 +462,7 @@ void SAL_CALL SampleAddIn::setPosition( const awt::Point& aPos )
 }
 
 // XShapeDescriptor ( ::XShape ::XDiagram )
-OUString SAL_CALL SampleAddIn::getShapeType() throw( com::sun::star::uno::RuntimeException )
+OUString SAL_CALL SampleAddIn::getShapeType() throw( css::uno::RuntimeException )
 {
     return "com.sun.star.chart.SampleAddinShape";
 }
