@@ -269,8 +269,6 @@ System::String^ mapUnoPolymorphicName(System::String^ unoName)
 }
 
 
-
-
 Assembly ^ TypeEmitter::type_resolve(
     ::System::Object ^, ::System::ResolveEventArgs ^ args )
 {
@@ -341,7 +339,7 @@ Assembly ^ TypeEmitter::type_resolve(
             ::System::Text::StringBuilder ^ sb = gcnew ::System::Text::StringBuilder();
             sb->Append(gcnew ::System::String("\nThe type "));
             sb->Append(cts_name);
-            sb->Append(gcnew ::System::String(" \n could not be found. Did you forget to " \
+            sb->Append(gcnew ::System::String(" \n could not be found. Did you forget to "
                 "specify an additional assembly with the --reference option?\n"));
             if (throw_exc)
                 throw gcnew ::System::Exception(sb->ToString(), exc);
@@ -755,7 +753,6 @@ Assembly ^ TypeEmitter::type_resolve(
 }
 
 
-
 ::System::Type ^ TypeEmitter::get_type(
     Reference< reflection::XServiceTypeDescription2 > const & xType )
 {
@@ -2049,7 +2046,6 @@ Emit::CustomAttributeBuilder^ TypeEmitter::get_exception_attribute(
 }
 
 
-
 ::System::Type ^ TypeEmitter::get_type(
     Reference< reflection::XTypeDescription > const & xType )
 {
@@ -2270,10 +2266,7 @@ resolveInterfaceTypedef(
         return xIfaceTd;
 
     Reference<reflection::XIndirectTypeDescription> xIndTd(
-        type, UNO_QUERY);
-    if (xIndTd.is() == sal_False)
-        throw css::uno::Exception(
-            "resolveInterfaceTypedef was called with an invalid argument", 0);
+        type, UNO_QUERY_THROW);
 
     return resolveInterfaceTypedef(xIndTd->getReferencedType());
 }
