@@ -18,7 +18,11 @@
  */
 
 #pragma warning(push, 1)
+#if !defined WIN32_LEAN_AND_MEAN
+# define WIN32_LEAN_AND_MEAN
+#endif
 #include "windows.h"
+#include <ole2.h>
 #pragma warning(pop)
 
 #include <memory>
@@ -716,9 +720,11 @@ OUString mapCliString(System::String ^ data)
 
     if (data != nullptr)
     {
-        OSL_ASSERT(sizeof(wchar_t) == sizeof(sal_Unicode));
+        static_assert(sizeof(wchar_t) == sizeof(sal_Unicode), "char mismatch");
         pin_ptr<wchar_t const> pdata= PtrToStringChars(data);
-        return OUString(pdata, const_cast<System::String^>(data)->Length);
+        return OUString(
+            reinterpret_cast<sal_Unicode const *>(pdata),
+            const_cast<System::String^>(data)->Length);
     }
     else
     {
@@ -818,8 +824,9 @@ void Bridge::map_to_uno(void * uno_data, System::Object^ cli_data,
             {
                 System::String ^s= safe_cast<System::String^>(cli_data);
                 pin_ptr<const wchar_t> pdata= PtrToStringChars(s);
-                rtl_uString_newFromStr_WithLength( (rtl_uString**) uno_data,
-                                                  pdata, s->Length );
+                rtl_uString_newFromStr_WithLength(
+                    reinterpret_cast<rtl_uString **>(uno_data),
+                    reinterpret_cast<sal_Unicode const *>(pdata), s->Length);
             }
             break;
         }
@@ -1294,8 +1301,10 @@ void Bridge::map_to_uno(void * uno_data, System::Object^ cli_data,
                             rtl_uString** pStr=  & ((rtl_uString**) &
                                                     ((uno_Sequence*) seq.get())->elements)[i];
                             *pStr= NULL;
-                            rtl_uString_newFromStr_WithLength( pStr, pdata,
-                                                               arStr[i]->Length);
+                            rtl_uString_newFromStr_WithLength(
+                                pStr,
+                                reinterpret_cast<sal_Unicode const *>(pdata),
+                                arStr[i]->Length);
                         }
                         break;
                     }
@@ -1428,7 +1437,7 @@ void Bridge::map_to_uno(void * uno_data, System::Object^ cli_data,
 
 /**
    @param info
-       The expected target type. Currently info is provdided when this method is called
+       The expected target type. Currently info is provided when this method is called
        to convert the in/out and out parameters of a call from cli to uno. Then info
        is always a byref type, e.g. "System.String&". info is used for Any and Enum conversion.
    @param bDontCreateObj
@@ -1537,7 +1546,7 @@ void Bridge::map_to_cli(
         //create the type
         System::Type^ cliType= loadCliType(td.get()->pTypeName);
         //detect if we recursivly convert inherited structures
-        //If this point is reached because of a recursive call during convering a
+        //If this point is reached because of a recursive call during covering a
         //struct then we must not create a new object rather we use the one in
         // cli_data argument.
         System::Object^ cliObj;
