@@ -18,7 +18,7 @@
  */
 
 
-#include "codemaker/options.hxx"
+#include <codemaker/options.hxx>
 
 using ::rtl::OString;
 
@@ -31,18 +31,13 @@ Options::~Options()
 
 }
 
-const OString& Options::getProgramName() const
-{
-    return m_program;
-}
 
-sal_Bool Options::isValid(const OString& option) const
+bool Options::isValid(const OString& option) const
 {
     return m_options.find(option) != m_options.end();
 }
 
-const OString Options::getOption(const OString& option) const
-    throw( IllegalArgument )
+const OString& Options::getOption(const OString& option) const
 {
     OptionMap::const_iterator i(m_options.find(option));
     if (i == m_options.end()) {
@@ -51,9 +46,5 @@ const OString Options::getOption(const OString& option) const
     return i->second;
 }
 
-const StringVector& Options::getInputFiles()
-{
-    return m_inputFiles;
-}
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
