@@ -17,21 +17,21 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "sal/config.h"
+#include <sal/config.h>
 
 #include <cstdlib>
 #include <cstring>
 #include <iostream>
 #include <vector>
 
-#include "codemaker/generatedtypeset.hxx"
-#include "codemaker/typemanager.hxx"
-#include "rtl/ref.hxx"
-#include "rtl/string.hxx"
-#include "rtl/ustring.hxx"
-#include "sal/main.h"
-#include "sal/types.h"
-#include "unoidl/unoidl.hxx"
+#include <codemaker/generatedtypeset.hxx>
+#include <codemaker/typemanager.hxx>
+#include <rtl/ref.hxx>
+#include <rtl/string.hxx>
+#include <rtl/ustring.hxx>
+#include <sal/main.h>
+#include <sal/types.h>
+#include <unoidl/unoidl.hxx>
 
 #include "javaoptions.hxx"
 #include "javatype.hxx"
@@ -44,17 +44,13 @@ SAL_IMPLEMENT_MAIN_WITH_ARGS(argc, argv) {
         }
 
         rtl::Reference< TypeManager > typeMgr(new TypeManager);
-        for (std::vector< rtl::OString >::const_iterator i(
-                 options.getExtraInputFiles().begin());
-             i != options.getExtraInputFiles().end(); ++i)
+        for (const OString& i : options.getExtraInputFiles())
         {
-            typeMgr->loadProvider(convertToFileUrl(*i), false);
+            typeMgr->loadProvider(convertToFileUrl(i), false);
         }
-        for (std::vector< rtl::OString >::const_iterator i(
-                 options.getInputFiles().begin());
-             i != options.getInputFiles().end(); ++i)
+        for (const OString& i : options.getInputFiles())
         {
-            typeMgr->loadProvider(convertToFileUrl(*i), true);
+            typeMgr->loadProvider(convertToFileUrl(i), true);
         }
         codemaker::GeneratedTypeSet generated;
         if (options.isValid("-T")) {
