@@ -17,11 +17,15 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
+#include <config_gpgme.h>
+
 #include <algorithm>
 
 #include <comphelper/docpasswordhelper.hxx>
+#include <comphelper/storagehelper.hxx>
 #include <com/sun/star/beans/PropertyValue.hpp>
 #include <com/sun/star/task/XInteractionHandler.hpp>
+#include <com/sun/star/lang/IllegalArgumentException.hpp>
 
 #include <osl/time.h>
 #include <osl/diagnose.h>
@@ -29,10 +33,16 @@
 #include <rtl/random.h>
 #include <string.h>
 
+#if HAVE_FEATURE_GPGME
+# include <gpgme.h>
+# include <context.h>
+# include <data.h>
+# include <decryptionresult.h>
+#endif
+
 using ::com::sun::star::uno::Sequence;
 using ::com::sun::star::uno::Exception;
 using ::com::sun::star::uno::Reference;
-using ::com::sun::star::uno::UNO_SET_THROW;
 using ::com::sun::star::task::PasswordRequestMode;
 using ::com::sun::star::task::PasswordRequestMode_PASSWORD_ENTER;
 using ::com::sun::star::task::PasswordRequestMode_PASSWORD_REENTER;
@@ -44,7 +54,6 @@ using namespace ::com::sun::star;
 namespace comphelper {
 
 
-
 static uno::Sequence< sal_Int8 > GeneratePBKDF2Hash( const OUString& aPassword, const uno::Sequence< sal_Int8 >& aSalt, sal_Int32 nCount, sal_Int32 nHashLength )
 {
     uno::Sequence< sal_Int8 > aResult;
@@ -66,7 +75,6 @@ static uno::Sequence< sal_Int8 > GeneratePBKDF2Hash( const OUString& aPassword,
 }
 
 
-
 IDocPasswordVerifier::~IDocPasswordVerifier()
 {
 }
@@ -77,9 +85,9 @@ uno::Sequence< beans::PropertyValue > DocPasswordHelper::GenerateNewModifyPasswo
     uno::Sequence< beans::PropertyValue > aResult;
 
     uno::Sequence< sal_Int8 > aSalt = GenerateRandomByteSequence( 16 );
-    sal_Int32 nCount = 1024;
+    sal_Int32 const nPBKDF2IterationCount = 100000;
 
-    uno::Sequence< sal_Int8 > aNewHash = GeneratePBKDF2Hash( aPassword, aSalt, nCount, 16 );
+    uno::Sequence< sal_Int8 > aNewHash = GeneratePBKDF2Hash(aPassword, aSalt, nPBKDF2IterationCount, 16);
     if ( aNewHash.getLength() )
     {
         aResult.realloc( 4 );
@@ -88,7 +96,7 @@ uno::Sequence< beans::PropertyValue > DocPasswordHelper::GenerateNewModifyPasswo
         aResult[1].Name = "salt";
         aResult[1].Value <<= aSalt;
         aResult[2].Name = "iteration-count";
-        aResult[2].Value <<= nCount;
+        aResult[2].Value <<= nPBKDF2IterationCount;
         aResult[3].Name = "hash";
         aResult[3].Value <<= aNewHash;
     }
@@ -184,13 +192,12 @@ sal_uInt32 DocPasswordHelper::GetWordHashAsUINT32(
         sal_uInt16 nHighResult = pInitialCode[nLen - 1];
         sal_uInt16 nLowResult = 0;
 
-        const sal_Unicode* pStr = aUString.getStr();
         for ( sal_uInt32 nInd = 0; nInd < nLen; nInd++ )
         {
             // NO Encoding during conversion!
             // The specification says that the low byte should be used in case it is not NULL
-            char nHighChar = (char)( pStr[nInd] >> 8 );
-            char nLowChar = (char)( pStr[nInd] & 0xFF );
+            char nHighChar = (char)( aUString[nInd] >> 8 );
+            char nLowChar = (char)( aUString[nInd] & 0xFF );
             char nChar = nLowChar ? nLowChar : nHighChar;
 
             for ( int nMatrixInd = 0; nMatrixInd < 7; ++nMatrixInd )
@@ -237,10 +244,9 @@ sal_uInt16 DocPasswordHelper::GetXLHashAsUINT16(
 
 
 Sequence< sal_Int8 > DocPasswordHelper::GetXLHashAsSequence(
-                const OUString& aUString,
-                rtl_TextEncoding nEnc )
+                const OUString& aUString )
 {
-    sal_uInt16 nHash = GetXLHashAsUINT16( aUString, nEnc );
+    sal_uInt16 nHash = GetXLHashAsUINT16( aUString );
     Sequence< sal_Int8 > aResult( 2 );
     aResult[0] = ( nHash >> 8 );
     aResult[1] = ( nHash & 0xFF );
@@ -264,7 +270,6 @@ Sequence< sal_Int8 > DocPasswordHelper::GetXLHashAsSequence(
 }
 
 
-
 /*static*/ uno::Sequence< sal_Int8 > DocPasswordHelper::GenerateStd97Key( const OUString& aPassword, const uno::Sequence< sal_Int8 >& aDocId )
 {
     uno::Sequence< sal_Int8 > aResultKey;
@@ -273,7 +278,7 @@ Sequence< sal_Int8 > DocPasswordHelper::GetXLHashAsSequence(
         sal_uInt16 pPassData[16];
         memset( pPassData, 0, sizeof(pPassData) );
 
-        sal_Int32 nPassLen = ::std::min< sal_Int32 >( aPassword.getLength(), 15 );
+        sal_Int32 nPassLen = std::min< sal_Int32 >( aPassword.getLength(), 15 );
         memcpy( pPassData, aPassword.getStr(), nPassLen * sizeof(pPassData[0]) );
 
         aResultKey = GenerateStd97Key( pPassData, aDocId );
@@ -342,14 +347,14 @@ Sequence< sal_Int8 > DocPasswordHelper::GetXLHashAsSequence(
 
         // Erase KeyData array and leave.
         rtl_secureZeroMemory (pKeyData, sizeof(pKeyData));
+
+        rtl_digest_destroy(hDigest);
     }
 
     return aResultKey;
 }
 
 
-
-
 /*static*/ css::uno::Sequence< css::beans::NamedValue > DocPasswordHelper::requestAndVerifyDocPassword(
         IDocPasswordVerifier& rVerifier,
         const css::uno::Sequence< css::beans::NamedValue >& rMediaEncData,
@@ -357,52 +362,52 @@ Sequence< sal_Int8 > DocPasswordHelper::GetXLHashAsSequence(
         const Reference< XInteractionHandler >& rxInteractHandler,
         const OUString& rDocumentUrl,
         DocPasswordRequestType eRequestType,
-        const ::std::vector< OUString >* pDefaultPasswords,
+        const std::vector< OUString >* pDefaultPasswords,
         bool* pbIsDefaultPassword )
 {
     css::uno::Sequence< css::beans::NamedValue > aEncData;
-    DocPasswordVerifierResult eResult = DocPasswordVerifierResult_WRONG_PASSWORD;
+    DocPasswordVerifierResult eResult = DocPasswordVerifierResult::WrongPassword;
 
     // first, try provided default passwords
     if( pbIsDefaultPassword )
         *pbIsDefaultPassword = false;
     if( pDefaultPasswords )
     {
-        for( ::std::vector< OUString >::const_iterator aIt = pDefaultPasswords->begin(), aEnd = pDefaultPasswords->end(); (eResult == DocPasswordVerifierResult_WRONG_PASSWORD) && (aIt != aEnd); ++aIt )
+        for( std::vector< OUString >::const_iterator aIt = pDefaultPasswords->begin(), aEnd = pDefaultPasswords->end(); (eResult == DocPasswordVerifierResult::WrongPassword) && (aIt != aEnd); ++aIt )
         {
             OSL_ENSURE( !aIt->isEmpty(), "DocPasswordHelper::requestAndVerifyDocPassword - unexpected empty default password" );
             if( !aIt->isEmpty() )
             {
                 eResult = rVerifier.verifyPassword( *aIt, aEncData );
                 if( pbIsDefaultPassword )
-                    *pbIsDefaultPassword = eResult == DocPasswordVerifierResult_OK;
+                    *pbIsDefaultPassword = eResult == DocPasswordVerifierResult::OK;
             }
         }
     }
 
     // try media encryption data (skip, if result is OK or ABORT)
-    if( eResult == DocPasswordVerifierResult_WRONG_PASSWORD )
+    if( eResult == DocPasswordVerifierResult::WrongPassword )
     {
         if( rMediaEncData.getLength() > 0 )
         {
             eResult = rVerifier.verifyEncryptionData( rMediaEncData );
-            if( eResult == DocPasswordVerifierResult_OK )
+            if( eResult == DocPasswordVerifierResult::OK )
                 aEncData = rMediaEncData;
         }
     }
 
     // try media password (skip, if result is OK or ABORT)
-    if( eResult == DocPasswordVerifierResult_WRONG_PASSWORD )
+    if( eResult == DocPasswordVerifierResult::WrongPassword )
     {
         if( !rMediaPassword.isEmpty() )
             eResult = rVerifier.verifyPassword( rMediaPassword, aEncData );
     }
 
     // request a password (skip, if result is OK or ABORT)
-    if( (eResult == DocPasswordVerifierResult_WRONG_PASSWORD) && rxInteractHandler.is() ) try
+    if( (eResult == DocPasswordVerifierResult::WrongPassword) && rxInteractHandler.is() ) try
     {
         PasswordRequestMode eRequestMode = PasswordRequestMode_PASSWORD_ENTER;
-        while( eResult == DocPasswordVerifierResult_WRONG_PASSWORD )
+        while( eResult == DocPasswordVerifierResult::WrongPassword )
         {
             DocPasswordRequest* pRequest = new DocPasswordRequest( eRequestType, eRequestMode, rDocumentUrl );
             Reference< XInteractionRequest > xRequest( pRequest );
@@ -414,7 +419,7 @@ Sequence< sal_Int8 > DocPasswordHelper::GetXLHashAsSequence(
             }
             else
             {
-                eResult = DocPasswordVerifierResult_ABORT;
+                eResult = DocPasswordVerifierResult::Abort;
             }
             eRequestMode = PasswordRequestMode_PASSWORD_REENTER;
         }
@@ -423,7 +428,92 @@ Sequence< sal_Int8 > DocPasswordHelper::GetXLHashAsSequence(
     {
     }
 
-    return (eResult == DocPasswordVerifierResult_OK) ? aEncData : uno::Sequence< beans::NamedValue >();
+    return (eResult == DocPasswordVerifierResult::OK) ? aEncData : uno::Sequence< beans::NamedValue >();
+}
+
+/*static*/ uno::Sequence< css::beans::NamedValue >
+    DocPasswordHelper::decryptGpgSession(
+        const uno::Sequence< uno::Sequence< beans::NamedValue > >& rGpgProperties )
+{
+#if HAVE_FEATURE_GPGME
+    if ( !rGpgProperties.hasElements() )
+        return uno::Sequence< beans::NamedValue >();
+
+    uno::Sequence< beans::NamedValue > aEncryptionData(1);
+    std::unique_ptr<GpgME::Context> ctx;
+    GpgME::initializeLibrary();
+    GpgME::Error err = GpgME::checkEngine(GpgME::OpenPGP);
+    if (err)
+        throw uno::RuntimeException("The GpgME library failed to initialize for the OpenPGP protocol.");
+
+    ctx.reset( GpgME::Context::createForProtocol(GpgME::OpenPGP) );
+    if (ctx == nullptr)
+        throw uno::RuntimeException("The GpgME library failed to initialize for the OpenPGP protocol.");
+    ctx->setArmor(false);
+
+    const uno::Sequence < beans::NamedValue > *pSequence = rGpgProperties.getConstArray();
+    const sal_Int32 nLength = rGpgProperties.getLength();
+    for ( sal_Int32 i = 0; i < nLength ; i++, pSequence++ )
+    {
+        const beans::NamedValue *pValues = pSequence->getConstArray();
+        if ( pSequence->getLength() == 3 )
+        {
+            // take CipherValue and try to decrypt that - stop after
+            // the first successful decryption
+
+            // ctx is setup now, let's decrypt the lot!
+            uno::Sequence < sal_Int8 > aVector;
+            pValues[2].Value >>= aVector;
+
+            GpgME::Data cipher(
+                reinterpret_cast<const char*>(aVector.getConstArray()),
+                size_t(aVector.getLength()), false);
+            GpgME::Data plain;
+
+            GpgME::DecryptionResult crypt_res = ctx->decrypt(
+                cipher, plain);
+
+            // NO_SECKEY -> skip
+            // BAD_PASSPHRASE -> retry?
+
+            off_t result = plain.seek(0,SEEK_SET);
+            (void) result;
+            assert(result == 0);
+            int len=0, curr=0; char buf;
+            while( (curr=plain.read(&buf, 1)) )
+                len += curr;
+
+            if(crypt_res.error() || !len)
+                continue; // can't use this key, take next one
+
+            uno::Sequence < sal_Int8 > aKeyValue(len);
+            result = plain.seek(0,SEEK_SET);
+            assert(result == 0);
+            if( plain.read(aKeyValue.getArray(), len) != len )
+                throw uno::RuntimeException("The GpgME library failed to read the encrypted value.");
+
+            SAL_INFO("comphelper.crypto", "Extracted gpg session key of length: " << len);
+
+            aEncryptionData[0].Name = PACKAGE_ENCRYPTIONDATA_SHA256UTF8;
+            aEncryptionData[0].Value <<= aKeyValue;
+            break;
+        }
+    }
+
+    if ( aEncryptionData[0].Value.hasValue() )
+    {
+        uno::Sequence< beans::NamedValue > aContainer(2);
+        aContainer[0].Name = "GpgInfos";
+        aContainer[0].Value <<= rGpgProperties;
+        aContainer[1].Name = "EncryptionKey";
+        aContainer[1].Value <<= aEncryptionData;
+
+        return aContainer;
+    }
+#else
+    (void)rGpgProperties;
+#endif
+    return uno::Sequence< beans::NamedValue >();
 }
 
 } // namespace comphelper
