@@ -30,6 +30,7 @@
 #include <comphelper/classids.hxx>
 #include <comphelper/sequenceashashmap.hxx>
 #include <comphelper/documentconstants.hxx>
+#include <comphelper/propertysequence.hxx>
 
 
 using namespace ::com::sun::star;
@@ -57,8 +58,7 @@ OUString MimeConfigurationHelper::GetStringClassIDRepresentation( const uno::Seq
 
             sal_Int32 nDigit1 = (sal_Int32)( (sal_uInt8)aClassID[nInd] / 16 );
             sal_Int32 nDigit2 = (sal_uInt8)aClassID[nInd] % 16;
-            aResult += OUString::number( nDigit1, 16 );
-            aResult += OUString::number( nDigit2, 16 );
+            aResult += OUString::number( nDigit1, 16 ) + OUString::number( nDigit2, 16 );
         }
     }
 
@@ -85,30 +85,26 @@ uno::Sequence< sal_Int8 > MimeConfigurationHelper::GetSequenceClassIDRepresentat
     if ( nLength == 36 )
     {
         OString aCharClassID = OUStringToOString( aClassID, RTL_TEXTENCODING_ASCII_US );
-        const sal_Char* pString = aCharClassID.getStr();
-        if ( pString )
+        uno::Sequence< sal_Int8 > aResult( 16 );
+
+        sal_Int32 nStrPointer = 0;
+        sal_Int32 nSeqInd = 0;
+        while( nSeqInd < 16 && nStrPointer + 1 < nLength )
         {
-            uno::Sequence< sal_Int8 > aResult( 16 );
+            sal_uInt8 nDigit1 = GetDigit_Impl( aCharClassID[nStrPointer++] );
+            sal_uInt8 nDigit2 = GetDigit_Impl( aCharClassID[nStrPointer++] );
 
-            sal_Int32 nStrPointer = 0;
-            sal_Int32 nSeqInd = 0;
-            while( nSeqInd < 16 && nStrPointer + 1 < nLength )
-            {
-                sal_uInt8 nDigit1 = GetDigit_Impl( pString[nStrPointer++] );
-                sal_uInt8 nDigit2 = GetDigit_Impl( pString[nStrPointer++] );
+            if ( nDigit1 > 15 || nDigit2 > 15 )
+                break;
 
-                if ( nDigit1 > 15 || nDigit2 > 15 )
-                    break;
+            aResult[nSeqInd++] = (sal_Int8)( nDigit1 * 16 + nDigit2 );
 
-                aResult[nSeqInd++] = (sal_Int8)( nDigit1 * 16 + nDigit2 );
-
-                if ( nStrPointer < nLength && pString[nStrPointer] == '-' )
-                    nStrPointer++;
-            }
-
-            if ( nSeqInd == 16 && nStrPointer == nLength )
-                return aResult;
+            if ( nStrPointer < nLength && aCharClassID[nStrPointer] == '-' )
+                nStrPointer++;
         }
+
+        if ( nSeqInd == 16 && nStrPointer == nLength )
+            return aResult;
     }
 
     return uno::Sequence< sal_Int8 >();
@@ -126,12 +122,10 @@ uno::Reference< container::XNameAccess > MimeConfigurationHelper::GetConfigurati
         if ( !m_xConfigProvider.is() )
             m_xConfigProvider = configuration::theDefaultProvider::get( m_xContext );
 
-        uno::Sequence< uno::Any > aArgs( 1 );
-        beans::PropertyValue aPathProp;
-        aPathProp.Name = "nodepath";
-        aPathProp.Value <<= aPath;
-        aArgs[0] <<= aPathProp;
-
+        uno::Sequence<uno::Any> aArgs(comphelper::InitAnyPropertySequence(
+        {
+            {"nodepath", uno::Any(aPath)}
+        }));
         xConfig.set( m_xConfigProvider->createInstanceWithArguments(
                         "com.sun.star.configuration.ConfigurationAccess",
                         aArgs ),
@@ -230,7 +224,7 @@ OUString MimeConfigurationHelper::GetDocServiceNameFromMediaType( const OUString
         try
         {
             // make query for all types matching the properties
-            uno::Sequence < beans::NamedValue > aSeq { { "MediaType", css::uno::makeAny(aMediaType) } };
+            uno::Sequence < beans::NamedValue > aSeq { { "MediaType", css::uno::Any(aMediaType) } };
 
             uno::Reference < container::XEnumeration > xEnum = xTypeCFG->createSubSetEnumerationByProperties( aSeq );
             while ( xEnum->hasMoreElements() )
@@ -313,17 +307,14 @@ uno::Sequence< beans::NamedValue > MimeConfigurationHelper::GetObjPropsFromConfi
                 if ( aObjPropNames[nInd] == "ObjectVerbs" )
                 {
                     uno::Sequence< OUString > aVerbShortcuts;
-                    if ( xObjectProps->getByName( aObjPropNames[nInd] ) >>= aVerbShortcuts )
-                    {
-                        uno::Sequence< embed::VerbDescriptor > aVerbDescriptors( aVerbShortcuts.getLength() );
-                        for ( sal_Int32 nVerbI = 0; nVerbI < aVerbShortcuts.getLength(); nVerbI++ )
-                            if ( !GetVerbByShortcut( aVerbShortcuts[nVerbI], aVerbDescriptors[nVerbI] ) )
-                                throw uno::RuntimeException();
-
-                        aResult[nInd+1].Value <<= aVerbDescriptors;
-                    }
-                    else
+                    if ( !(xObjectProps->getByName( aObjPropNames[nInd] ) >>= aVerbShortcuts) )
                         throw uno::RuntimeException();
+                    uno::Sequence< embed::VerbDescriptor > aVerbDescriptors( aVerbShortcuts.getLength() );
+                    for ( sal_Int32 nVerbI = 0; nVerbI < aVerbShortcuts.getLength(); nVerbI++ )
+                        if ( !GetVerbByShortcut( aVerbShortcuts[nVerbI], aVerbDescriptors[nVerbI] ) )
+                            throw uno::RuntimeException();
+
+                    aResult[nInd+1].Value <<= aVerbDescriptors;
                 }
                 else
                     aResult[nInd+1].Value = xObjectProps->getByName( aObjPropNames[nInd] );
@@ -549,7 +540,6 @@ OUString MimeConfigurationHelper::GetFactoryNameByDocumentName( const OUString&
 }
 
 
-
 OUString MimeConfigurationHelper::GetFactoryNameByMediaType( const OUString& aMediaType )
 {
     OUString aResult = GetFactoryNameByStringClassID( GetExplicitlyRegisteredObjClassID( aMediaType ) );
@@ -581,16 +571,13 @@ OUString MimeConfigurationHelper::UpdateMediaDescriptorWithFilterName(
 
         uno::Reference< document::XTypeDetection > xTypeDetection(
                 m_xContext->getServiceManager()->createInstanceWithContext("com.sun.star.document.TypeDetection", m_xContext),
-                uno::UNO_QUERY );
-
-        if ( !xTypeDetection.is() )
-            throw uno::RuntimeException(); // TODO
+                uno::UNO_QUERY_THROW );
 
         // typedetection can change the mode, add a stream and so on, thus a copy should be used
         uno::Sequence< beans::PropertyValue > aTempMD( aMediaDescr );
 
         // get TypeName
-        OUString aTypeName = xTypeDetection->queryTypeByDescriptor( aTempMD, sal_True );
+        OUString aTypeName = xTypeDetection->queryTypeByDescriptor( aTempMD, true );
 
         // get FilterName
         for ( sal_Int32 nInd = 0; nInd < aTempMD.getLength(); nInd++ )
@@ -642,7 +629,7 @@ OUString MimeConfigurationHelper::UpdateMediaDescriptorWithFilterName(
             break;
         }
 
-    OSL_ENSURE( !aDocName.isEmpty(), "The name must exist at this point!\n" );
+    OSL_ENSURE( !aDocName.isEmpty(), "The name must exist at this point!" );
 
 
     bool bNeedsAddition = true;
@@ -665,7 +652,7 @@ OUString MimeConfigurationHelper::UpdateMediaDescriptorWithFilterName(
     return UpdateMediaDescriptorWithFilterName( aMediaDescr, true );
 }
 
-#ifdef WNT
+#ifdef _WIN32
 
 SfxFilterFlags MimeConfigurationHelper::GetFilterFlags( const OUString& aFilterName )
 {
@@ -695,7 +682,7 @@ SfxFilterFlags MimeConfigurationHelper::GetFilterFlags( const OUString& aFilterN
 bool MimeConfigurationHelper::AddFilterNameCheckOwnFile(
                         uno::Sequence< beans::PropertyValue >& aMediaDescr )
 {
-    OUString aFilterName = UpdateMediaDescriptorWithFilterName( aMediaDescr, sal_False );
+    OUString aFilterName = UpdateMediaDescriptorWithFilterName( aMediaDescr, false );
     if ( !aFilterName.isEmpty() )
     {
         SfxFilterFlags nFlags = GetFilterFlags( aFilterName );
@@ -721,8 +708,8 @@ OUString MimeConfigurationHelper::GetDefaultFilterFromServiceName( const OUStrin
 
             uno::Sequence< beans::NamedValue > aSearchRequest
             {
-                { "DocumentService", css::uno::makeAny(aServiceName) },
-                { "FileFormatVersion", css::uno::makeAny(nVersion) }
+                { "DocumentService", css::uno::Any(aServiceName) },
+                { "FileFormatVersion", css::uno::Any(nVersion) }
             };
 
             uno::Reference< container::XEnumeration > xFilterEnum =
@@ -786,7 +773,7 @@ OUString MimeConfigurationHelper::GetExportFilterFromImportFilter( const OUStrin
                 if ( !( nFlags & SfxFilterFlags::IMPORT ) )
                 {
                     OSL_FAIL( "This is no import filter!" );
-                    throw uno::Exception();
+                    throw uno::Exception("this is no import filter", nullptr);
                 }
 
                 if ( nFlags & SfxFilterFlags::EXPORT )
@@ -803,8 +790,8 @@ OUString MimeConfigurationHelper::GetExportFilterFromImportFilter( const OUStrin
                     {
                         uno::Sequence< beans::NamedValue > aSearchRequest
                         {
-                            { "Type", css::uno::makeAny(aTypeName) },
-                            { "DocumentService", css::uno::makeAny(aDocumentServiceName) }
+                            { "Type", css::uno::Any(aTypeName) },
+                            { "DocumentService", css::uno::Any(aDocumentServiceName) }
                         };
 
                         uno::Sequence< beans::PropertyValue > aExportFilterProps = SearchForFilter(
@@ -871,7 +858,6 @@ uno::Sequence< beans::PropertyValue > MimeConfigurationHelper::SearchForFilter(
 }
 
 
-
 bool MimeConfigurationHelper::ClassIDsEqual( const uno::Sequence< sal_Int8 >& aClassID1, const uno::Sequence< sal_Int8 >& aClassID2 )
 {
     if ( aClassID1.getLength() != aClassID2.getLength() )
