@@ -7,9 +7,11 @@
  * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  */
 
+#include <cassert>
+#include <limits>
+
 #include "clang/Lex/Lexer.h"
 
-#include "compat.hxx"
 #include "plugin.hxx"
 
 namespace {
@@ -19,7 +21,7 @@ class LiteralToBoolConversion:
     public loplugin::RewritePlugin
 {
 public:
-    explicit LiteralToBoolConversion(InstantiationData const & data):
+    explicit LiteralToBoolConversion(loplugin::InstantiationData const & data):
         RewritePlugin(data) {}
 
     virtual void run() override
@@ -27,11 +29,17 @@ public:
 
     bool VisitImplicitCastExpr(ImplicitCastExpr const * expr);
 
+    bool TraverseLinkageSpecDecl(LinkageSpecDecl * decl);
+
 private:
     bool isFromCIncludeFile(SourceLocation spellingLocation) const;
 
+    bool isSharedCAndCppCode(SourceLocation location) const;
+
     void handleImplicitCastSubExpr(
         ImplicitCastExpr const * castExpr, Expr const * subExpr);
+
+    unsigned int externCContexts_ = 0;
 };
 
 bool LiteralToBoolConversion::VisitImplicitCastExpr(
@@ -47,16 +55,36 @@ bool LiteralToBoolConversion::VisitImplicitCastExpr(
     return true;
 }
 
+bool LiteralToBoolConversion::TraverseLinkageSpecDecl(LinkageSpecDecl * decl) {
+    assert(externCContexts_ != std::numeric_limits<unsigned int>::max()); //TODO
+    ++externCContexts_;
+    bool ret = RecursiveASTVisitor::TraverseLinkageSpecDecl(decl);
+    assert(externCContexts_ != 0);
+    --externCContexts_;
+    return ret;
+}
+
 bool LiteralToBoolConversion::isFromCIncludeFile(
     SourceLocation spellingLocation) const
 {
-    return !compat::isInMainFile(compiler.getSourceManager(), spellingLocation)
+    return !compiler.getSourceManager().isInMainFile(spellingLocation)
         && (StringRef(
                 compiler.getSourceManager().getPresumedLoc(spellingLocation)
                 .getFilename())
             .endswith(".h"));
 }
 
+bool LiteralToBoolConversion::isSharedCAndCppCode(SourceLocation location) const
+{
+    // Assume that code is intended to be shared between C and C++ if it comes
+    // from an include file ending in .h, and is either in an extern "C" context
+    // or the body of a macro definition:
+    return
+        isFromCIncludeFile(compiler.getSourceManager().getSpellingLoc(location))
+        && (externCContexts_ != 0
+            || compiler.getSourceManager().isMacroBodyExpansion(location));
+}
+
 void LiteralToBoolConversion::handleImplicitCastSubExpr(
     ImplicitCastExpr const * castExpr, Expr const * subExpr)
 {
@@ -93,21 +121,19 @@ void LiteralToBoolConversion::handleImplicitCastSubExpr(
         while (compiler.getSourceManager().isMacroArgExpansion(loc)) {
             loc = compiler.getSourceManager().getImmediateMacroCallerLoc(loc);
         }
-        if (compat::isMacroBodyExpansion(compiler, loc)) {
+        if (compiler.getSourceManager().isMacroBodyExpansion(loc)) {
             StringRef name { Lexer::getImmediateMacroName(
                 loc, compiler.getSourceManager(), compiler.getLangOpts()) };
             if (name == "sal_False" || name == "sal_True") {
                 loc = compiler.getSourceManager().getImmediateExpansionRange(
                     loc).first;
             }
-            if (isFromCIncludeFile(
-                    compiler.getSourceManager().getSpellingLoc(loc)))
-            {
+            if (isSharedCAndCppCode(loc)) {
                 return;
             }
         }
     }
-    if (isa<StringLiteral>(subExpr)) {
+    if (isa<clang::StringLiteral>(subExpr)) {
         SourceLocation loc { subExpr->getLocStart() };
         if (compiler.getSourceManager().isMacroArgExpansion(loc)
             && (Lexer::getImmediateMacroName(
@@ -119,9 +145,9 @@ void LiteralToBoolConversion::handleImplicitCastSubExpr(
     }
     if (isa<IntegerLiteral>(subExpr) || isa<CharacterLiteral>(subExpr)
         || isa<FloatingLiteral>(subExpr) || isa<ImaginaryLiteral>(subExpr)
-        || isa<StringLiteral>(subExpr))
+        || isa<clang::StringLiteral>(subExpr))
     {
-        bool rewritten = false;
+        bool bRewritten = false;
         if (rewriter != nullptr) {
             SourceLocation loc { compiler.getSourceManager().getExpansionLoc(
                     expr2->getLocStart()) };
@@ -135,19 +161,19 @@ void LiteralToBoolConversion::handleImplicitCastSubExpr(
                     compiler.getLangOpts());
                 std::string tok { s, n };
                 if (tok == "sal_False" || tok == "0") {
-                    rewritten = replaceText(
+                    bRewritten = replaceText(
                         compiler.getSourceManager().getExpansionLoc(
                             expr2->getLocStart()),
                         n, "false");
                 } else if (tok == "sal_True" || tok == "1") {
-                    rewritten = replaceText(
+                    bRewritten = replaceText(
                         compiler.getSourceManager().getExpansionLoc(
                             expr2->getLocStart()),
                         n, "true");
                 }
             }
         }
-        if (!rewritten) {
+        if (!bRewritten) {
             report(
                 DiagnosticsEngine::Warning,
                 "implicit conversion (%0) of literal of type %1 to %2",
