@@ -44,7 +44,7 @@ private:
     char* mmappedData;
 };
 
-static size_t getFilesize(const char* filename)
+size_t getFilesize(const char* filename)
 {
     struct stat st;
     stat(filename, &st);
@@ -71,7 +71,7 @@ RemoveVirtuals::~RemoveVirtuals()
     close(mmapFD);
 }
 
-static std::string niceName(const CXXMethodDecl* functionDecl)
+std::string niceName(const CXXMethodDecl* functionDecl)
 {
     std::string s =
            functionDecl->getParent()->getQualifiedNameAsString() + "::"
@@ -97,8 +97,7 @@ bool RemoveVirtuals::VisitCXXMethodDecl( const CXXMethodDecl* functionDecl )
         return true;
     }
     // ignore stuff that forms part of the stable URE interface
-    if (isInUnoIncludeFile(compiler.getSourceManager().getSpellingLoc(
-                              functionDecl->getCanonicalDecl()->getNameInfo().getLoc()))) {
+    if (isInUnoIncludeFile(functionDecl)) {
         return true;
     }
 
@@ -145,7 +144,6 @@ bool RemoveVirtuals::VisitCXXMethodDecl( const CXXMethodDecl* functionDecl )
 }
 
 
-
 loplugin::Plugin::Registration< RemoveVirtuals > X("removevirtuals", false);
 
 }
