@@ -23,7 +23,7 @@
 #include <cassert>
 #include <chrono>
 #include <cstddef>
-#include <list>
+#include <vector>
 #include <set>
 
 #include <com/sun/star/beans/Optional.hpp>
@@ -68,7 +68,7 @@
 #include "xcsparser.hxx"
 
 #if ENABLE_DCONF
-#include <dconf.hxx>
+#include "dconf.hxx"
 #endif
 
 #if defined(_WIN32)
@@ -79,17 +79,17 @@ namespace configmgr {
 
 namespace {
 
-struct UnresolvedListItem {
+struct UnresolvedVectorItem {
     OUString name;
     rtl::Reference< ParseManager > manager;
 
-    UnresolvedListItem(
+    UnresolvedVectorItem(
         OUString const & theName,
         rtl::Reference< ParseManager > const & theManager):
         name(theName), manager(theManager) {}
 };
 
-typedef std::list< UnresolvedListItem > UnresolvedList;
+typedef std::vector< UnresolvedVectorItem > UnresolvedVector;
 
 void parseXcsFile(
     OUString const & url, int layer, Data & data, Partial const * partial,
@@ -186,9 +186,7 @@ void Components::WriteThread::execute() {
             writeModFile(components_, url_, data_);
         } catch (css::uno::RuntimeException & e) {
             // Ignore write errors, instead of aborting:
-            SAL_WARN(
-                "configmgr",
-                "error writing modifications: \"" << e.Message << '"');
+            SAL_WARN("configmgr", "error writing modifications: " << e);
         }
     } catch (...) {
         reference_->clear();
@@ -404,8 +402,7 @@ void Components::insertModificationXcuFile(
     } catch (css::container::NoSuchElementException & e) {
         SAL_WARN(
             "configmgr",
-            "error inserting non-existing \"" << fileUri << "\": \""
-                << e.Message << '"');
+            "error inserting non-existing \"" << fileUri << "\": " << e);
     }
 }
 
@@ -433,15 +430,13 @@ css::beans::Optional< css::uno::Any > Components::getExternalValue(
             // installed:
             SAL_WARN(
                 "configmgr",
-                "createInstance(" << name << ") failed with \"" << e.Message
-                    << '"');
+                "createInstance(" << name << ") failed with " << e);
         }
         css::uno::Reference< css::beans::XPropertySet > propset;
         if (service.is()) {
             propset.set( service, css::uno::UNO_QUERY_THROW);
         }
-        j = externalServices_.insert(
-            ExternalServices::value_type(name, propset)).first;
+        j = externalServices_.emplace(name, propset).first;
     }
     css::beans::Optional< css::uno::Any > value;
     if (j->second.is()) {
@@ -663,7 +658,7 @@ void Components::parseFileLeniently(
         // starting:
         SAL_WARN(
             "configmgr",
-            "error reading \"" << url << "\": \"" << e.Message << '"');
+            "error reading \"" << url << "\": " << e);
     }
 }
 
@@ -732,8 +727,7 @@ void Components::parseFileList(
             try {
                 parseFileLeniently(parseFile, url, layer, nullptr, nullptr, adds);
             } catch (css::container::NoSuchElementException & e) {
-                SAL_WARN(
-                    "configmgr", "file does not exist: \"" << e.Message << '"');
+                SAL_WARN("configmgr", "file does not exist: " << e);
                 if (adds != nullptr) {
                     data_.removeExtensionXcuAdditions(url);
                 }
@@ -756,7 +750,7 @@ void Components::parseXcdFiles(int layer, OUString const & url) {
         throw css::uno::RuntimeException(
             "cannot open directory " + url);
     }
-    UnresolvedList unres;
+    UnresolvedVector unres;
     std::set< OUString > existingDeps;
     std::set< OUString > processedDeps;
     for (;;) {
@@ -793,14 +787,14 @@ void Components::parseXcdFiles(int layer, OUString const & url) {
                 if (manager->parse(nullptr)) {
                     processedDeps.insert(name);
                 } else {
-                    unres.push_back(UnresolvedListItem(name, manager));
+                    unres.emplace_back(name, manager);
                 }
             }
         }
     }
     while (!unres.empty()) {
         bool isResolved = false;
-        for (UnresolvedList::iterator i(unres.begin()); i != unres.end();) {
+        for (UnresolvedVector::iterator i(unres.begin()); i != unres.end();) {
             if (i->manager->parse(&existingDeps)) {
                 processedDeps.insert(i->name);
                 i = unres.erase(i);
@@ -884,7 +878,7 @@ void Components::parseModificationLayer(int layer, OUString const & url) {
     }
 }
 
-int Components::getExtensionLayer(bool shared) {
+int Components::getExtensionLayer(bool shared) const {
     int layer = shared ? sharedExtensionLayer_ : userExtensionLayer_;
     if (layer == -1) {
         throw css::uno::RuntimeException(
