@@ -26,14 +26,14 @@ extern "C" {
 #include <com/sun/star/uno/Sequence.hxx>
 #include <rtl/ustrbuf.hxx>
 
-#include <data.hxx>
-#include <dconf.hxx>
-#include <groupnode.hxx>
-#include <localizedpropertynode.hxx>
-#include <localizedvaluenode.hxx>
-#include <nodemap.hxx>
-#include <propertynode.hxx>
-#include <setnode.hxx>
+#include "data.hxx"
+#include "dconf.hxx"
+#include "groupnode.hxx"
+#include "localizedpropertynode.hxx"
+#include "localizedvaluenode.hxx"
+#include "nodemap.hxx"
+#include "propertynode.hxx"
+#include "setnode.hxx"
 
 // component-data is encoded in dconf as follows:
 //
@@ -54,7 +54,7 @@ extern "C" {
 // * The names of set element nodes are encoded as dconf path segments as
 //   follows: each occurrence of U+0000 NULL is replace by the three characters
 //   "\00", each occurrence of U+002F SOLIDUS is replaced by the three
-//   characters "\2F", and each ocurrence of U+005C REVERSE SOLIDUS is replaced
+//   characters "\2F", and each occurrence of U+005C REVERSE SOLIDUS is replaced
 //   by the three characters "\5C".
 //
 // * Set elements (which must themselves be either sets or groups) map to
@@ -227,7 +227,7 @@ bool decode(OUString * string, bool slash) {
             return true;
         }
         if (string->match("00", i + 1)) {
-            *string = string->replaceAt(i, 3, OUString(sal_Unicode(0)));
+            *string = string->replaceAt(i, 3, OUString(u'\0'));
         } else if (slash && string->match("2F", i + 1)) {
             *string = string->replaceAt(i, 3, "/");
         } else if (string->match("5C", i + 1)) {
@@ -749,7 +749,7 @@ ReadValue readValue(
 
 void finalize(
     GObjectHolder<DConfClient> const & client, OString const & path,
-    rtl::Reference<Node> & node, int layer)
+    rtl::Reference<Node> const & node, int layer)
 {
     if (!dconf_client_is_writable(client.get(), path.getStr())) {
         node->setFinalized(layer);
