@@ -56,65 +56,48 @@ private:
     Service(const Service&) = delete;
     Service& operator=(const Service&) = delete;
 
-    virtual ~Service() {}
+    virtual ~Service() override {}
 
-    virtual OUString SAL_CALL getImplementationName()
-        throw (css::uno::RuntimeException, std::exception) override
+    virtual OUString SAL_CALL getImplementationName() override
     { return read_write_access::getImplementationName(); }
 
-    virtual sal_Bool SAL_CALL supportsService(OUString const & ServiceName)
-        throw (css::uno::RuntimeException, std::exception) override
+    virtual sal_Bool SAL_CALL supportsService(OUString const & ServiceName) override
     { return cppu::supportsService(this, ServiceName); }
 
     virtual css::uno::Sequence< OUString > SAL_CALL
-    getSupportedServiceNames() throw (css::uno::RuntimeException, std::exception) override
+    getSupportedServiceNames() override
     { return read_write_access::getSupportedServiceNames(); }
 
     virtual void SAL_CALL initialize(
-        css::uno::Sequence< css::uno::Any > const & aArguments)
-        throw (css::uno::Exception, css::uno::RuntimeException, std::exception) override;
+        css::uno::Sequence< css::uno::Any > const & aArguments) override;
 
     virtual css::uno::Any SAL_CALL getByHierarchicalName(
-        OUString const & aName)
-        throw (
-            css::container::NoSuchElementException, css::uno::RuntimeException, std::exception) override
+        OUString const & aName) override
     { return getRoot()->getByHierarchicalName(aName); }
 
-    virtual sal_Bool SAL_CALL hasByHierarchicalName(OUString const & aName)
-        throw (css::uno::RuntimeException, std::exception) override
+    virtual sal_Bool SAL_CALL hasByHierarchicalName(OUString const & aName) override
     { return getRoot()->hasByHierarchicalName(aName); }
 
     virtual void SAL_CALL replaceByHierarchicalName(
-        OUString const & aName, css::uno::Any const & aElement)
-        throw (
-            css::lang::IllegalArgumentException,
-            css::container::NoSuchElementException,
-            css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception) override
+        OUString const & aName, css::uno::Any const & aElement) override
     { getRoot()->replaceByHierarchicalName(aName, aElement); }
 
-    virtual void SAL_CALL commitChanges()
-        throw (css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception) override
+    virtual void SAL_CALL commitChanges() override
     { getRoot()->commitChanges(); }
 
-    virtual sal_Bool SAL_CALL hasPendingChanges()
-        throw (css::uno::RuntimeException, std::exception) override
+    virtual sal_Bool SAL_CALL hasPendingChanges() override
     { return getRoot()->hasPendingChanges(); }
 
-    virtual css::util::ChangesSet SAL_CALL getPendingChanges()
-        throw (css::uno::RuntimeException, std::exception) override
+    virtual css::util::ChangesSet SAL_CALL getPendingChanges() override
     { return getRoot()->getPendingChanges(); }
 
     css::beans::Property SAL_CALL getPropertyByHierarchicalName(
         OUString const & aHierarchicalName)
-        throw (
-            css::beans::UnknownPropertyException, css::uno::RuntimeException,
-            std::exception)
         override
     { return getRoot()->getPropertyByHierarchicalName(aHierarchicalName); }
 
     sal_Bool SAL_CALL hasPropertyByHierarchicalName(
-        OUString const & aHierarchicalName)
-        throw (css::uno::RuntimeException, std::exception) override
+        OUString const & aHierarchicalName) override
     { return getRoot()->hasPropertyByHierarchicalName(aHierarchicalName); }
 
     rtl::Reference< RootAccess > getRoot();
@@ -126,7 +109,6 @@ private:
 };
 
 void Service::initialize(css::uno::Sequence< css::uno::Any > const & aArguments)
-    throw (css::uno::Exception, css::uno::RuntimeException, std::exception)
 {
     OUString locale;
     if (aArguments.getLength() != 1 || !(aArguments[0] >>= locale)) {
