@@ -46,7 +46,6 @@
 #include "nodemap.hxx"
 #include "parsemanager.hxx"
 #include "partial.hxx"
-#include "path.hxx"
 #include "propertynode.hxx"
 #include "setnode.hxx"
 #include "xcuparser.hxx"
@@ -73,9 +72,9 @@ xmlreader::XmlReader::Text XcuParser::getTextMode() {
 
 bool XcuParser::startElement(
     xmlreader::XmlReader & reader, int nsId, xmlreader::Span const & name,
-    std::set< OUString > const * existingDependencies)
+    std::set< OUString > const * /*existingDependencies*/)
 {
-    if (valueParser_.startElement(reader, nsId, name, existingDependencies)) {
+    if (valueParser_.startElement(reader, nsId, name)) {
         return true;
     }
     if (state_.empty()) {
@@ -94,42 +93,39 @@ bool XcuParser::startElement(
     } else if (state_.top().ignore) {
         state_.push(State::Ignore(false));
     } else if (!state_.top().node.is()) {
-        if (nsId == xmlreader::XmlReader::NAMESPACE_NONE && name.equals("item"))
+        if (nsId != xmlreader::XmlReader::NAMESPACE_NONE || !name.equals("item"))
         {
-            handleItem(reader);
-        } else {
             throw css::uno::RuntimeException(
                 "bad items node member <" + name.convertFromUtf8() + "> in " +
                 reader.getUrl());
         }
+        handleItem(reader);
     } else {
         switch (state_.top().node->kind()) {
         case Node::KIND_PROPERTY:
-            if (nsId == xmlreader::XmlReader::NAMESPACE_NONE &&
-                name.equals("value"))
+            if (nsId != xmlreader::XmlReader::NAMESPACE_NONE ||
+                !name.equals("value"))
             {
-                handlePropValue(
-                    reader,
-                    static_cast< PropertyNode * >(state_.top().node.get()));
-            } else {
                 throw css::uno::RuntimeException(
                     "bad property node member <" + name.convertFromUtf8() +
                     "> in " + reader.getUrl());
             }
+            handlePropValue(
+                reader,
+                static_cast< PropertyNode * >(state_.top().node.get()));
             break;
         case Node::KIND_LOCALIZED_PROPERTY:
-            if (nsId == xmlreader::XmlReader::NAMESPACE_NONE &&
-                name.equals("value"))
+            if (nsId != xmlreader::XmlReader::NAMESPACE_NONE ||
+                !name.equals("value"))
             {
-                handleLocpropValue(
-                    reader,
-                    static_cast< LocalizedPropertyNode * >(
-                        state_.top().node.get()));
-            } else {
                 throw css::uno::RuntimeException(
                     "bad localized property node member <" +
                     name.convertFromUtf8() + "> in " + reader.getUrl());
             }
+            handleLocpropValue(
+                reader,
+                static_cast< LocalizedPropertyNode * >(
+                    state_.top().node.get()));
             break;
         case Node::KIND_LOCALIZED_VALUE:
             throw css::uno::RuntimeException(
@@ -622,7 +618,7 @@ void XcuParser::handleGroupProp(
 }
 
 void XcuParser::handleUnknownGroupProp(
-    xmlreader::XmlReader const & reader, GroupNode * group,
+    xmlreader::XmlReader const & reader, GroupNode const * group,
     OUString const & name, Type type, Operation operation, bool finalized)
 {
     switch (operation) {
@@ -646,7 +642,7 @@ void XcuParser::handleUnknownGroupProp(
             recordModification(false);
             break;
         }
-        // fall through
+        SAL_FALLTHROUGH;
     default:
         SAL_WARN(
             "configmgr",
