@@ -17,11 +17,11 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "file/fcomp.hxx"
+#include <file/fcomp.hxx>
 #include <tools/debug.hxx>
-#include "TConnection.hxx"
+#include <TConnection.hxx>
 #include <connectivity/sqlparse.hxx>
-#include "file/fanalyzer.hxx"
+#include <file/fanalyzer.hxx>
 #include <com/sun/star/sdbc/XColumnLocate.hpp>
 #include <com/sun/star/util/DateTime.hpp>
 #include <com/sun/star/util/Date.hpp>
@@ -29,12 +29,12 @@
 #include <connectivity/dbexception.hxx>
 #include <connectivity/dbconversion.hxx>
 #include <com/sun/star/sdb/SQLFilterOperator.hpp>
-#include "resource/file_res.hrc"
-#include "file/FStringFunctions.hxx"
-#include "file/FDateFunctions.hxx"
-#include "file/FNumericFunctions.hxx"
-#include "file/FConnection.hxx"
-#include "sqlbison.hxx"
+#include <file/FStringFunctions.hxx>
+#include <file/FDateFunctions.hxx>
+#include <file/FNumericFunctions.hxx>
+#include <file/FConnection.hxx>
+#include <sqlbison.hxx>
+#include <strings.hrc>
 
 using namespace connectivity;
 using namespace connectivity::file;
@@ -47,7 +47,6 @@ using namespace com::sun::star;
 OPredicateCompiler::OPredicateCompiler(OSQLAnalyzer* pAnalyzer)//,OCursor& rCurs)
                      : m_pAnalyzer(pAnalyzer)
                      , m_nParamCounter(0)
-                     , m_bORCondition(false)
 {
 }
 
@@ -64,7 +63,7 @@ void OPredicateCompiler::dispose()
     m_xIndexes.clear();
 }
 
-void OPredicateCompiler::start(OSQLParseNode* pSQLParseNode)
+void OPredicateCompiler::start(OSQLParseNode const * pSQLParseNode)
 {
     if (!pSQLParseNode)
         return;
@@ -77,12 +76,12 @@ void OPredicateCompiler::start(OSQLParseNode* pSQLParseNode)
     if (SQL_ISRULE(pSQLParseNode,select_statement))
     {
         OSQLParseNode * pOrderbyClause = nullptr;
-        DBG_ASSERT(pSQLParseNode->count() >= 4,"OFILECursor: Fehler im Parse Tree");
+        DBG_ASSERT(pSQLParseNode->count() >= 4,"OFILECursor: Error in Parse Tree");
 
         OSQLParseNode * pTableExp = pSQLParseNode->getChild(3);
-        DBG_ASSERT(pTableExp != nullptr,"Fehler im Parse Tree");
-        DBG_ASSERT(SQL_ISRULE(pTableExp,table_exp)," Fehler im Parse Tree");
-        DBG_ASSERT(pTableExp->count() == TABLE_EXPRESSION_CHILD_COUNT,"Fehler im Parse Tree");
+        DBG_ASSERT(pTableExp != nullptr,"Error in Parse Tree");
+        DBG_ASSERT(SQL_ISRULE(pTableExp,table_exp)," Error in Parse Tree");
+        DBG_ASSERT(pTableExp->count() == TABLE_EXPRESSION_CHILD_COUNT,"Error in Parse Tree");
 
         // check that we don't use anything other than count(*) as function
         OSQLParseNode* pSelection = pSQLParseNode->getChild(2);
@@ -105,12 +104,12 @@ void OPredicateCompiler::start(OSQLParseNode* pSQLParseNode)
     }
     else if (SQL_ISRULE(pSQLParseNode,update_statement_searched))
     {
-        DBG_ASSERT(pSQLParseNode->count() == 5,"OFILECursor: Fehler im Parse Tree");
+        DBG_ASSERT(pSQLParseNode->count() == 5,"OFILECursor: Error in Parse Tree");
         pWhereClause = pSQLParseNode->getChild(4);
     }
     else if (SQL_ISRULE(pSQLParseNode,delete_statement_searched))
     {
-        DBG_ASSERT(pSQLParseNode->count() == 4,"Fehler im Parse Tree");
+        DBG_ASSERT(pSQLParseNode->count() == 4,"Error in Parse Tree");
         pWhereClause = pSQLParseNode->getChild(3);
     }
     else
@@ -120,22 +119,22 @@ void OPredicateCompiler::start(OSQLParseNode* pSQLParseNode)
     if (SQL_ISRULE(pWhereClause,where_clause))
     {
         // a where-clause is not allowed to be empty:
-        DBG_ASSERT(pWhereClause->count() == 2,"OFILECursor: Fehler im Parse Tree");
+        DBG_ASSERT(pWhereClause->count() == 2,"OFILECursor: Error in Parse Tree");
 
         OSQLParseNode * pComparisonPredicate = pWhereClause->getChild(1);
-        DBG_ASSERT(pComparisonPredicate != nullptr,"OFILECursor: Fehler im Parse Tree");
+        DBG_ASSERT(pComparisonPredicate != nullptr,"OFILECursor: Error in Parse Tree");
 
         execute( pComparisonPredicate );
     }
     else
     {
         // The where-clause is optionally in the majority of cases, i.e. it might be an "optional-where-clause".
-        DBG_ASSERT(SQL_ISRULE(pWhereClause,opt_where_clause),"OPredicateCompiler: Fehler im Parse Tree");
+        DBG_ASSERT(SQL_ISRULE(pWhereClause,opt_where_clause),"OPredicateCompiler: Error in Parse Tree");
     }
 }
 
 
-OOperand* OPredicateCompiler::execute(OSQLParseNode* pPredicateNode)
+OOperand* OPredicateCompiler::execute(OSQLParseNode const * pPredicateNode)
 {
     OOperand* pOperand = nullptr;
     if (pPredicateNode->count() == 3 &&                         // Expression is bracketed
@@ -144,7 +143,7 @@ OOperand* OPredicateCompiler::execute(OSQLParseNode* pPredicateNode)
     {
         execute(pPredicateNode->getChild(1));
     }
-    else if ((SQL_ISRULE(pPredicateNode,search_condition) || (SQL_ISRULE(pPredicateNode,boolean_term)))
+    else if ((SQL_ISRULE(pPredicateNode,search_condition) || SQL_ISRULE(pPredicateNode,boolean_term))
                             &&          // AND/OR-linkage:
                             pPredicateNode->count() == 3)
     {
@@ -153,20 +152,19 @@ OOperand* OPredicateCompiler::execute(OSQLParseNode* pPredicateNode)
 
         if (SQL_ISTOKEN(pPredicateNode->getChild(1),OR))                // OR-Operator
         {
-            m_aCodeList.push_back(new OOp_OR());
-            m_bORCondition = true;
+            m_aCodeList.push_back(new OOp_OR);
         }
         else if (SQL_ISTOKEN(pPredicateNode->getChild(1),AND))      // AND-Operator
-            m_aCodeList.push_back(new OOp_AND());
+            m_aCodeList.push_back(new OOp_AND);
         else
         {
-            OSL_FAIL("OPredicateCompiler: Fehler im Parse Tree");
+            OSL_FAIL("OPredicateCompiler: Error in Parse Tree");
         }
     }
     else if (SQL_ISRULE(pPredicateNode,boolean_factor))
     {
         execute(pPredicateNode->getChild(1));
-        m_aCodeList.push_back(new OOp_NOT());
+        m_aCodeList.push_back(new OOp_NOT);
     }
     else if (SQL_ISRULE(pPredicateNode,comparison_predicate))
     {
@@ -190,13 +188,13 @@ OOperand* OPredicateCompiler::execute(OSQLParseNode* pPredicateNode)
         execute(pPredicateNode->getChild(2));                           // process the right branch
         if (SQL_ISPUNCTUATION(pPredicateNode->getChild(1),"+"))
         {
-            m_aCodeList.push_back(new OOp_ADD());
+            m_aCodeList.push_back(new OOp_ADD);
         }
         else if (SQL_ISPUNCTUATION(pPredicateNode->getChild(1),"-"))
-            m_aCodeList.push_back(new OOp_SUB());
+            m_aCodeList.push_back(new OOp_SUB);
         else
         {
-            OSL_FAIL("OPredicateCompiler: Fehler im Parse Tree num_value_exp");
+            OSL_FAIL("OPredicateCompiler: Error in Parse Tree num_value_exp");
         }
     }
     else if(SQL_ISRULE(pPredicateNode,term))
@@ -205,13 +203,13 @@ OOperand* OPredicateCompiler::execute(OSQLParseNode* pPredicateNode)
         execute(pPredicateNode->getChild(2));                           // process the right branch
         if (SQL_ISPUNCTUATION(pPredicateNode->getChild(1),"*"))
         {
-            m_aCodeList.push_back(new OOp_MUL());
+            m_aCodeList.push_back(new OOp_MUL);
         }
         else if (SQL_ISPUNCTUATION(pPredicateNode->getChild(1),"/"))
-            m_aCodeList.push_back(new OOp_DIV());
+            m_aCodeList.push_back(new OOp_DIV);
         else
         {
-            OSL_FAIL("OPredicateCompiler: Fehler im Parse Tree num_value_exp");
+            OSL_FAIL("OPredicateCompiler: Error in Parse Tree num_value_exp");
         }
     }
     else
@@ -221,14 +219,14 @@ OOperand* OPredicateCompiler::execute(OSQLParseNode* pPredicateNode)
 }
 
 
-OOperand* OPredicateCompiler::execute_COMPARE(OSQLParseNode* pPredicateNode)  throw(SQLException, RuntimeException)
+void OPredicateCompiler::execute_COMPARE(OSQLParseNode const * pPredicateNode)
 {
-    DBG_ASSERT(pPredicateNode->count() == 3,"OFILECursor: Fehler im Parse Tree");
+    DBG_ASSERT(pPredicateNode->count() == 3,"OFILECursor: Error in Parse Tree");
 
     if ( !(SQL_ISRULE(pPredicateNode->getChild(0),column_ref)               ||
-          pPredicateNode->getChild(2)->getNodeType() == SQL_NODE_STRING     ||
-          pPredicateNode->getChild(2)->getNodeType() == SQL_NODE_INTNUM     ||
-          pPredicateNode->getChild(2)->getNodeType() == SQL_NODE_APPROXNUM  ||
+          pPredicateNode->getChild(2)->getNodeType() == SQLNodeType::String     ||
+          pPredicateNode->getChild(2)->getNodeType() == SQLNodeType::IntNum     ||
+          pPredicateNode->getChild(2)->getNodeType() == SQLNodeType::ApproxNum  ||
           SQL_ISTOKEN(pPredicateNode->getChild(2),TRUE)                     ||
           SQL_ISTOKEN(pPredicateNode->getChild(2),FALSE)                    ||
           SQL_ISRULE(pPredicateNode->getChild(2),parameter)                 ||
@@ -240,23 +238,23 @@ OOperand* OPredicateCompiler::execute_COMPARE(OSQLParseNode* pPredicateNode)  th
           SQL_ISRULE(pPredicateNode->getChild(2),fold)) )
     {
         m_pAnalyzer->getConnection()->throwGenericSQLException(STR_QUERY_TOO_COMPLEX,nullptr);
-        return nullptr;
+        return;
     }
 
     sal_Int32 ePredicateType( SQLFilterOperator::EQUAL );
     OSQLParseNode *pPrec = pPredicateNode->getChild(1);
 
-    if (pPrec->getNodeType() == SQL_NODE_EQUAL)
+    if (pPrec->getNodeType() == SQLNodeType::Equal)
         ePredicateType = SQLFilterOperator::EQUAL;
-    else if (pPrec->getNodeType() == SQL_NODE_NOTEQUAL)
+    else if (pPrec->getNodeType() == SQLNodeType::NotEqual)
         ePredicateType = SQLFilterOperator::NOT_EQUAL;
-    else if (pPrec->getNodeType() == SQL_NODE_LESS)
+    else if (pPrec->getNodeType() == SQLNodeType::Less)
         ePredicateType = SQLFilterOperator::LESS;
-    else if (pPrec->getNodeType() == SQL_NODE_LESSEQ)
+    else if (pPrec->getNodeType() == SQLNodeType::LessEq)
         ePredicateType = SQLFilterOperator::LESS_EQUAL;
-    else if (pPrec->getNodeType() == SQL_NODE_GREATEQ)
+    else if (pPrec->getNodeType() == SQLNodeType::GreatEq)
         ePredicateType = SQLFilterOperator::GREATER_EQUAL;
-    else if (pPrec->getNodeType() == SQL_NODE_GREAT)
+    else if (pPrec->getNodeType() == SQLNodeType::Great)
         ePredicateType = SQLFilterOperator::GREATER;
     else
         OSL_FAIL( "OPredicateCompiler::execute_COMPARE: unexpected node type!" );
@@ -264,14 +262,12 @@ OOperand* OPredicateCompiler::execute_COMPARE(OSQLParseNode* pPredicateNode)  th
     execute(pPredicateNode->getChild(0));
     execute(pPredicateNode->getChild(2));
     m_aCodeList.push_back( new OOp_COMPARE(ePredicateType) );
-
-    return nullptr;
 }
 
 
-OOperand* OPredicateCompiler::execute_LIKE(OSQLParseNode* pPredicateNode) throw(SQLException, RuntimeException)
+void OPredicateCompiler::execute_LIKE(OSQLParseNode const * pPredicateNode)
 {
-    DBG_ASSERT(pPredicateNode->count() == 2,"OFILECursor: Fehler im Parse Tree");
+    DBG_ASSERT(pPredicateNode->count() == 2,"OFILECursor: Error in Parse Tree");
     const OSQLParseNode* pPart2 = pPredicateNode->getChild(1);
 
     sal_Unicode cEscape = L'\0';
@@ -280,7 +276,7 @@ OOperand* OPredicateCompiler::execute_LIKE(OSQLParseNode* pPredicateNode) throw(
     OSQLParseNode* pAtom        = pPart2->getChild(pPart2->count()-2);
     OSQLParseNode* pOptEscape   = pPart2->getChild(pPart2->count()-1);
 
-    if (!(pAtom->getNodeType() == SQL_NODE_STRING   ||
+    if (!(pAtom->getNodeType() == SQLNodeType::String   ||
           SQL_ISRULE(pAtom,parameter)               ||
           // odbc date
           SQL_ISRULE(pAtom,set_fct_spec)            ||
@@ -290,7 +286,7 @@ OOperand* OPredicateCompiler::execute_LIKE(OSQLParseNode* pPredicateNode) throw(
           SQL_ISRULE(pAtom,fold)) )
     {
         m_pAnalyzer->getConnection()->throwGenericSQLException(STR_QUERY_TOO_COMPLEX,nullptr);
-        return nullptr;
+        return;
     }
 
     if (pOptEscape->count() != 0)
@@ -300,7 +296,7 @@ OOperand* OPredicateCompiler::execute_LIKE(OSQLParseNode* pPredicateNode) throw(
             m_pAnalyzer->getConnection()->throwGenericSQLException(STR_QUERY_INVALID_LIKE_STRING,nullptr);
         }
         OSQLParseNode *pEscNode = pOptEscape->getChild(1);
-        if (pEscNode->getNodeType() != SQL_NODE_STRING)
+        if (pEscNode->getNodeType() != SQLNodeType::String)
         {
             m_pAnalyzer->getConnection()->throwGenericSQLException(STR_QUERY_INVALID_LIKE_STRING,nullptr);
         }
@@ -315,13 +311,11 @@ OOperand* OPredicateCompiler::execute_LIKE(OSQLParseNode* pPredicateNode) throw(
                                     ? new OOp_NOTLIKE(cEscape)
                                     : new OOp_LIKE(cEscape);
     m_aCodeList.push_back(pOperator);
-
-    return nullptr;
 }
 
-OOperand* OPredicateCompiler::execute_BETWEEN(OSQLParseNode* pPredicateNode) throw(SQLException, RuntimeException)
+void OPredicateCompiler::execute_BETWEEN(OSQLParseNode const * pPredicateNode)
 {
-    DBG_ASSERT(pPredicateNode->count() == 2,"OFILECursor: Fehler im Parse Tree");
+    DBG_ASSERT(pPredicateNode->count() == 2,"OFILECursor: Error in Parse Tree");
 
     OSQLParseNode* pColumn = pPredicateNode->getChild(0);
     const OSQLParseNode* pPart2 = pPredicateNode->getChild(1);
@@ -329,8 +323,8 @@ OOperand* OPredicateCompiler::execute_BETWEEN(OSQLParseNode* pPredicateNode) thr
     OSQLParseNode* p2ndtValue = pPart2->getChild(4);
 
     if (
-            !(p1stValue->getNodeType() == SQL_NODE_STRING || SQL_ISRULE(p1stValue,parameter))
-        &&  !(p2ndtValue->getNodeType() == SQL_NODE_STRING || SQL_ISRULE(p2ndtValue,parameter))
+            !(p1stValue->getNodeType() == SQLNodeType::String || SQL_ISRULE(p1stValue,parameter))
+        &&  !(p2ndtValue->getNodeType() == SQLNodeType::String || SQL_ISRULE(p2ndtValue,parameter))
         )
     {
         m_pAnalyzer->getConnection()->throwGenericSQLException(STR_QUERY_INVALID_BETWEEN,nullptr);
@@ -388,22 +382,19 @@ OOperand* OPredicateCompiler::execute_BETWEEN(OSQLParseNode* pPredicateNode) thr
     }
 
 
-
     OBoolOperator* pBoolOp = nullptr;
     if ( bNot )
-        pBoolOp = new OOp_OR();
+        pBoolOp = new OOp_OR;
     else
-        pBoolOp = new OOp_AND();
+        pBoolOp = new OOp_AND;
     m_aCodeList.push_back(pBoolOp);
-
-    return nullptr;
 }
 
-OOperand* OPredicateCompiler::execute_ISNULL(OSQLParseNode* pPredicateNode) throw(SQLException, RuntimeException)
+void OPredicateCompiler::execute_ISNULL(OSQLParseNode const * pPredicateNode)
 {
-    DBG_ASSERT(pPredicateNode->count() == 2,"OFILECursor: Fehler im Parse Tree");
+    DBG_ASSERT(pPredicateNode->count() == 2,"OFILECursor: Error in Parse Tree");
     const OSQLParseNode* pPart2 = pPredicateNode->getChild(1);
-    DBG_ASSERT(SQL_ISTOKEN(pPart2->getChild(0),IS),"OFILECursor: Fehler im Parse Tree");
+    DBG_ASSERT(SQL_ISTOKEN(pPart2->getChild(0),IS),"OFILECursor: Error in Parse Tree");
 
     sal_Int32 ePredicateType;
     if (SQL_ISTOKEN(pPart2->getChild(1),NOT))
@@ -413,13 +404,11 @@ OOperand* OPredicateCompiler::execute_ISNULL(OSQLParseNode* pPredicateNode) thro
 
     execute(pPredicateNode->getChild(0));
     OBoolOperator* pOperator = (ePredicateType == SQLFilterOperator::SQLNULL) ?
-                                new OOp_ISNULL() : new OOp_ISNOTNULL();
+                                new OOp_ISNULL : new OOp_ISNOTNULL;
     m_aCodeList.push_back(pOperator);
-
-    return nullptr;
 }
 
-OOperand* OPredicateCompiler::execute_Operand(OSQLParseNode* pPredicateNode) throw(SQLException, RuntimeException)
+OOperand* OPredicateCompiler::execute_Operand(OSQLParseNode const * pPredicateNode)
 {
     OOperand* pOperand = nullptr;
 
@@ -446,12 +435,12 @@ OOperand* OPredicateCompiler::execute_Operand(OSQLParseNode* pPredicateNode) thr
                  ) );
             ::dbtools::throwGenericSQLException( sError, nullptr );
         }
-        ::com::sun::star::uno::Reference< ::com::sun::star::beans::XPropertySet> xCol;
+        css::uno::Reference< css::beans::XPropertySet> xCol;
         try
         {
             if (m_orgColumns->getByName(aColumnName) >>= xCol)
             {
-                pOperand = OSQLAnalyzer::createOperandAttr(Reference< XColumnLocate>(m_orgColumns,UNO_QUERY)->findColumn(aColumnName),xCol,m_xIndexes);
+                pOperand = OSQLAnalyzer::createOperandAttr(Reference< XColumnLocate>(m_orgColumns,UNO_QUERY)->findColumn(aColumnName),xCol);
             }
             else
             {// Column doesn't exist in the Result-set
@@ -471,10 +460,10 @@ OOperand* OPredicateCompiler::execute_Operand(OSQLParseNode* pPredicateNode) thr
     {
         pOperand = new OOperandParam(pPredicateNode, ++m_nParamCounter);
     }
-    else if (pPredicateNode->getNodeType() == SQL_NODE_STRING ||
-             pPredicateNode->getNodeType() == SQL_NODE_INTNUM ||
-             pPredicateNode->getNodeType() == SQL_NODE_APPROXNUM ||
-             pPredicateNode->getNodeType() == SQL_NODE_NAME ||
+    else if (pPredicateNode->getNodeType() == SQLNodeType::String ||
+             pPredicateNode->getNodeType() == SQLNodeType::IntNum ||
+             pPredicateNode->getNodeType() == SQLNodeType::ApproxNum ||
+             pPredicateNode->getNodeType() == SQLNodeType::Name ||
              SQL_ISTOKEN(pPredicateNode,TRUE) ||
              SQL_ISTOKEN(pPredicateNode,FALSE) ||
              SQL_ISRULE(pPredicateNode,parameter))
@@ -483,10 +472,9 @@ OOperand* OPredicateCompiler::execute_Operand(OSQLParseNode* pPredicateNode) thr
     }
     else if((pPredicateNode->count() == 2) &&
             (SQL_ISPUNCTUATION(pPredicateNode->getChild(0),"+") || SQL_ISPUNCTUATION(pPredicateNode->getChild(0),"-")) &&
-            pPredicateNode->getChild(1)->getNodeType() == SQL_NODE_INTNUM)
+            pPredicateNode->getChild(1)->getNodeType() == SQLNodeType::IntNum)
     { // if -1 or +1 is there
-        OUString aValue(pPredicateNode->getChild(0)->getTokenValue());
-        aValue += pPredicateNode->getChild(1)->getTokenValue();
+        OUString aValue = pPredicateNode->getChild(0)->getTokenValue() + pPredicateNode->getChild(1)->getTokenValue();
         pOperand = new OOperandConst(*pPredicateNode->getChild(1), aValue);
     }
     else if( SQL_ISRULE(pPredicateNode,set_fct_spec) && SQL_ISPUNCTUATION(pPredicateNode->getChild(0),"{") )
@@ -495,7 +483,7 @@ OOperand* OPredicateCompiler::execute_Operand(OSQLParseNode* pPredicateNode) thr
         const OSQLParseNode* pODBCNodeChild = pODBCNode->getChild(0);
 
         // Odbc Date or time
-        if (pODBCNodeChild->getNodeType() == SQL_NODE_KEYWORD && (
+        if (pODBCNodeChild->getNodeType() == SQLNodeType::Keyword && (
             SQL_ISTOKEN(pODBCNodeChild,D) ||
             SQL_ISTOKEN(pODBCNodeChild,T) ||
             SQL_ISTOKEN(pODBCNodeChild,TS) ))
@@ -564,16 +552,16 @@ bool OPredicateInterpreter::evaluate(OCodeList& rCodeList)
     OOperand* pOperand = m_aStack.top();
     m_aStack.pop();
 
-    DBG_ASSERT(m_aStack.empty(), "StackFehler");
-    DBG_ASSERT(pOperand, "StackFehler");
+    DBG_ASSERT(m_aStack.empty(), "Stack error");
+    DBG_ASSERT(pOperand, "Stack error");
 
     bResult = pOperand->isValid();
-    if (dynamic_cast<const OOperandResult* >(pOperand) !=  nullptr)
+    if (typeid(OOperandResult) == typeid(*pOperand))
         delete pOperand;
     return bResult;
 }
 
-void OPredicateInterpreter::evaluateSelection(OCodeList& rCodeList,ORowSetValueDecoratorRef& _rVal)
+void OPredicateInterpreter::evaluateSelection(OCodeList& rCodeList, ORowSetValueDecoratorRef const & _rVal)
 {
     OCodeList::iterator aIter = rCodeList.begin();
     if (!(*aIter))
@@ -591,32 +579,31 @@ void OPredicateInterpreter::evaluateSelection(OCodeList& rCodeList,ORowSetValueD
     OOperand* pOperand = m_aStack.top();
     m_aStack.pop();
 
-    DBG_ASSERT(m_aStack.empty(), "StackFehler");
-    DBG_ASSERT(pOperand, "StackFehler");
+    DBG_ASSERT(m_aStack.empty(), "Stack error");
+    DBG_ASSERT(pOperand, "Stack error");
 
     (*_rVal) = pOperand->getValue();
-    if (dynamic_cast<const OOperandResult* >(pOperand) !=  nullptr)
+    if (typeid(OOperandResult) == typeid(*pOperand))
         delete pOperand;
 }
 
-OOperand* OPredicateCompiler::execute_Fold(OSQLParseNode* pPredicateNode)   throw(SQLException, RuntimeException)
+void OPredicateCompiler::execute_Fold(OSQLParseNode const * pPredicateNode)
 {
-    DBG_ASSERT(pPredicateNode->count() >= 4,"OFILECursor: Fehler im Parse Tree");
+    DBG_ASSERT(pPredicateNode->count() >= 4,"OFILECursor: Error in Parse Tree");
 
     bool bUpper = SQL_ISTOKEN(pPredicateNode->getChild(0),UPPER);
 
     execute(pPredicateNode->getChild(2));
     OOperator* pOperator = nullptr;
     if ( bUpper )
-        pOperator = new OOp_Upper();
+        pOperator = new OOp_Upper;
     else
-        pOperator = new OOp_Lower();
+        pOperator = new OOp_Lower;
 
     m_aCodeList.push_back(pOperator);
-    return nullptr;
 }
 
-OOperand* OPredicateCompiler::executeFunction(OSQLParseNode* pPredicateNode)    throw(SQLException, RuntimeException)
+void OPredicateCompiler::executeFunction(OSQLParseNode const * pPredicateNode)
 {
     OOperator* pOperator = nullptr;
 
@@ -668,107 +655,107 @@ OOperand* OPredicateCompiler::executeFunction(OSQLParseNode* pPredicateNode)
                 case SQL_TOKEN_CHAR_LENGTH:
                 case SQL_TOKEN_LENGTH:
                 case SQL_TOKEN_OCTET_LENGTH:
-                    pOperator = new OOp_CharLength();
+                    pOperator = new OOp_CharLength;
                     break;
                 case SQL_TOKEN_ASCII:
-                    pOperator = new OOp_Ascii();
+                    pOperator = new OOp_Ascii;
                     break;
                 case SQL_TOKEN_LCASE:
-                    pOperator = new OOp_Lower();
+                    pOperator = new OOp_Lower;
                     break;
 
                 case SQL_TOKEN_LTRIM:
-                    pOperator = new OOp_LTrim();
+                    pOperator = new OOp_LTrim;
                     break;
                 case SQL_TOKEN_RTRIM:
-                    pOperator = new OOp_RTrim();
+                    pOperator = new OOp_RTrim;
                     break;
                 case SQL_TOKEN_SPACE:
-                    pOperator = new OOp_Space();
+                    pOperator = new OOp_Space;
                     break;
                 case SQL_TOKEN_UCASE:
-                    pOperator = new OOp_Upper();
+                    pOperator = new OOp_Upper;
                     break;
                 case SQL_TOKEN_ABS:
-                    pOperator = new OOp_Abs();
+                    pOperator = new OOp_Abs;
                     break;
                 case SQL_TOKEN_ACOS:
-                    pOperator = new OOp_ACos();
+                    pOperator = new OOp_ACos;
                     break;
                 case SQL_TOKEN_ASIN:
-                    pOperator = new OOp_ASin();
+                    pOperator = new OOp_ASin;
                     break;
                 case SQL_TOKEN_ATAN:
-                    pOperator = new OOp_ATan();
+                    pOperator = new OOp_ATan;
                     break;
                 case SQL_TOKEN_CEILING:
-                    pOperator = new OOp_Ceiling();
+                    pOperator = new OOp_Ceiling;
                     break;
                 case SQL_TOKEN_COS:
-                    pOperator = new OOp_Cos();
+                    pOperator = new OOp_Cos;
                     break;
                 case SQL_TOKEN_DEGREES:
-                    pOperator = new OOp_Degrees();
+                    pOperator = new OOp_Degrees;
                     break;
                 case SQL_TOKEN_EXP:
-                    pOperator = new OOp_Exp();
+                    pOperator = new OOp_Exp;
                     break;
                 case SQL_TOKEN_FLOOR:
-                    pOperator = new OOp_Floor();
+                    pOperator = new OOp_Floor;
                     break;
                 case SQL_TOKEN_LOG10:
-                    pOperator = new OOp_Log10();
+                    pOperator = new OOp_Log10;
                     break;
                 case SQL_TOKEN_LN:
-                    pOperator = new OOp_Ln();
+                    pOperator = new OOp_Ln;
                     break;
                 case SQL_TOKEN_RADIANS:
-                    pOperator = new OOp_Radians();
+                    pOperator = new OOp_Radians;
                     break;
                 case SQL_TOKEN_SIGN:
-                    pOperator = new OOp_Sign();
+                    pOperator = new OOp_Sign;
                     break;
                 case SQL_TOKEN_SIN:
-                    pOperator = new OOp_Sin();
+                    pOperator = new OOp_Sin;
                     break;
                 case SQL_TOKEN_SQRT:
-                    pOperator = new OOp_Sqrt();
+                    pOperator = new OOp_Sqrt;
                     break;
                 case SQL_TOKEN_TAN:
-                    pOperator = new OOp_Tan();
+                    pOperator = new OOp_Tan;
                     break;
                 case SQL_TOKEN_DAYOFWEEK:
-                    pOperator = new OOp_DayOfWeek();
+                    pOperator = new OOp_DayOfWeek;
                     break;
                 case SQL_TOKEN_DAYOFMONTH:
-                    pOperator = new OOp_DayOfMonth();
+                    pOperator = new OOp_DayOfMonth;
                     break;
                 case SQL_TOKEN_DAYOFYEAR:
-                    pOperator = new OOp_DayOfYear();
+                    pOperator = new OOp_DayOfYear;
                     break;
                 case SQL_TOKEN_MONTH:
-                    pOperator = new OOp_Month();
+                    pOperator = new OOp_Month;
                     break;
                 case SQL_TOKEN_DAYNAME:
-                    pOperator = new OOp_DayName();
+                    pOperator = new OOp_DayName;
                     break;
                 case SQL_TOKEN_MONTHNAME:
-                    pOperator = new OOp_MonthName();
+                    pOperator = new OOp_MonthName;
                     break;
                 case SQL_TOKEN_QUARTER:
-                    pOperator = new OOp_Quarter();
+                    pOperator = new OOp_Quarter;
                     break;
                 case SQL_TOKEN_YEAR:
-                    pOperator = new OOp_Year();
+                    pOperator = new OOp_Year;
                     break;
                 case SQL_TOKEN_HOUR:
-                    pOperator = new OOp_Hour();
+                    pOperator = new OOp_Hour;
                     break;
                 case SQL_TOKEN_MINUTE:
-                    pOperator = new OOp_Minute();
+                    pOperator = new OOp_Minute;
                     break;
                 case SQL_TOKEN_SECOND:
-                    pOperator = new OOp_Second();
+                    pOperator = new OOp_Second;
                     break;
                 default:
                     OSL_FAIL("Error in switch!");
@@ -803,60 +790,60 @@ OOperand* OPredicateCompiler::executeFunction(OSQLParseNode* pPredicateNode)
                 switch( nTokenId )
                 {
                     case SQL_TOKEN_CHAR:
-                        pOperator = new OOp_Char();
+                        pOperator = new OOp_Char;
                         break;
                     case SQL_TOKEN_CONCAT:
-                        pOperator = new OOp_Concat();
+                        pOperator = new OOp_Concat;
                         break;
                     case SQL_TOKEN_INSERT:
-                        pOperator = new OOp_Insert();
+                        pOperator = new OOp_Insert;
                         break;
                     case SQL_TOKEN_LEFT:
-                        pOperator = new OOp_Left();
+                        pOperator = new OOp_Left;
                         break;
                     case SQL_TOKEN_LOCATE:
                     case SQL_TOKEN_LOCATE_2:
-                        pOperator = new OOp_Locate();
+                        pOperator = new OOp_Locate;
                         break;
                     case SQL_TOKEN_REPEAT:
-                        pOperator = new OOp_Repeat();
+                        pOperator = new OOp_Repeat;
                         break;
                     case SQL_TOKEN_REPLACE:
-                        pOperator = new OOp_Replace();
+                        pOperator = new OOp_Replace;
                         break;
                     case SQL_TOKEN_RIGHT:
-                        pOperator = new OOp_Right();
+                        pOperator = new OOp_Right;
                         break;
                     case SQL_TOKEN_MOD:
-                        pOperator = new OOp_Mod();
+                        pOperator = new OOp_Mod;
                         break;
                     case SQL_TOKEN_ROUND:
-                        pOperator = new OOp_Round();
+                        pOperator = new OOp_Round;
                         break;
                     case SQL_TOKEN_LOGF:
                     case SQL_TOKEN_LOG:
-                        pOperator = new OOp_Log();
+                        pOperator = new OOp_Log;
                         break;
                     case SQL_TOKEN_POWER:
-                        pOperator = new OOp_Pow();
+                        pOperator = new OOp_Pow;
                         break;
                     case SQL_TOKEN_ATAN2:
-                        pOperator = new OOp_ATan2();
+                        pOperator = new OOp_ATan2;
                         break;
                     case SQL_TOKEN_PI:
-                        pOperator = new OOp_Pi();
+                        pOperator = new OOp_Pi;
                         break;
                     case SQL_TOKEN_CURDATE:
-                        pOperator = new OOp_CurDate();
+                        pOperator = new OOp_CurDate;
                         break;
                     case SQL_TOKEN_CURTIME:
-                        pOperator = new OOp_CurTime();
+                        pOperator = new OOp_CurTime;
                         break;
                     case SQL_TOKEN_NOW:
-                        pOperator = new OOp_Now();
+                        pOperator = new OOp_Now;
                         break;
                     case SQL_TOKEN_WEEK:
-                        pOperator = new OOp_Week();
+                        pOperator = new OOp_Week;
                         break;
                     default:
                         OSL_FAIL("Error in switch!");
@@ -878,7 +865,7 @@ OOperand* OPredicateCompiler::executeFunction(OSQLParseNode* pPredicateNode)
                 execute(pPredicateNode->getChild(4));
                 execute(pPredicateNode->getChild(5)->getChild(1));
             }
-            pOperator = new OOp_SubString();
+            pOperator = new OOp_SubString;
             break;
 
         case SQL_TOKEN_POSITION:
@@ -894,16 +881,14 @@ OOperand* OPredicateCompiler::executeFunction(OSQLParseNode* pPredicateNode)
                 execute(pPredicateNode->getChild(2));
                 execute(pPredicateNode->getChild(4));
             }
-            pOperator = new OOp_Locate();
+            pOperator = new OOp_Locate;
             break;
         default:
             m_pAnalyzer->getConnection()->throwGenericSQLException(STR_QUERY_FUNCTION_NOT_SUPPORTED,nullptr);
     }
 
     m_aCodeList.push_back(pOperator);
-    return nullptr;
 }
 
 
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
