@@ -57,14 +57,14 @@ OResultSet::OResultSet(Connection* pConnection,
                        ::osl::Mutex& rMutex,
                        const uno::Reference< XInterface >& xStatement,
                        isc_stmt_handle& aStatementHandle,
-                       XSQLDA* pSqlda)
+                       XSQLDA* pSqlda )
     : OResultSet_BASE(rMutex)
     , OPropertyContainer(OResultSet_BASE::rBHelper)
     , m_bIsBookmarkable(false)
     , m_nFetchSize(1)
-    , m_nResultSetType(::com::sun::star::sdbc::ResultSetType::FORWARD_ONLY)
-    , m_nFetchDirection(::com::sun::star::sdbc::FetchDirection::FORWARD)
-    , m_nResultSetConcurrency(::com::sun::star::sdbc::ResultSetConcurrency::READ_ONLY)
+    , m_nResultSetType(css::sdbc::ResultSetType::FORWARD_ONLY)
+    , m_nFetchDirection(css::sdbc::FetchDirection::FORWARD)
+    , m_nResultSetConcurrency(css::sdbc::ResultSetConcurrency::READ_ONLY)
     , m_pConnection(pConnection)
     , m_rMutex(rMutex)
     , m_xStatement(xStatement)
@@ -113,7 +113,7 @@ OResultSet::~OResultSet()
 }
 
 // ---- XResultSet -- Row retrieval methods ------------------------------------
-sal_Int32 SAL_CALL OResultSet::getRow() throw(SQLException, RuntimeException, std::exception)
+sal_Int32 SAL_CALL OResultSet::getRow()
 {
     MutexGuard aGuard(m_rMutex);
     checkDisposed(OResultSet_BASE::rBHelper.bDisposed);
@@ -121,7 +121,7 @@ sal_Int32 SAL_CALL OResultSet::getRow() throw(SQLException, RuntimeException, st
     return m_currentRow;
 }
 
-sal_Bool SAL_CALL OResultSet::next() throw(SQLException, RuntimeException, std::exception)
+sal_Bool SAL_CALL OResultSet::next()
 {
     MutexGuard aGuard(m_rMutex);
     checkDisposed(OResultSet_BASE::rBHelper.bDisposed);
@@ -134,37 +134,37 @@ sal_Bool SAL_CALL OResultSet::next() throw(SQLException, RuntimeException, std::
                                m_pSqlda);
     if (fetchStat == 0)         // SUCCESSFUL
     {
-        return sal_True;
+        return true;
     }
-    else if (fetchStat == 100L) // END OF DATASET
+    else if (fetchStat == 100) // END OF DATASET
     {
         m_bIsAfterLastRow = true;
-        return sal_False;
+        return false;
     }
     else
     {
         SAL_WARN("connectivity.firebird", "Error when fetching data");
         // Throws sql exception as appropriate
         evaluateStatusVector(m_statusVector, "isc_dsql_fetch", *this);
-        return sal_False;
+        return false;
     }
 }
 
-sal_Bool SAL_CALL OResultSet::previous() throw(SQLException, RuntimeException, std::exception)
+sal_Bool SAL_CALL OResultSet::previous()
 {
     ::dbtools::throwFunctionNotSupportedSQLException("previous not supported in firebird",
                                                   *this);
-    return sal_False;
+    return false;
 }
 
-sal_Bool SAL_CALL OResultSet::isLast() throw(SQLException, RuntimeException, std::exception)
+sal_Bool SAL_CALL OResultSet::isLast()
 {
     ::dbtools::throwFunctionNotSupportedSQLException("isLast not supported in firebird",
                                                   *this);
-    return sal_False;
+    return false;
 }
 
-sal_Bool SAL_CALL OResultSet::isBeforeFirst() throw(SQLException, RuntimeException, std::exception)
+sal_Bool SAL_CALL OResultSet::isBeforeFirst()
 {
     MutexGuard aGuard(m_rMutex);
     checkDisposed(OResultSet_BASE::rBHelper.bDisposed);
@@ -172,7 +172,7 @@ sal_Bool SAL_CALL OResultSet::isBeforeFirst() throw(SQLException, RuntimeExcepti
     return m_currentRow == 0;
 }
 
-sal_Bool SAL_CALL OResultSet::isAfterLast() throw(SQLException, RuntimeException, std::exception)
+sal_Bool SAL_CALL OResultSet::isAfterLast()
 {
     MutexGuard aGuard(m_rMutex);
     checkDisposed(OResultSet_BASE::rBHelper.bDisposed);
@@ -180,7 +180,7 @@ sal_Bool SAL_CALL OResultSet::isAfterLast() throw(SQLException, RuntimeException
     return m_bIsAfterLastRow;
 }
 
-sal_Bool SAL_CALL OResultSet::isFirst() throw(SQLException, RuntimeException, std::exception)
+sal_Bool SAL_CALL OResultSet::isFirst()
 {
     MutexGuard aGuard(m_rMutex);
     checkDisposed(OResultSet_BASE::rBHelper.bDisposed);
@@ -188,7 +188,7 @@ sal_Bool SAL_CALL OResultSet::isFirst() throw(SQLException, RuntimeException, st
     return m_currentRow == 1 && !m_bIsAfterLastRow;
 }
 
-void SAL_CALL OResultSet::beforeFirst() throw(SQLException, RuntimeException, std::exception)
+void SAL_CALL OResultSet::beforeFirst()
 {
     MutexGuard aGuard(m_rMutex);
     checkDisposed(OResultSet_BASE::rBHelper.bDisposed);
@@ -198,7 +198,7 @@ void SAL_CALL OResultSet::beforeFirst() throw(SQLException, RuntimeException, st
                                                       *this);
 }
 
-void SAL_CALL OResultSet::afterLast() throw(SQLException, RuntimeException, std::exception)
+void SAL_CALL OResultSet::afterLast()
 {
     MutexGuard aGuard(m_rMutex);
     checkDisposed(OResultSet_BASE::rBHelper.bDisposed);
@@ -208,7 +208,7 @@ void SAL_CALL OResultSet::afterLast() throw(SQLException, RuntimeException, std:
                                                       *this);
 }
 
-sal_Bool SAL_CALL OResultSet::first() throw(SQLException, RuntimeException, std::exception)
+sal_Bool SAL_CALL OResultSet::first()
 {
     MutexGuard aGuard(m_rMutex);
     checkDisposed(OResultSet_BASE::rBHelper.bDisposed);
@@ -219,26 +219,26 @@ sal_Bool SAL_CALL OResultSet::first() throw(SQLException, RuntimeException, std:
     }
     else if (m_currentRow == 1 && !m_bIsAfterLastRow)
     {
-        return sal_True;
+        return true;
     }
     else
     {
         ::dbtools::throwFunctionNotSupportedSQLException("first not supported in firebird",
                                                       *this);
-        return sal_False;
+        return false;
     }
 }
 
-sal_Bool SAL_CALL OResultSet::last() throw(SQLException, RuntimeException, std::exception)
+sal_Bool SAL_CALL OResultSet::last()
 {
     // We need to iterate past the last row to know when we've passed the last
     // row, hence we can't actually move to last.
     ::dbtools::throwFunctionNotSupportedSQLException("last not supported in firebird",
                                                   *this);
-    return sal_False;
+    return false;
 }
 
-sal_Bool SAL_CALL OResultSet::absolute(sal_Int32 aRow) throw(SQLException, RuntimeException, std::exception)
+sal_Bool SAL_CALL OResultSet::absolute(sal_Int32 aRow)
 {
     MutexGuard aGuard(m_rMutex);
     checkDisposed(OResultSet_BASE::rBHelper.bDisposed);
@@ -252,11 +252,11 @@ sal_Bool SAL_CALL OResultSet::absolute(sal_Int32 aRow) throw(SQLException, Runti
     {
         ::dbtools::throwFunctionNotSupportedSQLException("absolute not supported in firebird",
                                                       *this);
-        return sal_False;
+        return false;
     }
 }
 
-sal_Bool SAL_CALL OResultSet::relative(sal_Int32 row) throw(SQLException, RuntimeException, std::exception)
+sal_Bool SAL_CALL OResultSet::relative(sal_Int32 row)
 {
     MutexGuard aGuard(m_rMutex);
     checkDisposed(OResultSet_BASE::rBHelper.bDisposed);
@@ -266,20 +266,19 @@ sal_Bool SAL_CALL OResultSet::relative(sal_Int32 row) throw(SQLException, Runtim
         while (row--)
         {
             if (!next())
-                return sal_False;
+                return false;
         }
-        return sal_True;
+        return true;
     }
     else
     {
         ::dbtools::throwFunctionNotSupportedSQLException("relative not supported in firebird",
                                                       *this);
-        return sal_False;
+        return false;
     }
 }
 
 void SAL_CALL OResultSet::checkColumnIndex(sal_Int32 nIndex)
-    throw (SQLException, RuntimeException)
 {
     MutexGuard aGuard(m_rMutex);
     checkDisposed(OResultSet_BASE::rBHelper.bDisposed);
@@ -288,13 +287,12 @@ void SAL_CALL OResultSet::checkColumnIndex(sal_Int32 nIndex)
     {
         ::dbtools::throwSQLException(
             "No column " + OUString::number(nIndex),
-            ::dbtools::SQL_COLUMN_NOT_FOUND,
+            ::dbtools::StandardSQLState::COLUMN_NOT_FOUND,
             *this);
     }
 }
 
 void SAL_CALL OResultSet::checkRowIndex()
-    throw (SQLException, RuntimeException)
 {
     MutexGuard aGuard(m_rMutex);
     checkDisposed(OResultSet_BASE::rBHelper.bDisposed);
@@ -303,24 +301,23 @@ void SAL_CALL OResultSet::checkRowIndex()
     {
         ::dbtools::throwSQLException(
             "Invalid Row",
-            ::dbtools::SQL_INVALID_CURSOR_POSITION,
+            ::dbtools::StandardSQLState::INVALID_CURSOR_POSITION,
             *this);
     }
 }
 
-Any SAL_CALL OResultSet::queryInterface( const Type & rType ) throw(RuntimeException, std::exception)
+Any SAL_CALL OResultSet::queryInterface( const Type & rType )
 {
     Any aRet = OPropertySetHelper::queryInterface(rType);
     return aRet.hasValue() ? aRet : OResultSet_BASE::queryInterface(rType);
 }
 
- Sequence<  Type > SAL_CALL OResultSet::getTypes() throw( RuntimeException, std::exception)
+ Sequence<  Type > SAL_CALL OResultSet::getTypes()
 {
     return concatSequences(OPropertySetHelper::getTypes(), OResultSet_BASE::getTypes());
 }
 // ---- XColumnLocate ---------------------------------------------------------
 sal_Int32 SAL_CALL OResultSet::findColumn(const OUString& rColumnName)
-    throw(SQLException, RuntimeException, std::exception)
 {
     MutexGuard aGuard(m_rMutex);
     checkDisposed(OResultSet_BASE::rBHelper.bDisposed);
@@ -342,18 +339,16 @@ sal_Int32 SAL_CALL OResultSet::findColumn(const OUString& rColumnName)
     return 0; // Never reached
 }
 
-uno::Reference< XInputStream > SAL_CALL OResultSet::getBinaryStream( sal_Int32 columnIndex ) throw(SQLException, RuntimeException, std::exception)
+uno::Reference< XInputStream > SAL_CALL OResultSet::getBinaryStream( sal_Int32 )
 {
-    (void) columnIndex;
     MutexGuard aGuard(m_rMutex);
     checkDisposed(OResultSet_BASE::rBHelper.bDisposed);
 
     return nullptr;
 }
 
-uno::Reference< XInputStream > SAL_CALL OResultSet::getCharacterStream( sal_Int32 columnIndex ) throw(SQLException, RuntimeException, std::exception)
+uno::Reference< XInputStream > SAL_CALL OResultSet::getCharacterStream( sal_Int32 )
 {
-    (void) columnIndex;
     MutexGuard aGuard(m_rMutex);
     checkDisposed(OResultSet_BASE::rBHelper.bDisposed);
 
@@ -374,10 +369,63 @@ bool OResultSet::isNull(const sal_Int32 nColumnIndex)
     return false;
 }
 
+template <typename T>
+OUString OResultSet::makeNumericString(const sal_Int32 nColumnIndex)
+{
+    //  minus because firebird stores scale as a negative number
+    int nDecimalCount = -(m_pSqlda->sqlvar[nColumnIndex-1].sqlscale);
+    if(nDecimalCount < 0)
+    {
+        // scale should be always positive
+        assert(false);
+        return OUString();
+    }
+
+    OUStringBuffer sRetBuffer;
+    T nAllDigits = *reinterpret_cast<T*>(m_pSqlda->sqlvar[nColumnIndex-1].sqldata);
+    sal_Int64 nDecimalCountExp = pow10Integer(nDecimalCount);
+
+    if(nAllDigits < 0)
+    {
+        sRetBuffer.append('-');
+        nAllDigits = -nAllDigits; // abs
+    }
+
+    sRetBuffer.append(static_cast<sal_Int64>(nAllDigits / nDecimalCountExp) );
+    if( nDecimalCount > 0)
+    {
+        sRetBuffer.append('.');
+
+        sal_Int64 nFractionalPart = nAllDigits % nDecimalCountExp;
+
+        int iCount = 0; // digit count
+        sal_Int64 nFracTemp = nFractionalPart;
+        while(nFracTemp>0)
+        {
+            nFracTemp /= 10;
+            iCount++;
+        }
+
+        int nMissingNulls = nDecimalCount - iCount;
+
+        // append nulls after dot and before nFractionalPart
+        for(int i=0; i<nMissingNulls; i++)
+        {
+            sRetBuffer.append('0');
+        }
+
+        // the rest
+        sRetBuffer.append(nFractionalPart);
+    }
+
+    return sRetBuffer.makeStringAndClear();
+}
+
 template <typename T>
 T OResultSet::retrieveValue(const sal_Int32 nColumnIndex, const ISC_SHORT nType)
 {
-    if ((m_bWasNull = isNull(nColumnIndex)))
+    m_bWasNull = isNull(nColumnIndex);
+    if (m_bWasNull)
         return T();
 
     if ((m_pSqlda->sqlvar[nColumnIndex-1].sqltype & ~1) == nType)
@@ -396,18 +444,32 @@ ORowSetValue OResultSet::retrieveValue(const sal_Int32 nColumnIndex, const ISC_S
     //
     // Basically we just have to map to the correct direct request and
     // ORowSetValue does the rest for us here.
+    int nSqlSubType = m_pSqlda->sqlvar[nColumnIndex-1].sqlsubtype;
+
+    // TODO Firebird 3.0 does not set subtype (i.e. set to 0) for computed numeric/decimal value.
+    // It may change in the future.
+    // Imply numeric data type when subtype is 0 and scale is negative
+    if( nSqlSubType == 0 && m_pSqlda->sqlvar[nColumnIndex-1].sqlscale < 0 )
+        nSqlSubType = 1;
+
     switch (m_pSqlda->sqlvar[nColumnIndex-1].sqltype & ~1)
     {
         case SQL_TEXT:
         case SQL_VARYING:
             return getString(nColumnIndex);
         case SQL_SHORT:
+            if(nSqlSubType == 1 || nSqlSubType == 2) //numeric or decimal
+                return getString(nColumnIndex);
             return getShort(nColumnIndex);
         case SQL_LONG:
+            if(nSqlSubType == 1 || nSqlSubType == 2) //numeric or decimal
+                return getString(nColumnIndex);
             return getInt(nColumnIndex);
         case SQL_FLOAT:
             return getFloat(nColumnIndex);
         case SQL_DOUBLE:
+            if(nSqlSubType == 1 || nSqlSubType == 2) //numeric or decimal
+                return getString(nColumnIndex);
             return getDouble(nColumnIndex);
         case SQL_D_FLOAT:
             return getFloat(nColumnIndex);
@@ -418,7 +480,11 @@ ORowSetValue OResultSet::retrieveValue(const sal_Int32 nColumnIndex, const ISC_S
         case SQL_TYPE_DATE:
             return getDate(nColumnIndex);
         case SQL_INT64:
+            if(nSqlSubType == 1 || nSqlSubType == 2) //numeric or decimal
+                return getString(nColumnIndex);
             return getLong(nColumnIndex);
+        case SQL_BOOLEAN:
+            return ORowSetValue(bool(getBoolean(nColumnIndex)));
         case SQL_BLOB:
         case SQL_NULL:
         case SQL_QUAD:
@@ -437,12 +503,12 @@ Date OResultSet::retrieveValue(const sal_Int32 nColumnIndex, const ISC_SHORT /*n
 {
     if ((m_pSqlda->sqlvar[nColumnIndex-1].sqltype & ~1) == SQL_TYPE_DATE)
     {
-        ISC_DATE aISCDate = *(reinterpret_cast<ISC_DATE*>(m_pSqlda->sqlvar[nColumnIndex-1].sqldata));
+        ISC_DATE aISCDate = *reinterpret_cast<ISC_DATE*>(m_pSqlda->sqlvar[nColumnIndex-1].sqldata);
 
         struct tm aCTime;
         isc_decode_sql_date(&aISCDate, &aCTime);
 
-        return Date(aCTime.tm_mday, aCTime.tm_mon, aCTime.tm_year);
+        return Date(aCTime.tm_mday, aCTime.tm_mon + 1, aCTime.tm_year + 1900);
     }
     else
     {
@@ -455,7 +521,7 @@ Time OResultSet::retrieveValue(const sal_Int32 nColumnIndex, const ISC_SHORT /*n
 {
     if ((m_pSqlda->sqlvar[nColumnIndex-1].sqltype & ~1) == SQL_TYPE_TIME)
     {
-        ISC_TIME aISCTime = *(reinterpret_cast<ISC_TIME*>(m_pSqlda->sqlvar[nColumnIndex-1].sqldata));
+        ISC_TIME aISCTime = *reinterpret_cast<ISC_TIME*>(m_pSqlda->sqlvar[nColumnIndex-1].sqldata);
 
         struct tm aCTime;
         isc_decode_sql_time(&aISCTime, &aCTime);
@@ -475,15 +541,19 @@ DateTime OResultSet::retrieveValue(const sal_Int32 nColumnIndex, const ISC_SHORT
 {
     if ((m_pSqlda->sqlvar[nColumnIndex-1].sqltype & ~1) == SQL_TIMESTAMP)
     {
-        ISC_TIMESTAMP aISCTimestamp = *(reinterpret_cast<ISC_TIMESTAMP*>(m_pSqlda->sqlvar[nColumnIndex-1].sqldata));
+        ISC_TIMESTAMP aISCTimestamp = *reinterpret_cast<ISC_TIMESTAMP*>(m_pSqlda->sqlvar[nColumnIndex-1].sqldata);
 
         struct tm aCTime;
         isc_decode_timestamp(&aISCTimestamp, &aCTime);
 
-        // first field is nanoseconds -- not supported in firebird or struct tm.
-        // last field denotes UTC (true) or unknown (false)
-        return DateTime(0, aCTime.tm_sec, aCTime.tm_min, aCTime.tm_hour, aCTime.tm_mday,
-                    aCTime.tm_mon, aCTime.tm_year, false);
+        return DateTime(0, //nanoseconds, not supported
+                        aCTime.tm_sec,
+                        aCTime.tm_min,
+                        aCTime.tm_hour,
+                        aCTime.tm_mday,
+                        aCTime.tm_mon + 1, // tm is from 0 to 11
+                        aCTime.tm_year + 1900, //tm_year is the years since 1900
+                        false); // denotes UTC (true), or unknown (false)
     }
     else
     {
@@ -496,6 +566,7 @@ OUString OResultSet::retrieveValue(const sal_Int32 nColumnIndex, const ISC_SHORT
 {
     // &~1 to remove the "can contain NULL" indicator
     int aSqlType = m_pSqlda->sqlvar[nColumnIndex-1].sqltype & ~1;
+    int aSqlSubType = m_pSqlda->sqlvar[nColumnIndex-1].sqlsubtype;
     if (aSqlType == SQL_TEXT )
     {
         return OUString(m_pSqlda->sqlvar[nColumnIndex-1].sqldata,
@@ -506,11 +577,33 @@ OUString OResultSet::retrieveValue(const sal_Int32 nColumnIndex, const ISC_SHORT
     {
         // First 2 bytes are a short containing the length of the string
         // No idea if sqllen is still valid here?
-        sal_uInt16 aLength = *(reinterpret_cast<sal_uInt16*>(m_pSqlda->sqlvar[nColumnIndex-1].sqldata));
+        sal_uInt16 aLength = *reinterpret_cast<sal_uInt16*>(m_pSqlda->sqlvar[nColumnIndex-1].sqldata);
         return OUString(m_pSqlda->sqlvar[nColumnIndex-1].sqldata + 2,
                         aLength,
                         RTL_TEXTENCODING_UTF8);
     }
+    else if ((aSqlType == SQL_SHORT || aSqlType == SQL_LONG ||
+              aSqlType == SQL_DOUBLE || aSqlType == SQL_INT64)
+          && (aSqlSubType == 1 ||
+              aSqlSubType == 2 ||
+              (aSqlSubType == 0 && m_pSqlda->sqlvar[nColumnIndex-1].sqlscale < 0) ) )
+    {
+        // decimal and numeric types
+        switch(aSqlType)
+        {
+            case SQL_SHORT:
+                return makeNumericString<sal_Int16>(nColumnIndex);
+            case SQL_LONG:
+                return makeNumericString<sal_Int32>(nColumnIndex);
+            case SQL_DOUBLE:
+                // TODO FIXME 64 bits?
+            case SQL_INT64:
+                return makeNumericString<sal_Int64>(nColumnIndex);
+            default:
+                assert(false);
+                return OUString(); // never reached
+        }
+    }
     else
     {
         return retrieveValue< ORowSetValue >(nColumnIndex, 0);
@@ -521,10 +614,10 @@ template <>
 ISC_QUAD* OResultSet::retrieveValue(const sal_Int32 nColumnIndex, const ISC_SHORT nType)
 {
     // TODO: this is probably wrong
-    if ((m_pSqlda->sqlvar[nColumnIndex-1].sqltype & ~1) == nType)
-        return reinterpret_cast<ISC_QUAD*>(m_pSqlda->sqlvar[nColumnIndex-1].sqldata);
-    else
+    if ((m_pSqlda->sqlvar[nColumnIndex-1].sqltype & ~1) != nType)
         throw SQLException(); // TODO: better exception (can't convert Blob)
+
+    return reinterpret_cast<ISC_QUAD*>(m_pSqlda->sqlvar[nColumnIndex-1].sqldata);
 }
 
 template <typename T>
@@ -536,14 +629,15 @@ T OResultSet::safelyRetrieveValue(const sal_Int32 nColumnIndex, const ISC_SHORT
     checkColumnIndex(nColumnIndex);
     checkRowIndex();
 
-    if ((m_bWasNull = isNull(nColumnIndex)))
+    m_bWasNull = isNull(nColumnIndex);
+    if (m_bWasNull)
         return T();
 
     return retrieveValue< T >(nColumnIndex, nType);
 }
 
 // ---- XRow -----------------------------------------------------------------
-sal_Bool SAL_CALL OResultSet::wasNull() throw(SQLException, RuntimeException, std::exception)
+sal_Bool SAL_CALL OResultSet::wasNull()
 {
     MutexGuard aGuard(m_rMutex);
     checkDisposed(OResultSet_BASE::rBHelper.bDisposed);
@@ -553,96 +647,82 @@ sal_Bool SAL_CALL OResultSet::wasNull() throw(SQLException, RuntimeException, st
 
 // ---- XRow: Simple Numerical types ------------------------------------------
 sal_Bool SAL_CALL OResultSet::getBoolean(sal_Int32 nColumnIndex)
-    throw(SQLException, RuntimeException, std::exception)
 {
-    // Not a native firebird type hence we always have to convert.
-    return safelyRetrieveValue< ORowSetValue >(nColumnIndex);
+    return safelyRetrieveValue< bool >(nColumnIndex, SQL_BOOLEAN);
 }
 
 sal_Int8 SAL_CALL OResultSet::getByte(sal_Int32 nColumnIndex)
-    throw(SQLException, RuntimeException, std::exception)
 {
     // Not a native firebird type hence we always have to convert.
     return safelyRetrieveValue< ORowSetValue >(nColumnIndex);
 }
 
-Sequence< sal_Int8 > SAL_CALL OResultSet::getBytes(sal_Int32 columnIndex)
-    throw(SQLException, RuntimeException, std::exception)
+Sequence< sal_Int8 > SAL_CALL OResultSet::getBytes(sal_Int32)
 {
-    (void) columnIndex;
     return Sequence< sal_Int8 >(); // TODO: implement
     //return safelyRetrieveValue(columnIndex);
 }
 
 sal_Int16 SAL_CALL OResultSet::getShort(sal_Int32 columnIndex)
-    throw(SQLException, RuntimeException, std::exception)
 {
     return safelyRetrieveValue< sal_Int16 >(columnIndex, SQL_SHORT);
 }
 
 sal_Int32 SAL_CALL OResultSet::getInt(sal_Int32 columnIndex)
-    throw(SQLException, RuntimeException, std::exception)
 {
     return safelyRetrieveValue< sal_Int32 >(columnIndex, SQL_LONG);
 }
 
 sal_Int64 SAL_CALL OResultSet::getLong(sal_Int32 columnIndex)
-    throw(SQLException, RuntimeException, std::exception)
 {
     return safelyRetrieveValue< sal_Int64 >(columnIndex, SQL_INT64);
 }
 
 float SAL_CALL OResultSet::getFloat(sal_Int32 columnIndex)
-    throw(SQLException, RuntimeException, std::exception)
 {
     return safelyRetrieveValue< float >(columnIndex, SQL_FLOAT);
 }
 
 double SAL_CALL OResultSet::getDouble(sal_Int32 columnIndex)
-    throw(SQLException, RuntimeException, std::exception)
 {
     return safelyRetrieveValue< double >(columnIndex, SQL_DOUBLE);
 }
 
 // ---- XRow: More complex types ----------------------------------------------
 OUString SAL_CALL OResultSet::getString(sal_Int32 nIndex)
-    throw(SQLException, RuntimeException, std::exception)
 {
     return safelyRetrieveValue< OUString >(nIndex);
 }
 
 Date SAL_CALL OResultSet::getDate(sal_Int32 nIndex)
-    throw(SQLException, RuntimeException, std::exception)
 {
     return safelyRetrieveValue< Date >(nIndex, SQL_TYPE_DATE);
 }
 
 Time SAL_CALL OResultSet::getTime(sal_Int32 nIndex)
-    throw(SQLException, RuntimeException, std::exception)
 {
     return safelyRetrieveValue< css::util::Time >(nIndex, SQL_TYPE_TIME);
 }
 
 DateTime SAL_CALL OResultSet::getTimestamp(sal_Int32 nIndex)
-    throw(SQLException, RuntimeException, std::exception)
 {
     return safelyRetrieveValue< DateTime >(nIndex, SQL_TIMESTAMP);
 }
 
 
-uno::Reference< XResultSetMetaData > SAL_CALL OResultSet::getMetaData(  ) throw(SQLException, RuntimeException, std::exception)
+uno::Reference< XResultSetMetaData > SAL_CALL OResultSet::getMetaData(  )
 {
     MutexGuard aGuard(m_rMutex);
     checkDisposed(OResultSet_BASE::rBHelper.bDisposed);
 
     if(!m_xMetaData.is())
-        m_xMetaData = new OResultSetMetaData(m_pConnection, m_pSqlda);
+        m_xMetaData = new OResultSetMetaData(m_pConnection
+                                           , m_pSqlda);
     return m_xMetaData;
 }
 
-uno::Reference< XArray > SAL_CALL OResultSet::getArray( sal_Int32 columnIndex ) throw(SQLException, RuntimeException, std::exception)
+uno::Reference< XArray > SAL_CALL OResultSet::getArray( sal_Int32 )
 {
-    (void) columnIndex;
     MutexGuard aGuard(m_rMutex);
     checkDisposed(OResultSet_BASE::rBHelper.bDisposed);
 
@@ -650,18 +730,23 @@ uno::Reference< XArray > SAL_CALL OResultSet::getArray( sal_Int32 columnIndex )
 }
 
 
-
-uno::Reference< XClob > SAL_CALL OResultSet::getClob( sal_Int32 columnIndex ) throw(SQLException, RuntimeException, std::exception)
+uno::Reference< XClob > SAL_CALL OResultSet::getClob( sal_Int32 columnIndex )
 {
-    (void) columnIndex;
     MutexGuard aGuard(m_rMutex);
     checkDisposed(OResultSet_BASE::rBHelper.bDisposed);
 
-    return nullptr;
+    int aSqlSubType = m_pSqlda->sqlvar[columnIndex-1].sqlsubtype;
+
+    SAL_WARN_IF(aSqlSubType != 1,
+        "connectivity.firebird", "wrong subtype, not a textual blob");
+
+    ISC_QUAD* pBlobID = safelyRetrieveValue< ISC_QUAD* >(columnIndex, SQL_BLOB);
+    if (!pBlobID)
+        return nullptr;
+    return m_pConnection->createClob(pBlobID);
 }
 
 uno::Reference< XBlob > SAL_CALL OResultSet::getBlob(sal_Int32 columnIndex)
-    throw(SQLException, RuntimeException, std::exception)
 {
     MutexGuard aGuard(m_rMutex);
     checkDisposed(OResultSet_BASE::rBHelper.bDisposed);
@@ -675,9 +760,8 @@ uno::Reference< XBlob > SAL_CALL OResultSet::getBlob(sal_Int32 columnIndex)
 }
 
 
-uno::Reference< XRef > SAL_CALL OResultSet::getRef( sal_Int32 columnIndex ) throw(SQLException, RuntimeException, std::exception)
+uno::Reference< XRef > SAL_CALL OResultSet::getRef( sal_Int32 )
 {
-    (void) columnIndex;
     MutexGuard aGuard(m_rMutex);
     checkDisposed(OResultSet_BASE::rBHelper.bDisposed);
 
@@ -685,10 +769,8 @@ uno::Reference< XRef > SAL_CALL OResultSet::getRef( sal_Int32 columnIndex ) thro
 }
 
 
-Any SAL_CALL OResultSet::getObject( sal_Int32 columnIndex, const uno::Reference< ::com::sun::star::container::XNameAccess >& typeMap ) throw(SQLException, RuntimeException, std::exception)
+Any SAL_CALL OResultSet::getObject( sal_Int32, const uno::Reference< css::container::XNameAccess >& )
 {
-    (void) columnIndex;
-    (void) typeMap;
     MutexGuard aGuard(m_rMutex);
     checkDisposed(OResultSet_BASE::rBHelper.bDisposed);
 
@@ -696,10 +778,7 @@ Any SAL_CALL OResultSet::getObject( sal_Int32 columnIndex, const uno::Reference<
 }
 
 
-
-
-
-void SAL_CALL OResultSet::close() throw(SQLException, RuntimeException, std::exception)
+void SAL_CALL OResultSet::close()
 {
     SAL_INFO("connectivity.firebird", "close().");
 
@@ -712,7 +791,6 @@ void SAL_CALL OResultSet::close() throw(SQLException, RuntimeException, std::exc
 
 
 uno::Reference< XInterface > SAL_CALL OResultSet::getStatement()
-    throw(SQLException, RuntimeException, std::exception)
 {
     MutexGuard aGuard(m_rMutex);
     checkDisposed(OResultSet_BASE::rBHelper.bDisposed);
@@ -720,34 +798,34 @@ uno::Reference< XInterface > SAL_CALL OResultSet::getStatement()
     return m_xStatement;
 }
 //----- XResultSet: unsupported change detection methods ---------------------
-sal_Bool SAL_CALL OResultSet::rowDeleted() throw(SQLException, RuntimeException, std::exception)
+sal_Bool SAL_CALL OResultSet::rowDeleted()
 {
     ::dbtools::throwFunctionNotSupportedSQLException("rowDeleted not supported in firebird",
                                                   *this);
-    return sal_False;
+    return false;
 }
-sal_Bool SAL_CALL OResultSet::rowInserted() throw(SQLException, RuntimeException, std::exception)
+sal_Bool SAL_CALL OResultSet::rowInserted()
 {
     ::dbtools::throwFunctionNotSupportedSQLException("rowInserted not supported in firebird",
                                                   *this);
-    return sal_False;
+    return false;
 }
 
-sal_Bool SAL_CALL OResultSet::rowUpdated() throw(SQLException, RuntimeException, std::exception)
+sal_Bool SAL_CALL OResultSet::rowUpdated()
 {
     ::dbtools::throwFunctionNotSupportedSQLException("rowUpdated not supported in firebird",
                                                   *this);
-    return sal_False;
+    return false;
 }
 
-void SAL_CALL OResultSet::refreshRow() throw(SQLException, RuntimeException, std::exception)
+void SAL_CALL OResultSet::refreshRow()
 {
     ::dbtools::throwFunctionNotSupportedSQLException("refreshRow not supported in firebird",
                                                   *this);
 }
 
 
-void SAL_CALL OResultSet::cancel(  ) throw(RuntimeException, std::exception)
+void SAL_CALL OResultSet::cancel(  )
 {
     MutexGuard aGuard(m_rMutex);
     checkDisposed(OResultSet_BASE::rBHelper.bDisposed);
@@ -793,28 +871,23 @@ void SAL_CALL OResultSet::release() throw()
     OResultSet_BASE::release();
 }
 
-uno::Reference< ::com::sun::star::beans::XPropertySetInfo > SAL_CALL OResultSet::getPropertySetInfo(  ) throw(::com::sun::star::uno::RuntimeException, std::exception)
+uno::Reference< css::beans::XPropertySetInfo > SAL_CALL OResultSet::getPropertySetInfo(  )
 {
     return ::cppu::OPropertySetHelper::createPropertySetInfo(getInfoHelper());
 }
 
 // ---- XServiceInfo -----------------------------------------------------------
-OUString SAL_CALL OResultSet::getImplementationName() throw ( RuntimeException, std::exception)
+OUString SAL_CALL OResultSet::getImplementationName()
 {
     return OUString("com.sun.star.sdbcx.firebird.ResultSet");
 }
 
 Sequence< OUString > SAL_CALL OResultSet::getSupportedServiceNames()
-    throw( RuntimeException, std::exception)
 {
-     Sequence< OUString > aSupported(2);
-    aSupported[0] = "com.sun.star.sdbc.ResultSet";
-    aSupported[1] = "com.sun.star.sdbcx.ResultSet";
-    return aSupported;
+    return {"com.sun.star.sdbc.ResultSet","com.sun.star.sdbcx.ResultSet"};
 }
 
 sal_Bool SAL_CALL OResultSet::supportsService(const OUString& _rServiceName)
-    throw( RuntimeException, std::exception)
 {
     return cppu::supportsService(this, _rServiceName);
 }
