@@ -17,10 +17,10 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "mysql/YCatalog.hxx"
-#include "mysql/YUsers.hxx"
-#include "mysql/YTables.hxx"
-#include "mysql/YViews.hxx"
+#include <mysql/YCatalog.hxx>
+#include <mysql/YUsers.hxx>
+#include <mysql/YTables.hxx>
+#include <mysql/YViews.hxx>
 #include <com/sun/star/sdbc/XRow.hpp>
 #include <com/sun/star/sdbc/XResultSet.hpp>
 #include <comphelper/types.hxx>
@@ -74,11 +74,9 @@ void OMySQLCatalog::refreshViews()
     // let's simply assume the server is new enough to support views. Current drivers
     // as of this writing might not return the proper information in getTableTypes, so
     // don't rely on it.
-    bool bSupportsViews = true;
 
     TStringVector aVector;
-    if ( bSupportsViews )
-        refreshObjects(aTypes,aVector);
+    refreshObjects(aTypes,aVector);
 
     if ( m_pViews )
         m_pViews->reFill(aVector);
@@ -98,7 +96,6 @@ void OMySQLCatalog::refreshUsers()
     if ( xResult.is() )
     {
         Reference< XRow > xRow(xResult,UNO_QUERY);
-        TString2IntMap aMap;
         while( xResult->next() )
             aVector.push_back(xRow->getString(1));
         ::comphelper::disposeComponent(xResult);
