@@ -18,7 +18,7 @@
  */
 
 #include "ORealDriver.hxx"
-#include "odbc/ODriver.hxx"
+#include <odbc/ODriver.hxx>
 #include <cppuhelper/factory.hxx>
 
 using namespace connectivity::odbc;
@@ -36,7 +36,7 @@ typedef Reference< XSingleServiceFactory > (SAL_CALL *createFactoryFunc)
             rtl_ModuleCount*
         );
 
-//---------------------------------------------------------------------------------------
+
 struct ProviderRequest
 {
     Reference< XSingleServiceFactory > xRet;
@@ -47,13 +47,12 @@ struct ProviderRequest
         void* pServiceManager,
         sal_Char const* pImplementationName
     )
-    : xServiceManager(reinterpret_cast<XMultiServiceFactory*>(pServiceManager))
+    : xServiceManager(static_cast<XMultiServiceFactory*>(pServiceManager))
     , sImplementationName(OUString::createFromAscii(pImplementationName))
     {
     }
 
-    inline
-    sal_Bool CREATE_PROVIDER(
+    bool CREATE_PROVIDER(
                 const OUString& Implname,
                 const Sequence< OUString > & Services,
                 ::cppu::ComponentInstantiation Factory,
@@ -64,7 +63,7 @@ struct ProviderRequest
         {
             try
             {
-                xRet = creator( xServiceManager, sImplementationName,Factory, Services,0);
+                xRet = creator( xServiceManager, sImplementationName,Factory, Services,nullptr);
             }
             catch(...)
             {
@@ -76,13 +75,13 @@ struct ProviderRequest
     void* getProvider() const { return xRet.get(); }
 };
 
-//---------------------------------------------------------------------------------------
+
 extern "C" SAL_DLLPUBLIC_EXPORT void* SAL_CALL odbc_component_getFactory(
                     const sal_Char* pImplementationName,
                     void* pServiceManager,
                     void* /*pRegistryKey*/)
 {
-    void* pRet = 0;
+    void* pRet = nullptr;
     if (pServiceManager)
     {
         ProviderRequest aReq(pServiceManager,pImplementationName);
