@@ -20,7 +20,7 @@
 #include <connectivity/sqliterator.hxx>
 #include <connectivity/sdbcx/VTable.hxx>
 #include <connectivity/sqlparse.hxx>
-#include "sqlbison.hxx"
+#include <sqlbison.hxx>
 #include <connectivity/dbtools.hxx>
 #include <connectivity/sqlerror.hxx>
 #include <com/sun/star/sdbc/ColumnValue.hpp>
@@ -33,7 +33,7 @@
 #endif
 #include <connectivity/PColumn.hxx>
 #include <tools/diagnose_ex.h>
-#include "TConnection.hxx"
+#include <TConnection.hxx>
 #include <comphelper/types.hxx>
 #include <connectivity/dbmetadata.hxx>
 #include <com/sun/star/sdb/SQLFilterOperator.hpp>
@@ -58,7 +58,7 @@ namespace connectivity
 {
     struct OSQLParseTreeIteratorImpl
     {
-        ::std::vector< TNodePair >      m_aJoinConditions;
+        std::vector< TNodePair >      m_aJoinConditions;
         Reference< XConnection >        m_xConnection;
         Reference< XDatabaseMetaData >  m_xDatabaseMetaData;
         Reference< XNameAccess >        m_xTableContainer;
@@ -98,7 +98,7 @@ namespace connectivity
         }
 
     public:
-        inline  bool    isQueryAllowed( const OUString& _rQueryName )
+        bool    isQueryAllowed( const OUString& _rQueryName )
         {
             if ( !m_pForbiddenQueryNames.get() )
                 return true;
@@ -135,12 +135,11 @@ namespace connectivity
 
 OSQLParseTreeIterator::OSQLParseTreeIterator(const Reference< XConnection >& _rxConnection,
                                              const Reference< XNameAccess >& _rxTables,
-                                             const OSQLParser& _rParser,
-                                             const OSQLParseNode* pRoot )
+                                             const OSQLParser& _rParser )
     :m_rParser( _rParser )
     ,m_pImpl( new OSQLParseTreeIteratorImpl( _rxConnection, _rxTables ) )
 {
-    setParseTree(pRoot);
+    setParseTree(nullptr);
 }
 
 
@@ -261,14 +260,12 @@ namespace
     {
         OUString sComposedName;
 
-        static const char s_sTableTypeView[] = "VIEW";
-        static const char s_sTableTypeTable[] = "TABLE";
         static const char s_sWildcard[] = "%" ;
 
         // we want all catalogues, all schemas, all tables
         Sequence< OUString > sTableTypes(3);
-        sTableTypes[0] = s_sTableTypeView;
-        sTableTypes[1] = s_sTableTypeTable;
+        sTableTypes[0] = "VIEW";
+        sTableTypes[1] = "TABLE";
         sTableTypes[2] = s_sWildcard;   // just to be sure to include anything else ....
 
         if ( _rxDBMeta.is() )
@@ -336,17 +333,16 @@ void OSQLParseTreeIterator::impl_getQueryParameterColumns( const OSQLTable& _rQu
         break;
 
     OSQLParseTreeIterator aSubQueryIterator( *this, m_rParser, pSubQueryNode.get() );
-    aSubQueryIterator.traverseSome( TraversalParts::Parameters | TraversalParts::SelectColumns );
-        // SelectColumns might also contain parameters
-        // #i77635# - 2007-07-23 / frank.schoenheit@sun.com
+    aSubQueryIterator.impl_traverse( TraversalParts::Parameters | TraversalParts::SelectColumns );
+        // SelectColumns might also contain parameters #i77635#
     pSubQueryParameterColumns = aSubQueryIterator.getParameters();
     aSubQueryIterator.dispose();
 
     } while ( false );
 
     // copy the parameters of the sub query to our own parameter array
-    ::std::copy( pSubQueryParameterColumns->get().begin(), pSubQueryParameterColumns->get().end(),
-        ::std::insert_iterator< OSQLColumns::Vector >( m_aParameters->get(), m_aParameters->get().end() ) );
+    std::copy( pSubQueryParameterColumns->get().begin(), pSubQueryParameterColumns->get().end(),
+        std::insert_iterator< OSQLColumns::Vector >( m_aParameters->get(), m_aParameters->get().end() ) );
 }
 
 
@@ -450,7 +446,7 @@ void OSQLParseTreeIterator::traverseOneTableName( OSQLTables& _rTables,const OSQ
                                 false,
                                 ::dbtools::EComposeRule::InDataManipulation);
 
-    // if there is no alias for the table name assign the orignal name to it
+    // if there is no alias for the table name assign the original name to it
     if ( aTableRange.isEmpty() )
         aTableRange = aComposedName;
 
@@ -491,7 +487,7 @@ void OSQLParseTreeIterator::impl_fillJoinConditions(const OSQLParseNode* i_pJoin
     }
 }
 
-::std::vector< TNodePair >& OSQLParseTreeIterator::getJoinConditions() const
+std::vector< TNodePair >& OSQLParseTreeIterator::getJoinConditions() const
 {
     return m_pImpl->m_aJoinConditions;
 }
@@ -577,13 +573,13 @@ const OSQLParseNode* OSQLParseTreeIterator::getTableNode( OSQLTables& _rTables,
                 if ( SQL_ISRULE( pQueryExpression, select_statement ) )
                 {
                     getSelect_statement( *m_pImpl->m_pSubTables, pQueryExpression );
-                    // LEM TODO: now, we need to setup a OSQLTable from pQueryExpression in some way
-                    //           and stick it in _rTables[rTableRange]. Probably fake it by
-                    //           setting up a full OSQLParseTreeIterator on pQueryExpression
-                    //           and using its m_aSelectColumns
-                    //           This is necessary in stuff like "SELECT * FROM tbl1 INNER JOIN (SELECT foo, bar FROM tbl2) AS tbl3"
-                    //           so that setSelectColumnName() can expand the "*" correctly.
-                    //           See e.g. R_UserAndLastSubscription query of https://bugs.libreoffice.org/attachment.cgi?id=71871
+                    // TODO: now, we need to setup a OSQLTable from pQueryExpression in some way
+                    //       and stick it in _rTables[rTableRange]. Probably fake it by
+                    //       setting up a full OSQLParseTreeIterator on pQueryExpression
+                    //       and using its m_aSelectColumns
+                    //       This is necessary in stuff like "SELECT * FROM tbl1 INNER JOIN (SELECT foo, bar FROM tbl2) AS tbl3"
+                    //       so that setSelectColumnName() can expand the "*" correctly.
+                    //       See e.g. R_UserAndLastSubscription query of https://bugs.libreoffice.org/attachment.cgi?id=71871
                 }
                 else
                 {
@@ -685,8 +681,7 @@ bool OSQLParseTreeIterator::traverseTableNames(OSQLTables& _rTables)
 
     if ( pTableName )
     {
-        OUString sTableRange;
-        traverseOneTableName( _rTables, pTableName, sTableRange );
+        traverseOneTableName( _rTables, pTableName, OUString() );
     }
 
     return !hasErrors();
@@ -884,13 +879,6 @@ void OSQLParseTreeIterator::traverseCreateColumns(const OSQLParseNode* pSelectNo
                 aTypeName = pType->getTokenValue();
                 if (pDatatype->count() == 2 && (pType->getTokenID() == SQL_TOKEN_CHAR || pType->getTokenID() == SQL_TOKEN_CHARACTER ))
                     nType = DataType::CHAR;
-
-                const OSQLParseNode *pParams = pDatatype->getChild(pDatatype->count()-1);
-                if ( pParams->count() )
-                {
-                    sal_Int32 nLen = pParams->getChild(1)->getTokenValue().toInt32();
-                    (void)nLen;
-                }
             }
             else if(pDatatype && pDatatype->getNodeType() == SQLNodeType::Keyword)
             {
@@ -931,16 +919,15 @@ bool OSQLParseTreeIterator::traverseSelectColumnNames(const OSQLParseNode* pSele
             /*&&  traverseSelectColumnNames( pSelectNode->getChild( 3 ) )*/;
     }
 
-    static OUString aEmptyString;
     // nyi: more checks for correct structure!
     if (pSelectNode->getChild(2)->isRule() && SQL_ISPUNCTUATION(pSelectNode->getChild(2)->getChild(0),"*"))
     {
         // SELECT * ...
-        setSelectColumnName(m_aSelectColumns,"*", aEmptyString,aEmptyString);
+        setSelectColumnName(m_aSelectColumns, "*", "", "");
     }
     else if (SQL_ISRULE(pSelectNode->getChild(2),scalar_exp_commalist))
     {
-        // SELECT column[,column] oder SELECT COUNT(*) ...
+        // SELECT column[,column] or SELECT COUNT(*) ...
         OSQLParseNode * pSelection = pSelectNode->getChild(2);
 
         for (size_t i = 0; i < pSelection->count(); i++)
@@ -956,7 +943,7 @@ bool OSQLParseTreeIterator::traverseSelectColumnNames(const OSQLParseNode* pSele
                 // All the table's columns
                 OUString aTableRange;
                 pColumnRef->getChild(0)->parseNodeToStr( aTableRange, m_pImpl->m_xConnection, nullptr, false, false );
-                setSelectColumnName(m_aSelectColumns,"*", aEmptyString,aTableRange);
+                setSelectColumnName(m_aSelectColumns, "*", "", aTableRange);
                 continue;
             }
             else if (SQL_ISRULE(pColumnRef,derived_column))
@@ -992,9 +979,9 @@ bool OSQLParseTreeIterator::traverseSelectColumnNames(const OSQLParseNode* pSele
 
                     if ( pColumnRef->isRule() )
                     {
-                        // LEM FIXME: the if condition is not quite right
-                        //            many expressions are rules, e.g. "5+3"
-                        //            or even: "colName + 1"
+                        // FIXME: the if condition is not quite right
+                        //        many expressions are rules, e.g. "5+3"
+                        //        or even: "colName + 1"
                         bFkt = true;
                         nType = getFunctionReturnType(pColumnRef);
                     }
@@ -1248,7 +1235,7 @@ bool OSQLParseTreeIterator::traverseSelectionCriteria(const OSQLParseNode* pSele
 }
 
 
-void OSQLParseTreeIterator::traverseSearchCondition(OSQLParseNode * pSearchCondition)
+void OSQLParseTreeIterator::traverseSearchCondition(OSQLParseNode const * pSearchCondition)
 {
     if (
             SQL_ISRULE(pSearchCondition,boolean_primary) &&
@@ -1358,7 +1345,6 @@ void OSQLParseTreeIterator::traverseSearchCondition(OSQLParseNode * pSearchCondi
     {
         OSL_ENSURE(pSearchCondition->count() == 2,"OSQLParseTreeIterator: error in parse tree!");
         const OSQLParseNode* pPart2 = pSearchCondition->getChild(1);
-        (void)pPart2;
         OSL_ENSURE(SQL_ISTOKEN(pPart2->getChild(0),IS),"OSQLParseTreeIterator: error in parse tree!");
 
         OUString aString;
@@ -1515,9 +1501,9 @@ void OSQLParseTreeIterator::traverseParameter(const OSQLParseNode* _pParseNode
 }
 
 void OSQLParseTreeIterator::traverseOnePredicate(
-                                OSQLParseNode * pColumnRef,
+                                OSQLParseNode const * pColumnRef,
                                 OUString& rValue,
-                                OSQLParseNode * pParseNode)
+                                OSQLParseNode const * pParseNode)
 {
     if ( !pParseNode )
         return;
@@ -1530,7 +1516,7 @@ void OSQLParseTreeIterator::traverseOnePredicate(
 
     /*if (SQL_ISRULE(pParseNode,parameter))
         traverseParameter( pParseNode, pColumnRef, aColumnName, aTableRange, sColumnAlias );
-    else */if (SQL_ISRULE(pParseNode,column_ref))// Column-Name (und TableRange):
+    else */if (SQL_ISRULE(pParseNode,column_ref))// Column-Name (and TableRange):
         getColumnRange(pParseNode,aName,rValue);
     else
     {
@@ -1540,12 +1526,6 @@ void OSQLParseTreeIterator::traverseOnePredicate(
 }
 
 
-void OSQLParseTreeIterator::traverseSome( TraversalParts _nIncludeMask )
-{
-    impl_traverse( _nIncludeMask );
-}
-
-
 void OSQLParseTreeIterator::traverseAll()
 {
     impl_traverse( TraversalParts::All );
@@ -1554,7 +1534,9 @@ void OSQLParseTreeIterator::traverseAll()
 
 void OSQLParseTreeIterator::impl_traverse( TraversalParts _nIncludeMask )
 {
-    impl_resetErrors();
+    // resets our errors
+    m_aErrors = css::sdbc::SQLException();
+
     m_pImpl->m_nIncludeMask = _nIncludeMask;
 
     if ( !traverseTableNames( *m_pImpl->m_pTables ) )
@@ -1604,15 +1586,15 @@ OSQLTable OSQLParseTreeIterator::impl_createTableObject( const OUString& rTableN
         nullptr,
         false,
         rTableName,
-        OUString("Table"),
-        OUString("New Created Table"),
+        "Table",
+        "New Created Table",
         rSchemaName,
         rCatalogName
     );
     return aReturnTable;
 }
 
-void OSQLParseTreeIterator::appendColumns(::rtl::Reference<OSQLColumns>& _rColumns,const OUString& _rTableAlias,const OSQLTable& _rTable)
+void OSQLParseTreeIterator::appendColumns(::rtl::Reference<OSQLColumns> const & _rColumns,const OUString& _rTableAlias,const OSQLTable& _rTable)
 {
     if (!_rTable.is())
         return;
@@ -1657,7 +1639,7 @@ void OSQLParseTreeIterator::appendColumns(::rtl::Reference<OSQLColumns>& _rColum
     }
 }
 
-void OSQLParseTreeIterator::setSelectColumnName(::rtl::Reference<OSQLColumns>& _rColumns,const OUString & rColumnName,const OUString & rColumnAlias, const OUString & rTableRange, bool bFkt, sal_Int32 _nType, bool bAggFkt)
+void OSQLParseTreeIterator::setSelectColumnName(::rtl::Reference<OSQLColumns> const & _rColumns,const OUString & rColumnName,const OUString & rColumnAlias, const OUString & rTableRange, bool bFkt, sal_Int32 _nType, bool bAggFkt)
 {
     if(rColumnName.toChar() == '*' && rTableRange.isEmpty())
     {   // SELECT * ...
@@ -1711,7 +1693,7 @@ void OSQLParseTreeIterator::setSelectColumnName(::rtl::Reference<OSQLColumns>& _
                 // did not find a column with this name in any of the tables
                 OParseColumn* pColumn = new OParseColumn(
                     aNewColName,
-                    OUString("VARCHAR"),
+                    "VARCHAR",
                         // TODO: does this match with _nType?
                         // Or should be fill this from the getTypeInfo of the connection?
                     OUString(),
