@@ -26,8 +26,8 @@ using namespace cppu;
 
 extern "C"
 {
-//##################################################################################################
-CPPU_DLLPUBLIC void SAL_CALL uno_type_any_assign(
+
+void SAL_CALL uno_type_any_assign(
     uno_Any * pDest, void * pSource,
     typelib_TypeDescriptionReference * pType,
     uno_AcquireFunc acquire, uno_ReleaseFunc release )
@@ -36,15 +36,15 @@ CPPU_DLLPUBLIC void SAL_CALL uno_type_any_assign(
     _destructAny( pDest, release );
     if (pType)
     {
-        _copyConstructAny( pDest, pSource, pType, 0, acquire, 0 );
+        _copyConstructAny( pDest, pSource, pType, nullptr, acquire, nullptr );
     }
     else
     {
         CONSTRUCT_EMPTY_ANY( pDest );
     }
 }
-//##################################################################################################
-CPPU_DLLPUBLIC void SAL_CALL uno_any_assign(
+
+void SAL_CALL uno_any_assign(
     uno_Any * pDest, void * pSource,
     typelib_TypeDescription * pTypeDescr,
     uno_AcquireFunc acquire, uno_ReleaseFunc release )
@@ -53,15 +53,15 @@ CPPU_DLLPUBLIC void SAL_CALL uno_any_assign(
     _destructAny( pDest, release );
     if (pTypeDescr)
     {
-        _copyConstructAny( pDest, pSource, pTypeDescr->pWeakRef, pTypeDescr, acquire, 0 );
+        _copyConstructAny( pDest, pSource, pTypeDescr->pWeakRef, pTypeDescr, acquire, nullptr );
     }
     else
     {
         CONSTRUCT_EMPTY_ANY( pDest );
     }
 }
-//##################################################################################################
-CPPU_DLLPUBLIC void SAL_CALL uno_type_any_construct(
+
+void SAL_CALL uno_type_any_construct(
     uno_Any * pDest, void * pSource,
     typelib_TypeDescriptionReference * pType,
     uno_AcquireFunc acquire )
@@ -69,15 +69,15 @@ CPPU_DLLPUBLIC void SAL_CALL uno_type_any_construct(
 {
     if (pType)
     {
-        _copyConstructAny( pDest, pSource, pType, 0, acquire, 0 );
+        _copyConstructAny( pDest, pSource, pType, nullptr, acquire, nullptr );
     }
     else
     {
         CONSTRUCT_EMPTY_ANY( pDest );
     }
 }
-//##################################################################################################
-CPPU_DLLPUBLIC void SAL_CALL uno_any_construct(
+
+void SAL_CALL uno_any_construct(
     uno_Any * pDest, void * pSource,
     typelib_TypeDescription * pTypeDescr,
     uno_AcquireFunc acquire )
@@ -85,15 +85,15 @@ CPPU_DLLPUBLIC void SAL_CALL uno_any_construct(
 {
     if (pTypeDescr)
     {
-        _copyConstructAny( pDest, pSource, pTypeDescr->pWeakRef, pTypeDescr, acquire, 0 );
+        _copyConstructAny( pDest, pSource, pTypeDescr->pWeakRef, pTypeDescr, acquire, nullptr );
     }
     else
     {
         CONSTRUCT_EMPTY_ANY( pDest );
     }
 }
-//##################################################################################################
-CPPU_DLLPUBLIC void SAL_CALL uno_type_any_constructAndConvert(
+
+void SAL_CALL uno_type_any_constructAndConvert(
     uno_Any * pDest, void * pSource,
     typelib_TypeDescriptionReference * pType,
     uno_Mapping * mapping )
@@ -101,15 +101,15 @@ CPPU_DLLPUBLIC void SAL_CALL uno_type_any_constructAndConvert(
 {
     if (pType)
     {
-        _copyConstructAny( pDest, pSource, pType, 0, 0, mapping );
+        _copyConstructAny( pDest, pSource, pType, nullptr, nullptr, mapping );
     }
     else
     {
         CONSTRUCT_EMPTY_ANY( pDest );
     }
 }
-//##################################################################################################
-CPPU_DLLPUBLIC void SAL_CALL uno_any_constructAndConvert(
+
+void SAL_CALL uno_any_constructAndConvert(
     uno_Any * pDest, void * pSource,
     typelib_TypeDescription * pTypeDescr,
     uno_Mapping * mapping )
@@ -117,21 +117,21 @@ CPPU_DLLPUBLIC void SAL_CALL uno_any_constructAndConvert(
 {
     if (pTypeDescr)
     {
-        _copyConstructAny( pDest, pSource, pTypeDescr->pWeakRef, pTypeDescr, 0, mapping );
+        _copyConstructAny( pDest, pSource, pTypeDescr->pWeakRef, pTypeDescr, nullptr, mapping );
     }
     else
     {
         CONSTRUCT_EMPTY_ANY( pDest );
     }
 }
-//##################################################################################################
-CPPU_DLLPUBLIC void SAL_CALL uno_any_destruct( uno_Any * pValue, uno_ReleaseFunc release )
+
+void SAL_CALL uno_any_destruct( uno_Any * pValue, uno_ReleaseFunc release )
     SAL_THROW_EXTERN_C()
 {
     _destructAny( pValue, release );
 }
-//##################################################################################################
-CPPU_DLLPUBLIC void SAL_CALL uno_any_clear( uno_Any * pValue, uno_ReleaseFunc release )
+
+void SAL_CALL uno_any_clear( uno_Any * pValue, uno_ReleaseFunc release )
     SAL_THROW_EXTERN_C()
 {
     _destructAny( pValue, release );
