@@ -19,23 +19,23 @@
 
 #include <config_features.h>
 
-#include "cppu/EnvDcp.hxx"
+#include <cppu/EnvDcp.hxx>
 
-#include "sal/log.hxx"
-#include "osl/diagnose.h"
-#include "osl/interlck.h"
-#include "osl/mutex.hxx"
-#include "osl/module.h"
-#include "osl/process.h"
-#include "rtl/process.h"
-#include "rtl/string.hxx"
-#include "rtl/ustring.hxx"
-#include "rtl/ustrbuf.hxx"
-#include "rtl/instance.hxx"
-#include "typelib/typedescription.h"
-#include "uno/dispatcher.h"
-#include "uno/environment.h"
-#include "uno/lbnames.h"
+#include <sal/log.hxx>
+#include <osl/diagnose.h>
+#include <osl/interlck.h>
+#include <osl/mutex.hxx>
+#include <osl/module.h>
+#include <osl/process.h>
+#include <rtl/process.h>
+#include <rtl/string.hxx>
+#include <rtl/ustring.hxx>
+#include <rtl/ustrbuf.hxx>
+#include <rtl/instance.hxx>
+#include <typelib/typedescription.h>
+#include <uno/dispatcher.h>
+#include <uno/environment.h>
+#include <uno/lbnames.h>
 #include "prim.hxx"
 #include "destr.hxx"
 #include "loadmodule.hxx"
@@ -46,14 +46,13 @@
 
 
 using ::rtl::OUString;
-using ::rtl::OUStringHash;
 
 namespace
 {
 
 
-inline bool td_equals( typelib_InterfaceTypeDescription * pTD1,
-                              typelib_InterfaceTypeDescription * pTD2 )
+inline bool td_equals( typelib_InterfaceTypeDescription const * pTD1,
+                       typelib_InterfaceTypeDescription const * pTD2 )
 {
     return (pTD1 == pTD2 ||
             (pTD1->aBase.pTypeName->length == pTD2->aBase.pTypeName->length &&
@@ -89,12 +88,11 @@ struct ObjectEntry
         uno_freeProxyFunc fpFreeProxy );
     inline InterfaceEntry * find(
         typelib_InterfaceTypeDescription * pTypeDescr );
-    inline sal_Int32 find( void * iface_ptr, std::size_t pos );
+    inline sal_Int32 find( void const * iface_ptr, std::size_t pos ) const;
 };
 
 
-struct FctPtrHash :
-    public std::unary_function< const void *, std::size_t >
+struct FctPtrHash
 {
     std::size_t operator () ( const void * pKey ) const
         { return reinterpret_cast< std::size_t>( pKey ); }
@@ -103,14 +101,14 @@ struct FctPtrHash :
 
 // mapping from environment name to environment
 typedef std::unordered_map<
-    OUString, uno_Environment *, OUStringHash > OUString2EnvironmentMap;
+    OUString, uno_Environment * > OUString2EnvironmentMap;
 
 // mapping from ptr to object entry
 typedef std::unordered_map<
     void *, ObjectEntry *, FctPtrHash > Ptr2ObjectMap;
 // mapping from oid to object entry
 typedef std::unordered_map<
-    OUString, ObjectEntry *, OUStringHash > OId2ObjectMap;
+    OUString, ObjectEntry * > OId2ObjectMap;
 
 struct EnvironmentsData
 {
@@ -171,8 +169,7 @@ inline void ObjectEntry::append(
     aNewEntry.pTypeDescr = pTypeDescr;
 
     std::pair< Ptr2ObjectMap::iterator, bool > i(
-        pEnv->aPtr2ObjectMap.insert( Ptr2ObjectMap::value_type(
-                                         pInterface, this ) ) );
+        pEnv->aPtr2ObjectMap.emplace( pInterface, this ) );
     SAL_WARN_IF(
         !i.second && (find(pInterface, 0) == -1 || i.first->second != this),
         "cppu",
@@ -214,7 +211,7 @@ inline InterfaceEntry * ObjectEntry::find(
 
 
 inline sal_Int32 ObjectEntry::find(
-    void * iface_ptr, std::size_t pos )
+    void const * iface_ptr, std::size_t pos ) const
 {
     std::size_t size = aInterfaces.size();
     for ( ; pos < size; ++pos )
@@ -242,7 +239,7 @@ static void SAL_CALL defenv_registerInterface(
 
     // try to insert dummy 0:
     std::pair<OId2ObjectMap::iterator, bool> const insertion(
-        that->aOId2ObjectMap.insert( OId2ObjectMap::value_type( rOId, nullptr ) ) );
+        that->aOId2ObjectMap.emplace(  rOId, nullptr ) );
     if (insertion.second)
     {
         ObjectEntry * pOEntry = new ObjectEntry( rOId );
@@ -290,7 +287,7 @@ static void SAL_CALL defenv_registerProxyInterface(
 
     // try to insert dummy 0:
     std::pair<OId2ObjectMap::iterator, bool> const insertion(
-        that->aOId2ObjectMap.insert( OId2ObjectMap::value_type( rOId, nullptr ) ) );
+        that->aOId2ObjectMap.emplace(  rOId, nullptr ) );
     if (insertion.second)
     {
         ObjectEntry * pOEntry = new ObjectEntry( rOId );
@@ -953,8 +950,7 @@ inline void EnvironmentsData::registerEnvironment( uno_Environment ** ppEnv )
     {
         (*pEnv->acquireWeak)( pEnv );
         std::pair< OUString2EnvironmentMap::iterator, bool > insertion (
-            aName2EnvMap.insert(
-                OUString2EnvironmentMap::value_type( aKey, pEnv ) ) );
+            aName2EnvMap.emplace( aKey, pEnv ) );
         SAL_WARN_IF( !insertion.second, "cppu", "key " << aKey << " already in env map" );
     }
     else
@@ -993,7 +989,7 @@ inline void EnvironmentsData::getRegisteredEnvironments(
     {
         uno_Environment * pWeak = iPos->second;
         if (rEnvDcp.isEmpty() ||
-            rEnvDcp.equals( pWeak->pTypeName ))
+            rEnvDcp == pWeak->pTypeName )
         {
             aFounds[nSize] = nullptr;
             (*pWeak->harden)( &aFounds[nSize], pWeak );
