@@ -29,7 +29,6 @@ using namespace com::sun::star;
 using namespace com::sun::star::uno;
 using namespace com::sun::star::lang;
 
-using ::rtl::OUString;
 using ::rtl::OString;
 using ::rtl::OUStringToOString;
 
@@ -48,18 +47,18 @@ OComponentHelper::~OComponentHelper()
 {
 }
 
-Any OComponentHelper::queryInterface( Type const & rType ) throw (RuntimeException, std::exception)
+Any OComponentHelper::queryInterface( Type const & rType )
 {
     return OWeakAggObject::queryInterface( rType );
 }
-Any OComponentHelper::queryAggregation( Type const & rType ) throw (RuntimeException, std::exception)
+Any OComponentHelper::queryAggregation( Type const & rType )
 {
     if (rType == cppu::UnoType<lang::XComponent>::get())
     {
         void * p = static_cast< lang::XComponent * >( this );
         return Any( &p, rType );
     }
-    else if (rType == cppu::UnoType<lang::XTypeProvider>::get())
+    if (rType == cppu::UnoType<lang::XTypeProvider>::get())
     {
         void * p = static_cast< lang::XTypeProvider * >( this );
         return Any( &p, rType );
@@ -93,12 +92,7 @@ void OComponentHelper::release() throw()
                 catch (css::uno::RuntimeException & exc)
                 {
                     // release should not throw exceptions
-#if OSL_DEBUG_LEVEL > 0
-                    OString msg( OUStringToOString( exc.Message, RTL_TEXTENCODING_ASCII_US ) );
-                    OSL_FAIL( msg.getStr() );
-#else
-                    (void) exc; // avoid warning about unused variable
-#endif
+                    SAL_WARN( "cppuhelper", exc );
                 }
 
                 // only the alive ref holds the object
@@ -113,7 +107,7 @@ void OComponentHelper::release() throw()
     OWeakAggObject::release();
 }
 
-Sequence< Type > OComponentHelper::getTypes() throw (RuntimeException, std::exception)
+Sequence< Type > OComponentHelper::getTypes()
 {
     static OTypeCollection * s_pTypes = nullptr;
     if (! s_pTypes)
@@ -139,24 +133,23 @@ void OComponentHelper::disposing()
 
 // XComponent
 void OComponentHelper::dispose()
-    throw(css::uno::RuntimeException, std::exception)
 {
     // An frequently programming error is to release the last
     // reference to this object in the disposing message.
-    // Make it rubust, hold a self Reference.
+    // Make it robust, hold a self Reference.
     Reference<XComponent > xSelf( this );
 
-    // Guard dispose against multible threading
+    // Guard dispose against multiple threading
     // Remark: It is an error to call dispose more than once
     bool bDoDispose = false;
     {
-    MutexGuard aGuard( rBHelper.rMutex );
-    if( !rBHelper.bDisposed && !rBHelper.bInDispose )
-    {
-        // only one call go into this section
-        rBHelper.bInDispose = sal_True;
-        bDoDispose = true;
-    }
+        MutexGuard aGuard( rBHelper.rMutex );
+        if( !rBHelper.bDisposed && !rBHelper.bInDispose )
+        {
+            // only one call go into this section
+            rBHelper.bInDispose = true;
+            bDoDispose = true;
+        }
     }
 
     // Do not hold the mutex because we are broadcasting
@@ -181,14 +174,14 @@ void OComponentHelper::dispose()
             {
                 MutexGuard aGuard( rBHelper.rMutex );
                 // bDispose and bInDisposing must be set in this order:
-                rBHelper.bDisposed = sal_True;
-                rBHelper.bInDispose = sal_False;
+                rBHelper.bDisposed = true;
+                rBHelper.bInDispose = false;
                 throw;
             }
             MutexGuard aGuard( rBHelper.rMutex );
             // bDispose and bInDisposing must be set in this order:
-            rBHelper.bDisposed = sal_True;
-            rBHelper.bInDispose = sal_False;
+            rBHelper.bDisposed = true;
+            rBHelper.bInDispose = false;
         }
         catch (RuntimeException &)
         {
@@ -205,14 +198,13 @@ void OComponentHelper::dispose()
         // in a multithreaded environment, it can't be avoided
         // that dispose is called twice.
         // However this condition is traced, because it MAY indicate an error.
-        OSL_TRACE( "OComponentHelper::dispose() - dispose called twice" );
+        SAL_WARN("cppuhelper",  "OComponentHelper::dispose() - dispose called twice" );
     }
 }
 
 // XComponent
 void OComponentHelper::addEventListener(
     const Reference<XEventListener > & rxListener )
-    throw(css::uno::RuntimeException, std::exception)
 {
     ClearableMutexGuard aGuard( rBHelper.rMutex );
     if (rBHelper.bDisposed || rBHelper.bInDispose)
@@ -230,7 +222,6 @@ void OComponentHelper::addEventListener(
 // XComponent
 void OComponentHelper::removeEventListener(
     const Reference<XEventListener > & rxListener )
-    throw(css::uno::RuntimeException, std::exception)
 {
     rBHelper.removeListener( cppu::UnoType<decltype(rxListener)>::get(), rxListener );
 }
