@@ -58,44 +58,41 @@ cppu::defaultBootstrap_InitialComponentContext(rtl::OUString const & iniUri)
     smgr->init(getBootstrapVariable(bs, "UNO_SERVICES"));
     rtl::Reference< cppuhelper::TypeManager > tmgr(new cppuhelper::TypeManager);
     tmgr->init(getBootstrapVariable(bs, "UNO_TYPES"));
-    cppu::ContextEntry_Init entry;
     std::vector< cppu::ContextEntry_Init > context_values;
     context_values.push_back(
         cppu::ContextEntry_Init(
             "/singletons/com.sun.star.lang.theServiceManager",
-            css::uno::makeAny(
+            css::uno::Any(
                 css::uno::Reference< css::uno::XInterface >(
                     static_cast< cppu::OWeakObject * >(smgr.get()))),
             false));
     context_values.push_back(
         cppu::ContextEntry_Init(
             "/singletons/com.sun.star.reflection.theTypeDescriptionManager",
-            css::uno::makeAny(
+            css::uno::Any(
                 css::uno::Reference< css::uno::XInterface >(
                     static_cast< cppu::OWeakObject * >(tmgr.get()))),
             false));
     context_values.push_back( //TODO: from services.rdb?
         cppu::ContextEntry_Init(
             "/singletons/com.sun.star.util.theMacroExpander",
-            css::uno::makeAny(
+            css::uno::Any(
                 cppuhelper::detail::create_bootstrap_macro_expander_factory()),
             true));
     smgr->addSingletonContextEntries(&context_values);
     context_values.push_back(
         cppu::ContextEntry_Init(
             "/services/com.sun.star.security.AccessController/mode",
-            css::uno::makeAny(rtl::OUString("off")), false));
+            css::uno::Any(rtl::OUString("off")), false));
     context_values.push_back(
         cppu::ContextEntry_Init(
             "/singletons/com.sun.star.security.theAccessController",
-            css::uno::makeAny(
+            css::uno::Any(
                 rtl::OUString("com.sun.star.security.AccessController")),
             true));
     assert(!context_values.empty());
     css::uno::Reference< css::uno::XComponentContext > context(
-        createComponentContext(
-            &context_values[0], context_values.size(),
-            css::uno::Reference< css::uno::XComponentContext >()));
+        createComponentContext(&context_values[0], context_values.size()));
     smgr->setContext(context);
     cppu::installTypeDescriptionManager(tmgr.get());
     return context;
