@@ -19,7 +19,7 @@
 
 #include <stdio.h>
 
-#include "sal/main.h"
+#include <sal/main.h>
 #include <osl/diagnose.h>
 #include <osl/mutex.hxx>
 #include <osl/conditn.hxx>
@@ -30,7 +30,7 @@
 #include <rtl/ustrbuf.hxx>
 
 #include <cppuhelper/bootstrap.hxx>
-#include <cppuhelper/implbase1.hxx>
+#include <cppuhelper/implbase.hxx>
 
 #include <com/sun/star/lang/XMain.hpp>
 #include <com/sun/star/lang/XInitialization.hpp>
@@ -84,9 +84,9 @@ static const char arUsingText[] =
 "    [--quiet]\n"
 "    [-- Argument1 Argument2 ...]\n";
 
+/// @throws RuntimeException
 static bool readOption( OUString * pValue, const sal_Char * pOpt,
                         sal_uInt32 * pnIndex, const OUString & aArg)
-    throw (RuntimeException)
 {
     const OUString dash("-");
     if(!aArg.startsWith(dash))
@@ -103,35 +103,18 @@ static bool readOption( OUString * pValue, const sal_Char * pOpt,
         ++(*pnIndex);
 
         rtl_getAppCommandArg(*pnIndex, &pValue->pData);
-        if (*pnIndex >= rtl_getAppCommandArgCount() || pValue->copy(1).equals(dash))
+        if (*pnIndex >= rtl_getAppCommandArgCount() || pValue->copy(1) == dash)
         {
-            throw RuntimeException(
-                "incomplete option \"-" + aOpt + "\" given!",
-                Reference< XInterface >() );
-        }
-        else
-        {
-#if OSL_DEBUG_LEVEL > 1
-            out( "\n> identified option -" );
-            out( pOpt );
-            out( " = " );
-            OString tmp = OUStringToOString(aArg, RTL_TEXTENCODING_ASCII_US);
-              out( tmp.getStr() );
-#endif
-            ++(*pnIndex);
-            return true;
+            throw RuntimeException( "incomplete option \"-" + aOpt + "\" given!" );
         }
+        SAL_INFO("cpputools.unoexe", "> identified option -" << pOpt << " = " << aArg);
+        ++(*pnIndex);
+        return true;
     }
       else if (aArg.indexOf(aOpt) == 1)
     {
         *pValue = aArg.copy(1 + aOpt.getLength());
-#if OSL_DEBUG_LEVEL > 1
-        out( "\n> identified option -" );
-        out( pOpt );
-        out( " = " );
-        OString tmp = OUStringToOString(aArg.copy(aOpt.getLength()), RTL_TEXTENCODING_ASCII_US);
-        out( tmp.getStr() );
-#endif
+        SAL_INFO("cpputools.unoexe", "> identified option -" << pOpt << " = " << aArg);
         ++(*pnIndex);
 
         return true;
@@ -142,129 +125,105 @@ static bool readOption( OUString * pValue, const sal_Char * pOpt,
 static bool readOption( bool * pbOpt, const sal_Char * pOpt,
                         sal_uInt32 * pnIndex, const OUString & aArg)
 {
-    const OUString dashdash("--");
     OUString aOpt = OUString::createFromAscii(pOpt);
 
-    if(aArg.startsWith(dashdash) && aOpt.equals(aArg.copy(2)))
+    if(aArg.startsWith("--") && aOpt == aArg.copy(2))
     {
         ++(*pnIndex);
         *pbOpt = true;
-#if OSL_DEBUG_LEVEL > 1
-        out( "\n> identified option --" );
-        out( pOpt );
-#endif
+        SAL_INFO("cpputools.unoexe", "> identified option --" << pOpt);
         return true;
     }
     return false;
 }
 
+/// @throws Exception
 template< class T >
 void createInstance(
     Reference< T > & rxOut,
     const Reference< XComponentContext > & xContext,
     const OUString & rServiceName )
-    throw (Exception)
 {
     Reference< XMultiComponentFactory > xMgr( xContext->getServiceManager() );
     Reference< XInterface > x( xMgr->createInstanceWithContext( rServiceName, xContext ) );
 
     if (! x.is())
     {
-        throw RuntimeException(
-            "cannot get service instance \"" + rServiceName + "\"!",
-            Reference< XInterface >() );
+        throw RuntimeException( "cannot get service instance \"" + rServiceName + "\"!" );
     }
 
-    rxOut = Reference< T >::query( x );
-    if (! rxOut.is())
-    {
-        const Type & rType = ::getCppuType( (const Reference< T > *)0 );
-        throw RuntimeException(
-            "service instance \"" + rServiceName +
-            "\" does not support demanded interface \"" +
-            rType.getTypeName() + "\"!",
-            Reference< XInterface >() );
-    }
+    rxOut.set( x, UNO_QUERY_THROW );
 }
 
+/// @throws Exception
 static Reference< XInterface > loadComponent(
     const Reference< XComponentContext > & xContext,
     const OUString & rImplName, const OUString & rLocation )
-    throw (Exception)
 {
     // determine loader to be used
     sal_Int32 nDot = rLocation.lastIndexOf( '.' );
-    if (nDot > 0 && nDot < rLocation.getLength())
+    if (nDot <= 0 || nDot >= rLocation.getLength())
     {
-        Reference< XImplementationLoader > xLoader;
+        throw RuntimeException(
+            "location \"" + rLocation + "\" has no extension!  Cannot determine loader to be used!" );
+    }
 
-        OUString aExt( rLocation.copy( nDot +1 ) );
+    Reference< XImplementationLoader > xLoader;
 
-        if (aExt.equalsAscii( "dll" ) ||
-            aExt.equalsAscii( "exe" ) ||
-            aExt.equalsAscii( "dylib" ) ||
-            aExt.equalsAscii( "so" ) )
-        {
-            createInstance(
-                xLoader, xContext, OUString("com.sun.star.loader.SharedLibrary") );
-        }
-        else if (aExt.equalsAscii( "jar" ) ||
-                 aExt.equalsAscii( "class" ) )
-        {
-            createInstance(
-                xLoader, xContext, OUString("com.sun.star.loader.Java") );
-        }
-        else
-        {
-            throw RuntimeException(
-                "unknown extension of \"" + rLocation + "\"!  No loader available!",
-                Reference< XInterface >() );
-        }
+    OUString aExt( rLocation.copy( nDot +1 ) );
 
-        Reference< XInterface > xInstance;
-
-        // activate
-        Reference< XInterface > xFactory( xLoader->activate(
-            rImplName, OUString(), rLocation, Reference< XRegistryKey >() ) );
-        if (xFactory.is())
-        {
-            Reference< XSingleComponentFactory > xCFac( xFactory, UNO_QUERY );
-            if (xCFac.is())
-            {
-                xInstance = xCFac->createInstanceWithContext( xContext );
-            }
-            else
-            {
-                Reference< XSingleServiceFactory > xSFac( xFactory, UNO_QUERY );
-                if (xSFac.is())
-                {
-                    out( "\n> warning: ignroing context for implementation \"" );
-                    out( rImplName );
-                    out( "\"!" );
-                    xInstance = xSFac->createInstance();
-                }
-            }
-        }
-
-        if (! xInstance.is())
-        {
-            throw RuntimeException(
-                "activating component \"" + rImplName + "\" from location \"" + rLocation + "\" failed!",
-                Reference< XInterface >() );
-        }
-
-        return xInstance;
+    if (aExt == "dll" || aExt == "exe" || aExt == "dylib" || aExt == "so")
+    {
+        createInstance(
+            xLoader, xContext, "com.sun.star.loader.SharedLibrary" );
+    }
+    else if (aExt == "jar" || aExt == "class")
+    {
+        createInstance(
+            xLoader, xContext, "com.sun.star.loader.Java" );
     }
     else
     {
         throw RuntimeException(
-            "location \"" + rLocation + "\" has no extension!  Cannot determine loader to be used!",
-            Reference< XInterface >() );
+            "unknown extension of \"" + rLocation + "\"!  No loader available!" );
     }
+
+    Reference< XInterface > xInstance;
+
+    // activate
+    Reference< XInterface > xFactory( xLoader->activate(
+        rImplName, OUString(), rLocation, Reference< XRegistryKey >() ) );
+    if (xFactory.is())
+    {
+        Reference< XSingleComponentFactory > xCFac( xFactory, UNO_QUERY );
+        if (xCFac.is())
+        {
+            xInstance = xCFac->createInstanceWithContext( xContext );
+        }
+        else
+        {
+            Reference< XSingleServiceFactory > xSFac( xFactory, UNO_QUERY );
+            if (xSFac.is())
+            {
+                out( "\n> warning: ignoring context for implementation \"" );
+                out( rImplName );
+                out( "\"!" );
+                xInstance = xSFac->createInstance();
+            }
+        }
+    }
+
+    if (! xInstance.is())
+    {
+        throw RuntimeException(
+            "activating component \"" + rImplName + "\" from location \"" + rLocation + "\" failed!" );
+    }
+
+    return xInstance;
 }
 
 class OInstanceProvider
-    : public WeakImplHelper1< XInstanceProvider >
+    : public WeakImplHelper< XInstanceProvider >
 {
     Reference< XComponentContext > _xContext;
 
@@ -279,7 +238,8 @@ class OInstanceProvider
 
     OUString                          _aInstanceName;
 
-    inline Reference< XInterface > createInstance() throw (Exception);
+    /// @throws Exception
+    inline Reference< XInterface > createInstance();
 
 public:
     OInstanceProvider( const Reference< XComponentContext > & xContext,
@@ -296,12 +256,10 @@ public:
         {}
 
     // XInstanceProvider
-    virtual Reference< XInterface > SAL_CALL getInstance( const OUString & rName )
-        throw (NoSuchElementException, RuntimeException, std::exception) SAL_OVERRIDE;
+    virtual Reference< XInterface > SAL_CALL getInstance( const OUString & rName ) override;
 };
 
 inline Reference< XInterface > OInstanceProvider::createInstance()
-    throw (Exception)
 {
     Reference< XInterface > xRet;
     if (!_aImplName.isEmpty()) // manually via loader
@@ -318,7 +276,6 @@ inline Reference< XInterface > OInstanceProvider::createInstance()
 }
 
 Reference< XInterface > OInstanceProvider::getInstance( const OUString & rName )
-    throw (NoSuchElementException, RuntimeException, std::exception)
 {
     try
     {
@@ -357,30 +314,27 @@ Reference< XInterface > OInstanceProvider::getInstance( const OUString & rName )
         out( rExc.Message );
     }
     throw NoSuchElementException(
-        "no such element \"" + rName + "\"!",
-        Reference< XInterface >() );
+        "no such element \"" + rName + "\"!" );
 }
 
-struct ODisposingListener : public WeakImplHelper1< XEventListener >
+struct ODisposingListener : public WeakImplHelper< XEventListener >
 {
     Condition cDisposed;
 
     // XEventListener
-    virtual void SAL_CALL disposing( const EventObject & rEvt )
-        throw (RuntimeException, std::exception) SAL_OVERRIDE;
+    virtual void SAL_CALL disposing( const EventObject & rEvt ) override;
 
     static void waitFor( const Reference< XComponent > & xComp );
 };
 
 void ODisposingListener::disposing( const EventObject & )
-    throw (RuntimeException, std::exception)
 {
     cDisposed.set();
 }
 
 void ODisposingListener::waitFor( const Reference< XComponent > & xComp )
 {
-    ODisposingListener * pListener = new ODisposingListener();
+    ODisposingListener * pListener = new ODisposingListener;
     Reference< XEventListener > xListener( pListener );
 
     xComp->addEventListener( xListener );
@@ -421,8 +375,7 @@ SAL_IMPLEMENT_MAIN()
 
             rtl_getAppCommandArg(nPos, &arg.pData);
 
-            const OUString dashdash("--");
-            if (dashdash == arg)
+            if (arg == "--")
             {
                 ++nPos;
                 break;
@@ -437,26 +390,23 @@ SAL_IMPLEMENT_MAIN()
                   readOption( &bSingleInstance, "singleinstance", &nPos, arg)))
             {
                 throw RuntimeException(
-                    "unexpected argument \"" + arg + "\"",
-                    Reference< XInterface >() );
+                    "unexpected argument \"" + arg + "\"" );
             }
         }
 
         if (!(aImplName.isEmpty() || aServiceName.isEmpty()))
-            throw RuntimeException("give component exOR service name!", Reference< XInterface >() );
+            throw RuntimeException("give component exOR service name!" );
         if (aImplName.isEmpty() && aServiceName.isEmpty())
         {
             if (! aUnoUrl.endsWithIgnoreAsciiCase( ";uno.ComponentContext" ))
                 throw RuntimeException(
-                    OUString("expected UNO-URL with instance name uno.ComponentContext!" ),
-                    Reference<XInterface>() );
+                    "expected UNO-URL with instance name uno.ComponentContext!" );
             if (bSingleInstance)
                 throw RuntimeException(
-                    OUString("unexpected option --singleinstance!"),
-                    Reference<XInterface>() );
+                    "unexpected option --singleinstance!" );
         }
         if (!aImplName.isEmpty() && aLocation.isEmpty())
-            throw RuntimeException("give component location!", Reference< XInterface >() );
+            throw RuntimeException("give component location!" );
         if (!aServiceName.isEmpty() && !aLocation.isEmpty())
             out( "\n> warning: service name given, will ignore location!" );
 
@@ -472,7 +422,7 @@ SAL_IMPLEMENT_MAIN()
 
         xContext = defaultBootstrap_InitialComponentContext();
 
-        // accept, instanciate, etc.
+        // accept, instantiate, etc.
 
         if (!aUnoUrl.isEmpty()) // accepting connections
         {
@@ -481,7 +431,7 @@ SAL_IMPLEMENT_MAIN()
             if (nTokens != 3 || aUnoUrl.getLength() < 10 ||
                 !aUnoUrl.copy( 0, 4 ).equalsIgnoreAsciiCase( "uno:" ))
             {
-                throw RuntimeException("illegal uno url given!", Reference< XInterface >() );
+                throw RuntimeException("illegal uno url given!" );
             }
             nIndex = 0;
             OUString aConnectDescr( aUnoUrl.getToken( 0, ';', nIndex ).copy( 4 ) ); // uno:CONNECTDESCR;iiop;InstanceName
@@ -495,7 +445,7 @@ SAL_IMPLEMENT_MAIN()
             Any * pInitParams = aInitParams.getArray();
             for ( sal_Int32 i = aParams.getLength(); i--; )
             {
-                pInitParams[i] = makeAny( p[i] );
+                pInitParams[i] <<= p[i];
             }
 
             // instance provider
@@ -505,6 +455,7 @@ SAL_IMPLEMENT_MAIN()
 
             nIndex = 0;
             OUString aUnoUrlToken( aUnoUrl.getToken( 1, ';', nIndex ) );
+            // coverity[loop_top] - not really an infinite loop, we can be instructed to exit via the connection
             for (;;)
             {
                 // accepting
@@ -517,7 +468,7 @@ SAL_IMPLEMENT_MAIN()
                 Reference< XBridgeFactory > xBridgeFactory;
                 createInstance(
                     xBridgeFactory, xContext,
-                    OUString("com.sun.star.bridge.BridgeFactory") );
+                    "com.sun.star.bridge.BridgeFactory" );
 
                 // bridge
                 Reference< XBridge > xBridge( xBridgeFactory->createBridge(
@@ -526,9 +477,7 @@ SAL_IMPLEMENT_MAIN()
 
                 if (bSingleAccept)
                 {
-                    Reference< XComponent > xComp( xBridge, UNO_QUERY );
-                    if (! xComp.is())
-                        throw RuntimeException( OUString( "bridge factory does not export interface \"com.sun.star.lang.XComponent\"!" ), Reference< XInterface >() );
+                    Reference< XComponent > xComp( xBridge, UNO_QUERY_THROW );
                     ODisposingListener::waitFor( xComp );
                     xComp->dispose();
                         // explicitly dispose the remote bridge so that it joins
@@ -557,7 +506,7 @@ SAL_IMPLEMENT_MAIN()
                 Reference< XComponent > xComp( xInstance, UNO_QUERY );
                 if (xComp.is())
                     xComp->dispose();
-                throw RuntimeException( OUString( "component does not export interface interface \"com.sun.star.lang.XMain\"!" ), Reference< XInterface >() );
+                throw RuntimeException( "component does not export interface \"com.sun.star.lang.XMain\"!" );
             }
         }
     }
@@ -574,9 +523,6 @@ SAL_IMPLEMENT_MAIN()
     if (xComp.is())
         xComp->dispose();
 
-#if OSL_DEBUG_LEVEL > 1
-    out( "\n" );
-#endif
     return nRet;
 }
 
