@@ -17,14 +17,13 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "sal/config.h"
+#include <sal/config.h>
 
 #include <algorithm>
 #include <cassert>
 
 #include <vcl/errinf.hxx>
 #include <ucbhelper/content.hxx>
-#include <osl/mutex.hxx>
 #include <vcl/svapp.hxx>
 #include <vcl/msgbox.hxx>
 #include <avmedia/mediawindow.hxx>
@@ -33,9 +32,9 @@
 #include <vcl/graphicfilter.hxx>
 #include <svx/gallery1.hxx>
 #include <svx/galtheme.hxx>
-#include "cuigaldlg.hxx"
-#include "helpid.hrc"
-#include "bitmaps.hlst"
+#include <cuigaldlg.hxx>
+#include <helpids.h>
+#include <bitmaps.hlst>
 #include <unotools/syslocale.hxx>
 #include <com/sun/star/uno/Reference.hxx>
 #include <com/sun/star/lang/XInitialization.hpp>
@@ -47,10 +46,11 @@
 #include <com/sun/star/ui/dialogs/FolderPicker.hpp>
 #include <com/sun/star/ui/dialogs/XAsynchronousExecutableDialog.hpp>
 #include <sfx2/sfxuno.hxx>
-#include "dialmgr.hxx"
-#include "gallery.hrc"
+#include <dialmgr.hxx>
+#include <strings.hrc>
 #include <svx/dialogs.hrc>
 #include <svx/dialmgr.hxx>
+#include <svx/strings.hrc>
 
 using namespace ::ucbhelper;
 using namespace ::cppu;
@@ -283,13 +283,13 @@ void TakeThread::execute()
     {
         SolarMutexGuard aGuard;
         pStatusProgress = new GalleryProgress;
-        nEntries = mpBrowser->bTakeAll ? mpBrowser->m_pLbxFound->GetEntryCount() : mpBrowser->m_pLbxFound->GetSelectEntryCount();
+        nEntries = mpBrowser->bTakeAll ? mpBrowser->m_pLbxFound->GetEntryCount() : mpBrowser->m_pLbxFound->GetSelectedEntryCount();
         pThm->LockBroadcaster();
     }
 
     for( sal_Int32 i = 0; i < nEntries && schedule(); ++i )
     {
-        const sal_Int32 nPos = mpBrowser->bTakeAll ? i : mpBrowser->m_pLbxFound->GetSelectEntryPos( i );
+        const sal_Int32 nPos = mpBrowser->bTakeAll ? i : mpBrowser->m_pLbxFound->GetSelectedEntryPos( i );
         const INetURLObject aURL( mpBrowser->aFoundList[ nPos ]);
 
         mrTakenList.push_back( (sal_uLong)nPos );
@@ -483,8 +483,7 @@ IMPL_LINK( ActualizeProgress, TimeoutHdl, Timer*, _pTimer, void)
 
 IMPL_LINK( ActualizeProgress, ActualizeHdl, const INetURLObject&, rURL, void )
 {
-    for( long i = 0; i < 128; i++ )
-        Application::Reschedule();
+    Application::Reschedule( true );
 
     Flush();
 
@@ -576,7 +575,7 @@ IMPL_LINK_NOARG(GalleryIdDialog, ClickOkHdl, Button*, void)
 
 
 GalleryThemeProperties::GalleryThemeProperties(vcl::Window* pParent,
-    ExchangeData* _pData, SfxItemSet* pItemSet)
+    ExchangeData* _pData, SfxItemSet const * pItemSet)
     : SfxTabDialog( pParent, "GalleryThemeDialog",
         "cui/ui/gallerythemedialog.ui", pItemSet)
     , pData(_pData)
@@ -710,7 +709,6 @@ VclPtr<SfxTabPage> TPGalleryThemeGeneral::Create( vcl::Window* pParent, const Sf
 TPGalleryThemeProperties::TPGalleryThemeProperties( vcl::Window* pWindow, const SfxItemSet& rSet )
     : SfxTabPage(pWindow, "GalleryFilesPage", "cui/ui/galleryfilespage.ui", &rSet)
     , pData(nullptr)
-    , nCurFilterPos(0)
     , nFirstExtFilterPos(0)
     , bEntriesFound(false)
     , bInputAllowed(true)
@@ -720,7 +718,7 @@ TPGalleryThemeProperties::TPGalleryThemeProperties( vcl::Window* pWindow, const
 {
     get(m_pCbbFileType, "filetype");
     get(m_pLbxFound, "files");
-    Size aSize(LogicToPixel(Size(172, 156), MapUnit::MapAppFont));
+    Size aSize(LogicToPixel(Size(172, 156), MapMode(MapUnit::MapAppFont)));
     m_pLbxFound->set_width_request(aSize.Width());
     m_pLbxFound->set_height_request(aSize.Height());
     m_pLbxFound->EnableMultiSelection(true);
@@ -748,7 +746,7 @@ void TPGalleryThemeProperties::SetXChgData( ExchangeData* _pData )
     m_pCbbFileType->EnableDDAutoWidth( false );
     m_pLbxFound->SetDoubleClickHdl(LINK(this, TPGalleryThemeProperties, DClickFoundHdl));
     m_pLbxFound->SetSelectHdl(LINK(this, TPGalleryThemeProperties, SelectFoundHdl));
-    m_pLbxFound->InsertEntry(OUString(CuiResId(RID_SVXSTR_GALLERY_NOFILES)));
+    m_pLbxFound->InsertEntry(CuiResId(RID_SVXSTR_GALLERY_NOFILES));
     m_pLbxFound->Show();
 
     FillFilterList();
@@ -767,8 +765,6 @@ void TPGalleryThemeProperties::StartSearchFiles( const OUString& _rFolderURL, sh
         bSearchRecursive = true;    // UI choice no longer possible, windows file picker allows no user controls
         SearchFiles();
     }
-
-    nCurFilterPos = m_pCbbFileType->GetEntryPos( m_pCbbFileType->GetText() );
 }
 
 
@@ -807,14 +803,10 @@ VclPtr<SfxTabPage> TPGalleryThemeProperties::Create( vcl::Window* pParent, const
 
 OUString TPGalleryThemeProperties::addExtension( const OUString& _rDisplayText, const OUString& _rExtension )
 {
-    OUString sAllFilter( "(*.*)" );
-    OUString sOpenBracket( " (" );
-    OUString sCloseBracket( ")" );
     OUString sRet = _rDisplayText;
-
-    if ( sRet.indexOf( sAllFilter ) == -1 )
+    if ( sRet.indexOf( "(*.*)" ) == -1 )
     {
-        sRet += sOpenBracket + _rExtension + sCloseBracket;
+        sRet += " (" + _rExtension + ")";
     }
     return sRet;
 }
@@ -1014,8 +1006,6 @@ IMPL_LINK_NOARG(TPGalleryThemeProperties, ClickSearchHdl, Button*, void)
                     bSearchRecursive = true;    // UI choice no longer possible, windows file picker allows no user controls
                     SearchFiles();
                 }
-
-                nCurFilterPos = m_pCbbFileType->GetEntryPos( m_pCbbFileType->GetText() );
             }
         }
         catch (const IllegalArgumentException&)
@@ -1028,7 +1018,7 @@ IMPL_LINK_NOARG(TPGalleryThemeProperties, ClickSearchHdl, Button*, void)
 
 void TPGalleryThemeProperties::TakeFiles()
 {
-    if( m_pLbxFound->GetSelectEntryCount() || ( bTakeAll && bEntriesFound ) )
+    if( m_pLbxFound->GetSelectedEntryCount() || ( bTakeAll && bEntriesFound ) )
     {
         VclPtrInstance<TakeProgress> pTakeProgress( this );
         pTakeProgress->Update();
@@ -1061,7 +1051,7 @@ IMPL_LINK_NOARG(TPGalleryThemeProperties, ClickPreviewHdl, Button*, void)
 
 void TPGalleryThemeProperties::DoPreview()
 {
-    OUString aString( m_pLbxFound->GetSelectEntry() );
+    OUString aString( m_pLbxFound->GetSelectedEntry() );
 
     if( aString != aPreviewString )
     {
@@ -1093,9 +1083,9 @@ IMPL_LINK_NOARG(TPGalleryThemeProperties, ClickTakeHdl, Button*, void)
     {
         aPreviewTimer.Stop();
 
-        if( !m_pLbxFound->GetSelectEntryCount() || !bEntriesFound )
+        if( !m_pLbxFound->GetSelectedEntryCount() || !bEntriesFound )
         {
-            SvxOpenGraphicDialog aDlg("Gallery");
+            SvxOpenGraphicDialog aDlg("Gallery", this);
             aDlg.EnableLink(false);
             aDlg.AsLink(false);
 
@@ -1132,7 +1122,7 @@ IMPL_LINK_NOARG(TPGalleryThemeProperties, SelectFoundHdl, ListBox&, void)
 
         if( bEntriesFound )
         {
-            if( m_pLbxFound->GetSelectEntryCount() == 1 )
+            if( m_pLbxFound->GetSelectedEntryCount() == 1 )
             {
                 m_pCbxPreview->Enable();
                 bPreviewPossible = true;
@@ -1158,7 +1148,7 @@ IMPL_LINK_NOARG(TPGalleryThemeProperties, DClickFoundHdl, ListBox&, void)
     {
         aPreviewTimer.Stop();
 
-        if (m_pLbxFound->GetSelectEntryCount() == 1 && bEntriesFound)
+        if (m_pLbxFound->GetSelectedEntryCount() == 1 && bEntriesFound)
             ClickTakeHdl(nullptr);
     }
 }
@@ -1182,7 +1172,7 @@ IMPL_LINK_NOARG(TPGalleryThemeProperties, EndSearchProgressHdl, Dialog&, void)
   }
   else
   {
-      m_pLbxFound->InsertEntry( OUString( CuiResId( RID_SVXSTR_GALLERY_NOFILES ) ) );
+      m_pLbxFound->InsertEntry( CuiResId( RID_SVXSTR_GALLERY_NOFILES ) );
       m_pBtnTakeAll->Disable();
       m_pCbxPreview->Disable();
       bEntriesFound = false;
