@@ -18,7 +18,6 @@
  */
 
 #include <string>
-#include <tools/shl.hxx>
 #include <svl/intitem.hxx>
 #include <svl/eitem.hxx>
 #include <svl/stritem.hxx>
@@ -26,29 +25,30 @@
 #include <vcl/toolbox.hxx>
 #include <vcl/fixed.hxx>
 #include <dialmgr.hxx>
-#include <cuires.hrc>
-#include "cuitbxform.hxx"
+#include <cuitbxform.hxx>
 #include <sfx2/viewfrm.hxx>
 #include <sfx2/viewsh.hxx>
-#include "fmsearch.hrc"
 
-//========================================================================
-// class FmInputRecordNoDialog
-//========================================================================
-
-FmInputRecordNoDialog::FmInputRecordNoDialog(Window * pParent)
-    :ModalDialog( pParent, CUI_RES(RID_SVX_DLG_INPUTRECORDNO))
-    ,m_aLabel(this, CUI_RES(1))
-    ,m_aRecordNo(this, CUI_RES(1))
-    ,m_aOk(this, CUI_RES(1))
-    ,m_aCancel(this, CUI_RES(1))
+FmInputRecordNoDialog::FmInputRecordNoDialog(vcl::Window * pParent)
+    : ModalDialog( pParent, "RecordNumberDialog", "cui/ui/recordnumberdialog.ui")
 {
-    m_aRecordNo.SetMin(1);
-    m_aRecordNo.SetMax(0x7FFFFFFF);
-    m_aRecordNo.SetStrictFormat(sal_True);
-    m_aRecordNo.SetDecimalDigits(0);
+    get(m_pRecordNo, "entry-nospin");
 
-    FreeResource();
+    m_pRecordNo->SetMin(1);
+    m_pRecordNo->SetMax(0x7FFFFFFF);
+    m_pRecordNo->SetStrictFormat(true);
+    m_pRecordNo->SetDecimalDigits(0);
+}
+
+FmInputRecordNoDialog::~FmInputRecordNoDialog()
+{
+    disposeOnce();
+}
+
+void FmInputRecordNoDialog::dispose()
+{
+    m_pRecordNo.clear();
+    ModalDialog::dispose();
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
