@@ -17,9 +17,7 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include <com/sun/star/frame/XDispatchProvider.hpp>
 #include <com/sun/star/util/XURLTransformer.hpp>
-#include <com/sun/star/frame/FrameSearchFlag.hpp>
 #include <sfx2/request.hxx>
 
 #include <comphelper/processfactory.hxx>
@@ -27,8 +25,8 @@
 #include <unotools/pathoptions.hxx>
 #include <unotools/moduleoptions.hxx>
 
-#include "hlmailtp.hxx"
-#include "bitmaps.hlst"
+#include <hlmailtp.hxx>
+#include <bitmaps.hlst>
 
 using namespace ::com::sun::star;
 
@@ -225,7 +223,7 @@ void SvxHyperlinkMailTp::RemoveImproperProtocol(const OUString& aProperScheme)
 
 /*************************************************************************
 |*
-|* Contens of editfield "receiver" modified
+|* Contents of editfield "receiver" modified
 |*
 |************************************************************************/
 
