@@ -17,10 +17,10 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "screenshotannotationdlg.hxx"
+#include <screenshotannotationdlg.hxx>
 
-#include "cuires.hrc"
-#include "dialmgr.hxx"
+#include <strings.hrc>
+#include <dialmgr.hxx>
 
 #include <basegfx/range/b2irange.hxx>
 #include <cppuhelper/bootstrap.hxx>
@@ -54,7 +54,7 @@ namespace
 
     OUString lcl_AltDescr()
     {
-        OUString aTempl = OUString("<alt xml-lang=\"en-US\" id=\"%1\">"
+        OUString aTempl = OUString("<alt id=\"%1\">"
                                    " " //FIXME real dialog title or something
                                   "</alt>");
         aTempl = aTempl.replaceFirst( "%1", lcl_genRandom("alt_id") );
@@ -79,7 +79,7 @@ namespace
 
     OUString lcl_ParagraphWithImage( const OUString& rScreenshotId, const Size& rSize )
     {
-        OUString aTempl = OUString( "<paragraph id=\"%1\" role=\"paragraph\" xml-lang=\"en-US\">%2"
+        OUString aTempl = OUString( "<paragraph id=\"%1\" role=\"paragraph\">%2"
                                     "</paragraph>"  SAL_NEWLINE_STRING );
         aTempl = aTempl.replaceFirst( "%1", lcl_genRandom("par_id") );
         aTempl = aTempl.replaceFirst( "%2", lcl_Image(rScreenshotId, rSize) );
@@ -90,7 +90,7 @@ namespace
     OUString lcl_Bookmark( const OUString& rWidgetId )
     {
         OUString aTempl = "<!-- Bookmark for widget %1 -->" SAL_NEWLINE_STRING
-                          "<bookmark xml-lang=\"en-US\" branch=\"hid/%2\" id=\"%3\" localize=\"false\"/>" SAL_NEWLINE_STRING;
+                          "<bookmark branch=\"hid/%2\" id=\"%3\" localize=\"false\"/>" SAL_NEWLINE_STRING;
         aTempl = aTempl.replaceFirst( "%1", rWidgetId );
         aTempl = aTempl.replaceFirst( "%2", rWidgetId );
         aTempl = aTempl.replaceFirst( "%3", lcl_genRandom("bm_id") );
@@ -265,7 +265,7 @@ ScreenshotAnnotationDlg_Impl::ScreenshotAnnotationDlg_Impl(
         mpText->set_width_request(400);
         mpText->set_height_request( mpText->GetTextHeight() * 10 );
         OUString aHelpId = OStringToOUString( mrParentDialog.GetHelpId(), RTL_TEXTENCODING_UTF8 );
-        Size aSizeCm = mrParentDialog.PixelToLogic( maParentDialogSize, MapUnit::MapCM );
+        Size aSizeCm = mrParentDialog.PixelToLogic(maParentDialogSize, MapMode(MapUnit::MapCM));
         maMainMarkupText = lcl_ParagraphWithImage( aHelpId, aSizeCm );
         mpText->SetText( maMainMarkupText );
         mpText->SetReadOnly();
@@ -292,7 +292,7 @@ void ScreenshotAnnotationDlg_Impl::CollectChildren(
 
         if (!aCurrentRange.isEmpty())
         {
-            rControlDataCollection.push_back(ControlDataEntry(rCurrent, aCurrentRange));
+            rControlDataCollection.emplace_back(rCurrent, aCurrentRange);
         }
 
         for (sal_uInt16 a(0); a < rCurrent.GetChildCount(); a++)
@@ -312,10 +312,8 @@ ScreenshotAnnotationDlg_Impl::~ScreenshotAnnotationDlg_Impl()
     mpVirtualBufferDevice.disposeAndClear();
 }
 
-IMPL_LINK(ScreenshotAnnotationDlg_Impl, saveButtonHandler, Button*, pButton, void)
+IMPL_LINK_NOARG(ScreenshotAnnotationDlg_Impl, saveButtonHandler, Button*, void)
 {
-    (void)pButton;
-
     // 'save screenshot...' pressed, offer to save maParentDialogBitmap
     // as PNG image, use *.id file name as screenshot file name offering
     OString aDerivedFileName;
@@ -366,7 +364,7 @@ IMPL_LINK(ScreenshotAnnotationDlg_Impl, saveButtonHandler, Button*, pButton, voi
                 INetURLObject aConfirmedURL(aConfirmedName);
                 OUString aCurrentExtension(aConfirmedURL.getExtension());
 
-                if (!aCurrentExtension.isEmpty() && 0 != aCurrentExtension.compareTo("png"))
+                if (!aCurrentExtension.isEmpty() && aCurrentExtension != "png")
                 {
                     aConfirmedURL.removeExtension();
                     aCurrentExtension.clear();
@@ -448,7 +446,7 @@ void ScreenshotAnnotationDlg_Impl::PaintControlDataEntry(
         // createPolygonFromRect is relative [0.0 .. 1.0]
         static double fEdgeRoundPixel(8.0);
         const basegfx::B2DPolygon aPolygon(
-            basegfx::tools::createPolygonFromRect(
+            basegfx::utils::createPolygonFromRect(
             aB2DRange,
             fEdgeRoundPixel / aB2DRange.getWidth(),
             fEdgeRoundPixel / aB2DRange.getHeight()));
