@@ -18,22 +18,12 @@
  */
 
 #include <dialmgr.hxx>
-#include <svl/solar.hrc>
-#include <tools/resmgr.hxx>
-#include <vcl/svapp.hxx>
-#include <vcl/settings.hxx>
+#include <unotools/resmgr.hxx>
 
-// struct DialogsResMgr --------------------------------------------------
-ResMgr* CuiResMgr::GetResMgr()
+OUString CuiResId(const char *pKey)
 {
-    static ResMgr* pResMgr=nullptr;
-
-    if ( !pResMgr )
-    {
-        pResMgr = ResMgr::CreateResMgr("cui", Application::GetSettings().GetUILanguageTag());
-    }
-
-    return pResMgr;
+    static std::locale loc(Translate::Create("cui"));
+    return Translate::get(pKey, loc);
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
