@@ -21,12 +21,12 @@
 #include <unotools/moduleoptions.hxx>
 #include <unotools/fltrcfg.hxx>
 #include "optfltr.hxx"
-#include <cuires.hrc>
-#include "helpid.hrc"
+#include <helpids.h>
+#include <strings.hrc>
 #include <dialmgr.hxx>
 
-#include "svtools/svlbitm.hxx"
-#include "svtools/treelistentry.hxx"
+#include <svtools/svlbitm.hxx>
+#include <svtools/treelistentry.hxx>
 
 enum MSFltrPg2_CheckBoxEntries {
     Math,
@@ -73,12 +73,12 @@ void OfaMSFilterTabPage::dispose()
 }
 
 
-IMPL_LINK_NOARG_TYPED(OfaMSFilterTabPage, LoadWordBasicCheckHdl_Impl, Button*, void)
+IMPL_LINK_NOARG(OfaMSFilterTabPage, LoadWordBasicCheckHdl_Impl, Button*, void)
 {
     aWBasicWbctblCB->Enable( aWBasicCodeCB->IsChecked() );
 }
 
-IMPL_LINK_NOARG_TYPED(OfaMSFilterTabPage, LoadExcelBasicCheckHdl_Impl, Button*, void)
+IMPL_LINK_NOARG(OfaMSFilterTabPage, LoadExcelBasicCheckHdl_Impl, Button*, void)
 {
     aEBasicExectblCB->Enable( aEBasicCodeCB->IsChecked() );
 }
@@ -143,14 +143,13 @@ void OfaMSFilterTabPage::Reset( const SfxItemSet* )
 
 OfaMSFilterTabPage2::OfaMSFilterTabPage2( vcl::Window* pParent, const SfxItemSet& rSet ) :
     SfxTabPage( pParent, "OptFilterPage", "cui/ui/optfltrembedpage.ui", &rSet ),
-    sHeader1(CUI_RES(RID_SVXSTR_HEADER1)),
-    sHeader2(CUI_RES(RID_SVXSTR_HEADER2)),
-    sChgToFromMath(CUI_RES(RID_SVXSTR_CHG_MATH)),
-    sChgToFromWriter(CUI_RES(RID_SVXSTR_CHG_WRITER)),
-    sChgToFromCalc(CUI_RES(RID_SVXSTR_CHG_CALC)),
-    sChgToFromImpress(CUI_RES(RID_SVXSTR_CHG_IMPRESS)),
-    sChgToFromSmartArt(CUI_RES(RID_SVXSTR_CHG_SMARTART)),
-    pCheckButtonData(nullptr)
+    sHeader1(CuiResId(RID_SVXSTR_HEADER1)),
+    sHeader2(CuiResId(RID_SVXSTR_HEADER2)),
+    sChgToFromMath(CuiResId(RID_SVXSTR_CHG_MATH)),
+    sChgToFromWriter(CuiResId(RID_SVXSTR_CHG_WRITER)),
+    sChgToFromCalc(CuiResId(RID_SVXSTR_CHG_CALC)),
+    sChgToFromImpress(CuiResId(RID_SVXSTR_CHG_IMPRESS)),
+    sChgToFromSmartArt(CuiResId(RID_SVXSTR_CHG_SMARTART))
 {
     get(m_pCheckLBContainer, "checklbcontainer");
 
@@ -158,7 +157,7 @@ OfaMSFilterTabPage2::OfaMSFilterTabPage2( vcl::Window* pParent, const SfxItemSet
     get( aShadingRB,      "shading"     );
 
     Size aControlSize(248, 55);
-    aControlSize = LogicToPixel(aControlSize, MAP_APPFONT);
+    aControlSize = LogicToPixel(aControlSize, MapMode(MapUnit::MapAppFont));
     m_pCheckLBContainer->set_width_request(aControlSize.Width());
     m_pCheckLBContainer->set_height_request(aControlSize.Height());
 
@@ -181,8 +180,7 @@ OfaMSFilterTabPage2::~OfaMSFilterTabPage2()
 
 void OfaMSFilterTabPage2::dispose()
 {
-    delete pCheckButtonData;
-    pCheckButtonData = nullptr;
+    m_xCheckButtonData.reset();
     m_pCheckLB.disposeAndClear();
     m_pCheckLBContainer.clear();
     aHighlightingRB.clear();
@@ -236,7 +234,7 @@ bool OfaMSFilterTabPage2::FillItemSet( SfxItemSet* )
         if( pEntry )
         {
             SvLBoxButton& rItem = static_cast<SvLBoxButton&>(pEntry->GetItem( nCol ));
-            if (rItem.GetType() == SV_ITEM_ID_LBOXBUTTON)
+            if (rItem.GetType() == SvLBoxItemType::Button)
             {
                 SvItemStateFlags nButtonFlags = rItem.GetButtonFlags();
                 bCheck = SvButtonState::Checked ==
@@ -304,7 +302,7 @@ void OfaMSFilterTabPage2::Reset( const SfxItemSet* )
         if( pEntry )
         {
             SvLBoxButton& rItem = static_cast<SvLBoxButton&>(pEntry->GetItem( nCol ));
-            if (rItem.GetType() == SV_ITEM_ID_LBOXBUTTON)
+            if (rItem.GetType() == SvLBoxItemType::Button)
             {
                 if( (rOpt.*pArr->FnIs)() )
                     rItem.SetStateChecked();
@@ -334,18 +332,18 @@ void OfaMSFilterTabPage2::InsertEntry( const OUString& _rTxt, sal_IntPtr _nType,
 {
     SvTreeListEntry* pEntry = new SvTreeListEntry;
 
-    if( !pCheckButtonData )
-        pCheckButtonData = new SvLBoxButtonData( m_pCheckLB );
+    if (!m_xCheckButtonData)
+        m_xCheckButtonData.reset(new SvLBoxButtonData(m_pCheckLB));
 
     pEntry->AddItem(o3tl::make_unique<SvLBoxContextBmp>(
         Image(), Image(), false));
     pEntry->AddItem(o3tl::make_unique<SvLBoxButton>(
         SvLBoxButtonKind::EnabledCheckbox,
-               pCheckButtonData));
+               m_xCheckButtonData.get()));
     pEntry->AddItem(o3tl::make_unique<SvLBoxButton>(
         saveEnabled ? SvLBoxButtonKind::EnabledCheckbox
                                      : SvLBoxButtonKind::DisabledCheckbox,
-               pCheckButtonData));
+               m_xCheckButtonData.get()));
     pEntry->AddItem(o3tl::make_unique<SvLBoxString>(_rTxt));
 
     pEntry->SetUserData( reinterpret_cast<void*>(_nType) );
@@ -393,7 +391,7 @@ void OfaMSFilterTabPage2::MSFltrSimpleTable::SetCheckButtonState(
 {
     SvLBoxButton& rItem = static_cast<SvLBoxButton&>(pEntry->GetItem(nCol + 1));
 
-    if (rItem.GetType() == SV_ITEM_ID_LBOXBUTTON)
+    if (rItem.GetType() == SvLBoxItemType::Button)
     {
         switch( eState )
         {
@@ -419,7 +417,7 @@ SvButtonState OfaMSFilterTabPage2::MSFltrSimpleTable::GetCheckButtonState(
     SvButtonState eState = SvButtonState::Unchecked;
     SvLBoxButton& rItem = static_cast<SvLBoxButton&>(pEntry->GetItem(nCol + 1));
 
-    if (rItem.GetType() == SV_ITEM_ID_LBOXBUTTON)
+    if (rItem.GetType() == SvLBoxItemType::Button)
     {
         SvItemStateFlags nButtonFlags = rItem.GetButtonFlags();
         eState = SvLBoxButtonData::ConvertToButtonState( nButtonFlags );
@@ -449,7 +447,7 @@ void OfaMSFilterTabPage2::MSFltrSimpleTable::KeyInput( const KeyEvent& rKEvt )
             SvTreeListEntry* pEntry = GetEntry( nSelPos );
             bool bIsChecked = ( GetCheckButtonState( pEntry, nCol ) == SvButtonState::Checked );
             CheckEntryPos( nSelPos, nCol, !bIsChecked );
-            CallImplEventListeners( VCLEVENT_CHECKBOX_TOGGLE, static_cast<void*>(pEntry) );
+            CallImplEventListeners( VclEventId::CheckboxToggle, static_cast<void*>(pEntry) );
         }
         else
         {
