@@ -43,18 +43,17 @@
 #include <sfx2/viewfrm.hxx>
 #include <unotools/pathoptions.hxx>
 #include <unotools/securityoptions.hxx>
-#include <unotools/localfilehelper.hxx>
 #include <unotools/extendedsecurityoptions.hxx>
 #include <com/sun/star/uno/Sequence.hxx>
 
 #include <dialmgr.hxx>
 #include "optinet2.hxx"
 #include <svx/svxdlg.hxx>
-#include <cuires.hrc>
-#include "helpid.hrc"
+#include <helpids.h>
 #include <svx/ofaitem.hxx>
 #include <sfx2/htmlmode.hxx>
 #include <svx/svxids.hrc>
+#include <strings.hrc>
 
 #include <com/sun/star/security/DocumentDigitalSignatures.hpp>
 
@@ -84,22 +83,23 @@
 #include <comphelper/processfactory.hxx>
 #include <comphelper/string.hxx>
 
-#include "com/sun/star/ui/dialogs/TemplateDescription.hpp"
-#include "com/sun/star/task/PasswordContainer.hpp"
-#include "com/sun/star/task/XPasswordContainer2.hpp"
+#include <com/sun/star/ui/dialogs/TemplateDescription.hpp>
+#include <com/sun/star/task/PasswordContainer.hpp>
+#include <com/sun/star/task/XPasswordContainer2.hpp>
 #include "securityoptions.hxx"
 #include "webconninfo.hxx"
 #include "certpath.hxx"
 #include "tsaurls.hxx"
 
+#include <svtools/restartdialog.hxx>
+#include <comphelper/solarmutex.hxx>
+
 using namespace ::com::sun::star;
 using namespace ::com::sun::star::uno;
 using namespace ::sfx2;
 
 // static ----------------------------------------------------------------
 
-#include <sal/config.h>
-
 VCL_BUILDER_FACTORY_ARGS(SvxNoSpaceEdit, WB_LEFT|WB_VCENTER|WB_BORDER|WB_3DLOOK)
 
 void SvxNoSpaceEdit::KeyInput( const KeyEvent& rKEvent )
@@ -114,7 +114,7 @@ void SvxNoSpaceEdit::KeyInput( const KeyEvent& rKEvent )
                  ( KEYGROUP_MISC == nGroup && ( nKey < KEY_ADD || nKey > KEY_EQUAL ) ) );
         if ( !bValid && ( rKeyCode.IsMod1() && (
              KEY_A == nKey || KEY_C == nKey || KEY_V == nKey || KEY_X == nKey || KEY_Z == nKey ) ) )
-            // Erase, Copy, Paste, Select All und Undo soll funktionieren
+            // Erase, Copy, Paste, Select All and Undo should work
             bValid = true;
     }
     if (bValid)
@@ -122,7 +122,6 @@ void SvxNoSpaceEdit::KeyInput( const KeyEvent& rKEvent )
 }
 
 
-
 void SvxNoSpaceEdit::Modify()
 {
     Edit::Modify();
@@ -133,11 +132,11 @@ void SvxNoSpaceEdit::Modify()
 
         if ( !comphelper::string::isdigitAsciiString(aValue) || (long)aValue.toInt32() > USHRT_MAX )
             // the maximum value of a port number is USHRT_MAX
-            ScopedVclPtrInstance<MessageDialog>::Create( this, CUI_RES( RID_SVXSTR_OPT_PROXYPORTS ) )->Execute();
+            ScopedVclPtrInstance<MessageDialog>(this, CuiResId( RID_SVXSTR_OPT_PROXYPORTS))->Execute();
     }
 }
 
-bool SvxNoSpaceEdit::set_property(const OString &rKey, const OString &rValue)
+bool SvxNoSpaceEdit::set_property(const OString &rKey, const OUString &rValue)
 {
     if (rKey == "only-numeric")
         bOnlyNumeric = toBool(rValue);
@@ -147,6 +146,15 @@ bool SvxNoSpaceEdit::set_property(const OString &rKey, const OString &rValue)
 }
 
 
+static const char g_aProxyModePN[] = "ooInetProxyType";
+static const char g_aHttpProxyPN[] = "ooInetHTTPProxyName";
+static const char g_aHttpPortPN[] = "ooInetHTTPProxyPort";
+static const char g_aHttpsProxyPN[] = "ooInetHTTPSProxyName";
+static const char g_aHttpsPortPN[] = "ooInetHTTPSProxyPort";
+static const char g_aFtpProxyPN[] = "ooInetFTPProxyName";
+static const char g_aFtpPortPN[] = "ooInetFTPProxyPort";
+static const char g_aNoProxyDescPN[] = "ooInetNoProxy";
+
 /********************************************************************/
 /*                                                                  */
 /*  SvxProxyTabPage                                                 */
@@ -155,14 +163,6 @@ bool SvxNoSpaceEdit::set_property(const OString &rKey, const OString &rValue)
 
 SvxProxyTabPage::SvxProxyTabPage(vcl::Window* pParent, const SfxItemSet& rSet)
     : SfxTabPage(pParent, "OptProxyPage","cui/ui/optproxypage.ui", &rSet)
-    , aProxyModePN("ooInetProxyType")
-    , aHttpProxyPN("ooInetHTTPProxyName")
-    , aHttpPortPN("ooInetHTTPProxyPort")
-    , aHttpsProxyPN("ooInetHTTPSProxyName")
-    , aHttpsPortPN("ooInetHTTPSProxyPort")
-    , aFtpProxyPN("ooInetFTPProxyName")
-    , aFtpPortPN("ooInetFTPProxyPort")
-    , aNoProxyDescPN("ooInetNoProxy")
 {
     get(m_pProxyModeLB, "proxymode");
 
@@ -185,29 +185,27 @@ SvxProxyTabPage::SvxProxyTabPage(vcl::Window* pParent, const SfxItemSet& rSet)
     get(m_pNoProxyForED, "noproxy");
     get(m_pNoProxyDescFT, "noproxydesc");
 
-    Link<> aLink = LINK( this, SvxProxyTabPage, LoseFocusHdl_Impl );
+    Link<Control&,void> aLink = LINK( this, SvxProxyTabPage, LoseFocusHdl_Impl );
     m_pHttpPortED->SetLoseFocusHdl( aLink );
     m_pHttpsPortED->SetLoseFocusHdl( aLink );
     m_pFtpPortED->SetLoseFocusHdl( aLink );
 
     m_pProxyModeLB->SetSelectHdl(LINK( this, SvxProxyTabPage, ProxyHdl_Impl ));
 
-    Reference< com::sun::star::lang::XMultiServiceFactory >
+    Reference< css::lang::XMultiServiceFactory >
         xConfigurationProvider(
             configuration::theDefaultProvider::get(
                 comphelper::getProcessComponentContext() ) );
 
-    OUString aConfigRoot( "org.openoffice.Inet/Settings" );
-
     beans::NamedValue aProperty;
     aProperty.Name  = "nodepath";
-    aProperty.Value = makeAny( aConfigRoot );
+    aProperty.Value <<= OUString( "org.openoffice.Inet/Settings" );
 
     Sequence< Any > aArgumentList( 1 );
-    aArgumentList[0] = makeAny( aProperty );
+    aArgumentList[0] <<= aProperty;
 
     m_xConfigurationUpdateAccess = xConfigurationProvider->createInstanceWithArguments(
-        OUString( "com.sun.star.configuration.ConfigurationUpdateAccess" ),
+        "com.sun.star.configuration.ConfigurationUpdateAccess",
         aArgumentList );
 }
 
@@ -250,59 +248,55 @@ void SvxProxyTabPage::ReadConfigData_Impl()
         sal_Int32 nIntValue = 0;
         OUString  aStringValue;
 
-        if( xNameAccess->getByName(aProxyModePN) >>= nIntValue )
+        if( xNameAccess->getByName(g_aProxyModePN) >>= nIntValue )
         {
             m_pProxyModeLB->SelectEntryPos( nIntValue );
         }
 
-        if( xNameAccess->getByName(aHttpProxyPN) >>= aStringValue )
+        if( xNameAccess->getByName(g_aHttpProxyPN) >>= aStringValue )
         {
             m_pHttpProxyED->SetText( aStringValue );
         }
 
-        if( xNameAccess->getByName(aHttpPortPN) >>= nIntValue )
+        if( xNameAccess->getByName(g_aHttpPortPN) >>= nIntValue )
         {
             m_pHttpPortED->SetText( OUString::number( nIntValue ));
         }
 
-        if( xNameAccess->getByName(aHttpsProxyPN) >>= aStringValue )
+        if( xNameAccess->getByName(g_aHttpsProxyPN) >>= aStringValue )
         {
             m_pHttpsProxyED->SetText( aStringValue );
         }
 
-        if( xNameAccess->getByName(aHttpsPortPN) >>= nIntValue )
+        if( xNameAccess->getByName(g_aHttpsPortPN) >>= nIntValue )
         {
             m_pHttpsPortED->SetText( OUString::number( nIntValue ));
         }
 
-        if( xNameAccess->getByName(aFtpProxyPN) >>= aStringValue )
+        if( xNameAccess->getByName(g_aFtpProxyPN) >>= aStringValue )
         {
             m_pFtpProxyED->SetText( aStringValue );
         }
 
-        if( xNameAccess->getByName(aFtpPortPN) >>= nIntValue )
+        if( xNameAccess->getByName(g_aFtpPortPN) >>= nIntValue )
         {
             m_pFtpPortED->SetText( OUString::number( nIntValue ));
         }
 
-        if( xNameAccess->getByName(aNoProxyDescPN) >>= aStringValue )
+        if( xNameAccess->getByName(g_aNoProxyDescPN) >>= aStringValue )
         {
             m_pNoProxyForED->SetText( aStringValue );
         }
     }
-
     catch (const container::NoSuchElementException&) {
-        OSL_TRACE( "SvxProxyTabPage::ReadConfigData_Impl: NoSuchElementException caught" );
+        SAL_WARN("cui.options", "SvxProxyTabPage::ReadConfigData_Impl: NoSuchElementException caught" );
     }
-
-    catch (const com::sun::star::lang::WrappedTargetException &) {
-        OSL_TRACE( "SvxProxyTabPage::ReadConfigData_Impl: WrappedTargetException caught" );
+    catch (const css::lang::WrappedTargetException &) {
+        SAL_WARN("cui.options", "SvxProxyTabPage::ReadConfigData_Impl: WrappedTargetException caught" );
     }
-
     catch (const RuntimeException &) {
-        OSL_TRACE( "SvxProxyTabPage::ReadConfigData_Impl: RuntimeException caught" );
+        SAL_WARN("cui.options", "SvxProxyTabPage::ReadConfigData_Impl: RuntimeException caught" );
     }
-
 }
 
 void SvxProxyTabPage::ReadConfigDefaults_Impl()
@@ -314,53 +308,51 @@ void SvxProxyTabPage::ReadConfigDefaults_Impl()
         sal_Int32 nIntValue = 0;
         OUString  aStringValue;
 
-        if( xPropertyState->getPropertyDefault(aHttpProxyPN) >>= aStringValue )
+        if( xPropertyState->getPropertyDefault(g_aHttpProxyPN) >>= aStringValue )
         {
             m_pHttpProxyED->SetText( aStringValue );
         }
 
-        if( xPropertyState->getPropertyDefault(aHttpPortPN) >>= nIntValue )
+        if( xPropertyState->getPropertyDefault(g_aHttpPortPN) >>= nIntValue )
         {
             m_pHttpPortED->SetText( OUString::number( nIntValue ));
         }
 
-        if( xPropertyState->getPropertyDefault(aHttpsProxyPN) >>= aStringValue )
+        if( xPropertyState->getPropertyDefault(g_aHttpsProxyPN) >>= aStringValue )
         {
             m_pHttpsProxyED->SetText( aStringValue );
         }
 
-        if( xPropertyState->getPropertyDefault(aHttpsPortPN) >>= nIntValue )
+        if( xPropertyState->getPropertyDefault(g_aHttpsPortPN) >>= nIntValue )
         {
             m_pHttpsPortED->SetText( OUString::number( nIntValue ));
         }
 
-        if( xPropertyState->getPropertyDefault(aFtpProxyPN) >>= aStringValue )
+        if( xPropertyState->getPropertyDefault(g_aFtpProxyPN) >>= aStringValue )
         {
             m_pFtpProxyED->SetText( aStringValue );
         }
 
-        if( xPropertyState->getPropertyDefault(aFtpPortPN) >>= nIntValue )
+        if( xPropertyState->getPropertyDefault(g_aFtpPortPN) >>= nIntValue )
         {
             m_pFtpPortED->SetText( OUString::number( nIntValue ));
         }
 
-        if( xPropertyState->getPropertyDefault(aNoProxyDescPN) >>= aStringValue )
+        if( xPropertyState->getPropertyDefault(g_aNoProxyDescPN) >>= aStringValue )
         {
             m_pNoProxyForED->SetText( aStringValue );
         }
     }
     catch (const beans::UnknownPropertyException &)
     {
-        OSL_TRACE( "SvxProxyTabPage::RestoreConfigDefaults_Impl: UnknownPropertyException caught" );
+        SAL_WARN("cui.options", "SvxProxyTabPage::RestoreConfigDefaults_Impl: UnknownPropertyException caught" );
     }
-
-    catch (const com::sun::star::lang::WrappedTargetException &) {
-        OSL_TRACE( "SvxProxyTabPage::RestoreConfigDefaults_Impl: WrappedTargetException caught" );
+    catch (const css::lang::WrappedTargetException &) {
+        SAL_WARN("cui.options", "SvxProxyTabPage::RestoreConfigDefaults_Impl: WrappedTargetException caught" );
     }
-
     catch (const RuntimeException &)
     {
-        OSL_TRACE( "SvxProxyTabPage::RestoreConfigDefaults_Impl: RuntimeException caught" );
+        SAL_WARN("cui.options", "SvxProxyTabPage::RestoreConfigDefaults_Impl: RuntimeException caught" );
     }
 }
 
@@ -370,31 +362,28 @@ void SvxProxyTabPage::RestoreConfigDefaults_Impl()
     {
         Reference< beans::XPropertyState > xPropertyState(m_xConfigurationUpdateAccess, UNO_QUERY_THROW);
 
-        xPropertyState->setPropertyToDefault(aProxyModePN);
-        xPropertyState->setPropertyToDefault(aHttpProxyPN);
-        xPropertyState->setPropertyToDefault(aHttpPortPN);
-        xPropertyState->setPropertyToDefault(aHttpsProxyPN);
-        xPropertyState->setPropertyToDefault(aHttpsPortPN);
-        xPropertyState->setPropertyToDefault(aFtpProxyPN);
-        xPropertyState->setPropertyToDefault(aFtpPortPN);
-        xPropertyState->setPropertyToDefault(aNoProxyDescPN);
+        xPropertyState->setPropertyToDefault(g_aProxyModePN);
+        xPropertyState->setPropertyToDefault(g_aHttpProxyPN);
+        xPropertyState->setPropertyToDefault(g_aHttpPortPN);
+        xPropertyState->setPropertyToDefault(g_aHttpsProxyPN);
+        xPropertyState->setPropertyToDefault(g_aHttpsPortPN);
+        xPropertyState->setPropertyToDefault(g_aFtpProxyPN);
+        xPropertyState->setPropertyToDefault(g_aFtpPortPN);
+        xPropertyState->setPropertyToDefault(g_aNoProxyDescPN);
 
         Reference< util::XChangesBatch > xChangesBatch(m_xConfigurationUpdateAccess, UNO_QUERY_THROW);
         xChangesBatch->commitChanges();
     }
-
     catch (const beans::UnknownPropertyException &)
     {
-        OSL_TRACE( "SvxProxyTabPage::RestoreConfigDefaults_Impl: UnknownPropertyException caught" );
+        SAL_WARN("cui.options", "SvxProxyTabPage::RestoreConfigDefaults_Impl: UnknownPropertyException caught" );
     }
-
-    catch (const com::sun::star::lang::WrappedTargetException &) {
-        OSL_TRACE( "SvxProxyTabPage::RestoreConfigDefaults_Impl: WrappedTargetException caught" );
+    catch (const css::lang::WrappedTargetException &) {
+        SAL_WARN("cui.options", "SvxProxyTabPage::RestoreConfigDefaults_Impl: WrappedTargetException caught" );
     }
-
     catch (const RuntimeException &)
     {
-        OSL_TRACE( "SvxProxyTabPage::RestoreConfigDefaults_Impl: RuntimeException caught" );
+        SAL_WARN("cui.options", "SvxProxyTabPage::RestoreConfigDefaults_Impl: RuntimeException caught" );
     }
 }
 
@@ -411,7 +400,7 @@ void SvxProxyTabPage::Reset(const SfxItemSet*)
     m_pFtpPortED->SaveValue();
     m_pNoProxyForED->SaveValue();
 
-    EnableControls_Impl( m_pProxyModeLB->GetSelectEntryPos() == 2 );
+    EnableControls_Impl( m_pProxyModeLB->GetSelectedEntryPos() == 2 );
 }
 
 bool SvxProxyTabPage::FillItemSet(SfxItemSet* )
@@ -421,7 +410,7 @@ bool SvxProxyTabPage::FillItemSet(SfxItemSet* )
     try {
         Reference< beans::XPropertySet > xPropertySet(m_xConfigurationUpdateAccess, UNO_QUERY_THROW );
 
-        sal_Int32 nSelPos = m_pProxyModeLB->GetSelectEntryPos();
+        sal_Int32 nSelPos = m_pProxyModeLB->GetSelectedEntryPos();
         if(m_pProxyModeLB->IsValueChangedFromSaved())
         {
             if( nSelPos == 1 )
@@ -430,75 +419,69 @@ bool SvxProxyTabPage::FillItemSet(SfxItemSet* )
                 return true;
             }
 
-            xPropertySet->setPropertyValue(aProxyModePN,
-                makeAny((sal_Int32) nSelPos));
+            xPropertySet->setPropertyValue(g_aProxyModePN, Any(nSelPos));
             bModified = true;
         }
 
         if(m_pHttpProxyED->IsValueChangedFromSaved())
         {
-            xPropertySet->setPropertyValue( aHttpProxyPN, makeAny(m_pHttpProxyED->GetText()));
+            xPropertySet->setPropertyValue( g_aHttpProxyPN, Any(m_pHttpProxyED->GetText()));
             bModified = true;
         }
 
         if ( m_pHttpPortED->IsValueChangedFromSaved())
         {
-            xPropertySet->setPropertyValue( aHttpPortPN, makeAny(m_pHttpPortED->GetText().toInt32()));
+            xPropertySet->setPropertyValue( g_aHttpPortPN, Any(m_pHttpPortED->GetText().toInt32()));
             bModified = true;
         }
 
         if( m_pHttpsProxyED->IsValueChangedFromSaved() )
         {
-            xPropertySet->setPropertyValue( aHttpsProxyPN, makeAny(m_pHttpsProxyED->GetText()) );
+            xPropertySet->setPropertyValue( g_aHttpsProxyPN, Any(m_pHttpsProxyED->GetText()) );
             bModified = true;
         }
 
         if ( m_pHttpsPortED->IsValueChangedFromSaved() )
         {
-            xPropertySet->setPropertyValue( aHttpsPortPN, makeAny(m_pHttpsPortED->GetText().toInt32()) );
+            xPropertySet->setPropertyValue( g_aHttpsPortPN, Any(m_pHttpsPortED->GetText().toInt32()) );
             bModified = true;
         }
 
         if( m_pFtpProxyED->IsValueChangedFromSaved())
         {
-            xPropertySet->setPropertyValue( aFtpProxyPN, makeAny(m_pFtpProxyED->GetText()) );
+            xPropertySet->setPropertyValue( g_aFtpProxyPN, Any(m_pFtpProxyED->GetText()) );
             bModified = true;
         }
 
         if ( m_pFtpPortED->IsValueChangedFromSaved() )
         {
-            xPropertySet->setPropertyValue( aFtpPortPN, makeAny(m_pFtpPortED->GetText().toInt32()));
+            xPropertySet->setPropertyValue( g_aFtpPortPN, Any(m_pFtpPortED->GetText().toInt32()));
             bModified = true;
         }
 
         if ( m_pNoProxyForED->IsValueChangedFromSaved() )
         {
-            xPropertySet->setPropertyValue( aNoProxyDescPN, makeAny( m_pNoProxyForED->GetText()));
+            xPropertySet->setPropertyValue( g_aNoProxyDescPN, Any( m_pNoProxyForED->GetText()));
             bModified = true;
         }
 
         Reference< util::XChangesBatch > xChangesBatch(m_xConfigurationUpdateAccess, UNO_QUERY_THROW);
         xChangesBatch->commitChanges();
     }
-
-    catch (const com::sun::star::lang::IllegalArgumentException &) {
-        OSL_TRACE( "SvxProxyTabPage::FillItemSet: IllegalArgumentException caught" );
+    catch (const css::lang::IllegalArgumentException &) {
+        SAL_WARN("cui.options", "SvxProxyTabPage::FillItemSet: IllegalArgumentException caught" );
     }
-
     catch (const beans::UnknownPropertyException &) {
-        OSL_TRACE( "SvxProxyTabPage::FillItemSet: UnknownPropertyException caught" );
+        SAL_WARN("cui.options", "SvxProxyTabPage::FillItemSet: UnknownPropertyException caught" );
     }
-
     catch (const beans::PropertyVetoException &) {
-        OSL_TRACE( "SvxProxyTabPage::FillItemSet: PropertyVetoException caught" );
+        SAL_WARN("cui.options", "SvxProxyTabPage::FillItemSet: PropertyVetoException caught" );
     }
-
-    catch (const com::sun::star::lang::WrappedTargetException &) {
-        OSL_TRACE( "SvxProxyTabPage::FillItemSet: WrappedTargetException caught" );
+    catch (const css::lang::WrappedTargetException &) {
+        SAL_WARN("cui.options", "SvxProxyTabPage::FillItemSet: WrappedTargetException caught" );
     }
-
     catch (const RuntimeException &) {
-        OSL_TRACE( "SvxProxyTabPage::FillItemSet: RuntimeException caught" );
+        SAL_WARN("cui.options", "SvxProxyTabPage::FillItemSet: RuntimeException caught" );
     }
 
     return bModified;
@@ -527,10 +510,9 @@ void SvxProxyTabPage::EnableControls_Impl(bool bEnable)
 }
 
 
-
-IMPL_LINK( SvxProxyTabPage, ProxyHdl_Impl, ListBox *, pBox )
+IMPL_LINK( SvxProxyTabPage, ProxyHdl_Impl, ListBox&, rBox, void )
 {
-    sal_Int32 nPos = pBox->GetSelectEntryPos();
+    sal_Int32 nPos = rBox.GetSelectedEntryPos();
 
     // Restore original system values
     if( nPos == 1 )
@@ -539,58 +521,20 @@ IMPL_LINK( SvxProxyTabPage, ProxyHdl_Impl, ListBox *, pBox )
     }
 
     EnableControls_Impl(nPos == 2);
-    return 0;
 }
 
 
-
-IMPL_STATIC_LINK( SvxProxyTabPage, LoseFocusHdl_Impl, Edit *, pEdit )
+IMPL_STATIC_LINK( SvxProxyTabPage, LoseFocusHdl_Impl, Control&, rControl, void )
 {
+    Edit* pEdit = static_cast<Edit*>(&rControl);
     OUString aValue = pEdit->GetText();
 
     if ( !comphelper::string::isdigitAsciiString(aValue) || (long)aValue.toInt32() > USHRT_MAX )
         pEdit->SetText( OUString('0') );
-    return 0;
 }
 
 
 
-//#98647#----------------------------------------------
-void SvxScriptExecListBox::RequestHelp( const HelpEvent& rHEvt )
-{   // try to show tips just like as on toolbars
-    sal_Int32 nPos=LISTBOX_ENTRY_NOTFOUND;
-    sal_Int32 nTop = GetTopEntry();
-    sal_uInt16 nCount = GetDisplayLineCount(); // Attention: Not GetLineCount()
-    Point aPt = ScreenToOutputPixel( rHEvt.GetMousePosPixel() );
-    Rectangle aItemRect;
-    if( nCount > 0 ) // if there're some entries, find it.
-         for( nPos = nTop ; nPos <= nTop+nCount-1 ; nPos++ ) {
-            aItemRect = GetBoundingRectangle(nPos);
-            if( aPt.Y() < aItemRect.Top() || aPt.Y() > aItemRect.Bottom() )
-                continue;
-            else
-                break;
-        }
-     else // if not, nothing happens.
-         return;
-     OUString aHelpText;
-     if( nPos <= nTop+nCount-1 ) // if find the matching entry, get its content.
-         aHelpText = GetEntry(nPos);
-    if( aHelpText.getLength() && GetTextWidth(aHelpText)<GetOutputSizePixel().Width() )
-        aHelpText.clear(); // if the entry is quite short, clear the helping tip content.
-    aItemRect = Rectangle(Point(0,0),GetSizePixel());
-    aPt = Point(OutputToScreenPixel( aItemRect.TopLeft() ));
-    aItemRect.Left()   = aPt.X();
-    aItemRect.Top()    = aPt.Y();
-    aPt = OutputToScreenPixel( aItemRect.BottomRight() );
-    aItemRect.Right()  = aPt.X();
-    aItemRect.Bottom() = aPt.Y();
-    if( rHEvt.GetMode() == HelpEventMode::BALLOON )
-        Help::ShowBalloon( this, aItemRect.Center(), aItemRect, aHelpText);
-    else
-        Help::ShowQuickHelp( this, aItemRect, aHelpText );
-}
-
 /********************************************************************/
 /*                                                                  */
 /*  SvxSecurityTabPage                                             */
@@ -600,8 +544,8 @@ void SvxScriptExecListBox::RequestHelp( const HelpEvent& rHEvt )
 SvxSecurityTabPage::SvxSecurityTabPage(vcl::Window* pParent, const SfxItemSet& rSet)
     : SfxTabPage(pParent, "OptSecurityPage", "cui/ui/optsecuritypage.ui", &rSet)
     , mpSecOptions(new SvtSecurityOptions)
-    , mpSecOptDlg(NULL)
-    , mpCertPathDlg(NULL)
+    , mpSecOptDlg(nullptr)
+    , mpCertPathDlg(nullptr)
 {
     get(m_pSecurityOptionsPB, "options");
     get(m_pSavePasswordsCB, "savepassword");
@@ -650,7 +594,7 @@ SvxSecurityTabPage::~SvxSecurityTabPage()
 void SvxSecurityTabPage::dispose()
 {
     delete mpSecOptions;
-    mpSecOptions = NULL;
+    mpSecOptions = nullptr;
     mpCertPathDlg.disposeAndClear();
     mpSecOptDlg.clear();
     m_pSecurityOptionsPB.clear();
@@ -669,15 +613,14 @@ void SvxSecurityTabPage::dispose()
     SfxTabPage::dispose();
 }
 
-IMPL_LINK_NOARG(SvxSecurityTabPage, SecurityOptionsHdl)
+IMPL_LINK_NOARG(SvxSecurityTabPage, SecurityOptionsHdl, Button*, void)
 {
     if ( !mpSecOptDlg )
         mpSecOptDlg = VclPtr<svx::SecurityOptionsDialog>::Create( this, mpSecOptions );
     mpSecOptDlg->Execute();
-    return 0;
 }
 
-IMPL_LINK_NOARG(SvxSecurityTabPage, SavePasswordHdl)
+IMPL_LINK_NOARG(SvxSecurityTabPage, SavePasswordHdl, Button*, void)
 {
     try
     {
@@ -686,15 +629,15 @@ IMPL_LINK_NOARG(SvxSecurityTabPage, SavePasswordHdl)
 
         if ( m_pSavePasswordsCB->IsChecked() )
         {
-            bool bOldValue = xMasterPasswd->allowPersistentStoring( sal_True );
+            bool bOldValue = xMasterPasswd->allowPersistentStoring( true );
             xMasterPasswd->removeMasterPassword();
             if ( xMasterPasswd->changeMasterPassword( Reference< task::XInteractionHandler >() ) )
             {
-                m_pMasterPasswordPB->Enable( true );
-                m_pMasterPasswordCB->Check( true );
-                m_pMasterPasswordCB->Enable( true );
-                m_pMasterPasswordFT->Enable( true );
-                m_pShowConnectionsPB->Enable( true );
+                m_pMasterPasswordPB->Enable();
+                m_pMasterPasswordCB->Check();
+                m_pMasterPasswordCB->Enable();
+                m_pMasterPasswordFT->Enable();
+                m_pShowConnectionsPB->Enable();
             }
             else
             {
@@ -704,13 +647,13 @@ IMPL_LINK_NOARG(SvxSecurityTabPage, SavePasswordHdl)
         }
         else
         {
-            ScopedVclPtrInstance< QueryBox > aQuery( this, WB_YES_NO|WB_DEF_NO, m_sPasswordStoringDeactivateStr );
+            ScopedVclPtrInstance< QueryBox > aQuery( this, MessBoxStyle::YesNo|MessBoxStyle::DefaultNo, m_sPasswordStoringDeactivateStr );
             sal_uInt16 nRet = aQuery->Execute();
 
             if( RET_YES == nRet )
             {
-                xMasterPasswd->allowPersistentStoring( sal_False );
-                m_pMasterPasswordCB->Check( true );
+                xMasterPasswd->allowPersistentStoring( false );
+                m_pMasterPasswordCB->Check();
                 m_pMasterPasswordPB->Enable( false );
                 m_pMasterPasswordCB->Enable( false );
                 m_pMasterPasswordFT->Enable( false );
@@ -718,9 +661,9 @@ IMPL_LINK_NOARG(SvxSecurityTabPage, SavePasswordHdl)
             }
             else
             {
-                m_pSavePasswordsCB->Check( true );
-                m_pMasterPasswordPB->Enable( true );
-                m_pShowConnectionsPB->Enable( true );
+                m_pSavePasswordsCB->Check();
+                m_pMasterPasswordPB->Enable();
+                m_pShowConnectionsPB->Enable();
             }
         }
     }
@@ -728,11 +671,9 @@ IMPL_LINK_NOARG(SvxSecurityTabPage, SavePasswordHdl)
     {
         m_pSavePasswordsCB->Check( !m_pSavePasswordsCB->IsChecked() );
     }
-
-    return 0;
 }
 
-IMPL_STATIC_LINK_NOARG(SvxSecurityTabPage, MasterPasswordHdl)
+IMPL_STATIC_LINK_NOARG(SvxSecurityTabPage, MasterPasswordHdl, Button*, void)
 {
     try
     {
@@ -744,11 +685,9 @@ IMPL_STATIC_LINK_NOARG(SvxSecurityTabPage, MasterPasswordHdl)
     }
     catch (const Exception&)
     {}
-
-    return 0;
 }
 
-IMPL_LINK_NOARG(SvxSecurityTabPage, MasterPasswordCBHdl)
+IMPL_LINK_NOARG(SvxSecurityTabPage, MasterPasswordCBHdl, Button*, void)
 {
     try
     {
@@ -759,14 +698,14 @@ IMPL_LINK_NOARG(SvxSecurityTabPage, MasterPasswordCBHdl)
         {
             if ( xMasterPasswd->isPersistentStoringAllowed() && xMasterPasswd->changeMasterPassword( Reference< task::XInteractionHandler >() ) )
             {
-                m_pMasterPasswordPB->Enable( true );
-                m_pMasterPasswordFT->Enable( true );
+                m_pMasterPasswordPB->Enable();
+                m_pMasterPasswordFT->Enable();
             }
             else
             {
                 m_pMasterPasswordCB->Check( false );
-                m_pMasterPasswordPB->Enable( true );
-                m_pMasterPasswordFT->Enable( true );
+                m_pMasterPasswordPB->Enable();
+                m_pMasterPasswordFT->Enable();
             }
         }
         else
@@ -778,9 +717,9 @@ IMPL_LINK_NOARG(SvxSecurityTabPage, MasterPasswordCBHdl)
             }
             else
             {
-                m_pMasterPasswordCB->Check( true );
-                m_pMasterPasswordPB->Enable( true );
-                m_pShowConnectionsPB->Enable( true );
+                m_pMasterPasswordCB->Check();
+                m_pMasterPasswordPB->Enable();
+                m_pShowConnectionsPB->Enable();
             }
         }
     }
@@ -788,11 +727,9 @@ IMPL_LINK_NOARG(SvxSecurityTabPage, MasterPasswordCBHdl)
     {
         m_pSavePasswordsCB->Check( !m_pSavePasswordsCB->IsChecked() );
     }
-
-    return 0;
 }
 
-IMPL_LINK_NOARG(SvxSecurityTabPage, ShowPasswordsHdl)
+IMPL_LINK_NOARG(SvxSecurityTabPage, ShowPasswordsHdl, Button*, void)
 {
     try
     {
@@ -807,10 +744,9 @@ IMPL_LINK_NOARG(SvxSecurityTabPage, ShowPasswordsHdl)
     }
     catch (const Exception&)
     {}
-    return 0;
 }
 
-IMPL_LINK_NOARG(SvxSecurityTabPage, CertPathPBHdl)
+IMPL_LINK_NOARG(SvxSecurityTabPage, CertPathPBHdl, Button*, void)
 {
     if (!mpCertPathDlg)
         mpCertPathDlg = VclPtr<CertPathDialog>::Create(this);
@@ -820,14 +756,12 @@ IMPL_LINK_NOARG(SvxSecurityTabPage, CertPathPBHdl)
 
     if (nRet == RET_OK && sOrig != mpCertPathDlg->getDirectory())
     {
-        ScopedVclPtrInstance< MessageDialog > aWarnBox(this, CUI_RES(RID_SVXSTR_OPTIONS_RESTART), VCL_MESSAGE_INFO);
-        aWarnBox->Execute();
+        SolarMutexGuard aGuard;
+        svtools::executeRestartDialog(comphelper::getProcessComponentContext(), nullptr, svtools::RESTART_REASON_ADDING_PATH);
     }
-
-    return 0;
 }
 
-IMPL_LINK_NOARG(SvxSecurityTabPage, TSAURLsPBHdl)
+IMPL_LINK_NOARG(SvxSecurityTabPage, TSAURLsPBHdl, Button*, void)
 {
     // Unlike the mpCertPathDlg, we *don't* keep the same dialog object around between
     // invocations. Seems clearer to my little brain that way.
@@ -835,11 +769,9 @@ IMPL_LINK_NOARG(SvxSecurityTabPage, TSAURLsPBHdl)
     ScopedVclPtrInstance<TSAURLsDialog> pTSAURLsDlg(this);
 
     pTSAURLsDlg->Execute();
-
-    return 0;
 }
 
-IMPL_STATIC_LINK_NOARG(SvxSecurityTabPage, MacroSecPBHdl)
+IMPL_STATIC_LINK_NOARG(SvxSecurityTabPage, MacroSecPBHdl, Button*, void)
 {
     try
     {
@@ -849,10 +781,8 @@ IMPL_STATIC_LINK_NOARG(SvxSecurityTabPage, MacroSecPBHdl)
     }
     catch (const Exception& e)
     {
-        OSL_FAIL(OUStringToOString(e.Message, osl_getThreadTextEncoding()).getStr());
-        (void)e;
+        SAL_WARN( "cui.options", e);
     }
-    return 0;
 }
 
 
@@ -864,9 +794,9 @@ void SvxSecurityTabPage::InitControls()
     // @@@ Better would be to query the dialog whether it is 'useful' or not. Exposing
     //     macro security dialog implementations here, which is bad.
     if (    mpSecOptions->IsMacroDisabled()
-         || (    mpSecOptions->IsReadOnly( SvtSecurityOptions::E_MACRO_SECLEVEL )
-              && mpSecOptions->IsReadOnly( SvtSecurityOptions::E_MACRO_TRUSTEDAUTHORS )
-              && mpSecOptions->IsReadOnly( SvtSecurityOptions::E_SECUREURLS ) ) )
+         || (    mpSecOptions->IsReadOnly( SvtSecurityOptions::EOption::MacroSecLevel )
+              && mpSecOptions->IsReadOnly( SvtSecurityOptions::EOption::MacroTrustedAuthors )
+              && mpSecOptions->IsReadOnly( SvtSecurityOptions::EOption::SecureUrls ) ) )
     {
         //Hide these
         m_pMacroSecFrame->Hide();
@@ -878,7 +808,7 @@ void SvxSecurityTabPage::InitControls()
 
     m_pMasterPasswordPB->Enable( false );
     m_pMasterPasswordCB->Enable( false );
-    m_pMasterPasswordCB->Check( true );
+    m_pMasterPasswordCB->Check();
     m_pMasterPasswordFT->Enable( false );
     m_pShowConnectionsPB->Enable( false );
 
@@ -890,17 +820,17 @@ void SvxSecurityTabPage::InitControls()
 
         if ( xMasterPasswd->isPersistentStoringAllowed() )
         {
-            m_pMasterPasswordCB->Enable( true );
-            m_pShowConnectionsPB->Enable( true );
-            m_pSavePasswordsCB->Check( true );
+            m_pMasterPasswordCB->Enable();
+            m_pShowConnectionsPB->Enable();
+            m_pSavePasswordsCB->Check();
 
             if ( xMasterPasswd->isDefaultMasterPasswordUsed() )
                 m_pMasterPasswordCB->Check( false );
             else
             {
-                m_pMasterPasswordPB->Enable( true );
-                m_pMasterPasswordCB->Check( true );
-                m_pMasterPasswordFT->Enable( true );
+                m_pMasterPasswordPB->Enable();
+                m_pMasterPasswordCB->Check();
+                m_pMasterPasswordFT->Enable();
             }
         }
     }
@@ -919,11 +849,11 @@ void SvxSecurityTabPage::ActivatePage( const SfxItemSet& )
 {
 }
 
-SfxTabPage::sfxpg SvxSecurityTabPage::DeactivatePage( SfxItemSet* _pSet )
+DeactivateRC SvxSecurityTabPage::DeactivatePage( SfxItemSet* _pSet )
 {
     if( _pSet )
         FillItemSet( _pSet );
-    return LEAVE_PAGE;
+    return DeactivateRC::LeavePage;
 }
 
 namespace
@@ -951,14 +881,14 @@ bool SvxSecurityTabPage::FillItemSet( SfxItemSet* )
 
     if ( mpSecOptDlg )
     {
-        CheckAndSave( *mpSecOptions, SvtSecurityOptions::E_DOCWARN_SAVEORSEND, mpSecOptDlg->IsSaveOrSendDocsChecked(), bModified );
-        CheckAndSave( *mpSecOptions, SvtSecurityOptions::E_DOCWARN_SIGNING, mpSecOptDlg->IsSignDocsChecked(), bModified );
-        CheckAndSave( *mpSecOptions, SvtSecurityOptions::E_DOCWARN_PRINT, mpSecOptDlg->IsPrintDocsChecked(), bModified );
-        CheckAndSave( *mpSecOptions, SvtSecurityOptions::E_DOCWARN_CREATEPDF, mpSecOptDlg->IsCreatePdfChecked(), bModified );
-        CheckAndSave( *mpSecOptions, SvtSecurityOptions::E_DOCWARN_REMOVEPERSONALINFO, mpSecOptDlg->IsRemovePersInfoChecked(), bModified );
-        CheckAndSave( *mpSecOptions, SvtSecurityOptions::E_DOCWARN_RECOMMENDPASSWORD, mpSecOptDlg->IsRecommPasswdChecked(), bModified );
-        CheckAndSave( *mpSecOptions, SvtSecurityOptions::E_CTRLCLICK_HYPERLINK, mpSecOptDlg->IsCtrlHyperlinkChecked(), bModified );
-        CheckAndSave( *mpSecOptions, SvtSecurityOptions::E_BLOCKUNTRUSTEDREFERERLINKS, mpSecOptDlg->IsBlockUntrustedRefererLinksChecked(), bModified );
+        CheckAndSave( *mpSecOptions, SvtSecurityOptions::EOption::DocWarnSaveOrSend, mpSecOptDlg->IsSaveOrSendDocsChecked(), bModified );
+        CheckAndSave( *mpSecOptions, SvtSecurityOptions::EOption::DocWarnSigning, mpSecOptDlg->IsSignDocsChecked(), bModified );
+        CheckAndSave( *mpSecOptions, SvtSecurityOptions::EOption::DocWarnPrint, mpSecOptDlg->IsPrintDocsChecked(), bModified );
+        CheckAndSave( *mpSecOptions, SvtSecurityOptions::EOption::DocWarnCreatePdf, mpSecOptDlg->IsCreatePdfChecked(), bModified );
+        CheckAndSave( *mpSecOptions, SvtSecurityOptions::EOption::DocWarnRemovePersonalInfo, mpSecOptDlg->IsRemovePersInfoChecked(), bModified );
+        CheckAndSave( *mpSecOptions, SvtSecurityOptions::EOption::DocWarnRecommendPassword, mpSecOptDlg->IsRecommPasswdChecked(), bModified );
+        CheckAndSave( *mpSecOptions, SvtSecurityOptions::EOption::CtrlClickHyperlink, mpSecOptDlg->IsCtrlHyperlinkChecked(), bModified );
+        CheckAndSave( *mpSecOptions, SvtSecurityOptions::EOption::BlockUntrustedRefererLinks, mpSecOptDlg->IsBlockUntrustedRefererLinksChecked(), bModified );
     }
 
     return bModified;
@@ -1012,8 +942,7 @@ SvxEMailTabPage::~SvxEMailTabPage()
 
 void SvxEMailTabPage::dispose()
 {
-    delete pImpl;
-    pImpl = NULL;
+    pImpl.reset();
     m_pMailContainer.clear();
     m_pMailerURLFI.clear();
     m_pMailerURLED.clear();
@@ -1058,8 +987,8 @@ bool SvxEMailTabPage::FillItemSet( SfxItemSet* )
 
 void SvxEMailTabPage::Reset( const SfxItemSet* )
 {
-    m_pMailerURLED->Enable(true );
-    m_pMailerURLPB->Enable(true );
+    m_pMailerURLED->Enable();
+    m_pMailerURLPB->Enable();
 
     if (pImpl->bROProgram)
         m_pMailerURLFI->Show();
@@ -1079,32 +1008,32 @@ void SvxEMailTabPage::Reset( const SfxItemSet* )
 
 /* -------------------------------------------------------------------------*/
 
-IMPL_LINK(  SvxEMailTabPage, FileDialogHdl_Impl, PushButton*, pButton )
+IMPL_LINK(  SvxEMailTabPage, FileDialogHdl_Impl, Button*, pButton, void )
 {
     if (m_pMailerURLPB == pButton && !pImpl->bROProgram)
     {
-        FileDialogHelper aHelper(
-            com::sun::star::ui::dialogs::TemplateDescription::FILEOPEN_SIMPLE,
-            0 );
+        FileDialogHelper aHelper(css::ui::dialogs::TemplateDescription::FILEOPEN_SIMPLE, FileDialogFlags::NONE, this);
         OUString sPath = m_pMailerURLED->GetText();
         if ( sPath.isEmpty() )
             sPath = "/usr/bin";
 
         OUString sUrl;
-        ::utl::LocalFileHelper::ConvertPhysicalNameToURL(sPath, sUrl);
+        osl::FileBase::getFileURLFromSystemPath(sPath, sUrl);
         aHelper.SetDisplayDirectory(sUrl);
-        aHelper.AddFilter( m_sDefaultFilterName, OUString("*"));
+        aHelper.AddFilter( m_sDefaultFilterName, "*");
 
         if ( ERRCODE_NONE == aHelper.Execute() )
         {
             sUrl = aHelper.GetPath();
-            ::utl::LocalFileHelper::ConvertURLToPhysicalName(sUrl, sPath);
+            if (osl::FileBase::getSystemPathFromFileURL(sUrl, sPath)
+                != osl::FileBase::E_None)
+            {
+                sPath.clear();
+            }
             m_pMailerURLED->SetText(sPath);
         }
     }
-    return 0;
 }
 
 
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
