@@ -26,13 +26,19 @@
 #include <vcl/svapp.hxx>
 #include <vcl/settings.hxx>
 #include <vcl/graphicfilter.hxx>
+#include <vcl/mnemonic.hxx>
 #include <dialmgr.hxx>
-#include "cuires.hrc"
+#include <strings.hrc>
+#include <personalization.hrc>
 
+#include <com/sun/star/task/InteractionHandler.hpp>
 #include <com/sun/star/ucb/SimpleFileAccess.hpp>
 #include <com/sun/star/xml/sax/XParser.hpp>
 #include <com/sun/star/xml/sax/Parser.hpp>
-#include "ucbhelper/content.hxx"
+#include <ucbhelper/content.hxx>
+#include <comphelper/simplefileaccessinteraction.hxx>
+
+#define MAX_RESULTS 9
 
 using namespace com::sun::star;
 using namespace ::com::sun::star::uno;
@@ -46,27 +52,20 @@ SelectPersonaDialog::SelectPersonaDialog( vcl::Window *pParent )
     m_pSearchButton->SetClickHdl( LINK( this, SelectPersonaDialog, SearchPersonas ) );
 
     get( m_vSearchSuggestions[0], "suggestion1" );
-    m_vSearchSuggestions[0]->SetText( "LibreOffice" );
-    m_vSearchSuggestions[0]->SetClickHdl( LINK( this, SelectPersonaDialog, SearchPersonas ) );
-
     get( m_vSearchSuggestions[1], "suggestion2" );
-    m_vSearchSuggestions[1]->SetText( CUI_RES ( RID_SVXSTR_PERSONA_ABSTRACT ) );
-    m_vSearchSuggestions[1]->SetClickHdl( LINK( this, SelectPersonaDialog, SearchPersonas ) );
-
     get( m_vSearchSuggestions[2], "suggestion3" );
-    m_vSearchSuggestions[2]->SetText( CUI_RES ( RID_SVXSTR_PERSONA_COLOR ) );
-    m_vSearchSuggestions[2]->SetClickHdl( LINK( this, SelectPersonaDialog, SearchPersonas ) );
-
     get( m_vSearchSuggestions[3], "suggestion4" );
-    m_vSearchSuggestions[3]->SetText( CUI_RES( RID_SVXSTR_PERSONA_MUSIC ) );
-    m_vSearchSuggestions[3]->SetClickHdl( LINK( this, SelectPersonaDialog, SearchPersonas ) );
-
     get( m_vSearchSuggestions[4], "suggestion5" );
-    m_vSearchSuggestions[4]->SetText( CUI_RES( RID_SVXSTR_PERSONA_NATURE ) );
-    m_vSearchSuggestions[4]->SetClickHdl( LINK( this, SelectPersonaDialog, SearchPersonas ) );
+    get( m_vSearchSuggestions[5], "suggestion6" );
+
+    assert(SAL_N_ELEMENTS(RID_SVXSTR_PERSONA_CATEGORIES) >= CATEGORYCOUNT);
+    for(sal_uInt32 i = 0; i < CATEGORYCOUNT; ++i)
+    {
+        m_vSearchSuggestions[i]->SetText(CuiResId(RID_SVXSTR_PERSONA_CATEGORIES[i]));
+        m_vSearchSuggestions[i]->SetClickHdl( LINK( this, SelectPersonaDialog, SearchPersonas ) );
+    }
 
     get( m_pEdit, "search_term" );
-    m_pEdit->SetPlaceholderText( CUI_RES( RID_SVXSTR_SEARCHTERM ) );
 
     get( m_pProgressLabel, "progress_label" );
 
@@ -85,13 +84,35 @@ SelectPersonaDialog::SelectPersonaDialog( vcl::Window *pParent )
     get( m_vResultList[7], "result8" );
     get( m_vResultList[8], "result9" );
 
-    for (sal_Int32 nIndex = 0; nIndex < 9; ++nIndex)
+    for (VclPtr<PushButton> & nIndex : m_vResultList)
     {
-        m_vResultList[nIndex]->SetClickHdl( LINK( this, SelectPersonaDialog, SelectPersona ) );
-        m_vResultList[nIndex]->Disable();
+        nIndex->SetClickHdl( LINK( this, SelectPersonaDialog, SelectPersona ) );
+        nIndex->Disable();
     }
 }
 
+SelectPersonaDialog::~SelectPersonaDialog()
+{
+    disposeOnce();
+}
+
+void SelectPersonaDialog::dispose()
+{
+    if (m_pSearchThread.is())
+        m_pSearchThread->join();
+
+    m_pEdit.clear();
+    m_pSearchButton.clear();
+    m_pProgressLabel.clear();
+    for (VclPtr<PushButton>& vp : m_vResultList)
+        vp.clear();
+    for (VclPtr<PushButton>& vp : m_vSearchSuggestions)
+        vp.clear();
+    m_pOkButton.clear();
+    m_pCancelButton.clear();
+    ModalDialog::dispose();
+}
+
 OUString SelectPersonaDialog::GetSelectedPersona() const
 {
     if( !m_aSelectedPersona.isEmpty( ) )
@@ -100,98 +121,82 @@ OUString SelectPersonaDialog::GetSelectedPersona() const
     return OUString();
 }
 
-IMPL_LINK( SelectPersonaDialog, SearchPersonas, PushButton*, pButton )
+IMPL_LINK( SelectPersonaDialog, SearchPersonas, Button*, pButton, void )
 {
+    /*
+     * English category names should be used for search.
+     * These strings should be in sync with the strings of
+     * RID_SVXSTR_PERSONA_CATEGORIES in personalization.hrc
+     */
+    static const OUStringLiteral vSuggestionCategories[] =
+        {"LibreOffice", "Abstract", "Color", "Music", "Nature", "Solid"};
+
     OUString searchTerm;
-    if( m_rSearchThread.is() )
-        m_rSearchThread->StopExecution();
+    if( m_pSearchThread.is() )
+        m_pSearchThread->StopExecution();
 
     if( pButton ==  m_pSearchButton )
         searchTerm = m_pEdit->GetText();
     else
     {
-        for( sal_Int32 nIndex = 0; nIndex < 5; nIndex++ )
+        for ( sal_uInt32 i = 0; i < CATEGORYCOUNT; ++i)
         {
-            if( pButton == m_vSearchSuggestions[nIndex] )
+            if( pButton == m_vSearchSuggestions[i] )
             {
-                searchTerm = m_vSearchSuggestions[nIndex]->GetDisplayText();
+                // Use the category name in English as search term
+                searchTerm = vSuggestionCategories[i];
                 break;
             }
         }
     }
 
     if( searchTerm.isEmpty( ) )
-        return 0;
+        return;
 
-    // TODO FIXME!
-    // Before the release, the allizom.org url shoud be changed to:
-    // OUString rSearchURL = "https://services.addons.mozilla.org/en-US/firefox/api/1.5/search/" + searchTerm + "/9/9";
-    // The problem why it cannot be done just now is that the SSL negotiation
-    // with services.addons.mozilla.org fails very early - during an early
-    // propfind, SSL returns X509_V_ERR_CERT_UNTRUSTED to neon, causing the
-    // NE_SSL_UNTRUSTED being set in verify_callback in neon/src/ne_openssl.c
-    //
-    // This is not cleared anywhere during the init, and so later, even though
-    // we have found the certificate, this triggers
-    // NeonSession_CertificationNotify callback, that
-    // causes that NE_SSL_UNTRUSTED is igored in cases when the condition
-    //   if ( pSession->isDomainMatch(
-    //      GetHostnamePart( xEECert.get()->getSubjectName() ) ) )
-    // is true; but that is only when getSubjectName() actually returns a
-    // wildcard, or the exact name.
-    //
-    // In the case of services.addons.mozilla.com, the certificate is for
-    // versioncheck.addons.mozilla.com, but it also has
-    //   X509v3 Subject Alternative Name:
-    //       DNS:services.addons.mozilla.org, DNS:versioncheck-bg.addons.mozilla.org, DNS:pyrepo.addons.mozilla.org, DNS:versioncheck.addons.mozilla.org
-    // So it is all valid; but the early X509_V_ERR_CERT_UNTRUSTED failure
-    // described above just makes this being ignored.
-    //
-    // My suspicion is that this never actually worked, and the
-    //   if ( pSession->isDomainMatch(
-    //      GetHostnamePart( xEECert.get()->getSubjectName() ) ) )
-    // works around the root cause that is there for years, and which makes it
-    // work in most cases.  I guess that we initialize something wrongly or
-    // too late; but I have already spent few hours debugging, and
-    // give up for the moment - need to return to this at some stage.
-    OUString rSearchURL = "https://addons.allizom.org/en-US/firefox/api/1.5/search/" + searchTerm + "/9/9";
-    m_rSearchThread = new SearchAndParseThread( this, rSearchURL );
-    m_rSearchThread->launch();
-    return 0;
+    // 15 results so that invalid and duplicate search results whose names can't be retrieved can be skipped
+    OUString rSearchURL = "https://services.addons.mozilla.org/en-US/firefox/api/1.5/search/" + searchTerm + "/9/15";
+
+    if ( searchTerm.startsWith( "https://addons.mozilla.org/" ) )
+    {
+        searchTerm = "https://addons.mozilla.org/en-US/" + searchTerm.copy( searchTerm.indexOf( "firefox" ) );
+        m_pSearchThread = new SearchAndParseThread( this, searchTerm, true );
+    }
+    else
+        m_pSearchThread = new SearchAndParseThread( this, rSearchURL, false );
+
+    m_pSearchThread->launch();
 }
 
-IMPL_LINK( SelectPersonaDialog, ActionOK, PushButton*, /* pButton */ )
+IMPL_LINK_NOARG( SelectPersonaDialog, ActionOK, Button*, void )
 {
     OUString aSelectedPersona = GetSelectedPersona();
 
     if( !aSelectedPersona.isEmpty() )
     {
-        m_rSearchThread = new SearchAndParseThread( this, aSelectedPersona );
-        m_rSearchThread->launch();
+        m_pSearchThread = new SearchAndParseThread( this, aSelectedPersona, false );
+        m_pSearchThread->launch();
     }
 
     else
     {
-        if( m_rSearchThread.is() )
-            m_rSearchThread->StopExecution();
+        if( m_pSearchThread.is() )
+            m_pSearchThread->StopExecution();
         EndDialog( RET_OK );
     }
-    return 0;
 }
 
-IMPL_LINK( SelectPersonaDialog, ActionCancel, PushButton*, /* pButton */ )
+IMPL_LINK_NOARG( SelectPersonaDialog, ActionCancel, Button*, void )
 {
-    if( m_rSearchThread.is() )
-        m_rSearchThread->StopExecution();
+    if( m_pSearchThread.is() )
+        m_pSearchThread->StopExecution();
 
-    EndDialog( RET_CANCEL );
-    return 0;
+    EndDialog();
 }
 
-IMPL_LINK( SelectPersonaDialog, SelectPersona, PushButton*, pButton )
+IMPL_LINK( SelectPersonaDialog, SelectPersona, Button*, pButton, void )
 {
-    if( m_rSearchThread.is() )
-        m_rSearchThread->StopExecution();
+    if( m_pSearchThread.is() )
+        m_pSearchThread->StopExecution();
 
     for( sal_Int32 index = 0; index < 9; index++ )
     {
@@ -203,27 +208,25 @@ IMPL_LINK( SelectPersonaDialog, SelectPersona, PushButton*, pButton )
                 // get the persona name from the setting variable to show in the progress.
                 sal_Int32 nNameIndex = m_aSelectedPersona.indexOf( ';' );
                 OUString aName = m_aSelectedPersona.copy( 0, nNameIndex );
-                OUString aProgress( CUI_RES( RID_SVXSTR_SELECTEDPERSONA ) );
-                aProgress += aName;
+                OUString aProgress = CuiResId(RID_SVXSTR_SELECTEDPERSONA) + aName;
                 SetProgress( aProgress );
             }
             break;
         }
     }
-    return 0;
 }
 
-void SelectPersonaDialog::SetAppliedPersonaSetting( OUString& rPersonaSetting )
+void SelectPersonaDialog::SetAppliedPersonaSetting( OUString const & rPersonaSetting )
 {
     m_aAppliedPersona = rPersonaSetting;
 }
 
-OUString SelectPersonaDialog::GetAppliedPersonaSetting() const
+const OUString& SelectPersonaDialog::GetAppliedPersonaSetting() const
 {
     return m_aAppliedPersona;
 }
 
-void SelectPersonaDialog::SetProgress( OUString& rProgress )
+void SelectPersonaDialog::SetProgress( const OUString& rProgress )
 {
     if(rProgress.isEmpty())
         m_pProgressLabel->Hide();
@@ -236,13 +239,13 @@ void SelectPersonaDialog::SetProgress( OUString& rProgress )
     }
 }
 
-void SelectPersonaDialog::SetImages( Image aImage, sal_Int32 nIndex )
+void SelectPersonaDialog::SetImages( const Image& aImage, sal_Int32 nIndex )
 {
     m_vResultList[nIndex]->Enable();
     m_vResultList[nIndex]->SetModeImage( aImage );
 }
 
-void SelectPersonaDialog::AddPersonaSetting( OUString& rPersonaSetting )
+void SelectPersonaDialog::AddPersonaSetting( OUString const & rPersonaSetting )
 {
     m_vPersonaSettings.push_back( rPersonaSetting );
 }
@@ -250,11 +253,11 @@ void SelectPersonaDialog::AddPersonaSetting( OUString& rPersonaSetting )
 void SelectPersonaDialog::ClearSearchResults()
 {
     m_vPersonaSettings.clear();
-    m_aSelectedPersona = "";
-    for( sal_Int32 nIndex = 0; nIndex < 9; nIndex++ )
+    m_aSelectedPersona.clear();
+    for(VclPtr<PushButton> & nIndex : m_vResultList)
     {
-        m_vResultList[nIndex]->Disable();
-        m_vResultList[nIndex]->SetModeImage(Image());
+        nIndex->Disable();
+        nIndex->SetModeImage(Image());
     }
 }
 
@@ -264,6 +267,7 @@ SvxPersonalizationTabPage::SvxPersonalizationTabPage( vcl::Window *pParent, cons
     // persona
     get( m_pNoPersona, "no_persona" );
     get( m_pDefaultPersona, "default_persona" );
+    get( m_pAppliedThemeLabel, "applied_theme" );
 
     get( m_pOwnPersona, "own_persona" );
     m_pOwnPersona->SetClickHdl( LINK( this, SvxPersonalizationTabPage, ForceSelect ) );
@@ -287,17 +291,35 @@ SvxPersonalizationTabPage::SvxPersonalizationTabPage( vcl::Window *pParent, cons
 
     get ( m_pExtensionLabel, "extensions_label" );
 
+    CheckAppliedTheme();
     LoadDefaultImages();
     LoadExtensionThemes();
 }
 
 SvxPersonalizationTabPage::~SvxPersonalizationTabPage()
 {
+    disposeOnce();
 }
 
-SfxTabPage* SvxPersonalizationTabPage::Create( vcl::Window *pParent, const SfxItemSet *rSet )
+void SvxPersonalizationTabPage::dispose()
 {
-    return new SvxPersonalizationTabPage( pParent, *rSet );
+    m_pNoPersona.clear();
+    m_pDefaultPersona.clear();
+    m_pOwnPersona.clear();
+    m_pSelectPersona.clear();
+    for (VclPtr<PushButton> & i : m_vDefaultPersonaImages)
+        i.clear();
+    m_pExtensionPersonaPreview.clear();
+    m_pPersonaList.clear();
+    m_pExtensionLabel.clear();
+    m_pAppliedThemeLabel.clear();
+    SfxTabPage::dispose();
+}
+
+
+VclPtr<SfxTabPage> SvxPersonalizationTabPage::Create( vcl::Window *pParent, const SfxItemSet *rSet )
+{
+    return VclPtr<SvxPersonalizationTabPage>::Create( pParent, *rSet );
 }
 
 bool SvxPersonalizationTabPage::FillItemSet( SfxItemSet * )
@@ -319,9 +341,9 @@ bool SvxPersonalizationTabPage::FillItemSet( SfxItemSet * )
     }
 
     // write
-    boost::shared_ptr< comphelper::ConfigurationChanges > batch( comphelper::ConfigurationChanges::create() );
+    std::shared_ptr< comphelper::ConfigurationChanges > batch( comphelper::ConfigurationChanges::create() );
     if( aPersona == "no" )
-        m_aPersonaSettings = "";
+        m_aPersonaSettings.clear();
     officecfg::Office::Common::Misc::Persona::set( aPersona, batch );
     officecfg::Office::Common::Misc::PersonaSettings::set( m_aPersonaSettings, batch );
     batch->commit();
@@ -329,7 +351,7 @@ bool SvxPersonalizationTabPage::FillItemSet( SfxItemSet * )
     if ( bModified )
     {
         // broadcast the change
-        DataChangedEvent aDataChanged( DATACHANGED_SETTINGS, NULL, SETTINGS_STYLE );
+        DataChangedEvent aDataChanged( DataChangedEventType::SETTINGS, nullptr, AllSettingsFlags::STYLE );
         Application::NotifyAllWindows( aDataChanged );
     }
 
@@ -359,30 +381,51 @@ void SvxPersonalizationTabPage::Reset( const SfxItemSet * )
 void SvxPersonalizationTabPage::SetPersonaSettings( const OUString& aPersonaSettings )
 {
     m_aPersonaSettings = aPersonaSettings;
+    ShowAppliedThemeLabel( m_aPersonaSettings );
     m_pOwnPersona->Check();
 }
 
+void SvxPersonalizationTabPage::CheckAppliedTheme()
+{
+    uno::Reference< uno::XComponentContext > xContext( comphelper::getProcessComponentContext() );
+    OUString aPersona( "default" ), aPersonaSetting;
+    if ( xContext.is())
+    {
+        aPersona = officecfg::Office::Common::Misc::Persona::get( xContext );
+        aPersonaSetting = officecfg::Office::Common::Misc::PersonaSettings::get( xContext );
+    }
+    if(aPersona == "own")
+        ShowAppliedThemeLabel(aPersonaSetting);
+}
+
+void SvxPersonalizationTabPage::ShowAppliedThemeLabel(const OUString& aPersonaSetting)
+{
+    sal_Int32 nNameIndex = aPersonaSetting.indexOf( '/' );
+    OUString aName = "(" + aPersonaSetting.copy( 0, nNameIndex ) +")";
+    m_pAppliedThemeLabel->Show();
+    m_pAppliedThemeLabel->SetText( aName );
+}
+
 void SvxPersonalizationTabPage::LoadDefaultImages()
 {
     // Load the pre saved personas
 
-    OUString gallery( "" );
-    gallery = "$BRAND_BASE_DIR/" LIBO_SHARE_FOLDER;
-    gallery += "/gallery/personas/";
+    OUString gallery
+        = "$BRAND_BASE_DIR/" LIBO_SHARE_FOLDER "/gallery/personas/";
     rtl::Bootstrap::expandMacros( gallery );
     OUString aPersonasList = gallery + "personas_list.txt";
-    SvFileStream aStream( aPersonasList, STREAM_READ );
+    SvFileStream aStream( aPersonasList, StreamMode::READ );
     GraphicFilter aFilter;
     Graphic aGraphic;
     sal_Int32 nIndex = 0;
 
-    while( aStream.IsOpen() && !aStream.IsEof() )
+    while( aStream.IsOpen() && !aStream.eof() )
     {
         OString aLine;
         aStream.ReadLine( aLine );
         OUString aPersonaSetting( OStringToOUString( aLine, RTL_TEXTENCODING_UTF8 ) );
         OUString aPreviewFile;
-        sal_Int32 nNewIndex = aPersonaSetting.indexOf( ';', 0 );
+        sal_Int32 nNewIndex = aPersonaSetting.indexOf( ';' );
         if( nNewIndex < 0 )
             break;
         aPreviewFile = aPersonaSetting.copy( 0, nNewIndex );
@@ -439,33 +482,27 @@ void SvxPersonalizationTabPage::LoadExtensionThemes()
     }
 }
 
-IMPL_LINK( SvxPersonalizationTabPage, SelectPersona, PushButton*, /*pButton*/ )
+IMPL_LINK_NOARG( SvxPersonalizationTabPage, SelectPersona, Button*, void )
 {
-    SelectPersonaDialog aDialog( NULL );
+    ScopedVclPtrInstance< SelectPersonaDialog > aDialog(nullptr);
 
-    while ( aDialog.Execute() == RET_OK )
+    if ( aDialog->Execute() == RET_OK )
     {
-        OUString aPersonaSetting( aDialog.GetAppliedPersonaSetting() );
+        OUString aPersonaSetting( aDialog->GetAppliedPersonaSetting() );
         if ( !aPersonaSetting.isEmpty() )
         {
             SetPersonaSettings( aPersonaSetting );
         }
-
-        break;
     }
-
-    return 0;
 }
 
-IMPL_LINK( SvxPersonalizationTabPage, ForceSelect, RadioButton*, pButton )
+IMPL_LINK( SvxPersonalizationTabPage, ForceSelect, Button*, pButton, void )
 {
     if ( pButton == m_pOwnPersona && m_aPersonaSettings.isEmpty() )
         SelectPersona( m_pSelectPersona );
-
-    return 0;
 }
 
-IMPL_LINK( SvxPersonalizationTabPage, DefaultPersona, PushButton*, pButton )
+IMPL_LINK( SvxPersonalizationTabPage, DefaultPersona, Button*, pButton, void )
 {
     m_pDefaultPersona->Check();
     for( sal_Int32 nIndex = 0; nIndex < 3; nIndex++ )
@@ -473,19 +510,17 @@ IMPL_LINK( SvxPersonalizationTabPage, DefaultPersona, PushButton*, pButton )
         if( pButton == m_vDefaultPersonaImages[nIndex] )
             m_aPersonaSettings = m_vDefaultPersonaSettings[nIndex];
     }
-
-    return 0;
 }
 
-IMPL_LINK( SvxPersonalizationTabPage, SelectInstalledPersona, ListBox*, )
+IMPL_LINK_NOARG( SvxPersonalizationTabPage, SelectInstalledPersona, ListBox&, void)
 {
     m_pOwnPersona->Check();
 
     // Get the details of the selected theme.
     m_pExtensionPersonaPreview->Show();
-    sal_Int32 nSelectedPos = m_pPersonaList->GetSelectEntryPos();
+    sal_Int32 nSelectedPos = m_pPersonaList->GetSelectedEntryPos();
     OUString aSettings = m_vExtensionPersonaSettings[nSelectedPos];
-    sal_Int32 nIndex = aSettings.indexOf( ';', 0 );
+    sal_Int32 nIndex = aSettings.indexOf( ';' );
     OUString aPreviewFile = aSettings.copy( 0, nIndex );
     m_aPersonaSettings = aSettings.copy( nIndex + 1 );
 
@@ -496,8 +531,6 @@ IMPL_LINK( SvxPersonalizationTabPage, SelectInstalledPersona, ListBox*, )
     aFilter.ImportGraphic( aGraphic, aURLObj );
     Bitmap aBmp = aGraphic.GetBitmap();
     m_pExtensionPersonaPreview->SetModeImage( Image( aBmp ) );
-
-    return 0;
 }
 
 /// Find the value on the Persona page, and convert it to a usable form.
@@ -520,10 +553,13 @@ static OUString searchValue( const OString &rBuffer, sal_Int32 from, const OStri
 }
 
 /// Parse the Persona web page, and find where to get the bitmaps + the color values.
-static bool parsePersonaInfo( const OString &rBuffer, OUString *pHeaderURL, OUString *pFooterURL,
+static bool parsePersonaInfo( const OString &rBufferArg, OUString *pHeaderURL, OUString *pFooterURL,
                               OUString *pTextColor, OUString *pAccentColor, OUString *pPreviewURL,
                               OUString *pName )
 {
+    // tdf#115417: buffer retrieved from html response can contain &quot; or &#34;
+    // let's replace the whole buffer with last one so we can treat it easily
+    OString rBuffer = rBufferArg.replaceAll(OString("&quot;"), OString("&#34;"));
     // it is the first attribute that contains "persona="
     sal_Int32 persona = rBuffer.indexOf( "data-browsertheme=\"{" );
     if ( persona < 0 )
@@ -551,18 +587,16 @@ static bool parsePersonaInfo( const OString &rBuffer, OUString *pHeaderURL, OUSt
         return false;
 
     *pName = searchValue( rBuffer, persona, "&#34;name&#34;:&#34;" );
-    if ( pName->isEmpty() )
-        return false;
-
-    return true;
+    return !pName->isEmpty();
 }
 
 SearchAndParseThread::SearchAndParseThread( SelectPersonaDialog* pDialog,
-                          const OUString& rURL ) :
+                          const OUString& rURL, bool bDirectURL ) :
             Thread( "cuiPersonasSearchThread" ),
             m_pPersonaDialog( pDialog ),
             m_aURL( rURL ),
-            m_bExecute( true )
+            m_bExecute( true ),
+            m_bDirectURL( bDirectURL )
 {
 }
 
@@ -570,56 +604,171 @@ SearchAndParseThread::~SearchAndParseThread()
 {
 }
 
+namespace {
+
+bool getPreviewFile( const OUString& rURL, OUString *pPreviewFile, OUString *pPersonaSetting )
+{
+    uno::Reference< ucb::XSimpleFileAccess3 > xFileAccess( ucb::SimpleFileAccess::create( comphelper::getProcessComponentContext() ), uno::UNO_QUERY );
+    if ( !xFileAccess.is() )
+        return false;
+
+    Reference<XComponentContext> xContext( ::comphelper::getProcessComponentContext() );
+    uno::Reference< io::XInputStream > xStream;
+    try {
+        css:: uno::Reference< task::XInteractionHandler > xIH(
+            css::task::InteractionHandler::createWithParent( xContext, nullptr ) );
+
+        xFileAccess->setInteractionHandler( new comphelper::SimpleFileAccessInteraction( xIH ) );
+        xStream = xFileAccess->openFileRead( rURL );
+
+        if( !xStream.is() )
+            return false;
+    }
+    catch (...)
+    {
+        return false;
+    }
+
+    // read the persona specification
+    // NOTE: Parsing for real is an overkill here; and worse - I tried, and
+    // the HTML the site provides is not 100% valid ;-)
+    const sal_Int32 BUF_LEN = 8000;
+    uno::Sequence< sal_Int8 > buffer( BUF_LEN );
+    OStringBuffer aBuffer( 64000 );
+
+    sal_Int32 nRead = 0;
+    while ( ( nRead = xStream->readBytes( buffer, BUF_LEN ) ) == BUF_LEN )
+        aBuffer.append( reinterpret_cast< const char* >( buffer.getConstArray() ), nRead );
+
+    if ( nRead > 0 )
+        aBuffer.append( reinterpret_cast< const char* >( buffer.getConstArray() ), nRead );
+
+    xStream->closeInput();
+
+    // get the important bits of info
+    OUString aHeaderURL, aFooterURL, aTextColor, aAccentColor, aPreviewURL, aName;
+
+    if ( !parsePersonaInfo( aBuffer.makeStringAndClear(), &aHeaderURL, &aFooterURL, &aTextColor, &aAccentColor, &aPreviewURL, &aName ) )
+        return false;
+
+    // copy the images to the user's gallery
+    OUString gallery = "${$BRAND_BASE_DIR/" LIBO_ETC_FOLDER "/" SAL_CONFIGFILE( "bootstrap") "::UserInstallation}";
+    rtl::Bootstrap::expandMacros( gallery );
+    gallery += "/user/gallery/personas/" + aName + "/";
+    osl::Directory::createPath( gallery );
+
+    OUString aPreviewFile( INetURLObject( aPreviewURL ).getName() );
+
+    try {
+        xFileAccess->copy( aPreviewURL, gallery + aPreviewFile );
+    }
+    catch ( const uno::Exception & )
+    {
+        return false;
+    }
+    *pPreviewFile = gallery + aPreviewFile;
+    *pPersonaSetting = aName + ";" + aHeaderURL + ";" + aFooterURL + ";" + aTextColor + ";" + aAccentColor;
+    return true;
+}
+
+}
+
 void SearchAndParseThread::execute()
 {
     if( m_aURL.startsWith( "https://" ) )
     {
         m_pPersonaDialog->ClearSearchResults();
-        OUString sProgress( CUI_RES( RID_SVXSTR_SEARCHING ) );
+        OUString sProgress( CuiResId( RID_SVXSTR_SEARCHING ) ), sError;
         m_pPersonaDialog->SetProgress( sProgress );
+
+        PersonasDocHandler* pHandler = new PersonasDocHandler();
         Reference<XComponentContext> xContext( ::comphelper::getProcessComponentContext() );
         Reference< xml::sax::XParser > xParser = xml::sax::Parser::create(xContext);
-        PersonasDocHandler* pHandler = new PersonasDocHandler();
         Reference< xml::sax::XDocumentHandler > xDocHandler = pHandler;
         uno::Reference< ucb::XSimpleFileAccess3 > xFileAccess( ucb::SimpleFileAccess::create( comphelper::getProcessComponentContext() ), uno::UNO_QUERY );
         uno::Reference< io::XInputStream > xStream;
         xParser->setDocumentHandler( xDocHandler );
 
-        if ( !xFileAccess.is() )
-            return;
-
-        try {
-            xStream = xFileAccess->openFileRead( m_aURL );
-        }
-        catch (...)
+        if( !m_bDirectURL )
         {
-            sProgress = CUI_RES(RID_SVXSTR_SEARCHERROR);
-            sProgress = sProgress.replaceAll("%1", m_aURL);
-            m_pPersonaDialog->SetProgress(sProgress);
-            return;
+            if ( !xFileAccess.is() )
+                return;
+
+            try {
+                css:: uno::Reference< task::XInteractionHandler > xIH(
+                    css::task::InteractionHandler::createWithParent( xContext, nullptr ) );
+
+                xFileAccess->setInteractionHandler( new comphelper::SimpleFileAccessInteraction( xIH ) );
+
+                xStream = xFileAccess->openFileRead( m_aURL );
+                if( !xStream.is() )
+                {
+                    // in case of a returned CommandFailedException
+                    // SimpleFileAccess serves it, returning an empty stream
+                    SolarMutexGuard aGuard;
+                    sError = CuiResId(RID_SVXSTR_SEARCHERROR);
+                    sError = sError.replaceAll("%1", m_aURL);
+                    m_pPersonaDialog->SetProgress( OUString() );
+                    ScopedVclPtrInstance< ErrorBox > aBox( nullptr, MessBoxStyle::Ok, sError);
+                    aBox->Execute();
+                    return;
+                }
+            }
+            catch (...)
+            {
+                // a catch all clause, in case the exception is not
+                // served elsewhere
+                SolarMutexGuard aGuard;
+                sError = CuiResId(RID_SVXSTR_SEARCHERROR);
+                sError = sError.replaceAll("%1", m_aURL);
+                m_pPersonaDialog->SetProgress( OUString() );
+                ScopedVclPtrInstance< ErrorBox > aBox( nullptr, MessBoxStyle::Ok, sError );
+                aBox->Execute();
+                return;
+            }
+
+            xml::sax::InputSource aParserInput;
+            aParserInput.aInputStream = xStream;
+            xParser->parseStream( aParserInput );
+
+            if( !pHandler->hasResults() )
+            {
+                sProgress = CuiResId( RID_SVXSTR_NORESULTS );
+                m_pPersonaDialog->SetProgress( sProgress );
+                return;
+            }
         }
 
-        xml::sax::InputSource aParserInput;
-        aParserInput.aInputStream = xStream;
-        xParser->parseStream( aParserInput );
-
-        if( !pHandler->hasResults() )
-        {
-            sProgress = CUI_RES( RID_SVXSTR_NORESULTS );
-            m_pPersonaDialog->SetProgress( sProgress );
-            return;
-        }
-
-        std::vector<OUString> vLearnmoreURLs = pHandler->getLearnmoreURLs();
+        std::vector<OUString> vLearnmoreURLs;
         std::vector<OUString>::iterator it;
         sal_Int32 nIndex = 0;
         GraphicFilter aFilter;
         Graphic aGraphic;
 
-        for( it = vLearnmoreURLs.begin(); it!=vLearnmoreURLs.end(); ++it )
+        if( !m_bDirectURL )
+            vLearnmoreURLs = pHandler->getLearnmoreURLs();
+        else
+            vLearnmoreURLs.push_back( m_aURL );
+
+        for( it = vLearnmoreURLs.begin(); it!=vLearnmoreURLs.end() && nIndex < MAX_RESULTS; ++it )
         {
             OUString sPreviewFile, aPersonaSetting;
-            getPreviewFile( *it, &sPreviewFile, &aPersonaSetting );
+            bool bResult = getPreviewFile( *it, &sPreviewFile, &aPersonaSetting );
+            // parsing is buggy at times, as HTML is not proper. Skip it.
+            if(aPersonaSetting.isEmpty() || !bResult)
+            {
+                if( m_bDirectURL )
+                {
+                    SolarMutexGuard aGuard;
+                    sError = CuiResId(RID_SVXSTR_SEARCHERROR);
+                    sError = sError.replaceAll("%1", m_aURL);
+                    m_pPersonaDialog->SetProgress( OUString() );
+                    ScopedVclPtrInstance< ErrorBox > aBox( nullptr, MessBoxStyle::Ok, sError);
+                    aBox->Execute();
+                    return;
+                }
+                continue;
+            }
             INetURLObject aURLObj( sPreviewFile );
             aFilter.ImportGraphic( aGraphic, aURLObj );
             Bitmap aBmp = aGraphic.GetBitmap();
@@ -638,14 +787,14 @@ void SearchAndParseThread::execute()
             return;
 
         SolarMutexGuard aGuard;
-        sProgress = "";
+        sProgress.clear();
         m_pPersonaDialog->SetProgress( sProgress );
         m_pPersonaDialog->setOptimalLayoutSize();
     }
 
     else
     {
-        OUString sProgress( CUI_RES( RID_SVXSTR_APPLYPERSONA ) );
+        OUString sProgress( CuiResId( RID_SVXSTR_APPLYPERSONA ) ), sError;
         m_pPersonaDialog->SetProgress( sProgress );
 
         uno::Reference< ucb::XSimpleFileAccess3 > xFileAccess( ucb::SimpleFileAccess::create( comphelper::getProcessComponentContext() ), uno::UNO_QUERY );
@@ -694,9 +843,12 @@ void SearchAndParseThread::execute()
         }
         catch ( const uno::Exception & )
         {
-            sProgress = CUI_RES( RID_SVXSTR_SEARCHERROR );
-            sProgress = sProgress.replaceAll("%1", m_aURL);
-            m_pPersonaDialog->SetProgress( sProgress );
+            SolarMutexGuard aGuard;
+            sError = CuiResId( RID_SVXSTR_SEARCHERROR );
+            sError = sError.replaceAll("%1", m_aURL);
+            m_pPersonaDialog->SetProgress( OUString() );
+            ScopedVclPtrInstance< ErrorBox > aBox( nullptr, MessBoxStyle::Ok, sError);
+            aBox->Execute();
             return;
         }
 
@@ -711,66 +863,4 @@ void SearchAndParseThread::execute()
     }
 }
 
-void SearchAndParseThread::getPreviewFile( const OUString& rURL, OUString *pPreviewFile, OUString *pPersonaSetting )
-{
-    uno::Reference< ucb::XSimpleFileAccess3 > xFileAccess( ucb::SimpleFileAccess::create( comphelper::getProcessComponentContext() ), uno::UNO_QUERY );
-    if ( !xFileAccess.is() )
-        return;
-
-    uno::Reference< io::XInputStream > xStream;
-    try {
-        xStream = xFileAccess->openFileRead( rURL );
-    }
-    catch (...)
-    {
-        OUString sProgress( CUI_RES( RID_SVXSTR_SEARCHERROR ) );
-        sProgress = sProgress.replaceAll("%1", m_aURL);
-        m_pPersonaDialog->SetProgress( sProgress );
-        return;
-    }
-    if ( !xStream.is() )
-        return;
-
-    // read the persona specification
-    // NOTE: Parsing for real is an overkill here; and worse - I tried, and
-    // the HTML the site provides is not 100% valid ;-)
-    const sal_Int32 BUF_LEN = 8000;
-    uno::Sequence< sal_Int8 > buffer( BUF_LEN );
-    OStringBuffer aBuffer( 64000 );
-
-    sal_Int32 nRead = 0;
-    while ( ( nRead = xStream->readBytes( buffer, BUF_LEN ) ) == BUF_LEN )
-        aBuffer.append( reinterpret_cast< const char* >( buffer.getConstArray() ), nRead );
-
-    if ( nRead > 0 )
-        aBuffer.append( reinterpret_cast< const char* >( buffer.getConstArray() ), nRead );
-
-    xStream->closeInput();
-
-    // get the important bits of info
-    OUString aHeaderURL, aFooterURL, aTextColor, aAccentColor, aPreviewURL, aName;
-
-    if ( !parsePersonaInfo( aBuffer.makeStringAndClear(), &aHeaderURL, &aFooterURL, &aTextColor, &aAccentColor, &aPreviewURL, &aName ) )
-        return;
-
-    // copy the images to the user's gallery
-    OUString gallery = "${$BRAND_BASE_DIR/" LIBO_ETC_FOLDER "/" SAL_CONFIGFILE( "bootstrap") "::UserInstallation}";
-    rtl::Bootstrap::expandMacros( gallery );
-    gallery += "/user/gallery/personas/";
-    gallery += aName + "/";
-    osl::Directory::createPath( gallery );
-
-    OUString aPreviewFile( INetURLObject( aPreviewURL ).getName() );
-
-    try {
-        xFileAccess->copy( aPreviewURL, gallery + aPreviewFile );
-    }
-    catch ( const uno::Exception & )
-    {
-        return;
-    }
-    *pPreviewFile = gallery + aPreviewFile;
-    *pPersonaSetting = aName + ";" + aHeaderURL + ";" + aFooterURL + ";" + aTextColor + ";" + aAccentColor;
-}
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
