@@ -19,7 +19,6 @@
 
 #include "webconninfo.hxx"
 #include <dialmgr.hxx>
-#include <cuires.hrc>
 #include <sal/macros.h>
 #include <com/sun/star/task/InteractionHandler.hpp>
 #include <com/sun/star/task/PasswordContainer.hpp>
@@ -27,7 +26,7 @@
 #include <com/sun/star/task/XPasswordContainer2.hpp>
 #include <comphelper/processfactory.hxx>
 #include <comphelper/docpasswordrequest.hxx>
-#include "svtools/treelistentry.hxx"
+#include <svtools/treelistentry.hxx>
 #include <vcl/layout.hxx>
 
 using namespace ::com::sun::star;
@@ -96,7 +95,7 @@ void PasswordTable::setColWidths()
         GetSizePixel().Width() - nUserNameWidth);
     long aStaticTabs[]= { 2, 0, 0 };
     aStaticTabs[2] = nWebSiteWidth;
-    SvSimpleTable::SetTabs(aStaticTabs, MAP_PIXEL);
+    SvSimpleTable::SetTabs(aStaticTabs, MapUnit::MapPixel);
 }
 
 // class WebConnectionInfoDialog -----------------------------------------
@@ -113,7 +112,7 @@ WebConnectionInfoDialog::WebConnectionInfoDialog(vcl::Window* pParent)
     SvSimpleTableContainer *pPasswordsLBContainer = get<SvSimpleTableContainer>("logins");
     m_pPasswordsLB = VclPtr<PasswordTable>::Create(*pPasswordsLBContainer, 0);
 
-    long aStaticTabs[]= { 2, 0, 0 };
+    long const aStaticTabs[]= { 2, 0, 0 };
     m_pPasswordsLB->SetTabs( aStaticTabs );
     m_pPasswordsLB->InsertHeaderItem( 1, get<FixedText>("website")->GetText(),
         HeaderBarItemBits::LEFT | HeaderBarItemBits::VCENTER | HeaderBarItemBits::FIXEDPOS | HeaderBarItemBits::CLICKABLE | HeaderBarItemBits::UPARROW );
@@ -154,7 +153,7 @@ void WebConnectionInfoDialog::dispose()
     ModalDialog::dispose();
 }
 
-IMPL_LINK_TYPED( WebConnectionInfoDialog, HeaderBarClickedHdl, SvSimpleTable*, pTable, void )
+IMPL_LINK( WebConnectionInfoDialog, HeaderBarClickedHdl, SvSimpleTable*, pTable, void )
 {
     m_pPasswordsLB->Resort( nullptr == pTable );
 }
@@ -190,7 +189,7 @@ void WebConnectionInfoDialog::FillPasswordList()
             m_nPos = nCount;
 
             uno::Sequence< OUString > aUrls
-                = xMasterPasswd->getUrls( sal_True /* OnlyPersistent */ );
+                = xMasterPasswd->getUrls( true /* OnlyPersistent */ );
 
             for ( sal_Int32 nURLIdx = 0; nURLIdx < aUrls.getLength(); nURLIdx++ )
             {
@@ -205,7 +204,7 @@ void WebConnectionInfoDialog::FillPasswordList()
 }
 
 
-IMPL_LINK_NOARG_TYPED(WebConnectionInfoDialog, RemovePasswordHdl, Button*, void)
+IMPL_LINK_NOARG(WebConnectionInfoDialog, RemovePasswordHdl, Button*, void)
 {
     try
     {
@@ -235,7 +234,7 @@ IMPL_LINK_NOARG_TYPED(WebConnectionInfoDialog, RemovePasswordHdl, Button*, void)
 }
 
 
-IMPL_LINK_NOARG_TYPED(WebConnectionInfoDialog, RemoveAllPasswordsHdl, Button*, void)
+IMPL_LINK_NOARG(WebConnectionInfoDialog, RemoveAllPasswordsHdl, Button*, void)
 {
     try
     {
@@ -246,7 +245,7 @@ IMPL_LINK_NOARG_TYPED(WebConnectionInfoDialog, RemoveAllPasswordsHdl, Button*, v
         xPasswdContainer->removeAllPersistent();
 
         uno::Sequence< OUString > aUrls
-            = xPasswdContainer->getUrls( sal_True /* OnlyPersistent */ );
+            = xPasswdContainer->getUrls( true /* OnlyPersistent */ );
         for ( sal_Int32 nURLIdx = 0; nURLIdx < aUrls.getLength(); nURLIdx++ )
             xPasswdContainer->removeUrl( aUrls[ nURLIdx ] );
 
@@ -257,7 +256,7 @@ IMPL_LINK_NOARG_TYPED(WebConnectionInfoDialog, RemoveAllPasswordsHdl, Button*, v
 }
 
 
-IMPL_LINK_NOARG_TYPED(WebConnectionInfoDialog, ChangePasswordHdl, Button*, void)
+IMPL_LINK_NOARG(WebConnectionInfoDialog, ChangePasswordHdl, Button*, void)
 {
     try
     {
@@ -268,7 +267,7 @@ IMPL_LINK_NOARG_TYPED(WebConnectionInfoDialog, ChangePasswordHdl, Button*, void)
             OUString aUserName = SvTabListBox::GetEntryText( pEntry, 1 );
 
             ::comphelper::SimplePasswordRequest* pPasswordRequest
-                  = new ::comphelper::SimplePasswordRequest( task::PasswordRequestMode_PASSWORD_CREATE );
+                  = new ::comphelper::SimplePasswordRequest;
             uno::Reference< task::XInteractionRequest > rRequest( pPasswordRequest );
 
             uno::Reference< task::XInteractionHandler > xInteractionHandler(
@@ -293,7 +292,7 @@ IMPL_LINK_NOARG_TYPED(WebConnectionInfoDialog, ChangePasswordHdl, Button*, void)
 }
 
 
-IMPL_LINK_NOARG_TYPED(WebConnectionInfoDialog, EntrySelectedHdl, SvTreeListBox*, void)
+IMPL_LINK_NOARG(WebConnectionInfoDialog, EntrySelectedHdl, SvTreeListBox*, void)
 {
     SvTreeListEntry* pEntry = m_pPasswordsLB->GetCurEntry();
     if ( !pEntry )
