@@ -19,17 +19,17 @@
 
 #include <sfx2/app.hxx>
 #include <sfx2/module.hxx>
-#include <tools/shl.hxx>
 
-#include <cuires.hrc>
 #include <svx/dialogs.hrc>
 
-#include "textanim.hxx"
-#include "textattr.hxx"
+#include <textanim.hxx>
+#include <textattr.hxx>
 #include <dialmgr.hxx>
-#include "svx/dlgutil.hxx"
+#include <svx/dlgutil.hxx>
+#include <svx/svdmark.hxx>
+#include <svx/svdview.hxx>
 
-static sal_uInt16 pRanges[] =
+const sal_uInt16 SvxTextAnimationPage::pRanges[] =
 {
     SDRATTR_TEXT_ANIKIND,
     SDRATTR_TEXT_ANIAMOUNT,
@@ -42,7 +42,7 @@ static sal_uInt16 pRanges[] =
 |*
 \************************************************************************/
 
-SvxTextTabDialog::SvxTextTabDialog( Window* pParent,
+SvxTextTabDialog::SvxTextTabDialog( vcl::Window* pParent,
                                 const SfxItemSet* pAttr,
                                 const SdrView* pSdrView ) :
         SfxTabDialog        ( pParent
@@ -51,8 +51,8 @@ SvxTextTabDialog::SvxTextTabDialog( Window* pParent,
                               , pAttr ),
         pView               ( pSdrView )
 {
-    m_nTextId = AddTabPage( "RID_SVXPAGE_TEXTATTR", SvxTextAttrPage::Create, 0);
-    m_nTextAnimId = AddTabPage( "RID_SVXPAGE_TEXTANIMATION", SvxTextAnimationPage::Create, 0);
+    m_nTextId = AddTabPage( "RID_SVXPAGE_TEXTATTR", SvxTextAttrPage::Create, nullptr);
+    AddTabPage( "RID_SVXPAGE_TEXTANIMATION", SvxTextAnimationPage::Create, nullptr);
 }
 
 /*************************************************************************
@@ -64,10 +64,21 @@ SvxTextTabDialog::SvxTextTabDialog( Window* pParent,
 void SvxTextTabDialog::PageCreated( sal_uInt16 nId, SfxTabPage &rPage )
 {
     if (nId == m_nTextId)
+    {
+        const SdrMarkList& rMarkList = pView->GetMarkedObjectList();
+        bool bHasMarked = rMarkList.GetMarkCount() > 0;
+        SdrObjKind eKind = OBJ_NONE;
+        if (bHasMarked)
         {
-            ( (SvxTextAttrPage&) rPage ).SetView( pView );
-            ( (SvxTextAttrPage&) rPage ).Construct();
+            if (rMarkList.GetMarkCount() == 1)
+            {
+                const SdrObject* pObj = rMarkList.GetMark(0)->GetMarkedSdrObj();
+                eKind = (SdrObjKind)pObj->GetObjIdentifier();
+            }
         }
+        static_cast<SvxTextAttrPage&>(rPage).SetObjKind(eKind);
+        static_cast<SvxTextAttrPage&>(rPage).Construct();
+    }
 }
 
 
@@ -77,13 +88,14 @@ void SvxTextTabDialog::PageCreated( sal_uInt16 nId, SfxTabPage &rPage )
 |*
 \************************************************************************/
 
-SvxTextAnimationPage::SvxTextAnimationPage( Window* pWindow, const SfxItemSet& rInAttrs ) :
-                SfxTabPage      ( pWindow
-                                  ,"TextAnimation"
-                                  ,"cui/ui/textanimtabpage.ui"
-                                  ,rInAttrs ),
-                rOutAttrs       ( rInAttrs ),
-                eAniKind        ( SDRTEXTANI_NONE )
+SvxTextAnimationPage::SvxTextAnimationPage(vcl::Window* pWindow, const SfxItemSet& rInAttrs)
+    : SfxTabPage(pWindow, "TextAnimation", "cui/ui/textanimtabpage.ui", &rInAttrs)
+    , rOutAttrs(rInAttrs)
+    , eAniKind(SdrTextAniKind::NONE)
+    , m_aUpState(TRISTATE_INDET)
+    , m_aLeftState(TRISTATE_INDET)
+    , m_aRightState(TRISTATE_INDET)
+    , m_aDownState(TRISTATE_INDET)
 {
     get(m_pLbEffect, "LB_EFFECT");
     get(m_pBoxDirection,"boxDIRECTION");
@@ -108,7 +120,7 @@ SvxTextAnimationPage::SvxTextAnimationPage( Window* pWindow, const SfxItemSet& r
 
     eFUnit = GetModuleFieldUnit( rInAttrs );
     SfxItemPool* pPool = rOutAttrs.GetPool();
-    DBG_ASSERT( pPool, "Wo ist der Pool" );
+    DBG_ASSERT( pPool, "Where is the pool?" );
     eUnit = pPool->GetMetric( SDRATTR_TEXT_LEFTDIST );
 
     m_pLbEffect->SetSelectHdl( LINK( this, SvxTextAnimationPage, SelectEffectHdl_Impl ) );
@@ -116,21 +128,37 @@ SvxTextAnimationPage::SvxTextAnimationPage( Window* pWindow, const SfxItemSet& r
     m_pTsbAuto->SetClickHdl( LINK( this, SvxTextAnimationPage, ClickAutoHdl_Impl ) );
     m_pTsbPixel->SetClickHdl( LINK( this, SvxTextAnimationPage, ClickPixelHdl_Impl ) );
 
-    Link aLink( LINK( this, SvxTextAnimationPage, ClickDirectionHdl_Impl ) );
+    Link<Button*,void> aLink( LINK( this, SvxTextAnimationPage, ClickDirectionHdl_Impl ) );
     m_pBtnUp->SetClickHdl( aLink );
     m_pBtnLeft->SetClickHdl( aLink );
     m_pBtnRight->SetClickHdl( aLink );
     m_pBtnDown->SetClickHdl( aLink );
 }
 
-/*************************************************************************
-|*
-|* Dtor
-|*
-\************************************************************************/
-
 SvxTextAnimationPage::~SvxTextAnimationPage()
 {
+    disposeOnce();
+}
+
+void SvxTextAnimationPage::dispose()
+{
+    m_pLbEffect.clear();
+    m_pBoxDirection.clear();
+    m_pBtnUp.clear();
+    m_pBtnLeft.clear();
+    m_pBtnRight.clear();
+    m_pBtnDown.clear();
+    m_pFlProperties.clear();
+    m_pTsbStartInside.clear();
+    m_pTsbStopInside.clear();
+    m_pBoxCount.clear();
+    m_pTsbEndless.clear();
+    m_pNumFldCount.clear();
+    m_pTsbPixel.clear();
+    m_pMtrFldAmount.clear();
+    m_pTsbAuto.clear();
+    m_pMtrFldDelay.clear();
+    SfxTabPage::dispose();
 }
 
 /*************************************************************************
@@ -139,148 +167,148 @@ SvxTextAnimationPage::~SvxTextAnimationPage()
 |*
 \************************************************************************/
 
-void SvxTextAnimationPage::Reset( const SfxItemSet& rAttrs )
+void SvxTextAnimationPage::Reset( const SfxItemSet* rAttrs )
 {
-    const SfxItemPool* pPool = rAttrs.GetPool();
+    const SfxItemPool* pPool = rAttrs->GetPool();
 
     // animation type
-    const SfxPoolItem* pItem = GetItem( rAttrs, SDRATTR_TEXT_ANIKIND );
+    const SfxPoolItem* pItem = GetItem( *rAttrs, SDRATTR_TEXT_ANIKIND );
 
     if( !pItem )
         pItem = &pPool->GetDefaultItem( SDRATTR_TEXT_ANIKIND );
     if( pItem )
     {
-        eAniKind = ( ( const SdrTextAniKindItem* )pItem )->GetValue();
-        m_pLbEffect->SelectEntryPos( sal::static_int_cast< sal_uInt16 >(eAniKind) );
+        eAniKind = static_cast<const SdrTextAniKindItem*>(pItem)->GetValue();
+        m_pLbEffect->SelectEntryPos( sal::static_int_cast< sal_Int32 >(eAniKind) );
     }
     else
         m_pLbEffect->SetNoSelection();
     m_pLbEffect->SaveValue();
 
     // animation direction
-    pItem = GetItem( rAttrs, SDRATTR_TEXT_ANIDIRECTION );
+    pItem = GetItem( *rAttrs, SDRATTR_TEXT_ANIDIRECTION );
     if( !pItem )
         pItem = &pPool->GetDefaultItem( SDRATTR_TEXT_ANIDIRECTION );
     if( pItem )
     {
-        SdrTextAniDirection eValue = ( ( const SdrTextAniDirectionItem* )pItem )->GetValue();
+        SdrTextAniDirection eValue = static_cast<const SdrTextAniDirectionItem*>(pItem)->GetValue();
         SelectDirection( eValue );
     }
     else
     {
-        m_pBtnUp->Check( sal_False );
-        m_pBtnLeft->Check( sal_False );
-        m_pBtnRight->Check( sal_False );
-        m_pBtnDown->Check( sal_False );
+        m_pBtnUp->Check( false );
+        m_pBtnLeft->Check( false );
+        m_pBtnRight->Check( false );
+        m_pBtnDown->Check( false );
     }
-    m_pBtnUp->SaveValue();
-    m_pBtnLeft->SaveValue();
-    m_pBtnRight->SaveValue();
-    m_pBtnDown->SaveValue();
+    m_aUpState = m_pBtnUp->GetState();
+    m_aLeftState = m_pBtnLeft->GetState();
+    m_aRightState = m_pBtnRight->GetState();
+    m_aDownState = m_pBtnDown->GetState();
 
     // Start inside
-    pItem = GetItem( rAttrs, SDRATTR_TEXT_ANISTARTINSIDE );
+    pItem = GetItem( *rAttrs, SDRATTR_TEXT_ANISTARTINSIDE );
     if( !pItem )
         pItem = &pPool->GetDefaultItem( SDRATTR_TEXT_ANISTARTINSIDE );
     if( pItem )
     {
-        m_pTsbStartInside->EnableTriState( sal_False );
-        sal_Bool bValue = ( ( const SdrTextAniStartInsideItem* )pItem )->GetValue();
+        m_pTsbStartInside->EnableTriState( false );
+        bool bValue = static_cast<const SdrTextAniStartInsideItem*>(pItem)->GetValue();
         if( bValue )
-            m_pTsbStartInside->SetState( STATE_CHECK );
+            m_pTsbStartInside->SetState( TRISTATE_TRUE );
         else
-            m_pTsbStartInside->SetState( STATE_NOCHECK );
+            m_pTsbStartInside->SetState( TRISTATE_FALSE );
     }
     else
-        m_pTsbStartInside->SetState( STATE_DONTKNOW );
+        m_pTsbStartInside->SetState( TRISTATE_INDET );
     m_pTsbStartInside->SaveValue();
 
     // Stop inside
-    pItem = GetItem( rAttrs, SDRATTR_TEXT_ANISTOPINSIDE );
+    pItem = GetItem( *rAttrs, SDRATTR_TEXT_ANISTOPINSIDE );
     if( !pItem )
         pItem = &pPool->GetDefaultItem( SDRATTR_TEXT_ANISTOPINSIDE );
     if( pItem )
     {
-        m_pTsbStopInside->EnableTriState( sal_False );
-        sal_Bool bValue = ( ( const SdrTextAniStopInsideItem* )pItem )->GetValue();
+        m_pTsbStopInside->EnableTriState( false );
+        bool bValue = static_cast<const SdrTextAniStopInsideItem*>(pItem)->GetValue();
         if( bValue )
-            m_pTsbStopInside->SetState( STATE_CHECK );
+            m_pTsbStopInside->SetState( TRISTATE_TRUE );
         else
-            m_pTsbStopInside->SetState( STATE_NOCHECK );
+            m_pTsbStopInside->SetState( TRISTATE_FALSE );
     }
     else
-        m_pTsbStopInside->SetState( STATE_DONTKNOW );
+        m_pTsbStopInside->SetState( TRISTATE_INDET );
     m_pTsbStopInside->SaveValue();
 
     // quantity
-    pItem = GetItem( rAttrs, SDRATTR_TEXT_ANICOUNT );
+    pItem = GetItem( *rAttrs, SDRATTR_TEXT_ANICOUNT );
     if( !pItem )
         pItem = &pPool->GetDefaultItem( SDRATTR_TEXT_ANICOUNT );
     if( pItem )
     {
-        m_pTsbEndless->EnableTriState( sal_False );
-        long nValue = (long) ( ( const SdrTextAniCountItem* )pItem )->GetValue();
+        m_pTsbEndless->EnableTriState( false );
+        long nValue = (long) static_cast<const SdrTextAniCountItem*>(pItem)->GetValue();
         m_pNumFldCount->SetValue( nValue );
         if( nValue == 0 )
         {
-            if( eAniKind == SDRTEXTANI_SLIDE )
+            if( eAniKind == SdrTextAniKind::Slide )
             {
-                m_pTsbEndless->SetState( STATE_NOCHECK );
-                m_pTsbEndless->Enable( sal_False );
+                m_pTsbEndless->SetState( TRISTATE_FALSE );
+                m_pTsbEndless->Enable( false );
             }
             else
             {
-                m_pTsbEndless->SetState( STATE_CHECK );
+                m_pTsbEndless->SetState( TRISTATE_TRUE );
                 m_pNumFldCount->SetEmptyFieldValue();
             }
         }
         else
-            m_pTsbEndless->SetState( STATE_NOCHECK );
+            m_pTsbEndless->SetState( TRISTATE_FALSE );
     }
     else
     {
         m_pNumFldCount->SetEmptyFieldValue();
-        m_pTsbEndless->SetState( STATE_DONTKNOW );
+        m_pTsbEndless->SetState( TRISTATE_INDET );
     }
     m_pTsbEndless->SaveValue();
     m_pNumFldCount->SaveValue();
 
     // delay
-    pItem = GetItem( rAttrs, SDRATTR_TEXT_ANIDELAY );
+    pItem = GetItem( *rAttrs, SDRATTR_TEXT_ANIDELAY );
     if( !pItem )
         pItem = &pPool->GetDefaultItem( SDRATTR_TEXT_ANIDELAY );
     if( pItem )
     {
-        m_pTsbAuto->EnableTriState( sal_False );
-        long nValue = (long) ( ( const SdrTextAniDelayItem* )pItem )->GetValue();
+        m_pTsbAuto->EnableTriState( false );
+        long nValue = (long) static_cast<const SdrTextAniDelayItem*>(pItem)->GetValue();
         m_pMtrFldDelay->SetValue( nValue );
         if( nValue == 0 )
         {
-            m_pTsbAuto->SetState( STATE_CHECK );
+            m_pTsbAuto->SetState( TRISTATE_TRUE );
             m_pMtrFldDelay->SetEmptyFieldValue();
         }
         else
-            m_pTsbAuto->SetState( STATE_NOCHECK );
+            m_pTsbAuto->SetState( TRISTATE_FALSE );
     }
     else
     {
         m_pMtrFldDelay->SetEmptyFieldValue();
-        m_pTsbAuto->SetState( STATE_DONTKNOW );
+        m_pTsbAuto->SetState( TRISTATE_INDET );
     }
     m_pTsbAuto->SaveValue();
     m_pMtrFldDelay->SaveValue();
 
     // step size
-    pItem = GetItem( rAttrs, SDRATTR_TEXT_ANIAMOUNT );
+    pItem = GetItem( *rAttrs, SDRATTR_TEXT_ANIAMOUNT );
     if( !pItem )
         pItem = &pPool->GetDefaultItem( SDRATTR_TEXT_ANIAMOUNT );
     if( pItem )
     {
-        m_pTsbPixel->EnableTriState( sal_False );
-        long nValue = (long) ( ( const SdrTextAniAmountItem* )pItem )->GetValue();
+        m_pTsbPixel->EnableTriState( false );
+        long nValue = (long) static_cast<const SdrTextAniAmountItem*>(pItem)->GetValue();
         if( nValue <= 0 )
         {
-            m_pTsbPixel->SetState( STATE_CHECK );
+            m_pTsbPixel->SetState( TRISTATE_TRUE );
             nValue = -nValue;
             if( nValue == 0 )
                 nValue++;
@@ -297,7 +325,7 @@ void SvxTextAnimationPage::Reset( const SfxItemSet& rAttrs )
         }
         else
         {
-            m_pTsbPixel->SetState( STATE_NOCHECK );
+            m_pTsbPixel->SetState( TRISTATE_FALSE );
             m_pMtrFldAmount->SetUnit( eFUnit );
             m_pMtrFldAmount->SetDecimalDigits( 2 );
 
@@ -314,15 +342,15 @@ void SvxTextAnimationPage::Reset( const SfxItemSet& rAttrs )
     {
         m_pMtrFldAmount->Disable();
         m_pMtrFldAmount->SetEmptyFieldValue();
-        m_pTsbPixel->SetState( STATE_DONTKNOW );
+        m_pTsbPixel->SetState( TRISTATE_INDET );
     }
     m_pTsbPixel->SaveValue();
     m_pMtrFldAmount->SaveValue();
 
 
-    SelectEffectHdl_Impl( NULL );
-    ClickEndlessHdl_Impl( NULL );
-    ClickAutoHdl_Impl( NULL );
+    SelectEffectHdl_Impl( *m_pLbEffect );
+    ClickEndlessHdl_Impl( nullptr );
+    ClickAutoHdl_Impl( nullptr );
     //ClickPixelHdl_Impl( NULL );
 }
 
@@ -332,98 +360,98 @@ void SvxTextAnimationPage::Reset( const SfxItemSet& rAttrs )
 |*
 \************************************************************************/
 
-sal_Bool SvxTextAnimationPage::FillItemSet( SfxItemSet& rAttrs)
+bool SvxTextAnimationPage::FillItemSet( SfxItemSet* rAttrs)
 {
-    sal_Bool bModified = sal_False;
-    sal_uInt16 nPos;
+    bool bModified = false;
+    sal_Int32 nPos;
     TriState eState;
 
     // animation type
-    nPos = m_pLbEffect->GetSelectEntryPos();
+    nPos = m_pLbEffect->GetSelectedEntryPos();
     if( nPos != LISTBOX_ENTRY_NOTFOUND &&
-        nPos != m_pLbEffect->GetSavedValue() )
+        m_pLbEffect->IsValueChangedFromSaved() )
     {
-        rAttrs.Put( SdrTextAniKindItem( (SdrTextAniKind) nPos ) );
-        bModified = sal_True;
+        rAttrs->Put( SdrTextAniKindItem( (SdrTextAniKind) nPos ) );
+        bModified = true;
     }
 
     // animation direction
-    if( m_pBtnUp->GetSavedValue() != m_pBtnUp->IsChecked() ||
-        m_pBtnLeft->GetSavedValue() != m_pBtnLeft->IsChecked() ||
-        m_pBtnRight->GetSavedValue() != m_pBtnRight->IsChecked() ||
-        m_pBtnDown->GetSavedValue() != m_pBtnDown->IsChecked() )
+    if (m_aUpState != m_pBtnUp->GetState() ||
+        m_aLeftState != m_pBtnLeft->GetState() ||
+        m_aRightState != m_pBtnRight->GetState() ||
+        m_aDownState != m_pBtnDown->GetState())
     {
         SdrTextAniDirection eValue = (SdrTextAniDirection) GetSelectedDirection();
-        rAttrs.Put( SdrTextAniDirectionItem( eValue ) );
-        bModified = sal_True;
+        rAttrs->Put( SdrTextAniDirectionItem( eValue ) );
+        bModified = true;
     }
 
     // Start inside
     eState = m_pTsbStartInside->GetState();
-    if( eState != m_pTsbStartInside->GetSavedValue() )
+    if( m_pTsbStartInside->IsValueChangedFromSaved() )
     {
-        rAttrs.Put( SdrTextAniStartInsideItem( (sal_Bool) STATE_CHECK == eState ) );
-        bModified = sal_True;
+        rAttrs->Put( SdrTextAniStartInsideItem( TRISTATE_TRUE == eState ) );
+        bModified = true;
     }
 
     // Stop inside
     eState = m_pTsbStopInside->GetState();
-    if( eState != m_pTsbStopInside->GetSavedValue() )
+    if( m_pTsbStopInside->IsValueChangedFromSaved() )
     {
-        rAttrs.Put( SdrTextAniStopInsideItem( (sal_Bool) STATE_CHECK == eState ) );
-        bModified = sal_True;
+        rAttrs->Put( SdrTextAniStopInsideItem( TRISTATE_TRUE == eState ) );
+        bModified = true;
     }
 
     // quantity
     eState = m_pTsbEndless->GetState();
     OUString aStr = m_pNumFldCount->GetText();
-    if( eState != m_pTsbEndless->GetSavedValue() ||
-        aStr != m_pNumFldCount->GetSavedValue() )
+    if( m_pTsbEndless->IsValueChangedFromSaved() ||
+        m_pNumFldCount->IsValueChangedFromSaved() )
     {
         sal_Int64 nValue = 0;
-        if( eState == STATE_CHECK /*#89844#*/ && m_pTsbEndless->IsEnabled())
-            bModified = sal_True;
+        if( eState == TRISTATE_TRUE /*#89844#*/ && m_pTsbEndless->IsEnabled())
+            bModified = true;
         else
         {
-            if( aStr != m_pNumFldCount->GetSavedValue() )
+            if( m_pNumFldCount->IsValueChangedFromSaved() )
             {
                 nValue = m_pNumFldCount->GetValue();
-                bModified = sal_True;
+                bModified = true;
             }
         }
         if( bModified )
-            rAttrs.Put( SdrTextAniCountItem( (sal_uInt16) nValue ) );
+            rAttrs->Put( SdrTextAniCountItem( (sal_uInt16) nValue ) );
     }
 
     // delay
     eState = m_pTsbAuto->GetState();
     aStr = m_pMtrFldDelay->GetText();
-    if( eState != m_pTsbAuto->GetSavedValue() ||
-        aStr != m_pMtrFldDelay->GetSavedValue() )
+    if( m_pTsbAuto->IsValueChangedFromSaved() ||
+        m_pMtrFldDelay->IsValueChangedFromSaved() )
     {
         sal_Int64 nValue = 0;
-        if( eState == STATE_CHECK )
-            bModified = sal_True;
+        if( eState == TRISTATE_TRUE )
+            bModified = true;
         else
         {
-            if( aStr != m_pMtrFldDelay->GetSavedValue() )
+            if( m_pMtrFldDelay->IsValueChangedFromSaved() )
             {
                 nValue = m_pMtrFldDelay->GetValue();
-                bModified = sal_True;
+                bModified = true;
             }
         }
         if( bModified )
-            rAttrs.Put( SdrTextAniDelayItem( (sal_uInt16) nValue ) );
+            rAttrs->Put( SdrTextAniDelayItem( (sal_uInt16) nValue ) );
     }
 
     // step size
     eState = m_pTsbPixel->GetState();
     aStr = m_pMtrFldAmount->GetText();
-    if( eState != m_pTsbPixel->GetSavedValue() ||
-        aStr != m_pMtrFldAmount->GetSavedValue() )
+    if( m_pTsbPixel->IsValueChangedFromSaved() ||
+        m_pMtrFldAmount->IsValueChangedFromSaved() )
     {
         sal_Int64 nValue = 0;
-        if( eState == STATE_CHECK )
+        if( eState == TRISTATE_TRUE )
         {
             nValue = m_pMtrFldAmount->GetValue();
             nValue = -nValue;
@@ -432,17 +460,12 @@ sal_Bool SvxTextAnimationPage::FillItemSet( SfxItemSet& rAttrs)
         {
             nValue = GetCoreValue( *m_pMtrFldAmount, eUnit );
         }
-        rAttrs.Put( SdrTextAniAmountItem( (sal_Int16) nValue ) );
+        rAttrs->Put( SdrTextAniAmountItem( (sal_Int16) nValue ) );
 
-        bModified = sal_True;
+        bModified = true;
     }
 
-    return( bModified );
-}
-
-sal_uInt16* SvxTextAnimationPage::GetRanges()
-{
-    return( pRanges );
+    return bModified;
 }
 
 /*************************************************************************
@@ -451,34 +474,34 @@ sal_uInt16* SvxTextAnimationPage::GetRanges()
 |*
 \************************************************************************/
 
-SfxTabPage* SvxTextAnimationPage::Create( Window* pWindow,
-                const SfxItemSet& rAttrs )
+VclPtr<SfxTabPage> SvxTextAnimationPage::Create( vcl::Window* pWindow,
+                                                 const SfxItemSet* rAttrs )
 {
-    return( new SvxTextAnimationPage( pWindow, rAttrs ) );
+    return VclPtr<SvxTextAnimationPage>::Create( pWindow, *rAttrs );
 }
 
-IMPL_LINK_NOARG(SvxTextAnimationPage, SelectEffectHdl_Impl)
+IMPL_LINK_NOARG(SvxTextAnimationPage, SelectEffectHdl_Impl, ListBox&, void)
 {
-    sal_uInt16 nPos = m_pLbEffect->GetSelectEntryPos();
+    sal_Int32 nPos = m_pLbEffect->GetSelectedEntryPos();
     if( nPos != LISTBOX_ENTRY_NOTFOUND )
     {
         eAniKind = (SdrTextAniKind) nPos;
         switch( eAniKind )
         {
-            case SDRTEXTANI_NONE:
+            case SdrTextAniKind::NONE:
             {
                 m_pBoxDirection->Disable();
                 m_pFlProperties->Disable();
             }
             break;
 
-            case SDRTEXTANI_BLINK:
-            case SDRTEXTANI_SCROLL:
-            case SDRTEXTANI_ALTERNATE:
-            case SDRTEXTANI_SLIDE:
+            case SdrTextAniKind::Blink:
+            case SdrTextAniKind::Scroll:
+            case SdrTextAniKind::Alternate:
+            case SdrTextAniKind::Slide:
             {
                 m_pFlProperties->Enable();
-                if( eAniKind == SDRTEXTANI_SLIDE )
+                if( eAniKind == SdrTextAniKind::Slide )
                 {
                     m_pTsbStartInside->Disable();
                     m_pTsbStopInside->Disable();
@@ -491,13 +514,13 @@ IMPL_LINK_NOARG(SvxTextAnimationPage, SelectEffectHdl_Impl)
                     m_pTsbStartInside->Enable();
                     m_pTsbStopInside->Enable();
                     m_pTsbEndless->Enable();
-                    ClickEndlessHdl_Impl( NULL );
+                    ClickEndlessHdl_Impl( nullptr );
                 }
 
                 m_pTsbAuto->Enable();
-                ClickAutoHdl_Impl( NULL );
+                ClickAutoHdl_Impl( nullptr );
 
-                if( eAniKind == SDRTEXTANI_BLINK )
+                if( eAniKind == SdrTextAniKind::Blink )
                 {
                     m_pBoxDirection->Disable();
                     m_pBoxCount->Disable();
@@ -512,16 +535,15 @@ IMPL_LINK_NOARG(SvxTextAnimationPage, SelectEffectHdl_Impl)
         }
 
     }
-    return( 0L );
 }
 
-IMPL_LINK_NOARG(SvxTextAnimationPage, ClickEndlessHdl_Impl)
+IMPL_LINK_NOARG(SvxTextAnimationPage, ClickEndlessHdl_Impl, Button*, void)
 {
 
-    if( eAniKind != SDRTEXTANI_SLIDE )
+    if( eAniKind != SdrTextAniKind::Slide )
     {
         TriState eState = m_pTsbEndless->GetState();
-        if( eState != STATE_NOCHECK )
+        if( eState != TRISTATE_FALSE )
         {
             m_pNumFldCount->Disable();
             m_pNumFldCount->SetEmptyFieldValue();
@@ -532,13 +554,12 @@ IMPL_LINK_NOARG(SvxTextAnimationPage, ClickEndlessHdl_Impl)
             m_pNumFldCount->SetValue( m_pNumFldCount->GetValue() );
         }
     }
-    return( 0L );
 }
 
-IMPL_LINK_NOARG(SvxTextAnimationPage, ClickAutoHdl_Impl)
+IMPL_LINK_NOARG(SvxTextAnimationPage, ClickAutoHdl_Impl, Button*, void)
 {
     TriState eState = m_pTsbAuto->GetState();
-    if( eState != STATE_NOCHECK )
+    if( eState != TRISTATE_FALSE )
     {
         m_pMtrFldDelay->Disable();
         m_pMtrFldDelay->SetEmptyFieldValue();
@@ -548,14 +569,12 @@ IMPL_LINK_NOARG(SvxTextAnimationPage, ClickAutoHdl_Impl)
         m_pMtrFldDelay->Enable();
         m_pMtrFldDelay->SetValue( m_pMtrFldDelay->GetValue() );
     }
-
-    return( 0L );
 }
 
-IMPL_LINK_NOARG(SvxTextAnimationPage, ClickPixelHdl_Impl)
+IMPL_LINK_NOARG(SvxTextAnimationPage, ClickPixelHdl_Impl, Button*, void)
 {
     TriState eState = m_pTsbPixel->GetState();
-    if( eState == STATE_CHECK )
+    if( eState == TRISTATE_TRUE )
     {
         sal_Int64 nValue = m_pMtrFldAmount->GetValue() / 10;
         m_pMtrFldAmount->Enable();
@@ -571,7 +590,7 @@ IMPL_LINK_NOARG(SvxTextAnimationPage, ClickPixelHdl_Impl)
 
         m_pMtrFldAmount->SetValue( nValue );
     }
-    else if( eState == STATE_NOCHECK )
+    else if( eState == TRISTATE_FALSE )
     {
         sal_Int64 nValue = m_pMtrFldAmount->GetValue() * 10;
         m_pMtrFldAmount->Enable();
@@ -587,42 +606,38 @@ IMPL_LINK_NOARG(SvxTextAnimationPage, ClickPixelHdl_Impl)
 
         m_pMtrFldAmount->SetValue( nValue );
     }
-
-    return( 0L );
 }
 
-IMPL_LINK( SvxTextAnimationPage, ClickDirectionHdl_Impl, ImageButton *, pBtn )
+IMPL_LINK( SvxTextAnimationPage, ClickDirectionHdl_Impl, Button *, pBtn, void )
 {
     m_pBtnUp->Check( pBtn == m_pBtnUp );
     m_pBtnLeft->Check( pBtn == m_pBtnLeft );
     m_pBtnRight->Check( pBtn == m_pBtnRight );
     m_pBtnDown->Check( pBtn == m_pBtnDown );
-
-    return( 0L );
 }
 
 void SvxTextAnimationPage::SelectDirection( SdrTextAniDirection nValue )
 {
-    m_pBtnUp->Check( nValue == SDRTEXTANI_UP );
-    m_pBtnLeft->Check( nValue == SDRTEXTANI_LEFT );
-    m_pBtnRight->Check( nValue == SDRTEXTANI_RIGHT );
-    m_pBtnDown->Check( nValue == SDRTEXTANI_DOWN );
+    m_pBtnUp->Check( nValue == SdrTextAniDirection::Up );
+    m_pBtnLeft->Check( nValue == SdrTextAniDirection::Left );
+    m_pBtnRight->Check( nValue == SdrTextAniDirection::Right );
+    m_pBtnDown->Check( nValue == SdrTextAniDirection::Down );
 }
 
 sal_uInt16 SvxTextAnimationPage::GetSelectedDirection()
 {
-    sal_uInt16 nValue = 0;
+    SdrTextAniDirection nValue = SdrTextAniDirection::Left;
 
     if( m_pBtnUp->IsChecked() )
-        nValue = SDRTEXTANI_UP;
+        nValue = SdrTextAniDirection::Up;
     else if( m_pBtnLeft->IsChecked() )
-        nValue = SDRTEXTANI_LEFT;
+        nValue = SdrTextAniDirection::Left;
     else if( m_pBtnRight->IsChecked() )
-        nValue = SDRTEXTANI_RIGHT;
+        nValue = SdrTextAniDirection::Right;
     else if( m_pBtnDown->IsChecked() )
-        nValue = SDRTEXTANI_DOWN;
+        nValue = SdrTextAniDirection::Down;
 
-    return( nValue );
+    return (sal_uInt16)nValue;
 }
 
 
