@@ -18,8 +18,9 @@
  */
 
 #include "CacheSet.hxx"
-#include "core_resource.hxx"
-#include "core_resource.hrc"
+#include <core_resource.hxx>
+#include <strings.hrc>
+#include <strings.hxx>
 #include <com/sun/star/sdbcx/CompareBookmark.hpp>
 #include <com/sun/star/sdbc/XResultSetMetaDataSupplier.hpp>
 #include <com/sun/star/beans/XPropertySet.hpp>
@@ -27,7 +28,7 @@
 #include <com/sun/star/sdbc/XPreparedStatement.hpp>
 #include <com/sun/star/sdbc/ColumnValue.hpp>
 #include <com/sun/star/sdbc/XParameters.hpp>
-#include "dbastrings.hrc"
+#include <stringconstants.hxx>
 #include <com/sun/star/sdbcx/XKeysSupplier.hpp>
 #include <com/sun/star/sdbcx/XIndexesSupplier.hpp>
 
@@ -38,7 +39,6 @@
 #include <comphelper/extract.hxx>
 #include <com/sun/star/io/XInputStream.hpp>
 #include <comphelper/types.hxx>
-#include <tools/debug.hxx>
 #include <rtl/ustrbuf.hxx>
 
 using namespace comphelper;
@@ -55,22 +55,18 @@ using namespace ::com::sun::star::lang;
 using namespace ::com::sun::star::io;
 using namespace ::osl;
 
-DBG_NAME(OCacheSet)
 
 OCacheSet::OCacheSet(sal_Int32 i_nMaxRows)
             :m_nMaxRows(i_nMaxRows)
-            ,m_bInserted(sal_False)
-            ,m_bUpdated(sal_False)
-            ,m_bDeleted(sal_False)
+            ,m_bInserted(false)
+            ,m_bUpdated(false)
+            ,m_bDeleted(false)
 {
-    SAL_INFO("dbaccess", "OCacheSet::OCacheSet" );
-    DBG_CTOR(OCacheSet,NULL);
 
 }
 
 OUString OCacheSet::getIdentifierQuoteString() const
 {
-    SAL_INFO("dbaccess", "OCacheSet::getIdentifierQuoteString" );
     OUString sQuote;
     Reference<XDatabaseMetaData> xMeta;
     if ( m_xConnection.is() && (xMeta = m_xConnection->getMetaData()).is() )
@@ -78,10 +74,12 @@ OUString OCacheSet::getIdentifierQuoteString() const
     return sQuote;
 }
 
-void OCacheSet::construct(  const Reference< XResultSet>& _xDriverSet,const OUString& /*i_sRowSetFilter*/)
+void OCacheSet::construct(  const Reference< XResultSet>& _xDriverSet,const OUString &i_sRowSetFilter)
 {
-    SAL_INFO("dbaccess", "OCacheSet::construct" );
     OSL_ENSURE(_xDriverSet.is(),"Invalid resultSet");
+
+    m_sRowSetFilter = i_sRowSetFilter;
+
     if(_xDriverSet.is())
     {
         m_xDriverSet = _xDriverSet;
@@ -90,12 +88,12 @@ void OCacheSet::construct(  const Reference< XResultSet>& _xDriverSet,const OUSt
         if ( m_xSetMetaData.is() )
         {
             const sal_Int32 nCount = m_xSetMetaData->getColumnCount();
-            m_aNullable.realloc(nCount);
-            m_aSignedFlags.realloc(nCount);
-            m_aColumnTypes.realloc(nCount);
-            sal_Bool* pNullableIter = m_aNullable.getArray();
-            sal_Bool* pSignedIter = m_aSignedFlags.getArray();
-            sal_Int32* pColumnIter = m_aColumnTypes.getArray();
+            m_aNullable.resize(nCount);
+            m_aSignedFlags.resize(nCount);
+            m_aColumnTypes.resize(nCount);
+            auto pNullableIter = m_aNullable.begin();
+            auto pSignedIter = m_aSignedFlags.begin();
+            auto pColumnIter = m_aColumnTypes.begin();
             for (sal_Int32 i=1; i <= nCount; ++i,++pSignedIter,++pColumnIter,++pNullableIter)
             {
                 *pNullableIter = m_xSetMetaData->isNullable(i) != ColumnValue::NO_NULLS;
@@ -119,10 +117,10 @@ OCacheSet::~OCacheSet()
 {
     try
     {
-        m_xDriverSet = NULL;
-        m_xDriverRow = NULL;
-        m_xSetMetaData = NULL;
-        m_xConnection = NULL;
+        m_xDriverSet = nullptr;
+        m_xDriverRow = nullptr;
+        m_xSetMetaData = nullptr;
+        m_xConnection = nullptr;
     }
     catch(Exception&)
     {
@@ -133,12 +131,10 @@ OCacheSet::~OCacheSet()
         SAL_WARN("dbaccess", "Unknown Exception occurred");
     }
 
-    DBG_DTOR(OCacheSet,NULL);
 }
 
-void OCacheSet::fillTableName(const Reference<XPropertySet>& _xTable)  throw(SQLException, RuntimeException)
+void OCacheSet::fillTableName(const Reference<XPropertySet>& _xTable)
 {
-    SAL_INFO("dbaccess", "OCacheSet::fillTableName" );
     OSL_ENSURE(_xTable.is(),"OCacheSet::fillTableName: PropertySet is empty!");
     if(m_aComposedTableName.isEmpty() && _xTable.is() )
     {
@@ -147,14 +143,13 @@ void OCacheSet::fillTableName(const Reference<XPropertySet>& _xTable)  throw(SQL
                         ,comphelper::getString(_xTable->getPropertyValue(PROPERTY_CATALOGNAME))
                         ,comphelper::getString(_xTable->getPropertyValue(PROPERTY_SCHEMANAME))
                         ,comphelper::getString(_xTable->getPropertyValue(PROPERTY_NAME))
-                        ,sal_True
-                        ,::dbtools::eInDataManipulation);
+                        ,true
+                        ,::dbtools::EComposeRule::InDataManipulation);
     }
 }
 
-void SAL_CALL OCacheSet::insertRow( const ORowSetRow& _rInsertRow,const connectivity::OSQLTable& _xTable ) throw(SQLException, RuntimeException)
+void SAL_CALL OCacheSet::insertRow( const ORowSetRow& _rInsertRow,const connectivity::OSQLTable& _xTable )
 {
-    SAL_INFO("dbaccess", "OCacheSet::insertRow" );
     Reference<XPropertySet> xSet(_xTable,UNO_QUERY);
     fillTableName(xSet);
 
@@ -162,16 +157,14 @@ void SAL_CALL OCacheSet::insertRow( const ORowSetRow& _rInsertRow,const connecti
 
     // set values and column names
     OUStringBuffer aValues(" VALUES ( ");
-    static OUString aPara("?,");
     OUString aQuote = getIdentifierQuoteString();
-    static OUString aComma(",");
     sal_Int32 i = 1;
     ORowVector< ORowSetValue >::Vector::const_iterator aIter = _rInsertRow->get().begin()+1;
     connectivity::ORowVector< ORowSetValue > ::Vector::iterator aEnd = _rInsertRow->get().end();
     for(; aIter != aEnd;++aIter)
     {
-        aSql.append(::dbtools::quoteName( aQuote,m_xSetMetaData->getColumnName(i++)) + aComma);
-        aValues.append(aPara);
+        aSql.append(::dbtools::quoteName( aQuote,m_xSetMetaData->getColumnName(i++)) + ",");
+        aValues.append("?,");
     }
 
     aSql[aSql.getLength() - 1] = ')';
@@ -201,9 +194,8 @@ void OCacheSet::fillParameters( const ORowSetRow& _rRow
                                         ,const connectivity::OSQLTable& _xTable
                                         ,OUStringBuffer& _sCondition
                                         ,OUStringBuffer& _sParameter
-                                        ,::std::list< sal_Int32>& _rOrgValues)
+                                        ,std::vector< sal_Int32>& _rOrgValues)
 {
-    SAL_INFO("dbaccess", "OCacheSet::fillParameters" );
     // use keys and indexes for exact positioning
     // first the keys
     Reference<XPropertySet> xSet(_xTable,UNO_QUERY);
@@ -214,10 +206,8 @@ void OCacheSet::fillParameters( const ORowSetRow& _rRow
     if(xIndexSup.is())
         xIndexes.set(xIndexSup->getIndexes(),UNO_QUERY);
 
-    //  Reference<XColumnsSupplier>
     Reference<XPropertySet> xIndexColsSup;
-    Reference<XNameAccess> xIndexColumns;
-    ::std::vector< Reference<XNameAccess> > aAllIndexColumns;
+    std::vector< Reference<XNameAccess> > aAllIndexColumns;
     if(xIndexes.is())
     {
         for(sal_Int32 j=0;j<xIndexes->getCount();++j)
@@ -233,12 +223,11 @@ void OCacheSet::fillParameters( const ORowSetRow& _rRow
 
     OUString aColumnName;
 
-    static OUString aPara("?,");
-    static OUString aAnd(" AND ");
+    static const char aAnd[] = " AND ";
 
     OUString aQuote  = getIdentifierQuoteString();
 
-    sal_Int32 nCheckCount = 1; // index for the orginal values
+    sal_Int32 nCheckCount = 1; // index for the original values
     sal_Int32 i = 1;
 
     OUString sIsNull(" IS NULL");
@@ -259,8 +248,8 @@ void OCacheSet::fillParameters( const ORowSetRow& _rRow
             _rOrgValues.push_back(nCheckCount);
 
         }
-        ::std::vector< Reference<XNameAccess> >::const_iterator aIndexEnd = aAllIndexColumns.end();
-        for( ::std::vector< Reference<XNameAccess> >::const_iterator aIndexIter = aAllIndexColumns.begin();
+        std::vector< Reference<XNameAccess> >::const_iterator aIndexEnd = aAllIndexColumns.end();
+        for( std::vector< Reference<XNameAccess> >::const_iterator aIndexIter = aAllIndexColumns.begin();
                 aIndexIter != aIndexEnd;++aIndexIter)
         {
             if((*aIndexIter)->hasByName(aColumnName))
@@ -277,22 +266,21 @@ void OCacheSet::fillParameters( const ORowSetRow& _rRow
         }
         if(aIter->isModified())
         {
-            _sParameter.append(::dbtools::quoteName( aQuote,aColumnName) + aPara);
+            _sParameter.append(::dbtools::quoteName( aQuote,aColumnName) + "?,");
         }
     }
 }
 
-void SAL_CALL OCacheSet::updateRow(const ORowSetRow& _rInsertRow ,const ORowSetRow& _rOrginalRow,const connectivity::OSQLTable& _xTable  ) throw(SQLException, RuntimeException)
+void SAL_CALL OCacheSet::updateRow(const ORowSetRow& _rInsertRow ,const ORowSetRow& _rOriginalRow,const connectivity::OSQLTable& _xTable  )
 {
-    SAL_INFO("dbaccess", "OCacheSet::updateRow" );
     Reference<XPropertySet> xSet(_xTable,UNO_QUERY);
     fillTableName(xSet);
 
     OUStringBuffer aSql("UPDATE " + m_aComposedTableName + " SET ");
-    // list all cloumns that should be set
+    // list all columns that should be set
 
     OUStringBuffer aCondition;
-    ::std::list< sal_Int32> aOrgValues;
+    std::vector< sal_Int32> aOrgValues;
     fillParameters(_rInsertRow,_xTable,aCondition,aSql,aOrgValues);
     aSql[aSql.getLength() - 1] = ' ';
     if ( !aCondition.isEmpty() )
@@ -303,7 +291,7 @@ void SAL_CALL OCacheSet::updateRow(const ORowSetRow& _rInsertRow ,const ORowSetR
     }
     else
         ::dbtools::throwSQLException(
-            DBACORE_RESSTRING( RID_STR_NO_UPDATE_MISSING_CONDITION ), SQL_GENERAL_ERROR, *this );
+            DBA_RES( RID_STR_NO_UPDATE_MISSING_CONDITION ), StandardSQLState::GENERAL_ERROR, *this );
 
     // now create end execute the prepared statement
     Reference< XPreparedStatement > xPrep(m_xConnection->prepareStatement(aSql.makeStringAndClear()));
@@ -318,18 +306,17 @@ void SAL_CALL OCacheSet::updateRow(const ORowSetRow& _rInsertRow ,const ORowSetR
             ++i;
         }
     }
-    ::std::list< sal_Int32>::const_iterator aOrgValueEnd = aOrgValues.end();
-    for(::std::list< sal_Int32>::const_iterator aOrgValue = aOrgValues.begin(); aOrgValue != aOrgValueEnd;++aOrgValue,++i)
+    auto aOrgValueEnd = aOrgValues.cend();
+    for(auto aOrgValue = aOrgValues.cbegin(); aOrgValue != aOrgValueEnd;++aOrgValue,++i)
     {
-        setParameter(i,xParameter,(_rOrginalRow->get())[*aOrgValue],m_xSetMetaData->getColumnType(i),m_xSetMetaData->getScale(i));
+        setParameter(i,xParameter,(_rOriginalRow->get())[*aOrgValue],m_xSetMetaData->getColumnType(i),m_xSetMetaData->getScale(i));
     }
 
      m_bUpdated = xPrep->executeUpdate() > 0;
 }
 
-void SAL_CALL OCacheSet::deleteRow(const ORowSetRow& _rDeleteRow ,const connectivity::OSQLTable& _xTable  ) throw(SQLException, RuntimeException)
+void SAL_CALL OCacheSet::deleteRow(const ORowSetRow& _rDeleteRow ,const connectivity::OSQLTable& _xTable  )
 {
-    SAL_INFO("dbaccess", "OCacheSet::deleteRow" );
     Reference<XPropertySet> xSet(_xTable,UNO_QUERY);
     fillTableName(xSet);
 
@@ -346,8 +333,7 @@ void SAL_CALL OCacheSet::deleteRow(const ORowSetRow& _rDeleteRow ,const connecti
 
     //  Reference<XColumnsSupplier>
     Reference<XPropertySet> xIndexColsSup;
-    Reference<XNameAccess> xIndexColumns;
-    ::std::vector< Reference<XNameAccess> > aAllIndexColumns;
+    std::vector< Reference<XNameAccess> > aAllIndexColumns;
     if(xIndexes.is())
     {
         for(sal_Int32 j=0;j<xIndexes->getCount();++j)
@@ -362,7 +348,7 @@ void SAL_CALL OCacheSet::deleteRow(const ORowSetRow& _rDeleteRow ,const connecti
     }
 
     OUStringBuffer aColumnName;
-    ::std::list< sal_Int32> aOrgValues;
+    std::vector< sal_Int32> aOrgValues;
     fillParameters(_rDeleteRow,_xTable,aSql,aColumnName,aOrgValues);
 
     aSql.setLength(aSql.getLength()-5);
@@ -371,8 +357,8 @@ void SAL_CALL OCacheSet::deleteRow(const ORowSetRow& _rDeleteRow ,const connecti
     Reference< XPreparedStatement > xPrep(m_xConnection->prepareStatement(aSql.makeStringAndClear()));
     Reference< XParameters > xParameter(xPrep,UNO_QUERY);
     sal_Int32 i = 1;
-    ::std::list< sal_Int32>::const_iterator aOrgValueEnd = aOrgValues.end();
-    for(::std::list< sal_Int32>::const_iterator j = aOrgValues.begin(); j != aOrgValueEnd;++j,++i)
+    auto aOrgValueEnd = aOrgValues.cend();
+    for(auto j = aOrgValues.cbegin(); j != aOrgValueEnd; ++j,++i)
     {
         setParameter(i,xParameter,(_rDeleteRow->get())[*j],m_xSetMetaData->getColumnType(i),m_xSetMetaData->getScale(i));
     }
@@ -384,19 +370,17 @@ void OCacheSet::setParameter(sal_Int32 nPos
                              ,const Reference< XParameters >& _xParameter
                              ,const ORowSetValue& _rValue
                              ,sal_Int32 _nType
-                             ,sal_Int32 _nScale) const
+                             ,sal_Int32 _nScale)
 {
-    SAL_INFO("dbaccess", "OCacheSet::setParameter" );
     sal_Int32 nType = ( _nType != DataType::OTHER ) ? _nType : _rValue.getTypeKind();
     ::dbtools::setObjectWithInfo(_xParameter,nPos,_rValue,nType,_nScale);
 }
 
 void OCacheSet::fillValueRow(ORowSetRow& _rRow,sal_Int32 _nPosition)
 {
-    SAL_INFO("dbaccess", "OCacheSet::fillValueRow" );
     Any aBookmark = getBookmark();
     if(!aBookmark.hasValue())
-        aBookmark = makeAny(_nPosition);
+        aBookmark <<= _nPosition;
 
     connectivity::ORowVector< ORowSetValue >::Vector::iterator aIter = _rRow->get().begin();
     connectivity::ORowVector< ORowSetValue >::Vector::iterator aEnd = _rRow->get().end();
@@ -409,269 +393,205 @@ void OCacheSet::fillValueRow(ORowSetRow& _rRow,sal_Int32 _nPosition)
     }
 }
 
-sal_Bool SAL_CALL OCacheSet::wasNull(  ) throw(SQLException, RuntimeException)
+sal_Bool SAL_CALL OCacheSet::wasNull(  )
 {
-    SAL_INFO("dbaccess", "OCacheSet::wasNull" );
     return m_xDriverRow->wasNull();
 }
 
-OUString SAL_CALL OCacheSet::getString( sal_Int32 columnIndex ) throw(SQLException, RuntimeException)
+OUString SAL_CALL OCacheSet::getString( sal_Int32 columnIndex )
 {
-    SAL_INFO("dbaccess", "OCacheSet::getString" );
     return m_xDriverRow->getString(columnIndex);
 }
 
-sal_Bool SAL_CALL OCacheSet::getBoolean( sal_Int32 columnIndex ) throw(SQLException, RuntimeException)
+sal_Bool SAL_CALL OCacheSet::getBoolean( sal_Int32 columnIndex )
 {
-    SAL_INFO("dbaccess", "OCacheSet::getBoolean" );
     return m_xDriverRow->getBoolean(columnIndex);
 }
 
-sal_Int8 SAL_CALL OCacheSet::getByte( sal_Int32 columnIndex ) throw(SQLException, RuntimeException)
+sal_Int8 SAL_CALL OCacheSet::getByte( sal_Int32 columnIndex )
 {
-    SAL_INFO("dbaccess", "OCacheSet::getByte" );
     return m_xDriverRow->getByte(columnIndex);
 }
 
-sal_Int16 SAL_CALL OCacheSet::getShort( sal_Int32 columnIndex ) throw(SQLException, RuntimeException)
+sal_Int16 SAL_CALL OCacheSet::getShort( sal_Int32 columnIndex )
 {
-    SAL_INFO("dbaccess", "OCacheSet::getShort" );
     return m_xDriverRow->getShort(columnIndex);
 }
 
-sal_Int32 SAL_CALL OCacheSet::getInt( sal_Int32 columnIndex ) throw(SQLException, RuntimeException)
+sal_Int32 SAL_CALL OCacheSet::getInt( sal_Int32 columnIndex )
 {
-    SAL_INFO("dbaccess", "OCacheSet::getInt" );
     return m_xDriverRow->getInt(columnIndex);
 }
 
-sal_Int64 SAL_CALL OCacheSet::getLong( sal_Int32 columnIndex ) throw(SQLException, RuntimeException)
+sal_Int64 SAL_CALL OCacheSet::getLong( sal_Int32 columnIndex )
 {
-    SAL_INFO("dbaccess", "OCacheSet::getLong" );
     return m_xDriverRow->getLong(columnIndex);
 }
 
-float SAL_CALL OCacheSet::getFloat( sal_Int32 columnIndex ) throw(SQLException, RuntimeException)
+float SAL_CALL OCacheSet::getFloat( sal_Int32 columnIndex )
 {
-    SAL_INFO("dbaccess", "OCacheSet::getFloat" );
     return m_xDriverRow->getFloat(columnIndex);
 }
 
-double SAL_CALL OCacheSet::getDouble( sal_Int32 columnIndex ) throw(SQLException, RuntimeException)
+double SAL_CALL OCacheSet::getDouble( sal_Int32 columnIndex )
 {
-    SAL_INFO("dbaccess", "OCacheSet::getDouble" );
     return m_xDriverRow->getDouble(columnIndex);
 }
 
-Sequence< sal_Int8 > SAL_CALL OCacheSet::getBytes( sal_Int32 columnIndex ) throw(SQLException, RuntimeException)
+Sequence< sal_Int8 > SAL_CALL OCacheSet::getBytes( sal_Int32 columnIndex )
 {
-    SAL_INFO("dbaccess", "OCacheSet::getBytes" );
     return m_xDriverRow->getBytes(columnIndex);
 }
 
-::com::sun::star::util::Date SAL_CALL OCacheSet::getDate( sal_Int32 columnIndex ) throw(SQLException, RuntimeException)
+css::util::Date SAL_CALL OCacheSet::getDate( sal_Int32 columnIndex )
 {
-    SAL_INFO("dbaccess", "OCacheSet::getDate" );
     return m_xDriverRow->getDate(columnIndex);
 }
 
-::com::sun::star::util::Time SAL_CALL OCacheSet::getTime( sal_Int32 columnIndex ) throw(SQLException, RuntimeException)
+css::util::Time SAL_CALL OCacheSet::getTime( sal_Int32 columnIndex )
 {
-    SAL_INFO("dbaccess", "OCacheSet::getTime" );
     return m_xDriverRow->getTime(columnIndex);
 }
 
-::com::sun::star::util::DateTime SAL_CALL OCacheSet::getTimestamp( sal_Int32 columnIndex ) throw(SQLException, RuntimeException)
+css::util::DateTime SAL_CALL OCacheSet::getTimestamp( sal_Int32 columnIndex )
 {
-    SAL_INFO("dbaccess", "OCacheSet::getTimestamp" );
     return m_xDriverRow->getTimestamp(columnIndex);
 }
 
-Reference< ::com::sun::star::io::XInputStream > SAL_CALL OCacheSet::getBinaryStream( sal_Int32 columnIndex ) throw(SQLException, RuntimeException)
+Reference< css::io::XInputStream > SAL_CALL OCacheSet::getBinaryStream( sal_Int32 columnIndex )
 {
-    SAL_INFO("dbaccess", "OCacheSet::getBinaryStream" );
     return m_xDriverRow->getBinaryStream(columnIndex);
 }
 
-Reference< ::com::sun::star::io::XInputStream > SAL_CALL OCacheSet::getCharacterStream( sal_Int32 columnIndex ) throw(SQLException, RuntimeException)
+Reference< css::io::XInputStream > SAL_CALL OCacheSet::getCharacterStream( sal_Int32 columnIndex )
 {
-    SAL_INFO("dbaccess", "OCacheSet::getCharacterStream" );
     return m_xDriverRow->getCharacterStream(columnIndex);
 }
 
-Any SAL_CALL OCacheSet::getObject( sal_Int32 columnIndex, const Reference< ::com::sun::star::container::XNameAccess >& typeMap ) throw(SQLException, RuntimeException)
+Any SAL_CALL OCacheSet::getObject( sal_Int32 columnIndex, const Reference< css::container::XNameAccess >& typeMap )
 {
-    SAL_INFO("dbaccess", "OCacheSet::getObject" );
     return m_xDriverRow->getObject(columnIndex,typeMap);
 }
 
-Reference< XRef > SAL_CALL OCacheSet::getRef( sal_Int32 columnIndex ) throw(SQLException, RuntimeException)
+Reference< XRef > SAL_CALL OCacheSet::getRef( sal_Int32 columnIndex )
 {
-    SAL_INFO("dbaccess", "OCacheSet::getRef" );
     return m_xDriverRow->getRef(columnIndex);
 }
 
-Reference< XBlob > SAL_CALL OCacheSet::getBlob( sal_Int32 columnIndex ) throw(SQLException, RuntimeException)
+Reference< XBlob > SAL_CALL OCacheSet::getBlob( sal_Int32 columnIndex )
 {
-    SAL_INFO("dbaccess", "OCacheSet::getBlob" );
     return m_xDriverRow->getBlob(columnIndex);
 }
 
-Reference< XClob > SAL_CALL OCacheSet::getClob( sal_Int32 columnIndex ) throw(SQLException, RuntimeException)
+Reference< XClob > SAL_CALL OCacheSet::getClob( sal_Int32 columnIndex )
 {
-    SAL_INFO("dbaccess", "OCacheSet::getClob" );
     return m_xDriverRow->getClob(columnIndex);
 }
 
-Reference< XArray > SAL_CALL OCacheSet::getArray( sal_Int32 columnIndex ) throw(SQLException, RuntimeException)
+Reference< XArray > SAL_CALL OCacheSet::getArray( sal_Int32 columnIndex )
 {
-    SAL_INFO("dbaccess", "OCacheSet::getArray" );
     return m_xDriverRow->getArray(columnIndex);
 }
 
 // XResultSet
-sal_Bool SAL_CALL OCacheSet::next(  ) throw(SQLException, RuntimeException)
+bool SAL_CALL OCacheSet::next()
 {
-    SAL_INFO("dbaccess", "OCacheSet::next" );
-    m_bInserted = m_bUpdated = m_bDeleted = sal_False;
+    m_bInserted = m_bUpdated = m_bDeleted = false;
     return m_xDriverSet->next();
 }
 
-sal_Bool SAL_CALL OCacheSet::isBeforeFirst(  ) throw(SQLException, RuntimeException)
+bool SAL_CALL OCacheSet::isBeforeFirst(  )
 {
-    SAL_INFO("dbaccess", "OCacheSet::isBeforeFirst" );
     return m_xDriverSet->isBeforeFirst();
 }
 
-sal_Bool SAL_CALL OCacheSet::isAfterLast(  ) throw(SQLException, RuntimeException)
+bool SAL_CALL OCacheSet::isAfterLast(  )
 {
-    SAL_INFO("dbaccess", "OCacheSet::isAfterLast" );
     return m_xDriverSet->isAfterLast();
 }
 
-sal_Bool SAL_CALL OCacheSet::isFirst(  ) throw(SQLException, RuntimeException)
+void SAL_CALL OCacheSet::beforeFirst(  )
 {
-    SAL_INFO("dbaccess", "OCacheSet::isFirst" );
-    return m_xDriverSet->isFirst();
-}
-
-sal_Bool SAL_CALL OCacheSet::isLast(  ) throw(SQLException, RuntimeException)
-{
-    SAL_INFO("dbaccess", "OCacheSet::isLast" );
-    return m_xDriverSet->isLast();
-}
-
-void SAL_CALL OCacheSet::beforeFirst(  ) throw(SQLException, RuntimeException)
-{
-    SAL_INFO("dbaccess", "OCacheSet::beforeFirst" );
-    m_bInserted = m_bUpdated = m_bDeleted = sal_False;
+    m_bInserted = m_bUpdated = m_bDeleted = false;
     m_xDriverSet->beforeFirst();
 }
 
-void SAL_CALL OCacheSet::afterLast(  ) throw(SQLException, RuntimeException)
+void SAL_CALL OCacheSet::afterLast(  )
 {
-    SAL_INFO("dbaccess", "OCacheSet::afterLast" );
-    m_bInserted = m_bUpdated = m_bDeleted = sal_False;
+    m_bInserted = m_bUpdated = m_bDeleted = false;
     m_xDriverSet->afterLast();
 }
 
-sal_Bool SAL_CALL OCacheSet::first(  ) throw(SQLException, RuntimeException)
+bool SAL_CALL OCacheSet::first()
 {
-    SAL_INFO("dbaccess", "OCacheSet::first" );
-    m_bInserted = m_bUpdated = m_bDeleted = sal_False;
+    m_bInserted = m_bUpdated = m_bDeleted = false;
     return m_xDriverSet->first();
 }
 
-sal_Bool SAL_CALL OCacheSet::last(  ) throw(SQLException, RuntimeException)
+bool SAL_CALL OCacheSet::last()
 {
-    SAL_INFO("dbaccess", "OCacheSet::last" );
-    m_bInserted = m_bUpdated = m_bDeleted = sal_False;
+    m_bInserted = m_bUpdated = m_bDeleted = false;
     return m_xDriverSet->last();
 }
 
-sal_Int32 SAL_CALL OCacheSet::getRow(  ) throw(SQLException, RuntimeException)
+sal_Int32 SAL_CALL OCacheSet::getRow(  )
 {
-    SAL_INFO("dbaccess", "OCacheSet::getRow" );
     return m_xDriverSet->getRow();
 }
 
-sal_Bool SAL_CALL OCacheSet::absolute( sal_Int32 row ) throw(SQLException, RuntimeException)
+bool SAL_CALL OCacheSet::absolute( sal_Int32 row )
 {
-    SAL_INFO("dbaccess", "OCacheSet::absolute" );
-    m_bInserted = m_bUpdated = m_bDeleted = sal_False;
+    m_bInserted = m_bUpdated = m_bDeleted = false;
     return m_xDriverSet->absolute(row);
 }
 
-sal_Bool SAL_CALL OCacheSet::relative( sal_Int32 rows ) throw(SQLException, RuntimeException)
+bool SAL_CALL OCacheSet::previous(  )
 {
-    SAL_INFO("dbaccess", "OCacheSet::relative" );
-    m_bInserted = m_bUpdated = m_bDeleted = sal_False;
-    return m_xDriverSet->relative(rows);
-}
-
-sal_Bool SAL_CALL OCacheSet::previous(  ) throw(SQLException, RuntimeException)
-{
-    SAL_INFO("dbaccess", "OCacheSet::previous" );
-    m_bInserted = m_bUpdated = m_bDeleted = sal_False;
+    m_bInserted = m_bUpdated = m_bDeleted = false;
     return m_xDriverSet->previous();
 }
 
-sal_Bool OCacheSet::last_checked( sal_Bool /*i_bFetchRow*/)
+bool OCacheSet::last_checked( bool /*i_bFetchRow*/)
 {
     return last();
 }
 
-sal_Bool OCacheSet::previous_checked( sal_Bool /*i_bFetchRow*/ )
+bool OCacheSet::previous_checked( bool /*i_bFetchRow*/ )
 {
     return previous();
 }
 
-sal_Bool OCacheSet::absolute_checked( sal_Int32 row,sal_Bool /*i_bFetchRow*/ )
+bool OCacheSet::absolute_checked( sal_Int32 row,bool /*i_bFetchRow*/ )
 {
     return absolute(row);
 }
 
-void SAL_CALL OCacheSet::refreshRow(  ) throw(SQLException, RuntimeException)
+void SAL_CALL OCacheSet::refreshRow(  )
 {
-    SAL_INFO("dbaccess", "OCacheSet::refreshRow" );
     m_xDriverSet->refreshRow();
 }
 
-sal_Bool SAL_CALL OCacheSet::rowUpdated(  ) throw(SQLException, RuntimeException)
+bool SAL_CALL OCacheSet::rowUpdated(  )
 {
-    SAL_INFO("dbaccess", "OCacheSet::rowUpdated" );
     return m_xDriverSet->rowUpdated();
 }
 
-sal_Bool SAL_CALL OCacheSet::rowInserted(  ) throw(SQLException, RuntimeException)
+bool SAL_CALL OCacheSet::rowInserted(  )
 {
-    SAL_INFO("dbaccess", "OCacheSet::rowInserted" );
     return m_xDriverSet->rowInserted();
 }
 
-sal_Bool SAL_CALL OCacheSet::rowDeleted(  ) throw(SQLException, RuntimeException)
+bool SAL_CALL OCacheSet::rowDeleted(  )
 {
-    SAL_INFO("dbaccess", "OCacheSet::rowDeleted" );
     return m_xDriverSet->rowDeleted();
 }
 
-Reference< XInterface > SAL_CALL OCacheSet::getStatement(  ) throw(SQLException, RuntimeException)
-{
-    SAL_INFO("dbaccess", "OCacheSet::getStatement" );
-    return m_xDriverSet->getStatement();
-}
-
 bool OCacheSet::isResultSetChanged() const
 {
     return false;
 }
 
-void OCacheSet::reset(const Reference< XResultSet>& /*_xDriverSet*/)
-{
-    SAL_WARN("dbaccess", "Illegal call!");
-}
-
-void OCacheSet::mergeColumnValues(sal_Int32 i_nColumnIndex,ORowSetValueVector::Vector& /*io_aInsertRow*/,ORowSetValueVector::Vector& /*io_aRow*/,::std::vector<sal_Int32>& o_aChangedColumns)
+void OCacheSet::mergeColumnValues(sal_Int32 i_nColumnIndex,ORowSetValueVector::Vector& /*io_aInsertRow*/,ORowSetValueVector::Vector& /*io_aRow*/,std::vector<sal_Int32>& o_aChangedColumns)
 {
     o_aChangedColumns.push_back(i_nColumnIndex);
 }
@@ -681,7 +601,7 @@ bool OCacheSet::columnValuesUpdated(ORowSetValueVector::Vector& /*io_aCachedRow*
     return false;
 }
 
-bool OCacheSet::updateColumnValues(const ORowSetValueVector::Vector& /*io_aCachedRow*/,ORowSetValueVector::Vector& /*io_aRow*/,const ::std::vector<sal_Int32>& /*i_aChangedColumns*/)
+bool OCacheSet::updateColumnValues(const ORowSetValueVector::Vector& /*io_aCachedRow*/,ORowSetValueVector::Vector& /*io_aRow*/,const std::vector<sal_Int32>& /*i_aChangedColumns*/)
 {
     return true;
 }
