@@ -18,7 +18,7 @@
  */
 
 #include <string.h>
-#include "ContentHelper.hxx"
+#include <ContentHelper.hxx>
 #include <rtl/ustrbuf.hxx>
 #include <ucbhelper/cancelcommandexecution.hxx>
 #include <comphelper/property.hxx>
@@ -27,14 +27,14 @@
 #include <com/sun/star/lang/IllegalAccessException.hpp>
 #include <com/sun/star/io/XOutputStream.hpp>
 #include <com/sun/star/io/XActiveDataSink.hpp>
+#include <com/sun/star/beans/IllegalTypeException.hpp>
 #include <com/sun/star/beans/PropertyAttribute.hpp>
 #include <ucbhelper/propertyvalueset.hxx>
 #include <ucbhelper/contentidentifier.hxx>
 #include "myucp_resultset.hxx"
 #include <com/sun/star/container/XNameContainer.hpp>
-#include "sdbcoretools.hxx"
-#include "dbastrings.hrc"
-#include <tools/debug.hxx>
+#include <sdbcoretools.hxx>
+#include <stringconstants.hxx>
 
 namespace dbaccess
 {
@@ -67,7 +67,6 @@ OContentHelper::OContentHelper(const Reference< XComponentContext >& _xORB
     ,m_aPropertyChangeListeners(m_aMutex)
     ,m_xParentContainer( _xParentContainer )
     ,m_aContext( _xORB )
-    ,m_aErrorHelper( m_aContext )
     ,m_pImpl(_pImpl)
     ,m_nCommandId(0)
 {
@@ -88,7 +87,7 @@ IMPLEMENT_SERVICE_INFO1(OContentHelper,"com.sun.star.comp.sdb.Content","com.sun.
 IMPLEMENT_IMPLEMENTATION_ID(OContentHelper)
 
 // XContent
-Reference< XContentIdentifier > SAL_CALL OContentHelper::getIdentifier(  ) throw (RuntimeException, std::exception)
+Reference< XContentIdentifier > SAL_CALL OContentHelper::getIdentifier(  )
 {
     ::osl::MutexGuard aGuard(m_aMutex);
     OUString aIdentifier( "private:" + impl_getHierarchicalName( true ) );
@@ -119,7 +118,7 @@ OUString OContentHelper::impl_getHierarchicalName( bool _includingRootContainer
     return sHierarchicalName;
 }
 
-OUString SAL_CALL OContentHelper::getContentType() throw (RuntimeException, std::exception)
+OUString SAL_CALL OContentHelper::getContentType()
 {
     ::osl::MutexGuard aGuard(m_aMutex);
 
@@ -131,14 +130,14 @@ OUString SAL_CALL OContentHelper::getContentType() throw (RuntimeException, std:
     return *m_pImpl->m_aProps.aContentType;
 }
 
-void SAL_CALL OContentHelper::addContentEventListener( const Reference< XContentEventListener >& _rxListener ) throw (RuntimeException, std::exception)
+void SAL_CALL OContentHelper::addContentEventListener( const Reference< XContentEventListener >& _rxListener )
 {
     ::osl::MutexGuard aGuard(m_aMutex);
     if ( _rxListener.is() )
         m_aContentListeners.addInterface(_rxListener);
 }
 
-void SAL_CALL OContentHelper::removeContentEventListener( const Reference< XContentEventListener >& _rxListener ) throw (RuntimeException, std::exception)
+void SAL_CALL OContentHelper::removeContentEventListener( const Reference< XContentEventListener >& _rxListener )
 {
     ::osl::MutexGuard aGuard(m_aMutex);
     if (_rxListener.is())
@@ -146,14 +145,14 @@ void SAL_CALL OContentHelper::removeContentEventListener( const Reference< XCont
 }
 
 // XCommandProcessor
-sal_Int32 SAL_CALL OContentHelper::createCommandIdentifier(  ) throw (RuntimeException, std::exception)
+sal_Int32 SAL_CALL OContentHelper::createCommandIdentifier(  )
 {
     ::osl::MutexGuard aGuard(m_aMutex);
     // Just increase counter on every call to generate an identifier.
     return ++m_nCommandId;
 }
 
-Any SAL_CALL OContentHelper::execute( const Command& aCommand, sal_Int32 /*CommandId*/, const Reference< XCommandEnvironment >& Environment ) throw (Exception, CommandAbortedException, RuntimeException, std::exception)
+Any SAL_CALL OContentHelper::execute( const Command& aCommand, sal_Int32 /*CommandId*/, const Reference< XCommandEnvironment >& Environment )
 {
     Any aRet;
     if ( aCommand.Name == "getPropertyValues" )
@@ -203,7 +202,7 @@ Any SAL_CALL OContentHelper::execute( const Command& aCommand, sal_Int32 /*Comma
             // Unreachable
         }
 
-        aRet <<= setPropertyValues( aProperties, Environment );
+        aRet <<= setPropertyValues( aProperties );
     }
     else if ( aCommand.Name == "getPropertySetInfo" )
     {
@@ -231,12 +230,12 @@ Any SAL_CALL OContentHelper::execute( const Command& aCommand, sal_Int32 /*Comma
     return aRet;
 }
 
-void SAL_CALL OContentHelper::abort( sal_Int32 /*CommandId*/ ) throw (RuntimeException, std::exception)
+void SAL_CALL OContentHelper::abort( sal_Int32 /*CommandId*/ )
 {
 }
 
 // XPropertiesChangeNotifier
-void SAL_CALL OContentHelper::addPropertiesChangeListener( const Sequence< OUString >& PropertyNames, const Reference< XPropertiesChangeListener >& Listener ) throw (RuntimeException, std::exception)
+void SAL_CALL OContentHelper::addPropertiesChangeListener( const Sequence< OUString >& PropertyNames, const Reference< XPropertiesChangeListener >& Listener )
 {
     ::osl::MutexGuard aGuard(m_aMutex);
     sal_Int32 nCount = PropertyNames.getLength();
@@ -258,7 +257,7 @@ void SAL_CALL OContentHelper::addPropertiesChangeListener( const Sequence< OUStr
     }
 }
 
-void SAL_CALL OContentHelper::removePropertiesChangeListener( const Sequence< OUString >& PropertyNames, const Reference< XPropertiesChangeListener >& Listener ) throw (RuntimeException, std::exception)
+void SAL_CALL OContentHelper::removePropertiesChangeListener( const Sequence< OUString >& PropertyNames, const Reference< XPropertiesChangeListener >& Listener )
 {
     ::osl::MutexGuard aGuard(m_aMutex);
     sal_Int32 nCount = PropertyNames.getLength();
@@ -281,18 +280,18 @@ void SAL_CALL OContentHelper::removePropertiesChangeListener( const Sequence< OU
 }
 
 // XPropertyContainer
-void SAL_CALL OContentHelper::addProperty( const OUString& /*Name*/, sal_Int16 /*Attributes*/, const Any& /*DefaultValue*/ ) throw (PropertyExistException, IllegalTypeException, IllegalArgumentException, RuntimeException, std::exception)
+void SAL_CALL OContentHelper::addProperty( const OUString& /*Name*/, sal_Int16 /*Attributes*/, const Any& /*DefaultValue*/ )
 {
     OSL_FAIL( "OContentHelper::addProperty: not implemented!" );
 }
 
-void SAL_CALL OContentHelper::removeProperty( const OUString& /*Name*/ ) throw (UnknownPropertyException, NotRemoveableException, RuntimeException, std::exception)
+void SAL_CALL OContentHelper::removeProperty( const OUString& /*Name*/ )
 {
     OSL_FAIL( "OContentHelper::removeProperty: not implemented!" );
 }
 
 // XInitialization
-void SAL_CALL OContentHelper::initialize( const Sequence< Any >& _aArguments ) throw(Exception, RuntimeException, std::exception)
+void SAL_CALL OContentHelper::initialize( const Sequence< Any >& _aArguments )
 {
     const Any* pBegin = _aArguments.getConstArray();
     const Any* pEnd = pBegin + _aArguments.getLength();
@@ -315,7 +314,7 @@ void SAL_CALL OContentHelper::initialize( const Sequence< Any >& _aArguments ) t
     }
 }
 
-Sequence< Any > OContentHelper::setPropertyValues(const Sequence< PropertyValue >& rValues,const Reference< XCommandEnvironment >& /*xEnv*/ )
+Sequence< Any > OContentHelper::setPropertyValues(const Sequence< PropertyValue >& rValues )
 {
     osl::ClearableGuard< osl::Mutex > aGuard( m_aMutex );
 
@@ -325,7 +324,7 @@ Sequence< Any > OContentHelper::setPropertyValues(const Sequence< PropertyValue
 
     PropertyChangeEvent aEvent;
     aEvent.Source         = static_cast< cppu::OWeakObject * >( this );
-    aEvent.Further        = sal_False;
+    aEvent.Further        = false;
     aEvent.PropertyHandle = -1;
 
     const PropertyValue* pValues = rValues.getConstArray();
@@ -361,14 +360,14 @@ Sequence< Any > OContentHelper::setPropertyValues(const Sequence< PropertyValue
                 if ( aNewValue != m_pImpl->m_aProps.aTitle )
                 {
                     aEvent.PropertyName = rValue.Name;
-                    aEvent.OldValue     = makeAny( m_pImpl->m_aProps.aTitle );
+                    aEvent.OldValue     <<= m_pImpl->m_aProps.aTitle;
 
                     try
                     {
                         impl_rename_throw( aNewValue ,false);
                         OSL_ENSURE( m_pImpl->m_aProps.aTitle == aNewValue, "OContentHelper::setPropertyValues('Title'): rename did not work!" );
 
-                        aEvent.NewValue     = makeAny( aNewValue );
+                        aEvent.NewValue     <<= aNewValue;
                         aChanges.getArray()[ nChanged ] = aEvent;
                         nChanged++;
                     }
@@ -498,7 +497,7 @@ void OContentHelper::notifyPropertiesChange( const Sequence< PropertyChangeEvent
         }
 
         typedef Sequence< PropertyChangeEvent > PropertyEventSequence;
-        typedef ::std::map< XPropertiesChangeListener*, PropertyEventSequence* > PropertiesEventListenerMap;
+        typedef std::map< XPropertiesChangeListener*, PropertyEventSequence* > PropertiesEventListenerMap;
         PropertiesEventListenerMap aListeners;
 
         const PropertyChangeEvent* propertyChangeEvent = evt.getConstArray();
@@ -517,7 +516,7 @@ void OContentHelper::notifyPropertiesChange( const Sequence< PropertyChangeEvent
                     PropertyEventSequence* propertyEvents = nullptr;
 
                     XPropertiesChangeListener* pListener = static_cast< XPropertiesChangeListener * >( aIter.next() );
-                    PropertiesEventListenerMap::iterator it = aListeners.find( pListener );
+                    PropertiesEventListenerMap::const_iterator it = aListeners.find( pListener );
                     if ( it == aListeners.end() )
                     {
                         // Not in map - create and insert new entry.
@@ -534,11 +533,10 @@ void OContentHelper::notifyPropertiesChange( const Sequence< PropertyChangeEvent
         }
 
         // Notify listeners.
-        PropertiesEventListenerMap::iterator it = aListeners.begin();
+        PropertiesEventListenerMap::const_iterator it = aListeners.begin();
         while ( !aListeners.empty() )
         {
-            XPropertiesChangeListener* pListener =
-                    static_cast< XPropertiesChangeListener * >( (*it).first );
+            XPropertiesChangeListener* pListener = (*it).first;
             PropertyEventSequence* pSeq = (*it).second;
 
             // Remove current element.
@@ -553,7 +551,7 @@ void OContentHelper::notifyPropertiesChange( const Sequence< PropertyChangeEvent
 }
 
 // css::lang::XUnoTunnel
-sal_Int64 OContentHelper::getSomething( const Sequence< sal_Int8 > & rId ) throw (RuntimeException, std::exception)
+sal_Int64 OContentHelper::getSomething( const Sequence< sal_Int8 > & rId )
 {
     if (rId.getLength() == 16 && 0 == memcmp(getUnoTunnelImplementationId().getConstArray(),  rId.getConstArray(), 16 ) )
         return reinterpret_cast<sal_Int64>(this);
@@ -572,13 +570,13 @@ OContentHelper* OContentHelper::getImplementation( const Reference< XInterface >
     return pContent;
 }
 
-Reference< XInterface > SAL_CALL OContentHelper::getParent(  ) throw (RuntimeException, std::exception)
+Reference< XInterface > SAL_CALL OContentHelper::getParent(  )
 {
     ::osl::MutexGuard aGuard(m_aMutex);
     return m_xParentContainer;
 }
 
-void SAL_CALL OContentHelper::setParent( const Reference< XInterface >& _xParent ) throw (NoSupportException, RuntimeException, std::exception)
+void SAL_CALL OContentHelper::setParent( const Reference< XInterface >& _xParent )
 {
     ::osl::MutexGuard aGuard(m_aMutex);
     m_xParentContainer = _xParent;
@@ -587,14 +585,14 @@ void SAL_CALL OContentHelper::setParent( const Reference< XInterface >& _xParent
 void OContentHelper::impl_rename_throw(const OUString& _sNewName,bool _bNotify )
 {
     osl::ClearableGuard< osl::Mutex > aGuard(m_aMutex);
-    if ( _sNewName.equals( m_pImpl->m_aProps.aTitle ) )
+    if ( _sNewName == m_pImpl->m_aProps.aTitle )
         return;
     try
     {
         Sequence< PropertyChangeEvent > aChanges( 1 );
 
         aChanges[0].Source          = static_cast< cppu::OWeakObject * >( this );
-        aChanges[0].Further         = sal_False;
+        aChanges[0].Further         = false;
         aChanges[0].PropertyName    = PROPERTY_NAME;
         aChanges[0].PropertyHandle  = PROPERTY_ID_NAME;
         aChanges[0].OldValue        <<= m_pImpl->m_aProps.aTitle;
@@ -613,7 +611,7 @@ void OContentHelper::impl_rename_throw(const OUString& _sNewName,bool _bNotify )
     }
 }
 
-void SAL_CALL OContentHelper::rename( const OUString& newName ) throw (SQLException, ElementExistException, RuntimeException, std::exception)
+void SAL_CALL OContentHelper::rename( const OUString& newName )
 {
 
     impl_rename_throw(newName);
@@ -622,7 +620,7 @@ void SAL_CALL OContentHelper::rename( const OUString& newName ) throw (SQLExcept
 
 void OContentHelper::notifyDataSourceModified()
 {
-    ::dbaccess::notifyDataSourceModified(m_xParentContainer,true);
+    ::dbaccess::notifyDataSourceModified(m_xParentContainer);
 }
 
 }   // namespace dbaccess
