@@ -23,7 +23,7 @@
 #include <ucbhelper/providerhelper.hxx>
 
 #include "myucp_datasupplier.hxx"
-#include "ContentHelper.hxx"
+#include <ContentHelper.hxx>
 #include <com/sun/star/container/XHierarchicalNameAccess.hpp>
 #include <com/sun/star/ucb/IllegalIdentifierException.hpp>
 
