@@ -18,17 +18,16 @@
  */
 
 
-#include "dbu_reghelper.hxx"
+#include <dbu_reghelper.hxx>
 
-#include <osl/diagnose.h>
 #include <comphelper/sequence.hxx>
 
 namespace dbaui
 {
 
-    #define _REGISTRATIONHELPER_CXX_INCLUDED_INDIRECTLY_
+    #define REGISTRATIONHELPER_CXX_INCLUDED_INDIRECTLY_
     #include "registrationhelper.cxx"
-    #undef _REGISTRATIONHELPER_CXX_INCLUDED_INDIRECTLY_
+    #undef REGISTRATIONHELPER_CXX_INCLUDED_INDIRECTLY_
 
 }
 
