@@ -17,16 +17,16 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "TablesSingleDlg.hxx"
+#include <TablesSingleDlg.hxx>
 #include "DbAdminImpl.hxx"
 #include "tablespage.hxx"
 #include <vcl/msgbox.hxx>
-#include "dsitems.hxx"
+#include <dsitems.hxx>
 #include <comphelper/processfactory.hxx>
 
-#include "propertysetitem.hxx"
+#include <propertysetitem.hxx>
 
-#include "dbu_dlg.hrc"
+#include <dbu_dlg.hxx>
 
 namespace dbaui
 {
@@ -36,18 +36,17 @@ using namespace com::sun::star::lang;
 using namespace com::sun::star::beans;
 using namespace com::sun::star::container;
 
-DBG_NAME(OTableSubscriptionDialog)
     // OTableSubscriptionDialog
-OTableSubscriptionDialog::OTableSubscriptionDialog(Window* pParent
+OTableSubscriptionDialog::OTableSubscriptionDialog(vcl::Window* pParent
             ,SfxItemSet* _pItems
             ,const Reference< XComponentContext >& _rxORB
-            ,const ::com::sun::star::uno::Any& _aDataSourceName)
-    :SfxNoLayoutSingleTabDialog(pParent,DLG_TABLE_FILTER,_pItems)
-    ,m_pImpl( new ODbDataSourceAdministrationHelper( _rxORB, pParent, this ) )
-    ,m_bStopExecution(sal_False)
-    ,m_pOutSet(_pItems)
+            ,const css::uno::Any& _aDataSourceName)
+    : SfxSingleTabDialog(pParent, _pItems, "TablesFilterDialog",
+        "dbaccess/ui/tablesfilterdialog.ui")
+    , m_pImpl( new ODbDataSourceAdministrationHelper( _rxORB, pParent, this ) )
+    , m_bStopExecution(false)
+    , m_pOutSet(_pItems)
 {
-    DBG_CTOR(OTableSubscriptionDialog,NULL);
     m_pImpl->setDataSourceOrName(_aDataSourceName);
     Reference< XPropertySet > xDatasource = m_pImpl->getCurrentDataSource();
     m_pOutSet = new SfxItemSet( *_pItems );
@@ -55,15 +54,20 @@ OTableSubscriptionDialog::OTableSubscriptionDialog(Window* pParent
     m_pImpl->translateProperties(xDatasource, *m_pOutSet);
     SetInputSet(m_pOutSet);
 
-    OTableSubscriptionPage* pTabPage = new OTableSubscriptionPage(this,*m_pOutSet,this);
+    VclPtrInstance<OTableSubscriptionPage> pTabPage(get_content_area(), *m_pOutSet, this);
     pTabPage->SetServiceFactory(_rxORB);
     SetTabPage(pTabPage);
 }
 
 OTableSubscriptionDialog::~OTableSubscriptionDialog()
 {
-    DBG_DTOR(OTableSubscriptionDialog,NULL);
+    disposeOnce();
+}
+
+void OTableSubscriptionDialog::dispose()
+{
     delete m_pOutSet;
+    SfxSingleTabDialog::dispose();
 }
 
 short OTableSubscriptionDialog::Execute()
@@ -71,7 +75,7 @@ short OTableSubscriptionDialog::Execute()
     short nRet = RET_CANCEL;
     if ( !m_bStopExecution )
     {
-        nRet = SfxNoLayoutSingleTabDialog::Execute();
+        nRet = SfxSingleTabDialog::Execute();
         if ( nRet == RET_OK )
         {
             m_pOutSet->Put(*GetOutputItemSet());
@@ -81,7 +85,7 @@ short OTableSubscriptionDialog::Execute()
     return nRet;
 }
 
-sal_Bool OTableSubscriptionDialog::getCurrentSettings(Sequence< PropertyValue >& _rDriverParams)
+bool OTableSubscriptionDialog::getCurrentSettings(Sequence< PropertyValue >& _rDriverParams)
 {
     return m_pImpl->getCurrentSettings(_rDriverParams);
 }
