@@ -17,23 +17,25 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "sqlmessage.hxx"
-#include "dbu_dlg.hrc"
+#include <core_resource.hxx>
+#include <sqlmessage.hxx>
+#include <dbu_dlg.hxx>
+#include <strings.hrc>
+#include <bitmaps.hlst>
 #include <com/sun/star/sdbc/SQLException.hpp>
 #include <com/sun/star/sdb/SQLContext.hpp>
 #include <vcl/fixed.hxx>
 #include <osl/diagnose.h>
 #include <svtools/treelistbox.hxx>
-#include "svtools/treelistentry.hxx"
+#include <svtools/treelistentry.hxx>
 #include <svtools/svmedit.hxx>
 #include <connectivity/dbexception.hxx>
 #include <connectivity/sqlerror.hxx>
 #include <vcl/msgbox.hxx>
 #include <unotools/configmgr.hxx>
 #include <sfx2/sfxuno.hxx>
-#include "dbaccess_helpid.hrc"
-#include "UITools.hxx"
-#include "moduledbu.hxx"
+#include <helpids.h>
+#include <UITools.hxx>
 
 #include <tools/urlobj.hxx>
 
@@ -58,12 +60,12 @@ namespace
     class ImageProvider
     {
     private:
-        sal_uInt16  m_defaultImageID;
+        OUString m_defaultImageID;
 
         mutable Image   m_defaultImage;
 
     public:
-        explicit ImageProvider( sal_uInt16 _defaultImageID )
+        explicit ImageProvider(const OUString& _defaultImageID)
             :m_defaultImageID( _defaultImageID )
         {
         }
@@ -71,7 +73,7 @@ namespace
         Image const & getImage() const
         {
             if ( !m_defaultImage )
-                m_defaultImage = Image( ModuleRes( m_defaultImageID ) );
+                m_defaultImage = Image(BitmapEx(m_defaultImageID));
             return m_defaultImage;
         }
     };
@@ -81,8 +83,8 @@ namespace
     private:
         OUString  m_label;
     public:
-        explicit LabelProvider( sal_uInt16 _labelResourceID )
-            :m_label( ModuleRes( _labelResourceID ) )
+        explicit LabelProvider(const char* labelResourceID)
+            : m_label(DBA_RES(labelResourceID))
         {
         }
 
@@ -110,18 +112,18 @@ namespace
         std::shared_ptr< ImageProvider > const & getImageProvider( SQLExceptionInfo::TYPE _eType ) const
         {
             std::shared_ptr< ImageProvider >* ppProvider( &m_pErrorImage );
-            sal_uInt16 nNormalImageID( BMP_EXCEPTION_ERROR );
+            OUString sNormalImageID(BMP_EXCEPTION_ERROR);
 
             switch ( _eType )
             {
             case SQLExceptionInfo::TYPE::SQLWarning:
                 ppProvider = &m_pWarningsImage;
-                nNormalImageID = BMP_EXCEPTION_WARNING;
+                sNormalImageID = BMP_EXCEPTION_WARNING;
                 break;
 
             case SQLExceptionInfo::TYPE::SQLContext:
                 ppProvider = &m_pInfoImage;
-                nNormalImageID = BMP_EXCEPTION_INFO;
+                sNormalImageID = BMP_EXCEPTION_INFO;
                 break;
 
             default:
@@ -129,32 +131,32 @@ namespace
             }
 
             if ( !ppProvider->get() )
-                ppProvider->reset( new ImageProvider( nNormalImageID ) );
+                ppProvider->reset(new ImageProvider(sNormalImageID));
             return *ppProvider;
         }
 
         std::shared_ptr< LabelProvider > const & getLabelProvider( SQLExceptionInfo::TYPE _eType, bool _bSubLabel ) const
         {
             std::shared_ptr< LabelProvider >* ppProvider( &m_pErrorLabel );
-            sal_uInt16 nLabelID( STR_EXCEPTION_ERROR );
+            const char* pLabelID( STR_EXCEPTION_ERROR );
 
             switch ( _eType )
             {
             case SQLExceptionInfo::TYPE::SQLWarning:
                 ppProvider = &m_pWarningsLabel;
-                nLabelID = STR_EXCEPTION_WARNING;
+                pLabelID = STR_EXCEPTION_WARNING;
                 break;
 
             case SQLExceptionInfo::TYPE::SQLContext:
                 ppProvider = &m_pInfoLabel;
-                nLabelID = _bSubLabel ? STR_EXCEPTION_DETAILS : STR_EXCEPTION_INFO;
+                pLabelID = _bSubLabel ? STR_EXCEPTION_DETAILS : STR_EXCEPTION_INFO;
                 break;
             default:
                 break;
             }
 
             if ( !ppProvider->get() )
-                ppProvider->reset( new LabelProvider( nLabelID ) );
+                ppProvider->reset( new LabelProvider( pLabelID ) );
             return *ppProvider;
         }
 
@@ -186,7 +188,7 @@ namespace
                     );
     }
 
-    typedef ::std::vector< ExceptionDisplayInfo >   ExceptionDisplayChain;
+    typedef std::vector< ExceptionDisplayInfo >   ExceptionDisplayChain;
 
     /// strips the [OOoBase] vendor identifier from the given error message, if applicable
     OUString lcl_stripOOoBaseVendor( const OUString& _rErrorMessage )
@@ -303,16 +305,16 @@ OExceptionChainDialog::OExceptionChainDialog(vcl::Window* pParent, const Excepti
     , m_aExceptions(_rExceptions)
 {
     get(m_pExceptionList, "list");
-    Size aListSize(LogicToPixel(Size(85, 93), MapUnit::MapAppFont));
+    Size aListSize(LogicToPixel(Size(85, 93), MapMode(MapUnit::MapAppFont)));
     m_pExceptionList->set_width_request(aListSize.Width());
     m_pExceptionList->set_height_request(aListSize.Height());
     get(m_pExceptionText, "description");
-    Size aTextSize(LogicToPixel(Size(125 , 93), MapUnit::MapAppFont));
+    Size aTextSize(LogicToPixel(Size(125, 93), MapMode(MapUnit::MapAppFont)));
     m_pExceptionText->set_width_request(aTextSize.Width());
     m_pExceptionText->set_height_request(aTextSize.Height());
 
-    m_sStatusLabel = ModuleRes( STR_EXCEPTION_STATUS );
-    m_sErrorCodeLabel = ModuleRes( STR_EXCEPTION_ERRORCODE );
+    m_sStatusLabel = DBA_RES( STR_EXCEPTION_STATUS );
+    m_sErrorCodeLabel = DBA_RES( STR_EXCEPTION_ERRORCODE );
 
     m_pExceptionList->SetSelectionMode(SelectionMode::Single);
     m_pExceptionList->SetDragDropMode(DragDropMode::NONE);
@@ -341,7 +343,7 @@ OExceptionChainDialog::OExceptionChainDialog(vcl::Window* pParent, const Excepti
         ProviderFactory aProviderFactory;
 
         ExceptionDisplayInfo aInfo22018;
-        aInfo22018.sMessage = ModuleRes( STR_EXPLAN_STRINGCONVERSION_ERROR );
+        aInfo22018.sMessage = DBA_RES( STR_EXPLAN_STRINGCONVERSION_ERROR );
         aInfo22018.pLabelProvider = aProviderFactory.getLabelProvider( SQLExceptionInfo::TYPE::SQLContext, false );
         aInfo22018.pImageProvider = aProviderFactory.getImageProvider( SQLExceptionInfo::TYPE::SQLContext );
         m_aExceptions.push_back( aInfo22018 );
@@ -398,8 +400,8 @@ namespace
 {
     void lcl_positionInAppFont( const vcl::Window& _rParent, vcl::Window& _rChild, long _nX, long _nY, long Width, long Height )
     {
-        Point aPos = _rParent.LogicToPixel( Point( _nX, _nY ), MapUnit::MapAppFont );
-        Size aSize = _rParent.LogicToPixel( Size( Width, Height ), MapUnit::MapAppFont );
+        Point aPos = _rParent.LogicToPixel(Point(_nX, _nY), MapMode(MapUnit::MapAppFont));
+        Size aSize = _rParent.LogicToPixel(Size(Width, Height), MapMode(MapUnit::MapAppFont));
         _rChild.SetPosSizePixel( aPos, aSize );
     }
 
@@ -462,7 +464,7 @@ void OSQLMessageBox::impl_positionControls()
     m_aTitle->SetText( sPrimary );
     m_aTitle->Show();
 
-    Rectangle aPrimaryRect( m_aTitle->GetPosPixel(), m_aTitle->GetSizePixel() );
+    tools::Rectangle aPrimaryRect( m_aTitle->GetPosPixel(), m_aTitle->GetSizePixel() );
 
     // secondary text (if applicable)
     m_aMessage->SetStyle( m_aMessage->GetStyle() | WB_NOLABEL );
@@ -470,7 +472,7 @@ void OSQLMessageBox::impl_positionControls()
     m_aMessage->SetText( sSecondary );
 
     lcl_positionInAppFont( *this, *m_aMessage.get(), TEXT_POS_X, OUTER_MARGIN + 16 + 3, DIALOG_WIDTH - TEXT_POS_X - 2 * OUTER_MARGIN, 8 );
-    Rectangle aSecondaryRect( m_aMessage->GetPosPixel(), m_aMessage->GetSizePixel() );
+    tools::Rectangle aSecondaryRect( m_aMessage->GetPosPixel(), m_aMessage->GetSizePixel() );
 
     bool bHaveSecondaryText = !sSecondary.isEmpty();
 
@@ -487,13 +489,13 @@ void OSQLMessageBox::impl_positionControls()
     // if there's no secondary text ...
     if ( !bHaveSecondaryText )
     {   // then give the primary text as much horizontal space as it needs
-        Rectangle aSuggestedRect( GetTextRect( aPrimaryRect, sPrimary, DrawTextFlags::WordBreak | DrawTextFlags::MultiLine | DrawTextFlags::Center ) );
+        tools::Rectangle aSuggestedRect( GetTextRect( aPrimaryRect, sPrimary, DrawTextFlags::WordBreak | DrawTextFlags::MultiLine | DrawTextFlags::Center ) );
         aPrimaryRect.Right() = aPrimaryRect.Left() + aSuggestedRect.GetWidth();
         aPrimaryRect.Bottom() = aPrimaryRect.Top() + aSuggestedRect.GetHeight();
         // and center it horizontally
         m_aTitle->SetStyle( ( m_aTitle->GetStyle() & ~WB_LEFT ) | WB_CENTER );
 
-        Rectangle aInfoRect( m_aInfoImage->GetPosPixel(), m_aInfoImage->GetSizePixel() );
+        tools::Rectangle aInfoRect( m_aInfoImage->GetPosPixel(), m_aInfoImage->GetSizePixel() );
         // also, if it's not as high as the image ...
         if ( aPrimaryRect.GetHeight() < m_aInfoImage->GetSizePixel().Height() )
         {   // ... make it fit the image height
@@ -511,9 +513,9 @@ void OSQLMessageBox::impl_positionControls()
     }
 
     // adjust dialog size accordingly
-    const Rectangle& rBottomTextRect( bHaveSecondaryText ? aSecondaryRect : aPrimaryRect );
-    Size aBorderSize = LogicToPixel( Size( OUTER_MARGIN, OUTER_MARGIN ), MapUnit::MapAppFont );
-    Size aDialogSize( LogicToPixel( Size( DIALOG_WIDTH, 30 ), MapUnit::MapAppFont ) );
+    const tools::Rectangle& rBottomTextRect( bHaveSecondaryText ? aSecondaryRect : aPrimaryRect );
+    Size aBorderSize = LogicToPixel(Size(OUTER_MARGIN, OUTER_MARGIN), MapMode(MapUnit::MapAppFont));
+    Size aDialogSize( LogicToPixel(Size(DIALOG_WIDTH, 30), MapMode(MapUnit::MapAppFont)));
     aDialogSize.Height() = rBottomTextRect.Bottom() + aBorderSize.Height();
     aDialogSize.Width() = aPrimaryRect.Right() + aBorderSize.Width();
 
@@ -521,32 +523,32 @@ void OSQLMessageBox::impl_positionControls()
     SetPageSizePixel( aDialogSize );
 }
 
-void OSQLMessageBox::impl_createStandardButtons( WinBits _nStyle )
+void OSQLMessageBox::impl_createStandardButtons( MessBoxStyle _nStyle )
 {
-    if ( _nStyle & WB_YES_NO_CANCEL )
+    if ( _nStyle & MessBoxStyle::YesNoCancel )
     {
-        lcl_addButton( *this, StandardButtonType::Yes,    ( _nStyle & WB_DEF_YES ) != 0 );
-        lcl_addButton( *this, StandardButtonType::No,     ( _nStyle & WB_DEF_NO ) != 0 );
-        lcl_addButton( *this, StandardButtonType::Cancel, ( _nStyle & WB_DEF_CANCEL ) != 0 );
+        lcl_addButton( *this, StandardButtonType::Yes,    bool(_nStyle & MessBoxStyle::DefaultYes) );
+        lcl_addButton( *this, StandardButtonType::No,     bool( _nStyle & MessBoxStyle::DefaultNo ) );
+        lcl_addButton( *this, StandardButtonType::Cancel, bool( _nStyle & MessBoxStyle::DefaultCancel ) );
     }
-    else if ( _nStyle & WB_OK_CANCEL )
+    else if ( _nStyle & MessBoxStyle::OkCancel )
     {
-        lcl_addButton( *this, StandardButtonType::OK,     ( _nStyle & WB_DEF_OK ) != 0 );
-        lcl_addButton( *this, StandardButtonType::Cancel, ( _nStyle & WB_DEF_CANCEL ) != 0 );
+        lcl_addButton( *this, StandardButtonType::OK,     bool( _nStyle & MessBoxStyle::DefaultOk ) );
+        lcl_addButton( *this, StandardButtonType::Cancel, bool( _nStyle & MessBoxStyle::DefaultCancel ) );
     }
-    else if ( _nStyle & WB_YES_NO )
+    else if ( _nStyle & MessBoxStyle::YesNo )
     {
-        lcl_addButton( *this, StandardButtonType::Yes,    ( _nStyle & WB_DEF_YES ) != 0 );
-        lcl_addButton( *this, StandardButtonType::No,     ( _nStyle & WB_DEF_NO ) != 0 );
+        lcl_addButton( *this, StandardButtonType::Yes,    bool( _nStyle & MessBoxStyle::DefaultYes ) );
+        lcl_addButton( *this, StandardButtonType::No,     bool( _nStyle & MessBoxStyle::DefaultNo ) );
     }
-    else if ( _nStyle & WB_RETRY_CANCEL )
+    else if ( _nStyle & MessBoxStyle::RetryCancel )
     {
-        lcl_addButton( *this, StandardButtonType::Retry,  ( _nStyle & WB_DEF_RETRY ) != 0 );
-        lcl_addButton( *this, StandardButtonType::Cancel, ( _nStyle & WB_DEF_CANCEL ) != 0 );
+        lcl_addButton( *this, StandardButtonType::Retry,  bool( _nStyle & MessBoxStyle::DefaultRetry ) );
+        lcl_addButton( *this, StandardButtonType::Cancel, bool( _nStyle & MessBoxStyle::DefaultCancel ) );
     }
     else
     {
-        OSL_ENSURE( WB_OK & _nStyle, "OSQLMessageBox::impl_createStandardButtons: unsupported dialog style requested!" );
+        OSL_ENSURE( MessBoxStyle::Ok & _nStyle, "OSQLMessageBox::impl_createStandardButtons: unsupported dialog style requested!" );
         AddButton( StandardButtonType::OK, RET_OK, ButtonDialogFlags::Default | ButtonDialogFlags::Focus );
     }
 
@@ -596,7 +598,7 @@ void OSQLMessageBox::impl_addDetailsButton()
     }
 }
 
-void OSQLMessageBox::Construct( WinBits _nStyle, MessageType _eImage )
+void OSQLMessageBox::Construct( MessBoxStyle _nStyle, MessageType _eImage )
 {
     SetText( utl::ConfigManager::getProductName() + " Base" );
 
@@ -639,7 +641,7 @@ void OSQLMessageBox::Construct( WinBits _nStyle, MessageType _eImage )
     impl_addDetailsButton();
 }
 
-OSQLMessageBox::OSQLMessageBox(vcl::Window* _pParent, const SQLExceptionInfo& _rException, WinBits _nStyle, const OUString& _rHelpURL )
+OSQLMessageBox::OSQLMessageBox(vcl::Window* _pParent, const SQLExceptionInfo& _rException, MessBoxStyle _nStyle, const OUString& _rHelpURL )
     :ButtonDialog( _pParent, WB_HORZ | WB_STDDIALOG )
     ,m_aInfoImage( VclPtr<FixedImage>::Create(this) )
     ,m_aTitle( VclPtr<FixedText>::Create(this, WB_WORDBREAK | WB_LEFT) )
@@ -650,7 +652,7 @@ OSQLMessageBox::OSQLMessageBox(vcl::Window* _pParent, const SQLExceptionInfo& _r
     Construct( _nStyle, AUTO );
 }
 
-OSQLMessageBox::OSQLMessageBox( vcl::Window* _pParent, const OUString& _rTitle, const OUString& _rMessage, WinBits _nStyle, MessageType _eType, const ::dbtools::SQLExceptionInfo* _pAdditionalErrorInfo )
+OSQLMessageBox::OSQLMessageBox( vcl::Window* _pParent, const OUString& _rTitle, const OUString& _rMessage, MessBoxStyle _nStyle, MessageType _eType, const ::dbtools::SQLExceptionInfo* _pAdditionalErrorInfo )
     :ButtonDialog( _pParent, WB_HORZ | WB_STDDIALOG )
     ,m_aInfoImage( VclPtr<FixedImage>::Create(this) )
     ,m_aTitle( VclPtr<FixedText>::Create(this, WB_WORDBREAK | WB_LEFT) )
@@ -687,15 +689,15 @@ IMPL_LINK_NOARG( OSQLMessageBox, ButtonClickHdl, Button *, void )
 }
 
 // OSQLWarningBox
-OSQLWarningBox::OSQLWarningBox( vcl::Window* _pParent, const OUString& _rMessage, WinBits _nStyle,
+OSQLWarningBox::OSQLWarningBox( vcl::Window* _pParent, const OUString& _rMessage, MessBoxStyle _nStyle,
     const ::dbtools::SQLExceptionInfo* _pAdditionalErrorInfo )
-    :OSQLMessageBox( _pParent, ModuleRes( STR_EXCEPTION_WARNING ), _rMessage, _nStyle, OSQLMessageBox::Warning, _pAdditionalErrorInfo )
+    :OSQLMessageBox( _pParent, DBA_RES( STR_EXCEPTION_WARNING ), _rMessage, _nStyle, OSQLMessageBox::Warning, _pAdditionalErrorInfo )
 {
 }
 
 // OSQLErrorBox
 OSQLErrorBox::OSQLErrorBox( vcl::Window* _pParent, const OUString& _rMessage )
-    :OSQLMessageBox( _pParent, ModuleRes( STR_EXCEPTION_ERROR ), _rMessage, WB_OK | WB_DEF_OK, OSQLMessageBox::Error, nullptr )
+    :OSQLMessageBox( _pParent, DBA_RES( STR_EXCEPTION_ERROR ), _rMessage, MessBoxStyle::Ok | MessBoxStyle::DefaultOk, OSQLMessageBox::Error, nullptr )
 {
 }
 
