@@ -21,7 +21,7 @@
 #include <vcl/toolbox.hxx>
 #include <vcl/svapp.hxx>
 #include <svtools/miscopt.hxx>
-#include "UITools.hxx"
+#include <UITools.hxx>
 #include <svtools/imgdef.hxx>
 #include <vcl/event.hxx>
 #include <vcl/settings.hxx>
@@ -29,8 +29,8 @@
 namespace dbaui
 {
     OToolBoxHelper::OToolBoxHelper()
-        : m_nSymbolsSize(-1 )
-        , m_pToolBox(NULL)
+        : m_nSymbolsSize(-1)
+        , m_pToolBox(nullptr)
     {
 
         OSL_ENSURE(m_nSymbolsSize != SvtMiscOptions().GetCurrentSymbolsSize(),"SymbolsSize should not be identical");
@@ -51,8 +51,8 @@ namespace dbaui
             if ( nCurSymbolsSize != m_nSymbolsSize )
             {
                 m_nSymbolsSize  = nCurSymbolsSize;
+                setImageList(m_nSymbolsSize);
 
-                m_pToolBox->SetImageList( getImageList(m_nSymbolsSize) );
                 Size aTbOldSize = m_pToolBox->GetSizePixel();
                 adjustToolBoxSize(m_pToolBox);
                 Size aTbNewSize = m_pToolBox->GetSizePixel();
@@ -62,7 +62,8 @@ namespace dbaui
             }
         }
     }
-    IMPL_LINK(OToolBoxHelper, ConfigOptionsChanged, SvtMiscOptions*, /*_pOptions*/)
+
+    IMPL_LINK_NOARG(OToolBoxHelper, ConfigOptionsChanged, LinkParamNone*, void)
     {
         if ( m_pToolBox )
         {
@@ -72,30 +73,26 @@ namespace dbaui
             if ( aOptions.GetToolboxStyle() != m_pToolBox->GetOutStyle() )
                 m_pToolBox->SetOutStyle(aOptions.GetToolboxStyle());
         }
-
-        return 0L;
     }
-    IMPL_LINK(OToolBoxHelper, SettingsChanged, VclWindowEvent*, _pEvt)
+    IMPL_LINK(OToolBoxHelper, SettingsChanged, VclSimpleEvent&, _rEvt, void)
     {
-        if ( m_pToolBox && _pEvt && _pEvt->GetId() == VCLEVENT_APPLICATION_DATACHANGED )
+        if ( m_pToolBox && _rEvt.GetId() == VclEventId::ApplicationDataChanged )
         {
-            DataChangedEvent* pData = reinterpret_cast<DataChangedEvent*>(_pEvt->GetData());
-            if ( pData && ((( pData->GetType() == DATACHANGED_SETTINGS  )   ||
-            ( pData->GetType() == DATACHANGED_DISPLAY   ))  &&
-            ( pData->GetFlags() & SETTINGS_STYLE        )))
+            DataChangedEvent* pData = static_cast<DataChangedEvent*>(static_cast<VclWindowEvent&>(_rEvt).GetData());
+            if ( pData && ((( pData->GetType() == DataChangedEventType::SETTINGS  )   ||
+            ( pData->GetType() == DataChangedEventType::DISPLAY   ))  &&
+            ( pData->GetFlags() & AllSettingsFlags::STYLE        )))
                 // check if imagelist changed
                 checkImageList();
         }
-
-        return 0L;
     }
     void OToolBoxHelper::setToolBox(ToolBox* _pTB)
     {
-        bool bFirstTime = (m_pToolBox == NULL);
+        bool bFirstTime = (m_pToolBox == nullptr);
         m_pToolBox = _pTB;
         if ( m_pToolBox )
         {
-            ConfigOptionsChanged(NULL);
+            ConfigOptionsChanged(nullptr);
             if ( bFirstTime )
                 adjustToolBoxSize(m_pToolBox);
         }
