@@ -17,9 +17,10 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "datasourceconnector.hxx"
+#include <core_resource.hxx>
+#include <datasourceconnector.hxx>
 #include <osl/diagnose.h>
-#include "dbustrings.hrc"
+#include <stringconstants.hxx>
 #include <com/sun/star/sdbc/XWarningsSupplier.hpp>
 #include <com/sun/star/beans/XPropertySet.hpp>
 #include <com/sun/star/sdb/XCompletedConnection.hpp>
@@ -33,14 +34,14 @@
 #include <comphelper/namedvaluecollection.hxx>
 #include <connectivity/dbexception.hxx>
 #include <com/sun/star/sdbc/XDataSource.hpp>
-#include "UITools.hxx"
+#include <UITools.hxx>
 #include <vcl/stdtext.hxx>
 #include <vcl/button.hxx>
 #include <svl/filenotation.hxx>
 #include <tools/diagnose_ex.h>
 #include <cppuhelper/exc_hlp.hxx>
-#include "dbu_misc.hrc"
-#include "moduledbu.hxx"
+#include <strings.hrc>
+#include <strings.hxx>
 
 namespace dbaui
 {
@@ -54,7 +55,6 @@ namespace dbaui
     using namespace ::com::sun::star::container;
     using namespace ::com::sun::star::frame;
     using namespace ::dbtools;
-    using ::svt::OFileNotation;
 
     // ODatasourceConnector
     ODatasourceConnector::ODatasourceConnector(const Reference< XComponentContext >& _rxContext, vcl::Window* _pMessageParent)
@@ -160,7 +160,7 @@ namespace dbaui
                     Any aWarnings( xConnectionWarnings->getWarnings() );
                     if ( aWarnings.hasValue() )
                     {
-                        OUString sMessage( ModuleRes( STR_WARNINGS_DURING_CONNECT ) );
+                        OUString sMessage( DBA_RES( STR_WARNINGS_DURING_CONNECT ) );
                         sMessage = sMessage.replaceFirst( "$buttontext$", Button::GetStandardText( StandardButtonType::More ) );
                         sMessage = OutputDevice::GetNonMnemonicString( sMessage );
 
