@@ -17,30 +17,30 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "JoinTableView.hxx"
+#include <JoinTableView.hxx>
 #include <osl/diagnose.h>
-#include "querycontroller.hxx"
-#include "JoinDesignView.hxx"
-#include "dbu_qry.hrc"
-#include "TableWindow.hxx"
-#include "TableWindowListBox.hxx"
-#include "TableConnection.hxx"
-#include "TableConnectionData.hxx"
-#include "ConnectionLine.hxx"
-#include "ConnectionLineData.hxx"
-#include "browserids.hxx"
+#include <querycontroller.hxx>
+#include <JoinDesignView.hxx>
+#include <strings.hrc>
+#include <TableWindow.hxx>
+#include <TableWindowListBox.hxx>
+#include <TableConnection.hxx>
+#include <TableConnectionData.hxx>
+#include <ConnectionLine.hxx>
+#include <ConnectionLineData.hxx>
+#include <browserids.hxx>
 #include <svl/urlbmk.hxx>
 #include <com/sun/star/sdbc/XDatabaseMetaData.hpp>
 #include "QueryMoveTabWinUndoAct.hxx"
 #include "QuerySizeTabWinUndoAct.hxx"
 #include <vcl/svapp.hxx>
 #include <vcl/settings.hxx>
-#include "TableWindowData.hxx"
-#include "JAccess.hxx"
+#include <TableWindowData.hxx>
+#include <JAccess.hxx>
 #include <com/sun/star/accessibility/XAccessible.hpp>
 #include <com/sun/star/accessibility/AccessibleRole.hpp>
 #include <com/sun/star/accessibility/AccessibleEventId.hpp>
-#include "UITools.hxx"
+#include <UITools.hxx>
 #include <cppuhelper/exc_hlp.hxx>
 #include <comphelper/processfactory.hxx>
 #include <tools/diagnose_ex.h>
@@ -834,11 +834,11 @@ void OJoinTableView::MouseButtonUp( const MouseEvent& rEvt )
         {
             if( (*aIter)->CheckHit(rEvt.GetPosPixel()) )
             {
-                SelectConn((*aIter));
+                SelectConn(*aIter);
 
                 // Double-click
                 if( rEvt.GetClicks() == 2 )
-                    ConnDoubleClicked( (*aIter) );
+                    ConnDoubleClicked( *aIter );
 
                 break;
             }
@@ -1063,7 +1063,7 @@ void OJoinTableView::ScrollWhileDragging()
     // resetting timer, if still necessary
     if (bNeedScrollTimer)
     {
-        m_aDragScrollIdle.SetPriority(TaskPriority::LOW);
+        m_aDragScrollIdle.SetPriority( TaskPriority::HIGH_IDLE );
         m_aDragScrollIdle.Start();
     }
 
@@ -1563,7 +1563,7 @@ void OJoinTableView::addConnection(OTableConnection* _pConnection,bool _bAddData
 #endif
         m_pView->getController().getTableConnectionData().push_back(_pConnection->GetData());
     }
-    m_vTableConnection.push_back(_pConnection);
+    m_vTableConnection.emplace_back(_pConnection);
     _pConnection->RecalcLines();
     _pConnection->InvalidateConnection();
 
