@@ -19,7 +19,6 @@
 
 #include "TEditControl.hxx"
 #include <comphelper/processfactory.hxx>
-#include <tools/debug.hxx>
 #include <com/sun/star/sdbc/XDatabaseMetaData.hpp>
 #include <com/sun/star/sdbcx/XColumnsSupplier.hpp>
 #include <com/sun/star/sdbcx/XAlterTable.hpp>
@@ -27,25 +26,27 @@
 #include <com/sun/star/sdbcx/XAppend.hpp>
 #include <com/sun/star/beans/PropertyAttribute.hpp>
 #include <com/sun/star/util/XNumberFormatTypes.hpp>
-#include "dbu_tbl.hrc"
-#include "dbustrings.hrc"
-#include "browserids.hxx"
-#include "dbaccess_helpid.hrc"
+#include <strings.hrc>
+#include <strings.hxx>
+#include <stringconstants.hxx>
+#include <browserids.hxx>
+#include <helpids.h>
 #include <comphelper/types.hxx>
-#include "FieldDescControl.hxx"
-#include "FieldDescriptions.hxx"
+#include <FieldDescControl.hxx>
+#include <FieldDescriptions.hxx>
 #include <vcl/msgbox.hxx>
 #include "TableUndo.hxx"
-#include "TableController.hxx"
+#include <TableController.hxx>
+#include <connectivity/dbmetadata.hxx>
 #include <connectivity/dbtools.hxx>
-#include "SqlNameEdit.hxx"
-#include "TableRowExchange.hxx"
+#include <SqlNameEdit.hxx>
+#include <TableRowExchange.hxx>
 #include <sot/storage.hxx>
-#include "UITools.hxx"
+#include <UITools.hxx>
 #include "TableFieldControl.hxx"
-#include "dsntypes.hxx"
+#include <dsntypes.hxx>
 
-#include "dbaccess_slotid.hrc"
+#include <dbaccess_slotid.hrc>
 
 using namespace ::dbaui;
 using namespace ::comphelper;
@@ -54,7 +55,6 @@ using namespace ::com::sun::star::uno;
 using namespace ::com::sun::star::container;
 using namespace ::com::sun::star::io;
 using namespace ::com::sun::star::beans;
-using namespace ::com::sun::star::frame;
 using namespace ::com::sun::star::util;
 using namespace ::com::sun::star::lang;
 using namespace ::com::sun::star::sdbc;
@@ -72,12 +72,12 @@ using namespace ::com::sun::star::sdb;
 // Maximum length in description field
 #define MAX_DESCR_LEN       256
 
-OTableEditorCtrl::ClipboardInvalidator::ClipboardInvalidator(sal_uLong nTimeout,OTableEditorCtrl* _pOwner)
+OTableEditorCtrl::ClipboardInvalidator::ClipboardInvalidator(OTableEditorCtrl* _pOwner)
 : m_pOwner(_pOwner)
 {
 
-    m_aInvalidateTimer.SetTimeout(nTimeout);
-    m_aInvalidateTimer.SetTimeoutHdl(LINK(this, OTableEditorCtrl::ClipboardInvalidator, OnInvalidate));
+    m_aInvalidateTimer.SetTimeout(500);
+    m_aInvalidateTimer.SetInvokeHandler(LINK(this, OTableEditorCtrl::ClipboardInvalidator, OnInvalidate));
     m_aInvalidateTimer.Start();
 }
 
@@ -91,7 +91,7 @@ void OTableEditorCtrl::ClipboardInvalidator::Stop()
     m_aInvalidateTimer.Stop();
 }
 
-IMPL_LINK_NOARG_TYPED(OTableEditorCtrl::ClipboardInvalidator, OnInvalidate, Timer *, void)
+IMPL_LINK_NOARG(OTableEditorCtrl::ClipboardInvalidator, OnInvalidate, Timer *, void)
 {
     m_pOwner->GetView()->getController().InvalidateFeature(SID_CUT);
     m_pOwner->GetView()->getController().InvalidateFeature(SID_COPY);
@@ -108,21 +108,17 @@ void OTableEditorCtrl::Init()
     SetReadOnly( bRead );
 
     // Insert the columns
-    OUString aColumnName( ModuleRes(STR_TAB_FIELD_COLUMN_NAME) );
-    InsertDataColumn( FIELD_NAME, aColumnName, FIELDNAME_WIDTH );
+    InsertDataColumn( FIELD_NAME, DBA_RES(STR_TAB_FIELD_COLUMN_NAME), FIELDNAME_WIDTH );
 
-    aColumnName = ModuleRes(STR_TAB_FIELD_COLUMN_DATATYPE);
-    InsertDataColumn( FIELD_TYPE, aColumnName, FIELDTYPE_WIDTH );
+    InsertDataColumn( FIELD_TYPE, DBA_RES(STR_TAB_FIELD_COLUMN_DATATYPE), FIELDTYPE_WIDTH );
 
     ::dbaccess::ODsnTypeCollection aDsnTypes(GetView()->getController().getORB());
     bool bShowColumnDescription = aDsnTypes.supportsColumnDescription(::comphelper::getString(GetView()->getController().getDataSource()->getPropertyValue(PROPERTY_URL)));
-    aColumnName = ModuleRes(STR_TAB_HELP_TEXT);
-    InsertDataColumn( HELP_TEXT, aColumnName, bShowColumnDescription ? FIELDTYPE_WIDTH : FIELDDESCR_WIDTH );
+    InsertDataColumn( HELP_TEXT, DBA_RES(STR_TAB_HELP_TEXT), bShowColumnDescription ? FIELDTYPE_WIDTH : FIELDDESCR_WIDTH );
 
     if ( bShowColumnDescription )
     {
-        aColumnName = ModuleRes(STR_COLUMN_DESCRIPTION);
-        InsertDataColumn( COLUMN_DESCRIPTION, aColumnName, FIELDTYPE_WIDTH );
+        InsertDataColumn( COLUMN_DESCRIPTION, DBA_RES(STR_COLUMN_DESCRIPTION), FIELDTYPE_WIDTH );
     }
 
     InitCellController();
@@ -145,9 +141,8 @@ OTableEditorCtrl::OTableEditorCtrl(vcl::Window* pWindow)
     ,nInvalidateTypeEvent(nullptr)
     ,m_eChildFocus(NONE)
     ,nOldDataPos(-1)
-    ,bSaveOnMove(true)
     ,bReadOnly(true)
-    ,m_aInvalidate(500,this)
+    ,m_aInvalidate(this)
 {
 
     SetHelpId(HID_TABDESIGN_BACKGROUND);
@@ -234,9 +229,9 @@ void OTableEditorCtrl::InitCellController()
 
     Size aHeight;
     const Control* pControls[] = { pTypeCell,pDescrCell,pNameCell,pHelpTextCell};
-    for(sal_Size i= 0; i < sizeof(pControls) / sizeof(pControls[0]);++i)
+    for(const Control* pControl : pControls)
     {
-        const Size aTemp(pControls[i]->GetOptimalSize());
+        const Size aTemp(pControl->GetOptimalSize());
         if ( aTemp.Height() > aHeight.Height() )
             aHeight.Height() = aTemp.Height();
     }
@@ -307,7 +302,7 @@ bool OTableEditorCtrl::SeekRow(long _nRow)
     return SetDataPtr(_nRow);
 }
 
-void OTableEditorCtrl::PaintCell(OutputDevice& rDev, const Rectangle& rRect,
+void OTableEditorCtrl::PaintCell(OutputDevice& rDev, const tools::Rectangle& rRect,
                                    sal_uInt16 nColumnId ) const
 {
     const OUString aText( GetCellText( m_nCurrentPos, nColumnId ));
@@ -424,20 +419,19 @@ EditBrowseBox::RowStatus OTableEditorCtrl::GetRowStatus(long nRow) const
     }
 }
 
-bool OTableEditorCtrl::SaveCurRow()
+void OTableEditorCtrl::SaveCurRow()
 {
     if (GetFieldDescr(GetCurRow()) == nullptr)
         // there is no data in the current row
-        return true;
+        return;
     if (!SaveModified())
-        return false;
+        return;
 
     SetDataPtr(GetCurRow());
     pDescrWin->SaveData( pActRow->GetActFieldDescr() );
-    return true;
 }
 
-void OTableEditorCtrl::DisplayData(long nRow, bool bGrabFocus)
+void OTableEditorCtrl::DisplayData(long nRow)
 {
     // go to the correct cell
     SetDataPtr(nRow);
@@ -460,8 +454,7 @@ void OTableEditorCtrl::DisplayData(long nRow, bool bGrabFocus)
     RowModified(nRow);
 
     // and re-enable edit mode
-    if (bWasEditing || bGrabFocus)
-        ActivateCell(nRow, GetCurColumnId(), bGrabFocus);
+    ActivateCell(nRow, GetCurColumnId());
 }
 
 void OTableEditorCtrl::CursorMoved()
@@ -488,8 +481,8 @@ sal_Int32 OTableEditorCtrl::HasFieldName( const OUString& rFieldName )
 
     ::comphelper::UStringMixEqual bCase(!xMetaData.is() || xMetaData->supportsMixedCaseQuotedIdentifiers());
 
-    ::std::vector< std::shared_ptr<OTableRow> >::iterator aIter = m_pRowList->begin();
-    ::std::vector< std::shared_ptr<OTableRow> >::iterator aEnd = m_pRowList->end();
+    std::vector< std::shared_ptr<OTableRow> >::const_iterator aIter = m_pRowList->begin();
+    std::vector< std::shared_ptr<OTableRow> >::const_iterator aEnd = m_pRowList->end();
     sal_Int32 nCount(0);
     for(;aIter != aEnd;++aIter)
     {
@@ -500,7 +493,7 @@ sal_Int32 OTableEditorCtrl::HasFieldName( const OUString& rFieldName )
     return nCount;
 }
 
-bool OTableEditorCtrl::SaveData(long nRow, sal_uInt16 nColId)
+void OTableEditorCtrl::SaveData(long nRow, sal_uInt16 nColId)
 {
     // Store the cell content
     SetDataPtr( nRow == -1 ? GetCurRow() : nRow);
@@ -512,7 +505,7 @@ bool OTableEditorCtrl::SaveData(long nRow, sal_uInt16 nColId)
         case FIELD_NAME:
         {
             // If there is no name, do nothing
-            OUString aName(pNameCell->GetText());
+            const OUString aName(pNameCell->GetText());
 
             if( aName.isEmpty() )
             {
@@ -524,7 +517,7 @@ bool OTableEditorCtrl::SaveData(long nRow, sal_uInt16 nColId)
                     pActFieldDescr = pActRow->GetActFieldDescr();
                 }
                 else
-                    return true;
+                    return;
             }
             if(pActFieldDescr)
                 pActFieldDescr->SetName( aName );
@@ -584,7 +577,6 @@ bool OTableEditorCtrl::SaveData(long nRow, sal_uInt16 nColId)
             }
             break;
     }
-    return true;
 }
 
 bool OTableEditorCtrl::SaveModified()
@@ -629,7 +621,7 @@ bool OTableEditorCtrl::CursorMoving(long nNewRow, sal_uInt16 nNewCol)
     return true;
 }
 
-IMPL_LINK_NOARG_TYPED( OTableEditorCtrl, InvalidateFieldType, void*, void )
+IMPL_LINK_NOARG( OTableEditorCtrl, InvalidateFieldType, void*, void )
 {
     nInvalidateTypeEvent = nullptr;
     Invalidate( GetFieldRectPixel(nOldDataPos, FIELD_TYPE) );
@@ -647,14 +639,14 @@ void OTableEditorCtrl::CellModified( long nRow, sal_uInt16 nColId )
     OUString sActionDescription;
     switch ( nColId )
     {
-    case FIELD_NAME:    sActionDescription = ModuleRes( STR_CHANGE_COLUMN_NAME ); break;
-    case FIELD_TYPE:    sActionDescription = ModuleRes( STR_CHANGE_COLUMN_TYPE ); break;
+    case FIELD_NAME:    sActionDescription = DBA_RES( STR_CHANGE_COLUMN_NAME ); break;
+    case FIELD_TYPE:    sActionDescription = DBA_RES( STR_CHANGE_COLUMN_TYPE ); break;
     case HELP_TEXT:
-    case COLUMN_DESCRIPTION:   sActionDescription = ModuleRes( STR_CHANGE_COLUMN_DESCRIPTION ); break;
-    default:            sActionDescription = ModuleRes( STR_CHANGE_COLUMN_ATTRIBUTE ); break;
+    case COLUMN_DESCRIPTION:   sActionDescription = DBA_RES( STR_CHANGE_COLUMN_DESCRIPTION ); break;
+    default:            sActionDescription = DBA_RES( STR_CHANGE_COLUMN_ATTRIBUTE ); break;
     }
 
-    GetUndoManager().EnterListAction( sActionDescription, OUString() );
+    GetUndoManager().EnterListAction( sActionDescription, OUString(), 0, ViewShellId(-1) );
     if (!pActFieldDescr)
     {
         const OTypeInfoMap& rTypeInfoMap = GetView()->getController().getTypeInfo();
@@ -687,17 +679,17 @@ void OTableEditorCtrl::CellModified( long nRow, sal_uInt16 nColId )
     GetUndoManager().LeaveListAction();
     RowModified(nRow);
     CellControllerRef xController(Controller());
-    if(xController.Is())
+    if(xController.is())
         xController->SetModified();
 
     // Set the Modify flag
-    GetView()->getController().setModified( sal_True );
+    GetView()->getController().setModified( true );
     InvalidateFeatures();
 }
 
 void OTableEditorCtrl::resetType()
 {
-    sal_Int32 nPos = pTypeCell->GetSelectEntryPos();
+    sal_Int32 nPos = pTypeCell->GetSelectedEntryPos();
     if(nPos != LISTBOX_ENTRY_NOTFOUND)
         SwitchType( GetView()->getController().getTypeInfo(nPos) );
     else
@@ -725,7 +717,7 @@ void OTableEditorCtrl::CopyRows()
     // Copy selected rows to the ClipboardList
      std::shared_ptr<OTableRow>  pClipboardRow;
      std::shared_ptr<OTableRow>  pRow;
-    ::std::vector< std::shared_ptr<OTableRow> > vClipboardList;
+    std::vector< std::shared_ptr<OTableRow> > vClipboardList;
     vClipboardList.reserve(GetSelectRowCount());
 
     for( long nIndex=FirstSelectedRow(); nIndex >= 0 && nIndex < static_cast<long>(m_pRowList->size()); nIndex=NextSelectedRow() )
@@ -740,8 +732,7 @@ void OTableEditorCtrl::CopyRows()
     }
     if(!vClipboardList.empty())
     {
-        OTableRowExchange* pData = new OTableRowExchange(vClipboardList);
-        Reference< css::datatransfer::XTransferable> xRef = pData;
+        rtl::Reference<OTableRowExchange> pData = new OTableRowExchange(vClipboardList);
         pData->CopyToClipboard(GetParent());
     }
 }
@@ -775,19 +766,18 @@ OUString OTableEditorCtrl::GenerateName( const OUString& rName )
 void OTableEditorCtrl::InsertRows( long nRow )
 {
 
-    ::std::vector<  std::shared_ptr<OTableRow> > vInsertedUndoRedoRows; // need for undo/redo handling
+    std::vector<  std::shared_ptr<OTableRow> > vInsertedUndoRedoRows; // need for undo/redo handling
     // get rows from clipboard
     TransferableDataHelper aTransferData(TransferableDataHelper::CreateFromSystemClipboard(GetParent()));
     if(aTransferData.HasFormat(SotClipboardFormatId::SBA_TABED))
     {
         ::tools::SvRef<SotStorageStream> aStreamRef;
         bool bOk = aTransferData.GetSotStorageStream(SotClipboardFormatId::SBA_TABED,aStreamRef);
-        if (bOk && aStreamRef.Is())
+        if (bOk && aStreamRef.is())
         {
             aStreamRef->Seek(STREAM_SEEK_TO_BEGIN);
             aStreamRef->ResetError();
             long nInsertRow = nRow;
-            OUString aFieldName;
              std::shared_ptr<OTableRow>  pRow;
             sal_Int32 nSize = 0;
             (*aStreamRef).ReadInt32( nSize );
@@ -801,24 +791,21 @@ void OTableEditorCtrl::InsertRows( long nRow )
                 if ( pRow->GetActFieldDescr() )
                     pRow->GetActFieldDescr()->SetType(GetView()->getController().getTypeInfoByType(nType));
                 // Adjust the field names
-                aFieldName = GenerateName( pRow->GetActFieldDescr()->GetName() );
-                pRow->GetActFieldDescr()->SetName( aFieldName );
+                pRow->GetActFieldDescr()->SetName( GenerateName( pRow->GetActFieldDescr()->GetName() ) );
                 pRow->SetPos(nInsertRow);
                 m_pRowList->insert( m_pRowList->begin()+nInsertRow,pRow );
-                vInsertedUndoRedoRows.push_back(std::shared_ptr<OTableRow>(new OTableRow(*pRow)));
+                vInsertedUndoRedoRows.push_back(std::make_shared<OTableRow>(*pRow));
                 nInsertRow++;
             }
         }
     }
     // RowInserted calls CursorMoved.
     // The UI data should not be stored here.
-    bSaveOnMove = false;
     RowInserted( nRow,vInsertedUndoRedoRows.size() );
-    bSaveOnMove = true;
 
     // Create the Undo-Action
     GetUndoManager().AddUndoAction( new OTableEditorInsUndoAct(this, nRow,vInsertedUndoRedoRows) );
-    GetView()->getController().setModified( sal_True );
+    GetView()->getController().setModified( true );
     InvalidateFeatures();
 }
 
@@ -831,7 +818,6 @@ void OTableEditorCtrl::DeleteRows()
     // Delete all marked rows
     long nIndex = FirstSelectedRow();
     nOldDataPos = nIndex;
-    bSaveOnMove = false;
 
     while( nIndex >= 0 && nIndex < static_cast<long>(m_pRowList->size()) )
     {
@@ -840,14 +826,12 @@ void OTableEditorCtrl::DeleteRows()
         RowRemoved( nIndex );
 
         // Insert the empty row at the end
-        m_pRowList->push_back( std::shared_ptr<OTableRow>(new OTableRow()));
+        m_pRowList->push_back( std::make_shared<OTableRow>());
         RowInserted( GetRowCount()-1 );
 
         nIndex = FirstSelectedRow();
     }
 
-    bSaveOnMove = true;
-
     // Force the current record to be displayed
     m_nDataPos = GetCurRow();
     InvalidateStatusCell( nOldDataPos );
@@ -855,7 +839,7 @@ void OTableEditorCtrl::DeleteRows()
     SetDataPtr( m_nDataPos );
     ActivateCell();
     pDescrWin->DisplayData( pActRow->GetActFieldDescr() );
-    GetView()->getController().setModified( sal_True );
+    GetView()->getController().setModified( true );
     InvalidateFeatures();
 }
 
@@ -869,10 +853,10 @@ void OTableEditorCtrl::InsertNewRows( long nRow )
     GetUndoManager().AddUndoAction( new OTableEditorInsNewUndoAct(this, nRow, nInsertRows) );
     // Insert the number of selected rows
     for( long i=nRow; i<(nRow+nInsertRows); i++ )
-        m_pRowList->insert( m_pRowList->begin()+i ,std::shared_ptr<OTableRow>(new OTableRow()));
+        m_pRowList->insert( m_pRowList->begin()+i ,std::make_shared<OTableRow>());
     RowInserted( nRow, nInsertRows );
 
-    GetView()->getController().setModified( sal_True );
+    GetView()->getController().setModified( true );
     InvalidateFeatures();
 }
 
@@ -884,7 +868,7 @@ void OTableEditorCtrl::SetControlText( long nRow, sal_uInt16 nColId, const OUStr
         GoToRow( nRow );
         GoToColumnId( nColId );
         CellControllerRef xController = Controller();
-        if(xController.Is())
+        if(xController.is())
             xController->GetWindow().SetText( rText );
         else
             RowModified(nRow,nColId);
@@ -928,7 +912,7 @@ void OTableEditorCtrl::SetCellData( long nRow, sal_uInt16 nColId, const css::uno
         return;
 
     OUString sValue;
-    // Set indvidual fields
+    // Set individual fields
     switch( nColId )
     {
         case FIELD_NAME:
@@ -970,9 +954,8 @@ void OTableEditorCtrl::SetCellData( long nRow, sal_uInt16 nColId, const css::uno
 
         case FIELD_PROPERTY_AUTOINC:
             {
-                OUString strYes(ModuleRes(STR_VALUE_YES));
                 sValue = ::comphelper::getString(_rNewData);
-                pFieldDescr->SetAutoIncrement(sValue == strYes);
+                pFieldDescr->SetAutoIncrement(sValue == DBA_RES(STR_VALUE_YES));
             }
             break;
         case FIELD_PROPERTY_SCALE:
@@ -984,7 +967,7 @@ void OTableEditorCtrl::SetCellData( long nRow, sal_uInt16 nColId, const css::uno
 
         case FIELD_PROPERTY_BOOL_DEFAULT:
             sValue = GetView()->GetDescWin()->BoolStringPersistent(::comphelper::getString(_rNewData));
-            pFieldDescr->SetControlDefault(makeAny(OUString(sValue)));
+            pFieldDescr->SetControlDefault(makeAny(sValue));
             break;
 
         case FIELD_PROPERTY_FORMAT:
@@ -1009,8 +992,8 @@ Any OTableEditorCtrl::GetCellData( long nRow, sal_uInt16 nColId )
         nRow = GetCurRow();
     SetDataPtr( nRow );
 
-    static const OUString strYes(ModuleRes(STR_VALUE_YES));
-    static const OUString strNo(ModuleRes(STR_VALUE_NO));
+    static const OUString strYes(DBA_RES(STR_VALUE_YES));
+    static const OUString strNo(DBA_RES(STR_VALUE_NO));
     OUString sValue;
     // Read out the fields
     switch( nColId )
@@ -1076,7 +1059,7 @@ OUString OTableEditorCtrl::GetCellText( long nRow, sal_uInt16 nColId ) const
 
 sal_uInt32 OTableEditorCtrl::GetTotalCellWidth(long nRow, sal_uInt16 nColId)
 {
-    return GetTextWidth(GetCellText(nRow, nColId)) + 2 * GetTextWidth(OUString('0'));
+    return GetTextWidth(GetCellText(nRow, nColId)) + 2 * GetTextWidth("0");
 }
 
 OFieldDescription* OTableEditorCtrl::GetFieldDescr( long nRow )
@@ -1094,7 +1077,7 @@ OFieldDescription* OTableEditorCtrl::GetFieldDescr( long nRow )
     return pRow->GetActFieldDescr();
 }
 
-bool OTableEditorCtrl::IsCutAllowed( long nRow )
+bool OTableEditorCtrl::IsCutAllowed()
 {
     bool bIsCutAllowed = (GetView()->getController().isAddAllowed() && GetView()->getController().isDropAllowed()) ||
                             GetView()->getController().isAlterAllowed();
@@ -1113,7 +1096,7 @@ bool OTableEditorCtrl::IsCutAllowed( long nRow )
                 bIsCutAllowed = !pNameCell->GetSelected().isEmpty();
                 break;
             case ROW:
-                bIsCutAllowed = IsCopyAllowed(nRow);
+                bIsCutAllowed = IsCopyAllowed();
                 break;
             default:
                 bIsCutAllowed = false;
@@ -1124,7 +1107,7 @@ bool OTableEditorCtrl::IsCutAllowed( long nRow )
     return bIsCutAllowed;
 }
 
-bool OTableEditorCtrl::IsCopyAllowed( long /*nRow*/ )
+bool OTableEditorCtrl::IsCopyAllowed()
 {
     bool bIsCopyAllowed = false;
     if(m_eChildFocus == DESCRIPTION )
@@ -1157,7 +1140,7 @@ bool OTableEditorCtrl::IsCopyAllowed( long /*nRow*/ )
     return bIsCopyAllowed;
 }
 
-bool OTableEditorCtrl::IsPasteAllowed( long /*nRow*/ )
+bool OTableEditorCtrl::IsPasteAllowed()
 {
     bool bAllowed = GetView()->getController().isAddAllowed();
     if ( bAllowed )
@@ -1338,13 +1321,13 @@ void OTableEditorCtrl::Command(const CommandEvent& rEvt)
                     sal_uInt16 nSelId = GetColumnId(
                         sal::static_int_cast< sal_uInt16 >(
                             FirstSelectedColumn() ) );
-                    ::Rectangle aColRect( GetFieldRectPixel( 0, nSelId, false ) );
+                    ::tools::Rectangle aColRect( GetFieldRectPixel( 0, nSelId, false ) );
 
                     aMenuPos = aColRect.TopCenter();
                 }
                 else if ( GetSelectRowCount() > 0 )
                 {
-                    ::Rectangle aColRect( GetFieldRectPixel( FirstSelectedRow(), HANDLE_ID ) );
+                    ::tools::Rectangle aColRect( GetFieldRectPixel( FirstSelectedRow(), HANDLE_ID ) );
 
                     aMenuPos = aColRect.TopCenter();
                 }
@@ -1370,32 +1353,30 @@ void OTableEditorCtrl::Command(const CommandEvent& rEvt)
                             if ( !IsColumnSelected( nColId ) )
                                 SelectColumnId( nColId );
 
-                            PopupMenu aContextMenu( ModuleRes( RID_QUERYCOLPOPUPMENU ) );
-                            aContextMenu.EnableItem( SID_DELETE, false );
-                            aContextMenu.RemoveDisabledEntries(true, true);
-                            switch ( aContextMenu.Execute( this, aMenuPos ) )
-                            {
-                                case ID_BROWSER_COLWIDTH:
-                                    adjustBrowseBoxColumnWidth( this, nColId );
-                                    break;
-                            }
+                            VclBuilder aBuilder(nullptr, VclBuilderContainer::getUIRootDir(), "dbaccess/ui/querycolmenu.ui", "");
+                            VclPtr<PopupMenu> aContextMenu(aBuilder.get_menu("menu"));
+                            aContextMenu->EnableItem(aContextMenu->GetItemId("delete"), false);
+                            aContextMenu->RemoveDisabledEntries(true, true);
+                            if (aContextMenu->Execute(this, aMenuPos) == aContextMenu->GetItemId("width"))
+                                adjustBrowseBoxColumnWidth( this, nColId );
                         }
                     }
                 }
                 else
                 {
-                    PopupMenu aContextMenu(ModuleRes(RID_TABLEDESIGNROWPOPUPMENU));
+                    VclBuilder aBuilder(nullptr, VclBuilderContainer::getUIRootDir(), "dbaccess/ui/tabledesignrowmenu.ui", "");
+                    VclPtr<PopupMenu> aContextMenu(aBuilder.get_menu("menu"));
 
-                    aContextMenu.EnableItem( SID_CUT, IsCutAllowed(nRow) );
-                    aContextMenu.EnableItem( SID_COPY, IsCopyAllowed(nRow) );
-                    aContextMenu.EnableItem( SID_PASTE, IsPasteAllowed(nRow) );
-                    aContextMenu.EnableItem( SID_DELETE, IsDeleteAllowed(nRow) );
-                    aContextMenu.EnableItem( SID_TABLEDESIGN_TABED_PRIMARYKEY, IsPrimaryKeyAllowed(nRow) );
-                    aContextMenu.EnableItem( SID_TABLEDESIGN_INSERTROWS, IsInsertNewAllowed(nRow) );
-                    aContextMenu.CheckItem( SID_TABLEDESIGN_TABED_PRIMARYKEY, IsRowSelected(GetCurRow()) && IsPrimaryKey() );
+                    aContextMenu->EnableItem(aContextMenu->GetItemId("cut"), IsCutAllowed());
+                    aContextMenu->EnableItem(aContextMenu->GetItemId("copy"), IsCopyAllowed());
+                    aContextMenu->EnableItem(aContextMenu->GetItemId("paste"), IsPasteAllowed());
+                    aContextMenu->EnableItem(aContextMenu->GetItemId("delete"), IsDeleteAllowed(nRow));
+                    aContextMenu->EnableItem(aContextMenu->GetItemId("primarykey"), IsPrimaryKeyAllowed(nRow));
+                    aContextMenu->EnableItem(aContextMenu->GetItemId("insert"), IsInsertNewAllowed(nRow));
+                    aContextMenu->CheckItem(aContextMenu->GetItemId("primarykey"), IsRowSelected(GetCurRow()) && IsPrimaryKey());
 
                     // remove all the disable entries
-                    aContextMenu.RemoveDisabledEntries(true, true);
+                    aContextMenu->RemoveDisabledEntries(true, true);
 
                     if( SetDataPtr(m_nDataPos) )
                         pDescrWin->SaveData( pActRow->GetActFieldDescr() );
@@ -1403,32 +1384,29 @@ void OTableEditorCtrl::Command(const CommandEvent& rEvt)
                     // All actions which change the number of rows must be run asynchronously
                     // otherwise there may be problems between the Context menu and the Browser
                     m_nDataPos = GetCurRow();
-                    switch (aContextMenu.Execute(this, aMenuPos))
+                    aContextMenu->Execute(this, aMenuPos);
+                    OString sIdent = aContextMenu->GetCurItemIdent();
+                    if (sIdent == "cut")
+                        cut();
+                    else if (sIdent == "copy")
+                        copy();
+                    else if (sIdent == "paste")
+                        paste();
+                    else if (sIdent == "delete")
                     {
-                        case SID_CUT:
-                            cut();
-                            break;
-                        case SID_COPY:
-                            copy();
-                            break;
-                        case SID_PASTE:
-                            paste();
-                            break;
-                        case SID_DELETE:
-                            if( nDeleteEvent )
-                                Application::RemoveUserEvent( nDeleteEvent );
-                            nDeleteEvent = Application::PostUserEvent( LINK(this, OTableEditorCtrl, DelayedDelete), nullptr, true );
-                            break;
-                        case SID_TABLEDESIGN_INSERTROWS:
-                            if( nInsNewRowsEvent )
-                                Application::RemoveUserEvent( nInsNewRowsEvent );
-                            nInsNewRowsEvent = Application::PostUserEvent( LINK(this, OTableEditorCtrl, DelayedInsNewRows), nullptr, true );
-                            break;
-                        case SID_TABLEDESIGN_TABED_PRIMARYKEY:
-                            SetPrimaryKey( !IsPrimaryKey() );
-                            break;
-                        default:
-                            break;
+                        if( nDeleteEvent )
+                            Application::RemoveUserEvent( nDeleteEvent );
+                        nDeleteEvent = Application::PostUserEvent( LINK(this, OTableEditorCtrl, DelayedDelete), nullptr, true );
+                    }
+                    else if (sIdent == "insert")
+                    {
+                        if( nInsNewRowsEvent )
+                            Application::RemoveUserEvent( nInsNewRowsEvent );
+                        nInsNewRowsEvent = Application::PostUserEvent( LINK(this, OTableEditorCtrl, DelayedInsNewRows), nullptr, true );
+                    }
+                    else if (sIdent == "primarykey")
+                    {
+                        SetPrimaryKey( !IsPrimaryKey() );
                     }
                 }
             }
@@ -1440,13 +1418,13 @@ void OTableEditorCtrl::Command(const CommandEvent& rEvt)
 
 }
 
-IMPL_LINK_NOARG_TYPED( OTableEditorCtrl, DelayedCut, void*, void )
+IMPL_LINK_NOARG( OTableEditorCtrl, DelayedCut, void*, void )
 {
     nCutEvent = nullptr;
     OTableRowView::cut();
 }
 
-IMPL_LINK_NOARG_TYPED( OTableEditorCtrl, DelayedPaste, void*, void )
+IMPL_LINK_NOARG( OTableEditorCtrl, DelayedPaste, void*, void )
 {
     nPasteEvent = nullptr;
 
@@ -1458,7 +1436,7 @@ IMPL_LINK_NOARG_TYPED( OTableEditorCtrl, DelayedPaste, void*, void )
     {   // Insertion is not allowed, only appending, so test if there are full cells after the PastePosition
 
         sal_Int32 nFreeFromPos; // from here on there are only empty rows
-        ::std::vector< std::shared_ptr<OTableRow> >::reverse_iterator aIter = m_pRowList->rbegin();
+        std::vector< std::shared_ptr<OTableRow> >::const_reverse_iterator aIter = m_pRowList->rbegin();
         for(nFreeFromPos = m_pRowList->size();
             aIter != m_pRowList->rend() && (!(*aIter) || !(*aIter)->GetActFieldDescr() || (*aIter)->GetActFieldDescr()->GetName().isEmpty());
             --nFreeFromPos, ++aIter)
@@ -1472,13 +1450,13 @@ IMPL_LINK_NOARG_TYPED( OTableEditorCtrl, DelayedPaste, void*, void )
     GoToRow( nPastePosition );
 }
 
-IMPL_LINK_NOARG_TYPED( OTableEditorCtrl, DelayedDelete, void*, void )
+IMPL_LINK_NOARG( OTableEditorCtrl, DelayedDelete, void*, void )
 {
     nDeleteEvent = nullptr;
     DeleteRows();
 }
 
-IMPL_LINK_NOARG_TYPED( OTableEditorCtrl, DelayedInsNewRows, void*, void )
+IMPL_LINK_NOARG( OTableEditorCtrl, DelayedInsNewRows, void*, void )
 {
     nInsNewRowsEvent = nullptr;
     sal_Int32 nPastePosition = GetView()->getController().getFirstEmptyRowPosition();
@@ -1523,8 +1501,8 @@ void OTableEditorCtrl::SetPrimaryKey( bool bSet )
     MultiSelection aDeletedPrimKeys;
     aDeletedPrimKeys.SetTotalRange( Range(0,GetRowCount()) );
 
-    ::std::vector< std::shared_ptr<OTableRow> >::const_iterator aIter = m_pRowList->begin();
-    ::std::vector< std::shared_ptr<OTableRow> >::const_iterator aEnd = m_pRowList->end();
+    std::vector< std::shared_ptr<OTableRow> >::const_iterator aIter = m_pRowList->begin();
+    std::vector< std::shared_ptr<OTableRow> >::const_iterator aEnd = m_pRowList->end();
     for(sal_Int32 nRow = 0;aIter != aEnd;++aIter,++nRow)
     {
         OFieldDescription* pFieldDescr = (*aIter)->GetActFieldDescr();
@@ -1558,7 +1536,7 @@ void OTableEditorCtrl::SetPrimaryKey( bool bSet )
     InvalidateHandleColumn();
 
     // Set the TableDocSh's ModifyFlag
-    GetView()->getController().setModified( sal_True );
+    GetView()->getController().setModified( true );
     InvalidateFeatures();
 }
 
@@ -1566,8 +1544,8 @@ bool OTableEditorCtrl::IsPrimaryKey()
 {
     // Are all marked fields part of the Primary Key ?
     long nPrimaryKeys = 0;
-    ::std::vector< std::shared_ptr<OTableRow> >::const_iterator aIter = m_pRowList->begin();
-    ::std::vector< std::shared_ptr<OTableRow> >::const_iterator aEnd = m_pRowList->end();
+    std::vector< std::shared_ptr<OTableRow> >::const_iterator aIter = m_pRowList->begin();
+    std::vector< std::shared_ptr<OTableRow> >::const_iterator aEnd = m_pRowList->end();
     for(sal_Int32 nRow=0;aIter != aEnd;++aIter,++nRow)
     {
         if( IsRowSelected(nRow) && !(*aIter)->IsPrimaryKey() )
@@ -1596,7 +1574,7 @@ void OTableEditorCtrl::SwitchType( const TOTypeInfoSP& _pType )
     pRow->SetFieldType( _pType, true );
     if ( _pType.get() )
     {
-        const sal_Int32 nCurrentlySelected = pTypeCell->GetSelectEntryPos();
+        const sal_Int32 nCurrentlySelected = pTypeCell->GetSelectedEntryPos();
 
         if  (   ( LISTBOX_ENTRY_NOTFOUND == nCurrentlySelected )
             ||  ( GetView()->getController().getTypeInfo( nCurrentlySelected ) != _pType )
