@@ -17,13 +17,9 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "dp_misc.h"
-#include "dp_persmap.h"
-#include "rtl/strbuf.hxx"
-
-#ifndef DISABLE_BDB2PMAP
-#  include <vector>
-#endif
+#include <dp_misc.h>
+#include <dp_persmap.h>
+#include <rtl/strbuf.hxx>
 
 using namespace ::rtl;
 
@@ -39,22 +35,17 @@ namespace dp_misc
 
 static const char PmapMagic[4] = {'P','m','p','1'};
 
-PersistentMap::PersistentMap( OUString const & url_, bool readOnly )
+PersistentMap::PersistentMap( OUString const & url_ )
 :    m_MapFile( expandUnoRcUrl(url_) )
-,    m_bReadOnly( readOnly )
 ,    m_bIsOpen( false )
-,    m_bToBeCreated( !readOnly )
+,    m_bToBeCreated( true )
 ,    m_bIsDirty( false )
 {
-#ifndef DISABLE_BDB2PMAP
-    m_MapFileName = expandUnoRcUrl( url_ );
-#endif
     open();
 }
 
 PersistentMap::PersistentMap()
 :    m_MapFile( OUString() )
-,    m_bReadOnly( false )
 ,    m_bIsOpen( false )
 ,    m_bToBeCreated( false )
 ,    m_bIsDirty( false )
@@ -145,12 +136,10 @@ static OString decodeString( const sal_Char* pEncChars, int nLen)
     return aDecStr.makeStringAndClear();
 }
 
-bool PersistentMap::open()
+void PersistentMap::open()
 {
     // open the existing file
-    sal_uInt32 nOpenFlags = osl_File_OpenFlag_Read;
-    if( !m_bReadOnly)
-        nOpenFlags |= osl_File_OpenFlag_Write;
+    sal_uInt32 const nOpenFlags = osl_File_OpenFlag_Read | osl_File_OpenFlag_Write;
 
     const osl::File::RC rcOpen = m_MapFile.open( nOpenFlags);
     m_bIsOpen = (rcOpen == osl::File::E_None);
@@ -158,24 +147,23 @@ bool PersistentMap::open()
     // or create later if needed
     m_bToBeCreated &= (rcOpen == osl::File::E_NOENT) && !m_bIsOpen;
 
-#ifndef DISABLE_BDB2PMAP
-    if( m_bToBeCreated )
-        importFromBDB();
-#endif
-
     if( !m_bIsOpen)
-        return m_bToBeCreated;
+        return;
 
-    return readAll();
+    readAll();
 }
 
-//______________________________________________________________________________
-bool PersistentMap::readAll()
+
+void PersistentMap::readAll()
 {
     // prepare for re-reading the map-file
-    const osl::FileBase::RC nRes = m_MapFile.setPos( osl_Pos_Absolut, 0);
-    (void)nRes;
     m_entries.clear();
+    const osl::FileBase::RC nRes = m_MapFile.setPos( osl_Pos_Absolut, 0);
+    if (nRes != osl::FileBase::E_None)
+    {
+        SAL_WARN("desktop.deployment", "setPos failed with " << +nRes);
+        return;
+    }
 
     // read header and check magic
     char aHeaderBytes[ sizeof(PmapMagic)];
@@ -183,11 +171,11 @@ bool PersistentMap::readAll()
     m_MapFile.read( aHeaderBytes, sizeof(aHeaderBytes), nBytesRead);
     OSL_ASSERT( nBytesRead == sizeof(aHeaderBytes));
     if( nBytesRead != sizeof(aHeaderBytes))
-        return false;
+        return;
     // check header magic
     for( int i = 0; i < (int)sizeof(PmapMagic); ++i)
         if( aHeaderBytes[i] != PmapMagic[i])
-            return false;
+            return;
 
     // read key value pairs and add them to the map
     ByteSequence aKeyLine;
@@ -197,33 +185,31 @@ bool PersistentMap::readAll()
         // read key-value line pair
         // an empty key name indicates the end of the line pairs
         if( m_MapFile.readLine( aKeyLine) != osl::File::E_None)
-            return false;
+            return;
         if( !aKeyLine.getLength())
             break;
         if( m_MapFile.readLine( aValLine) != osl::File::E_None)
-            return false;
+            return;
         // decode key and value strings
-        const OString aKeyName = decodeString( (sal_Char*)aKeyLine.getConstArray(), aKeyLine.getLength());
-        const OString aValName = decodeString( (sal_Char*)aValLine.getConstArray(), aValLine.getLength());
+        const OString aKeyName = decodeString( reinterpret_cast<char const *>(aKeyLine.getConstArray()), aKeyLine.getLength());
+        const OString aValName = decodeString( reinterpret_cast<char const *>(aValLine.getConstArray()), aValLine.getLength());
         // insert key-value pair into map
         add( aKeyName, aValName );
         // check end-of-file status
         sal_Bool bIsEOF = true;
         if( m_MapFile.isEndOfFile( &bIsEOF) != osl::File::E_None )
-            return false;
+            return;
         if( bIsEOF )
             break;
     }
 
     m_bIsDirty = false;
-    return true;
 }
 
 void PersistentMap::flush()
 {
     if( !m_bIsDirty)
         return;
-    OSL_ASSERT( !m_bReadOnly);
     if( m_bToBeCreated && !m_entries.empty())
     {
         const sal_uInt32 nOpenFlags = osl_File_OpenFlag_Read | osl_File_OpenFlag_Write | osl_File_OpenFlag_Create;
@@ -236,7 +222,11 @@ void PersistentMap::flush()
 
     // write header magic
     const osl::FileBase::RC nRes = m_MapFile.setPos( osl_Pos_Absolut, 0);
-    (void)nRes;
+    if (nRes != osl::FileBase::E_None)
+    {
+        SAL_WARN("desktop.deployment", "setPos failed with " << +nRes);
+        return;
+    }
     sal_uInt64 nBytesWritten = 0;
     m_MapFile.write( PmapMagic, sizeof(PmapMagic), nBytesWritten);
 
@@ -271,7 +261,7 @@ void PersistentMap::flush()
 
 bool PersistentMap::has( OString const & key ) const
 {
-    return get( NULL, key );
+    return get( nullptr, key );
 }
 
 bool PersistentMap::get( OString * value, OString const & key ) const
@@ -286,14 +276,12 @@ bool PersistentMap::get( OString * value, OString const & key ) const
 
 void PersistentMap::add( OString const & key, OString const & value )
 {
-    if( m_bReadOnly)
-        return;
     typedef std::pair<t_string2string_map::iterator,bool> InsertRC;
-    InsertRC r = m_entries.insert( t_string2string_map::value_type(key,value));
+    InsertRC r = m_entries.emplace(key,value);
     m_bIsDirty = r.second;
 }
 
-//______________________________________________________________________________
+
 void PersistentMap::put( OString const & key, OString const & value )
 {
     add( key, value);
@@ -303,121 +291,16 @@ void PersistentMap::put( OString const & key, OString const & value )
         flush();
 }
 
-bool PersistentMap::erase( OString const & key, bool flush_immediately )
+bool PersistentMap::erase( OString const & key )
 {
-    if( m_bReadOnly)
-        return false;
     size_t nCount = m_entries.erase( key);
     if( !nCount)
         return false;
     m_bIsDirty = true;
-    if( flush_immediately)
-        flush();
+    flush();
     return true;
 }
 
-t_string2string_map PersistentMap::getEntries() const
-{
-    // TODO: return by const reference instead?
-    return m_entries;
-}
-
-#ifndef DISABLE_BDB2PMAP
-bool PersistentMap::importFromBDB()
-{
-    if( m_bReadOnly)
-        return false;
-
-    // get the name of its BDB counterpart
-    OUString aDBName = m_MapFileName;
-    if( !aDBName.endsWith( ".pmap" ))
-        return false;
-    aDBName = aDBName.replaceAt( aDBName.getLength()-5, 5, ".db");
-
-    // open the corresponding BDB file for reading
-    osl::File aDBFile( aDBName);
-    osl::File::RC rc = aDBFile.open( osl_File_OpenFlag_Read);
-    if( rc != osl::File::E_None)
-        return false;
-    sal_uInt64 nFileSize = 0;
-    if( aDBFile.getSize( nFileSize) != osl::File::E_None)
-        return false;
-
-    // read the BDB file
-    std::vector<sal_uInt8> aRawBDB( nFileSize);
-    for( sal_uInt64 nOfs = 0; nOfs < nFileSize;) {
-        sal_uInt64 nBytesRead = 0;
-        rc = aDBFile.read( (void*)&aRawBDB[nOfs], nFileSize - nOfs, nBytesRead);
-        if( (rc != osl::File::E_None) || !nBytesRead)
-            return false;
-        nOfs += nBytesRead;
-    }
-
-    // check BDB file header for non_encrypted Hash format v4..9
-    if( nFileSize < 0x0100)
-        return false;
-    if( aRawBDB[24] != 0) // only not-encrypted migration
-        return false;
-    if( aRawBDB[25] != 8) // we expect a P_HASHMETA page
-        return false;
-    const bool bLE = (aRawBDB[12]==0x61 && aRawBDB[13]==0x15 && aRawBDB[14]==0x06);
-    const bool bBE = (aRawBDB[15]==0x61 && aRawBDB[14]==0x15 && aRawBDB[13]==0x06);
-    if( bBE == bLE)
-        return false;
-    if( (aRawBDB[16] < 4) || (9 < aRawBDB[16])) // version
-        return false;
-    const sal_uInt64 nPgSize = bLE
-    ?    (aRawBDB[20] + (aRawBDB[21]<<8) + (aRawBDB[22]<<16) + (aRawBDB[23]<<24))
-    :    (aRawBDB[23] + (aRawBDB[22]<<8) + (aRawBDB[21]<<16) + (aRawBDB[20]<<24));
-    const int nPgCount = nFileSize / nPgSize;
-    if( nPgCount * nPgSize != nFileSize)
-        return false;
-
-    // find PackageManager's new_style entries
-    // using a simple heuristic for BDB_Hash pages
-    int nEntryCount = 0;
-    for( int nPgNo = 1; nPgNo < nPgCount; ++nPgNo) {
-        // parse the next _db_page
-        const sal_uInt8* const pPage = &aRawBDB[ nPgNo * nPgSize];
-        const sal_uInt8* const pEnd = pPage + nPgSize;
-        const int nHfOffset = bLE ? (pPage[22] + (pPage[23]<<8)) : (pPage[23] + (pPage[22]<<8));
-        if( nHfOffset <= 0)
-            continue;
-        const sal_uInt8* pCur = pPage + nHfOffset;
-        // iterate through the entries
-        for(; pCur < pEnd; ++pCur) {
-            if( pCur[0] != 0x01)
-                continue;
-            // get the value-candidate
-            const sal_uInt8* pVal = pCur + 1;
-            while( ++pCur < pEnd)
-                if( (*pCur < ' ') || ((*pCur > 0x7F) && (*pCur != 0xFF)))
-                    break;
-            if( pCur >= pEnd)
-                break;
-            if( (pCur[0] != 0x01) || (pCur[1] != 0xFF))
-                continue;
-            const OString aVal( (sal_Char*)pVal, pCur - pVal);
-            // get the key-candidate
-            const sal_uInt8* pKey = pCur + 1;
-            while( ++pCur < pEnd)
-                if( (*pCur < ' ') || ((*pCur > 0x7F) && (*pCur != 0xFF)))
-                    break;
-            if( (pCur < pEnd) && (*pCur > 0x01))
-                continue;
-            const OString aKey( (sal_Char*)pKey, pCur - pKey);
-            --pCur; // prepare for next round by rewinding to end of key-string
-
-            // add the key/value pair
-            add( aKey, aVal);
-            ++nEntryCount;
-        }
-    }
-
-    return (nEntryCount > 0);
-}
-#endif // DISABLE_BDB2PMAP
-
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
