@@ -18,24 +18,24 @@
  */
 
 
-#include "dp_gui_shared.hxx"
+#include <memory>
+#include <dp_shared.hxx>
 #include "dp_gui.h"
 #include "dp_gui_theextmgr.hxx"
-#include "cppuhelper/implbase2.hxx"
-#include "cppuhelper/implementationentry.hxx"
-#include "unotools/configmgr.hxx"
-#include "comphelper/processfactory.hxx"
-#include "comphelper/servicedecl.hxx"
-#include "comphelper/unwrapargs.hxx"
-#include <i18nlangtag/languagetag.hxx>
-#include "vcl/svapp.hxx"
-#include "vcl/msgbox.hxx"
-#include "com/sun/star/lang/XServiceInfo.hpp"
-#include "com/sun/star/task/XJobExecutor.hpp"
-#include "com/sun/star/ui/dialogs/XAsynchronousExecutableDialog.hpp"
+#include <cppuhelper/implbase.hxx>
+#include <cppuhelper/implementationentry.hxx>
+#include <unotools/configmgr.hxx>
+#include <comphelper/processfactory.hxx>
+#include <comphelper/servicedecl.hxx>
+#include <comphelper/unwrapargs.hxx>
+#include <vcl/layout.hxx>
+#include <vcl/svapp.hxx>
+#include <vcl/settings.hxx>
+#include <com/sun/star/lang/XServiceInfo.hpp>
+#include <com/sun/star/task/XJobExecutor.hpp>
+#include <com/sun/star/ui/dialogs/XAsynchronousExecutableDialog.hpp>
 
 #include <boost/optional.hpp>
-#include <boost/utility.hpp>
 #include "license_dialog.hxx"
 #include "dp_gui_dialog2.hxx"
 #include "dp_gui_extensioncmdqueue.hxx"
@@ -44,32 +44,29 @@ using namespace ::dp_misc;
 using namespace ::com::sun::star;
 using namespace ::com::sun::star::uno;
 
+namespace sdecl = comphelper::service_decl;
 
 namespace dp_gui {
 
-//==============================================================================
-class MyApp : public Application, private boost::noncopyable
+
+class MyApp : public Application
 {
 public:
     MyApp();
-    virtual ~MyApp();
+
+    MyApp(const MyApp&) = delete;
+    const MyApp& operator=(const MyApp&) = delete;
 
     // Application
-    virtual int Main();
-    virtual void DeInit();
+    virtual int Main() override;
+    virtual void DeInit() override;
 };
 
-//______________________________________________________________________________
-MyApp::~MyApp()
-{
-}
-
-//______________________________________________________________________________
 MyApp::MyApp()
 {
 }
 
-//______________________________________________________________________________
+
 int MyApp::Main()
 {
     return EXIT_SUCCESS;
@@ -82,7 +79,7 @@ void MyApp::DeInit()
     dp_misc::disposeBridges(context);
     css::uno::Reference< css::lang::XComponent >(
         context, css::uno::UNO_QUERY_THROW)->dispose();
-    comphelper::setProcessServiceFactory(0);
+    comphelper::setProcessServiceFactory(nullptr);
 }
 
 namespace
@@ -135,9 +132,9 @@ OUString ReplaceProductNameHookProc( const OUString& rStr )
     return sRet;
 }
 
-//==============================================================================
+
 class ServiceImpl
-    : public ::cppu::WeakImplHelper2<ui::dialogs::XAsynchronousExecutableDialog,
+    : public ::cppu::WeakImplHelper<ui::dialogs::XAsynchronousExecutableDialog,
                                      task::XJobExecutor>
 {
     Reference<XComponentContext> const m_xComponentContext;
@@ -154,18 +151,15 @@ public:
                  Reference<XComponentContext> const & xComponentContext );
 
     // XAsynchronousExecutableDialog
-    virtual void SAL_CALL setDialogTitle( OUString const & aTitle )
-        throw (RuntimeException);
+    virtual void SAL_CALL setDialogTitle( OUString const & aTitle ) override;
     virtual void SAL_CALL startExecuteModal(
-        Reference< ui::dialogs::XDialogClosedListener > const & xListener )
-        throw (RuntimeException);
+        Reference< ui::dialogs::XDialogClosedListener > const & xListener ) override;
 
     // XJobExecutor
-    virtual void SAL_CALL trigger( OUString const & event )
-        throw (RuntimeException);
+    virtual void SAL_CALL trigger( OUString const & event ) override;
 };
 
-//______________________________________________________________________________
+
 ServiceImpl::ServiceImpl( Sequence<Any> const& args,
                           Reference<XComponentContext> const& xComponentContext)
     : m_xComponentContext(xComponentContext),
@@ -181,15 +175,14 @@ ServiceImpl::ServiceImpl( Sequence<Any> const& args,
     } catch ( const css::lang::IllegalArgumentException & ) {
     }
 
-    ResHookProc pProc = ResMgr::GetReadStringHook();
+    ResHookProc pProc = Translate::GetReadStringHook();
     if ( !pProc )
-        ResMgr::SetReadStringHook( ReplaceProductNameHookProc );
+        Translate::SetReadStringHook(ReplaceProductNameHookProc);
 }
 
 // XAsynchronousExecutableDialog
-//______________________________________________________________________________
+
 void ServiceImpl::setDialogTitle( OUString const & title )
-    throw (RuntimeException)
 {
     if ( dp_gui::TheExtensionManager::s_ExtMgr.is() )
     {
@@ -204,17 +197,16 @@ void ServiceImpl::setDialogTitle( OUString const & title )
         m_initialTitle = title;
 }
 
-//______________________________________________________________________________
+
 void ServiceImpl::startExecuteModal(
     Reference< ui::dialogs::XDialogClosedListener > const & xListener )
-    throw (RuntimeException)
 {
     bool bCloseDialog = true;  // only used if m_bShowUpdateOnly is true
-    ::std::auto_ptr<Application> app;
+    std::unique_ptr<Application> app;
     //ToDo: synchronize access to s_dialog !!!
     if (! dp_gui::TheExtensionManager::s_ExtMgr.is())
     {
-        const bool bAppUp = (GetpApp() != 0);
+        const bool bAppUp = (GetpApp() != nullptr);
         bool bOfficePipePresent;
         try {
             bOfficePipePresent = dp_misc::office_is_running();
@@ -222,9 +214,8 @@ void ServiceImpl::startExecuteModal(
         catch (const Exception & exc) {
             if (bAppUp) {
                 const SolarMutexGuard guard;
-                std::auto_ptr<ErrorBox> box(
-                    new ErrorBox( Application::GetActiveTopWindow(),
-                                  WB_OK, exc.Message ) );
+                ScopedVclPtrInstance<MessageDialog> box(
+                        Application::GetActiveTopWindow(), exc.Message);
                 box->Execute();
             }
             throw;
@@ -236,12 +227,9 @@ void ServiceImpl::startExecuteModal(
             if (! InitVCL() )
                 throw RuntimeException( "Cannot initialize VCL!",
                                         static_cast<OWeakObject *>(this) );
-            AllSettings as = app->GetSettings();
-            as.SetUILanguageTag( LanguageTag( utl::ConfigManager::getLocale() ).makeFallback() );
-            app->SetSettings( as );
-            app->SetDisplayName(
+            Application::SetDisplayName(
                 utl::ConfigManager::getProductName() +
-                OUString(" ") +
+                " " +
                 utl::ConfigManager::getProductVersion());
             ExtensionCmdQueue::syncRepositories( m_xComponentContext );
         }
@@ -265,24 +253,24 @@ void ServiceImpl::startExecuteModal(
         myExtMgr->createDialog( false );
         if (!m_initialTitle.isEmpty()) {
             myExtMgr->SetText( m_initialTitle );
-            m_initialTitle = OUString();
+            m_initialTitle.clear();
         }
         if ( m_bShowUpdateOnly )
         {
-            myExtMgr->checkUpdates( true, !bCloseDialog );
+            myExtMgr->checkUpdates();
             if ( bCloseDialog )
                 myExtMgr->Close();
             else
-                myExtMgr->ToTop( TOTOP_RESTOREWHENMIN );
+                myExtMgr->ToTop( ToTopFlags::RestoreWhenMin );
         }
         else
         {
             myExtMgr->Show();
-            myExtMgr->ToTop( TOTOP_RESTOREWHENMIN );
+            myExtMgr->ToTop( ToTopFlags::RestoreWhenMin );
         }
     }
 
-    if (app.get() != 0) {
+    if (app.get() != nullptr) {
         Application::Execute();
         DeInitVCL();
     }
@@ -295,8 +283,8 @@ void ServiceImpl::startExecuteModal(
 }
 
 // XJobExecutor
-//______________________________________________________________________________
-void ServiceImpl::trigger( OUString const &rEvent ) throw (RuntimeException)
+
+void ServiceImpl::trigger( OUString const &rEvent )
 {
     if ( rEvent == "SHOW_UPDATE_DIALOG" )
         m_bShowUpdateOnly = true;
@@ -306,20 +294,19 @@ void ServiceImpl::trigger( OUString const &rEvent ) throw (RuntimeException)
     startExecuteModal( Reference< ui::dialogs::XDialogClosedListener >() );
 }
 
-namespace sdecl = comphelper::service_decl;
-sdecl::class_<ServiceImpl, sdecl::with_args<true> > serviceSI;
+sdecl::class_<ServiceImpl, sdecl::with_args<true> > const serviceSI;
 sdecl::ServiceDecl const serviceDecl(
     serviceSI,
     "com.sun.star.comp.deployment.ui.PackageManagerDialog",
     "com.sun.star.deployment.ui.PackageManagerDialog" );
 
-sdecl::class_<LicenseDialog, sdecl::with_args<true> > licenseSI;
+sdecl::class_<LicenseDialog, sdecl::with_args<true> > const licenseSI;
 sdecl::ServiceDecl const licenseDecl(
     licenseSI,
     "com.sun.star.comp.deployment.ui.LicenseDialog",
     "com.sun.star.deployment.ui.LicenseDialog" );
 
-sdecl::class_<UpdateRequiredDialogService, sdecl::with_args<true> > updateSI;
+sdecl::class_<UpdateRequiredDialogService, sdecl::with_args<true> > const updateSI;
 sdecl::ServiceDecl const updateDecl(
     updateSI,
     "com.sun.star.comp.deployment.ui.UpdateRequiredDialog",
@@ -329,12 +316,11 @@ sdecl::ServiceDecl const updateDecl(
 extern "C" {
 
 SAL_DLLPUBLIC_EXPORT void * SAL_CALL deploymentgui_component_getFactory(
-    sal_Char const * pImplName,
-    lang::XMultiServiceFactory * pServiceManager,
-    registry::XRegistryKey * pRegistryKey )
+    sal_Char const * pImplName, void *, void *)
 {
-    return component_getFactoryHelper(
-        pImplName, pServiceManager, pRegistryKey, dp_gui::serviceDecl, dp_gui::licenseDecl, dp_gui::updateDecl );
+    return sdecl::component_getFactoryHelper(
+        pImplName,
+        {&dp_gui::serviceDecl, &dp_gui::licenseDecl, &dp_gui::updateDecl});
 }
 
 } // extern "C"
