@@ -19,10 +19,11 @@
 
 #include <config_folders.h>
 #include <config_features.h>
+#include <chrono>
 
-#include "dp_misc.h"
-#include "dp_version.hxx"
-#include "dp_interact.h"
+#include <dp_misc.h>
+#include <dp_version.hxx>
+#include <dp_interact.h>
 #include <rtl/uri.hxx>
 #include <rtl/digest.h>
 #include <rtl/random.h>
@@ -33,7 +34,6 @@
 #include <osl/pipe.hxx>
 #include <osl/security.hxx>
 #include <osl/thread.hxx>
-#include <osl/mutex.hxx>
 #include <com/sun/star/ucb/CommandAbortedException.hpp>
 #include <com/sun/star/task/XInteractionHandler.hpp>
 #include <com/sun/star/bridge/BridgeFactory.hpp>
@@ -46,8 +46,7 @@
 #include <comphelper/processfactory.hxx>
 #include <salhelper/linkhelper.hxx>
 
-#ifdef WNT
-#define UNICODE
+#ifdef _WIN32
 #define WIN32_LEAN_AND_MEAN
 #include <windows.h>
 #endif
@@ -55,7 +54,7 @@
 using namespace ::com::sun::star;
 using namespace ::com::sun::star::uno;
 
-#if defined WNT
+#if defined(_WIN32)
 #define SOFFICE1 "soffice.exe"
 #define SBASE "sbase.exe"
 #define SCALC "scalc.exe"
@@ -107,7 +106,7 @@ const OUString OfficePipeId::operator () ()
 
     sal_uInt8 const * data =
         reinterpret_cast<sal_uInt8 const *>(userPath.getStr());
-    sal_Size size = (userPath.getLength() * sizeof (sal_Unicode));
+    std::size_t size = (userPath.getLength() * sizeof (sal_Unicode));
     sal_uInt32 md5_key_len = rtl_digest_queryLength( digest );
     std::unique_ptr<sal_uInt8[]> md5_buf( new sal_uInt8 [ md5_key_len ] );
 
@@ -137,7 +136,7 @@ bool existsOfficePipe()
 }
 
 //get modification time
-static bool getModifyTimeTargetFile(const OUString &rFileURL, TimeValue &rTime)
+bool getModifyTimeTargetFile(const OUString &rFileURL, TimeValue &rTime)
 {
     salhelper::LinkResolver aResolver(osl_FileStatus_Mask_ModifyTime);
 
@@ -239,7 +238,6 @@ bool needToSyncRepository(OUString const & name)
 } // anon namespace
 
 
-
 namespace {
 inline OUString encodeForRcFile( OUString const & str )
 {
@@ -294,10 +292,9 @@ OUString makeURL( OUString const & baseURL, OUString const & relPath_ )
     return buf.makeStringAndClear();
 }
 
-OUString makeURLAppendSysPathSegment( OUString const & baseURL, OUString const & relPath_ )
+OUString makeURLAppendSysPathSegment( OUString const & baseURL, OUString const & segment )
 {
-    OUString segment = relPath_;
-    OSL_ASSERT(segment.indexOf(static_cast<sal_Unicode>('/')) == -1);
+    OSL_ASSERT(segment.indexOf(u'/') == -1);
 
     ::rtl::Uri::encode(
         segment, rtl_UriCharClassPchar, rtl_UriEncodeIgnoreEscapes,
@@ -306,8 +303,6 @@ OUString makeURLAppendSysPathSegment( OUString const & baseURL, OUString const &
 }
 
 
-
-
 OUString expandUnoRcTerm( OUString const & term_ )
 {
     OUString term(term_);
@@ -431,12 +426,12 @@ OUString generateRandomPipeId()
         throw RuntimeException( "cannot create random pool!?", nullptr );
     sal_uInt8 bytes[ 32 ];
     if (rtl_random_getBytes(
-            s_hPool, bytes, ARLEN(bytes) ) != rtl_Random_E_None) {
+            s_hPool, bytes, SAL_N_ELEMENTS(bytes) ) != rtl_Random_E_None) {
         throw RuntimeException( "random pool error!?", nullptr );
     }
     OUStringBuffer buf;
-    for ( sal_uInt32 i = 0; i < ARLEN(bytes); ++i ) {
-        buf.append( static_cast<sal_Int32>(bytes[ i ]), 0x10 );
+    for (unsigned char byte : bytes) {
+        buf.append( static_cast<sal_Int32>(byte), 0x10 );
     }
     return buf.makeStringAndClear();
 }
@@ -445,7 +440,7 @@ OUString generateRandomPipeId()
 Reference<XInterface> resolveUnoURL(
     OUString const & connectString,
     Reference<XComponentContext> const & xLocalContext,
-    AbortChannel * abortChannel )
+    AbortChannel const * abortChannel )
 {
     Reference<bridge::XUnoUrlResolver> xUnoUrlResolver(
         bridge::UnoUrlResolver::create( xLocalContext ) );
@@ -461,8 +456,7 @@ Reference<XInterface> resolveUnoURL(
         catch (const connection::NoConnectException &) {
             if (i < 20)
             {
-                TimeValue tv = { 0 /* secs */, 500000000 /* nanosecs */ };
-                ::osl::Thread::wait( tv );
+                ::osl::Thread::wait( std::chrono::milliseconds(500) );
             }
             else throw;
         }
@@ -470,12 +464,12 @@ Reference<XInterface> resolveUnoURL(
     return nullptr; // warning C4715
 }
 
-#ifdef WNT
+#ifdef _WIN32
 void writeConsoleWithStream(OUString const & sText, HANDLE stream)
 {
     DWORD nWrittenChars = 0;
     WriteFile(stream, sText.getStr(),
-        sText.getLength() * 2, &nWrittenChars, NULL);
+        sText.getLength() * 2, &nWrittenChars, nullptr);
 }
 #else
 void writeConsoleWithStream(OUString const & sText, FILE * stream)
@@ -488,7 +482,7 @@ void writeConsoleWithStream(OUString const & sText, FILE * stream)
 
 void writeConsole(OUString const & sText)
 {
-#ifdef WNT
+#ifdef _WIN32
     writeConsoleWithStream(sText, GetStdHandle(STD_OUTPUT_HANDLE));
 #else
     writeConsoleWithStream(sText, stdout);
@@ -497,7 +491,7 @@ void writeConsole(OUString const & sText)
 
 void writeConsoleError(OUString const & sText)
 {
-#ifdef WNT
+#ifdef _WIN32
     writeConsoleWithStream(sText, GetStdHandle(STD_ERROR_HANDLE));
 #else
     writeConsoleWithStream(sText, stderr);
@@ -506,11 +500,11 @@ void writeConsoleError(OUString const & sText)
 
 OUString readConsole()
 {
-#ifdef WNT
+#ifdef _WIN32
     sal_Unicode aBuffer[1024];
     DWORD   dwRead = 0;
     //unopkg.com feeds unopkg.exe with wchar_t|s
-    if (ReadFile( GetStdHandle(STD_INPUT_HANDLE), &aBuffer, sizeof(aBuffer), &dwRead, NULL ) )
+    if (ReadFile( GetStdHandle(STD_INPUT_HANDLE), &aBuffer, sizeof(aBuffer), &dwRead, nullptr ) )
     {
         OSL_ASSERT((dwRead % 2) == 0);
         OUString value( aBuffer, dwRead / 2);
@@ -526,7 +520,7 @@ OUString readConsole()
         return value.trim();
     }
 #endif
-    return OUString();
+    throw css::uno::RuntimeException("reading from stdin failed");
 }
 
 void TRACE(OUString const & sText)
@@ -543,7 +537,7 @@ void syncRepositories(
         return;
 
     Reference<deployment::XExtensionManager> xExtensionManager;
-    //synchronize shared before bundled otherewise there are
+    //synchronize shared before bundled otherwise there are
     //more revoke and registration calls.
     bool bModified = false;
     if (force || needToSyncRepository("shared") || needToSyncRepository("bundled"))
@@ -564,7 +558,6 @@ void syncRepositories(
         Reference<task::XRestartManager> restarter(task::OfficeRestartManager::get(comphelper::getProcessComponentContext()));
         if (restarter.is())
         {
-            OSL_TRACE( "Request restart for modified extensions manager" );
             restarter->requestRestart(xCmdEnv.is() ? xCmdEnv->getInteractionHandler() :
                                       Reference<task::XInteractionHandler>());
         }
