@@ -31,11 +31,9 @@
 #include <drawinglayer/geometry/viewinformation2d.hxx>
 
 
-
 using namespace com::sun::star;
 
 
-
 namespace
 {
     sal_uInt32 calculateStepsForSvgGradient(const basegfx::BColor& rColorA, const basegfx::BColor& rColorB, double fDelta, double fDiscreteUnit)
@@ -60,16 +58,14 @@ namespace
 } // end of anonymous namespace
 
 
-
 namespace drawinglayer
 {
     namespace primitive2d
     {
-        Primitive2DSequence SvgGradientHelper::createSingleGradientEntryFill() const
+        void SvgGradientHelper::createSingleGradientEntryFill(Primitive2DContainer& rContainer) const
         {
             const SvgGradientEntryVector& rEntries = getGradientEntries();
             const sal_uInt32 nCount(rEntries.size());
-            Primitive2DSequence xRetval;
 
             if(nCount)
             {
@@ -85,7 +81,7 @@ namespace drawinglayer
 
                     if(fOpacity < 1.0)
                     {
-                        const Primitive2DSequence aContent(&xRef, 1);
+                        const Primitive2DContainer aContent { xRef };
 
                         xRef = Primitive2DReference(
                             new UnifiedTransparencePrimitive2D(
@@ -93,15 +89,13 @@ namespace drawinglayer
                                 1.0 - fOpacity));
                     }
 
-                    xRetval = Primitive2DSequence(&xRef, 1);
+                    rContainer.push_back(xRef);
                 }
             }
             else
             {
                 OSL_ENSURE(false, "Single gradient entry construction without entry (!)");
             }
-
-            return xRetval;
         }
 
         void SvgGradientHelper::checkPreconditions()
@@ -184,8 +178,8 @@ namespace drawinglayer
         }
 
         double SvgGradientHelper::createRun(
-            Primitive2DVector& rTargetColor,
-            Primitive2DVector& rTargetOpacity,
+            Primitive2DContainer& rTargetColor,
+            Primitive2DContainer& rTargetOpacity,
             double fPos,
             double fMax,
             const SvgGradientEntryVector& rEntries,
@@ -196,7 +190,7 @@ namespace drawinglayer
             if(nCount)
             {
                 const SvgGradientEntry& rStart = rEntries[0];
-                const bool bCreateStartPad(fPos < 0.0 && Spread_pad == getSpreadMethod());
+                const bool bCreateStartPad(fPos < 0.0 && SpreadMethod::Pad == getSpreadMethod());
                 const bool bCreateStartFill(rStart.getOffset() > 0.0);
                 sal_uInt32 nIndex(0);
 
@@ -218,7 +212,7 @@ namespace drawinglayer
                 }
 
                 const SvgGradientEntry& rEnd = rEntries[nCount - 1];
-                const bool bCreateEndPad(fPos < fMax && Spread_pad == getSpreadMethod());
+                const bool bCreateEndPad(fPos < fMax && SpreadMethod::Pad == getSpreadMethod());
                 const bool bCreateEndFill(rEnd.getOffset() < 1.0);
 
                 if(bCreateEndPad || bCreateEndFill)
@@ -238,21 +232,21 @@ namespace drawinglayer
             return fPos;
         }
 
-        Primitive2DSequence SvgGradientHelper::createResult(
-            const Primitive2DVector& rTargetColor,
-            const Primitive2DVector& rTargetOpacity,
+        void SvgGradientHelper::createResult(
+            Primitive2DContainer& rContainer,
+            const Primitive2DContainer& rTargetColor,
+            const Primitive2DContainer& rTargetOpacity,
             const basegfx::B2DHomMatrix& rUnitGradientToObject,
             bool bInvert) const
         {
-            Primitive2DSequence xRetval;
-            const Primitive2DSequence aTargetColorEntries(Primitive2DVectorToPrimitive2DSequence(rTargetColor, bInvert));
-            const Primitive2DSequence aTargetOpacityEntries(Primitive2DVectorToPrimitive2DSequence(rTargetOpacity, bInvert));
+            const Primitive2DContainer aTargetColorEntries(rTargetColor.maybeInvert(bInvert));
+            const Primitive2DContainer aTargetOpacityEntries(rTargetOpacity.maybeInvert(bInvert));
 
-            if(aTargetColorEntries.hasElements())
+            if(!aTargetColorEntries.empty())
             {
                 Primitive2DReference xRefContent;
 
-                if(aTargetOpacityEntries.hasElements())
+                if(!aTargetOpacityEntries.empty())
                 {
                     const Primitive2DReference xRefOpacity = new TransparencePrimitive2D(
                         aTargetColorEntries,
@@ -260,7 +254,7 @@ namespace drawinglayer
 
                     xRefContent = new TransformPrimitive2D(
                         rUnitGradientToObject,
-                        Primitive2DSequence(&xRefOpacity, 1));
+                        Primitive2DContainer { xRefOpacity });
                 }
                 else
                 {
@@ -269,14 +263,10 @@ namespace drawinglayer
                         aTargetColorEntries);
                 }
 
-                xRefContent = new MaskPrimitive2D(
+                rContainer.push_back(new MaskPrimitive2D(
                     getPolyPolygon(),
-                    Primitive2DSequence(&xRefContent, 1));
-
-                xRetval = Primitive2DSequence(&xRefContent, 1);
+                    Primitive2DContainer { xRefContent }));
             }
-
-            return xRetval;
         }
 
         SvgGradientHelper::SvgGradientHelper(
@@ -305,7 +295,7 @@ namespace drawinglayer
 
         bool SvgGradientHelper::operator==(const SvgGradientHelper& rSvgGradientHelper) const
         {
-            const SvgGradientHelper& rCompare = static_cast< const SvgGradientHelper& >(rSvgGradientHelper);
+            const SvgGradientHelper& rCompare = rSvgGradientHelper;
 
             return (getGradientTransform() == rCompare.getGradientTransform()
                 && getPolyPolygon() == rCompare.getPolyPolygon()
@@ -319,7 +309,6 @@ namespace drawinglayer
 } // end of namespace drawinglayer
 
 
-
 namespace drawinglayer
 {
     namespace primitive2d
@@ -343,8 +332,8 @@ namespace drawinglayer
         }
 
         void SvgLinearGradientPrimitive2D::createAtom(
-            Primitive2DVector& rTargetColor,
-            Primitive2DVector& rTargetOpacity,
+            Primitive2DContainer& rTargetColor,
+            Primitive2DContainer& rTargetOpacity,
             const SvgGradientEntry& rFrom,
             const SvgGradientEntry& rTo,
             sal_Int32 nOffset) const
@@ -376,10 +365,8 @@ namespace drawinglayer
             }
         }
 
-        Primitive2DSequence SvgLinearGradientPrimitive2D::create2DDecomposition(const geometry::ViewInformation2D& /*rViewInformation*/) const
+        void SvgLinearGradientPrimitive2D::create2DDecomposition(Primitive2DContainer& rContainer, const geometry::ViewInformation2D& /*rViewInformation*/) const
         {
-            Primitive2DSequence xRetval;
-
             if(!getPreconditionsChecked())
             {
                 const_cast< SvgLinearGradientPrimitive2D* >(this)->checkPreconditions();
@@ -388,7 +375,7 @@ namespace drawinglayer
             if(getSingleEntry())
             {
                 // fill with last existing color
-                xRetval = createSingleGradientEntryFill();
+                createSingleGradientEntryFill(rContainer);
             }
             else if(getCreatesContent())
             {
@@ -400,7 +387,7 @@ namespace drawinglayer
 
                 // create ObjectTransform based on polygon range
                 const basegfx::B2DHomMatrix aObjectTransform(
-                    basegfx::tools::createScaleTranslateB2DHomMatrix(
+                    basegfx::utils::createScaleTranslateB2DHomMatrix(
                         fPolyWidth, fPolyHeight,
                         aPolyRange.getMinX(), aPolyRange.getMinY()));
                 basegfx::B2DHomMatrix aUnitGradientToObject;
@@ -454,39 +441,39 @@ namespace drawinglayer
                 const basegfx::B2DRange aUnitRange(aUnitPoly.getB2DRange());
 
                 // prepare result vectors
-                Primitive2DVector aTargetColor;
-                Primitive2DVector aTargetOpacity;
+                Primitive2DContainer aTargetColor;
+                Primitive2DContainer aTargetOpacity;
 
                 if(basegfx::fTools::more(aUnitRange.getWidth(), 0.0))
                 {
                     // add a pre-multiply to aUnitGradientToObject to allow
                     // multiplication of the polygon(xl, 0.0, xr, 1.0)
                     const basegfx::B2DHomMatrix aPreMultiply(
-                        basegfx::tools::createScaleTranslateB2DHomMatrix(
+                        basegfx::utils::createScaleTranslateB2DHomMatrix(
                             1.0, aUnitRange.getHeight(), 0.0, aUnitRange.getMinY()));
                     aUnitGradientToObject = aUnitGradientToObject * aPreMultiply;
 
                     // create central run, may also already do all necessary when
-                    // Spread_pad is set as SpreadMethod and/or the range is smaller
+                    // SpreadMethod::Pad is set as SpreadMethod and/or the range is smaller
                     double fPos(createRun(aTargetColor, aTargetOpacity, aUnitRange.getMinX(), aUnitRange.getMaxX(), getGradientEntries(), 0));
 
                     if(fPos < aUnitRange.getMaxX())
                     {
-                        // can only happen when SpreadMethod is Spread_reflect or Spread_repeat,
+                        // can only happen when SpreadMethod is SpreadMethod::Reflect or SpreadMethod::Repeat,
                         // else the start and end pads are already created and fPos == aUnitRange.getMaxX().
                         // Its possible to express the repeated linear gradient by adding the
                         // transformed central run. Create it this way
-                        Primitive2DSequence aTargetColorEntries(Primitive2DVectorToPrimitive2DSequence(aTargetColor));
-                        Primitive2DSequence aTargetOpacityEntries(Primitive2DVectorToPrimitive2DSequence(aTargetOpacity));
+                        Primitive2DContainer aTargetColorEntries(aTargetColor.maybeInvert());
+                        Primitive2DContainer aTargetOpacityEntries(aTargetOpacity.maybeInvert());
                         aTargetColor.clear();
                         aTargetOpacity.clear();
 
-                        if(aTargetColorEntries.hasElements())
+                        if(!aTargetColorEntries.empty())
                         {
                             // add original central run as group primitive
                             aTargetColor.push_back(new GroupPrimitive2D(aTargetColorEntries));
 
-                            if(aTargetOpacityEntries.hasElements())
+                            if(!aTargetOpacityEntries.empty())
                             {
                                 aTargetOpacity.push_back(new GroupPrimitive2D(aTargetOpacityEntries));
                             }
@@ -501,7 +488,7 @@ namespace drawinglayer
                                 nOffset++;
 
                                 basegfx::B2DHomMatrix aTransform;
-                                const bool bMirror(Spread_reflect == getSpreadMethod() && (nOffset % 2));
+                                const bool bMirror(SpreadMethod::Reflect == getSpreadMethod() && (nOffset % 2));
 
                                 if(bMirror)
                                 {
@@ -515,7 +502,7 @@ namespace drawinglayer
 
                                 aTargetColor.push_back(new TransformPrimitive2D(aTransform, aTargetColorEntries));
 
-                                if(aTargetOpacityEntries.hasElements())
+                                if(!aTargetOpacityEntries.empty())
                                 {
                                     aTargetOpacity.push_back(new TransformPrimitive2D(aTransform, aTargetOpacityEntries));
                                 }
@@ -528,7 +515,7 @@ namespace drawinglayer
                             while(fPos < aUnitRange.getMaxX())
                             {
                                 basegfx::B2DHomMatrix aTransform;
-                                const bool bMirror(Spread_reflect == getSpreadMethod() && (nOffset % 2));
+                                const bool bMirror(SpreadMethod::Reflect == getSpreadMethod() && (nOffset % 2));
 
                                 if(bMirror)
                                 {
@@ -542,7 +529,7 @@ namespace drawinglayer
 
                                 aTargetColor.push_back(new TransformPrimitive2D(aTransform, aTargetColorEntries));
 
-                                if(aTargetOpacityEntries.hasElements())
+                                if(!aTargetOpacityEntries.empty())
                                 {
                                     aTargetOpacity.push_back(new TransformPrimitive2D(aTransform, aTargetOpacityEntries));
                                 }
@@ -554,10 +541,8 @@ namespace drawinglayer
                     }
                 }
 
-                xRetval = createResult(aTargetColor, aTargetOpacity, aUnitGradientToObject);
+                createResult(rContainer, aTargetColor, aTargetOpacity, aUnitGradientToObject);
             }
-
-            return xRetval;
         }
 
         SvgLinearGradientPrimitive2D::SvgLinearGradientPrimitive2D(
@@ -605,7 +590,6 @@ namespace drawinglayer
 } // end of namespace drawinglayer
 
 
-
 namespace drawinglayer
 {
     namespace primitive2d
@@ -627,8 +611,8 @@ namespace drawinglayer
         }
 
         void SvgRadialGradientPrimitive2D::createAtom(
-            Primitive2DVector& rTargetColor,
-            Primitive2DVector& rTargetOpacity,
+            Primitive2DContainer& rTargetColor,
+            Primitive2DContainer& rTargetOpacity,
             const SvgGradientEntry& rFrom,
             const SvgGradientEntry& rTo,
             sal_Int32 nOffset) const
@@ -711,19 +695,16 @@ namespace drawinglayer
                 {
                     const SvgGradientEntry& rCandidate = getGradientEntries()[nCount - 1 - a];
 
-                    maMirroredGradientEntries.push_back(
-                        SvgGradientEntry(
+                    maMirroredGradientEntries.emplace_back(
                             1.0 - rCandidate.getOffset(),
                             rCandidate.getColor(),
-                            rCandidate.getOpacity()));
+                            rCandidate.getOpacity());
                 }
             }
         }
 
-        Primitive2DSequence SvgRadialGradientPrimitive2D::create2DDecomposition(const geometry::ViewInformation2D& /*rViewInformation*/) const
+        void SvgRadialGradientPrimitive2D::create2DDecomposition(Primitive2DContainer& rContainer, const geometry::ViewInformation2D& /*rViewInformation*/) const
         {
-            Primitive2DSequence xRetval;
-
             if(!getPreconditionsChecked())
             {
                 const_cast< SvgRadialGradientPrimitive2D* >(this)->checkPreconditions();
@@ -732,7 +713,7 @@ namespace drawinglayer
             if(getSingleEntry())
             {
                 // fill with last existing color
-                xRetval = createSingleGradientEntryFill();
+                createSingleGradientEntryFill(rContainer);
             }
             else if(getCreatesContent())
             {
@@ -744,7 +725,7 @@ namespace drawinglayer
 
                 // create ObjectTransform based on polygon range
                 const basegfx::B2DHomMatrix aObjectTransform(
-                    basegfx::tools::createScaleTranslateB2DHomMatrix(
+                    basegfx::utils::createScaleTranslateB2DHomMatrix(
                         fPolyWidth, fPolyHeight,
                         aPolyRange.getMinX(), aPolyRange.getMinY()));
                 basegfx::B2DHomMatrix aUnitGradientToObject;
@@ -800,8 +781,8 @@ namespace drawinglayer
                 fMax = std::max(fMax, basegfx::B2DVector(aUnitRange.getMaxX(), aUnitRange.getMinY()).getLength());
 
                 // prepare result vectors
-                Primitive2DVector aTargetColor;
-                Primitive2DVector aTargetOpacity;
+                Primitive2DContainer aTargetColor;
+                Primitive2DContainer aTargetOpacity;
 
                 if(0.0 < fMax)
                 {
@@ -812,12 +793,12 @@ namespace drawinglayer
                     }
 
                     // create central run, may also already do all necessary when
-                    // Spread_pad is set as SpreadMethod and/or the range is smaller
+                    // SpreadMethod::Pad is set as SpreadMethod and/or the range is smaller
                     double fPos(createRun(aTargetColor, aTargetOpacity, 0.0, fMax, getGradientEntries(), 0));
 
                     if(fPos < fMax)
                     {
-                        // can only happen when SpreadMethod is Spread_reflect or Spread_repeat,
+                        // can only happen when SpreadMethod is SpreadMethod::Reflect or SpreadMethod::Repeat,
                         // else the start and end pads are already created and fPos == fMax.
                         // For radial there is no way to transform the already created
                         // central run, it needs to be created from 1.0 to fMax
@@ -825,7 +806,7 @@ namespace drawinglayer
 
                         while(fPos < fMax)
                         {
-                            const bool bMirror(Spread_reflect == getSpreadMethod() && (nOffset % 2));
+                            const bool bMirror(SpreadMethod::Reflect == getSpreadMethod() && (nOffset % 2));
 
                             if(bMirror)
                             {
@@ -842,10 +823,8 @@ namespace drawinglayer
                     }
                 }
 
-                xRetval = createResult(aTargetColor, aTargetOpacity, aUnitGradientToObject, true);
+                createResult(rContainer, aTargetColor, aTargetOpacity, aUnitGradientToObject, true);
             }
-
-            return xRetval;
         }
 
         SvgRadialGradientPrimitive2D::SvgRadialGradientPrimitive2D(
@@ -924,9 +903,8 @@ namespace drawinglayer
 {
     namespace primitive2d
     {
-        Primitive2DSequence SvgLinearAtomPrimitive2D::create2DDecomposition(const geometry::ViewInformation2D& /*rViewInformation*/) const
+        void SvgLinearAtomPrimitive2D::create2DDecomposition(Primitive2DContainer& rContainer, const geometry::ViewInformation2D& /*rViewInformation*/) const
         {
-            Primitive2DSequence xRetval;
             const double fDelta(getOffsetB() - getOffsetA());
 
             if(!basegfx::fTools::equalZero(fDelta))
@@ -939,7 +917,7 @@ namespace drawinglayer
 
                 // prepare polygon in needed width at start position (with discrete overlap)
                 const basegfx::B2DPolygon aPolygon(
-                    basegfx::tools::createPolygonFromRect(
+                    basegfx::utils::createPolygonFromRect(
                         basegfx::B2DRange(
                             getOffsetA() - fDiscreteUnit,
                             0.0,
@@ -950,21 +928,16 @@ namespace drawinglayer
                 double fUnitScale(0.0);
                 const double fUnitStep(1.0 / nSteps);
 
-                // prepare result set (known size)
-                xRetval.realloc(nSteps);
-
                 for(sal_uInt32 a(0); a < nSteps; a++, fUnitScale += fUnitStep)
                 {
                     basegfx::B2DPolygon aNew(aPolygon);
 
-                    aNew.transform(basegfx::tools::createTranslateB2DHomMatrix(fDelta * fUnitScale, 0.0));
-                    xRetval[a] = new PolyPolygonColorPrimitive2D(
+                    aNew.transform(basegfx::utils::createTranslateB2DHomMatrix(fDelta * fUnitScale, 0.0));
+                    rContainer.push_back(new PolyPolygonColorPrimitive2D(
                         basegfx::B2DPolyPolygon(aNew),
-                        basegfx::interpolate(getColorA(), getColorB(), fUnitScale));
+                        basegfx::interpolate(getColorA(), getColorB(), fUnitScale)));
                 }
             }
-
-            return xRetval;
         }
 
         SvgLinearAtomPrimitive2D::SvgLinearAtomPrimitive2D(
@@ -979,7 +952,7 @@ namespace drawinglayer
             if(mfOffsetA > mfOffsetB)
             {
                 OSL_ENSURE(false, "Wrong offset order (!)");
-                ::std::swap(mfOffsetA, mfOffsetB);
+                std::swap(mfOffsetA, mfOffsetB);
             }
         }
 
@@ -1011,9 +984,8 @@ namespace drawinglayer
 {
     namespace primitive2d
     {
-        Primitive2DSequence SvgRadialAtomPrimitive2D::create2DDecomposition(const geometry::ViewInformation2D& /*rViewInformation*/) const
+        void SvgRadialAtomPrimitive2D::create2DDecomposition(Primitive2DContainer& rContainer, const geometry::ViewInformation2D& /*rViewInformation*/) const
         {
-            Primitive2DSequence xRetval;
             const double fDeltaScale(getScaleB() - getScaleA());
 
             if(!basegfx::fTools::equalZero(fDeltaScale))
@@ -1028,9 +1000,6 @@ namespace drawinglayer
                 double fUnitScale(0.0);
                 const double fUnitStep(1.0 / nSteps);
 
-                // prepare result set (known size)
-                xRetval.realloc(nSteps);
-
                 for(sal_uInt32 a(0); a < nSteps; a++, fUnitScale += fUnitStep)
                 {
                     basegfx::B2DHomMatrix aTransform;
@@ -1044,7 +1013,7 @@ namespace drawinglayer
                                 getTranslateA(),
                                 fUnitScale));
 
-                        aTransform = basegfx::tools::createScaleTranslateB2DHomMatrix(
+                        aTransform = basegfx::utils::createScaleTranslateB2DHomMatrix(
                             fEndScale,
                             fEndScale,
                             aTranslate.getX(),
@@ -1052,21 +1021,19 @@ namespace drawinglayer
                     }
                     else
                     {
-                        aTransform = basegfx::tools::createScaleB2DHomMatrix(
+                        aTransform = basegfx::utils::createScaleB2DHomMatrix(
                             fEndScale,
                             fEndScale);
                     }
 
-                    basegfx::B2DPolygon aNew(basegfx::tools::createPolygonFromUnitCircle());
+                    basegfx::B2DPolygon aNew(basegfx::utils::createPolygonFromUnitCircle());
 
                     aNew.transform(aTransform);
-                    xRetval[a] = new PolyPolygonColorPrimitive2D(
+                    rContainer.push_back(new PolyPolygonColorPrimitive2D(
                         basegfx::B2DPolyPolygon(aNew),
-                        basegfx::interpolate(getColorB(), getColorA(), fUnitScale));
+                        basegfx::interpolate(getColorB(), getColorA(), fUnitScale)));
                 }
             }
-
-            return xRetval;
         }
 
         SvgRadialAtomPrimitive2D::SvgRadialAtomPrimitive2D(
@@ -1086,18 +1053,18 @@ namespace drawinglayer
             }
 
             // scale A and B have to be positive
-            mfScaleA = ::std::max(mfScaleA, 0.0);
-            mfScaleB = ::std::max(mfScaleB, 0.0);
+            mfScaleA = std::max(mfScaleA, 0.0);
+            mfScaleB = std::max(mfScaleB, 0.0);
 
             // scale B has to be bigger than scale A; swap if different
             if(mfScaleA > mfScaleB)
             {
                 OSL_ENSURE(false, "Wrong offset order (!)");
-                ::std::swap(mfScaleA, mfScaleB);
+                std::swap(mfScaleA, mfScaleB);
 
                 if(mpTranslate)
                 {
-                    ::std::swap(mpTranslate->maTranslateA, mpTranslate->maTranslateB);
+                    std::swap(mpTranslate->maTranslateA, mpTranslate->maTranslateB);
                 }
             }
         }
@@ -1113,14 +1080,14 @@ namespace drawinglayer
             mpTranslate(nullptr)
         {
             // scale A and B have to be positive
-            mfScaleA = ::std::max(mfScaleA, 0.0);
-            mfScaleB = ::std::max(mfScaleB, 0.0);
+            mfScaleA = std::max(mfScaleA, 0.0);
+            mfScaleB = std::max(mfScaleB, 0.0);
 
             // scale B has to be bigger than scale A; swap if different
             if(mfScaleA > mfScaleB)
             {
                 OSL_ENSURE(false, "Wrong offset order (!)");
-                ::std::swap(mfScaleA, mfScaleB);
+                std::swap(mfScaleA, mfScaleB);
             }
         }
 
