@@ -7,7 +7,7 @@
  * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  */
 
-#include "editeng/editdata.hxx"
+#include <editeng/editdata.hxx>
 
 #include <limits>
 
