@@ -49,11 +49,11 @@
 #include <editeng/charreliefitem.hxx>
 #include <editeng/frmdiritem.hxx>
 
-#include <impedit.hxx>
+#include "impedit.hxx"
 #include <editeng/editeng.hxx>
 #include <editeng/editview.hxx>
 #include <editdoc.hxx>
-#include <editdbg.hxx>
+#include "editdbg.hxx"
 
 #include <rtl/strbuf.hxx>
 
@@ -418,7 +418,7 @@ void EditDbg::ShowEditEngineData( EditEngine* pEE, bool bInfoBox )
         for ( sal_Int32 nLine = 0; nLine < pPPortion->GetLines().Count(); nLine++ )
         {
             EditLine& rLine = pPPortion->GetLines()[nLine];
-            fprintf( fp, "\nZeile %" SAL_PRIdINT32 ":\tStart: %" SAL_PRIdINT32 ",\tEnd: %" SAL_PRIdINT32, nLine, rLine.GetStart(), rLine.GetEnd() );
+            fprintf( fp, "\nLine %" SAL_PRIdINT32 ":\tStart: %" SAL_PRIdINT32 ",\tEnd: %" SAL_PRIdINT32, nLine, rLine.GetStart(), rLine.GetEnd() );
             fprintf( fp, "\t\tPortions: %" SAL_PRIdINT32 " - %" SAL_PRIdINT32 ".\tHight: %i, Ascent=%i", rLine.GetStartPortion(), rLine.GetEndPortion(), rLine.GetHeight(), rLine.GetMaxAscent() );
         }
 
@@ -498,12 +498,12 @@ bool ParaPortion::DbgCheckTextPortions(ParaPortion const& rPara)
     return nXLen == rPara.pNode->Len();
 }
 
-void CheckOrderedList(const CharAttribList::AttribsType& rAttribs, bool bStart)
+void CheckOrderedList(const CharAttribList::AttribsType& rAttribs)
 {
     sal_Int32 nPrev = 0;
     for (const std::unique_ptr<EditCharAttrib>& rAttr : rAttribs)
     {
-        sal_Int32 const nCur = bStart ? rAttr->GetStart() : rAttr->GetEnd();
+        sal_Int32 const nCur = rAttr->GetStart();
         assert(nCur >= nPrev);
         nPrev = nCur;
     }
