@@ -17,10 +17,10 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "editeng/justifyitem.hxx"
-#include "editeng/memberids.hrc"
-#include "editeng/editrids.hrc"
-#include "editeng/eerdll.hxx"
+#include <editeng/justifyitem.hxx>
+#include <editeng/memberids.h>
+#include <editeng/editrids.hrc>
+#include <editeng/eerdll.hxx>
 
 #include <tools/stream.hxx>
 
@@ -31,22 +31,20 @@
 #include <com/sun/star/style/VerticalAlignment.hpp>
 
 
-
-SfxPoolItem* SvxHorJustifyItem::CreateDefault() { return new  SvxHorJustifyItem(SVX_HOR_JUSTIFY_STANDARD, 0) ;}
-SfxPoolItem* SvxVerJustifyItem::CreateDefault() { return new  SvxVerJustifyItem(SVX_VER_JUSTIFY_STANDARD, 0) ;}
+SfxPoolItem* SvxHorJustifyItem::CreateDefault() { return new  SvxHorJustifyItem(SvxCellHorJustify::Standard, 0) ;}
+SfxPoolItem* SvxVerJustifyItem::CreateDefault() { return new  SvxVerJustifyItem(SvxCellVerJustify::Standard, 0) ;}
 
 using namespace ::com::sun::star;
 
 
-
 SvxHorJustifyItem::SvxHorJustifyItem( const sal_uInt16 nId ) :
-    SfxEnumItem( nId, (sal_uInt16)SVX_HOR_JUSTIFY_STANDARD )
+    SfxEnumItem( nId, SvxCellHorJustify::Standard )
 {
 }
 
 SvxHorJustifyItem::SvxHorJustifyItem( const SvxCellHorJustify eJustify,
                                       const sal_uInt16 nId ) :
-    SfxEnumItem( nId, (sal_uInt16)eJustify )
+    SfxEnumItem( nId, eJustify )
 {
 }
 
@@ -54,11 +52,11 @@ SvxHorJustifyItem::SvxHorJustifyItem( const SvxCellHorJustify eJustify,
 bool SvxHorJustifyItem::GetPresentation
 (
     SfxItemPresentation /*ePres*/,
-    SfxMapUnit          /*eCoreUnit*/,
-    SfxMapUnit          /*ePresUnit*/,
-    OUString&           rText, const IntlWrapper *)    const
+    MapUnit             /*eCoreUnit*/,
+    MapUnit             /*ePresUnit*/,
+    OUString&           rText, const IntlWrapper&)    const
 {
-    rText = GetValueText( GetValue() );
+    rText = GetValueText( (sal_uInt16)GetValue() );
     return true;
 }
 
@@ -71,14 +69,14 @@ bool SvxHorJustifyItem::QueryValue( uno::Any& rVal, sal_uInt8 nMemberId ) const
         case MID_HORJUST_HORJUST:
             {
                 table::CellHoriJustify eUno = table::CellHoriJustify_STANDARD;
-                switch ( (SvxCellHorJustify)GetValue() )
+                switch ( GetValue() )
                 {
-                    case SVX_HOR_JUSTIFY_STANDARD: eUno = table::CellHoriJustify_STANDARD; break;
-                    case SVX_HOR_JUSTIFY_LEFT:     eUno = table::CellHoriJustify_LEFT;     break;
-                    case SVX_HOR_JUSTIFY_CENTER:   eUno = table::CellHoriJustify_CENTER;   break;
-                    case SVX_HOR_JUSTIFY_RIGHT:    eUno = table::CellHoriJustify_RIGHT;    break;
-                    case SVX_HOR_JUSTIFY_BLOCK:    eUno = table::CellHoriJustify_BLOCK;    break;
-                    case SVX_HOR_JUSTIFY_REPEAT:   eUno = table::CellHoriJustify_REPEAT;   break;
+                    case SvxCellHorJustify::Standard: eUno = table::CellHoriJustify_STANDARD; break;
+                    case SvxCellHorJustify::Left:     eUno = table::CellHoriJustify_LEFT;     break;
+                    case SvxCellHorJustify::Center:   eUno = table::CellHoriJustify_CENTER;   break;
+                    case SvxCellHorJustify::Right:    eUno = table::CellHoriJustify_RIGHT;    break;
+                    case SvxCellHorJustify::Block:    eUno = table::CellHoriJustify_BLOCK;    break;
+                    case SvxCellHorJustify::Repeat:   eUno = table::CellHoriJustify_REPEAT;   break;
                 }
                 rVal <<= eUno;
             }
@@ -88,18 +86,18 @@ bool SvxHorJustifyItem::QueryValue( uno::Any& rVal, sal_uInt8 nMemberId ) const
                 //  ParagraphAdjust values, as in SvxAdjustItem
                 //  (same value for ParaAdjust and ParaLastLineAdjust)
 
-                sal_Int16 nAdjust = style::ParagraphAdjust_LEFT;
-                switch ( (SvxCellHorJustify)GetValue() )
+                style::ParagraphAdjust nAdjust = style::ParagraphAdjust_LEFT;
+                switch ( GetValue() )
                 {
                     // ParagraphAdjust_LEFT is used for STANDARD and REPEAT
-                    case SVX_HOR_JUSTIFY_STANDARD:
-                    case SVX_HOR_JUSTIFY_REPEAT:
-                    case SVX_HOR_JUSTIFY_LEFT:   nAdjust = style::ParagraphAdjust_LEFT;   break;
-                    case SVX_HOR_JUSTIFY_CENTER: nAdjust = style::ParagraphAdjust_CENTER; break;
-                    case SVX_HOR_JUSTIFY_RIGHT:  nAdjust = style::ParagraphAdjust_RIGHT;  break;
-                    case SVX_HOR_JUSTIFY_BLOCK:  nAdjust = style::ParagraphAdjust_BLOCK;  break;
+                    case SvxCellHorJustify::Standard:
+                    case SvxCellHorJustify::Repeat:
+                    case SvxCellHorJustify::Left:   nAdjust = style::ParagraphAdjust_LEFT;   break;
+                    case SvxCellHorJustify::Center: nAdjust = style::ParagraphAdjust_CENTER; break;
+                    case SvxCellHorJustify::Right:  nAdjust = style::ParagraphAdjust_RIGHT;  break;
+                    case SvxCellHorJustify::Block:  nAdjust = style::ParagraphAdjust_BLOCK;  break;
                 }
-                rVal <<= nAdjust;       // as sal_Int16
+                rVal <<= (sal_Int16)nAdjust;       // as sal_Int16
             }
             break;
     }
@@ -121,18 +119,18 @@ bool SvxHorJustifyItem::PutValue( const uno::Any& rVal, sal_uInt8 nMemberId )
                         return false;
                     eUno = (table::CellHoriJustify)nValue;
                 }
-                SvxCellHorJustify eSvx = SVX_HOR_JUSTIFY_STANDARD;
+                SvxCellHorJustify eSvx = SvxCellHorJustify::Standard;
                 switch (eUno)
                 {
-                    case table::CellHoriJustify_STANDARD: eSvx = SVX_HOR_JUSTIFY_STANDARD; break;
-                    case table::CellHoriJustify_LEFT:     eSvx = SVX_HOR_JUSTIFY_LEFT;     break;
-                    case table::CellHoriJustify_CENTER:   eSvx = SVX_HOR_JUSTIFY_CENTER;   break;
-                    case table::CellHoriJustify_RIGHT:    eSvx = SVX_HOR_JUSTIFY_RIGHT;    break;
-                    case table::CellHoriJustify_BLOCK:    eSvx = SVX_HOR_JUSTIFY_BLOCK;    break;
-                    case table::CellHoriJustify_REPEAT:   eSvx = SVX_HOR_JUSTIFY_REPEAT;   break;
+                    case table::CellHoriJustify_STANDARD: eSvx = SvxCellHorJustify::Standard; break;
+                    case table::CellHoriJustify_LEFT:     eSvx = SvxCellHorJustify::Left;     break;
+                    case table::CellHoriJustify_CENTER:   eSvx = SvxCellHorJustify::Center;   break;
+                    case table::CellHoriJustify_RIGHT:    eSvx = SvxCellHorJustify::Right;    break;
+                    case table::CellHoriJustify_BLOCK:    eSvx = SvxCellHorJustify::Block;    break;
+                    case table::CellHoriJustify_REPEAT:   eSvx = SvxCellHorJustify::Repeat;   break;
                     default: ; //prevent warning
                 }
-                SetValue( (sal_uInt16)eSvx );
+                SetValue( eSvx );
             }
             break;
         case MID_HORJUST_ADJUST:
@@ -142,17 +140,18 @@ bool SvxHorJustifyItem::PutValue( const uno::Any& rVal, sal_uInt8 nMemberId )
                 if(!(rVal >>= nVal))
                     return false;
 
-                SvxCellHorJustify eSvx = SVX_HOR_JUSTIFY_STANDARD;
-                switch (nVal)
+                SvxCellHorJustify eSvx = SvxCellHorJustify::Standard;
+                switch ((style::ParagraphAdjust)nVal)
                 {
                     //  STRETCH is treated as BLOCK
-                    case style::ParagraphAdjust_LEFT:    eSvx = SVX_HOR_JUSTIFY_LEFT;   break;
-                    case style::ParagraphAdjust_RIGHT:   eSvx = SVX_HOR_JUSTIFY_RIGHT;  break;
+                    case style::ParagraphAdjust_LEFT:    eSvx = SvxCellHorJustify::Left;   break;
+                    case style::ParagraphAdjust_RIGHT:   eSvx = SvxCellHorJustify::Right;  break;
                     case style::ParagraphAdjust_STRETCH:
-                    case style::ParagraphAdjust_BLOCK:   eSvx = SVX_HOR_JUSTIFY_BLOCK;  break;
-                    case style::ParagraphAdjust_CENTER:  eSvx = SVX_HOR_JUSTIFY_CENTER; break;
+                    case style::ParagraphAdjust_BLOCK:   eSvx = SvxCellHorJustify::Block;  break;
+                    case style::ParagraphAdjust_CENTER:  eSvx = SvxCellHorJustify::Center; break;
+                    default: break;
                 }
-                SetValue( (sal_uInt16)eSvx );
+                SetValue( eSvx );
             }
     }
     return true;
@@ -161,8 +160,8 @@ bool SvxHorJustifyItem::PutValue( const uno::Any& rVal, sal_uInt8 nMemberId )
 
 OUString SvxHorJustifyItem::GetValueText( sal_uInt16 nVal )
 {
-    DBG_ASSERT( nVal <= SVX_HOR_JUSTIFY_REPEAT, "enum overflow!" );
-    return EE_RESSTR(RID_SVXITEMS_HORJUST_STANDARD + nVal);
+    DBG_ASSERT( nVal <= (sal_uInt16)SvxCellHorJustify::Repeat, "enum overflow!" );
+    return EditResId(RID_SVXITEMS_HORJUST_STANDARD + nVal);
 }
 
 
@@ -182,18 +181,18 @@ SfxPoolItem* SvxHorJustifyItem::Create( SvStream& rStream, sal_uInt16 ) const
 
 sal_uInt16 SvxHorJustifyItem::GetValueCount() const
 {
-    return SVX_HOR_JUSTIFY_REPEAT + 1;  // Last Enum value + 1
+    return (sal_uInt16)SvxCellHorJustify::Repeat + 1;  // Last Enum value + 1
 }
 
 
 SvxVerJustifyItem::SvxVerJustifyItem( const sal_uInt16 nId ) :
-    SfxEnumItem( nId, (sal_uInt16)SVX_VER_JUSTIFY_STANDARD )
+    SfxEnumItem( nId, SvxCellVerJustify::Standard )
 {
 }
 
 SvxVerJustifyItem::SvxVerJustifyItem( const SvxCellVerJustify eJustify,
                                       const sal_uInt16 nId ) :
-    SfxEnumItem( nId, (sal_uInt16)eJustify )
+    SfxEnumItem( nId, eJustify )
 {
 }
 
@@ -201,10 +200,10 @@ SvxVerJustifyItem::SvxVerJustifyItem( const SvxCellVerJustify eJustify,
 bool SvxVerJustifyItem::GetPresentation
 (
     SfxItemPresentation /*ePres*/,
-    SfxMapUnit          /*eCoreUnit*/,
-    SfxMapUnit          /*ePresUnit*/,
+    MapUnit             /*eCoreUnit*/,
+    MapUnit             /*ePresUnit*/,
     OUString&           rText,
-    const IntlWrapper * )    const
+    const IntlWrapper& )    const
 {
     rText = GetValueText( GetValue() );
     return true;
@@ -219,11 +218,11 @@ bool SvxVerJustifyItem::QueryValue( uno::Any& rVal, sal_uInt8 nMemberId ) const
         case MID_HORJUST_ADJUST:
             {
                 style::VerticalAlignment eUno = style::VerticalAlignment_TOP;
-                switch ( (SvxCellVerJustify)GetValue() )
+                switch ( GetValue() )
                 {
-                    case SVX_VER_JUSTIFY_TOP:      eUno = style::VerticalAlignment_TOP;     break;
-                    case SVX_VER_JUSTIFY_CENTER:   eUno = style::VerticalAlignment_MIDDLE;  break;
-                    case SVX_VER_JUSTIFY_BOTTOM:   eUno = style::VerticalAlignment_BOTTOM;  break;
+                    case SvxCellVerJustify::Top:      eUno = style::VerticalAlignment_TOP;     break;
+                    case SvxCellVerJustify::Center:   eUno = style::VerticalAlignment_MIDDLE;  break;
+                    case SvxCellVerJustify::Bottom:   eUno = style::VerticalAlignment_BOTTOM;  break;
                     default: ; //prevent warning
                 }
                 rVal <<= eUno;
@@ -232,13 +231,13 @@ bool SvxVerJustifyItem::QueryValue( uno::Any& rVal, sal_uInt8 nMemberId ) const
         default:
             {
                 sal_Int32 nUno = table::CellVertJustify2::STANDARD;
-                switch ( (SvxCellVerJustify)GetValue() )
+                switch ( GetValue() )
                 {
-                    case SVX_VER_JUSTIFY_STANDARD: nUno = table::CellVertJustify2::STANDARD; break;
-                    case SVX_VER_JUSTIFY_TOP:      nUno = table::CellVertJustify2::TOP;     break;
-                    case SVX_VER_JUSTIFY_CENTER:   nUno = table::CellVertJustify2::CENTER;  break;
-                    case SVX_VER_JUSTIFY_BOTTOM:   nUno = table::CellVertJustify2::BOTTOM;  break;
-                    case SVX_VER_JUSTIFY_BLOCK:    nUno = table::CellVertJustify2::BLOCK;  break;
+                    case SvxCellVerJustify::Standard: nUno = table::CellVertJustify2::STANDARD; break;
+                    case SvxCellVerJustify::Top:      nUno = table::CellVertJustify2::TOP;     break;
+                    case SvxCellVerJustify::Center:   nUno = table::CellVertJustify2::CENTER;  break;
+                    case SvxCellVerJustify::Bottom:   nUno = table::CellVertJustify2::BOTTOM;  break;
+                    case SvxCellVerJustify::Block:    nUno = table::CellVertJustify2::BLOCK;  break;
                     default: ; //prevent warning
                 }
                 rVal <<= nUno;
@@ -260,15 +259,15 @@ bool SvxVerJustifyItem::PutValue( const uno::Any& rVal, sal_uInt8 nMemberId )
                 if(!(rVal >>= nVal))
                     return false;
 
-                SvxCellVerJustify eSvx = SVX_VER_JUSTIFY_STANDARD;
+                SvxCellVerJustify eSvx = SvxCellVerJustify::Standard;
                 switch (nVal)
                 {
-                    case style::VerticalAlignment_TOP:      eSvx = SVX_VER_JUSTIFY_TOP;     break;
-                    case style::VerticalAlignment_MIDDLE:   eSvx = SVX_VER_JUSTIFY_CENTER;  break;
-                    case style::VerticalAlignment_BOTTOM:   eSvx = SVX_VER_JUSTIFY_BOTTOM;  break;
+                    case style::VerticalAlignment_TOP:      eSvx = SvxCellVerJustify::Top;     break;
+                    case style::VerticalAlignment_MIDDLE:   eSvx = SvxCellVerJustify::Center;  break;
+                    case style::VerticalAlignment_BOTTOM:   eSvx = SvxCellVerJustify::Bottom;  break;
                     default:;
                 }
-                SetValue( (sal_uInt16)eSvx );
+                SetValue( eSvx );
                 break;
             }
         default:
@@ -276,17 +275,17 @@ bool SvxVerJustifyItem::PutValue( const uno::Any& rVal, sal_uInt8 nMemberId )
                 sal_Int32 eUno = table::CellVertJustify2::STANDARD;
                 rVal >>= eUno;
 
-                SvxCellVerJustify eSvx = SVX_VER_JUSTIFY_STANDARD;
+                SvxCellVerJustify eSvx = SvxCellVerJustify::Standard;
                 switch (eUno)
                 {
-                    case table::CellVertJustify2::STANDARD: eSvx = SVX_VER_JUSTIFY_STANDARD;  break;
-                    case table::CellVertJustify2::TOP:      eSvx = SVX_VER_JUSTIFY_TOP;       break;
-                    case table::CellVertJustify2::CENTER:   eSvx = SVX_VER_JUSTIFY_CENTER;    break;
-                    case table::CellVertJustify2::BOTTOM:   eSvx = SVX_VER_JUSTIFY_BOTTOM;    break;
-                    case table::CellVertJustify2::BLOCK:    eSvx = SVX_VER_JUSTIFY_BLOCK;     break;
+                    case table::CellVertJustify2::STANDARD: eSvx = SvxCellVerJustify::Standard;  break;
+                    case table::CellVertJustify2::TOP:      eSvx = SvxCellVerJustify::Top;       break;
+                    case table::CellVertJustify2::CENTER:   eSvx = SvxCellVerJustify::Center;    break;
+                    case table::CellVertJustify2::BOTTOM:   eSvx = SvxCellVerJustify::Bottom;    break;
+                    case table::CellVertJustify2::BLOCK:    eSvx = SvxCellVerJustify::Block;     break;
                     default: ; //prevent warning
                 }
-                SetValue( (sal_uInt16)eSvx );
+                SetValue( eSvx );
                 break;
             }
     }
@@ -295,10 +294,10 @@ bool SvxVerJustifyItem::PutValue( const uno::Any& rVal, sal_uInt8 nMemberId )
 }
 
 
-OUString SvxVerJustifyItem::GetValueText( sal_uInt16 nVal )
+OUString SvxVerJustifyItem::GetValueText( SvxCellVerJustify nVal )
 {
-    DBG_ASSERT( nVal <= SVX_VER_JUSTIFY_BOTTOM, "enum overflow!" );
-    return EE_RESSTR(RID_SVXITEMS_VERJUST_STANDARD + nVal);
+    DBG_ASSERT( nVal <= SvxCellVerJustify::Bottom, "enum overflow!" );
+    return EditResId(RID_SVXITEMS_VERJUST_STANDARD + static_cast<int>(nVal));
 }
 
 
@@ -318,13 +317,13 @@ SfxPoolItem* SvxVerJustifyItem::Create( SvStream& rStream, sal_uInt16 ) const
 
 sal_uInt16 SvxVerJustifyItem::GetValueCount() const
 {
-    return SVX_VER_JUSTIFY_BOTTOM + 1;  // Last Enum value + 1
+    return static_cast<sal_uInt16>(SvxCellVerJustify::Bottom) + 1;  // Last Enum value + 1
 }
 
 
 SvxJustifyMethodItem::SvxJustifyMethodItem( const SvxCellJustifyMethod eJustify,
                                       const sal_uInt16 nId ) :
-    SfxEnumItem( nId, (sal_uInt16)eJustify )
+    SfxEnumItem( nId, eJustify )
 {
 }
 
@@ -332,10 +331,10 @@ SvxJustifyMethodItem::SvxJustifyMethodItem( const SvxCellJustifyMethod eJustify,
 bool SvxJustifyMethodItem::GetPresentation
 (
     SfxItemPresentation /*ePres*/,
-    SfxMapUnit          /*eCoreUnit*/,
-    SfxMapUnit          /*ePresUnit*/,
+    MapUnit             /*eCoreUnit*/,
+    MapUnit             /*ePresUnit*/,
     OUString&           rText,
-    const IntlWrapper * )    const
+    const IntlWrapper& )    const
 {
     rText = GetValueText( GetValue() );
     return true;
@@ -345,10 +344,10 @@ bool SvxJustifyMethodItem::GetPresentation
 bool SvxJustifyMethodItem::QueryValue( uno::Any& rVal, sal_uInt8 /*nMemberId*/ ) const
 {
     sal_Int32 nUno = table::CellJustifyMethod::AUTO;
-    switch (static_cast<SvxCellJustifyMethod>(GetValue()))
+    switch (GetValue())
     {
-        case SVX_JUSTIFY_METHOD_AUTO:       nUno = table::CellJustifyMethod::AUTO;       break;
-        case SVX_JUSTIFY_METHOD_DISTRIBUTE: nUno = table::CellJustifyMethod::DISTRIBUTE; break;
+        case SvxCellJustifyMethod::Auto:       nUno = table::CellJustifyMethod::AUTO;       break;
+        case SvxCellJustifyMethod::Distribute: nUno = table::CellJustifyMethod::DISTRIBUTE; break;
         default:;
     }
     rVal <<= nUno;
@@ -361,26 +360,25 @@ bool SvxJustifyMethodItem::PutValue( const uno::Any& rVal, sal_uInt8 /*nMemberId
     if (!(rVal >>= nVal))
         return false;
 
-    SvxCellJustifyMethod eSvx = SVX_JUSTIFY_METHOD_AUTO;
+    SvxCellJustifyMethod eSvx = SvxCellJustifyMethod::Auto;
     switch (nVal)
     {
         case table::CellJustifyMethod::AUTO:
-            eSvx = SVX_JUSTIFY_METHOD_AUTO;
+            eSvx = SvxCellJustifyMethod::Auto;
         break;
         case table::CellJustifyMethod::DISTRIBUTE:
-            eSvx = SVX_JUSTIFY_METHOD_DISTRIBUTE;
+            eSvx = SvxCellJustifyMethod::Distribute;
         break;
         default:;
     }
-    SetValue(static_cast<sal_uInt16>(eSvx));
+    SetValue(eSvx);
     return true;
 }
 
 
-OUString SvxJustifyMethodItem::GetValueText( sal_uInt16 nVal )
+OUString SvxJustifyMethodItem::GetValueText( SvxCellJustifyMethod nVal )
 {
-    DBG_ASSERT( nVal <= SVX_VER_JUSTIFY_BOTTOM, "enum overflow!" );
-    return EE_RESSTR(RID_SVXITEMS_JUSTMETHOD_AUTO + nVal);
+    return EditResId(RID_SVXITEMS_JUSTMETHOD_AUTO + static_cast<int>(nVal));
 }
 
 
@@ -390,17 +388,9 @@ SfxPoolItem* SvxJustifyMethodItem::Clone( SfxItemPool* ) const
 }
 
 
-SfxPoolItem* SvxJustifyMethodItem::Create( SvStream& rStream, sal_uInt16 ) const
-{
-    sal_uInt16 nVal;
-    rStream.ReadUInt16( nVal );
-    return new SvxJustifyMethodItem( (SvxCellJustifyMethod)nVal, Which() );
-}
-
-
 sal_uInt16 SvxJustifyMethodItem::GetValueCount() const
 {
-    return SVX_JUSTIFY_METHOD_DISTRIBUTE + 1;   // Last Enum value + 1
+    return static_cast<sal_uInt16>(SvxCellJustifyMethod::Distribute) + 1;   // Last Enum value + 1
 }
 
 SvxJustifyMethodItem& SvxJustifyMethodItem::operator=(const SvxJustifyMethodItem& r)
