@@ -23,7 +23,6 @@
 #include <editeng/postitem.hxx>
 #include <editeng/wghtitem.hxx>
 #include <editeng/fhgtitem.hxx>
-#include <editeng/fwdtitem.hxx>
 #include <editeng/udlnitem.hxx>
 #include <editeng/crossedoutitem.hxx>
 #include <editeng/shdditem.hxx>
@@ -39,7 +38,6 @@
 #include <editeng/langitem.hxx>
 #include <editeng/nlbkitem.hxx>
 #include <editeng/nhypitem.hxx>
-#include <editeng/lcolitem.hxx>
 #include <editeng/blinkitem.hxx>
 #include <editeng/emphasismarkitem.hxx>
 #include <editeng/twolinesitem.hxx>
@@ -87,18 +85,6 @@
 using namespace ::com::sun::star;
 using namespace editeng;
 
-// Some helper functions
-// char
-inline const SvxEscapementItem& GetEscapement(const SfxItemSet& rSet,sal_uInt16 nId,bool bInP=true)
-    { return static_cast<const SvxEscapementItem&>(rSet.Get( nId,bInP)); }
-inline const SvxLineSpacingItem& GetLineSpacing(const SfxItemSet& rSet,sal_uInt16 nId,bool bInP=true)
-    { return static_cast<const SvxLineSpacingItem&>(rSet.Get( nId,bInP)); }
-// frm
-inline const SvxLRSpaceItem& GetLRSpace(const SfxItemSet& rSet,sal_uInt16 nId,bool bInP=true)
-    { return static_cast<const SvxLRSpaceItem&>(rSet.Get( nId,bInP)); }
-inline const SvxULSpaceItem& GetULSpace(const SfxItemSet& rSet,sal_uInt16 nId,bool bInP=true)
-    { return static_cast<const SvxULSpaceItem&>(rSet.Get( nId,bInP)); }
-
 void SvxRTFParser::SetScriptAttr( RTF_CharTypeDef eType, SfxItemSet& rSet,
                                     SfxPoolItem& rItem )
 {
@@ -200,18 +186,16 @@ void SvxRTFParser::SetScriptAttr( RTF_CharTypeDef eType, SfxItemSet& rSet,
 }
 
 
-
 void SvxRTFParser::ReadAttr( int nToken, SfxItemSet* pSet )
 {
     DBG_ASSERT( pSet, "A SfxItemSet has to be provided as argument!" );
     bool bFirstToken = true;
     bool bContinue = true;
-    FontUnderline eUnderline;
-    FontUnderline eOverline;
+    FontLineStyle eUnderline;
+    FontLineStyle eOverline;
     FontEmphasisMark eEmphasis;
-    bPardTokenRead = false;
     RTF_CharTypeDef eCharType = NOTDEF_CHARTYPE;
-    sal_uInt16 nFontAlign;
+    SvxParaVertAlignItem::Align nFontAlign;
 
     bool bChkStkPos = !bNewGroup && !aAttrStack.empty();
 
@@ -221,7 +205,6 @@ void SvxRTFParser::ReadAttr( int nToken, SfxItemSet* pSet )
         {
         case RTF_PARD:
             RTFPardPlain( true, &pSet );
-            bPardTokenRead = true;
             break;
 
         case RTF_PLAIN:
@@ -286,15 +269,12 @@ void SvxRTFParser::ReadAttr( int nToken, SfxItemSet* pSet )
                 else
                 {
                     sal_uInt16 nStyleNo = -1 == nTokenValue ? 0 : sal_uInt16(nTokenValue);
-                    /* setze am akt. auf dem AttrStack stehenden Style die
-                       I sit on akt. which is on the immediate style AttrStack */
-                    // StyleNummer
+                    // set StyleNo to the current style on the AttrStack
                     SvxRTFItemStackType* pAkt = aAttrStack.empty() ? nullptr : aAttrStack.back();
                     if( !pAkt )
                         break;
 
-                    pAkt->nStyleNo = sal_uInt16( nStyleNo );
-
+                    pAkt->nStyleNo = nStyleNo;
                 }
                 break;
 
@@ -315,7 +295,7 @@ void SvxRTFParser::ReadAttr( int nToken, SfxItemSet* pSet )
             case RTF_LEVEL:
                 if( aPardMap.nOutlineLvl )
                 {
-                    pSet->Put( SfxUInt16Item( aPardMap.nOutlineLvl,
+                    pSet->Put( SfxInt16Item( aPardMap.nOutlineLvl,
                                                 (sal_uInt16)nTokenValue ));
                 }
                 break;
@@ -323,32 +303,33 @@ void SvxRTFParser::ReadAttr( int nToken, SfxItemSet* pSet )
             case RTF_QL:
                 if( aPardMap.nAdjust )
                 {
-                    pSet->Put( SvxAdjustItem( SVX_ADJUST_LEFT, aPardMap.nAdjust ));
+                    pSet->Put( SvxAdjustItem( SvxAdjust::Left, aPardMap.nAdjust ));
                 }
                 break;
             case RTF_QR:
                 if( aPardMap.nAdjust )
                 {
-                    pSet->Put( SvxAdjustItem( SVX_ADJUST_RIGHT, aPardMap.nAdjust ));
+                    pSet->Put( SvxAdjustItem( SvxAdjust::Right, aPardMap.nAdjust ));
                 }
                 break;
             case RTF_QJ:
                 if( aPardMap.nAdjust )
                 {
-                    pSet->Put( SvxAdjustItem( SVX_ADJUST_BLOCK, aPardMap.nAdjust ));
+                    pSet->Put( SvxAdjustItem( SvxAdjust::Block, aPardMap.nAdjust ));
                 }
                 break;
             case RTF_QC:
                 if( aPardMap.nAdjust )
                 {
-                    pSet->Put( SvxAdjustItem( SVX_ADJUST_CENTER, aPardMap.nAdjust ));
+                    pSet->Put( SvxAdjustItem( SvxAdjust::Center, aPardMap.nAdjust ));
                 }
                 break;
 
             case RTF_FI:
                 if( aPardMap.nLRSpace )
                 {
-                    SvxLRSpaceItem aLR( GetLRSpace(*pSet, aPardMap.nLRSpace ));
+                    SvxLRSpaceItem aLR(
+                        static_cast<const SvxLRSpaceItem&>(pSet->Get(aPardMap.nLRSpace)));
                     sal_uInt16 nSz = 0;
                     if( -1 != nTokenValue )
                     {
@@ -365,7 +346,8 @@ void SvxRTFParser::ReadAttr( int nToken, SfxItemSet* pSet )
             case RTF_LIN:
                 if( aPardMap.nLRSpace )
                 {
-                    SvxLRSpaceItem aLR( GetLRSpace(*pSet, aPardMap.nLRSpace ));
+                    SvxLRSpaceItem aLR(
+                        static_cast<const SvxLRSpaceItem&>(pSet->Get(aPardMap.nLRSpace)));
                     sal_uInt16 nSz = 0;
                     if( 0 < nTokenValue )
                     {
@@ -382,7 +364,8 @@ void SvxRTFParser::ReadAttr( int nToken, SfxItemSet* pSet )
             case RTF_RIN:
                 if( aPardMap.nLRSpace )
                 {
-                    SvxLRSpaceItem aLR( GetLRSpace(*pSet, aPardMap.nLRSpace ));
+                    SvxLRSpaceItem aLR(
+                        static_cast<const SvxLRSpaceItem&>(pSet->Get(aPardMap.nLRSpace)));
                     sal_uInt16 nSz = 0;
                     if( 0 < nTokenValue )
                     {
@@ -398,7 +381,8 @@ void SvxRTFParser::ReadAttr( int nToken, SfxItemSet* pSet )
             case RTF_SB:
                 if( aPardMap.nULSpace )
                 {
-                    SvxULSpaceItem aUL( GetULSpace(*pSet, aPardMap.nULSpace ));
+                    SvxULSpaceItem aUL(
+                        static_cast<const SvxULSpaceItem&>(pSet->Get(aPardMap.nULSpace)));
                     sal_uInt16 nSz = 0;
                     if( 0 < nTokenValue )
                     {
@@ -414,7 +398,8 @@ void SvxRTFParser::ReadAttr( int nToken, SfxItemSet* pSet )
             case RTF_SA:
                 if( aPardMap.nULSpace )
                 {
-                    SvxULSpaceItem aUL( GetULSpace(*pSet, aPardMap.nULSpace ));
+                    SvxULSpaceItem aUL(
+                        static_cast<const SvxULSpaceItem&>(pSet->Get(aPardMap.nULSpace)));
                     sal_uInt16 nSz = 0;
                     if( 0 < nTokenValue )
                     {
@@ -431,8 +416,8 @@ void SvxRTFParser::ReadAttr( int nToken, SfxItemSet* pSet )
                 if( aPardMap.nLinespacing && 1 == nTokenValue )
                 {
                     // then switches to multi-line!
-                    SvxLineSpacingItem aLSpace( GetLineSpacing( *pSet,
-                                                aPardMap.nLinespacing, false ));
+                    SvxLineSpacingItem aLSpace(
+                            static_cast<const SvxLineSpacingItem&>(pSet->Get( aPardMap.nLinespacing,false)));
 
                     // how much do you get from the line height value?
 
@@ -443,14 +428,13 @@ void SvxRTFParser::ReadAttr( int nToken, SfxItemSet* pSet )
                     if( IsCalcValue() )
                         CalcValue();
 
-                    nTokenValue = short( 100L * aLSpace.GetLineHeight()
-                                            / long( nTokenValue ) );
+                    nTokenValue = short( 100L * aLSpace.GetLineHeight() / nTokenValue );
 
                     if( nTokenValue > 200 )     // Data value for PropLnSp
                         nTokenValue = 200;      // is one BYTE !!!
 
-                    aLSpace.SetPropLineSpace( (const sal_uInt8)nTokenValue );
-                    aLSpace.GetLineSpaceRule() = SVX_LINE_SPACE_AUTO;
+                    aLSpace.SetPropLineSpace( (sal_uInt8)nTokenValue );
+                    aLSpace.SetLineSpaceRule( SvxLineSpaceRule::Auto );
 
                     pSet->Put( aLSpace );
                 }
@@ -468,28 +452,28 @@ void SvxRTFParser::ReadAttr( int nToken, SfxItemSet* pSet )
                     if (1000 == nTokenValue )
                         nTokenValue = 240;
 
-                    SvxLineSpace eLnSpc;
+                    SvxLineSpaceRule eLnSpc;
                     if (nTokenValue < 0)
                     {
-                        eLnSpc = SVX_LINE_SPACE_FIX;
+                        eLnSpc = SvxLineSpaceRule::Fix;
                         nTokenValue = -nTokenValue;
                     }
                     else if (nTokenValue == 0)
                     {
                         //if \sl0 is used, the line spacing is automatically
                         //determined
-                        eLnSpc = SVX_LINE_SPACE_AUTO;
+                        eLnSpc = SvxLineSpaceRule::Auto;
                     }
                     else
-                        eLnSpc = SVX_LINE_SPACE_MIN;
+                        eLnSpc = SvxLineSpaceRule::Min;
 
                     if (IsCalcValue())
                         CalcValue();
 
-                    if (eLnSpc != SVX_LINE_SPACE_AUTO)
-                        aLSpace.SetLineHeight( (const sal_uInt16)nTokenValue );
+                    if (eLnSpc != SvxLineSpaceRule::Auto)
+                        aLSpace.SetLineHeight( (sal_uInt16)nTokenValue );
 
-                    aLSpace.GetLineSpaceRule() = eLnSpc;
+                    aLSpace.SetLineSpaceRule(eLnSpc);
                     pSet->Put(aLSpace);
                 }
                 break;
@@ -518,15 +502,15 @@ void SvxRTFParser::ReadAttr( int nToken, SfxItemSet* pSet )
                 break;
 
             case RTF_FAFIXED:
-            case RTF_FAAUTO:    nFontAlign = SvxParaVertAlignItem::AUTOMATIC;
+            case RTF_FAAUTO:    nFontAlign = SvxParaVertAlignItem::Align::Automatic;
                                 goto SET_FONTALIGNMENT;
-            case RTF_FAHANG:    nFontAlign = SvxParaVertAlignItem::TOP;
+            case RTF_FAHANG:    nFontAlign = SvxParaVertAlignItem::Align::Top;
                                 goto SET_FONTALIGNMENT;
-            case RTF_FAVAR:     nFontAlign = SvxParaVertAlignItem::BOTTOM;
+            case RTF_FAVAR:     nFontAlign = SvxParaVertAlignItem::Align::Bottom;
                                 goto SET_FONTALIGNMENT;
-            case RTF_FACENTER:  nFontAlign = SvxParaVertAlignItem::CENTER;
+            case RTF_FACENTER:  nFontAlign = SvxParaVertAlignItem::Align::Center;
                                 goto SET_FONTALIGNMENT;
-            case RTF_FAROMAN:   nFontAlign = SvxParaVertAlignItem::BASELINE;
+            case RTF_FAROMAN:   nFontAlign = SvxParaVertAlignItem::Align::Baseline;
                                 goto SET_FONTALIGNMENT;
 SET_FONTALIGNMENT:
             if( aPardMap.nFontAlign )
@@ -555,11 +539,11 @@ SET_FONTALIGNMENT:
                 {
                     SvxCaseMap eCaseMap;
                     if( !nTokenValue )
-                        eCaseMap = SVX_CASEMAP_NOT_MAPPED;
+                        eCaseMap = SvxCaseMap::NotMapped;
                     else if( RTF_CAPS == nToken )
-                        eCaseMap = SVX_CASEMAP_VERSALIEN;
+                        eCaseMap = SvxCaseMap::Uppercase;
                     else
-                        eCaseMap = SVX_CASEMAP_KAPITAELCHEN;
+                        eCaseMap = SvxCaseMap::SmallCaps;
 
                     pSet->Put( SvxCaseMapItem( eCaseMap, aPlainMap.nCaseMap ));
                 }
@@ -574,13 +558,14 @@ SET_FONTALIGNMENT:
                         nTokenValue = 6;
                     if( IsCalcValue() )
                         CalcValue();
-                    const SvxEscapementItem& rOld = GetEscapement( *pSet, nEsc, false );
+                    const SvxEscapementItem& rOld =
+                        static_cast<const SvxEscapementItem&>(pSet->Get( nEsc,false));
                     short nEs;
                     sal_uInt8 nProp;
                     if( DFLT_ESC_AUTO_SUPER == rOld.GetEsc() )
                     {
                         nEs = DFLT_ESC_AUTO_SUB;
-                        nProp = rOld.GetProp();
+                        nProp = rOld.GetProportionalHeight();
                     }
                     else
                     {
@@ -641,8 +626,8 @@ SET_FONTALIGNMENT:
             case RTF_AF:
                 {
                     const vcl::Font& rSVFont = GetFont( sal_uInt16(nTokenValue) );
-                    SvxFontItem aTmpItem( rSVFont.GetFamily(),
-                                    rSVFont.GetName(), rSVFont.GetStyleName(),
+                    SvxFontItem aTmpItem( rSVFont.GetFamilyType(),
+                                    rSVFont.GetFamilyName(), rSVFont.GetStyleName(),
                                     rSVFont.GetPitch(), rSVFont.GetCharSet(),
                                     SID_ATTR_CHAR_FONT );
                     SetScriptAttr( eCharType, *pSet, aTmpItem );
@@ -663,12 +648,12 @@ SET_FONTALIGNMENT:
                         nTokenValue *= 10;
 // #i66167#
 // for the SwRTFParser 'IsCalcValue' will be false and for the EditRTFParser
-// the converiosn takes now place in EditRTFParser since for other reasons
+// the conversion takes now place in EditRTFParser since for other reasons
 // the wrong MapUnit might still be use there
 //                   if( IsCalcValue() )
 //                       CalcValue();
                     SvxFontHeightItem aTmpItem(
-                            (const sal_uInt16)nTokenValue, 100,
+                            (sal_uInt16)nTokenValue, 100,
                             SID_ATTR_CHAR_FONTHEIGHT );
                     SetScriptAttr( eCharType, *pSet, aTmpItem );
                 }
@@ -725,60 +710,60 @@ SET_FONTALIGNMENT:
             case RTF_UL:
                 if( !IsAttrSttPos() )
                     break;
-                eUnderline = nTokenValue ? UNDERLINE_SINGLE : UNDERLINE_NONE;
+                eUnderline = nTokenValue ? LINESTYLE_SINGLE : LINESTYLE_NONE;
                 goto ATTR_SETUNDERLINE;
 
             case RTF_ULD:
-                eUnderline = UNDERLINE_DOTTED;
+                eUnderline = LINESTYLE_DOTTED;
                 goto ATTR_SETUNDERLINE;
             case RTF_ULDASH:
-                eUnderline = UNDERLINE_DASH;
+                eUnderline = LINESTYLE_DASH;
                 goto ATTR_SETUNDERLINE;
             case RTF_ULDASHD:
-                eUnderline = UNDERLINE_DASHDOT;
+                eUnderline = LINESTYLE_DASHDOT;
                 goto ATTR_SETUNDERLINE;
             case RTF_ULDASHDD:
-                eUnderline = UNDERLINE_DASHDOTDOT;
+                eUnderline = LINESTYLE_DASHDOTDOT;
                 goto ATTR_SETUNDERLINE;
             case RTF_ULDB:
-                eUnderline = UNDERLINE_DOUBLE;
+                eUnderline = LINESTYLE_DOUBLE;
                 goto ATTR_SETUNDERLINE;
             case RTF_ULNONE:
-                eUnderline = UNDERLINE_NONE;
+                eUnderline = LINESTYLE_NONE;
                 goto ATTR_SETUNDERLINE;
             case RTF_ULTH:
-                eUnderline = UNDERLINE_BOLD;
+                eUnderline = LINESTYLE_BOLD;
                 goto ATTR_SETUNDERLINE;
             case RTF_ULWAVE:
-                eUnderline = UNDERLINE_WAVE;
+                eUnderline = LINESTYLE_WAVE;
                 goto ATTR_SETUNDERLINE;
             case RTF_ULTHD:
-                eUnderline = UNDERLINE_BOLDDOTTED;
+                eUnderline = LINESTYLE_BOLDDOTTED;
                 goto ATTR_SETUNDERLINE;
             case RTF_ULTHDASH:
-                eUnderline = UNDERLINE_BOLDDASH;
+                eUnderline = LINESTYLE_BOLDDASH;
                 goto ATTR_SETUNDERLINE;
             case RTF_ULLDASH:
-                eUnderline = UNDERLINE_LONGDASH;
+                eUnderline = LINESTYLE_LONGDASH;
                 goto ATTR_SETUNDERLINE;
             case RTF_ULTHLDASH:
-                eUnderline = UNDERLINE_BOLDLONGDASH;
+                eUnderline = LINESTYLE_BOLDLONGDASH;
                 goto ATTR_SETUNDERLINE;
             case RTF_ULTHDASHD:
-                eUnderline = UNDERLINE_BOLDDASHDOT;
+                eUnderline = LINESTYLE_BOLDDASHDOT;
                 goto ATTR_SETUNDERLINE;
             case RTF_ULTHDASHDD:
-                eUnderline = UNDERLINE_BOLDDASHDOTDOT;
+                eUnderline = LINESTYLE_BOLDDASHDOTDOT;
                 goto ATTR_SETUNDERLINE;
             case RTF_ULHWAVE:
-                eUnderline = UNDERLINE_BOLDWAVE;
+                eUnderline = LINESTYLE_BOLDWAVE;
                 goto ATTR_SETUNDERLINE;
             case RTF_ULULDBWAVE:
-                eUnderline = UNDERLINE_DOUBLEWAVE;
+                eUnderline = LINESTYLE_DOUBLEWAVE;
                 goto ATTR_SETUNDERLINE;
 
             case RTF_ULW:
-                eUnderline = UNDERLINE_SINGLE;
+                eUnderline = LINESTYLE_SINGLE;
 
                 if( aPlainMap.nWordlineMode )
                 {
@@ -796,13 +781,13 @@ ATTR_SETUNDERLINE:
             case RTF_ULC:
                 if( aPlainMap.nUnderline )
                 {
-                    SvxUnderlineItem aUL( UNDERLINE_SINGLE, aPlainMap.nUnderline );
+                    SvxUnderlineItem aUL( LINESTYLE_SINGLE, aPlainMap.nUnderline );
                     const SfxPoolItem* pItem;
                     if( SfxItemState::SET == pSet->GetItemState(
                         aPlainMap.nUnderline, false, &pItem ) )
                     {
                         // is switched off ?
-                        if( UNDERLINE_NONE ==
+                        if( LINESTYLE_NONE ==
                             static_cast<const SvxUnderlineItem*>(pItem)->GetLineStyle() )
                             break;
                         aUL = *static_cast<const SvxUnderlineItem*>(pItem);
@@ -810,8 +795,8 @@ ATTR_SETUNDERLINE:
                     else
                         aUL = static_cast<const SvxUnderlineItem&>(pSet->Get( aPlainMap.nUnderline, false ));
 
-                    if( UNDERLINE_NONE == aUL.GetLineStyle() )
-                        aUL.SetLineStyle( UNDERLINE_SINGLE );
+                    if( LINESTYLE_NONE == aUL.GetLineStyle() )
+                        aUL.SetLineStyle( LINESTYLE_SINGLE );
                     aUL.SetColor( GetColor( sal_uInt16(nTokenValue) ));
                     pSet->Put( aUL );
                 }
@@ -820,60 +805,60 @@ ATTR_SETUNDERLINE:
             case RTF_OL:
                 if( !IsAttrSttPos() )
                     break;
-                eOverline = nTokenValue ? UNDERLINE_SINGLE : UNDERLINE_NONE;
+                eOverline = nTokenValue ? LINESTYLE_SINGLE : LINESTYLE_NONE;
                 goto ATTR_SETOVERLINE;
 
             case RTF_OLD:
-                eOverline = UNDERLINE_DOTTED;
+                eOverline = LINESTYLE_DOTTED;
                 goto ATTR_SETOVERLINE;
             case RTF_OLDASH:
-                eOverline = UNDERLINE_DASH;
+                eOverline = LINESTYLE_DASH;
                 goto ATTR_SETOVERLINE;
             case RTF_OLDASHD:
-                eOverline = UNDERLINE_DASHDOT;
+                eOverline = LINESTYLE_DASHDOT;
                 goto ATTR_SETOVERLINE;
             case RTF_OLDASHDD:
-                eOverline = UNDERLINE_DASHDOTDOT;
+                eOverline = LINESTYLE_DASHDOTDOT;
                 goto ATTR_SETOVERLINE;
             case RTF_OLDB:
-                eOverline = UNDERLINE_DOUBLE;
+                eOverline = LINESTYLE_DOUBLE;
                 goto ATTR_SETOVERLINE;
             case RTF_OLNONE:
-                eOverline = UNDERLINE_NONE;
+                eOverline = LINESTYLE_NONE;
                 goto ATTR_SETOVERLINE;
             case RTF_OLTH:
-                eOverline = UNDERLINE_BOLD;
+                eOverline = LINESTYLE_BOLD;
                 goto ATTR_SETOVERLINE;
             case RTF_OLWAVE:
-                eOverline = UNDERLINE_WAVE;
+                eOverline = LINESTYLE_WAVE;
                 goto ATTR_SETOVERLINE;
             case RTF_OLTHD:
-                eOverline = UNDERLINE_BOLDDOTTED;
+                eOverline = LINESTYLE_BOLDDOTTED;
                 goto ATTR_SETOVERLINE;
             case RTF_OLTHDASH:
-                eOverline = UNDERLINE_BOLDDASH;
+                eOverline = LINESTYLE_BOLDDASH;
                 goto ATTR_SETOVERLINE;
             case RTF_OLLDASH:
-                eOverline = UNDERLINE_LONGDASH;
+                eOverline = LINESTYLE_LONGDASH;
                 goto ATTR_SETOVERLINE;
             case RTF_OLTHLDASH:
-                eOverline = UNDERLINE_BOLDLONGDASH;
+                eOverline = LINESTYLE_BOLDLONGDASH;
                 goto ATTR_SETOVERLINE;
             case RTF_OLTHDASHD:
-                eOverline = UNDERLINE_BOLDDASHDOT;
+                eOverline = LINESTYLE_BOLDDASHDOT;
                 goto ATTR_SETOVERLINE;
             case RTF_OLTHDASHDD:
-                eOverline = UNDERLINE_BOLDDASHDOTDOT;
+                eOverline = LINESTYLE_BOLDDASHDOTDOT;
                 goto ATTR_SETOVERLINE;
             case RTF_OLHWAVE:
-                eOverline = UNDERLINE_BOLDWAVE;
+                eOverline = LINESTYLE_BOLDWAVE;
                 goto ATTR_SETOVERLINE;
             case RTF_OLOLDBWAVE:
-                eOverline = UNDERLINE_DOUBLEWAVE;
+                eOverline = LINESTYLE_DOUBLEWAVE;
                 goto ATTR_SETOVERLINE;
 
             case RTF_OLW:
-                eOverline = UNDERLINE_SINGLE;
+                eOverline = LINESTYLE_SINGLE;
 
                 if( aPlainMap.nWordlineMode )
                 {
@@ -891,13 +876,13 @@ ATTR_SETOVERLINE:
             case RTF_OLC:
                 if( aPlainMap.nOverline )
                 {
-                    SvxOverlineItem aOL( UNDERLINE_SINGLE, aPlainMap.nOverline );
+                    SvxOverlineItem aOL( LINESTYLE_SINGLE, aPlainMap.nOverline );
                     const SfxPoolItem* pItem;
                     if( SfxItemState::SET == pSet->GetItemState(
                         aPlainMap.nOverline, false, &pItem ) )
                     {
                         // is switched off ?
-                        if( UNDERLINE_NONE ==
+                        if( LINESTYLE_NONE ==
                             static_cast<const SvxOverlineItem*>(pItem)->GetLineStyle() )
                             break;
                         aOL = *static_cast<const SvxOverlineItem*>(pItem);
@@ -905,8 +890,8 @@ ATTR_SETOVERLINE:
                     else
                         aOL = static_cast<const SvxOverlineItem&>(pSet->Get( aPlainMap.nOverline, false ));
 
-                    if( UNDERLINE_NONE == aOL.GetLineStyle() )
-                        aOL.SetLineStyle( UNDERLINE_SINGLE );
+                    if( LINESTYLE_NONE == aOL.GetLineStyle() )
+                        aOL.SetLineStyle( LINESTYLE_SINGLE );
                     aOL.SetColor( GetColor( sal_uInt16(nTokenValue) ));
                     pSet->Put( aOL );
                 }
@@ -921,13 +906,14 @@ ATTR_SETOVERLINE:
                         nTokenValue = 6;
                     if( IsCalcValue() )
                         CalcValue();
-                    const SvxEscapementItem& rOld = GetEscapement( *pSet, nEsc, false );
+                    const SvxEscapementItem& rOld =
+                        static_cast<const SvxEscapementItem&>(pSet->Get( nEsc,false));
                     short nEs;
                     sal_uInt8 nProp;
                     if( DFLT_ESC_AUTO_SUB == rOld.GetEsc() )
                     {
                         nEs = DFLT_ESC_AUTO_SUPER;
-                        nProp = rOld.GetProp();
+                        nProp = rOld.GetProportionalHeight();
                     }
                     else
                     {
@@ -960,7 +946,7 @@ ATTR_SETOVERLINE:
             case RTF_LANG:
                 if( aPlainMap.nLanguage )
                 {
-                    pSet->Put( SvxLanguageItem( (LanguageType)nTokenValue,
+                    pSet->Put( SvxLanguageItem( LanguageType(nTokenValue),
                                 aPlainMap.nLanguage ));
                 }
                 break;
@@ -968,13 +954,13 @@ ATTR_SETOVERLINE:
             case RTF_LANGFE:
                 if( aPlainMap.nCJKLanguage )
                 {
-                    pSet->Put( SvxLanguageItem( (LanguageType)nTokenValue,
+                    pSet->Put( SvxLanguageItem( LanguageType(nTokenValue),
                                                 aPlainMap.nCJKLanguage ));
                 }
                 break;
             case RTF_ALANG:
                 {
-                    SvxLanguageItem aTmpItem( (LanguageType)nTokenValue,
+                    SvxLanguageItem aTmpItem( LanguageType(nTokenValue),
                                     SID_ATTR_CHAR_LANGUAGE );
                     SetScriptAttr( eCharType, *pSet, aTmpItem );
                 }
@@ -989,14 +975,14 @@ ATTR_SETOVERLINE:
             case RTF_RTLPAR:
                 if (aPardMap.nDirection)
                 {
-                    pSet->Put(SvxFrameDirectionItem(FRMDIR_HORI_RIGHT_TOP,
+                    pSet->Put(SvxFrameDirectionItem(SvxFrameDirection::Horizontal_RL_TB,
                         aPardMap.nDirection));
                 }
                 break;
             case RTF_LTRPAR:
                 if (aPardMap.nDirection)
                 {
-                    pSet->Put(SvxFrameDirectionItem(FRMDIR_HORI_LEFT_TOP,
+                    pSet->Put(SvxFrameDirectionItem(SvxFrameDirection::Horizontal_LR_TB,
                         aPardMap.nDirection));
                 }
                 break;
@@ -1006,14 +992,14 @@ ATTR_SETOVERLINE:
 
 
             case RTF_ACCNONE:
-                eEmphasis = EMPHASISMARK_NONE;
+                eEmphasis = FontEmphasisMark::NONE;
                 goto ATTR_SETEMPHASIS;
             case RTF_ACCDOT:
-                eEmphasis = EMPHASISMARK_DOTS_ABOVE;
+                eEmphasis = (FontEmphasisMark::Dot | FontEmphasisMark::PosAbove);
                 goto ATTR_SETEMPHASIS;
 
             case RTF_ACCCOMMA:
-                eEmphasis = EMPHASISMARK_SIDE_DOTS;
+                eEmphasis = (FontEmphasisMark::Accent | FontEmphasisMark::PosAbove);
 ATTR_SETEMPHASIS:
                 if( aPlainMap.nEmphasis )
                 {
@@ -1028,11 +1014,11 @@ ATTR_SETEMPHASIS:
                     sal_Unicode cStt, cEnd;
                     switch ( nTokenValue )
                     {
-                    case 1: cStt = '(', cEnd = ')'; break;
-                    case 2: cStt = '[', cEnd = ']'; break;
-                    case 3: cStt = '<', cEnd = '>'; break;
-                    case 4: cStt = '{', cEnd = '}'; break;
-                    default: cStt = 0, cEnd = 0; break;
+                    case 1: cStt = '('; cEnd = ')'; break;
+                    case 2: cStt = '['; cEnd = ']'; break;
+                    case 3: cStt = '<'; cEnd = '>'; break;
+                    case 4: cStt = '{'; cEnd = '}'; break;
+                    default: cStt = 0; cEnd = 0; break;
                     }
 
                     pSet->Put( SvxTwoLinesItem( true, cStt, cEnd,
@@ -1063,14 +1049,14 @@ ATTR_SETEMPHASIS:
             case RTF_EMBO:
                 if (aPlainMap.nRelief)
                 {
-                    pSet->Put(SvxCharReliefItem(RELIEF_EMBOSSED,
+                    pSet->Put(SvxCharReliefItem(FontRelief::Embossed,
                         aPlainMap.nRelief));
                 }
                 break;
             case RTF_IMPR:
                 if (aPlainMap.nRelief)
                 {
-                    pSet->Put(SvxCharReliefItem(RELIEF_ENGRAVED,
+                    pSet->Put(SvxCharReliefItem(FontRelief::Engraved,
                         aPlainMap.nRelief));
                 }
                 break;
@@ -1283,7 +1269,7 @@ void SvxRTFParser::ReadTabAttr( int nToken, SfxItemSet& rSet )
     bool bMethodOwnsToken = false; // #i52542# patch from cmc.
 // then read all the TabStops
     SvxTabStop aTabStop;
-    SvxTabStopItem aAttr( 0, 0, SVX_TAB_ADJUST_DEFAULT, aPardMap.nTabStop );
+    SvxTabStopItem aAttr( 0, 0, SvxTabAdjust::Default, aPardMap.nTabStop );
     bool bContinue = true;
     do {
         switch( nToken )
@@ -1300,16 +1286,16 @@ void SvxRTFParser::ReadTabAttr( int nToken, SfxItemSet& rSet )
             break;
 
         case RTF_TQL:
-            aTabStop.GetAdjustment() = SVX_TAB_ADJUST_LEFT;
+            aTabStop.GetAdjustment() = SvxTabAdjust::Left;
             break;
         case RTF_TQR:
-            aTabStop.GetAdjustment() = SVX_TAB_ADJUST_RIGHT;
+            aTabStop.GetAdjustment() = SvxTabAdjust::Right;
             break;
         case RTF_TQC:
-            aTabStop.GetAdjustment() = SVX_TAB_ADJUST_CENTER;
+            aTabStop.GetAdjustment() = SvxTabAdjust::Center;
             break;
         case RTF_TQDEC:
-            aTabStop.GetAdjustment() = SVX_TAB_ADJUST_DECIMAL;
+            aTabStop.GetAdjustment() = SvxTabAdjust::Decimal;
             break;
 
         case RTF_TLDOT:     aTabStop.GetFill() = '.';   break;
@@ -1367,17 +1353,17 @@ static void SetBorderLine( int nBorderTyp, SvxBoxItem& rItem,
         rItem.SetLine( &rBorder, SvxBoxItemLine::TOP );
         if( RTF_BOX != nBorderTyp )
             return;
-        // fall-through
+        SAL_FALLTHROUGH;
     case RTF_BRDRB:
         rItem.SetLine( &rBorder, SvxBoxItemLine::BOTTOM );
         if( RTF_BOX != nBorderTyp )
             return;
-        // fall-through
+        SAL_FALLTHROUGH;
     case RTF_BRDRL:
         rItem.SetLine( &rBorder, SvxBoxItemLine::LEFT );
         if( RTF_BOX != nBorderTyp )
             return;
-        // fall-through
+        SAL_FALLTHROUGH;
     case RTF_BRDRR:
         rItem.SetLine( &rBorder, SvxBoxItemLine::RIGHT );
         if( RTF_BOX != nBorderTyp )
@@ -1454,49 +1440,49 @@ void SvxRTFParser::ReadBorderAttr( int nToken, SfxItemSet& rSet,
             }
 
         case RTF_BRDRDOT:       // dotted border
-            aBrd.SetBorderLineStyle(table::BorderLineStyle::DOTTED);
+            aBrd.SetBorderLineStyle(SvxBorderLineStyle::DOTTED);
             break;
         case RTF_BRDRDASH:      // dashed border
-            aBrd.SetBorderLineStyle(table::BorderLineStyle::DASHED);
+            aBrd.SetBorderLineStyle(SvxBorderLineStyle::DASHED);
             break;
         case RTF_BRDRHAIR:      // hairline border
             {
-                aBrd.SetBorderLineStyle( table::BorderLineStyle::SOLID);
+                aBrd.SetBorderLineStyle( SvxBorderLineStyle::SOLID);
                 aBrd.SetWidth( DEF_LINE_WIDTH_0 );
             }
             break;
         case RTF_BRDRDB:        // Double border
-            aBrd.SetBorderLineStyle(table::BorderLineStyle::DOUBLE);
+            aBrd.SetBorderLineStyle(SvxBorderLineStyle::DOUBLE);
             break;
         case RTF_BRDRINSET:     // inset border
-            aBrd.SetBorderLineStyle(table::BorderLineStyle::INSET);
+            aBrd.SetBorderLineStyle(SvxBorderLineStyle::INSET);
             break;
         case RTF_BRDROUTSET:    // outset border
-            aBrd.SetBorderLineStyle(table::BorderLineStyle::OUTSET);
+            aBrd.SetBorderLineStyle(SvxBorderLineStyle::OUTSET);
             break;
         case RTF_BRDRTNTHSG:    // ThinThick Small gap
-            aBrd.SetBorderLineStyle(table::BorderLineStyle::THINTHICK_SMALLGAP);
+            aBrd.SetBorderLineStyle(SvxBorderLineStyle::THINTHICK_SMALLGAP);
             break;
         case RTF_BRDRTNTHMG:    // ThinThick Medium gap
-            aBrd.SetBorderLineStyle(table::BorderLineStyle::THINTHICK_MEDIUMGAP);
+            aBrd.SetBorderLineStyle(SvxBorderLineStyle::THINTHICK_MEDIUMGAP);
             break;
         case RTF_BRDRTNTHLG:    // ThinThick Large gap
-            aBrd.SetBorderLineStyle(table::BorderLineStyle::THINTHICK_LARGEGAP);
+            aBrd.SetBorderLineStyle(SvxBorderLineStyle::THINTHICK_LARGEGAP);
             break;
         case RTF_BRDRTHTNSG:    // ThickThin Small gap
-            aBrd.SetBorderLineStyle(table::BorderLineStyle::THICKTHIN_SMALLGAP);
+            aBrd.SetBorderLineStyle(SvxBorderLineStyle::THICKTHIN_SMALLGAP);
             break;
         case RTF_BRDRTHTNMG:    // ThickThin Medium gap
-            aBrd.SetBorderLineStyle(table::BorderLineStyle::THICKTHIN_MEDIUMGAP);
+            aBrd.SetBorderLineStyle(SvxBorderLineStyle::THICKTHIN_MEDIUMGAP);
             break;
         case RTF_BRDRTHTNLG:    // ThickThin Large gap
-            aBrd.SetBorderLineStyle(table::BorderLineStyle::THICKTHIN_LARGEGAP);
+            aBrd.SetBorderLineStyle(SvxBorderLineStyle::THICKTHIN_LARGEGAP);
             break;
         case RTF_BRDREMBOSS:    // Embossed border
-            aBrd.SetBorderLineStyle(table::BorderLineStyle::EMBOSSED);
+            aBrd.SetBorderLineStyle(SvxBorderLineStyle::EMBOSSED);
             break;
         case RTF_BRDRENGRAVE:   // Engraved border
-            aBrd.SetBorderLineStyle(table::BorderLineStyle::ENGRAVED);
+            aBrd.SetBorderLineStyle(SvxBorderLineStyle::ENGRAVED);
             break;
 
         case RTF_BRDRS:         // single thickness border
@@ -1515,7 +1501,7 @@ void SvxRTFParser::ReadBorderAttr( int nToken, SfxItemSet& rSet,
 
         case RTF_BRDRSH:        // Shadowed border
                 rSet.Put( SvxShadowItem( aPardMap.nShadow, nullptr, 60 /*3pt*/,
-                                        SVX_SHADOW_BOTTOMRIGHT ) );
+                                        SvxShadowLocation::BottomRight ) );
                 break;
 
         case RTF_BRSP:          // Spacing to content in twip
@@ -1539,7 +1525,7 @@ void SvxRTFParser::ReadBorderAttr( int nToken, SfxItemSet& rSet,
                     break;
 
                 case RTF_BOX:
-                    aAttr.SetDistance( (sal_uInt16)nTokenValue );
+                    aAttr.SetAllDistances( (sal_uInt16)nTokenValue );
                     break;
                 }
             }
@@ -1664,7 +1650,7 @@ void SvxRTFParser::ReadBackgroundAttr( int nToken, SfxItemSet& rSet,
     Color aCol( COL_WHITE ), aFCol;
     if( !nFillValue )
     {
-        // there was only one of two colors specified or no BrushTyp
+        // there was only one of two colors specified or no BrushType
         if( USHRT_MAX != nFillColor )
         {
             nFillValue = 100;
@@ -1759,7 +1745,7 @@ void SvxRTFParser::RTFPardPlain( bool const bPard, SfxItemSet** ppSet )
                 // Item set and different -> Set the Default Pool
                 if( !*pPtr )
                     ;
-                else if( SFX_WHICH_MAX < *pPtr )
+                else if (SfxItemPool::IsSlot(*pPtr))
                     pAkt->aAttrSet.ClearItem( *pPtr );
                 else if( IsChkStyleAttr() )
                     pAkt->aAttrSet.Put( pDfltSet->Get( *pPtr ) );
@@ -1816,27 +1802,30 @@ void SvxRTFParser::SetDefault( int nToken, int nValue )
     bIsLeftToRightDef = true;
     switch( nToken )
     {
-    case RTF_ADEFF: bIsLeftToRightDef = false;  // no break!
+    case RTF_ADEFF:
+        bIsLeftToRightDef = false;
+        SAL_FALLTHROUGH;
     case RTF_DEFF:
         {
             if( -1 == nValue )
                 nValue = 0;
             const vcl::Font& rSVFont = GetFont( sal_uInt16(nValue) );
             SvxFontItem aTmpItem(
-                                rSVFont.GetFamily(), rSVFont.GetName(),
+                                rSVFont.GetFamilyType(), rSVFont.GetFamilyName(),
                                 rSVFont.GetStyleName(), rSVFont.GetPitch(),
                                 rSVFont.GetCharSet(), SID_ATTR_CHAR_FONT );
             SetScriptAttr( NOTDEF_CHARTYPE, aTmp, aTmpItem );
         }
         break;
 
-    case RTF_ADEFLANG:  bIsLeftToRightDef = false;  // no break!
+    case RTF_ADEFLANG:
+        bIsLeftToRightDef = false;
+        SAL_FALLTHROUGH;
     case RTF_DEFLANG:
         // store default Language
         if( -1 != nValue )
         {
-            SvxLanguageItem aTmpItem( (const LanguageType)nValue,
-                                        SID_ATTR_CHAR_LANGUAGE );
+            SvxLanguageItem aTmpItem( LanguageType(nValue), SID_ATTR_CHAR_LANGUAGE );
             SetScriptAttr( NOTDEF_CHARTYPE, aTmp, aTmpItem );
         }
         break;
@@ -1863,16 +1852,16 @@ void SvxRTFParser::SetDefault( int nToken, int nValue )
             sal_uInt16 nTabCount = (SVX_TAB_DEFDIST * 13 ) / sal_uInt16(nValue);
             /*
              cmc, make sure we have at least one, or all hell breaks loose in
-             everybodies exporters, #i8247#
+             everybody exporters, #i8247#
             */
             if (nTabCount < 1)
                 nTabCount = 1;
 
             // we want Defaulttabs
             SvxTabStopItem aNewTab( nTabCount, sal_uInt16(nValue),
-                                SVX_TAB_ADJUST_DEFAULT, aPardMap.nTabStop );
+                                SvxTabAdjust::Default, aPardMap.nTabStop );
             while( nTabCount )
-                ((SvxTabStop&)aNewTab[ --nTabCount ]).GetAdjustment() = SVX_TAB_ADJUST_DEFAULT;
+                const_cast<SvxTabStop&>(aNewTab[ --nTabCount ]).GetAdjustment() = SvxTabAdjust::Default;
 
             pAttrPool->SetPoolDefaultItem( aNewTab );
         }
