@@ -20,6 +20,9 @@
 #include <com/sun/star/embed/EmbedStates.hpp>
 #include <com/sun/star/embed/EmbedVerbs.hpp>
 #include <com/sun/star/embed/EmbedUpdateModes.hpp>
+#include <com/sun/star/embed/ObjectSaveVetoException.hpp>
+#include <com/sun/star/embed/StorageWrappedTargetException.hpp>
+#include <com/sun/star/embed/UnreachableStateException.hpp>
 #include <com/sun/star/embed/XEmbeddedClient.hpp>
 #include <com/sun/star/embed/XInplaceClient.hpp>
 #include <com/sun/star/embed/XWindowSupplier.hpp>
@@ -27,12 +30,10 @@
 #include <com/sun/star/embed/Aspects.hpp>
 
 #include <com/sun/star/awt/XWindowPeer.hpp>
+#include <com/sun/star/io/IOException.hpp>
 #include <com/sun/star/util/XCloseBroadcaster.hpp>
 #include <com/sun/star/util/XCloseable.hpp>
 #include <com/sun/star/util/XModifiable.hpp>
-#include <com/sun/star/frame/XFrame.hpp>
-#include <com/sun/star/frame/XComponentLoader.hpp>
-#include <com/sun/star/frame/XDispatchProviderInterception.hpp>
 #include <com/sun/star/frame/ModuleManager.hpp>
 #include <com/sun/star/lang/DisposedException.hpp>
 
@@ -44,8 +45,8 @@
 
 #include <targetstatecontrol.hxx>
 
-#include "commonembobj.hxx"
-#include "intercept.hxx"
+#include <commonembobj.hxx>
+#include <intercept.hxx>
 #include "embedobj.hxx"
 
 using namespace ::com::sun::star;
@@ -83,7 +84,7 @@ sal_Int32 OCommonEmbeddedObject::ConvertVerbToState_Impl( sal_Int32 nVerb )
 
 void OCommonEmbeddedObject::Deactivate()
 {
-    uno::Reference< util::XModifiable > xModif( m_pDocHolder->GetComponent(), uno::UNO_QUERY );
+    uno::Reference< util::XModifiable > xModif( m_xDocHolder->GetComponent(), uno::UNO_QUERY );
 
     // no need to lock for the initialization
     uno::Reference< embed::XEmbeddedClient > xClientSite = m_xClientSite;
@@ -108,7 +109,7 @@ void OCommonEmbeddedObject::Deactivate()
         }
     }
 
-    m_pDocHolder->CloseFrame();
+    m_xDocHolder->CloseFrame();
 
     xClientSite->visibilityChanged( false );
 }
@@ -166,7 +167,7 @@ void OCommonEmbeddedObject::SwitchStateTo_Impl( sal_Int32 nNextState )
 
             if ( m_bIsLink )
             {
-                m_pDocHolder->SetComponent( LoadLink_Impl(), m_bReadOnly );
+                m_xDocHolder->SetComponent( LoadLink_Impl(), m_bReadOnly );
             }
             else
             {
@@ -179,7 +180,7 @@ void OCommonEmbeddedObject::SwitchStateTo_Impl( sal_Int32 nNextState )
                     if ( !m_xObjectStorage.is() )
                         throw io::IOException(); //TODO: access denied
 
-                    m_pDocHolder->SetComponent( LoadDocumentFromStorage_Impl(), m_bReadOnly );
+                    m_xDocHolder->SetComponent( LoadDocumentFromStorage_Impl(), m_bReadOnly );
                 }
                 else
                 {
@@ -194,11 +195,11 @@ void OCommonEmbeddedObject::SwitchStateTo_Impl( sal_Int32 nNextState )
                     if ( xChild.is() )
                         xChild->setParent( m_xParent );
 
-                    m_pDocHolder->SetComponent( xDocument, m_bReadOnly );
+                    m_xDocHolder->SetComponent( xDocument, m_bReadOnly );
                 }
             }
 
-            if ( !m_pDocHolder->GetComponent().is() )
+            if ( !m_xDocHolder->GetComponent().is() )
                 throw embed::UnreachableStateException(); //TODO: can't open document
 
             m_nObjectState = nNextState;
@@ -213,11 +214,11 @@ void OCommonEmbeddedObject::SwitchStateTo_Impl( sal_Int32 nNextState )
     {
         if ( nNextState == embed::EmbedStates::LOADED )
         {
-            m_nClonedMapUnit = m_pDocHolder->GetMapUnit( embed::Aspects::MSOLE_CONTENT );
-            m_bHasClonedSize = m_pDocHolder->GetExtent( embed::Aspects::MSOLE_CONTENT, &m_aClonedSize );
+            m_nClonedMapUnit = m_xDocHolder->GetMapUnit( embed::Aspects::MSOLE_CONTENT );
+            m_bHasClonedSize = m_xDocHolder->GetExtent( embed::Aspects::MSOLE_CONTENT, &m_aClonedSize );
 
             // actually frame should not exist at this point
-            m_pDocHolder->CloseDocument( false, false );
+            m_xDocHolder->CloseDocument( false, false );
 
             m_nObjectState = nNextState;
         }
@@ -229,37 +230,30 @@ void OCommonEmbeddedObject::SwitchStateTo_Impl( sal_Int32 nNextState )
                     throw embed::WrongStateException( "client site not set, yet", *this );
 
                 uno::Reference< embed::XInplaceClient > xInplaceClient( m_xClientSite, uno::UNO_QUERY );
-                if ( xInplaceClient.is() && xInplaceClient->canInplaceActivate() )
-                {
-                    xInplaceClient->activatingInplace();
-
-                    uno::Reference< embed::XWindowSupplier > xClientWindowSupplier( xInplaceClient, uno::UNO_QUERY );
-                    if ( !xClientWindowSupplier.is() )
-                        throw uno::RuntimeException(); // TODO: the inplace client implementation must support XWinSupp
-
-                    m_xClientWindow = xClientWindowSupplier->getWindow();
-                    m_aOwnRectangle = xInplaceClient->getPlacement();
-                    m_aClipRectangle = xInplaceClient->getClipRectangle();
-                    awt::Rectangle aRectangleToShow = GetRectangleInterception( m_aOwnRectangle, m_aClipRectangle );
-
-                    // create own window based on the client window
-                    // place and resize the window according to the rectangles
-                    uno::Reference< awt::XWindowPeer > xClientWindowPeer( m_xClientWindow, uno::UNO_QUERY );
-                    if ( !xClientWindowPeer.is() )
-                        throw uno::RuntimeException(); // TODO: the container window must support the interface
-
-                    // dispatch provider may not be provided
-                    uno::Reference< frame::XDispatchProvider > xContainerDP = xInplaceClient->getInplaceDispatchProvider();
-                    bool bOk = m_pDocHolder->ShowInplace( xClientWindowPeer, aRectangleToShow, xContainerDP );
-                    m_nObjectState = nNextState;
-                    if ( !bOk )
-                    {
-                        SwitchStateTo_Impl( embed::EmbedStates::RUNNING );
-                        throw embed::WrongStateException(); //TODO: can't activate inplace
-                    }
-                }
-                else
+                if ( !xInplaceClient.is() || !xInplaceClient->canInplaceActivate() )
                     throw embed::WrongStateException(); //TODO: can't activate inplace
+                xInplaceClient->activatingInplace();
+
+                uno::Reference< embed::XWindowSupplier > xClientWindowSupplier( xInplaceClient, uno::UNO_QUERY_THROW );
+
+                m_xClientWindow = xClientWindowSupplier->getWindow();
+                m_aOwnRectangle = xInplaceClient->getPlacement();
+                m_aClipRectangle = xInplaceClient->getClipRectangle();
+                awt::Rectangle aRectangleToShow = GetRectangleInterception( m_aOwnRectangle, m_aClipRectangle );
+
+                // create own window based on the client window
+                // place and resize the window according to the rectangles
+                uno::Reference< awt::XWindowPeer > xClientWindowPeer( m_xClientWindow, uno::UNO_QUERY_THROW );
+
+                // dispatch provider may not be provided
+                uno::Reference< frame::XDispatchProvider > xContainerDP = xInplaceClient->getInplaceDispatchProvider();
+                bool bOk = m_xDocHolder->ShowInplace( xClientWindowPeer, aRectangleToShow, xContainerDP );
+                m_nObjectState = nNextState;
+                if ( !bOk )
+                {
+                    SwitchStateTo_Impl( embed::EmbedStates::RUNNING );
+                    throw embed::WrongStateException(); //TODO: can't activate inplace
+                }
             }
             else if ( nNextState == embed::EmbedStates::ACTIVE )
             {
@@ -267,7 +261,7 @@ void OCommonEmbeddedObject::SwitchStateTo_Impl( sal_Int32 nNextState )
                     throw embed::WrongStateException(); //TODO: client site is not set!
 
                 // create frame and load document in the frame
-                m_pDocHolder->Show();
+                m_xDocHolder->Show();
 
                 m_xClientSite->visibilityChanged( true );
                 m_nObjectState = nNextState;
@@ -283,9 +277,7 @@ void OCommonEmbeddedObject::SwitchStateTo_Impl( sal_Int32 nNextState )
     {
         if ( nNextState == embed::EmbedStates::RUNNING )
         {
-            uno::Reference< embed::XInplaceClient > xInplaceClient( m_xClientSite, uno::UNO_QUERY );
-            if ( !xInplaceClient.is() )
-                throw uno::RuntimeException();
+            uno::Reference< embed::XInplaceClient > xInplaceClient( m_xClientSite, uno::UNO_QUERY_THROW );
 
             m_xClientSite->visibilityChanged( true );
 
@@ -301,45 +293,42 @@ void OCommonEmbeddedObject::SwitchStateTo_Impl( sal_Int32 nNextState )
                 // TODO:
                 uno::Reference< css::frame::XLayoutManager > xContainerLM =
                             xInplaceClient->getLayoutManager();
-                if ( xContainerLM.is() )
+                if ( !xContainerLM.is() )
+                    throw embed::WrongStateException(); //TODO: can't activate UI
+                // dispatch provider may not be provided
+                uno::Reference< frame::XDispatchProvider > xContainerDP = xInplaceClient->getInplaceDispatchProvider();
+
+                // get the container module name
+                OUString aModuleName;
+                try
                 {
-                    // dispatch provider may not be provided
-                    uno::Reference< frame::XDispatchProvider > xContainerDP = xInplaceClient->getInplaceDispatchProvider();
+                    uno::Reference< embed::XComponentSupplier > xCompSupl( m_xClientSite, uno::UNO_QUERY_THROW );
+                    uno::Reference< uno::XInterface > xContDoc( xCompSupl->getComponent(), uno::UNO_QUERY_THROW );
 
-                    // get the container module name
-                    OUString aModuleName;
-                    try
-                    {
-                        uno::Reference< embed::XComponentSupplier > xCompSupl( m_xClientSite, uno::UNO_QUERY_THROW );
-                        uno::Reference< uno::XInterface > xContDoc( xCompSupl->getComponent(), uno::UNO_QUERY_THROW );
+                    uno::Reference< frame::XModuleManager2 > xManager( frame::ModuleManager::create( m_xContext ) );
 
-                        uno::Reference< frame::XModuleManager2 > xManager( frame::ModuleManager::create( m_xContext ) );
+                    aModuleName = xManager->identify( xContDoc );
+                }
+                catch( const uno::Exception& )
+                {}
 
-                        aModuleName = xManager->identify( xContDoc );
-                    }
-                    catch( const uno::Exception& )
-                    {}
+                // if currently another object is UIactive it will be deactivated; usually this will activate the LM of
+                // the container. Locking the LM will prevent flicker.
+                xContainerLM->lock();
+                xInplaceClient->activatingUI();
+                bool bOk = m_xDocHolder->ShowUI( xContainerLM, xContainerDP, aModuleName );
+                xContainerLM->unlock();
 
-                    // if currently another object is UIactive it will be deactivated; usually this will activate the LM of
-                    // the container. Locking the LM will prevent flicker.
-                    xContainerLM->lock();
-                    xInplaceClient->activatingUI();
-                    bool bOk = m_pDocHolder->ShowUI( xContainerLM, xContainerDP, aModuleName );
-                    xContainerLM->unlock();
-
-                    if ( bOk )
-                    {
-                        m_nObjectState = nNextState;
-                        m_pDocHolder->ResizeHatchWindow();
-                    }
-                    else
-                    {
-                        xInplaceClient->deactivatedUI();
-                        throw embed::WrongStateException(); //TODO: can't activate UI
-                    }
+                if ( bOk )
+                {
+                    m_nObjectState = nNextState;
+                    m_xDocHolder->ResizeHatchWindow();
                 }
                 else
+                {
+                    xInplaceClient->deactivatedUI();
                     throw embed::WrongStateException(); //TODO: can't activate UI
+                }
             }
         }
         else
@@ -371,16 +360,13 @@ void OCommonEmbeddedObject::SwitchStateTo_Impl( sal_Int32 nNextState )
 
             bool bOk = false;
             if ( xContainerLM.is() )
-                bOk = m_pDocHolder->HideUI( xContainerLM );
+                bOk = m_xDocHolder->HideUI( xContainerLM );
 
-            if ( bOk )
-            {
-                m_nObjectState = nNextState;
-                m_pDocHolder->ResizeHatchWindow();
-                xInplaceClient->deactivatedUI();
-            }
-            else
+            if ( !bOk )
                 throw embed::WrongStateException(); //TODO: can't activate UI
+            m_nObjectState = nNextState;
+            m_xDocHolder->ResizeHatchWindow();
+            xInplaceClient->deactivatedUI();
         }
     }
     else
@@ -417,78 +403,70 @@ uno::Sequence< sal_Int32 > const & OCommonEmbeddedObject::GetIntermediateStatesS
 
 
 void SAL_CALL OCommonEmbeddedObject::changeState( sal_Int32 nNewState )
-        throw ( embed::UnreachableStateException,
-                embed::WrongStateException,
-                uno::Exception,
-                uno::RuntimeException, std::exception )
 {
+    ::osl::ResettableMutexGuard aGuard( m_aMutex );
+    if ( m_bDisposed )
+        throw lang::DisposedException(); // TODO
+
+    if ( m_nObjectState == -1 )
+        throw embed::WrongStateException( "The object has no persistence!",
+                                          static_cast< ::cppu::OWeakObject* >(this) );
+
+    sal_Int32 nOldState = m_nObjectState;
+
+    if ( m_nTargetState != -1 )
     {
-        ::osl::ResettableMutexGuard aGuard( m_aMutex );
-        if ( m_bDisposed )
-            throw lang::DisposedException(); // TODO
-
-        if ( m_nObjectState == -1 )
-            throw embed::WrongStateException( "The object has no persistence!",
-                                              static_cast< ::cppu::OWeakObject* >(this) );
-
-        sal_Int32 nOldState = m_nObjectState;
-
-        if ( m_nTargetState != -1 )
-        {
-            // means that the object is currently trying to reach the target state
-            throw embed::StateChangeInProgressException( OUString(),
-                                                        uno::Reference< uno::XInterface >(),
-                                                        m_nTargetState );
-        }
-        else
-        {
-            TargetStateControl_Impl aControl( m_nTargetState, nNewState );
-
-            // in case the object is already in requested state
-            if ( m_nObjectState == nNewState )
-            {
-                // if active object is activated again, bring its window to top
-                if ( m_nObjectState == embed::EmbedStates::ACTIVE )
-                    m_pDocHolder->Show();
-
-                return;
-            }
-
-            // retrieve sequence of states that should be passed to reach desired state
-            uno::Sequence< sal_Int32 > aIntermediateStates = GetIntermediateStatesSequence_Impl( nNewState );
-
-            // notify listeners that the object is going to change the state
-            StateChangeNotification_Impl( true, nOldState, nNewState,aGuard );
-
-            try {
-                for ( sal_Int32 nInd = 0; nInd < aIntermediateStates.getLength(); nInd++ )
-                    SwitchStateTo_Impl( aIntermediateStates[nInd] );
-
-                SwitchStateTo_Impl( nNewState );
-            }
-            catch( const uno::Exception& )
-            {
-                if ( nOldState != m_nObjectState )
-                    // notify listeners that the object has changed the state
-                    StateChangeNotification_Impl( false, nOldState, m_nObjectState, aGuard );
-
-                throw;
-            }
-        }
-
-        // notify listeners that the object has changed the state
-        StateChangeNotification_Impl( false, nOldState, nNewState, aGuard );
-
-        // let the object window be shown
-        if ( nNewState == embed::EmbedStates::UI_ACTIVE || nNewState == embed::EmbedStates::INPLACE_ACTIVE )
-            PostEvent_Impl( "OnVisAreaChanged" );
+        // means that the object is currently trying to reach the target state
+        throw embed::StateChangeInProgressException( OUString(),
+                                                    uno::Reference< uno::XInterface >(),
+                                                    m_nTargetState );
     }
+    else
+    {
+        TargetStateControl_Impl aControl( m_nTargetState, nNewState );
+
+        // in case the object is already in requested state
+        if ( m_nObjectState == nNewState )
+        {
+            // if active object is activated again, bring its window to top
+            if ( m_nObjectState == embed::EmbedStates::ACTIVE )
+                m_xDocHolder->Show();
+
+            return;
+        }
+
+        // retrieve sequence of states that should be passed to reach desired state
+        uno::Sequence< sal_Int32 > aIntermediateStates = GetIntermediateStatesSequence_Impl( nNewState );
+
+        // notify listeners that the object is going to change the state
+        StateChangeNotification_Impl( true, nOldState, nNewState,aGuard );
+
+        try {
+            for ( sal_Int32 nInd = 0; nInd < aIntermediateStates.getLength(); nInd++ )
+                SwitchStateTo_Impl( aIntermediateStates[nInd] );
+
+            SwitchStateTo_Impl( nNewState );
+        }
+        catch( const uno::Exception& )
+        {
+            if ( nOldState != m_nObjectState )
+                // notify listeners that the object has changed the state
+                StateChangeNotification_Impl( false, nOldState, m_nObjectState, aGuard );
+
+            throw;
+        }
+    }
+
+    // notify listeners that the object has changed the state
+    StateChangeNotification_Impl( false, nOldState, nNewState, aGuard );
+
+    // let the object window be shown
+    if ( nNewState == embed::EmbedStates::UI_ACTIVE || nNewState == embed::EmbedStates::INPLACE_ACTIVE )
+        PostEvent_Impl( "OnVisAreaChanged" );
 }
 
 
 uno::Sequence< sal_Int32 > SAL_CALL OCommonEmbeddedObject::getReachableStates()
-        throw ( embed::WrongStateException,
-                uno::RuntimeException, std::exception )
 {
     if ( m_bDisposed )
         throw lang::DisposedException(); // TODO
@@ -502,8 +480,6 @@ uno::Sequence< sal_Int32 > SAL_CALL OCommonEmbeddedObject::getReachableStates()
 
 
 sal_Int32 SAL_CALL OCommonEmbeddedObject::getCurrentState()
-        throw ( embed::WrongStateException,
-                uno::RuntimeException, std::exception )
 {
     if ( m_bDisposed )
         throw lang::DisposedException(); // TODO
@@ -517,11 +493,6 @@ sal_Int32 SAL_CALL OCommonEmbeddedObject::getCurrentState()
 
 
 void SAL_CALL OCommonEmbeddedObject::doVerb( sal_Int32 nVerbID )
-        throw ( lang::IllegalArgumentException,
-                embed::WrongStateException,
-                embed::UnreachableStateException,
-                uno::Exception,
-                uno::RuntimeException, std::exception )
 {
     SolarMutexGuard aSolarGuard;
         //TODO: a gross hack to avoid deadlocks when this is called from the
@@ -564,8 +535,6 @@ void SAL_CALL OCommonEmbeddedObject::doVerb( sal_Int32 nVerbID )
 
 
 uno::Sequence< embed::VerbDescriptor > SAL_CALL OCommonEmbeddedObject::getSupportedVerbs()
-        throw ( embed::WrongStateException,
-                uno::RuntimeException, std::exception )
 {
     if ( m_bDisposed )
         throw lang::DisposedException(); // TODO
@@ -580,8 +549,6 @@ uno::Sequence< embed::VerbDescriptor > SAL_CALL OCommonEmbeddedObject::getSuppor
 
 void SAL_CALL OCommonEmbeddedObject::setClientSite(
                 const uno::Reference< embed::XEmbeddedClient >& xClient )
-        throw ( embed::WrongStateException,
-                uno::RuntimeException, std::exception )
 {
     ::osl::MutexGuard aGuard( m_aMutex );
     if ( m_bDisposed )
@@ -600,8 +567,6 @@ void SAL_CALL OCommonEmbeddedObject::setClientSite(
 
 
 uno::Reference< embed::XEmbeddedClient > SAL_CALL OCommonEmbeddedObject::getClientSite()
-        throw ( embed::WrongStateException,
-                uno::RuntimeException, std::exception )
 {
     if ( m_bDisposed )
         throw lang::DisposedException(); // TODO
@@ -615,9 +580,6 @@ uno::Reference< embed::XEmbeddedClient > SAL_CALL OCommonEmbeddedObject::getClie
 
 
 void SAL_CALL OCommonEmbeddedObject::update()
-        throw ( embed::WrongStateException,
-                uno::Exception,
-                uno::RuntimeException, std::exception )
 {
     ::osl::MutexGuard aGuard( m_aMutex );
     if ( m_bDisposed )
@@ -632,8 +594,6 @@ void SAL_CALL OCommonEmbeddedObject::update()
 
 
 void SAL_CALL OCommonEmbeddedObject::setUpdateMode( sal_Int32 nMode )
-        throw ( embed::WrongStateException,
-                uno::RuntimeException, std::exception )
 {
     ::osl::MutexGuard aGuard( m_aMutex );
     if ( m_bDisposed )
@@ -645,14 +605,12 @@ void SAL_CALL OCommonEmbeddedObject::setUpdateMode( sal_Int32 nMode )
 
     OSL_ENSURE( nMode == embed::EmbedUpdateModes::ALWAYS_UPDATE
                     || nMode == embed::EmbedUpdateModes::EXPLICIT_UPDATE,
-                "Unknown update mode!\n" );
+                "Unknown update mode!" );
     m_nUpdateMode = nMode;
 }
 
 
 sal_Int64 SAL_CALL OCommonEmbeddedObject::getStatus( sal_Int64 )
-        throw ( embed::WrongStateException,
-                uno::RuntimeException, std::exception )
 {
     if ( m_bDisposed )
         throw lang::DisposedException(); // TODO
@@ -662,7 +620,6 @@ sal_Int64 SAL_CALL OCommonEmbeddedObject::getStatus( sal_Int64 )
 
 
 void SAL_CALL OCommonEmbeddedObject::setContainerName( const OUString& sName )
-        throw ( uno::RuntimeException, std::exception )
 {
     ::osl::MutexGuard aGuard( m_aMutex );
     if ( m_bDisposed )
@@ -671,24 +628,24 @@ void SAL_CALL OCommonEmbeddedObject::setContainerName( const OUString& sName )
     m_aContainerName = sName;
 }
 
-css::uno::Reference< css::uno::XInterface > SAL_CALL OCommonEmbeddedObject::getParent() throw (css::uno::RuntimeException, std::exception)
+css::uno::Reference< css::uno::XInterface > SAL_CALL OCommonEmbeddedObject::getParent()
 {
     return m_xParent;
 }
 
-void SAL_CALL OCommonEmbeddedObject::setParent( const css::uno::Reference< css::uno::XInterface >& xParent ) throw (css::lang::NoSupportException, css::uno::RuntimeException, std::exception)
+void SAL_CALL OCommonEmbeddedObject::setParent( const css::uno::Reference< css::uno::XInterface >& xParent )
 {
     m_xParent = xParent;
     if ( m_nObjectState != -1 && m_nObjectState != embed::EmbedStates::LOADED )
     {
-        uno::Reference < container::XChild > xChild( m_pDocHolder->GetComponent(), uno::UNO_QUERY );
+        uno::Reference < container::XChild > xChild( m_xDocHolder->GetComponent(), uno::UNO_QUERY );
         if ( xChild.is() )
             xChild->setParent( xParent );
     }
 }
 
 // XDefaultSizeTransmitter
-void SAL_CALL OCommonEmbeddedObject::setDefaultSize( const css::awt::Size& rSize_100TH_MM ) throw (css::uno::RuntimeException, std::exception)
+void SAL_CALL OCommonEmbeddedObject::setDefaultSize( const css::awt::Size& rSize_100TH_MM )
 {
     //#i103460# charts do not necessaryly have an own size within ODF files, in this case they need to use the size settings from the surrounding frame, which is made available with this method
     m_aDefaultSizeForChart_In_100TH_MM = rSize_100TH_MM;
