@@ -35,8 +35,8 @@
 
 #include <vcl/svapp.hxx>
 
-#include "closepreventer.hxx"
-#include "intercept.hxx"
+#include <closepreventer.hxx>
+#include <intercept.hxx>
 #include "persistence.hxx"
 
 using namespace ::com::sun::star;
@@ -234,7 +234,7 @@ void OCommonEmbeddedObject::LinkInit_Impl(
     {
         ::comphelper::MimeConfigurationHelper aHelper( m_xContext );
         OUString aExportFilterName = aHelper.GetExportFilterFromImportFilter( m_aLinkFilterName );
-        m_bReadOnly = !( aExportFilterName.equals( m_aLinkFilterName ) );
+        m_bReadOnly = aExportFilterName != m_aLinkFilterName;
     }
 
     m_aDocMediaDescriptor = GetValuableArgs_Impl( aMediaDescr, false );
