@@ -43,8 +43,8 @@ public class NativeView extends java.awt.Canvas
      * ctor
      * Does nothing really.
      * We can use our JNI mechanism for an already visible
-     * canvas only. So we overload the method for showing ( "setVisible()" )
-     * and make our intialization there. BUt we try to show an empty clean
+     * canvas only. So we override the method for showing ( "setVisible()" )
+     * and make our initialization there. BUt we try to show an empty clean
      * window till there.
      */
     public NativeView()
@@ -57,14 +57,14 @@ public class NativeView extends java.awt.Canvas
 
 
     /**
-     * Overload this method to make necessary initializations here.
+     * Override this method to make necessary initializations here.
      * ( e.g. get the window handle and necessary system information )
      *
      * Why here?
-     * Because the handle seems to be available for already visible windows
-     * only. So it's the best place to get it. Special helper method
-     * can be called more then ones - but call native code one times only
-     * and safe the handle and the system type on our members maHandle/maSystem!
+     * Because the handle seems to be available for already-visible windows
+     * only. So it's the best place to get it. The special helper method
+     * can be called more than once - but call native code one time only
+     * and save the handle and the system type on our members maHandle/maSystem!
      */
     public void setVisible( boolean bState )
     {
@@ -96,7 +96,7 @@ public class NativeView extends java.awt.Canvas
 
 
     /**
-     * overload paint routine to show provide against
+     * override paint routine to show provide against
      * repaint errors if no office view is really plugged
      * into this canvas.
      * If handle is present - we shouldn't paint anything further.
@@ -123,11 +123,11 @@ public class NativeView extends java.awt.Canvas
      * windows in a java UI container.
      *
      * Note:
-     * Native code for windows register special function pointer to handle
-     * window messages ... But if it doesn't check for an already registered
+     * Native code for Windows registers a special function pointer to handle
+     * window messages... But if it doesn't check for an already-registered
      * instance of this handler it will do it twice and produce a stack overflow
-     * because such method call herself in a never ending loop ...
-     * So we try to use the JNI code one times only and safe already getted
+     * because such method calls itself in a never-ending loop...
+     * So we try to use the JNI code one time only and save already-obtained
      * information inside this class.
      */
     public  native int  getNativeWindowSystemType();
@@ -137,7 +137,7 @@ public class NativeView extends java.awt.Canvas
     {
         if( maHandle == null )
         {
-            maHandle = new Integer( (int )getNativeWindow() );
+            maHandle = Integer.valueOf( (int )getNativeWindow() );
             maSystem = getNativeWindowSystemType();
         }
         return maHandle;
