@@ -17,9 +17,9 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "embeddoc.hxx"
+#include <embeddoc.hxx>
 #include <osl/diagnose.h>
-#include <com/sun/star/frame/XController.hpp>
+#include <o3tl/char16_t2wchar_t.hxx>
 #include <com/sun/star/beans/PropertyValue.hpp>
 
 
@@ -45,10 +45,8 @@ STDMETHODIMP EmbedDocument_Impl::SetHostNames( LPCOLESTR szContainerApp, LPCOLES
     // the code should be ignored for links
     if ( !m_aFileName.getLength() )
     {
-        m_pDocHolder->setTitle(
-            OUString(reinterpret_cast<sal_Unicode const *>(szContainerObj)));
-        m_pDocHolder->setContainerName(
-            OUString(reinterpret_cast<sal_Unicode const *>(szContainerApp)));
+        m_pDocHolder->setTitle(o3tl::toU(szContainerObj));
+        m_pDocHolder->setContainerName(o3tl::toU(szContainerApp));
     }
 
     return S_OK;
@@ -90,8 +88,6 @@ STDMETHODIMP EmbedDocument_Impl::Close( DWORD dwSaveOption )
 
 HRESULT EmbedDocument_Impl::OLENotifyClosing()
 {
-    HRESULT hr = S_OK;
-
     AdviseSinkHashMap aAHM(m_aAdviseHashMap);
 
     for ( AdviseSinkHashMapIterator iAdvise = aAHM.begin();
@@ -101,7 +97,7 @@ HRESULT EmbedDocument_Impl::OLENotifyClosing()
             iAdvise->second->OnClose();
     }
 
-    return hr;
+    return S_OK;
 
 }
 
@@ -422,8 +418,7 @@ HRESULT EmbedDocument_Impl::SaveObject()
 
         // in case of links the containers does not provide client site sometimes
         hr = Save( static_cast<LPCOLESTR>(nullptr), FALSE ); // triggers saving to the link location
-        SaveCompleted(
-            reinterpret_cast<wchar_t const *>(aPreservFileName.getStr()));
+        SaveCompleted(o3tl::toW(aPreservFileName.getStr()));
     }
 
     notify( false );
