@@ -18,13 +18,12 @@
  */
 
 
-#include "abpresid.hrc"
+#include <strings.hrc>
 #include "abptypes.hxx"
-#include "componentmodule.hxx"
+#include <componentmodule.hxx>
 #include "datasourcehandling.hxx"
 #include "addresssettings.hxx"
 
-#include <boost/noncopyable.hpp>
 #include <com/sun/star/beans/XPropertySet.hpp>
 #include <com/sun/star/container/XNameAccess.hpp>
 #include <com/sun/star/frame/XStorable.hpp>
@@ -39,6 +38,8 @@
 #include <com/sun/star/sdbcx/XTablesSupplier.hpp>
 #include <com/sun/star/task/InteractionHandler.hpp>
 #include <com/sun/star/uno/XNamingService.hpp>
+#include <com/sun/star/uri/UriReferenceFactory.hpp>
+#include <com/sun/star/uri/VndSunStarPkgUrlReferenceFactory.hpp>
 
 #include <comphelper/interaction.hxx>
 #include <comphelper/processfactory.hxx>
@@ -56,7 +57,7 @@ namespace
 {
 
 /// Returns the URL of this object shell.
-OUString lcl_getOwnURL(SfxObjectShell* pObjectShell)
+OUString lcl_getOwnURL(SfxObjectShell const * pObjectShell)
 {
     OUString aRet;
 
@@ -64,7 +65,7 @@ OUString lcl_getOwnURL(SfxObjectShell* pObjectShell)
         return aRet;
 
     const INetURLObject& rURLObject = pObjectShell->GetMedium()->GetURLObject();
-    aRet = rURLObject.GetMainURL(INetURLObject::DECODE_WITH_CHARSET);
+    aRet = rURLObject.GetMainURL(INetURLObject::DecodeMechanism::NONE);
     return aRet;
 }
 
@@ -91,7 +92,6 @@ namespace abp
     struct PackageAccessControl { };
 
 
-
     static Reference< XDatabaseContext > lcl_getDataSourceContext( const Reference< XComponentContext >& _rxContext )
     {
         Reference<XDatabaseContext> xContext = DatabaseContext::create(_rxContext);
@@ -109,7 +109,6 @@ namespace abp
         Reference< XDatabaseContext > xContext = lcl_getDataSourceContext( _rxContext );
 
         DBG_ASSERT( !xContext->hasByName( _rName ), "lcl_implCreateAndInsert: name already used!" );
-        (void)_rName;
 
 
         // create a new data source
@@ -181,7 +180,7 @@ namespace abp
         }
     }
 
-    struct ODataSourceContextImpl: private boost::noncopyable
+    struct ODataSourceContextImpl
     {
         Reference< XComponentContext >      xORB;
         Reference< XNameAccess >            xContext;           /// the UNO data source context
@@ -191,6 +190,8 @@ namespace abp
             : xORB(_rxORB)
         {
         }
+        ODataSourceContextImpl(const ODataSourceContextImpl&) = delete;
+        ODataSourceContextImpl& operator=(const ODataSourceContextImpl&) = delete;
     };
 
     ODataSourceContext::ODataSourceContext(const Reference< XComponentContext >& _rxORB)
@@ -222,7 +223,7 @@ namespace abp
     }
 
 
-    OUString& ODataSourceContext::disambiguate(OUString& _rDataSourceName)
+    void ODataSourceContext::disambiguate(OUString& _rDataSourceName)
     {
         OUString sCheck( _rDataSourceName );
         StringBag::const_iterator aPos = m_pImpl->aDataSourceNames.find( sCheck );
@@ -237,7 +238,6 @@ namespace abp
         }
 
         _rDataSourceName = sCheck;
-        return _rDataSourceName;
     }
 
 
@@ -300,56 +300,43 @@ namespace abp
         ::utl::SharedUNOComponent< XConnection >
                                                 xConnection;
         StringBag                               aTables;            // the cached table names
-        OUString                         sName;
-        bool                                bTablesUpToDate;    // table name cache up-to-date?
+        OUString                                sName;
 
         explicit ODataSourceImpl(const Reference< XComponentContext >& _rxORB)
             : xORB(_rxORB)
-            , bTablesUpToDate(false)
         {
         }
-
-        ODataSourceImpl( const ODataSourceImpl& _rSource );
     };
 
 
-    ODataSourceImpl::ODataSourceImpl( const ODataSourceImpl& _rSource )
-        :xORB( _rSource.xORB )
-        ,xDataSource( _rSource.xDataSource )
-        ,xConnection( _rSource.xConnection )
-        ,aTables( _rSource.aTables )
-        ,sName( _rSource.sName )
-        ,bTablesUpToDate( _rSource.bTablesUpToDate )
-    {
-    }
-
     ODataSource::ODataSource( const ODataSource& _rSource )
         :m_pImpl( nullptr )
     {
         *this = _rSource;
     }
 
-
     ODataSource& ODataSource::operator=( const ODataSource& _rSource )
     {
         if( this != &_rSource )
         {
-            delete m_pImpl;
-            m_pImpl = new ODataSourceImpl( *_rSource.m_pImpl );
+            m_pImpl.reset( new ODataSourceImpl( *_rSource.m_pImpl ) );
         }
         return *this;
     }
 
+    ODataSource& ODataSource::operator=( ODataSource&& _rSource )
+    {
+        m_pImpl = std::move(_rSource.m_pImpl);
+        return *this;
+    }
 
     ODataSource::ODataSource( const Reference< XComponentContext >& _rxORB )
         :m_pImpl(new ODataSourceImpl(_rxORB))
     {
     }
 
-
     ODataSource::~ODataSource( )
     {
-        delete m_pImpl;
     }
 
     void ODataSource::store(const AddressSettings& rSettings)
@@ -366,8 +353,9 @@ namespace abp
             OSL_ENSURE( xStorable.is(),"DataSource is no XStorable!" );
             if ( xStorable.is() )
             {
-                SfxObjectShell* pObjectShell = SfxViewFrame::Current()->GetObjectShell();
-                OUString aOwnURL = lcl_getOwnURL(pObjectShell);
+                SfxViewFrame* pFrame = SfxViewFrame::Current();
+                SfxObjectShell* pObjectShell = pFrame ? pFrame->GetObjectShell() : nullptr;
+                OUString aOwnURL = lcl_getOwnURL(pObjectShell); // empty if pObjectShell is nullptr
                 if (aOwnURL.isEmpty() || !rSettings.bEmbedDataSource)
                 {
                     // Cannot or should not embed.
@@ -377,9 +365,13 @@ namespace abp
                 {
                     // Embed.
                     OUString aStreamRelPath = "EmbeddedDatabase";
-                    OUString sTmpName = "vnd.sun.star.pkg://";
-                    sTmpName += INetURLObject::encode(aOwnURL, INetURLObject::PART_AUTHORITY, INetURLObject::ENCODE_ALL);
-                    sTmpName += "/" + aStreamRelPath;
+                    auto xContext(comphelper::getProcessComponentContext());
+                    auto xUri = css::uri::UriReferenceFactory::create(xContext)->parse(aOwnURL);
+                    assert(xUri.is());
+                    xUri = css::uri::VndSunStarPkgUrlReferenceFactory::create(xContext)->createVndSunStarPkgUrlReference(xUri);
+                    assert(xUri.is());
+                    OUString const sTmpName = xUri->getUriReference() + "/" + aStreamRelPath;
+                    assert(pObjectShell);
                     uno::Reference<embed::XStorage> xStorage = pObjectShell->GetStorage();
                     uno::Sequence<beans::PropertyValue> aSequence = comphelper::InitPropertySequence(
                     {
@@ -518,7 +510,6 @@ namespace abp
         }
 
         // now the table cache is up-to-date
-        m_pImpl->bTablesUpToDate = true;
         return m_pImpl->aTables;
     }
 
@@ -546,9 +537,8 @@ namespace abp
         // failure to create the interaction handler is a serious issue ...
         if (!xInteractions.is())
         {
-            OUString s_sInteractionHandlerServiceName("com.sun.star.task.InteractionHandler");
             if ( _pMessageParent )
-                ShowServiceNotAvailableError( _pMessageParent, s_sInteractionHandlerServiceName, true );
+                ShowServiceNotAvailableError( _pMessageParent, "com.sun.star.task.InteractionHandler", true );
             return false;
         }
 
@@ -583,8 +573,8 @@ namespace abp
                   {
                     // prepend some context info
                     SQLContext aDetailedError;
-                    aDetailedError.Message = ModuleRes(RID_STR_NOCONNECTION).toString();
-                    aDetailedError.Details = ModuleRes(RID_STR_PLEASECHECKSETTINGS).toString();
+                    aDetailedError.Message = compmodule::ModuleRes(RID_STR_NOCONNECTION);
+                    aDetailedError.Details = compmodule::ModuleRes(RID_STR_PLEASECHECKSETTINGS);
                     aDetailedError.NextException = aError;
                     // handle (aka display) the new context info
                     xInteractions->handle( new OInteractionRequest( makeAny( aDetailedError ) ) );
@@ -608,7 +598,6 @@ namespace abp
         // success
         m_pImpl->xConnection.reset( xConnection );
         m_pImpl->aTables.clear();
-        m_pImpl->bTablesUpToDate = false;
 
         return true;
     }
@@ -618,7 +607,6 @@ namespace abp
     {
         m_pImpl->xConnection.clear();
         m_pImpl->aTables.clear();
-        m_pImpl->bTablesUpToDate = false;
     }
 
 
