@@ -66,12 +66,11 @@ namespace abp
         // - MORK, THUNDERBIRD
         // - OTHER
 
+#if !defined(_WIN32)
         bool bHaveEvolution = false;
         bool bHaveKab = false;
         bool bHaveMacab = false;
 
-#if !defined(_WIN32)
-
         Reference< XDriverManager2 > xManager = DriverManager::create( _pParent->getORB() );
 
         try
@@ -106,7 +105,10 @@ namespace abp
         catch(...)
         {
         }
-
+#else
+        bool const bHaveEvolution = false;
+        bool const bHaveKab = false;
+        bool const bHaveMacab = false;
 #endif
 
         // Items are displayed in list order
@@ -226,7 +228,7 @@ namespace abp
 
         if (AST_INVALID == getSelectedType( ))
         {
-            ScopedVclPtrInstance< MessageDialog > aError(this, ModuleRes(RID_STR_NEEDTYPESELECTION));
+            ScopedVclPtrInstance< MessageDialog > aError(this, compmodule::ModuleRes(RID_STR_NEEDTYPESELECTION));
             aError->Execute();
             return false;
         }
