@@ -17,7 +17,9 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include <osl/mutex.hxx>
+#include <sal/config.h>
+
+#include <o3tl/any.hxx>
 #include <sal/log.hxx>
 #include <tools/diagnose_ex.h>
 #include <comphelper/processfactory.hxx>
@@ -62,14 +64,13 @@
 #include "bibresid.hxx"
 #include "bibmod.hxx"
 #include "bibview.hxx"
-#include "bibprop.hrc"
+#include "bibprop.hxx"
 #include "toolbar.hxx"
-#include "toolbar.hrc"
 #include "bibconfig.hxx"
 #include "bibbeam.hxx"
 #include "general.hxx"
-#include "bib.hrc"
-#include "bibliography.hrc"
+#include <strings.hrc>
+#include <helpids.h>
 #include <connectivity/dbtools.hxx>
 #include <memory>
 
@@ -108,7 +109,6 @@ Reference< XConnection > getConnection(const OUString& _rURL)
     if (xDataSource.is())
     {
         // need user/pwd for this
-        Reference< XPropertySet >  xDataSourceProps(xDataSource, UNO_QUERY);
         Reference< XCompletedConnection > xComplConn(xDataSource, UNO_QUERY);
         try
         {
@@ -135,7 +135,7 @@ Reference< XConnection >    getConnection(const Reference< XInterface > & xRowSe
         if (!xFormProps.is())
             return xConn;
 
-        xConn.set(*static_cast<Reference< XInterface > const *>(xFormProps->getPropertyValue("ActiveConnection").getValue()), UNO_QUERY);
+        xConn.set(xFormProps->getPropertyValue("ActiveConnection"), UNO_QUERY);
         if (!xConn.is())
         {
             SAL_INFO("extensions.biblio", "no active connection");
@@ -167,26 +167,19 @@ Reference< XNameAccess >  getColumns(const Reference< XForm > & _rxForm)
         {
             try
             {
-                DBG_ASSERT((*static_cast<sal_Int32 const *>(xFormProps->getPropertyValue("CommandType").getValue())) == CommandType::TABLE,
+                DBG_ASSERT(*o3tl::forceAccess<sal_Int32>(xFormProps->getPropertyValue("CommandType")) == CommandType::TABLE,
                     "::getColumns : invalid form (has no table as data source) !");
                 OUString sTable;
                 xFormProps->getPropertyValue("Command") >>= sTable;
                 Reference< XNameAccess >  xTables = xSupplyTables->getTables();
                 if (xTables.is() && xTables->hasByName(sTable))
-                    xSupplyCols.set(
-                        *static_cast<Reference< XInterface > const *>(xTables->getByName(sTable).getValue()), UNO_QUERY);
+                    xSupplyCols.set(xTables->getByName(sTable), UNO_QUERY);
                 if (xSupplyCols.is())
                     xReturn = xSupplyCols->getColumns();
             }
             catch (const Exception& e)
             {
-#ifdef DBG_UTIL
-                OUString sMsg( "::getColumns : catched an exception (" + e.Message + ") ..." );
-
-                OSL_FAIL(OUStringToOString(sMsg, RTL_TEXTENCODING_ASCII_US ).getStr());
-#else
-                (void)e;
-#endif
+                SAL_WARN( "extensions.biblio", "::getColumns : caught an exception. " << e);
             }
 
         }
@@ -235,21 +228,17 @@ class MappingDialog_Impl : public ModalDialog
     bool        bModified;
 
 
-
-    DECL_LINK_TYPED(OkHdl, Button*, void);
-    DECL_LINK_TYPED(ListBoxSelectHdl, ListBox&, void);
+    DECL_LINK(OkHdl, Button*, void);
+    DECL_LINK(ListBoxSelectHdl, ListBox&, void);
 
 public:
     MappingDialog_Impl(vcl::Window* pParent, BibDataManager* pDatMan);
-    virtual ~MappingDialog_Impl();
+    virtual ~MappingDialog_Impl() override;
     virtual void dispose() override;
-
-    void    SetModified() {bModified = true;}
-
 };
 
-static sal_uInt16 lcl_FindLogicalName(BibConfig* pConfig ,
-                                    const OUString& rLogicalColumnName)
+static sal_uInt16 lcl_FindLogicalName(BibConfig const * pConfig ,
+                                      const OUString& rLogicalColumnName)
 {
     for(sal_uInt16 i = 0; i < COLUMN_COUNT; i++)
     {
@@ -262,7 +251,7 @@ static sal_uInt16 lcl_FindLogicalName(BibConfig* pConfig ,
 MappingDialog_Impl::MappingDialog_Impl(vcl::Window* pParent, BibDataManager* pMan)
     : ModalDialog(pParent, "MappingDialog", "modules/sbibliography/ui/mappingdialog.ui")
     , pDatMan(pMan)
-    , sNone(BIB_RESSTR(RID_BIB_STR_NONE))
+    , sNone(BibResId(RID_BIB_STR_NONE))
     , bModified(false)
 {
     get(pOKBT, "ok");
@@ -367,12 +356,12 @@ MappingDialog_Impl::MappingDialog_Impl(vcl::Window* pParent, BibDataManager* pMa
     const Mapping* pMapping = pConfig->GetMapping(aDesc);
     if(pMapping)
     {
-        for(sal_uInt16 nEntry = 0; nEntry < COLUMN_COUNT; nEntry++)
+        for(const auto & aColumnPair : pMapping->aColumnPairs)
         {
-            sal_uInt16 nListBoxIndex = lcl_FindLogicalName( pConfig, pMapping->aColumnPairs[nEntry].sLogicalColumnName);
+            sal_uInt16 nListBoxIndex = lcl_FindLogicalName( pConfig, aColumnPair.sLogicalColumnName);
             if(nListBoxIndex < COLUMN_COUNT)
             {
-                aListBoxes[nListBoxIndex]->SelectEntry(pMapping->aColumnPairs[nEntry].sRealColumnName);
+                aListBoxes[nListBoxIndex]->SelectEntry(aColumnPair.sRealColumnName);
             }
         }
     }
@@ -422,21 +411,21 @@ void MappingDialog_Impl::dispose()
     ModalDialog::dispose();
 }
 
-IMPL_LINK_TYPED(MappingDialog_Impl, ListBoxSelectHdl, ListBox&, rListBox, void)
+IMPL_LINK(MappingDialog_Impl, ListBoxSelectHdl, ListBox&, rListBox, void)
 {
-    const sal_Int32 nEntryPos = rListBox.GetSelectEntryPos();
+    const sal_Int32 nEntryPos = rListBox.GetSelectedEntryPos();
     if(0 < nEntryPos)
     {
-        for(sal_uInt16 i = 0; i < COLUMN_COUNT; i++)
+        for(VclPtr<ListBox> & aListBoxe : aListBoxes)
         {
-            if(&rListBox != aListBoxes[i] && aListBoxes[i]->GetSelectEntryPos() == nEntryPos)
-                aListBoxes[i]->SelectEntryPos(0);
+            if(&rListBox != aListBoxe && aListBoxe->GetSelectedEntryPos() == nEntryPos)
+                aListBoxe->SelectEntryPos(0);
         }
     }
-    SetModified();
+    bModified = true;
 }
 
-IMPL_LINK_NOARG_TYPED(MappingDialog_Impl, OkHdl, Button*, void)
+IMPL_LINK_NOARG(MappingDialog_Impl, OkHdl, Button*, void)
 {
     if(bModified)
     {
@@ -448,7 +437,7 @@ IMPL_LINK_NOARG_TYPED(MappingDialog_Impl, OkHdl, Button*, void)
         BibConfig* pConfig = BibModul::GetConfig();
         for(sal_uInt16 nEntry = 0; nEntry < COLUMN_COUNT; nEntry++)
         {
-            OUString sSel = aListBoxes[nEntry]->GetSelectEntry();
+            OUString sSel = aListBoxes[nEntry]->GetSelectedEntry();
             if(sSel != sNone)
             {
                 aNew.aColumnPairs[nWriteIndex].sRealColumnName = sSel;
@@ -473,10 +462,10 @@ class DBChangeDialog_Impl : public ModalDialog
 
     BibDataManager* pDatMan;
 
-    DECL_LINK_TYPED(DoubleClickHdl, ListBox&, void);
+    DECL_LINK(DoubleClickHdl, ListBox&, void);
 public:
     DBChangeDialog_Impl(vcl::Window* pParent, BibDataManager* pMan );
-    virtual ~DBChangeDialog_Impl();
+    virtual ~DBChangeDialog_Impl() override;
     virtual void dispose() override;
 
     OUString     GetCurrentURL()const;
@@ -508,11 +497,11 @@ DBChangeDialog_Impl::DBChangeDialog_Impl(vcl::Window* pParent, BibDataManager* p
     {
         SAL_WARN("extensions.biblio",
             "Exception in BibDataManager::DBChangeDialog_Impl::DBChangeDialog_Impl "
-            << e.Message);
+            << e);
     }
 }
 
-IMPL_LINK_NOARG_TYPED(DBChangeDialog_Impl, DoubleClickHdl, ListBox&, void)
+IMPL_LINK_NOARG(DBChangeDialog_Impl, DoubleClickHdl, ListBox&, void)
 {
     EndDialog(RET_OK);
 }
@@ -530,11 +519,11 @@ void DBChangeDialog_Impl::dispose()
 
 OUString  DBChangeDialog_Impl::GetCurrentURL()const
 {
-    return m_pSelectionLB->GetSelectEntry();
+    return m_pSelectionLB->GetSelectedEntry();
 }
 
 // XDispatchProvider
-BibInterceptorHelper::BibInterceptorHelper( ::bib::BibBeamer* pBibBeamer, css::uno::Reference< css::frame::XDispatch > xDispatch)
+BibInterceptorHelper::BibInterceptorHelper( ::bib::BibBeamer* pBibBeamer, css::uno::Reference< css::frame::XDispatch > const & xDispatch)
 {
     if( pBibBeamer )
     {
@@ -558,7 +547,7 @@ void BibInterceptorHelper::ReleaseInterceptor()
 }
 
 css::uno::Reference< css::frame::XDispatch > SAL_CALL
-    BibInterceptorHelper::queryDispatch( const css::util::URL& aURL, const OUString& aTargetFrameName, sal_Int32 nSearchFlags ) throw (css::uno::RuntimeException, std::exception)
+    BibInterceptorHelper::queryDispatch( const css::util::URL& aURL, const OUString& aTargetFrameName, sal_Int32 nSearchFlags )
 {
     Reference< XDispatch > xReturn;
 
@@ -573,7 +562,7 @@ css::uno::Reference< css::frame::XDispatch > SAL_CALL
 }
 
 css::uno::Sequence< css::uno::Reference< css::frame::XDispatch > > SAL_CALL
-    BibInterceptorHelper::queryDispatches( const css::uno::Sequence< css::frame::DispatchDescriptor >& aDescripts ) throw (css::uno::RuntimeException, std::exception)
+    BibInterceptorHelper::queryDispatches( const css::uno::Sequence< css::frame::DispatchDescriptor >& aDescripts )
 {
     Sequence< Reference< XDispatch> > aReturn( aDescripts.getLength() );
     Reference< XDispatch >* pReturn = aReturn.getArray();
@@ -587,38 +576,37 @@ css::uno::Sequence< css::uno::Reference< css::frame::XDispatch > > SAL_CALL
 
 // XDispatchProviderInterceptor
 css::uno::Reference< css::frame::XDispatchProvider > SAL_CALL
-    BibInterceptorHelper::getSlaveDispatchProvider(  ) throw (css::uno::RuntimeException, std::exception)
+    BibInterceptorHelper::getSlaveDispatchProvider(  )
 {
     return xSlaveDispatchProvider;
 }
 
-void SAL_CALL BibInterceptorHelper::setSlaveDispatchProvider( const css::uno::Reference< css::frame::XDispatchProvider >& xNewSlaveDispatchProvider ) throw (css::uno::RuntimeException, std::exception)
+void SAL_CALL BibInterceptorHelper::setSlaveDispatchProvider( const css::uno::Reference< css::frame::XDispatchProvider >& xNewSlaveDispatchProvider )
 {
     xSlaveDispatchProvider = xNewSlaveDispatchProvider;
 }
 
 css::uno::Reference< css::frame::XDispatchProvider > SAL_CALL
-    BibInterceptorHelper::getMasterDispatchProvider(  ) throw (css::uno::RuntimeException, std::exception)
+    BibInterceptorHelper::getMasterDispatchProvider(  )
 {
     return xMasterDispatchProvider;
 }
 
-void SAL_CALL BibInterceptorHelper::setMasterDispatchProvider( const css::uno::Reference< css::frame::XDispatchProvider >& xNewMasterDispatchProvider ) throw (css::uno::RuntimeException, std::exception)
+void SAL_CALL BibInterceptorHelper::setMasterDispatchProvider( const css::uno::Reference< css::frame::XDispatchProvider >& xNewMasterDispatchProvider )
 {
     xMasterDispatchProvider = xNewMasterDispatchProvider;
 }
 
 
 #define STR_UID "uid"
-OUString gGridName("theGrid");
-OUString gViewName("theView");
-OUString gGlobalName("theGlobals");
-OUString gBeamerSize("theBeamerSize");
-OUString gViewSize("theViewSize");
+OUString const gGridName("theGrid");
+OUString const gViewName("theView");
+OUString const gGlobalName("theGlobals");
+OUString const gBeamerSize("theBeamerSize");
+OUString const gViewSize("theViewSize");
 
 BibDataManager::BibDataManager()
     :BibDataManager_Base( GetMutex() )
-    ,m_pInterceptorHelper( nullptr )
     ,m_aLoadListeners(m_aMutex)
     ,pBibView( nullptr )
     ,pToolbar(nullptr)
@@ -644,11 +632,10 @@ BibDataManager::~BibDataManager()
             xConnection->dispose();
         m_xForm = nullptr;
     }
-    if( m_pInterceptorHelper )
+    if( m_xInterceptorHelper.is() )
     {
-        m_pInterceptorHelper->ReleaseInterceptor();
-        m_pInterceptorHelper->release();
-        m_pInterceptorHelper = nullptr;
+        m_xInterceptorHelper->ReleaseInterceptor();
+        m_xInterceptorHelper.clear();
     }
 }
 
@@ -690,7 +677,7 @@ void BibDataManager::InsertFields(const Reference< XFormComponent > & _rxGrid)
             const OUString sType("Type");
             sal_Int32 nType = 0;
             bool bIsFormatted           = false;
-            sal_Bool bFormattedIsNumeric    = sal_True;
+            bool bFormattedIsNumeric    = true;
             xField->getPropertyValue(sType) >>= nType;
             switch(nType)
             {
@@ -710,8 +697,8 @@ void BibDataManager::InsertFields(const Reference< XFormComponent > & _rxGrid)
                 case DataType::LONGVARCHAR:
                 case DataType::CHAR:
                 case DataType::CLOB:
-                    bFormattedIsNumeric = sal_False;
-                    // _NO_ break !
+                    bFormattedIsNumeric = false;
+                    SAL_FALLTHROUGH;
                 default:
                     sCurrentModelType = "FormattedField";
                     bIsFormatted = true;
@@ -723,7 +710,7 @@ void BibDataManager::InsertFields(const Reference< XFormComponent > & _rxGrid)
             {
                 OUString sFormatKey("FormatKey");
                 xCurrentCol->setPropertyValue(sFormatKey, xField->getPropertyValue(sFormatKey));
-                Any aFormatted(&bFormattedIsNumeric, cppu::UnoType<bool>::get());
+                Any aFormatted(bFormattedIsNumeric);
                 xCurrentCol->setPropertyValue("TreatAsNumber", aFormatted);
             }
             Any aColName = makeAny( *pFields );
@@ -744,7 +731,7 @@ Reference< awt::XControlModel > BibDataManager::updateGridModel()
     return updateGridModel( m_xForm );
 }
 
-Reference< awt::XControlModel > BibDataManager::updateGridModel(const Reference< XForm > & xDbForm)
+Reference< awt::XControlModel > const & BibDataManager::updateGridModel(const Reference< XForm > & xDbForm)
 {
     try
     {
@@ -834,7 +821,7 @@ Reference< XForm >  BibDataManager::createDatabaseForm(BibDBDescriptor& rDesc)
                 OUString aString("SELECT * FROM ");
 
                 OUString sCatalog, sSchema, sName;
-                ::dbtools::qualifiedNameComponents( xMetaData, aActiveDataTable, sCatalog, sSchema, sName, ::dbtools::eInDataManipulation );
+                ::dbtools::qualifiedNameComponents( xMetaData, aActiveDataTable, sCatalog, sSchema, sName, ::dbtools::EComposeRule::InDataManipulation );
                 aString += ::dbtools::composeTableNameForSelect( xConnection, sCatalog, sSchema, sName );
 
                 m_xParser->setElementaryQuery(aString);
@@ -886,7 +873,7 @@ void BibDataManager::setFilter(const OUString& rQuery)
         OUString aQuery = m_xParser->getFilter();
         Reference< XPropertySet >  xFormProps( m_xForm, UNO_QUERY_THROW );
         xFormProps->setPropertyValue( "Filter", makeAny( aQuery ) );
-        xFormProps->setPropertyValue( "ApplyFilter", makeAny( sal_True ) );
+        xFormProps->setPropertyValue( "ApplyFilter", makeAny( true ) );
         reload();
     }
     catch (const Exception&)
@@ -1013,7 +1000,7 @@ void BibDataManager::setActiveDataSource(const OUString& rURL)
             aQuoteChar = xMetaData->getIdentifierQuoteString();
 
             OUString sCatalog, sSchema, sName;
-            ::dbtools::qualifiedNameComponents( xMetaData, aActiveDataTable, sCatalog, sSchema, sName, ::dbtools::eInDataManipulation );
+            ::dbtools::qualifiedNameComponents( xMetaData, aActiveDataTable, sCatalog, sSchema, sName, ::dbtools::EComposeRule::InDataManipulation );
             aString += ::dbtools::composeTableNameForSelect( xConnection, sCatalog, sSchema, sName );
 
             m_xParser->setElementaryQuery(aString);
@@ -1024,11 +1011,11 @@ void BibDataManager::setActiveDataSource(const OUString& rURL)
         }
         FeatureStateEvent aEvent;
         util::URL aURL;
-        aEvent.IsEnabled  = sal_True;
-        aEvent.Requery    = sal_False;
+        aEvent.IsEnabled  = true;
+        aEvent.Requery    = false;
         aEvent.FeatureDescriptor = getActiveDataTable();
 
-        aEvent.State = makeAny( getDataSources() );
+        aEvent.State <<= getDataSources();
 
         if(pToolbar)
         {
@@ -1083,7 +1070,7 @@ void BibDataManager::setActiveDataTable(const OUString& rTable)
                 OUString aString("SELECT * FROM ");
 
                 OUString sCatalog, sSchema, sName;
-                ::dbtools::qualifiedNameComponents( xMetaData, aActiveDataTable, sCatalog, sSchema, sName, ::dbtools::eInDataManipulation );
+                ::dbtools::qualifiedNameComponents( xMetaData, aActiveDataTable, sCatalog, sSchema, sName, ::dbtools::EComposeRule::InDataManipulation );
                 aString += ::dbtools::composeTableNameForSelect( xConnection, sCatalog, sSchema, sName );
 
                 m_xParser->setElementaryQuery(aString);
@@ -1107,7 +1094,7 @@ void BibDataManager::setActiveDataTable(const OUString& rTable)
 }
 
 
-void SAL_CALL BibDataManager::load(  ) throw (RuntimeException, std::exception)
+void SAL_CALL BibDataManager::load(  )
 {
     if ( isLoaded() )
         // nothing to do
@@ -1126,7 +1113,7 @@ void SAL_CALL BibDataManager::load(  ) throw (RuntimeException, std::exception)
 }
 
 
-void SAL_CALL BibDataManager::unload(  ) throw (RuntimeException, std::exception)
+void SAL_CALL BibDataManager::unload(  )
 {
     if ( !isLoaded() )
         // nothing to do
@@ -1152,7 +1139,7 @@ void SAL_CALL BibDataManager::unload(  ) throw (RuntimeException, std::exception
 }
 
 
-void SAL_CALL BibDataManager::reload(  ) throw (RuntimeException, std::exception)
+void SAL_CALL BibDataManager::reload(  )
 {
     if ( !isLoaded() )
         // nothing to do
@@ -1177,7 +1164,7 @@ void SAL_CALL BibDataManager::reload(  ) throw (RuntimeException, std::exception
 }
 
 
-sal_Bool SAL_CALL BibDataManager::isLoaded(  ) throw (RuntimeException, std::exception)
+sal_Bool SAL_CALL BibDataManager::isLoaded(  )
 {
     Reference< XLoadable >xFormAsLoadable( m_xForm, UNO_QUERY );
     DBG_ASSERT( xFormAsLoadable.is() || !m_xForm.is(), "BibDataManager::isLoaded: invalid form!");
@@ -1189,13 +1176,13 @@ sal_Bool SAL_CALL BibDataManager::isLoaded(  ) throw (RuntimeException, std::exc
 }
 
 
-void SAL_CALL BibDataManager::addLoadListener( const Reference< XLoadListener >& aListener ) throw (RuntimeException, std::exception)
+void SAL_CALL BibDataManager::addLoadListener( const Reference< XLoadListener >& aListener )
 {
     m_aLoadListeners.addInterface( aListener );
 }
 
 
-void SAL_CALL BibDataManager::removeLoadListener( const Reference< XLoadListener >& aListener ) throw (RuntimeException, std::exception)
+void SAL_CALL BibDataManager::removeLoadListener( const Reference< XLoadListener >& aListener )
 {
     m_aLoadListeners.removeInterface( aListener );
 }
@@ -1217,8 +1204,7 @@ Reference< awt::XControlModel > BibDataManager::createGridModel(const OUString&
         xPropSet->setPropertyValue( "Name", makeAny( rName ) );
 
         // set the name of the to-be-created control
-        OUString aControlName("com.sun.star.form.control.InteractionGridControl");
-        Any aAny; aAny <<= aControlName;
+        Any aAny(OUString("com.sun.star.form.control.InteractionGridControl"));
         xPropSet->setPropertyValue( "DefaultControl",aAny );
 
         // the helpURL
@@ -1297,7 +1283,6 @@ Reference< awt::XControlModel > BibDataManager::loadControlModel(
         {
             aElement = xFields->getByName(rName);
             aElement >>= xField;
-            Reference< XPropertySetInfo >  xInfo = xField.is() ? xField->getPropertySetInfo() : Reference< XPropertySetInfo > ();
 
             const OUString sType("Type");
             sal_Int32 nFormatKey = 0;
@@ -1327,8 +1312,7 @@ Reference< awt::XControlModel > BibDataManager::loadControlModel(
                 //uno::Reference< beans::XPropertySet >  xPropSet(xControl, UNO_QUERY);
                 aAny <<= (sal_Int16)1;
                 xPropSet->setPropertyValue("BoundColumn", aAny);
-                ListSourceType eSet = ListSourceType_VALUELIST;
-                aAny.setValue( &eSet, ::cppu::UnoType<ListSourceType>::get() );
+                aAny <<= ListSourceType_VALUELIST;
                 xPropSet->setPropertyValue("ListSourceType", aAny);
 
                 uno::Sequence<OUString> aListSource(TYPE_COUNT);
@@ -1336,44 +1320,42 @@ Reference< awt::XControlModel > BibDataManager::loadControlModel(
                 //pListSourceArr[0] = "select TypeName, TypeIndex from TypeNms";
                 for(sal_Int32 i = 0; i < TYPE_COUNT; ++i)
                     pListSourceArr[i] = OUString::number(i);
-                aAny.setValue(&aListSource, cppu::UnoType<uno::Sequence<OUString>>::get());
+                aAny <<= aListSource;
 
                 xPropSet->setPropertyValue("ListSource", aAny);
 
                 uno::Sequence<OUString> aValues(TYPE_COUNT + 1);
                 OUString* pValuesArr = aValues.getArray();
-                pValuesArr[0] = BIB_RESSTR(ST_TYPE_ARTICLE);
-                pValuesArr[1] = BIB_RESSTR(ST_TYPE_BOOK);
-                pValuesArr[2] = BIB_RESSTR(ST_TYPE_BOOKLET);
-                pValuesArr[3] = BIB_RESSTR(ST_TYPE_CONFERENCE);
-                pValuesArr[4] = BIB_RESSTR(ST_TYPE_INBOOK );
-                pValuesArr[5] = BIB_RESSTR(ST_TYPE_INCOLLECTION);
-                pValuesArr[6] = BIB_RESSTR(ST_TYPE_INPROCEEDINGS);
-                pValuesArr[7] = BIB_RESSTR(ST_TYPE_JOURNAL       );
-                pValuesArr[8] = BIB_RESSTR(ST_TYPE_MANUAL    );
-                pValuesArr[9] = BIB_RESSTR(ST_TYPE_MASTERSTHESIS);
-                pValuesArr[10] = BIB_RESSTR(ST_TYPE_MISC      );
-                pValuesArr[11] = BIB_RESSTR(ST_TYPE_PHDTHESIS );
-                pValuesArr[12] = BIB_RESSTR(ST_TYPE_PROCEEDINGS   );
-                pValuesArr[13] = BIB_RESSTR(ST_TYPE_TECHREPORT    );
-                pValuesArr[14] = BIB_RESSTR(ST_TYPE_UNPUBLISHED   );
-                pValuesArr[15] = BIB_RESSTR(ST_TYPE_EMAIL     );
-                pValuesArr[16] = BIB_RESSTR(ST_TYPE_WWW           );
-                pValuesArr[17] = BIB_RESSTR(ST_TYPE_CUSTOM1       );
-                pValuesArr[18] = BIB_RESSTR(ST_TYPE_CUSTOM2       );
-                pValuesArr[19] = BIB_RESSTR(ST_TYPE_CUSTOM3       );
-                pValuesArr[20] = BIB_RESSTR(ST_TYPE_CUSTOM4       );
-                pValuesArr[21] = BIB_RESSTR(ST_TYPE_CUSTOM5       );
+                pValuesArr[0] = BibResId(ST_TYPE_ARTICLE);
+                pValuesArr[1] = BibResId(ST_TYPE_BOOK);
+                pValuesArr[2] = BibResId(ST_TYPE_BOOKLET);
+                pValuesArr[3] = BibResId(ST_TYPE_CONFERENCE);
+                pValuesArr[4] = BibResId(ST_TYPE_INBOOK );
+                pValuesArr[5] = BibResId(ST_TYPE_INCOLLECTION);
+                pValuesArr[6] = BibResId(ST_TYPE_INPROCEEDINGS);
+                pValuesArr[7] = BibResId(ST_TYPE_JOURNAL       );
+                pValuesArr[8] = BibResId(ST_TYPE_MANUAL    );
+                pValuesArr[9] = BibResId(ST_TYPE_MASTERSTHESIS);
+                pValuesArr[10] = BibResId(ST_TYPE_MISC      );
+                pValuesArr[11] = BibResId(ST_TYPE_PHDTHESIS );
+                pValuesArr[12] = BibResId(ST_TYPE_PROCEEDINGS   );
+                pValuesArr[13] = BibResId(ST_TYPE_TECHREPORT    );
+                pValuesArr[14] = BibResId(ST_TYPE_UNPUBLISHED   );
+                pValuesArr[15] = BibResId(ST_TYPE_EMAIL     );
+                pValuesArr[16] = BibResId(ST_TYPE_WWW           );
+                pValuesArr[17] = BibResId(ST_TYPE_CUSTOM1       );
+                pValuesArr[18] = BibResId(ST_TYPE_CUSTOM2       );
+                pValuesArr[19] = BibResId(ST_TYPE_CUSTOM3       );
+                pValuesArr[20] = BibResId(ST_TYPE_CUSTOM4       );
+                pValuesArr[21] = BibResId(ST_TYPE_CUSTOM5       );
                 // empty string if an invalid value no values is set
                 pValuesArr[TYPE_COUNT].clear();
 
-                aAny.setValue(&aValues, cppu::UnoType<uno::Sequence<OUString>>::get());
+                aAny <<= aValues;
 
                 xPropSet->setPropertyValue("StringItemList", aAny);
 
-                sal_Bool bTrue = sal_True;
-                aAny.setValue( &bTrue, cppu::UnoType<bool>::get() );
-                xPropSet->setPropertyValue( "Dropdown", aAny );
+                xPropSet->setPropertyValue( "Dropdown", Any(true) );
             }
 
             Reference< XFormComponent >  aFormComp(xModel,UNO_QUERY );
@@ -1412,19 +1394,13 @@ Reference< awt::XControlModel > BibDataManager::loadControlModel(
     return xModel;
 }
 
-void SAL_CALL BibDataManager::disposing()
-{
-    BibDataManager_Base::WeakComponentImplHelperBase::disposing();
-}
-
-
-void BibDataManager::disposing( const EventObject& /*Source*/ ) throw( css::uno::RuntimeException, std::exception )
+void BibDataManager::disposing( const EventObject& /*Source*/ )
 {
     // not interested in
 }
 
 
-void BibDataManager::propertyChange(const beans::PropertyChangeEvent& evt) throw( RuntimeException, std::exception )
+void BibDataManager::propertyChange(const beans::PropertyChangeEvent& evt)
 {
     try
     {
@@ -1433,15 +1409,11 @@ void BibDataManager::propertyChange(const beans::PropertyChangeEvent& evt) throw
             if( evt.NewValue.getValueType() == cppu::UnoType<io::XInputStream>::get())
             {
                 Reference< io::XDataInputStream >  xStream(
-                    *static_cast<const Reference< io::XInputStream > *>(evt.NewValue.getValue()), UNO_QUERY );
+                    evt.NewValue, UNO_QUERY );
                 aUID <<= xStream->readUTF();
             }
             else
                 aUID = evt.NewValue;
-
-            Reference< XRowLocate > xLocate(xBibCursor, UNO_QUERY);
-            DBG_ASSERT(xLocate.is(), "BibDataManager::propertyChange : invalid cursor !");
-            xLocate->moveToBookmark(aUID);
         }
     }
     catch (const Exception&)
@@ -1462,13 +1434,12 @@ void BibDataManager::SetMeAsUidListener()
         Sequence< OUString > aFields(xFields->getElementNames());
         const OUString* pFields = aFields.getConstArray();
         sal_Int32 nCount=aFields.getLength();
-        OUString StrUID(STR_UID);
         OUString theFieldName;
         for( sal_Int32 i=0; i<nCount; i++ )
         {
             const OUString& rName = pFields[i];
 
-            if (rName.equalsIgnoreAsciiCase(StrUID))
+            if (rName.equalsIgnoreAsciiCase(STR_UID))
             {
                 theFieldName=pFields[i];
                 break;
@@ -1477,13 +1448,12 @@ void BibDataManager::SetMeAsUidListener()
 
         if(!theFieldName.isEmpty())
         {
-            Reference< XPropertySet >  xPropSet;
             Any aElement;
 
             aElement = xFields->getByName(theFieldName);
-            xPropSet = *static_cast<Reference< XPropertySet > const *>(aElement.getValue());
+            auto xPropSet = o3tl::doAccess<Reference<XPropertySet>>(aElement);
 
-            xPropSet->addPropertyChangeListener(FM_PROP_VALUE, this);
+            (*xPropSet)->addPropertyChangeListener(FM_PROP_VALUE, this);
         }
 
     }
@@ -1506,13 +1476,12 @@ void BibDataManager::RemoveMeAsUidListener()
         Sequence< OUString > aFields(xFields->getElementNames());
         const OUString* pFields = aFields.getConstArray();
         sal_Int32 nCount=aFields.getLength();
-        OUString StrUID(STR_UID);
         OUString theFieldName;
         for( sal_Int32 i=0; i<nCount; i++ )
         {
             const OUString& rName = pFields[i];
 
-            if (rName.equalsIgnoreAsciiCase(StrUID))
+            if (rName.equalsIgnoreAsciiCase(STR_UID))
             {
                 theFieldName=pFields[i];
                 break;
@@ -1521,13 +1490,12 @@ void BibDataManager::RemoveMeAsUidListener()
 
         if(!theFieldName.isEmpty())
         {
-            Reference< XPropertySet >  xPropSet;
             Any aElement;
 
             aElement = xFields->getByName(theFieldName);
-            xPropSet = *static_cast<Reference< XPropertySet > const *>(aElement.getValue());
+            auto xPropSet = o3tl::doAccess<Reference<XPropertySet>>(aElement);
 
-            xPropSet->removePropertyChangeListener(FM_PROP_VALUE, this);
+            (*xPropSet)->removePropertyChangeListener(FM_PROP_VALUE, this);
         }
 
     }
@@ -1563,8 +1531,8 @@ OUString BibDataManager::CreateDBChangeDialog(vcl::Window* pParent)
 
 void BibDataManager::DispatchDBChangeDialog()
 {
-    if(pToolbar)
-        pToolbar->SendDispatch(TBC_BT_CHANGESOURCE, Sequence< PropertyValue >());
+    if (pToolbar)
+        pToolbar->SendDispatch(pToolbar->GetChangeSourceId(), Sequence< PropertyValue >());
 }
 
 const OUString& BibDataManager::GetIdentifierMapping()
@@ -1580,11 +1548,11 @@ const OUString& BibDataManager::GetIdentifierMapping()
         sIdentifierMapping = pConfig->GetDefColumnName(IDENTIFIER_POS);
         if(pMapping)
         {
-            for(sal_uInt16 nEntry = 0; nEntry < COLUMN_COUNT; nEntry++)
+            for(const auto & aColumnPair : pMapping->aColumnPairs)
             {
-                if(pMapping->aColumnPairs[nEntry].sLogicalColumnName == sIdentifierMapping)
+                if(aColumnPair.sLogicalColumnName == sIdentifierMapping)
                 {
-                    sIdentifierMapping = pMapping->aColumnPairs[nEntry].sRealColumnName;
+                    sIdentifierMapping = aColumnPair.sRealColumnName;
                     break;
                 }
             }
@@ -1600,7 +1568,7 @@ void BibDataManager::SetToolbar(BibToolBar* pSet)
         pToolbar->SetDatMan(*this);
 }
 
-uno::Reference< form::runtime::XFormController > BibDataManager::GetFormController()
+uno::Reference< form::runtime::XFormController > const & BibDataManager::GetFormController()
 {
     if(!m_xFormCtrl.is())
     {
@@ -1614,12 +1582,10 @@ uno::Reference< form::runtime::XFormController > BibDataManager::GetFormControll
 
 void BibDataManager::RegisterInterceptor( ::bib::BibBeamer* pBibBeamer)
 {
-    DBG_ASSERT( !m_pInterceptorHelper, "BibDataManager::RegisterInterceptor: called twice!" );
+    DBG_ASSERT( !m_xInterceptorHelper.is(), "BibDataManager::RegisterInterceptor: called twice!" );
 
     if( pBibBeamer )
-        m_pInterceptorHelper = new BibInterceptorHelper( pBibBeamer, m_xFormDispatch);
-    if( m_pInterceptorHelper )
-        m_pInterceptorHelper->acquire();
+        m_xInterceptorHelper = new BibInterceptorHelper( pBibBeamer, m_xFormDispatch);
 }
 
 
