@@ -40,12 +40,14 @@
 #include <vcl/msgbox.hxx>
 #include <comphelper/interaction.hxx>
 #include <vcl/stdtext.hxx>
-#include <svtools/localresaccess.hxx>
 #include <connectivity/conncleanup.hxx>
 #include <com/sun/star/sdbc/DataType.hpp>
 #include <tools/urlobj.hxx>
 #include <vcl/layout.hxx>
 
+#define WINDOW_SIZE_X   240
+#define WINDOW_SIZE_Y   185
+
 namespace dbp
 {
     using namespace ::com::sun::star::uno;
@@ -75,12 +77,12 @@ namespace dbp
 
     OControlWizardPage::OControlWizardPage( OControlWizard* _pParent, const OString& rID, const OUString& rUIXMLDescription )
         :OControlWizardPage_Base( _pParent, rID, rUIXMLDescription )
-        ,m_pFormDatasourceLabel(NULL)
-        ,m_pFormDatasource(NULL)
-        ,m_pFormContentTypeLabel(NULL)
-        ,m_pFormContentType(NULL)
-        ,m_pFormTableLabel(NULL)
-        ,m_pFormTable(NULL)
+        ,m_pFormDatasourceLabel(nullptr)
+        ,m_pFormDatasource(nullptr)
+        ,m_pFormContentTypeLabel(nullptr)
+        ,m_pFormContentType(nullptr)
+        ,m_pFormTableLabel(nullptr)
+        ,m_pFormTable(nullptr)
     {
     }
 
@@ -135,10 +137,9 @@ namespace dbp
     }
 
 
-    void OControlWizardPage::fillListBox(ListBox& _rList, const Sequence< OUString >& _rItems, bool _bClear)
+    void OControlWizardPage::fillListBox(ListBox& _rList, const Sequence< OUString >& _rItems)
     {
-        if (_bClear)
-            _rList.Clear();
+        _rList.Clear();
         const OUString* pItems = _rItems.getConstArray();
         const OUString* pEnd = pItems + _rItems.getLength();
         ::svt::WizardTypes::WizardState nPos;
@@ -151,18 +152,16 @@ namespace dbp
     }
 
 
-    void OControlWizardPage::fillListBox(ComboBox& _rList, const Sequence< OUString >& _rItems, bool _bClear)
+    void OControlWizardPage::fillListBox(ComboBox& _rList, const Sequence< OUString >& _rItems)
     {
-        if (_bClear)
-            _rList.Clear();
+        _rList.Clear();
         const OUString* pItems = _rItems.getConstArray();
         const OUString* pEnd = pItems + _rItems.getLength();
         ::svt::WizardTypes::WizardState nPos;
-        sal_Int32 nIndex = 0;
         for (;pItems < pEnd; ++pItems)
         {
             nPos = _rList.InsertEntry(*pItems);
-            _rList.SetEntryData(nPos, reinterpret_cast<void*>(nIndex));
+            _rList.SetEntryData(nPos, reinterpret_cast<void*>(0));
         }
     }
 
@@ -215,26 +214,26 @@ namespace dbp
 
             INetURLObject aURL( sDataSource );
             if( aURL.GetProtocol() != INetProtocol::NotValid )
-                sDataSource = aURL.GetName(INetURLObject::DECODE_WITH_CHARSET);
+                sDataSource = aURL.GetName(INetURLObject::DecodeMechanism::WithCharset);
             m_pFormDatasource->SetText(sDataSource);
             m_pFormTable->SetText(sCommand);
 
-            ::svt::WizardTypes::WizardState nCommandTypeResourceId = 0;
+            const char* pCommandTypeResourceId = nullptr;
             switch (nCommandType)
             {
                 case CommandType::TABLE:
-                    nCommandTypeResourceId = RID_STR_TYPE_TABLE;
+                    pCommandTypeResourceId = RID_STR_TYPE_TABLE;
                     break;
 
                 case CommandType::QUERY:
-                    nCommandTypeResourceId = RID_STR_TYPE_QUERY;
+                    pCommandTypeResourceId = RID_STR_TYPE_QUERY;
                     break;
 
                 default:
-                    nCommandTypeResourceId = RID_STR_TYPE_COMMAND;
+                    pCommandTypeResourceId = RID_STR_TYPE_COMMAND;
                     break;
             }
-            m_pFormContentType->SetText(ModuleRes(nCommandTypeResourceId).toString());
+            m_pFormContentType->SetText(compmodule::ModuleRes(pCommandTypeResourceId));
         }
 
         OControlWizardPage_Base::initializePage();
@@ -248,7 +247,7 @@ namespace dbp
         m_aContext.xObjectModel = _rxObjectModel;
         initContext();
 
-        SetPageSizePixel(LogicToPixel(::Size(WINDOW_SIZE_X, WINDOW_SIZE_Y), MAP_APPFONT));
+        SetPageSizePixel(LogicToPixel(::Size(WINDOW_SIZE_X, WINDOW_SIZE_Y), MapMode(MapUnit::MapAppFont)));
         defaultButton(WizardButtonFlags::NEXT);
         enableButtons(WizardButtonFlags::FINISH, false);
     }
@@ -281,12 +280,6 @@ namespace dbp
     }
 
 
-    void OControlWizard::ActivatePage()
-    {
-        OControlWizard_Base::ActivatePage();
-    }
-
-
     void OControlWizard::implDetermineShape()
     {
         Reference< XIndexAccess > xPageObjects(m_aContext.xDrawPage, UNO_QUERY);
@@ -325,8 +318,8 @@ namespace dbp
         if (xModelAsChild.is())
             xControlParent = xModelAsChild->getParent();
 
-        m_aContext.xForm = Reference< XPropertySet >(xControlParent, UNO_QUERY);
-        m_aContext.xRowSet = Reference< XRowSet >(xControlParent, UNO_QUERY);
+        m_aContext.xForm.set(xControlParent, UNO_QUERY);
+        m_aContext.xRowSet.set(xControlParent, UNO_QUERY);
         DBG_ASSERT(m_aContext.xForm.is() && m_aContext.xRowSet.is(),
             "OControlWizard::implDetermineForm: missing some interfaces of the control parent!");
 
@@ -344,8 +337,8 @@ namespace dbp
             Reference< XModel > xModel(xModelSearch, UNO_QUERY);
             while (xModelSearch.is() && !xModel.is())
             {
-                xModelSearch = Reference< XChild >(xModelSearch->getParent(), UNO_QUERY);
-                xModel = Reference< XModel >(xModelSearch, UNO_QUERY);
+                xModelSearch.set(xModelSearch->getParent(), UNO_QUERY);
+                xModel.set(xModelSearch, UNO_QUERY);
             }
 
             Reference< XDrawPage > xPage;
@@ -369,7 +362,7 @@ namespace dbp
                     if (xView.is())
                     {   // okay, it is one
                         Reference< XSpreadsheet > xSheet = xView->getActiveSheet();
-                        xPageSupp = Reference< XDrawPageSupplier >(xSheet, UNO_QUERY);
+                        xPageSupp.set(xSheet, UNO_QUERY);
                         DBG_ASSERT(xPageSupp.is(), "OControlWizard::implDeterminePage: a spreadsheet which is no page supplier!");
                         if (xPageSupp.is())
                             xPage = xPageSupp->getDrawPage();
@@ -445,10 +438,9 @@ namespace dbp
             // set the new connection
             if ( _bAutoDispose )
             {
-                // for this, use a AutoDisposer (so the conn is cleaned up when the form dies or get's another connection)
+                // for this, use a AutoDisposer (so the conn is cleaned up when the form dies or gets another connection)
                 Reference< XRowSet > xFormRowSet( m_aContext.xForm, UNO_QUERY );
-                OAutoConnectionDisposer* pAutoDispose = new OAutoConnectionDisposer( xFormRowSet, _rxConn );
-                Reference< XPropertyChangeListener > xEnsureDelete( pAutoDispose );
+                rtl::Reference<OAutoConnectionDisposer> pAutoDispose = new OAutoConnectionDisposer( xFormRowSet, _rxConn );
             }
             else
             {
@@ -472,7 +464,7 @@ namespace dbp
         Reference< XInteractionHandler > xHandler;
         try
         {
-            xHandler = Reference< XInteractionHandler >( InteractionHandler::createWithParent(m_xContext, 0), UNO_QUERY_THROW );
+            xHandler.set( InteractionHandler::createWithParent(m_xContext, nullptr), UNO_QUERY_THROW );
         }
         catch(const Exception&) { }
         if (!xHandler.is())
@@ -517,7 +509,7 @@ namespace dbp
             // the shape of the control
             implDetermineShape();
 
-            // get the columns of the object the settins refer to
+            // get the columns of the object the settings refer to
             Reference< XNameAccess >  xColumns;
 
             if (m_aContext.xForm.is())
@@ -530,7 +522,7 @@ namespace dbp
                 Reference< XConnection > xConnection;
                 m_aContext.bEmbedded = ::dbtools::isEmbeddedInDatabase( m_aContext.xForm, xConnection );
                 if ( !m_aContext.bEmbedded )
-                    xConnection = ::dbtools::connectRowset( m_aContext.xRowSet, m_xContext, true );
+                    xConnection = ::dbtools::connectRowset( m_aContext.xRowSet, m_xContext );
 
                 // get the fields
                 if (xConnection.is())
@@ -583,7 +575,6 @@ namespace dbp
             if (xColumns.is())
             {
                 m_aContext.aFieldNames = xColumns->getElementNames();
-                static const char s_sFieldTypeProperty[] = "Type";
                 const OUString* pBegin = m_aContext.aFieldNames.getConstArray();
                 const OUString* pEnd   = pBegin + m_aContext.aFieldNames.getLength();
                 for(;pBegin != pEnd;++pBegin)
@@ -593,13 +584,13 @@ namespace dbp
                     {
                         Reference< XPropertySet > xColumn;
                         xColumns->getByName(*pBegin) >>= xColumn;
-                        xColumn->getPropertyValue(s_sFieldTypeProperty) >>= nFieldType;
+                        xColumn->getPropertyValue("Type") >>= nFieldType;
                     }
                     catch(const Exception&)
                     {
                         OSL_FAIL("OControlWizard::initContext: unexpected exception while gathering column information!");
                     }
-                    m_aContext.aTypes.insert(OControlWizardContext::TNameTypeMap::value_type(*pBegin,nFieldType));
+                    m_aContext.aTypes.emplace(*pBegin,nFieldType);
                 }
             }
         }
@@ -618,7 +609,7 @@ namespace dbp
 
             // prepend an extra SQLContext explaining what we were doing
             SQLContext aContext;
-            aContext.Message = ModuleRes(RID_STR_COULDNOTOPENTABLE).toString();
+            aContext.Message = compmodule::ModuleRes(RID_STR_COULDNOTOPENTABLE);
             aContext.NextException = aSQLException;
 
             // create an interaction handler to display this exception
@@ -639,7 +630,7 @@ namespace dbp
     }
 
 
-    void OControlWizard::commitControlSettings(OControlWizardSettings* _pSettings)
+    void OControlWizard::commitControlSettings(OControlWizardSettings const * _pSettings)
     {
         DBG_ASSERT(m_aContext.xObjectModel.is(), "OControlWizard::commitControlSettings: have no control model to work with!");
         if (!m_aContext.xObjectModel.is())
@@ -648,13 +639,12 @@ namespace dbp
         // the only thing we have at the moment is the label
         try
         {
-            OUString sLabelPropertyName("Label");
             Reference< XPropertySetInfo > xInfo = m_aContext.xObjectModel->getPropertySetInfo();
-            if (xInfo.is() && xInfo->hasPropertyByName(sLabelPropertyName))
+            if (xInfo.is() && xInfo->hasPropertyByName("Label"))
             {
                 OUString sControlLabel(_pSettings->sControlLabel);
                 m_aContext.xObjectModel->setPropertyValue(
-                    OUString("Label"),
+                    "Label",
                     makeAny(sControlLabel)
                 );
             }
