@@ -19,18 +19,16 @@
 
 #include <vector>
 
-#ifdef __MINGW32__
-#define INITGUID
-#include <initguid.h>
-#else
 #include "ole2uno.hxx"
 #include "unoconversionutilities.hxx"
-#endif
 #include "servprov.hxx"
 #include "unoobjw.hxx"
 #include "oleobjw.hxx"
+#include <com/sun/star/script/CannotConvertException.hpp>
 #include <cppuhelper/queryinterface.hxx>
 #include <cppuhelper/supportsservice.hxx>
+#include <o3tl/any.hxx>
+#include <o3tl/char16_t2wchar_t.hxx>
 
 using namespace cppu;
 using namespace osl;
@@ -56,13 +54,13 @@ DEFINE_GUID(OID_ServiceManager, 0x82154420, 0xfbf, 0x11d4, 0x83, 0x13, 0x0, 0x50
 *****************************************************************************/
 
 ProviderOleWrapper_Impl::ProviderOleWrapper_Impl(const Reference<XMultiServiceFactory>& smgr,
-                                                 const Reference<XSingleServiceFactory>& xSFact, GUID* pGuid)
+                                                 const Reference<XSingleServiceFactory>& xSFact, GUID const * pGuid)
     : m_xSingleServiceFactory(xSFact),
       m_smgr( smgr)
 {
     m_guid = *pGuid;
 
-    Reference<XInterface> xInt = smgr->createInstance(reinterpret_cast<const sal_Unicode*>(L"com.sun.star.bridge.oleautomation.BridgeSupplier"));
+    Reference<XInterface> xInt = smgr->createInstance("com.sun.star.bridge.oleautomation.BridgeSupplier");
 
     if (xInt.is())
     {
@@ -76,7 +74,7 @@ ProviderOleWrapper_Impl::~ProviderOleWrapper_Impl()
 {
 }
 
-sal_Bool ProviderOleWrapper_Impl::registerClass()
+bool ProviderOleWrapper_Impl::registerClass()
 {
     HRESULT hresult;
 
@@ -92,7 +90,7 @@ sal_Bool ProviderOleWrapper_Impl::registerClass()
     return (hresult == NOERROR);
 }
 
-sal_Bool ProviderOleWrapper_Impl::deregisterClass()
+bool ProviderOleWrapper_Impl::deregisterClass()
 {
     HRESULT hresult = CoRevokeClassObject(m_factoryHandle);
 
@@ -104,17 +102,17 @@ STDMETHODIMP ProviderOleWrapper_Impl::QueryInterface(REFIID riid, void FAR* FAR*
     if(IsEqualIID(riid, IID_IUnknown))
     {
         AddRef();
-        *ppv = (IUnknown*) (IClassFactory*) this;
+        *ppv = static_cast<IUnknown*>(static_cast<IClassFactory*>(this));
         return NOERROR;
     }
     else if (IsEqualIID(riid, IID_IClassFactory))
     {
         AddRef();
-        *ppv = (IClassFactory*) this;
+        *ppv = static_cast<IClassFactory*>(this);
         return NOERROR;
     }
 
-    *ppv = NULL;
+    *ppv = nullptr;
     return ResultFromScode(E_NOINTERFACE);
 }
 
@@ -140,7 +138,7 @@ STDMETHODIMP ProviderOleWrapper_Impl::CreateInstance(IUnknown FAR* punkOuter,
                                                      void FAR* FAR* ppv)
 {
     HRESULT ret = ResultFromScode(E_UNEXPECTED);
-    punkOuter = NULL;
+    punkOuter = nullptr;
 
     Reference<XInterface> xInstance;
 
@@ -155,14 +153,14 @@ STDMETHODIMP ProviderOleWrapper_Impl::CreateInstance(IUnknown FAR* punkOuter,
             sal_uInt8 arId[16];
             rtl_getGlobalProcessId( arId );
             Any oleAny = m_bridgeSupplier->createBridge(usrAny,
-                                        Sequence<sal_Int8>((sal_Int8*)arId, 16),
+                                        Sequence<sal_Int8>(reinterpret_cast<sal_Int8*>(arId), 16),
                                         UNO,
                                         OLE);
 
 
-            if (oleAny.getValueTypeClass() == cppu::UnoType<sal_uInt32>::get().getTypeClass())
+            if (auto v = o3tl::tryAccess<sal_uIntPtr>(oleAny))
             {
-                VARIANT* pVariant = *(VARIANT**)oleAny.getValue();
+                VARIANT* pVariant = reinterpret_cast<VARIANT*>(*v);
 
                 if (pVariant->vt == VT_DISPATCH)
                 {
@@ -191,7 +189,7 @@ STDMETHODIMP ProviderOleWrapper_Impl::LockServer(int /*fLock*/)
 
 OneInstanceOleWrapper_Impl::OneInstanceOleWrapper_Impl(  const Reference<XMultiServiceFactory>& smgr,
                                                          const Reference<XInterface>& xInst,
-                                                         GUID* pGuid )
+                                                         GUID const * pGuid )
     : m_refCount(0)
     , m_xInst(xInst)
     , m_factoryHandle(0)
@@ -199,7 +197,7 @@ OneInstanceOleWrapper_Impl::OneInstanceOleWrapper_Impl(  const Reference<XMultiS
 {
     m_guid = *pGuid;
 
-    Reference<XInterface> xInt = m_smgr->createInstance(reinterpret_cast<const sal_Unicode*>(L"com.sun.star.bridge.oleautomation.BridgeSupplier"));
+    Reference<XInterface> xInt = m_smgr->createInstance("com.sun.star.bridge.oleautomation.BridgeSupplier");
 
     if (xInt.is())
     {
@@ -212,7 +210,7 @@ OneInstanceOleWrapper_Impl::~OneInstanceOleWrapper_Impl()
 {
 }
 
-sal_Bool OneInstanceOleWrapper_Impl::registerClass()
+bool OneInstanceOleWrapper_Impl::registerClass()
 {
     HRESULT hresult;
 
@@ -228,13 +226,9 @@ sal_Bool OneInstanceOleWrapper_Impl::registerClass()
     return (hresult == NOERROR);
 }
 
-sal_Bool OneInstanceOleWrapper_Impl::deregisterClass()
+bool OneInstanceOleWrapper_Impl::deregisterClass()
 {
-    HRESULT hresult1 = NOERROR;
-
-    HRESULT hresult2 = CoRevokeClassObject(m_factoryHandle);
-
-    return (hresult1 == NOERROR && hresult2 == NOERROR);
+    return CoRevokeClassObject(m_factoryHandle) == NOERROR;
 }
 
 STDMETHODIMP OneInstanceOleWrapper_Impl::QueryInterface(REFIID riid, void FAR* FAR* ppv)
@@ -242,17 +236,17 @@ STDMETHODIMP OneInstanceOleWrapper_Impl::QueryInterface(REFIID riid, void FAR* F
     if(IsEqualIID(riid, IID_IUnknown))
     {
         AddRef();
-        *ppv = (IUnknown*) (IClassFactory*) this;
+        *ppv = static_cast<IUnknown*>(static_cast<IClassFactory*>(this));
         return NOERROR;
     }
     else if (IsEqualIID(riid, IID_IClassFactory))
     {
         AddRef();
-        *ppv = (IClassFactory*) this;
+        *ppv = static_cast<IClassFactory*>(this);
         return NOERROR;
     }
 
-    *ppv = NULL;
+    *ppv = nullptr;
     return ResultFromScode(E_NOINTERFACE);
 }
 
@@ -278,7 +272,7 @@ STDMETHODIMP OneInstanceOleWrapper_Impl::CreateInstance(IUnknown FAR* punkOuter,
                                                          void FAR* FAR* ppv)
 {
     HRESULT ret = ResultFromScode(E_UNEXPECTED);
-    punkOuter = NULL;
+    punkOuter = nullptr;
 
     if (m_xInst.is())
     {
@@ -286,14 +280,14 @@ STDMETHODIMP OneInstanceOleWrapper_Impl::CreateInstance(IUnknown FAR* punkOuter,
         sal_uInt8 arId[16];
         rtl_getGlobalProcessId( arId);
         Any oleAny = m_bridgeSupplier->createBridge(usrAny,
-                                        Sequence<sal_Int8>( (sal_Int8*)arId, 16),
+                                        Sequence<sal_Int8>( reinterpret_cast<sal_Int8*>(arId), 16),
                                         UNO,
                                         OLE);
 
 
-        if (oleAny.getValueTypeClass() == TypeClass_UNSIGNED_LONG)
+        if (auto v = o3tl::tryAccess<sal_uIntPtr>(oleAny))
         {
-            VARIANT* pVariant = *(VARIANT**)oleAny.getValue();
+            VARIANT* pVariant = reinterpret_cast<VARIANT*>(*v);
 
             if ((pVariant->vt == VT_UNKNOWN) || (pVariant->vt == VT_DISPATCH))
             {
@@ -342,14 +336,12 @@ Any SAL_CALL OleConverter_Impl2::createBridge(const Any& modelDepObject,
                                        const Sequence< sal_Int8 >& ProcessId,
                                        sal_Int16 sourceModelType,
                                        sal_Int16 destModelType)
-                                       throw (IllegalArgumentException,
-                                                   RuntimeException )
 {
     Any ret;
     sal_uInt8 arId[16];
     rtl_getGlobalProcessId( arId );
 
-    Sequence< sal_Int8 > seqProcessId( (sal_Int8*)arId, 16);
+    Sequence< sal_Int8 > seqProcessId( reinterpret_cast<sal_Int8*>(arId), 16);
 
     if ( seqProcessId == ProcessId)
     {
@@ -363,7 +355,7 @@ Any SAL_CALL OleConverter_Impl2::createBridge(const Any& modelDepObject,
             else if (destModelType == OLE)
             {
                 // convert UNO any into variant
-                VARIANT* pVariant = (VARIANT*) CoTaskMemAlloc(sizeof(VARIANT));
+                VARIANT* pVariant = static_cast<VARIANT*>(CoTaskMemAlloc(sizeof(VARIANT)));
                 VariantInit( pVariant);
                 try
                 {
@@ -374,36 +366,37 @@ Any SAL_CALL OleConverter_Impl2::createBridge(const Any& modelDepObject,
                     CoTaskMemFree(pVariant);
                     throw IllegalArgumentException();
                 }
-                ret.setValue((void*) &pVariant, cppu::UnoType<sal_uInt32>::get());
+                ret.setValue(static_cast<void*>(&pVariant), cppu::UnoType<sal_uIntPtr>::get());
             }
             else
                 throw IllegalArgumentException();
         }
         else if (sourceModelType == OLE)
         {
-            if (modelDepObject.getValueType() != cppu::UnoType<sal_uInt32>::get())
+            auto v = o3tl::tryAccess<sal_uIntPtr>(modelDepObject);
+            if (!v)
             {
                 throw IllegalArgumentException();
             }
             else if (destModelType == OLE)
             {
                 // same model -> copy value only
-                VARIANT* pVariant = (VARIANT*) CoTaskMemAlloc(sizeof(VARIANT));
+                VARIANT* pVariant = static_cast<VARIANT*>(CoTaskMemAlloc(sizeof(VARIANT)));
 
-                if (NOERROR != VariantCopy(pVariant, *(VARIANT**)modelDepObject.getValue()))
+                if (NOERROR != VariantCopy(pVariant, reinterpret_cast<VARIANT*>(*v)))
                 {
                     CoTaskMemFree(pVariant);
                     throw(IllegalArgumentException());
                 }
                 else
                 {
-                    ret.setValue((void*) &pVariant, cppu::UnoType<sal_uInt32>::get());
+                    ret.setValue(static_cast<void*>(&pVariant), cppu::UnoType<sal_uIntPtr>::get());
                 }
             }
             else if (destModelType == UNO)
             {
                 // convert variant into UNO any
-                VARIANT* pVariant = *(VARIANT**)modelDepObject.getValue();
+                VARIANT* pVariant = reinterpret_cast<VARIANT*>(*v);
                 try
                 {
                     variantToAny(pVariant, ret);
@@ -411,7 +404,7 @@ Any SAL_CALL OleConverter_Impl2::createBridge(const Any& modelDepObject,
                 catch (const CannotConvertException & e)
                 {
                     throw IllegalArgumentException(
-                        e.Message, 0, -1);
+                        e.Message, nullptr, -1);
                 }
             }
             else
@@ -426,7 +419,6 @@ Any SAL_CALL OleConverter_Impl2::createBridge(const Any& modelDepObject,
 }
 
 OUString OleConverter_Impl2::getImplementationName()
-    throw (css::uno::RuntimeException, std::exception)
 {
     return m_nUnoWrapperClass == INTERFACE_OLE_WRAPPER_IMPL
         ? OUString("com.sun.star.comp.ole.OleConverter2")
@@ -434,13 +426,11 @@ OUString OleConverter_Impl2::getImplementationName()
 }
 
 sal_Bool OleConverter_Impl2::supportsService(OUString const & ServiceName)
-    throw (css::uno::RuntimeException, std::exception)
 {
     return cppu::supportsService(this, ServiceName);
 }
 
 css::uno::Sequence<OUString> OleConverter_Impl2::getSupportedServiceNames()
-    throw (css::uno::RuntimeException, std::exception)
 {
     if (m_nUnoWrapperClass == INTERFACE_OLE_WRAPPER_IMPL)
     {
@@ -455,7 +445,6 @@ css::uno::Sequence<OUString> OleConverter_Impl2::getSupportedServiceNames()
 // XInitialize ------------------------------------------------------------------------------
 // the first argument is an XMultiServiceFactory if at all
 void SAL_CALL OleConverter_Impl2::initialize( const Sequence< Any >& aArguments )
-                throw(Exception, RuntimeException)
 {
     if( aArguments.getLength() == 1 && aArguments[0].getValueTypeClass() == TypeClass_INTERFACE)
     {
@@ -493,7 +482,6 @@ Reference< XInterface > OleConverter_Impl2::createComWrapperInstance()
 }
 
 
-
 /*****************************************************************************
 
     class implementation OleClient_Impl
@@ -516,7 +504,7 @@ OleClient_Impl::~OleClient_Impl()
 {
 }
 
-Sequence< OUString >    SAL_CALL OleClient_Impl::getAvailableServiceNames() throw( RuntimeException )
+Sequence< OUString >    SAL_CALL OleClient_Impl::getAvailableServiceNames()
 {
     Sequence< OUString > ret;
 
@@ -524,36 +512,33 @@ Sequence< OUString >    SAL_CALL OleClient_Impl::getAvailableServiceNames() thro
 }
 
 OUString OleClient_Impl::getImplementationName()
-    throw (css::uno::RuntimeException, std::exception)
 {
     return OUString("com.sun.star.comp.ole.OleClient");
 }
 
 sal_Bool OleClient_Impl::supportsService(OUString const & ServiceName)
-    throw (css::uno::RuntimeException, std::exception)
 {
     return cppu::supportsService(this, ServiceName);
 }
 
 css::uno::Sequence<OUString> OleClient_Impl::getSupportedServiceNames()
-    throw (css::uno::RuntimeException, std::exception)
 {
     return css::uno::Sequence<OUString>{
         "com.sun.star.bridge.OleObjectFactory",
         "com.sun.star.bridge.oleautomation.Factory"};
 }
 
-Reference<XInterface> SAL_CALL OleClient_Impl::createInstance(const OUString& ServiceSpecifier) throw (Exception, RuntimeException )
+Reference<XInterface> SAL_CALL OleClient_Impl::createInstance(const OUString& ServiceSpecifier)
 {
     Reference<XInterface>   ret;
     HRESULT         result;
-    IUnknown*       pUnknown = NULL;
+    IUnknown*       pUnknown = nullptr;
     CLSID           classId;
 
     o2u_attachCurrentThread();
 
     result = CLSIDFromProgID(
-                  reinterpret_cast<LPCWSTR>(ServiceSpecifier.getStr()),     //Pointer to the ProgID
+                  o3tl::toW(ServiceSpecifier.getStr()), //Pointer to the ProgID
                   &classId);                        //Pointer to the CLSID
 
 
@@ -561,14 +546,14 @@ Reference<XInterface> SAL_CALL OleClient_Impl::createInstance(const OUString& Se
     {
         result = CoCreateInstance(
                       classId,              //Class identifier (CLSID) of the object
-                      NULL,                 //Pointer to whether object is or isn't part of an aggregate
+                      nullptr,              //Pointer to whether object is or isn't part of an aggregate
                       CLSCTX_SERVER,  //Context for running executable code
                       IID_IUnknown,         //Reference to the identifier of the interface
-                      (void**)&pUnknown);   //Address of output variable that receives
+                      reinterpret_cast<void**>(&pUnknown)); //Address of output variable that receives
                                                   // the interface pointer requested in riid
     }
 
-    if (pUnknown != NULL)
+    if (pUnknown != nullptr)
     {
         Any any;
         CComVariant variant;
@@ -590,7 +575,7 @@ Reference<XInterface> SAL_CALL OleClient_Impl::createInstance(const OUString& Se
     return ret;
 }
 
-Reference<XInterface> SAL_CALL OleClient_Impl::createInstanceWithArguments(const OUString& ServiceSpecifier, const Sequence< Any >& /*Arguments*/) throw (Exception, RuntimeException)
+Reference<XInterface> SAL_CALL OleClient_Impl::createInstanceWithArguments(const OUString& ServiceSpecifier, const Sequence< Any >& /*Arguments*/)
 {
     return createInstance( ServiceSpecifier);
 }
@@ -622,7 +607,6 @@ Reference< XInterface > OleClient_Impl::createComWrapperInstance( )
 }
 
 
-
 /*****************************************************************************
 
     class implementation OleServer_Impl
@@ -632,7 +616,7 @@ Reference< XInterface > OleClient_Impl::createComWrapperInstance( )
 OleServer_Impl::OleServer_Impl( const Reference<XMultiServiceFactory>& smgr):
     m_smgr( smgr)
 {
-    Reference<XInterface> xInt = m_smgr->createInstance(reinterpret_cast<const sal_Unicode*>(L"com.sun.star.bridge.oleautomation.BridgeSupplier"));
+    Reference<XInterface> xInt = m_smgr->createInstance("com.sun.star.bridge.oleautomation.BridgeSupplier");
 
     if (xInt.is())
     {
@@ -640,8 +624,7 @@ OleServer_Impl::OleServer_Impl( const Reference<XMultiServiceFactory>& smgr):
         a >>= m_bridgeSupplier;
     }
 
-    sal_Bool ret = provideInstance( m_smgr, (GUID*)&OID_ServiceManager );
-    (void)ret;
+    (void) provideInstance( m_smgr, &OID_ServiceManager );
 }
 
 OleServer_Impl::~OleServer_Impl()
@@ -655,26 +638,23 @@ OleServer_Impl::~OleServer_Impl()
 }
 
 OUString OleServer_Impl::getImplementationName()
-    throw (css::uno::RuntimeException, std::exception)
 {
     return OUString("com.sun.star.comp.ole.OleServer");
 }
 
 sal_Bool OleServer_Impl::supportsService(OUString const & ServiceName)
-    throw (css::uno::RuntimeException, std::exception)
 {
     return cppu::supportsService(this, ServiceName);
 }
 
 css::uno::Sequence<OUString> OleServer_Impl::getSupportedServiceNames()
-    throw (css::uno::RuntimeException, std::exception)
 {
     return css::uno::Sequence<OUString>{
         "com.sun.star.bridge.OleApplicationRegistration",
         "com.sun.star.bridge.oleautomation.ApplicationRegistration"};
 }
 
-sal_Bool OleServer_Impl::provideService(const Reference<XSingleServiceFactory>& xSFact, GUID* guid)
+bool OleServer_Impl::provideService(const Reference<XSingleServiceFactory>& xSFact, GUID const * guid)
 {
     IClassFactoryWrapper* pFac = new ProviderOleWrapper_Impl( m_smgr, xSFact, guid);
 
@@ -685,7 +665,7 @@ sal_Bool OleServer_Impl::provideService(const Reference<XSingleServiceFactory>&
     return pFac->registerClass();
 }
 
-sal_Bool OleServer_Impl::provideInstance(const Reference<XInterface>& xInst, GUID* guid)
+bool OleServer_Impl::provideInstance(const Reference<XInterface>& xInst, GUID const * guid)
 {
     IClassFactoryWrapper* pFac =
         new OneInstanceOleWrapper_Impl( m_smgr, xInst, guid );
@@ -697,7 +677,6 @@ sal_Bool OleServer_Impl::provideInstance(const Reference<XInterface>& xInst, GUI
 }
 
 
-
 } // end namespace
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
