@@ -25,11 +25,9 @@
 #include <com/sun/star/beans/XFastPropertySet.hpp>
 #include <com/sun/star/lang/XComponent.hpp>
 #include <com/sun/star/frame/Desktop.hpp>
-#include <com/sun/star/frame/XFrame.hpp>
-#include <com/sun/star/frame/DispatchResultEvent.hpp>
-#include <com/sun/star/frame/DispatchResultState.hpp>
 #include <com/sun/star/office/Quickstart.hpp>
 #include <com/sun/star/system/SystemShellExecute.hpp>
+#include <com/sun/star/system/SystemShellExecuteException.hpp>
 #include <com/sun/star/system/SystemShellExecuteFlags.hpp>
 #include <com/sun/star/task/XJob.hpp>
 #include <com/sun/star/task/XJobExecutor.hpp>
@@ -42,7 +40,7 @@
 #include <osl/file.hxx>
 #include <sal/macros.h>
 
-#ifdef WNT
+#ifdef _WIN32
 #ifdef _MSC_VER
 #pragma warning(push,1) // disable warnings within system headers
 //#pragma warning(disable: 4917)
@@ -53,6 +51,7 @@
 #endif
 #endif
 
+#include "onlinecheck.hxx"
 #include "updateprotocol.hxx"
 #include "updatecheckconfig.hxx"
 
@@ -70,10 +69,6 @@ namespace uno = com::sun::star::uno ;
 #define PROPERTY_CLICK_HDL      "MenuClickHDL"
 #define PROPERTY_SHOW_MENUICON  "MenuIconVisible"
 
-#if defined WNT
-extern "C" bool SAL_CALL WNT_hasInternetConnection();
-#endif
-
 // Returns the URL of the release note for the given position
 OUString getReleaseNote(const UpdateInfo& rInfo, sal_uInt8 pos, bool autoDownloadEnabled)
 {
@@ -95,11 +90,10 @@ OUString getReleaseNote(const UpdateInfo& rInfo, sal_uInt8 pos, bool autoDownloa
 }
 
 
-
 namespace
 {
 
-static inline OUString getBuildId()
+inline OUString getBuildId()
 {
     OUString aPathVal("${$BRAND_BASE_DIR/" LIBO_ETC_FOLDER "/" SAL_CONFIGFILE("version") ":buildid}");
     rtl::Bootstrap::expandMacros(aPathVal);
@@ -107,8 +101,8 @@ static inline OUString getBuildId()
 }
 
 
-#if defined LINUX || defined SOLARIS
-static inline OUString getBaseInstallation()
+#if (defined LINUX || defined __sun)
+inline OUString getBaseInstallation()
 {
     OUString aPathVal("$BRAND_BASE_DIR");
     rtl::Bootstrap::expandMacros(aPathVal);
@@ -117,18 +111,15 @@ static inline OUString getBaseInstallation()
 #endif
 
 
-
 inline bool isObsoleteUpdateInfo(const OUString& rBuildId)
 {
-    return !rBuildId.equals(getBuildId()) && !rBuildId.isEmpty();
+    return rBuildId != getBuildId() && !rBuildId.isEmpty();
 }
 
 
-
-
 OUString getImageFromFileName(const OUString& aFile)
 {
-#ifndef WNT
+#ifndef _WIN32
     OUString aUnpackPath;
     if( osl_getExecutableFile(&aUnpackPath.pData) == osl_Process_E_None )
     {
@@ -200,9 +191,7 @@ OUString getImageFromFileName(const OUString& aFile)
 }
 
 
-
-
-static uno::Reference< beans::XPropertySet > createMenuBarUI(
+uno::Reference< beans::XPropertySet > createMenuBarUI(
     const uno::Reference< uno::XComponentContext >& xContext,
     const uno::Reference< task::XJob >& xJob)
 {
@@ -226,9 +215,6 @@ static uno::Reference< beans::XPropertySet > createMenuBarUI(
 }
 
 
-
-
-
 typedef sal_Bool (* OnlineCheckFunc) ();
 
 class UpdateCheckThread : public WorkerThread
@@ -243,7 +229,7 @@ public:
     virtual void cancel() override;
 
 protected:
-    virtual ~UpdateCheckThread();
+    virtual ~UpdateCheckThread() override;
 
     virtual void SAL_CALL run() override;
     virtual void SAL_CALL onTerminated() override;
@@ -254,9 +240,9 @@ protected:
 private:
 
     /* Used to avoid dialup login windows (on platforms we know how to double this) */
-    static inline bool hasInternetConnection()
+    static bool hasInternetConnection()
     {
-#ifdef WNT
+#ifdef _WIN32
         return WNT_hasInternetConnection();
 #else
         return true;
@@ -264,7 +250,7 @@ private:
     }
 
     /* Creates a new instance of UpdateInformationProvider and returns this instance */
-    inline uno::Reference<deployment::XUpdateInformationProvider> createProvider()
+    uno::Reference<deployment::XUpdateInformationProvider> createProvider()
     {
         osl::MutexGuard aGuard(m_aMutex);
         m_xProvider = deployment::UpdateInformationProvider::create(m_xContext);
@@ -272,15 +258,14 @@ private:
     };
 
     /* Returns the remembered instance of UpdateInformationProvider if any */
-    inline uno::Reference<deployment::XUpdateInformationProvider> getProvider()
+    uno::Reference<deployment::XUpdateInformationProvider> getProvider()
         { osl::MutexGuard aGuard(m_aMutex); return m_xProvider; };
 
     /* Releases the remembered instance of UpdateInformationProvider if any */
-    inline void clearProvider()
+    void clearProvider()
         { osl::MutexGuard aGuard(m_aMutex); m_xProvider.clear(); };
 
     osl::Mutex      m_aMutex;
-    osl::Module     m_aModule;
 
 protected:
     osl::Condition& m_aCondition;
@@ -304,11 +289,10 @@ public:
 class MenuBarButtonJob : public ::cppu::WeakImplHelper< task::XJob >
 {
 public:
-    MenuBarButtonJob(const rtl::Reference< UpdateCheck >& rUpdateCheck);
+    explicit MenuBarButtonJob(const rtl::Reference< UpdateCheck >& rUpdateCheck);
 
     // XJob
-    virtual uno::Any SAL_CALL execute(const uno::Sequence<beans::NamedValue>&)
-        throw (lang::IllegalArgumentException, uno::Exception, std::exception) override;
+    virtual uno::Any SAL_CALL execute(const uno::Sequence<beans::NamedValue>&) override;
 
 private:
     rtl::Reference< UpdateCheck > m_aUpdateCheck;
@@ -329,7 +313,7 @@ public:
     virtual void SAL_CALL onTerminated() override;
 
 protected:
-    virtual ~DownloadThread();
+    virtual ~DownloadThread() override;
 
 private:
     osl::Condition& m_aCondition;
@@ -342,13 +326,13 @@ private:
 class ShutdownThread :  public osl::Thread
 {
 public:
-    ShutdownThread( const uno::Reference<uno::XComponentContext>& xContext );
+    explicit ShutdownThread(const uno::Reference<uno::XComponentContext>& xContext);
 
     virtual void SAL_CALL run() override;
     virtual void SAL_CALL onTerminated() override;
 
 protected:
-    virtual ~ShutdownThread();
+    virtual ~ShutdownThread() override;
 
 private:
     osl::Condition m_aCondition;
@@ -356,7 +340,6 @@ private:
 };
 
 
-
 UpdateCheckThread::UpdateCheckThread( osl::Condition& rCondition,
                                       const uno::Reference<uno::XComponentContext>& xContext ) :
     m_aCondition(rCondition),
@@ -369,14 +352,11 @@ UpdateCheckThread::UpdateCheckThread( osl::Condition& rCondition,
 }
 
 
-
 UpdateCheckThread::~UpdateCheckThread()
 {
 }
 
 
-
-
 void SAL_CALL
 UpdateCheckThread::terminate()
 {
@@ -387,7 +367,6 @@ UpdateCheckThread::terminate()
 }
 
 
-
 void SAL_CALL
 UpdateCheckThread::join()
 {
@@ -401,7 +380,6 @@ UpdateCheckThread::join()
 }
 
 
-
 void
 UpdateCheckThread::cancel()
 {
@@ -412,7 +390,6 @@ UpdateCheckThread::cancel()
 }
 
 
-
 bool
 UpdateCheckThread::runCheck( bool & rbExtensionsChecked )
 {
@@ -451,7 +428,6 @@ UpdateCheckThread::runCheck( bool & rbExtensionsChecked )
 }
 
 
-
 void SAL_CALL
 UpdateCheckThread::onTerminated()
 {
@@ -459,7 +435,6 @@ UpdateCheckThread::onTerminated()
 }
 
 
-
 void SAL_CALL
 UpdateCheckThread::run()
 {
@@ -505,7 +480,7 @@ UpdateCheckThread::run()
             rModel.clear();
 
             // last == 0 means check immediately
-            bool checkNow = ! (last > 0);
+            bool checkNow = last <= 0;
 
             // Reset the condition to avoid busy loops
             if( osl::Condition::result_ok == aResult )
@@ -559,13 +534,11 @@ UpdateCheckThread::run()
 
     catch(const uno::Exception& e) {
         // Silently catch all errors
-        OSL_TRACE( "Caught exception: %s\n thread terminated.\n",
-            OUStringToOString(e.Message, RTL_TEXTENCODING_UTF8).getStr() );
+        SAL_WARN("extensions.update", "Caught exception, thread terminated. " << e );
     }
 }
 
 
-
 void SAL_CALL
 ManualUpdateCheckThread::run()
 {
@@ -576,23 +549,19 @@ ManualUpdateCheckThread::run()
     }
     catch(const uno::Exception& e) {
         // Silently catch all errors
-        OSL_TRACE( "Caught exception: %s\n thread terminated.\n",
-            OUStringToOString(e.Message, RTL_TEXTENCODING_UTF8).getStr() );
+        SAL_WARN("extensions.update", "Caught exception, thread terminated. " << e );
     }
 }
 
 
-
 MenuBarButtonJob::MenuBarButtonJob(const rtl::Reference< UpdateCheck >& rUpdateCheck) :
     m_aUpdateCheck(rUpdateCheck)
 {
 };
 
 
-
 uno::Any SAL_CALL
 MenuBarButtonJob::execute(const uno::Sequence<beans::NamedValue>& )
-    throw (lang::IllegalArgumentException, uno::Exception, std::exception)
 {
     if ( m_aUpdateCheck->shouldShowExtUpdDlg() )
         m_aUpdateCheck->showExtensionDialog();
@@ -603,7 +572,6 @@ MenuBarButtonJob::execute(const uno::Sequence<beans::NamedValue>& )
 }
 
 
-
 DownloadThread::DownloadThread(osl::Condition& rCondition,
                                const uno::Reference<uno::XComponentContext>& xContext,
                                const rtl::Reference< DownloadInteractionHandler >& rHandler,
@@ -617,21 +585,19 @@ DownloadThread::DownloadThread(osl::Condition& rCondition,
 }
 
 
-
 DownloadThread::~DownloadThread()
 {
 }
 
 
-
 void SAL_CALL
 DownloadThread::run()
 {
     osl_setThreadName("DownloadThread");
 
-#ifdef WNT
+#ifdef _WIN32
     CoUninitialize();
-    CoInitialize( NULL );
+    CoInitialize( nullptr );
 #endif
 
     while( schedule() )
@@ -672,7 +638,6 @@ DownloadThread::run()
 }
 
 
-
 void DownloadThread::cancel()
 {
     m_aDownload.stop();
@@ -683,7 +648,6 @@ void DownloadThread::cancel()
 }
 
 
-
 void SAL_CALL DownloadThread::suspend()
 {
     osl::Thread::suspend();
@@ -691,7 +655,6 @@ void SAL_CALL DownloadThread::suspend()
 }
 
 
-
 void SAL_CALL DownloadThread::onTerminated()
 {
     delete this;
@@ -737,7 +700,6 @@ void SAL_CALL ShutdownThread::onTerminated()
 }
 
 
-
 } // anonymous namespace
 
 UpdateCheck::UpdateCheck()
@@ -850,7 +812,6 @@ UpdateCheck::initialize(const uno::Sequence< beans::NamedValue >& rValues,
 }
 
 
-
 void
 UpdateCheck::cancel()
 {
@@ -868,7 +829,6 @@ UpdateCheck::cancel()
 }
 
 
-
 void
 UpdateCheck::download()
 {
@@ -877,6 +837,12 @@ UpdateCheck::download()
     State eState = m_eState;
     aGuard.clear();
 
+    if (aInfo.Sources.empty())
+    {
+        SAL_WARN("extensions.update", "download called without source");
+        return;
+    }
+
     if( aInfo.Sources[0].IsDirect )
     {
         // Ignore second click of a double click
@@ -897,7 +863,6 @@ UpdateCheck::download()
 }
 
 
-
 void
 UpdateCheck::install()
 {
@@ -918,30 +883,30 @@ UpdateCheck::install()
         OUString aInstallImage(m_aImageName);
         osl::FileBase::getSystemPathFromFileURL(aInstallImage, aInstallImage);
 
-        OUString aParameter;
-        sal_Int32 nFlags = c3s::SystemShellExecuteFlags::DEFAULTS;
-#if ( defined LINUX || defined SOLARIS )
+        sal_Int32 nFlags;
+#if (defined LINUX || defined __sun)
         nFlags = 42;
-        aParameter = getBaseInstallation();
+        OUString aParameter = getBaseInstallation();
         if( !aParameter.isEmpty() )
             osl::FileBase::getSystemPathFromFileURL(aParameter, aParameter);
 
         aParameter += " &";
+#else
+        nFlags = c3s::SystemShellExecuteFlags::DEFAULTS;
+        OUString const aParameter;
 #endif
 
         rtl::Reference< UpdateCheckConfig > rModel = UpdateCheckConfig::get( m_xContext );
         rModel->clearLocalFileName();
 
         xShellExecute->execute(aInstallImage, aParameter, nFlags);
-        ShutdownThread *pShutdownThread = new ShutdownThread( m_xContext );
-        (void) pShutdownThread;
+        new ShutdownThread( m_xContext );
     } catch(const uno::Exception&) {
         m_aUpdateHandler->setErrorMessage( m_aUpdateHandler->getDefaultInstErrMsg() );
     }
 }
 
 
-
 void
 UpdateCheck::pause()
 {
@@ -958,7 +923,6 @@ UpdateCheck::pause()
 }
 
 
-
 void
 UpdateCheck::resume()
 {
@@ -975,7 +939,6 @@ UpdateCheck::resume()
 }
 
 
-
 void
 UpdateCheck::closeAfterFailure()
 {
@@ -990,7 +953,6 @@ UpdateCheck::closeAfterFailure()
 }
 
 
-
 void
 UpdateCheck::shutdownThread(bool join)
 {
@@ -1014,7 +976,6 @@ UpdateCheck::shutdownThread(bool join)
 }
 
 
-
 void
 UpdateCheck::enableAutoCheck(bool enable)
 {
@@ -1025,7 +986,6 @@ UpdateCheck::enableAutoCheck(bool enable)
 }
 
 
-
 void
 UpdateCheck::enableDownload(bool enable, bool paused)
 {
@@ -1052,7 +1012,6 @@ UpdateCheck::enableDownload(bool enable, bool paused)
 }
 
 
-
 bool
 UpdateCheck::downloadTargetExists(const OUString& rFileName)
 {
@@ -1113,7 +1072,6 @@ bool UpdateCheck::checkDownloadDestination( const OUString& rFileName )
 }
 
 
-
 void
 UpdateCheck::downloadStalled(const OUString& rErrorMessage)
 {
@@ -1126,7 +1084,6 @@ UpdateCheck::downloadStalled(const OUString& rErrorMessage)
 }
 
 
-
 void
 UpdateCheck::downloadProgressAt(sal_Int8 nPercent)
 {
@@ -1139,7 +1096,6 @@ UpdateCheck::downloadProgressAt(sal_Int8 nPercent)
 }
 
 
-
 void
 UpdateCheck::downloadStarted(const OUString& rLocalFileName, sal_Int64 nFileSize)
 {
@@ -1158,7 +1114,6 @@ UpdateCheck::downloadStarted(const OUString& rLocalFileName, sal_Int64 nFileSize
 }
 
 
-
 void
 UpdateCheck::downloadFinished(const OUString& rLocalFileName)
 {
@@ -1181,7 +1136,6 @@ UpdateCheck::downloadFinished(const OUString& rLocalFileName)
 }
 
 
-
 void
 UpdateCheck::cancelDownload()
 {
@@ -1208,7 +1162,6 @@ UpdateCheck::cancelDownload()
 }
 
 
-
 void
 UpdateCheck::showDialog(bool forceCheck)
 {
@@ -1270,13 +1223,12 @@ UpdateCheck::showDialog(bool forceCheck)
 }
 
 
-
 void
 UpdateCheck::setUpdateInfo(const UpdateInfo& aInfo)
 {
     osl::ClearableMutexGuard aGuard(m_aMutex);
 
-    bool bSuppressBubble = aInfo.BuildId.equals(m_aUpdateInfo.BuildId);
+    bool bSuppressBubble = aInfo.BuildId == m_aUpdateInfo.BuildId;
     m_aUpdateInfo = aInfo;
 
     OSL_ASSERT(DISABLED == m_eState || CHECK_SCHEDULED == m_eState);
@@ -1351,7 +1303,6 @@ UpdateCheck::setUpdateInfo(const UpdateInfo& aInfo)
 }
 
 
-
 void
 UpdateCheck::setCheckFailedState()
 {
@@ -1359,7 +1310,7 @@ UpdateCheck::setCheckFailedState()
 }
 
 
-void UpdateCheck::handleMenuBarUI( rtl::Reference< UpdateHandler > rUpdateHandler,
+void UpdateCheck::handleMenuBarUI( const rtl::Reference< UpdateHandler >& rUpdateHandler,
                                    UpdateState& eState,
                                    bool suppressBubble )
 {
@@ -1377,7 +1328,7 @@ void UpdateCheck::handleMenuBarUI( rtl::Reference< UpdateHandler > rUpdateHandle
     {
         if( UPDATESTATE_NO_UPDATE_AVAIL == eState )
         {
-            xMenuBarUI->setPropertyValue( PROPERTY_SHOW_MENUICON, uno::makeAny(sal_False) );
+            xMenuBarUI->setPropertyValue( PROPERTY_SHOW_MENUICON, uno::makeAny(false) );
         }
         else
         {
@@ -1385,10 +1336,10 @@ void UpdateCheck::handleMenuBarUI( rtl::Reference< UpdateHandler > rUpdateHandle
             xMenuBarUI->setPropertyValue( PROPERTY_TEXT, uno::makeAny(rUpdateHandler->getBubbleText(eState)) );
 
             if( ! suppressBubble && ( ! rUpdateHandler->isVisible() || rUpdateHandler->isMinimized() ) )
-                xMenuBarUI->setPropertyValue( PROPERTY_SHOW_BUBBLE, uno::makeAny( sal_True ) );
+                xMenuBarUI->setPropertyValue( PROPERTY_SHOW_BUBBLE, uno::makeAny( true ) );
 
             if( UPDATESTATE_CHECKING != eState )
-                xMenuBarUI->setPropertyValue( PROPERTY_SHOW_MENUICON, uno::makeAny(sal_True) );
+                xMenuBarUI->setPropertyValue( PROPERTY_SHOW_MENUICON, uno::makeAny(true) );
         }
     }
 }
@@ -1448,7 +1399,6 @@ void UpdateCheck::setUIState(UpdateState eState, bool suppressBubble)
 }
 
 
-
 UpdateState
 UpdateCheck::getUIState(const UpdateInfo& rInfo)
 {
@@ -1466,7 +1416,6 @@ UpdateCheck::getUIState(const UpdateInfo& rInfo)
 }
 
 
-
 void
 UpdateCheck::showReleaseNote(const OUString& rURL) const
 {
@@ -1480,7 +1429,6 @@ UpdateCheck::showReleaseNote(const OUString& rURL) const
 }
 
 
-
 bool
 UpdateCheck::storeReleaseNote(sal_Int8 nNum, const OUString &rURL)
 {
@@ -1511,7 +1459,7 @@ UpdateCheck::storeReleaseNote(sal_Int8 nNum, const OUString &rURL)
     sal_uInt64 nWritten = 0;
 
     OUString aURL( rURL );
-#ifdef WNT
+#ifdef _WIN32
     rc = aFile.write( aLineBuf.getStr(), aLineBuf.getLength(), nWritten );
     if ( rc != osl::FileBase::E_None ) return false;
     aURL = "URL=" + rURL;
@@ -1547,7 +1495,6 @@ void UpdateCheck::showExtensionDialog()
 }
 
 
-
 rtl::Reference<UpdateHandler>
 UpdateCheck::getUpdateHandler()
 {
@@ -1560,7 +1507,6 @@ UpdateCheck::getUpdateHandler()
 }
 
 
-
 uno::Reference< task::XInteractionHandler >
 UpdateCheck::getInteractionHandler() const
 {
@@ -1575,7 +1521,6 @@ UpdateCheck::getInteractionHandler() const
 }
 
 
-
 bool
 UpdateCheck::isDialogShowing() const
 {
@@ -1584,7 +1529,6 @@ UpdateCheck::isDialogShowing() const
 };
 
 
-
 void
 UpdateCheck::autoCheckStatusChanged(bool enabled)
 {
@@ -1603,7 +1547,6 @@ UpdateCheck::autoCheckStatusChanged(bool enabled)
 };
 
 
-
 void
 UpdateCheck::autoCheckIntervalChanged()
 {
