@@ -21,6 +21,7 @@
 #include "constant.hxx"
 
 #include <com/sun/star/document/XExtendedFilterDetection.hpp>
+#include <com/sun/star/frame/Desktop.hpp>
 #include <com/sun/star/util/URLTransformer.hpp>
 #include <com/sun/star/util/XURLTransformer.hpp>
 
@@ -31,8 +32,9 @@
 #include <rtl/ustrbuf.hxx>
 #include <framework/interaction.hxx>
 #include <tools/urlobj.hxx>
-#include <unotools/localfilehelper.hxx>
+#include <comphelper/fileurl.hxx>
 #include <comphelper/processfactory.hxx>
+#include <comphelper/sequence.hxx>
 
 #define DEBUG_TYPE_DETECTION 0
 
@@ -49,7 +51,10 @@ namespace filter{
 
 TypeDetection::TypeDetection(const css::uno::Reference< css::uno::XComponentContext >& rxContext)
    : m_xContext(rxContext)
+   , m_xTerminateListener(new TerminateDetection(this))
+   , m_bCancel(false)
 {
+    css::frame::Desktop::create(m_xContext)->addTerminateListener(m_xTerminateListener.get());
     BaseContainer::init(rxContext                                     ,
                         TypeDetection::impl_getImplementationName()   ,
                         TypeDetection::impl_getSupportedServiceNames(),
@@ -57,15 +62,13 @@ TypeDetection::TypeDetection(const css::uno::Reference< css::uno::XComponentCont
 }
 
 
-
 TypeDetection::~TypeDetection()
 {
+    css::frame::Desktop::create(m_xContext)->removeTerminateListener(m_xTerminateListener.get());
 }
 
 
-
 OUString SAL_CALL TypeDetection::queryTypeByURL(const OUString& sURL)
-    throw (css::uno::RuntimeException, std::exception)
 {
     OUString sType;
 
@@ -80,16 +83,17 @@ OUString SAL_CALL TypeDetection::queryTypeByURL(const OUString& sURL)
     // set std types as minimum requirement first!
     // Only in case no type was found for given URL,
     // use optional types too ...
+    auto & cache = TheFilterCache::get();
     FlatDetection lFlatTypes;
-    m_rCache->detectFlatForURL(aURL, lFlatTypes);
+    cache.detectFlatForURL(aURL, lFlatTypes);
 
     if (
         (lFlatTypes.size() < 1                                ) &&
-        (!m_rCache->isFillState(FilterCache::E_CONTAINS_TYPES))
+        (!cache.isFillState(FilterCache::E_CONTAINS_TYPES))
        )
     {
-        m_rCache->load(FilterCache::E_CONTAINS_TYPES);
-        m_rCache->detectFlatForURL(aURL, lFlatTypes);
+        cache.load(FilterCache::E_CONTAINS_TYPES);
+        cache.detectFlatForURL(aURL, lFlatTypes);
     }
 
     // first item is guaranteed as "preferred" one!
@@ -243,6 +247,7 @@ int getFlatTypeRank(const OUString& rType)
         "calc_ODS_FlatXML",
         "impress_ODP_FlatXML",
         "draw_ODG_FlatXML",
+        "calc_ADO_rowset_XML",
         "calc_MS_Excel_2003_XML",
         "writer_MS_Word_2003_XML",
         "writer_DocBook_File",
@@ -269,7 +274,6 @@ int getFlatTypeRank(const OUString& rType)
 
         // Export only
         "writer_layout_dump_xml",
-        "pwp_PlaceWare",
         "graphic_SWF",
         "graphic_HTML",
 
@@ -297,7 +301,7 @@ int getFlatTypeRank(const OUString& rType)
  * types, then types that are supported by the document service come next.
  * Lastly, sort them alphabetically.
  */
-struct SortByPriority : public std::binary_function<FlatDetectionInfo, FlatDetectionInfo, bool>
+struct SortByPriority
 {
     bool operator() (const FlatDetectionInfo& r1, const FlatDetectionInfo& r2) const
     {
@@ -319,30 +323,30 @@ struct SortByPriority : public std::binary_function<FlatDetectionInfo, FlatDetec
         // All things being equal, sort them alphabetically.
         return r1.sType > r2.sType;
     }
-};
+} objSortByPriority;
 
-struct SortByType : public std::binary_function<FlatDetectionInfo, FlatDetectionInfo, bool>
+struct SortByType
 
 {
     bool operator() (const FlatDetectionInfo& r1, const FlatDetectionInfo& r2) const
     {
         return r1.sType > r2.sType;
     }
-};
+} objSortByType;
 
-struct EqualByType : public std::binary_function<FlatDetectionInfo, FlatDetectionInfo, bool>
+struct EqualByType
 {
     bool operator() (const FlatDetectionInfo& r1, const FlatDetectionInfo& r2) const
     {
         return r1.sType == r2.sType;
     }
-};
+} objEqualByType;
 
-class FindByType : std::unary_function<FlatDetectionInfo, bool>
+class FindByType
 {
     OUString maType;
 public:
-    FindByType(const OUString& rType) : maType(rType) {}
+    explicit FindByType(const OUString& rType) : maType(rType) {}
     bool operator() (const FlatDetectionInfo& rInfo) const
     {
         return rInfo.sType == maType;
@@ -369,7 +373,6 @@ void printFlatDetectionList(const char* caption, const FlatDetection& types)
 
 OUString SAL_CALL TypeDetection::queryTypeByDescriptor(css::uno::Sequence< css::beans::PropertyValue >& lDescriptor,
                                                               sal_Bool                                         bAllowDeep )
-    throw (css::uno::RuntimeException, std::exception)
 {
     // make the descriptor more useable :-)
     utl::MediaDescriptor stlDescriptor(lDescriptor);
@@ -410,8 +413,9 @@ OUString SAL_CALL TypeDetection::queryTypeByDescriptor(css::uno::Sequence< css::
         // <- SAFE ----------------------------------
 
         // Properly prioritize all candidate types.
-        lFlatTypes.sort(SortByPriority());
-        lFlatTypes.unique(EqualByType());
+        std::stable_sort(lFlatTypes.begin(), lFlatTypes.end(), objSortByPriority);
+        auto last = std::unique(lFlatTypes.begin(), lFlatTypes.end(), objEqualByType);
+        lFlatTypes.erase(last, lFlatTypes.end());
 
         OUString sLastChance;
 
@@ -426,18 +430,17 @@ OUString SAL_CALL TypeDetection::queryTypeByDescriptor(css::uno::Sequence< css::
         if (lFlatTypes.size()>0)
             sType = impl_detectTypeFlatAndDeep(stlDescriptor, lFlatTypes, bAllowDeep, lUsedDetectors, sLastChance);
 
-
         // flat detection failed
         // pure deep detection failed
         // => ask might existing InteractionHandler
-        // means: ask user for it's decision
-        if (sType.isEmpty())
+        // means: ask user for its decision
+        if (sType.isEmpty() && !m_bCancel)
             sType = impl_askUserForTypeAndFilterIfAllowed(stlDescriptor);
 
 
         // no real detected type - but a might valid one.
         // update descriptor and set last chance for return.
-        if (sType.isEmpty() && !sLastChance.isEmpty())
+        if (sType.isEmpty() && !sLastChance.isEmpty() && !m_bCancel)
         {
             OSL_FAIL("set first flat detected type without a registered deep detection service as \"last chance\" ... nevertheless some other deep detections said \"NO\". I TRY IT!");
             sType = sLastChance;
@@ -449,10 +452,8 @@ OUString SAL_CALL TypeDetection::queryTypeByDescriptor(css::uno::Sequence< css::
     }
     catch(const css::uno::Exception& e)
     {
-        SAL_WARN(
-            "filter.config",
-            "caught Exception \"" << e.Message
-                << "\" while querying type of <" << sURL << ">");
+        SAL_WARN("filter.config", "caught " << e
+                << " while querying type of " << sURL);
         sType.clear();
     }
 
@@ -466,21 +467,22 @@ OUString SAL_CALL TypeDetection::queryTypeByDescriptor(css::uno::Sequence< css::
 }
 
 
-
 void TypeDetection::impl_checkResultsAndAddBestFilter(utl::MediaDescriptor& rDescriptor,
                                                       OUString&               sType      )
 {
     // a)
-    // Dont overwrite a might preselected filter!
+    // Don't overwrite a might preselected filter!
     OUString sFilter = rDescriptor.getUnpackedValueOrDefault(
                                 utl::MediaDescriptor::PROP_FILTERNAME(),
                                 OUString());
     if (!sFilter.isEmpty())
         return;
 
+    auto & cache = TheFilterCache::get();
+
     // b)
     // check a preselected document service too.
-    // Then we have to search a suitable filter witin this module.
+    // Then we have to search a suitable filter within this module.
     OUString sDocumentService = rDescriptor.getUnpackedValueOrDefault(
                                             utl::MediaDescriptor::PROP_DOCUMENTSERVICE(),
                                             OUString());
@@ -496,12 +498,12 @@ void TypeDetection::impl_checkResultsAndAddBestFilter(utl::MediaDescriptor& rDes
             // Attention: For executing next lines of code, We must be sure that
             // all filters already loaded :-(
             // That can disturb our "load on demand feature". But we have no other chance!
-            m_rCache->load(FilterCache::E_CONTAINS_FILTERS);
+            cache.load(FilterCache::E_CONTAINS_FILTERS);
 
             CacheItem lIProps;
             lIProps[PROPNAME_DOCUMENTSERVICE] <<= sDocumentService;
             lIProps[PROPNAME_TYPE           ] <<= sRealType;
-            OUStringList lFilters = m_rCache->getMatchingItemsByProps(FilterCache::E_FILTER, lIProps);
+            OUStringList lFilters = cache.getMatchingItemsByProps(FilterCache::E_FILTER, lIProps);
 
             aLock.clear();
             // <- SAFE
@@ -513,13 +515,13 @@ void TypeDetection::impl_checkResultsAndAddBestFilter(utl::MediaDescriptor& rDes
                 aLock.reset();
                 try
                 {
-                    CacheItem aFilter = m_rCache->getItem(FilterCache::E_FILTER, *pIt);
+                    CacheItem aFilter = cache.getItem(FilterCache::E_FILTER, *pIt);
                     sal_Int32 nFlags  = 0;
                     aFilter[PROPNAME_FLAGS] >>= nFlags;
 
-                    if ((nFlags & FLAGVAL_IMPORT) == FLAGVAL_IMPORT)
+                    if (static_cast<SfxFilterFlags>(nFlags) & SfxFilterFlags::IMPORT)
                         sFilter = *pIt;
-                    if ((nFlags & FLAGVAL_PREFERRED) == FLAGVAL_PREFERRED)
+                    if (static_cast<SfxFilterFlags>(nFlags) & SfxFilterFlags::PREFERED)
                         break;
                 }
                 catch(const css::uno::Exception&) {}
@@ -552,9 +554,9 @@ void TypeDetection::impl_checkResultsAndAddBestFilter(utl::MediaDescriptor& rDes
         // SAFE ->
         ::osl::ResettableMutexGuard aLock(m_aLock);
 
-        CacheItem aType = m_rCache->getItem(FilterCache::E_TYPE, sType);
+        CacheItem aType = cache.getItem(FilterCache::E_TYPE, sType);
         aType[PROPNAME_PREFERREDFILTER] >>= sFilter;
-        CacheItem aFilter = m_rCache->getItem(FilterCache::E_FILTER, sFilter);
+        CacheItem aFilter = cache.getItem(FilterCache::E_FILTER, sFilter);
 
         aLock.clear();
         // <- SAFE
@@ -578,11 +580,11 @@ void TypeDetection::impl_checkResultsAndAddBestFilter(utl::MediaDescriptor& rDes
         // Attention: For executing next lines of code, We must be sure that
         // all filters already loaded :-(
         // That can disturb our "load on demand feature". But we have no other chance!
-        m_rCache->load(FilterCache::E_CONTAINS_FILTERS);
+        cache.load(FilterCache::E_CONTAINS_FILTERS);
 
         CacheItem lIProps;
         lIProps[PROPNAME_TYPE] <<= sType;
-        OUStringList lFilters = m_rCache->getMatchingItemsByProps(FilterCache::E_FILTER, lIProps);
+        OUStringList lFilters = cache.getMatchingItemsByProps(FilterCache::E_FILTER, lIProps);
 
         aLock.clear();
         // <- SAFE
@@ -598,11 +600,11 @@ void TypeDetection::impl_checkResultsAndAddBestFilter(utl::MediaDescriptor& rDes
             aLock.reset();
             try
             {
-                CacheItem aFilter = m_rCache->getItem(FilterCache::E_FILTER, sFilter);
+                CacheItem aFilter = cache.getItem(FilterCache::E_FILTER, sFilter);
                 sal_Int32 nFlags  = 0;
                 aFilter[PROPNAME_FLAGS] >>= nFlags;
 
-                if ((nFlags & FLAGVAL_IMPORT) == FLAGVAL_IMPORT)
+                if (static_cast<SfxFilterFlags>(nFlags) & SfxFilterFlags::IMPORT)
                     break;
             }
             catch(const css::uno::Exception&)
@@ -625,22 +627,21 @@ void TypeDetection::impl_checkResultsAndAddBestFilter(utl::MediaDescriptor& rDes
 }
 
 
-
 bool TypeDetection::impl_getPreselectionForType(
     const OUString& sPreSelType, const util::URL& aParsedURL, FlatDetection& rFlatTypes, bool bDocService)
 {
     // Can be used to suppress execution of some parts of this method
     // if its already clear that detected type is valid or not.
     // Its necessary to use shared code at the end, which update
-    // all return parameters constistency!
+    // all return parameters consistency!
     bool bBreakDetection = false;
 
     // Further we must know if it matches by pattern
-    // Every flat detected type by pattern wont be detected deep!
+    // Every flat detected type by pattern won't be detected deep!
     bool bMatchByPattern = false;
 
     // And we must know if a preselection must be preferred, because
-    // it matches by it's extension too.
+    // it matches by its extension too.
     bool bMatchByExtension = false;
 
     // validate type
@@ -650,7 +651,7 @@ bool TypeDetection::impl_getPreselectionForType(
     {
         // SAFE -> --------------------------
         ::osl::ResettableMutexGuard aLock(m_aLock);
-        aType = m_rCache->getItem(FilterCache::E_TYPE, sType);
+        aType = TheFilterCache::get().getItem(FilterCache::E_TYPE, sType);
         aLock.clear();
         // <- SAFE --------------------------
     }
@@ -674,20 +675,20 @@ bool TypeDetection::impl_getPreselectionForType(
         INetURLObject   aParser    (aParsedURL.Main);
         OUString sExtension = aParser.getExtension(INetURLObject::LAST_SEGMENT       ,
                                                           true                          ,
-                                                          INetURLObject::DECODE_WITH_CHARSET);
+                                                          INetURLObject::DecodeMechanism::WithCharset);
         sExtension = sExtension.toAsciiLowerCase();
 
         // otherwise we must know, if it matches to the given URL really.
         // especially if it matches by its extension or pattern registration.
-        OUStringList lExtensions(aType[PROPNAME_EXTENSIONS]);
-        OUStringList lURLPattern(aType[PROPNAME_URLPATTERN]);
+        OUStringList lExtensions(comphelper::sequenceToContainer<OUStringList>(aType[PROPNAME_EXTENSIONS].get<css::uno::Sequence<OUString> >() ));
+        OUStringList lURLPattern(comphelper::sequenceToContainer<OUStringList>(aType[PROPNAME_URLPATTERN].get<css::uno::Sequence<OUString> >() ));
 
         for (OUStringList::const_iterator pIt  = lExtensions.begin();
                                           pIt != lExtensions.end()  ;
                                         ++pIt                       )
         {
             OUString sCheckExtension(pIt->toAsciiLowerCase());
-            if (sCheckExtension.equals(sExtension))
+            if (sCheckExtension == sExtension)
             {
                 bBreakDetection        = true;
                 bMatchByExtension      = true;
@@ -704,7 +705,6 @@ bool TypeDetection::impl_getPreselectionForType(
                 WildCard aCheck(*pIt);
                 if (aCheck.Matches(aParsedURL.Main))
                 {
-                    bBreakDetection        = true;
                     bMatchByPattern        = true;
                     break;
                 }
@@ -746,11 +746,12 @@ bool TypeDetection::impl_getPreselectionForDocumentService(
         // Attention: For executing next lines of code, We must be sure that
         // all filters already loaded :-(
         // That can disturb our "load on demand feature". But we have no other chance!
-        m_rCache->load(FilterCache::E_CONTAINS_FILTERS);
+        auto & cache = TheFilterCache::get();
+        cache.load(FilterCache::E_CONTAINS_FILTERS);
 
         CacheItem lIProps;
         lIProps[PROPNAME_DOCUMENTSERVICE] <<= sPreSelDocumentService;
-        lFilters = m_rCache->getMatchingItemsByProps(FilterCache::E_FILTER, lIProps);
+        lFilters = cache.getMatchingItemsByProps(FilterCache::E_FILTER, lIProps);
 
         aLock.clear();
         // <- SAFE --------------------------
@@ -763,8 +764,8 @@ bool TypeDetection::impl_getPreselectionForDocumentService(
     // step over all filters, and check if its registered type
     // match the given URL.
     // But use temp. list of "preselected types" instead of incoming rFlatTypes list!
-    // The reason behind: we must filter the getted results. And copying of stl entries
-    // is an easier job then removing it .-)
+    // The reason behind: we must filter the obtained results. And copying stl entries
+    // is an easier job than removing them .-)
     for (OUStringList::const_iterator pFilter  = lFilters.begin();
          pFilter != lFilters.end();
          ++pFilter)
@@ -785,7 +786,7 @@ OUString TypeDetection::impl_getTypeFromFilter(const OUString& rFilterName)
     try
     {
         osl::MutexGuard aLock(m_aLock);
-        aFilter = m_rCache->getItem(FilterCache::E_FILTER, rFilterName);
+        aFilter = TheFilterCache::get().getItem(FilterCache::E_FILTER, rFilterName);
     }
     catch (const container::NoSuchElementException&)
     {
@@ -798,7 +799,7 @@ OUString TypeDetection::impl_getTypeFromFilter(const OUString& rFilterName)
 }
 
 void TypeDetection::impl_getAllFormatTypes(
-    const util::URL& aParsedURL, utl::MediaDescriptor& rDescriptor, FlatDetection& rFlatTypes)
+    const util::URL& aParsedURL, utl::MediaDescriptor const & rDescriptor, FlatDetection& rFlatTypes)
 {
     rFlatTypes.clear();
 
@@ -807,8 +808,9 @@ void TypeDetection::impl_getAllFormatTypes(
     try
     {
         osl::MutexGuard aLock(m_aLock);
-        m_rCache->load(FilterCache::E_CONTAINS_FILTERS);
-        aFilterNames = m_rCache->getItemNames(FilterCache::E_FILTER);
+        auto & cache = TheFilterCache::get();
+        cache.load(FilterCache::E_CONTAINS_FILTERS);
+        aFilterNames = cache.getItemNames(FilterCache::E_FILTER);
     }
     catch (const container::NoSuchElementException&)
     {
@@ -831,7 +833,7 @@ void TypeDetection::impl_getAllFormatTypes(
     {
         // Get all types that match the URL alone.
         FlatDetection aFlatByURL;
-        m_rCache->detectFlatForURL(aParsedURL, aFlatByURL);
+        TheFilterCache::get().detectFlatForURL(aParsedURL, aFlatByURL);
         FlatDetection::const_iterator it = aFlatByURL.begin(), itEnd = aFlatByURL.end();
         for (; it != itEnd; ++it)
         {
@@ -855,8 +857,9 @@ void TypeDetection::impl_getAllFormatTypes(
     }
 
     // Remove duplicates.
-    rFlatTypes.sort(SortByType());
-    rFlatTypes.unique(EqualByType());
+    std::stable_sort(rFlatTypes.begin(), rFlatTypes.end(), objSortByType);
+    auto last = std::unique(rFlatTypes.begin(), rFlatTypes.end(), objEqualByType);
+    rFlatTypes.erase(last, rFlatTypes.end());
 
     // Mark pre-selected type (if any) to have it prioritized.
     OUString sSelectedType = rDescriptor.getUnpackedValueOrDefault(utl::MediaDescriptor::PROP_TYPENAME(), OUString());
@@ -870,7 +873,6 @@ void TypeDetection::impl_getAllFormatTypes(
 }
 
 
-
 OUString TypeDetection::impl_detectTypeFlatAndDeep(      utl::MediaDescriptor& rDescriptor   ,
                                                           const FlatDetection&                 lFlatTypes    ,
                                                                 bool                       bAllowDeep    ,
@@ -885,7 +887,7 @@ OUString TypeDetection::impl_detectTypeFlatAndDeep(      utl::MediaDescriptor& r
     // step over all possible types for this URL.
     // solutions:
     // a) no types                                => no detection
-    // b) deep detection not allowed              => return first valid type of list (because its the preferred or the first valid one)
+    // b) deep detection not allowed              => return first valid type of list (because it's the preferred or the first valid one)
     //    or(!) match by URLPattern               => in such case a deep detection will be suppressed!
     // c) type has no detect service              => safe the first occurred type without a detect service
     //                                               as "last chance"(!). It will be used outside of this method
@@ -895,10 +897,10 @@ OUString TypeDetection::impl_detectTypeFlatAndDeep(      utl::MediaDescriptor& r
     // d) detect service return a valid result    => return its decision
     // e) detect service return an invalid result
     //    or any needed information could not be
-    //    getted from the cache                   => ignore it, and continue with search
+    //    obtained from the cache                 => ignore it, and continue with search
 
     for (FlatDetection::const_iterator pFlatIt  = lFlatTypes.begin();
-                                       pFlatIt != lFlatTypes.end()  ;
+                                       pFlatIt != lFlatTypes.end() && !m_bCancel;
                                      ++pFlatIt                      )
     {
         const FlatDetectionInfo& aFlatTypeInfo = *pFlatIt;
@@ -920,7 +922,7 @@ OUString TypeDetection::impl_detectTypeFlatAndDeep(      utl::MediaDescriptor& r
         {
             // SAFE -> ----------------------------------
             ::osl::ResettableMutexGuard aLock(m_aLock);
-            CacheItem aType = m_rCache->getItem(FilterCache::E_TYPE, sFlatType);
+            CacheItem aType = TheFilterCache::get().getItem(FilterCache::E_TYPE, sFlatType);
             aLock.clear();
 
             OUString sDetectService;
@@ -939,7 +941,7 @@ OUString TypeDetection::impl_detectTypeFlatAndDeep(      utl::MediaDescriptor& r
                 continue;
             }
 
-            // dont forget to add every real asked deep detection service here.
+            // don't forget to add every real asked deep detection service here.
             // Such detectors will be ignored if may be "impl_detectTypeDeepOnly()"
             // must be called later!
             rUsedDetectors.push_back(sDetectService);
@@ -958,7 +960,7 @@ OUString TypeDetection::impl_detectTypeFlatAndDeep(      utl::MediaDescriptor& r
     // <- SAFE ----------------------------------
 }
 
-void TypeDetection::impl_seekStreamToZero(utl::MediaDescriptor& rDescriptor)
+void TypeDetection::impl_seekStreamToZero(utl::MediaDescriptor const & rDescriptor)
 {
     // try to seek to 0 ...
     // But because XSeekable is an optional interface ... try it only .-)
@@ -1013,7 +1015,7 @@ OUString TypeDetection::impl_askDetectService(const OUString&               sDet
         // third party components here, which can make trouble anyway.  So we
         // should handle errors during creation of such services more
         // gracefully .-)
-        xDetector = css::uno::Reference< css::document::XExtendedFilterDetection >(
+        xDetector.set(
                 xContext->getServiceManager()->createInstanceWithContext(sDetectService, xContext),
                 css::uno::UNO_QUERY_THROW);
     }
@@ -1028,7 +1030,7 @@ OUString TypeDetection::impl_askDetectService(const OUString&               sDet
     try
     {
         // start deep detection
-        // Dont forget to convert stl descriptor to its uno representation.
+        // Don't forget to convert stl descriptor to its uno representation.
 
         /* Attention!
                 You have to use an explicit instance of this uno sequence ...
@@ -1040,14 +1042,14 @@ OUString TypeDetection::impl_askDetectService(const OUString&               sDet
         sDeepType = xDetector->detect(lDescriptor);
         rDescriptor << lDescriptor;
     }
-    catch(const css::uno::Exception&)
-        {
-            // We should ignore errors here.
-            // Thrown exceptions mostly will end in crash recovery ...
-            // But might be we find another deep detection service which can detect the same
-            // document without a problem .-)
-            sDeepType.clear();
-        }
+    catch (...)
+    {
+        // We should ignore errors here.
+        // Thrown exceptions mostly will end in crash recovery ...
+        // But might be we find another deep detection service which can detect the same
+        // document without a problem .-)
+        sDeepType.clear();
+    }
 
     // seek to 0 is an optional feature to be more robust against
     // "simple implemented detect services" .-)
@@ -1068,7 +1070,6 @@ OUString TypeDetection::impl_askDetectService(const OUString&               sDet
 }
 
 
-
 OUString TypeDetection::impl_askUserForTypeAndFilterIfAllowed(utl::MediaDescriptor& rDescriptor)
 {
     css::uno::Reference< css::task::XInteractionHandler > xInteraction =
@@ -1086,9 +1087,9 @@ OUString TypeDetection::impl_askUserForTypeAndFilterIfAllowed(utl::MediaDescript
         rDescriptor.getUnpackedValueOrDefault(utl::MediaDescriptor::PROP_INPUTSTREAM(),
         css::uno::Reference< css::io::XInputStream >());
 
-    // Dont distrub the user for "non existing files - means empty URLs" or
+    // Don't disturb the user for "non existing files - means empty URLs" or
     // if we was forced to detect a stream.
-    // Reason behind: We must be sure to ask user for "unknown contents" only ...
+    // Reason behind: we must be sure to ask user for "unknown contents" only...
     // and not for "missing files". Especially if detection is done by a stream only
     // we can't check if the stream points to an "existing content"!
     if (
@@ -1100,7 +1101,7 @@ OUString TypeDetection::impl_askUserForTypeAndFilterIfAllowed(utl::MediaDescript
 
     try
     {
-        // create a new request to ask user for it's decision about the usable filter
+        // create a new request to ask user for its decision about the usable filter
         ::framework::RequestFilterSelect aRequest(sURL);
         xInteraction->handle(aRequest.GetRequest());
 
@@ -1110,9 +1111,9 @@ OUString TypeDetection::impl_askUserForTypeAndFilterIfAllowed(utl::MediaDescript
 
         // "OK" pressed => verify the selected filter, get its corresponding
         // type and return it. (BTW: We must update the media descriptor here ...)
-        // The user selected explicitly a filter ... but normaly we are interested on
+        // The user selected explicitly a filter ... but normally we are interested on
         // a type here only. But we must be sure, that the selected filter is used
-        // too and no ambigous filter registration disturb us .-)
+        // too and no ambiguous filter registration disturb us .-)
 
         OUString sFilter = aRequest.getFilter();
         if (!impl_validateAndSetFilterOnDescriptor(rDescriptor, sFilter))
@@ -1129,14 +1130,12 @@ OUString TypeDetection::impl_askUserForTypeAndFilterIfAllowed(utl::MediaDescript
 }
 
 
-
 void TypeDetection::impl_openStream(utl::MediaDescriptor& rDescriptor)
-    throw (css::uno::Exception)
 {
     bool bSuccess = false;
     OUString sURL = rDescriptor.getUnpackedValueOrDefault( utl::MediaDescriptor::PROP_URL(), OUString() );
-    bool bRequestedReadOnly = rDescriptor.getUnpackedValueOrDefault( utl::MediaDescriptor::PROP_READONLY(), sal_False );
-    if ( !sURL.isEmpty() && ::utl::LocalFileHelper::IsLocalFile( INetURLObject( sURL ).GetMainURL( INetURLObject::NO_DECODE ) ) )
+    bool bRequestedReadOnly = rDescriptor.getUnpackedValueOrDefault( utl::MediaDescriptor::PROP_READONLY(), false );
+    if ( comphelper::isFileUrl( sURL ) )
     {
         // OOo uses own file locking mechanics in case of local file
         bSuccess = rDescriptor.addInputStreamOwnLock();
@@ -1160,7 +1159,6 @@ void TypeDetection::impl_openStream(utl::MediaDescriptor& rDescriptor)
 }
 
 
-
 void TypeDetection::impl_removeTypeFilterFromDescriptor(utl::MediaDescriptor& rDescriptor)
 {
     utl::MediaDescriptor::iterator pItType   = rDescriptor.find(utl::MediaDescriptor::PROP_TYPENAME()  );
@@ -1172,13 +1170,12 @@ void TypeDetection::impl_removeTypeFilterFromDescriptor(utl::MediaDescriptor& rD
 }
 
 
-
 bool TypeDetection::impl_validateAndSetTypeOnDescriptor(      utl::MediaDescriptor& rDescriptor,
                                                             const OUString&               sType      )
 {
     // SAFE ->
     ::osl::ResettableMutexGuard aLock(m_aLock);
-    if (m_rCache->hasItem(FilterCache::E_TYPE, sType))
+    if (TheFilterCache::get().hasItem(FilterCache::E_TYPE, sType))
     {
         rDescriptor[utl::MediaDescriptor::PROP_TYPENAME()] <<= sType;
         return true;
@@ -1192,7 +1189,6 @@ bool TypeDetection::impl_validateAndSetTypeOnDescriptor(      utl::MediaDescript
 }
 
 
-
 bool TypeDetection::impl_validateAndSetFilterOnDescriptor(      utl::MediaDescriptor& rDescriptor,
                                                               const OUString&               sFilter    )
 {
@@ -1201,10 +1197,11 @@ bool TypeDetection::impl_validateAndSetFilterOnDescriptor(      utl::MediaDescri
         // SAFE ->
         ::osl::ResettableMutexGuard aLock(m_aLock);
 
-        CacheItem aFilter = m_rCache->getItem(FilterCache::E_FILTER, sFilter);
+        auto & cache = TheFilterCache::get();
+        CacheItem aFilter = cache.getItem(FilterCache::E_FILTER, sFilter);
         OUString sType;
         aFilter[PROPNAME_TYPE] >>= sType;
-        CacheItem aType = m_rCache->getItem(FilterCache::E_TYPE, sType);
+        CacheItem aType = cache.getItem(FilterCache::E_TYPE, sType);
 
         aLock.clear();
         // <- SAFE
@@ -1222,23 +1219,18 @@ bool TypeDetection::impl_validateAndSetFilterOnDescriptor(      utl::MediaDescri
 }
 
 
-
 OUString TypeDetection::impl_getImplementationName()
 {
     return OUString( "com.sun.star.comp.filter.config.TypeDetection" );
 }
 
 
-
 css::uno::Sequence< OUString > TypeDetection::impl_getSupportedServiceNames()
 {
-    css::uno::Sequence< OUString > lServiceNames(1);
-    lServiceNames[0] = "com.sun.star.document.TypeDetection";
-    return lServiceNames;
+    return { "com.sun.star.document.TypeDetection" };
 }
 
 
-
 css::uno::Reference< css::uno::XInterface > SAL_CALL TypeDetection::impl_createInstance(const css::uno::Reference< css::lang::XMultiServiceFactory >& xSMGR)
 {
     TypeDetection* pNew = new TypeDetection( comphelper::getComponentContext(xSMGR) );
