@@ -17,6 +17,9 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
+#include <sal/config.h>
+
+#include <o3tl/any.hxx>
 #include <vcl/bitmapex.hxx>
 #include <com/sun/star/drawing/XDrawPagesSupplier.hpp>
 #include <com/sun/star/drawing/LineStyle.hpp>
@@ -41,22 +44,26 @@
 
 #include <comphelper/processfactory.hxx>
 #include <toolkit/helper/vclunohelper.hxx>
+#include <vcl/gradient.hxx>
 
 #include "main.hxx"
 #include "outact.hxx"
 
+
 using namespace ::com::sun::star;
 
-// ---------------------------------------------------------------
-
-CGMImpressOutAct::CGMImpressOutAct( CGM& rCGM, const uno::Reference< frame::XModel > & rModel ) :
-        CGMOutAct       ( rCGM ),
-        nFinalTextCount ( 0 )
+CGMImpressOutAct::CGMImpressOutAct(CGM& rCGM, const uno::Reference< frame::XModel > & rModel)
+    : mnCurrentPage(0)
+    , mnGroupActCount(0)
+    , mnGroupLevel(0)
+    , maGroupLevel()
+    , mpCGM(&rCGM)
+    , nFinalTextCount(0)
 {
-    sal_Bool bStatRet = sal_False;
-
     if ( mpCGM->mbStatus )
     {
+        bool bStatRet = false;
+
         uno::Reference< drawing::XDrawPagesSupplier >  aDrawPageSup( rModel, uno::UNO_QUERY );
         if( aDrawPageSup.is() )
         {
@@ -66,65 +73,59 @@ CGMImpressOutAct::CGMImpressOutAct( CGM& rCGM, const uno::Reference< frame::XMod
                 maXMultiServiceFactory.set( rModel, uno::UNO_QUERY);
                 if( maXMultiServiceFactory.is() )
                 {
-                    maXDrawPage = *(uno::Reference< drawing::XDrawPage > *)maXDrawPages->getByIndex( 0 ).getValue();
+                    maXDrawPage = *o3tl::doAccess<uno::Reference<drawing::XDrawPage>>(maXDrawPages->getByIndex( 0 ));
                     if ( ImplInitPage() )
-                        bStatRet = sal_True;
+                        bStatRet = true;
                 }
             }
         }
         mpCGM->mbStatus = bStatRet;
     }
-};
+}
 
-// ---------------------------------------------------------------
-
-sal_Bool CGMImpressOutAct::ImplInitPage()
+CGMImpressOutAct::~CGMImpressOutAct()
 {
-    sal_Bool    bStatRet = sal_False;
+}
+
+bool CGMImpressOutAct::ImplInitPage()
+{
+    bool    bStatRet = false;
     if( maXDrawPage.is() )
     {
         maXShapes = uno::Reference< drawing::XShapes >( maXDrawPage, uno::UNO_QUERY );
         if ( maXShapes.is() )
         {
-            bStatRet = sal_True;
+            bStatRet = true;
         }
     }
     return bStatRet;
 }
 
-// ---------------------------------------------------------------
 
-sal_Bool CGMImpressOutAct::ImplCreateShape( const OUString& rType )
+bool CGMImpressOutAct::ImplCreateShape( const OUString& rType )
 {
     uno::Reference< uno::XInterface > xNewShape( maXMultiServiceFactory->createInstance( rType ) );
-    maXShape = uno::Reference< drawing::XShape >( xNewShape, uno::UNO_QUERY );
-    maXPropSet = uno::Reference< beans::XPropertySet >( xNewShape, uno::UNO_QUERY );
+    maXShape.set( xNewShape, uno::UNO_QUERY );
+    maXPropSet.set( xNewShape, uno::UNO_QUERY );
     if ( maXShape.is() && maXPropSet.is() )
     {
         maXShapes->add( maXShape );
-        return sal_True;
+        return true;
     }
-    return sal_False;
+    return false;
 }
 
-// ---------------------------------------------------------------
 
-void CGMImpressOutAct::ImplSetOrientation( FloatPoint& rRefPoint, double& rOrientation )
+void CGMImpressOutAct::ImplSetOrientation( FloatPoint const & rRefPoint, double rOrientation )
 {
-    uno::Any aAny;
-    aAny <<= (sal_Int32)rRefPoint.X;
-    maXPropSet->setPropertyValue( "RotationPointX", aAny );
-    aAny <<= (sal_Int32)rRefPoint.Y;
-    maXPropSet->setPropertyValue( "RotationPointY", aAny );
-    aAny <<= (sal_Int32)( rOrientation * 100.0 );
-    maXPropSet->setPropertyValue( "RotateAngle", aAny );
+    maXPropSet->setPropertyValue( "RotationPointX", uno::Any((sal_Int32)rRefPoint.X) );
+    maXPropSet->setPropertyValue( "RotationPointY", uno::Any((sal_Int32)rRefPoint.Y) );
+    maXPropSet->setPropertyValue( "RotateAngle", uno::Any((sal_Int32)( rOrientation * 100.0 )) );
 }
 
-// ---------------------------------------------------------------
 
 void CGMImpressOutAct::ImplSetLineBundle()
 {
-    uno::Any            aAny;
     drawing::LineStyle  eLS;
 
     sal_uInt32          nLineColor;
@@ -144,11 +145,9 @@ void CGMImpressOutAct::ImplSetLineBundle()
     else
         fLineWidth = mpCGM->pElement->aLineBundle.nLineWidth;
 
-    aAny <<= (sal_Int32)nLineColor;
-    maXPropSet->setPropertyValue( "LineColor", aAny );
+    maXPropSet->setPropertyValue( "LineColor", uno::Any((sal_Int32)nLineColor) );
 
-    aAny <<= (sal_Int32)fLineWidth;
-    maXPropSet->setPropertyValue( "LineWidth", aAny );
+    maXPropSet->setPropertyValue( "LineWidth", uno::Any((sal_Int32)fLineWidth) );
 
     switch( eLineType )
     {
@@ -168,22 +167,16 @@ void CGMImpressOutAct::ImplSetLineBundle()
             eLS = drawing::LineStyle_SOLID;
         break;
     }
-    aAny <<= eLS;
-    maXPropSet->setPropertyValue( "LineStyle", aAny );
+    maXPropSet->setPropertyValue( "LineStyle", uno::Any(eLS) );
     if ( eLS == drawing::LineStyle_DASH )
     {
         drawing::LineDash aLineDash( drawing::DashStyle_RECTRELATIVE, 1, 50, 3, 33, 100 );
-        aAny <<= aLineDash;
-        maXPropSet->setPropertyValue( "LineDash", aAny );
+        maXPropSet->setPropertyValue( "LineDash", uno::Any(aLineDash) );
     }
-};
-
-// ---------------------------------------------------------------
+}
 
 void CGMImpressOutAct::ImplSetFillBundle()
 {
-
-    uno::Any                aAny;
     drawing::LineStyle      eLS;
     drawing::FillStyle      eFS;
 
@@ -226,8 +219,7 @@ void CGMImpressOutAct::ImplSetFillBundle()
     else
         nHatchIndex = (sal_uInt32)mpCGM->pElement->aFillBundle.nFillHatchIndex;
 
-    aAny <<= (sal_Int32)nFillColor;
-    maXPropSet->setPropertyValue( "FillColor", aAny );
+    maXPropSet->setPropertyValue( "FillColor", uno::Any((sal_Int32)nFillColor) );
 
     switch ( eFillStyle )
     {
@@ -274,28 +266,22 @@ void CGMImpressOutAct::ImplSetFillBundle()
 
     if ( eFS == drawing::FillStyle_GRADIENT )
     {
-        aAny <<= *mpGradient;
-        maXPropSet->setPropertyValue( "FillGradient", aAny );
+        maXPropSet->setPropertyValue( "FillGradient", uno::Any(*mpGradient) );
     }
-    aAny <<= eFS;
-    maXPropSet->setPropertyValue( "FillStyle", aAny );
+    maXPropSet->setPropertyValue( "FillStyle", uno::Any(eFS) );
 
     eLS = drawing::LineStyle_NONE;
     if ( eFillStyle == FIS_HOLLOW )
     {
         eLS = drawing::LineStyle_SOLID;
-        aAny <<= (sal_Int32)nFillColor;
-        maXPropSet->setPropertyValue( "LineColor", aAny );
-        aAny <<= (sal_Int32)0;
-        maXPropSet->setPropertyValue( "LineWidth", aAny );
+        maXPropSet->setPropertyValue( "LineColor", uno::Any((sal_Int32)nFillColor) );
+        maXPropSet->setPropertyValue( "LineWidth", uno::Any((sal_Int32)0) );
     }
     else if ( eEdgeType != ET_NONE )
     {
-        aAny <<= (sal_Int32)nEdgeColor;
-        maXPropSet->setPropertyValue( "LineColor", aAny );
+        maXPropSet->setPropertyValue( "LineColor", uno::Any((sal_Int32)nEdgeColor) );
 
-        aAny <<= (sal_Int32)fEdgeWidth;
-        maXPropSet->setPropertyValue( "LineWidth", aAny );
+        maXPropSet->setPropertyValue( "LineWidth", uno::Any((sal_Int32)fEdgeWidth) );
 
         switch( eEdgeType )
         {
@@ -314,8 +300,7 @@ void CGMImpressOutAct::ImplSetFillBundle()
         }
     }
 
-    aAny <<= eLS;
-    maXPropSet->setPropertyValue( "LineStyle", aAny );
+    maXPropSet->setPropertyValue( "LineStyle", uno::Any(eLS) );
 
     if ( eFS == drawing::FillStyle_HATCH )
     {
@@ -340,16 +325,12 @@ void CGMImpressOutAct::ImplSetFillBundle()
             aHatch.Distance = 10 * ( nHatchIndex & 0x1f ) | 100;
             aHatch.Angle = 15 * ( ( nHatchIndex & 0x1f ) - 5 );
         }
-        aAny <<= aHatch;
-        maXPropSet->setPropertyValue( "FillHatch", aAny );
+        maXPropSet->setPropertyValue( "FillHatch", uno::Any(aHatch) );
     }
-};
-
-// ---------------------------------------------------------------
+}
 
 void CGMImpressOutAct::ImplSetTextBundle( const uno::Reference< beans::XPropertySet > & rProperty )
 {
-    uno::Any        aAny;
     sal_uInt32      nTextFontIndex;
     sal_uInt32      nTextColor;
 
@@ -362,8 +343,7 @@ void CGMImpressOutAct::ImplSetTextBundle( const uno::Reference< beans::XProperty
     else
         nTextColor = mpCGM->pElement->aTextBundle.GetColor();
 
-    aAny <<= (sal_Int32)nTextColor;
-    rProperty->setPropertyValue( "CharColor", aAny );
+    rProperty->setPropertyValue( "CharColor", uno::Any((sal_Int32)nTextColor) );
 
     sal_uInt32 nFontType = 0;
     awt::FontDescriptor aFontDescriptor;
@@ -371,9 +351,9 @@ void CGMImpressOutAct::ImplSetTextBundle( const uno::Reference< beans::XProperty
     if ( pFontEntry )
     {
         nFontType = pFontEntry->nFontType;
-        aFontDescriptor.Name = OUString::createFromAscii( (const char*)pFontEntry->pFontName );
+        aFontDescriptor.Name = OUString::createFromAscii( reinterpret_cast<char*>(pFontEntry->pFontName.get()) );
     }
-    aFontDescriptor.Height = ( sal_Int16 )( ( mpCGM->pElement->nCharacterHeight * (double)1.50 ) );
+    aFontDescriptor.Height = sal_Int16( mpCGM->pElement->nCharacterHeight * 1.50 );
     if ( nFontType & 1 )
         aFontDescriptor.Slant = awt::FontSlant_ITALIC;
     if ( nFontType & 2 )
@@ -385,11 +365,8 @@ void CGMImpressOutAct::ImplSetTextBundle( const uno::Reference< beans::XProperty
     {
         aFontDescriptor.Underline = awt::FontUnderline::SINGLE;
     }
-    aAny <<= aFontDescriptor;
-    rProperty->setPropertyValue( "FontDescriptor", aAny );
-};
-
-// ---------------------------------------------------------------
+    rProperty->setPropertyValue( "FontDescriptor", uno::Any(aFontDescriptor) );
+}
 
 void CGMImpressOutAct::InsertPage()
 {
@@ -397,25 +374,21 @@ void CGMImpressOutAct::InsertPage()
     {
         uno::Reference< drawing::XDrawPage > xPage( maXDrawPages->insertNewByIndex( 0xffff ), uno::UNO_QUERY );
         maXDrawPage = xPage;
-        if ( ImplInitPage() == sal_False )
-            mpCGM->mbStatus = sal_False;
+        if ( !ImplInitPage() )
+            mpCGM->mbStatus = false;
     }
     mnCurrentPage++;
-};
-
-// ---------------------------------------------------------------
+}
 
 void CGMImpressOutAct::BeginGroup()
 {
     if ( mnGroupLevel < CGM_OUTACT_MAX_GROUP_LEVEL )
     {
-        mpGroupLevel[ mnGroupLevel ] = maXShapes->getCount();
+        maGroupLevel[mnGroupLevel] = maXShapes->getCount();
     }
     mnGroupLevel++;
     mnGroupActCount = mpCGM->mnActCount;
-};
-
-// ---------------------------------------------------------------
+}
 
 void CGMImpressOutAct::EndGroup()
 {
@@ -423,32 +396,30 @@ void CGMImpressOutAct::EndGroup()
         mnGroupLevel--;
     if ( mnGroupLevel < CGM_OUTACT_MAX_GROUP_LEVEL )
     {
-        sal_uInt32 mnFirstIndex = mpGroupLevel[ mnGroupLevel ];
-        if ( mnFirstIndex == 0xffffffff )
-            mnFirstIndex = 0;
-        sal_uInt32 mnCurrentCount = maXShapes->getCount();
-        if ( ( mnCurrentCount - mnFirstIndex ) > 1 )
+        sal_uInt32 nFirstIndex = maGroupLevel[mnGroupLevel];
+        if ( nFirstIndex == 0xffffffff )
+            nFirstIndex = 0;
+        sal_uInt32 nCurrentCount = maXShapes->getCount();
+        if ( ( nCurrentCount - nFirstIndex ) > 1 )
         {
             uno::Reference< drawing::XShapeGrouper > aXShapeGrouper;
             aXShapeGrouper.set( maXDrawPage, uno::UNO_QUERY );
             if( aXShapeGrouper.is() )
             {
                 uno::Reference< drawing::XShapes >  aXShapes = drawing::ShapeCollection::create(comphelper::getProcessComponentContext());
-                for ( sal_uInt32 i = mnFirstIndex; i < mnCurrentCount; i++ )
+                for ( sal_uInt32 i = nFirstIndex; i < nCurrentCount; i++ )
                 {
-                    uno::Reference< drawing::XShape >  aXShape = *(uno::Reference< drawing::XShape > *)maXShapes->getByIndex( i ).getValue();
+                    uno::Reference< drawing::XShape >  aXShape = *o3tl::doAccess<uno::Reference<drawing::XShape>>(maXShapes->getByIndex( i ));
                     if (aXShape.is() )
                     {
                         aXShapes->add( aXShape );
                     }
                 }
-                uno::Reference< drawing::XShapeGroup >  aXShapeGroup = aXShapeGrouper->group( aXShapes );
+                aXShapeGrouper->group( aXShapes );
             }
         }
     }
-};
-
-// ---------------------------------------------------------------
+}
 
 void CGMImpressOutAct::EndGrouping()
 {
@@ -458,9 +429,7 @@ void CGMImpressOutAct::EndGrouping()
     }
 }
 
-// ---------------------------------------------------------------
-
-void CGMImpressOutAct::DrawRectangle( FloatRect& rFloatRect )
+void CGMImpressOutAct::DrawRectangle( FloatRect const & rFloatRect )
 {
     if ( mnGroupActCount != ( mpCGM->mnActCount - 1 ) )         // POWERPOINT HACK !!!
     {
@@ -472,16 +441,14 @@ void CGMImpressOutAct::DrawRectangle( FloatRect& rFloatRect )
             ImplSetFillBundle();
         }
     }
-};
+}
 
-// ---------------------------------------------------------------
-
-void CGMImpressOutAct::DrawEllipse( FloatPoint& rCenter, FloatPoint& rSize, double& rOrientation )
+void CGMImpressOutAct::DrawEllipse( FloatPoint const & rCenter, FloatPoint const & rSize, double& rOrientation )
 {
     if ( ImplCreateShape( "com.sun.star.drawing.EllipseShape" ) )
     {
         drawing::CircleKind eCircleKind = drawing::CircleKind_FULL;
-        uno::Any aAny( &eCircleKind, ::getCppuType((const drawing::CircleKind*)0) );
+        uno::Any aAny( &eCircleKind, ::cppu::UnoType<drawing::CircleKind>::get() );
         maXPropSet->setPropertyValue( "CircleKind", aAny );
 
         long nXSize = (long)( rSize.X * 2.0 );      // strange behaviour with a awt::Size of 0
@@ -499,11 +466,9 @@ void CGMImpressOutAct::DrawEllipse( FloatPoint& rCenter, FloatPoint& rSize, doub
         }
         ImplSetFillBundle();
     }
-};
+}
 
-// ---------------------------------------------------------------
-
-void CGMImpressOutAct::DrawEllipticalArc( FloatPoint& rCenter, FloatPoint& rSize, double& rOrientation,
+void CGMImpressOutAct::DrawEllipticalArc( FloatPoint const & rCenter, FloatPoint const & rSize, double& rOrientation,
             sal_uInt32 nType, double& fStartAngle, double& fEndAngle )
 {
     if ( ImplCreateShape( "com.sun.star.drawing.EllipseShape" ) )
@@ -540,16 +505,13 @@ void CGMImpressOutAct::DrawEllipticalArc( FloatPoint& rCenter, FloatPoint& rSize
         if ( (long)fStartAngle == (long)fEndAngle )
         {
             eCircleKind = drawing::CircleKind_FULL;
-            aAny.setValue( &eCircleKind, ::getCppuType((const drawing::CircleKind*)0) );
+            maXPropSet->setPropertyValue( "CircleKind", uno::Any(eCircleKind) );
         }
         else
         {
-            aAny.setValue( &eCircleKind, ::getCppuType((const drawing::CircleKind*)0) );
-            maXPropSet->setPropertyValue( "CircleKind", aAny );
-            aAny <<= (sal_Int32)( (long)( fStartAngle * 100 ) );
-            maXPropSet->setPropertyValue( "CircleStartAngle", aAny );
-            aAny <<= (sal_Int32)( (long)( fEndAngle * 100 ) );
-            maXPropSet->setPropertyValue( "CircleEndAngle", aAny );
+            maXPropSet->setPropertyValue( "CircleKind", uno::Any(eCircleKind) );
+            maXPropSet->setPropertyValue( "CircleStartAngle", uno::Any((sal_Int32)( fStartAngle * 100 )) );
+            maXPropSet->setPropertyValue( "CircleEndAngle", uno::Any((sal_Int32)( fEndAngle * 100 )) );
         }
         maXShape->setPosition( awt::Point( (long)( rCenter.X - rSize.X ), (long)( rCenter.Y - rSize.Y ) ) );
         if ( rOrientation != 0 )
@@ -566,15 +528,12 @@ void CGMImpressOutAct::DrawEllipticalArc( FloatPoint& rCenter, FloatPoint& rSize
             if ( nType == 2 )
             {
                 ImplSetLineBundle();
-                drawing::FillStyle eFillStyle = drawing::FillStyle_NONE;
-                aAny.setValue( &eFillStyle, ::getCppuType((const drawing::FillStyle*)0) );
+                aAny <<= drawing::FillStyle_NONE;
                 maXPropSet->setPropertyValue( "FillStyle", aAny );
             }
         }
     }
-};
-
-// ---------------------------------------------------------------
+}
 
 void CGMImpressOutAct::DrawBitmap( CGMBitmapDescriptor* pBmpDesc )
 {
@@ -584,12 +543,10 @@ void CGMImpressOutAct::DrawBitmap( CGMBitmapDescriptor* pBmpDesc )
         double fdx = pBmpDesc->mndx;
         double fdy = pBmpDesc->mndy;
 
-        sal_uInt32  nMirr = BMP_MIRROR_NONE;
+        BmpMirrorFlags nMirr = BmpMirrorFlags::NONE;
         if ( pBmpDesc->mbVMirror )
-            nMirr |= BMP_MIRROR_VERT;
-        if ( pBmpDesc->mbHMirror )
-            nMirr |= BMP_MIRROR_HORZ;
-        if ( nMirr != BMP_MIRROR_NONE )
+            nMirr |= BmpMirrorFlags::Vertical;
+        if ( nMirr != BmpMirrorFlags::NONE )
             pBmpDesc->mpBitmap->Mirror( nMirr );
 
         mpCGM->ImplMapPoint( aOrigin );
@@ -607,17 +564,13 @@ void CGMImpressOutAct::DrawBitmap( CGMBitmapDescriptor* pBmpDesc )
             }
 
             uno::Reference< awt::XBitmap > xBitmap( VCLUnoHelper::CreateBitmap( BitmapEx( *( pBmpDesc->mpBitmap ) ) ) );
-            uno::Any aAny;
-            aAny <<= xBitmap;
-            maXPropSet->setPropertyValue( "GraphicObjectFillBitmap", aAny );
+            maXPropSet->setPropertyValue( "GraphicObjectFillBitmap", uno::Any(xBitmap) );
 
         }
     }
-};
+}
 
-// ---------------------------------------------------------------
-
-void CGMImpressOutAct::DrawPolygon( Polygon& rPoly )
+void CGMImpressOutAct::DrawPolygon( tools::Polygon& rPoly )
 {
     sal_uInt16 nPoints = rPoly.GetSize();
 
@@ -645,12 +598,9 @@ void CGMImpressOutAct::DrawPolygon( Polygon& rPoly )
         maXPropSet->setPropertyValue( "PolyPolygon", aParam );
         ImplSetFillBundle();
     }
-};
+}
 
-
-// ---------------------------------------------------------------
-
-void CGMImpressOutAct::DrawPolyLine( Polygon& rPoly )
+void CGMImpressOutAct::DrawPolyLine( tools::Polygon& rPoly )
 {
     sal_uInt16 nPoints = rPoly.GetSize();
 
@@ -678,11 +628,9 @@ void CGMImpressOutAct::DrawPolyLine( Polygon& rPoly )
         maXPropSet->setPropertyValue( "PolyPolygon", aParam );
         ImplSetLineBundle();
     }
-};
+}
 
-// ---------------------------------------------------------------
-
-void CGMImpressOutAct::DrawPolybezier( Polygon& rPolygon )
+void CGMImpressOutAct::DrawPolybezier( tools::Polygon& rPolygon )
 {
     sal_uInt16 nPoints = rPolygon.GetSize();
     if ( ( nPoints > 1 ) && ImplCreateShape( "com.sun.star.drawing.OpenBezierShape" ) )
@@ -713,11 +661,9 @@ void CGMImpressOutAct::DrawPolybezier( Polygon& rPolygon )
         maXPropSet->setPropertyValue( "PolyPolygonBezier", aParam );
         ImplSetLineBundle();
     }
-};
+}
 
-// ---------------------------------------------------------------
-
-void CGMImpressOutAct::DrawPolyPolygon( PolyPolygon& rPolyPolygon )
+void CGMImpressOutAct::DrawPolyPolygon( tools::PolyPolygon const & rPolyPolygon )
 {
     sal_uInt32 nNumPolys = rPolyPolygon.Count();
     if ( nNumPolys && ImplCreateShape( "com.sun.star.drawing.ClosedBezierShape" ) )
@@ -732,9 +678,9 @@ void CGMImpressOutAct::DrawPolyPolygon( PolyPolygon& rPolyPolygon )
         drawing::PointSequence* pOuterSequence = aRetval.Coordinates.getArray();
         drawing::FlagSequence* pOuterFlags = aRetval.Flags.getArray();
 
-        for( sal_uInt16 a = 0; a < nNumPolys; a++ )
+        for( sal_uInt32 a = 0; a < nNumPolys; a++ )
         {
-            Polygon aPolygon( rPolyPolygon.GetObject( a ) );
+            tools::Polygon aPolygon( rPolyPolygon.GetObject( a ) );
             sal_uInt32 nNumPoints = aPolygon.GetSize();
 
             // make room in arrays
@@ -745,7 +691,7 @@ void CGMImpressOutAct::DrawPolyPolygon( PolyPolygon& rPolyPolygon )
             awt::Point* pInnerSequence = pOuterSequence->getArray();
             drawing::PolygonFlags* pInnerFlags = pOuterFlags->getArray();
 
-            for( sal_uInt16 b = 0; b < nNumPoints; b++ )
+            for( sal_uInt32 b = 0; b < nNumPoints; b++ )
             {
                 *pInnerSequence++ = awt::Point( aPolygon.GetPoint( b ).X(), aPolygon.GetPoint( b ).Y() ) ;
                 *pInnerFlags++ = (drawing::PolygonFlags)aPolygon.GetFlags( b );
@@ -758,11 +704,9 @@ void CGMImpressOutAct::DrawPolyPolygon( PolyPolygon& rPolyPolygon )
         maXPropSet->setPropertyValue( "PolyPolygonBezier", aParam);
         ImplSetFillBundle();
     }
-};
+}
 
-// ---------------------------------------------------------------
-
-void CGMImpressOutAct::DrawText( awt::Point& rTextPos, awt::Size& rTextSize, char* pString, sal_uInt32 /*nSize*/, FinalFlag eFlag )
+void CGMImpressOutAct::DrawText( awt::Point const & rTextPos, awt::Size const & rTextSize, char const * pString, FinalFlag eFlag )
 {
     if ( ImplCreateShape( "com.sun.star.drawing.TextShape" ) )
     {
@@ -783,6 +727,7 @@ void CGMImpressOutAct::DrawText( awt::Point& rTextPos, awt::Size& rTextSize, cha
             case TAV_BOTTOM :
             case TAV_NORMAL :
                 aTextPos.Y -= static_cast<sal_Int32>( mpCGM->pElement->nCharacterHeight * 1.5 );
+                break;
             case TAV_TOP :
                 break;
             case TAV_CAP:
@@ -810,23 +755,20 @@ void CGMImpressOutAct::DrawText( awt::Point& rTextPos, awt::Size& rTextSize, cha
         maXShape->setSize( awt::Size( nWidth, nHeight ) );
         double nX = mpCGM->pElement->nCharacterOrientation[ 2 ];
         double nY = mpCGM->pElement->nCharacterOrientation[ 3 ];
-        double nOrientation = acos( nX / sqrt( nX * nX + nY * nY ) ) * 57.29577951308;
+        double fSqrt = sqrt(nX * nX + nY * nY);
+        double nOrientation = fSqrt != 0.0 ? (acos(nX / fSqrt) * 57.29577951308) : 0.0;
         if ( nY < 0 )
             nOrientation = 360 - nOrientation;
 
         if ( nOrientation )
         {
-            aAny <<= (sal_Int32)( aTextPos.X );
-            maXPropSet->setPropertyValue( "RotationPointX", aAny );
-            aAny <<= (sal_Int32)( aTextPos.Y + nHeight );
-            maXPropSet->setPropertyValue( "RotationPointY", aAny );
-            aAny <<= (sal_Int32)( (sal_Int32)( nOrientation * 100 ) );
-            maXPropSet->setPropertyValue( "RotateAngle", aAny );
+            maXPropSet->setPropertyValue( "RotationPointX", uno::Any((sal_Int32)( aTextPos.X )) );
+            maXPropSet->setPropertyValue( "RotationPointY", uno::Any((sal_Int32)( aTextPos.Y + nHeight )) );
+            maXPropSet->setPropertyValue( "RotateAngle", uno::Any((sal_Int32)( nOrientation * 100 )) );
         }
         if ( nWidth == -1 )
         {
-            sal_Bool bTrue( sal_True );
-            aAny.setValue( &bTrue, ::getCppuType((const sal_Bool*)0 ));
+            aAny <<= true;
             maXPropSet->setPropertyValue( "TextAutoGrowWidth", aAny );
 
             drawing::TextAdjust eTextAdjust;
@@ -844,31 +786,28 @@ void CGMImpressOutAct::DrawText( awt::Point& rTextPos, awt::Size& rTextSize, cha
                     eTextAdjust = drawing::TextAdjust_CENTER;
                 break;
             }
-            aAny <<= eTextAdjust;
-            maXPropSet->setPropertyValue( "TextHorizontalAdjust", aAny );
+            maXPropSet->setPropertyValue( "TextHorizontalAdjust", uno::Any(eTextAdjust) );
         }
         if ( nHeight == -1 )
         {
-            sal_Bool bTrue = sal_True;
-            aAny.setValue( &bTrue, ::getCppuType((const sal_Bool*)0) );
-            maXPropSet->setPropertyValue( "TextAutoGrowHeight", aAny );
+            maXPropSet->setPropertyValue( "TextAutoGrowHeight", uno::Any(true) );
         }
         uno::Reference< text::XText >  xText;
-        uno::Any aFirstQuery( maXShape->queryInterface( ::getCppuType((const uno::Reference< text::XText >*)0) ));
+        uno::Any aFirstQuery( maXShape->queryInterface( cppu::UnoType<text::XText>::get()));
         if( aFirstQuery >>= xText )
         {
-            OUString aStr( OUString::createFromAscii( pString ) );
+            OUString aStr(pString, rtl_str_getLength(pString), RTL_TEXTENCODING_ASCII_US);
 
             uno::Reference< text::XTextCursor >  aXTextCursor( xText->createTextCursor() );
             {
-                aXTextCursor->gotoEnd( sal_False );
+                aXTextCursor->gotoEnd( false );
                 uno::Reference< text::XTextRange >  aCursorText;
-                uno::Any aSecondQuery( aXTextCursor->queryInterface( ::getCppuType((const uno::Reference< text::XTextRange >*)0) ));
+                uno::Any aSecondQuery( aXTextCursor->queryInterface( cppu::UnoType<text::XTextRange>::get()));
                 if ( aSecondQuery >>= aCursorText )
                 {
                     uno::Reference< beans::XPropertySet >  aCursorPropSet;
 
-                    uno::Any aQuery( aCursorText->queryInterface( ::getCppuType((const uno::Reference< beans::XPropertySet >*)0) ));
+                    uno::Any aQuery( aCursorText->queryInterface( cppu::UnoType<beans::XPropertySet>::get()));
                     if( aQuery >>= aCursorPropSet )
                     {
                         if ( nWidth != -1 )     // paragraph adjusting in a valid textbox ?
@@ -891,12 +830,11 @@ void CGMImpressOutAct::DrawText( awt::Point& rTextPos, awt::Size& rTextSize, cha
                         }
                         if ( nWidth > 0 && nHeight > 0 )    // restricted text
                         {
-                            sal_Bool bTrue = sal_True;
-                            aAny.setValue( &bTrue, ::getCppuType((const sal_Bool*)0));
+                            aAny <<= true;
                             maXPropSet->setPropertyValue( "TextFitToSize", aAny );
                         }
                         aCursorText->setString( aStr );
-                        aXTextCursor->gotoEnd( sal_True );
+                        aXTextCursor->gotoEnd( true );
                         ImplSetTextBundle( aCursorPropSet );
                     }
                 }
@@ -907,37 +845,35 @@ void CGMImpressOutAct::DrawText( awt::Point& rTextPos, awt::Size& rTextSize, cha
             nFinalTextCount = maXShapes->getCount();
         }
     }
-};
+}
 
-// ---------------------------------------------------------------
-
-void CGMImpressOutAct::AppendText( char* pString, sal_uInt32 /*nSize*/, FinalFlag /*eFlag*/ )
+void CGMImpressOutAct::AppendText( const char* pString )
 {
     if ( nFinalTextCount )
     {
-        uno::Reference< drawing::XShape >  aShape = *(uno::Reference< drawing::XShape > *)maXShapes->getByIndex( nFinalTextCount - 1 ).getValue();
+        uno::Reference< drawing::XShape >  aShape = *o3tl::doAccess<uno::Reference<drawing::XShape>>(maXShapes->getByIndex( nFinalTextCount - 1 ));
         if ( aShape.is() )
         {
             uno::Reference< text::XText >  xText;
-            uno::Any aFirstQuery(  aShape->queryInterface( ::getCppuType((const uno::Reference< text::XText >*)0)) );
+            uno::Any aFirstQuery(  aShape->queryInterface( cppu::UnoType<text::XText>::get()) );
             if( aFirstQuery >>= xText )
             {
-                OUString aStr( OUString::createFromAscii( pString ) );
+                OUString aStr(pString, strlen(pString), RTL_TEXTENCODING_ASCII_US);
 
                 uno::Reference< text::XTextCursor >  aXTextCursor( xText->createTextCursor() );
                 if ( aXTextCursor.is() )
                 {
-                    aXTextCursor->gotoEnd( sal_False );
+                    aXTextCursor->gotoEnd( false );
                     uno::Reference< text::XTextRange >  aCursorText;
-                    uno::Any aSecondQuery(aXTextCursor->queryInterface( ::getCppuType((const uno::Reference< text::XTextRange >*)0) ));
+                    uno::Any aSecondQuery(aXTextCursor->queryInterface( cppu::UnoType<text::XTextRange>::get()));
                     if ( aSecondQuery >>= aCursorText )
                     {
                         uno::Reference< beans::XPropertySet >  aPropSet;
-                        uno::Any aQuery(aCursorText->queryInterface( ::getCppuType((const uno::Reference< beans::XPropertySet >*)0) ));
+                        uno::Any aQuery(aCursorText->queryInterface( cppu::UnoType<beans::XPropertySet>::get()));
                         if( aQuery >>= aPropSet )
                         {
                             aCursorText->setString( aStr );
-                            aXTextCursor->gotoEnd( sal_True );
+                            aXTextCursor->gotoEnd( true );
                             ImplSetTextBundle( aPropSet );
                         }
                     }
@@ -947,17 +883,126 @@ void CGMImpressOutAct::AppendText( char* pString, sal_uInt32 /*nSize*/, FinalFla
     }
 }
 
-// ---------------------------------------------------------------
-// nCount != 0 -> Append Text
-sal_uInt32 CGMImpressOutAct::DrawText( TextEntry* /*pTextEntry*/, NodeFrameSet& /*rNodeFrameSet*/, sal_uInt32 /*nObjCount*/ )
+
+void CGMImpressOutAct::BeginFigure()
 {
-return 0;
+    if (!maPoints.empty())
+        EndFigure();
+
+    BeginGroup();
+    maPoints.clear();
+    maFlags.clear();
 }
 
-// ---------------------------------------------------------------
-
-void CGMImpressOutAct::DrawChart()
+void CGMImpressOutAct::CloseRegion()
 {
+    if (maPoints.size() > 2)
+    {
+        NewRegion();
+        DrawPolyPolygon( maPolyPolygon );
+        maPolyPolygon.Clear();
+    }
+}
+
+void CGMImpressOutAct::NewRegion()
+{
+    if (maPoints.size() > 2)
+    {
+        tools::Polygon aPolygon(maPoints.size(), maPoints.data(), maFlags.data());
+        maPolyPolygon.Insert( aPolygon );
+    }
+    maPoints.clear();
+    maFlags.clear();
+}
+
+void CGMImpressOutAct::EndFigure()
+{
+    NewRegion();
+    DrawPolyPolygon( maPolyPolygon );
+    maPolyPolygon.Clear();
+    EndGroup();
+    maPoints.clear();
+    maFlags.clear();
+}
+
+void CGMImpressOutAct::RegPolyLine( tools::Polygon const & rPolygon, bool bReverse )
+{
+    sal_uInt16 nPoints = rPolygon.GetSize();
+    if ( nPoints )
+    {
+        if ( bReverse )
+        {
+            for ( sal_uInt16 i = 0; i <  nPoints; i++ )
+            {
+                maPoints.push_back(rPolygon.GetPoint(nPoints - i - 1));
+                maFlags.push_back(rPolygon.GetFlags(nPoints - i - 1));
+            }
+        }
+        else
+        {
+            for ( sal_uInt16 i = 0; i <  nPoints; i++ )
+            {
+                maPoints.push_back(rPolygon.GetPoint(i));
+                maFlags.push_back(rPolygon.GetFlags(i));
+            }
+        }
+    }
+}
+
+void CGMImpressOutAct::SetGradientOffset( long nHorzOfs, long nVertOfs )
+{
+    if ( !mpGradient )
+        mpGradient.reset( new awt::Gradient );
+    mpGradient->XOffset = ( (sal_uInt16)nHorzOfs & 0x7f );
+    mpGradient->YOffset = ( (sal_uInt16)nVertOfs & 0x7f );
+}
+
+void CGMImpressOutAct::SetGradientAngle( long nAngle )
+{
+    if ( !mpGradient )
+        mpGradient.reset( new awt::Gradient );
+    mpGradient->Angle = sal::static_int_cast< sal_Int16 >(nAngle);
+}
+
+void CGMImpressOutAct::SetGradientDescriptor( sal_uInt32 nColorFrom, sal_uInt32 nColorTo )
+{
+    if ( !mpGradient )
+        mpGradient.reset( new awt::Gradient );
+    mpGradient->StartColor = nColorFrom;
+    mpGradient->EndColor = nColorTo;
+}
+
+void CGMImpressOutAct::SetGradientStyle( sal_uInt32 nStyle )
+{
+    if ( !mpGradient )
+        mpGradient.reset( new awt::Gradient );
+    switch ( nStyle )
+    {
+        case 0xff :
+        {
+            mpGradient->Style = awt::GradientStyle_AXIAL;
+        }
+        break;
+        case 4 :
+        {
+            mpGradient->Style = awt::GradientStyle_RADIAL;          // CONICAL
+        }
+        break;
+        case 3 :
+        {
+            mpGradient->Style = awt::GradientStyle_RECT;
+        }
+        break;
+        case 2 :
+        {
+            mpGradient->Style = awt::GradientStyle_ELLIPTICAL;
+        }
+        break;
+        default :
+        {
+            mpGradient->Style = awt::GradientStyle_LINEAR;
+        }
+    }
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
