@@ -17,12 +17,11 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "filter/msfilter/countryid.hxx"
+#include <filter/msfilter/countryid.hxx>
 
 #include <algorithm>
 #include <sal/macros.h>
 
-// ----------------------------------------------------------------------------
 
 namespace msfilter {
 
@@ -30,7 +29,6 @@ namespace msfilter {
 
 namespace {
 
-// ----------------------------------------------------------------------------
 
 /** Table entry for Windows country ID <-> language type conversion.
 
@@ -57,7 +55,6 @@ struct CountryEntry
     bool                        mbUseSubLang;   /// false = Primary only, true = Primary and sub language.
 };
 
-// ----------------------------------------------------------------------------
 
 /** Table for Windows country ID <-> language type conversion.
 
@@ -147,7 +144,7 @@ static const CountryEntry pTable[] =
     { COUNTRY_INDIA,                LANGUAGE_URDU_INDIA,                    true    },
     { COUNTRY_INDIA,                LANGUAGE_PUNJABI,                       false   },
     { COUNTRY_INDIA,                LANGUAGE_GUJARATI,                      false   },
-    { COUNTRY_INDIA,                LANGUAGE_ORIYA,                         false   },
+    { COUNTRY_INDIA,                LANGUAGE_ODIA,                          false   },
     { COUNTRY_INDIA,                LANGUAGE_TAMIL,                         false   },
     { COUNTRY_INDIA,                LANGUAGE_TELUGU,                        false   },
     { COUNTRY_INDIA,                LANGUAGE_KANNADA,                       false   },
@@ -253,10 +250,10 @@ struct CountryEntryPred_Country
 {
     CountryId                   meCountry;
 
-    inline explicit             CountryEntryPred_Country( CountryId eCountry ) :
+    explicit             CountryEntryPred_Country( CountryId eCountry ) :
                                     meCountry( eCountry ) {}
 
-    inline bool                 operator()( const CountryEntry& rCmp ) const
+    bool                 operator()( const CountryEntry& rCmp ) const
                                     { return rCmp.meCountry == meCountry; }
 };
 
@@ -268,7 +265,7 @@ struct CountryEntryPred_Language
 {
     LanguageType                meLanguage;
 
-    inline explicit             CountryEntryPred_Language( LanguageType eLanguage ) :
+    explicit             CountryEntryPred_Language( LanguageType eLanguage ) :
                                     meLanguage( eLanguage ) {}
 
     inline bool                 operator()( const CountryEntry& rCmp ) const;
@@ -279,7 +276,7 @@ inline bool CountryEntryPred_Language::operator()( const CountryEntry& rCmp ) co
     //  rCmp.mbUseSubLang==true  -> compare full language type
     //  rCmp.mbUseSubLang==false -> compare primary language only
     return rCmp.mbUseSubLang ? (meLanguage == rCmp.meLanguage) :
-                ((meLanguage & 0x03FF) == (rCmp.meLanguage & 0x03FF));
+                (primary(meLanguage) == primary(rCmp.meLanguage));
 }
 
 } // namespace
@@ -317,6 +314,6 @@ LanguageType ConvertCountryToLanguage( CountryId eCountry )
     return (pEntry != pEnd) ? pEntry->meLanguage : LANGUAGE_DONTKNOW;
 }
 
-} // namespace svx
+}
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
