@@ -17,7 +17,6 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include <osl/mutex.hxx>
 #include <osl/thread.h>
 #include <cppuhelper/factory.hxx>
 
@@ -37,10 +36,10 @@ extern "C"
 SAL_DLLPUBLIC_EXPORT void * SAL_CALL t602filter_component_getFactory(
     const sal_Char * pImplName, void * pServiceManager, void * /* pRegistryKey */ )
 {
-    void * pRet = 0;
+    void * pRet = nullptr;
 
     OUString implName = OUString::createFromAscii( pImplName );
-    if ( pServiceManager && implName.equals(T602ImportFilter_getImplementationName()) )
+    if ( pServiceManager && implName == T602ImportFilter_getImplementationName() )
     {
         Reference< XSingleServiceFactory > xFactory( createSingleFactory(
             static_cast< XMultiServiceFactory * >( pServiceManager ),
@@ -53,7 +52,7 @@ SAL_DLLPUBLIC_EXPORT void * SAL_CALL t602filter_component_getFactory(
             pRet = xFactory.get();
         }
     }
-    else if ( pServiceManager && implName.equals(T602ImportFilterDialog_getImplementationName()) )
+    else if ( pServiceManager && implName == T602ImportFilterDialog_getImplementationName() )
     {
         Reference< XSingleServiceFactory > xFactory( createSingleFactory(
             static_cast< XMultiServiceFactory * >( pServiceManager ),
