@@ -18,12 +18,11 @@
  */
 
 #include "Filter.hxx"
-#include "FormComponent.hxx"
-#include "frm_resource.hrc"
-#include "frm_resource.hxx"
-#include "property.hrc"
-#include "property.hxx"
-#include "services.hxx"
+#include <FormComponent.hxx>
+#include <strings.hrc>
+#include <frm_resource.hxx>
+#include <property.hxx>
+#include <services.hxx>
 
 #include <com/sun/star/awt/VclWindowPeerAttribute.hpp>
 #include <com/sun/star/awt/XCheckBox.hpp>
@@ -356,7 +355,7 @@ namespace frm
         }
 
         OUString sText( aText.makeStringAndClear() );
-        if ( m_aText.compareTo( sText ) )
+        if ( m_aText != sText )
         {
             m_aText = sText;
             TextEvent aEvt;
@@ -514,7 +513,7 @@ namespace frm
             default:
                 return true;
         }
-        if (m_aText.compareTo(aText))
+        if ( m_aText != aText )
         {
             // check the text with the SQL-Parser
             OUString aNewText(aText);
@@ -810,7 +809,7 @@ namespace frm
         }
     }
 
-    void OFilterControl::initControlModel(Reference< XPropertySet >& xControlModel)
+    void OFilterControl::initControlModel(Reference< XPropertySet > const & xControlModel)
     {
 #if !HAVE_FEATURE_DBCONNECTIVITY
         (void) xControlModel;
