@@ -17,25 +17,21 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "urltransformer.hxx"
+#include <urltransformer.hxx>
 
 #include <com/sun/star/util/URLTransformer.hpp>
 #include <tools/debug.hxx>
 #include <comphelper/processfactory.hxx>
 
-//........................................................................
+
 namespace frm
 {
-//........................................................................
+
 
     using namespace ::com::sun::star::uno;
     using namespace ::com::sun::star::util;
     using namespace ::com::sun::star::lang;
 
-    //====================================================================
-    //= UrlTransformer
-    //====================================================================
-    //--------------------------------------------------------------------
     UrlTransformer::UrlTransformer( const Reference< XComponentContext >& _rxORB )
         :m_xORB( _rxORB )
         ,m_bTriedToCreateTransformer( false )
@@ -43,7 +39,7 @@ namespace frm
         DBG_ASSERT( _rxORB.is(), "UrlTransformer::UrlTransformer: invalid service factory!" );
     }
 
-    //--------------------------------------------------------------------
+
     bool UrlTransformer::implEnsureTransformer() const
     {
         // create the transformer, if not already attempted to do so
@@ -59,7 +55,7 @@ namespace frm
         return m_xTransformer.is();
     }
 
-    //--------------------------------------------------------------------
+
     URL UrlTransformer::getStrictURL( const OUString& _rURL ) const
     {
         URL aReturn;
@@ -69,21 +65,21 @@ namespace frm
         return aReturn;
     }
 
-    //--------------------------------------------------------------------
+
     URL UrlTransformer::getStrictURLFromAscii( const sal_Char* _pAsciiURL ) const
     {
         return getStrictURL( OUString::createFromAscii( _pAsciiURL ) );
     }
 
-    //--------------------------------------------------------------------
-    void UrlTransformer::parseSmartWithAsciiProtocol( ::com::sun::star::util::URL& _rURL, const sal_Char* _pAsciiURL ) const
+
+    void UrlTransformer::parseSmartWithAsciiProtocol( css::util::URL& _rURL, const sal_Char* _pAsciiURL ) const
     {
         if ( implEnsureTransformer() )
             m_xTransformer->parseSmart( _rURL, OUString::createFromAscii( _pAsciiURL ) );
     }
 
-//........................................................................
+
 } // namespace frm
-//........................................................................
+
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
