@@ -23,13 +23,13 @@
 #include <vcl/settings.hxx>
 
 #include "parawin.hxx"
-#include "formula/formdata.hxx"
-#include "formula/IFunctionDescription.hxx"
-#include "ModuleHelper.hxx"
-#include "ForResId.hrc"
+#include <formula/formdata.hxx>
+#include <formula/IFunctionDescription.hxx>
+#include <formula/funcvarargs.h>
+#include <strings.hrc>
+#include <bitmaps.hlst>
+#include <core_resource.hxx>
 
-#define VAR_ARGS 30
-#define PAIRED_VAR_ARGS (VAR_ARGS + VAR_ARGS)
 namespace formula
 {
 
@@ -38,9 +38,8 @@ ParaWin::ParaWin(vcl::Window* pParent,IControlReferenceHandler* _pDlg):
     TabPage         (pParent, "ParameterPage", "formula/ui/parameter.ui"),
     pFuncDesc       ( nullptr ),
     pMyParent       (_pDlg),
-    m_sOptional     ( ModuleRes( STR_OPTIONAL ) ),
-    m_sRequired     ( ModuleRes( STR_REQUIRED ) ),
-    bRefMode        (false)
+    m_sOptional     ( ForResId( STR_OPTIONAL ) ),
+    m_sRequired     ( ForResId( STR_REQUIRED ) )
 {
     get(m_pFtEditDesc, "editdesc");
     get(m_pFtArgName, "parname");
@@ -58,13 +57,13 @@ ParaWin::ParaWin(vcl::Window* pParent,IControlReferenceHandler* _pDlg):
     m_pFtArgDesc->SetText("");
 
     get(m_pBtnFx1, "FX1");
-    m_pBtnFx1->SetModeImage(Image(ModuleRes( BMP_FX )));
+    m_pBtnFx1->SetModeImage(Image(BitmapEx(BMP_FX)));
     get(m_pBtnFx2, "FX2");
-    m_pBtnFx2->SetModeImage(Image(ModuleRes( BMP_FX )));
+    m_pBtnFx2->SetModeImage(Image(BitmapEx(BMP_FX)));
     get(m_pBtnFx3, "FX3");
-    m_pBtnFx3->SetModeImage(Image(ModuleRes( BMP_FX )));
+    m_pBtnFx3->SetModeImage(Image(BitmapEx(BMP_FX)));
     get(m_pBtnFx4, "FX4");
-    m_pBtnFx4->SetModeImage(Image(ModuleRes( BMP_FX )));
+    m_pBtnFx4->SetModeImage(Image(BitmapEx(BMP_FX)));
 
     get(m_pFtArg1, "FT_ARG1");
     get(m_pFtArg2, "FT_ARG2");
@@ -436,8 +435,7 @@ void ParaWin::SetArgumentOffset(sal_uInt16 nOffset)
     {
         for ( int i=0; i<4 && i<nArgs; i++ )
         {
-            OUString aString;
-            aArgInput[i].SetArgVal(aString);
+            aArgInput[i].SetArgVal(OUString());
             aArgInput[i].GetArgEdPtr()->Init(
                 (i==0)               ? nullptr : aArgInput[i-1].GetArgEdPtr(),
                 (i==3 || i==nArgs-1) ? nullptr : aArgInput[i+1].GetArgEdPtr(),
