@@ -31,6 +31,7 @@
 #include <com/sun/star/xml/sax/Parser.hpp>
 #include <com/sun/star/xml/sax/InputSource.hpp>
 #include <com/sun/star/xml/sax/Writer.hpp>
+#include <com/sun/star/io/IOException.hpp>
 #include <com/sun/star/io/XActiveDataSource.hpp>
 #include <com/sun/star/embed/ElementModes.hpp>
 #include <com/sun/star/io/XSeekable.hpp>
@@ -83,11 +84,10 @@ XMLBasedAcceleratorConfiguration::XMLBasedAcceleratorConfiguration(const css::un
 
 XMLBasedAcceleratorConfiguration::~XMLBasedAcceleratorConfiguration()
 {
-    SAL_WARN_IF(m_pWriteCache, "fwk", "XMLBasedAcceleratorConfiguration::~XMLBasedAcceleratorConfiguration(): Changes not flushed. Ignore it ...");
+    SAL_WARN_IF(m_pWriteCache, "fwk.accelerators", "XMLBasedAcceleratorConfiguration::~XMLBasedAcceleratorConfiguration(): Changes not flushed. Ignore it ...");
 }
 
 css::uno::Sequence< css::awt::KeyEvent > SAL_CALL XMLBasedAcceleratorConfiguration::getAllKeyEvents()
-    throw(css::uno::RuntimeException, std::exception)
 {
     SolarMutexGuard g;
     AcceleratorCache&          rCache = impl_getCFG();
@@ -96,8 +96,6 @@ css::uno::Sequence< css::awt::KeyEvent > SAL_CALL XMLBasedAcceleratorConfigurati
 }
 
 OUString SAL_CALL XMLBasedAcceleratorConfiguration::getCommandByKeyEvent(const css::awt::KeyEvent& aKeyEvent)
-    throw(css::container::NoSuchElementException,
-          css::uno::RuntimeException, std::exception            )
 {
     SolarMutexGuard g;
     AcceleratorCache& rCache = impl_getCFG();
@@ -110,8 +108,6 @@ OUString SAL_CALL XMLBasedAcceleratorConfiguration::getCommandByKeyEvent(const c
 
 void SAL_CALL XMLBasedAcceleratorConfiguration::setKeyEvent(const css::awt::KeyEvent& aKeyEvent,
                                                     const OUString&    sCommand )
-                                                    throw(css::lang::IllegalArgumentException,
-                                                    css::uno::RuntimeException, std::exception         )
 {
     if (
         (aKeyEvent.KeyCode   == 0) &&
@@ -120,15 +116,15 @@ void SAL_CALL XMLBasedAcceleratorConfiguration::setKeyEvent(const css::awt::KeyE
         (aKeyEvent.Modifiers == 0)
         )
         throw css::lang::IllegalArgumentException(
-        OUString("Such key event seems not to be supported by any operating system."),
-        static_cast< ::cppu::OWeakObject* >(this),
-        0);
+            "Such key event seems not to be supported by any operating system.",
+            static_cast< ::cppu::OWeakObject* >(this),
+            0);
 
     if (sCommand.isEmpty())
         throw css::lang::IllegalArgumentException(
-        OUString("Empty command strings are not allowed here."),
-        static_cast< ::cppu::OWeakObject* >(this),
-        1);
+            "Empty command strings are not allowed here.",
+            static_cast< ::cppu::OWeakObject* >(this),
+            1);
 
     SolarMutexGuard g;
     AcceleratorCache& rCache = impl_getCFG(true); // sal_True => force getting of a writeable cache!
@@ -136,8 +132,6 @@ void SAL_CALL XMLBasedAcceleratorConfiguration::setKeyEvent(const css::awt::KeyE
 }
 
 void SAL_CALL XMLBasedAcceleratorConfiguration::removeKeyEvent(const css::awt::KeyEvent& aKeyEvent)
-throw(css::container::NoSuchElementException,
-      css::uno::RuntimeException, std::exception            )
 {
     SolarMutexGuard g;
     AcceleratorCache& rCache = impl_getCFG(true); // true => force using of a writeable cache
@@ -149,13 +143,10 @@ throw(css::container::NoSuchElementException,
 }
 
 css::uno::Sequence< css::awt::KeyEvent > SAL_CALL XMLBasedAcceleratorConfiguration::getKeyEventsByCommand(const OUString& sCommand)
-    throw(css::lang::IllegalArgumentException   ,
-          css::container::NoSuchElementException,
-          css::uno::RuntimeException, std::exception            )
 {
     if (sCommand.isEmpty())
         throw css::lang::IllegalArgumentException(
-                OUString("Empty command strings are not allowed here."),
+                "Empty command strings are not allowed here.",
                 static_cast< ::cppu::OWeakObject* >(this),
                 1);
 
@@ -171,8 +162,6 @@ css::uno::Sequence< css::awt::KeyEvent > SAL_CALL XMLBasedAcceleratorConfigurati
 }
 
 css::uno::Sequence< css::uno::Any > SAL_CALL XMLBasedAcceleratorConfiguration::getPreferredKeyEventsForCommandList(const css::uno::Sequence< OUString >& lCommandList)
-    throw (css::lang::IllegalArgumentException, css::container::NoSuchElementException,
-           css::uno::RuntimeException, std::exception)
 {
     SolarMutexGuard g;
 
@@ -186,7 +175,7 @@ css::uno::Sequence< css::uno::Any > SAL_CALL XMLBasedAcceleratorConfiguration::g
         const OUString& rCommand = lCommandList[i];
         if (rCommand.isEmpty())
             throw css::lang::IllegalArgumentException(
-                    OUString("Empty command strings are not allowed here."),
+                    "Empty command strings are not allowed here.",
                     static_cast< ::cppu::OWeakObject* >(this),
                     (sal_Int16)i);
 
@@ -205,13 +194,10 @@ css::uno::Sequence< css::uno::Any > SAL_CALL XMLBasedAcceleratorConfiguration::g
 }
 
 void SAL_CALL XMLBasedAcceleratorConfiguration::removeCommandFromAllKeyEvents(const OUString& sCommand)
-    throw(css::lang::IllegalArgumentException   ,
-          css::container::NoSuchElementException,
-          css::uno::RuntimeException, std::exception            )
 {
     if (sCommand.isEmpty())
         throw css::lang::IllegalArgumentException(
-                OUString("Empty command strings are not allowed here."),
+                "Empty command strings are not allowed here.",
                 static_cast< ::cppu::OWeakObject* >(this),
                 0);
 
@@ -219,14 +205,12 @@ void SAL_CALL XMLBasedAcceleratorConfiguration::removeCommandFromAllKeyEvents(co
     AcceleratorCache& rCache = impl_getCFG(true); // sal_True => force getting of a writeable cache!
     if (!rCache.hasCommand(sCommand))
         throw css::container::NoSuchElementException(
-                OUString("Command does not exists inside this container."),
+                "Command does not exists inside this container.",
                 static_cast< ::cppu::OWeakObject* >(this));
     rCache.removeCommand(sCommand);
 }
 
 void SAL_CALL XMLBasedAcceleratorConfiguration::reload()
-    throw(css::uno::Exception       ,
-        css::uno::RuntimeException, std::exception)
 {
     css::uno::Reference< css::io::XStream > xStream;
     css::uno::Reference< css::io::XStream > xStreamNoLang;
@@ -246,8 +230,8 @@ void SAL_CALL XMLBasedAcceleratorConfiguration::reload()
         xIn = xStream->getInputStream();
     if (!xIn.is())
         throw css::io::IOException(
-        OUString("Could not open accelerator configuration for reading."),
-        static_cast< ::cppu::OWeakObject* >(this));
+            "Could not open accelerator configuration for reading.",
+            static_cast< ::cppu::OWeakObject* >(this));
 
     // impl_ts_load() does not clear the cache
     {
@@ -268,8 +252,6 @@ void SAL_CALL XMLBasedAcceleratorConfiguration::reload()
 }
 
 void SAL_CALL XMLBasedAcceleratorConfiguration::store()
-    throw(css::uno::Exception       ,
-        css::uno::RuntimeException, std::exception)
 {
     css::uno::Reference< css::io::XStream > xStream;
     {
@@ -284,8 +266,8 @@ void SAL_CALL XMLBasedAcceleratorConfiguration::store()
 
     if (!xOut.is())
         throw css::io::IOException(
-        OUString("Could not open accelerator configuration for saving."),
-        static_cast< ::cppu::OWeakObject* >(this));
+            "Could not open accelerator configuration for saving.",
+            static_cast< ::cppu::OWeakObject* >(this));
 
     impl_ts_save(xOut);
 
@@ -296,8 +278,6 @@ void SAL_CALL XMLBasedAcceleratorConfiguration::store()
 }
 
 void SAL_CALL XMLBasedAcceleratorConfiguration::storeToStorage(const css::uno::Reference< css::embed::XStorage >& xStorage)
-    throw(css::uno::Exception       ,
-          css::uno::RuntimeException, std::exception)
 {
     css::uno::Reference< css::io::XStream > xStream = StorageHolder::openSubStreamWithFallback(
                                                             xStorage,
@@ -310,7 +290,7 @@ void SAL_CALL XMLBasedAcceleratorConfiguration::storeToStorage(const css::uno::R
 
     if (!xOut.is())
         throw css::io::IOException(
-                OUString("Could not open accelerator configuration for saving."),
+                "Could not open accelerator configuration for saving.",
                 static_cast< ::cppu::OWeakObject* >(this));
 
     impl_ts_save(xOut);
@@ -319,14 +299,12 @@ void SAL_CALL XMLBasedAcceleratorConfiguration::storeToStorage(const css::uno::R
 }
 
 sal_Bool SAL_CALL XMLBasedAcceleratorConfiguration::isModified()
-    throw(css::uno::RuntimeException, std::exception)
 {
     SolarMutexGuard g;
     return (m_pWriteCache != nullptr);
 }
 
 sal_Bool SAL_CALL XMLBasedAcceleratorConfiguration::isReadOnly()
-    throw(css::uno::RuntimeException, std::exception)
 {
     css::uno::Reference< css::io::XStream > xStream;
     {
@@ -342,32 +320,27 @@ sal_Bool SAL_CALL XMLBasedAcceleratorConfiguration::isReadOnly()
 }
 
 void SAL_CALL XMLBasedAcceleratorConfiguration::setStorage(const css::uno::Reference< css::embed::XStorage >& /*xStorage*/)
-    throw(css::uno::RuntimeException, std::exception)
 {
-    SAL_INFO("fwk", "XMLBasedAcceleratorConfiguration::setStorage(): implement this HACK .-)");
+    SAL_INFO("fwk.accelerators", "XMLBasedAcceleratorConfiguration::setStorage(): implement this HACK .-)");
 }
 
 sal_Bool SAL_CALL XMLBasedAcceleratorConfiguration::hasStorage()
-    throw(css::uno::RuntimeException, std::exception)
 {
-    SAL_INFO("fwk", "XMLBasedAcceleratorConfiguration::hasStorage(): implement this HACK .-)");
+    SAL_INFO("fwk.accelerators", "XMLBasedAcceleratorConfiguration::hasStorage(): implement this HACK .-)");
     return false;
 }
 
 void SAL_CALL XMLBasedAcceleratorConfiguration::addConfigurationListener(const css::uno::Reference< css::ui::XUIConfigurationListener >& /*xListener*/)
-    throw(css::uno::RuntimeException, std::exception)
 {
-    SAL_INFO("fwk", "XMLBasedAcceleratorConfiguration::addConfigurationListener(): implement me");
+    SAL_INFO("fwk.accelerators", "XMLBasedAcceleratorConfiguration::addConfigurationListener(): implement me");
 }
 
 void SAL_CALL XMLBasedAcceleratorConfiguration::removeConfigurationListener(const css::uno::Reference< css::ui::XUIConfigurationListener >& /*xListener*/)
-    throw(css::uno::RuntimeException, std::exception)
 {
-    SAL_INFO("fwk", "XMLBasedAcceleratorConfiguration::removeConfigurationListener(): implement me");
+    SAL_INFO("fwk.accelerators", "XMLBasedAcceleratorConfiguration::removeConfigurationListener(): implement me");
 }
 
 void SAL_CALL XMLBasedAcceleratorConfiguration::reset()
-throw(css::uno::RuntimeException, std::exception)
 {
     {
         SolarMutexGuard g;
@@ -378,15 +351,13 @@ throw(css::uno::RuntimeException, std::exception)
 }
 
 void SAL_CALL XMLBasedAcceleratorConfiguration::addResetListener(const css::uno::Reference< css::form::XResetListener >& /*xListener*/)
-    throw(css::uno::RuntimeException, std::exception)
 {
-    SAL_INFO("fwk", "XMLBasedAcceleratorConfiguration::addResetListener(): implement me");
+    SAL_INFO("fwk.accelerators", "XMLBasedAcceleratorConfiguration::addResetListener(): implement me");
 }
 
 void SAL_CALL XMLBasedAcceleratorConfiguration::removeResetListener(const css::uno::Reference< css::form::XResetListener >& /*xListener*/)
-    throw(css::uno::RuntimeException, std::exception)
 {
-    SAL_INFO("fwk", "XMLBasedAcceleratorConfiguration::removeResetListener(): implement me");
+    SAL_INFO("fwk.accelerators", "XMLBasedAcceleratorConfiguration::removeResetListener(): implement me");
 }
 
 // IStorageListener
@@ -487,10 +458,7 @@ AcceleratorCache& XMLBasedAcceleratorConfiguration::impl_getCFG(bool bWriteAcces
 
     //create copy of our readonly-cache, if write access is forced ... but
     //not still possible!
-    if (
-        (bWriteAccessRequested) &&
-        (!m_pWriteCache       )
-       )
+    if ( bWriteAccessRequested && !m_pWriteCache )
     {
         m_pWriteCache = new AcceleratorCache(m_aReadCache);
     }
@@ -534,7 +502,6 @@ XCUBasedAcceleratorConfiguration::~XCUBasedAcceleratorConfiguration()
 }
 
 css::uno::Sequence< css::awt::KeyEvent > SAL_CALL XCUBasedAcceleratorConfiguration::getAllKeyEvents()
-    throw(css::uno::RuntimeException, std::exception)
 {
     SolarMutexGuard g;
 
@@ -551,8 +518,6 @@ css::uno::Sequence< css::awt::KeyEvent > SAL_CALL XCUBasedAcceleratorConfigurati
 }
 
 OUString SAL_CALL XCUBasedAcceleratorConfiguration::getCommandByKeyEvent(const css::awt::KeyEvent& aKeyEvent)
-    throw(css::container::NoSuchElementException,
-          css::uno::RuntimeException, std::exception            )
 {
     SolarMutexGuard g;
 
@@ -572,9 +537,6 @@ OUString SAL_CALL XCUBasedAcceleratorConfiguration::getCommandByKeyEvent(const c
 
 void SAL_CALL XCUBasedAcceleratorConfiguration::setKeyEvent(const css::awt::KeyEvent& aKeyEvent,
                                                     const OUString&    sCommand )
-                                                    throw (css::lang::IllegalArgumentException,
-                                                           css::container::NoSuchElementException,
-                                                           css::uno::RuntimeException, std::exception)
 {
     SAL_INFO( "fwk.accelerators", "XCUBasedAcceleratorConfiguration::setKeyEvent" );
 
@@ -585,15 +547,15 @@ void SAL_CALL XCUBasedAcceleratorConfiguration::setKeyEvent(const css::awt::KeyE
         (aKeyEvent.Modifiers == 0)
         )
         throw css::lang::IllegalArgumentException(
-                OUString("Such key event seems not to be supported by any operating system."),
+                "Such key event seems not to be supported by any operating system.",
                 static_cast< ::cppu::OWeakObject* >(this),
                 0);
 
     if (sCommand.isEmpty())
                 throw css::lang::IllegalArgumentException(
-                OUString("Empty command strings are not allowed here."),
-                static_cast< ::cppu::OWeakObject* >(this),
-                1);
+                    "Empty command strings are not allowed here.",
+                    static_cast< ::cppu::OWeakObject* >(this),
+                    1);
 
     SolarMutexGuard g;
 
@@ -654,8 +616,6 @@ void SAL_CALL XCUBasedAcceleratorConfiguration::setKeyEvent(const css::awt::KeyE
 }
 
 void SAL_CALL XCUBasedAcceleratorConfiguration::removeKeyEvent(const css::awt::KeyEvent& aKeyEvent)
-    throw(css::container::NoSuchElementException,
-          css::uno::RuntimeException, std::exception            )
 {
     SolarMutexGuard g;
 
@@ -693,13 +653,10 @@ void SAL_CALL XCUBasedAcceleratorConfiguration::removeKeyEvent(const css::awt::K
 }
 
 css::uno::Sequence< css::awt::KeyEvent > SAL_CALL XCUBasedAcceleratorConfiguration::getKeyEventsByCommand(const OUString& sCommand)
-    throw(css::lang::IllegalArgumentException   ,
-        css::container::NoSuchElementException,
-        css::uno::RuntimeException, std::exception            )
 {
     if (sCommand.isEmpty())
         throw css::lang::IllegalArgumentException(
-                OUString("Empty command strings are not allowed here."),
+                "Empty command strings are not allowed here.",
                 static_cast< ::cppu::OWeakObject* >(this),
                 1);
 
@@ -742,8 +699,6 @@ AcceleratorCache::TKeyList::const_iterator lcl_getPreferredKey(const Accelerator
 }
 
 css::uno::Sequence< css::uno::Any > SAL_CALL XCUBasedAcceleratorConfiguration::getPreferredKeyEventsForCommandList(const css::uno::Sequence< OUString >& lCommandList)
-    throw(css::lang::IllegalArgumentException, css::container::NoSuchElementException,
-          css::uno::RuntimeException, std::exception)
 {
     SolarMutexGuard g;
 
@@ -757,7 +712,7 @@ css::uno::Sequence< css::uno::Any > SAL_CALL XCUBasedAcceleratorConfiguration::g
         const OUString& rCommand = lCommandList[i];
         if (rCommand.isEmpty())
             throw css::lang::IllegalArgumentException(
-                    OUString("Empty command strings are not allowed here."),
+                    "Empty command strings are not allowed here.",
                     static_cast< ::cppu::OWeakObject* >(this),
                     (sal_Int16)i);
 
@@ -772,7 +727,7 @@ css::uno::Sequence< css::uno::Any > SAL_CALL XCUBasedAcceleratorConfiguration::g
         if (pPreferredKey != lKeys.end ())
         {
             css::uno::Any& rAny = lPreferredOnes[i];
-            rAny <<= *(pPreferredKey);
+            rAny <<= *pPreferredKey;
         }
     }
 
@@ -780,13 +735,10 @@ css::uno::Sequence< css::uno::Any > SAL_CALL XCUBasedAcceleratorConfiguration::g
 }
 
 void SAL_CALL XCUBasedAcceleratorConfiguration::removeCommandFromAllKeyEvents(const OUString& sCommand)
-    throw(css::lang::IllegalArgumentException   ,
-        css::container::NoSuchElementException,
-        css::uno::RuntimeException, std::exception            )
 {
     if (sCommand.isEmpty())
         throw css::lang::IllegalArgumentException(
-                OUString("Empty command strings are not allowed here."),
+                "Empty command strings are not allowed here.",
                 static_cast< ::cppu::OWeakObject* >(this),
                 0);
 
@@ -797,7 +749,7 @@ void SAL_CALL XCUBasedAcceleratorConfiguration::removeCommandFromAllKeyEvents(co
 
     if (!rPrimaryCache.hasCommand(sCommand) && !rSecondaryCache.hasCommand(sCommand))
         throw css::container::NoSuchElementException(
-                OUString("Command does not exists inside this container."),
+                "Command does not exists inside this container.",
                 static_cast< ::cppu::OWeakObject* >(this));
 
     if (rPrimaryCache.hasCommand(sCommand))
@@ -807,8 +759,6 @@ void SAL_CALL XCUBasedAcceleratorConfiguration::removeCommandFromAllKeyEvents(co
 }
 
 void SAL_CALL XCUBasedAcceleratorConfiguration::reload()
-    throw(css::uno::Exception       ,
-        css::uno::RuntimeException, std::exception)
 {
     SAL_INFO( "fwk.accelerators", "XCUBasedAcceleratorConfiguration::reload()" );
 
@@ -843,32 +793,25 @@ void SAL_CALL XCUBasedAcceleratorConfiguration::reload()
 }
 
 void SAL_CALL XCUBasedAcceleratorConfiguration::store()
-    throw(css::uno::Exception       ,
-          css::uno::RuntimeException, std::exception)
 {
     SAL_INFO( "fwk.accelerators", "XCUBasedAcceleratorConfiguration::store()" );
 
     SolarMutexGuard g;
 
     bool bPreferred;
-    css::uno::Reference< css::container::XNameAccess > xAccess;
 
     bPreferred = true;
     // on-demand creation of the primary write cache
     impl_getCFG(bPreferred, true);
-    m_xCfg->getByName(CFG_ENTRY_PRIMARY) >>= xAccess;
-    impl_ts_save(bPreferred, xAccess);
+    impl_ts_save(bPreferred);
 
     bPreferred = false;
     // on-demand creation of the secondary write cache
     impl_getCFG(bPreferred, true);
-    m_xCfg->getByName(CFG_ENTRY_SECONDARY) >>= xAccess;
-    impl_ts_save(bPreferred, xAccess);
+    impl_ts_save(bPreferred);
 }
 
 void SAL_CALL XCUBasedAcceleratorConfiguration::storeToStorage(const css::uno::Reference< css::embed::XStorage >& xStorage)
-    throw(css::uno::Exception       ,
-      css::uno::RuntimeException, std::exception)
 {
     // use m_aCache + old AcceleratorXMLWriter to store data directly on storage given as parameter ...
     if (!xStorage.is())
@@ -885,8 +828,8 @@ void SAL_CALL XCUBasedAcceleratorConfiguration::storeToStorage(const css::uno::R
         xOut = xStream->getOutputStream();
     if (!xOut.is())
         throw css::io::IOException(
-        OUString("Could not open accelerator configuration for saving."),
-        static_cast< ::cppu::OWeakObject* >(this));
+            "Could not open accelerator configuration for saving.",
+            static_cast< ::cppu::OWeakObject* >(this));
 
     // the original m_aCache has been split into primary cache and secondary cache...
     // we should merge them before storing to storage
@@ -931,44 +874,37 @@ void SAL_CALL XCUBasedAcceleratorConfiguration::storeToStorage(const css::uno::R
 }
 
 sal_Bool SAL_CALL XCUBasedAcceleratorConfiguration::isModified()
-    throw(css::uno::RuntimeException, std::exception)
 {
     return false;
 }
 
 sal_Bool SAL_CALL XCUBasedAcceleratorConfiguration::isReadOnly()
-    throw(css::uno::RuntimeException, std::exception)
 {
     return false;
 }
 
 void SAL_CALL XCUBasedAcceleratorConfiguration::setStorage(const css::uno::Reference< css::embed::XStorage >& /*xStorage*/)
-    throw(css::uno::RuntimeException, std::exception)
 {
-    SAL_INFO("fwk", "XCUBasedAcceleratorConfiguration::setStorage(): implement this HACK .-)");
+    SAL_INFO("fwk.accelerators", "XCUBasedAcceleratorConfiguration::setStorage(): implement this HACK .-)");
 }
 
 sal_Bool SAL_CALL XCUBasedAcceleratorConfiguration::hasStorage()
-    throw(css::uno::RuntimeException, std::exception)
 {
-    SAL_INFO("fwk", "XCUBasedAcceleratorConfiguration::hasStorage(): implement this HACK .-)");
+    SAL_INFO("fwk.accelerators", "XCUBasedAcceleratorConfiguration::hasStorage(): implement this HACK .-)");
         return false;
 }
 
 void SAL_CALL XCUBasedAcceleratorConfiguration::addConfigurationListener(const css::uno::Reference< css::ui::XUIConfigurationListener >& /*xListener*/)
-    throw(css::uno::RuntimeException, std::exception)
 {
-    SAL_INFO("fwk", "XCUBasedAcceleratorConfiguration::addConfigurationListener(): implement me");
+    SAL_INFO("fwk.accelerators", "XCUBasedAcceleratorConfiguration::addConfigurationListener(): implement me");
 }
 
 void SAL_CALL XCUBasedAcceleratorConfiguration::removeConfigurationListener(const css::uno::Reference< css::ui::XUIConfigurationListener >& /*xListener*/)
-    throw(css::uno::RuntimeException, std::exception)
 {
-    SAL_INFO("fwk", "XCUBasedAcceleratorConfiguration::removeConfigurationListener(): implement me");
+    SAL_INFO("fwk.accelerators", "XCUBasedAcceleratorConfiguration::removeConfigurationListener(): implement me");
 }
 
 void SAL_CALL XCUBasedAcceleratorConfiguration::reset()
-    throw(css::uno::RuntimeException, std::exception)
 {
     css::uno::Reference< css::container::XNamed > xNamed(m_xCfg, css::uno::UNO_QUERY);
     OUString sConfig = xNamed->getName();
@@ -989,19 +925,16 @@ void SAL_CALL XCUBasedAcceleratorConfiguration::reset()
 }
 
 void SAL_CALL XCUBasedAcceleratorConfiguration::addResetListener(const css::uno::Reference< css::form::XResetListener >& /*xListener*/)
-    throw(css::uno::RuntimeException, std::exception)
 {
-    SAL_INFO("fwk", "XCUBasedAcceleratorConfiguration::addResetListener(): implement me");
+    SAL_INFO("fwk.accelerators", "XCUBasedAcceleratorConfiguration::addResetListener(): implement me");
 }
 
 void SAL_CALL XCUBasedAcceleratorConfiguration::removeResetListener(const css::uno::Reference< css::form::XResetListener >& /*xListener*/)
-    throw(css::uno::RuntimeException, std::exception)
 {
-    SAL_INFO("fwk", "XCUBasedAcceleratorConfiguration::removeResetListener(): implement me");
+    SAL_INFO("fwk.accelerators", "XCUBasedAcceleratorConfiguration::removeResetListener(): implement me");
 }
 
 void SAL_CALL XCUBasedAcceleratorConfiguration::changesOccurred(const css::util::ChangesEvent& aEvent)
-    throw(css::uno::RuntimeException, std::exception)
 {
     SAL_INFO( "fwk.accelerators", "XCUBasedAcceleratorConfiguration::changesOccurred()" );
 
@@ -1033,10 +966,9 @@ void SAL_CALL XCUBasedAcceleratorConfiguration::changesOccurred(const css::util:
 
         if ( sGlobalModules == CFG_ENTRY_GLOBAL )
         {
-            OUString sModule;
             sKey = ::utl::extractFirstFromConfigurationPath(sPath, &sPath);
             if ( !sKey.isEmpty() && !sPath.isEmpty() )
-                reloadChanged(sPrimarySecondary, sGlobalModules, sModule, sKey);
+                reloadChanged(sPrimarySecondary, sGlobalModules, OUString(), sKey);
         }
         else if ( sGlobalModules == CFG_ENTRY_MODULES )
         {
@@ -1052,28 +984,9 @@ void SAL_CALL XCUBasedAcceleratorConfiguration::changesOccurred(const css::util:
 }
 
 void SAL_CALL XCUBasedAcceleratorConfiguration::disposing(const css::lang::EventObject& /*aSource*/)
-    throw(css::uno::RuntimeException, std::exception)
 {
 }
 
-void SAL_CALL XCUBasedAcceleratorConfiguration::dispose()
-    throw(css::uno::RuntimeException, std::exception)
-{
-    // nop
-}
-
-void SAL_CALL XCUBasedAcceleratorConfiguration::addEventListener( const css::uno::Reference< css::lang::XEventListener >& /*xListener*/ )
-    throw(css::uno::RuntimeException, std::exception)
-{
-    // nop
-}
-
-void SAL_CALL XCUBasedAcceleratorConfiguration::removeEventListener( const css::uno::Reference< css::lang::XEventListener >& /*xListener*/ )
-    throw(css::uno::RuntimeException, std::exception)
-{
-    // nop
-}
-
 void XCUBasedAcceleratorConfiguration::impl_ts_load( bool bPreferred, const css::uno::Reference< css::container::XNameAccess >& xCfg )
 {
     AcceleratorCache aReadCache = AcceleratorCache();
@@ -1137,8 +1050,7 @@ void XCUBasedAcceleratorConfiguration::impl_ts_load( bool bPreferred, const css:
 
             sal_Int32 nIndex = 0;
             OUString sKeyCommand = sKey.getToken(0, '_', nIndex);
-            OUString sPrefix("KEY_");
-            aKeyEvent.KeyCode = KeyMapping::get().mapIdentifierToCode(sPrefix + sKeyCommand);
+            aKeyEvent.KeyCode = KeyMapping::get().mapIdentifierToCode("KEY_" + sKeyCommand);
 
             css::uno::Sequence< OUString > sToken(4);
             const sal_Int32 nToken = 4;
@@ -1182,7 +1094,7 @@ void XCUBasedAcceleratorConfiguration::impl_ts_load( bool bPreferred, const css:
         m_aSecondaryReadCache.takeOver(aReadCache);
 }
 
-void XCUBasedAcceleratorConfiguration::impl_ts_save(bool bPreferred, const css::uno::Reference< css::container::XNameAccess >& /*xCfg*/)
+void XCUBasedAcceleratorConfiguration::impl_ts_save(bool bPreferred)
 {
     if (bPreferred)
     {
@@ -1414,10 +1326,7 @@ AcceleratorCache& XCUBasedAcceleratorConfiguration::impl_getCFG(bool bPreferred,
     {
         //create copy of our readonly-cache, if write access is forced ... but
         //not still possible!
-        if (
-            (bWriteAccessRequested) &&
-            (!m_pPrimaryWriteCache       )
-            )
+        if ( bWriteAccessRequested && !m_pPrimaryWriteCache )
         {
             m_pPrimaryWriteCache = new AcceleratorCache(m_aPrimaryReadCache);
         }
@@ -1434,10 +1343,7 @@ AcceleratorCache& XCUBasedAcceleratorConfiguration::impl_getCFG(bool bPreferred,
     {
         //create copy of our readonly-cache, if write access is forced ... but
         //not still possible!
-        if (
-            (bWriteAccessRequested) &&
-            (!m_pSecondaryWriteCache       )
-            )
+        if ( bWriteAccessRequested && !m_pSecondaryWriteCache )
         {
             m_pSecondaryWriteCache = new AcceleratorCache(m_aSecondaryReadCache);
         }
