@@ -18,11 +18,10 @@
  */
 
 #include <algorithm>
+#include <utility>
 #include <helper/statusindicatorfactory.hxx>
 #include <helper/statusindicator.hxx>
 #include <helper/vclstatusindicator.hxx>
-#include <threadhelp/writeguard.hxx>
-#include <threadhelp/readguard.hxx>
 #include <services.h>
 #include <properties.h>
 
@@ -44,57 +43,34 @@
 #include <unotools/mediadescriptor.hxx>
 #include <vcl/svapp.hxx>
 #include <osl/mutex.hxx>
+#include <rtl/ref.hxx>
 
 #include <officecfg/Office/Common.hxx>
 
 namespace framework{
 
+sal_Int32 StatusIndicatorFactory::m_nInReschedule = 0;  ///< static counter for rescheduling
+struct RescheduleLock: public rtl::Static<osl::Mutex, RescheduleLock> {}; ///< mutex to guard the m_nInReschedule
 
-sal_Int32 StatusIndicatorFactory::m_nInReschedule = 0;  /// static counter for rescheduling
 const char PROGRESS_RESOURCE[] = "private:resource/progressbar/progressbar";
 
-//-----------------------------------------------
-
-DEFINE_XSERVICEINFO_MULTISERVICE_2(StatusIndicatorFactory                   ,
-                                   ::cppu::OWeakObject                      ,
-                                   OUString("com.sun.star.task.StatusIndicatorFactory"),
-                                   OUString("com.sun.star.comp.framework.StatusIndicatorFactory"))
-
-DEFINE_INIT_SERVICE(StatusIndicatorFactory,
-                    {
-                        /*Attention
-                            I think we don't need any mutex or lock here ... because we are called by our own static method impl_createInstance()
-                            to create a new instance of this class by our own supported service factory.
-                            see macro DEFINE_XSERVICEINFO_MULTISERVICE and "impl_initService()" for further information!
-                        */
-                    }
-                   )
-
-//-----------------------------------------------
 StatusIndicatorFactory::StatusIndicatorFactory(const css::uno::Reference< css::uno::XComponentContext >& xContext)
-    : ThreadHelpBase      (         )
-    , m_xContext          (xContext )
-    , m_pWakeUp           (0        )
-    , m_bAllowReschedule  (sal_False)
-    , m_bAllowParentShow  (sal_False)
-    , m_bDisableReschedule(sal_False)
+    : m_xContext          (xContext )
+    , m_bAllowReschedule  (false)
+    , m_bAllowParentShow  (false)
+    , m_bDisableReschedule(false)
 {
 }
 
-//-----------------------------------------------
 StatusIndicatorFactory::~StatusIndicatorFactory()
 {
     impl_stopWakeUpThread();
 }
 
-//-----------------------------------------------
 void SAL_CALL StatusIndicatorFactory::initialize(const css::uno::Sequence< css::uno::Any >& lArguments)
-    throw(css::uno::Exception       ,
-          css::uno::RuntimeException)
 {
     if (lArguments.getLength() > 0) {
-        // SAFE -> ----------------------------------
-        WriteGuard aWriteLock(m_aLock);
+        osl::MutexGuard g(m_mutex);
 
         css::uno::Reference< css::frame::XFrame > xTmpFrame;
         css::uno::Reference< css::awt::XWindow > xTmpWindow;
@@ -116,20 +92,15 @@ void SAL_CALL StatusIndicatorFactory::initialize(const css::uno::Sequence< css::
 
             m_xFrame             = lArgs.getUnpackedValueOrDefault("Frame"            , css::uno::Reference< css::frame::XFrame >());
             m_xPluggWindow       = lArgs.getUnpackedValueOrDefault("Window"           , css::uno::Reference< css::awt::XWindow >() );
-            m_bAllowParentShow   = lArgs.getUnpackedValueOrDefault("AllowParentShow"  , (sal_Bool)sal_False                        );
-            m_bDisableReschedule = lArgs.getUnpackedValueOrDefault("DisableReschedule", (sal_Bool)sal_False                        );
-
-            aWriteLock.unlock();
-           // <- SAFE ----------------------------------
+            m_bAllowParentShow   = lArgs.getUnpackedValueOrDefault("AllowParentShow"  , false );
+            m_bDisableReschedule = lArgs.getUnpackedValueOrDefault("DisableReschedule", false );
        }
     }
 
     impl_createProgress();
 }
 
-//-----------------------------------------------
 css::uno::Reference< css::task::XStatusIndicator > SAL_CALL StatusIndicatorFactory::createStatusIndicator()
-    throw(css::uno::RuntimeException)
 {
     StatusIndicator* pIndicator = new StatusIndicator(this);
     css::uno::Reference< css::task::XStatusIndicator > xIndicator(static_cast< ::cppu::OWeakObject* >(pIndicator), css::uno::UNO_QUERY_THROW);
@@ -137,36 +108,30 @@ css::uno::Reference< css::task::XStatusIndicator > SAL_CALL StatusIndicatorFacto
     return xIndicator;
 }
 
-//-----------------------------------------------
 void SAL_CALL StatusIndicatorFactory::update()
-    throw(css::uno::RuntimeException)
 {
-    // SAFE -> ----------------------------------
-    WriteGuard aWriteLock(m_aLock);
-    m_bAllowReschedule = sal_True;
-    aWriteLock.unlock();
-    // <- SAFE ----------------------------------
+    osl::MutexGuard g(m_mutex);
+    m_bAllowReschedule = true;
 }
 
-//-----------------------------------------------
 void StatusIndicatorFactory::start(const css::uno::Reference< css::task::XStatusIndicator >& xChild,
                                    const OUString&                                    sText ,
                                          sal_Int32                                           nRange)
 {
     // SAFE -> ----------------------------------
-    WriteGuard aWriteLock(m_aLock);
+    osl::ClearableMutexGuard aWriteLock(m_mutex);
 
     // create new info structure for this child or move it to the front of our stack
     IndicatorStack::iterator pItem = ::std::find(m_aStack.begin(), m_aStack.end(), xChild);
     if (pItem != m_aStack.end())
         m_aStack.erase(pItem);
-    IndicatorInfo aInfo(xChild, sText, nRange);
+    IndicatorInfo aInfo(xChild, sText);
     m_aStack.push_back (aInfo                );
 
     m_xActiveChild = xChild;
     css::uno::Reference< css::task::XStatusIndicator > xProgress = m_xProgress;
 
-    aWriteLock.unlock();
+    aWriteLock.clear();
     // <- SAFE ----------------------------------
 
     implts_makeParentVisibleIfAllowed();
@@ -175,45 +140,43 @@ void StatusIndicatorFactory::start(const css::uno::Reference< css::task::XStatus
         xProgress->start(sText, nRange);
 
     impl_startWakeUpThread();
-    impl_reschedule(sal_True);
+    impl_reschedule(true);
 }
 
-//-----------------------------------------------
 void StatusIndicatorFactory::reset(const css::uno::Reference< css::task::XStatusIndicator >& xChild)
 {
     // SAFE -> ----------------------------------
-    ReadGuard aReadLock(m_aLock);
+    osl::ClearableMutexGuard aReadLock(m_mutex);
 
     // reset the internal info structure related to this child
     IndicatorStack::iterator pItem = ::std::find(m_aStack.begin(), m_aStack.end(), xChild);
     if (pItem != m_aStack.end())
     {
         pItem->m_nValue = 0;
-        pItem->m_sText  = OUString();
+        (pItem->m_sText).clear();
     }
 
     css::uno::Reference< css::task::XStatusIndicator > xActive   = m_xActiveChild;
     css::uno::Reference< css::task::XStatusIndicator > xProgress = m_xProgress;
 
-    aReadLock.unlock();
+    aReadLock.clear();
     // <- SAFE ----------------------------------
 
-    // not the top most child => dont change UI
-    // But dont forget Reschedule!
+    // not the top most child => don't change UI
+    // But don't forget Reschedule!
     if (
         (xChild == xActive) &&
         (xProgress.is()   )
        )
         xProgress->reset();
 
-    impl_reschedule(sal_True);
+    impl_reschedule(true);
 }
 
-//-----------------------------------------------
 void StatusIndicatorFactory::end(const css::uno::Reference< css::task::XStatusIndicator >& xChild)
 {
     // SAFE -> ----------------------------------
-    WriteGuard aWriteLock(m_aLock);
+    osl::ClearableMutexGuard aWriteLock(m_mutex);
 
     // remove this child from our stack
     IndicatorStack::iterator pItem = ::std::find(m_aStack.begin(), m_aStack.end(), xChild);
@@ -235,7 +198,7 @@ void StatusIndicatorFactory::end(const css::uno::Reference< css::task::XStatusIn
     css::uno::Reference< css::task::XStatusIndicator > xActive   = m_xActiveChild;
     css::uno::Reference< css::task::XStatusIndicator > xProgress = m_xProgress;
 
-    aWriteLock.unlock();
+    aWriteLock.clear();
     // <- SAFE ----------------------------------
 
     if (xActive.is())
@@ -251,7 +214,7 @@ void StatusIndicatorFactory::end(const css::uno::Reference< css::task::XStatusIn
     else
     {
         // Our stack is empty. No further child exists.
-        // Se we must "end" our progress realy
+        // Se we must "end" our progress really
         if (xProgress.is())
             xProgress->end();
         // Now hide the progress bar again.
@@ -260,15 +223,14 @@ void StatusIndicatorFactory::end(const css::uno::Reference< css::task::XStatusIn
         impl_stopWakeUpThread();
     }
 
-    impl_reschedule(sal_True);
+    impl_reschedule(true);
 }
 
-//-----------------------------------------------
 void StatusIndicatorFactory::setText(const css::uno::Reference< css::task::XStatusIndicator >& xChild,
                                      const OUString&                                    sText )
 {
     // SAFE -> ----------------------------------
-    WriteGuard aWriteLock(m_aLock);
+    osl::ClearableMutexGuard aWriteLock(m_mutex);
 
     IndicatorStack::iterator pItem = ::std::find(m_aStack.begin(), m_aStack.end(), xChild);
     if (pItem != m_aStack.end())
@@ -277,11 +239,11 @@ void StatusIndicatorFactory::setText(const css::uno::Reference< css::task::XStat
     css::uno::Reference< css::task::XStatusIndicator > xActive   = m_xActiveChild;
     css::uno::Reference< css::task::XStatusIndicator > xProgress = m_xProgress;
 
-    aWriteLock.unlock();
+    aWriteLock.clear();
     // SAFE -> ----------------------------------
 
     // paint only the top most indicator
-    // but dont forget to Reschedule!
+    // but don't forget to Reschedule!
     if (
         (xChild == xActive) &&
         (xProgress.is()   )
@@ -290,15 +252,14 @@ void StatusIndicatorFactory::setText(const css::uno::Reference< css::task::XStat
         xProgress->setText(sText);
     }
 
-    impl_reschedule(sal_True);
+    impl_reschedule(true);
 }
 
-//-----------------------------------------------
 void StatusIndicatorFactory::setValue( const css::uno::Reference< css::task::XStatusIndicator >& xChild ,
                                              sal_Int32                                           nValue )
 {
     // SAFE -> ----------------------------------
-    WriteGuard aWriteLock(m_aLock);
+    osl::ClearableMutexGuard aWriteLock(m_mutex);
 
     sal_Int32 nOldValue = 0;
     IndicatorStack::iterator pItem = ::std::find(m_aStack.begin(), m_aStack.end(), xChild);
@@ -311,7 +272,7 @@ void StatusIndicatorFactory::setValue( const css::uno::Reference< css::task::XSt
     css::uno::Reference< css::task::XStatusIndicator > xActive    = m_xActiveChild;
     css::uno::Reference< css::task::XStatusIndicator > xProgress  = m_xProgress;
 
-    aWriteLock.unlock();
+    aWriteLock.clear();
     // SAFE -> ----------------------------------
 
     if (
@@ -323,14 +284,13 @@ void StatusIndicatorFactory::setValue( const css::uno::Reference< css::task::XSt
         xProgress->setValue(nValue);
     }
 
-    impl_reschedule(sal_False);
+    impl_reschedule(false);
 }
 
-//-----------------------------------------------
 void StatusIndicatorFactory::implts_makeParentVisibleIfAllowed()
 {
     // SAFE -> ----------------------------------
-    ReadGuard aReadLock(m_aLock);
+    osl::ClearableMutexGuard aReadLock(m_mutex);
 
     if (!m_bAllowParentShow)
         return;
@@ -339,7 +299,7 @@ void StatusIndicatorFactory::implts_makeParentVisibleIfAllowed()
     css::uno::Reference< css::awt::XWindow >  xPluggWindow(m_xPluggWindow.get(), css::uno::UNO_QUERY);
     css::uno::Reference< css::uno::XComponentContext > xContext( m_xContext);
 
-    aReadLock.unlock();
+    aReadLock.clear();
     // <- SAFE ----------------------------------
 
     css::uno::Reference< css::awt::XWindow > xParentWindow;
@@ -348,11 +308,11 @@ void StatusIndicatorFactory::implts_makeParentVisibleIfAllowed()
     else
         xParentWindow = xPluggWindow;
 
-    // dont disturb user in case he put the loading document into the background!
-    // Supress any setVisible() or toFront() call in case the initial show was
+    // don't disturb user in case he put the loading document into the background!
+    // Suppress any setVisible() or toFront() call in case the initial show was
     // already made.
     css::uno::Reference< css::awt::XWindow2 > xVisibleCheck(xParentWindow, css::uno::UNO_QUERY);
-    sal_Bool bIsVisible = sal_False;
+    bool bIsVisible = false;
     if (xVisibleCheck.is())
         bIsVisible = xVisibleCheck->isVisible();
 
@@ -368,7 +328,7 @@ void StatusIndicatorFactory::implts_makeParentVisibleIfAllowed()
     if (xPropSet.is())
     {
         css::uno::Reference< css::frame::XLayoutManager2 > xLayoutManager;
-        xPropSet->getPropertyValue(FRAME_PROPNAME_LAYOUTMANAGER) >>= xLayoutManager;
+        xPropSet->getPropertyValue(FRAME_PROPNAME_ASCII_LAYOUTMANAGER) >>= xLayoutManager;
         if (xLayoutManager.is())
         {
             if ( !xLayoutManager->isVisible() )
@@ -376,17 +336,17 @@ void StatusIndicatorFactory::implts_makeParentVisibleIfAllowed()
         }
     }
 
-    // Ok the window should be made visible ... because it isnt currently visible.
-    // BUT ..!
+    // Ok the window should be made visible... because it is not currently visible.
+    // BUT..!
     // We need a Hack for our applications: They get her progress from the frame directly
     // on saving documents. Because there is no progress set on the MediaDescriptor.
     // But that's wrong. In case the document was opened hidden, they should not use any progress .-(
-    // They only possible workaround: dont show the parent window here, if the document was opened hidden.
-    sal_Bool bHiddenDoc = sal_False;
+    // They only possible workaround: don't show the parent window here, if the document was opened hidden.
+    bool bHiddenDoc = false;
     if (xFrame.is())
     {
         css::uno::Reference< css::frame::XController > xController;
-        css::uno::Reference< css::frame::XModel >      xModel     ;
+        css::uno::Reference< css::frame::XModel >      xModel;
         xController = xFrame->getController();
         if (xController.is())
             xModel = xController->getModel();
@@ -395,7 +355,7 @@ void StatusIndicatorFactory::implts_makeParentVisibleIfAllowed()
             utl::MediaDescriptor lDocArgs(xModel->getArgs());
             bHiddenDoc = lDocArgs.getUnpackedValueOrDefault(
                 utl::MediaDescriptor::PROP_HIDDEN(),
-                (sal_Bool)sal_False);
+                false);
         }
     }
 
@@ -403,32 +363,31 @@ void StatusIndicatorFactory::implts_makeParentVisibleIfAllowed()
         return;
 
     // OK: The document was not opened in hidden mode ...
-    // and the window isnt already visible.
+    // and the window isn't already visible.
     // Show it and bring it to front.
     // But before we have to be sure, that our internal used helper progress
     // is visible too.
     impl_showProgress();
 
     SolarMutexGuard aSolarGuard;
-    Window* pWindow = VCLUnoHelper::GetWindow(xParentWindow);
+    VclPtr<vcl::Window> pWindow = VCLUnoHelper::GetWindow(xParentWindow);
     if ( pWindow )
     {
         bool bForceFrontAndFocus(officecfg::Office::Common::View::NewDocumentHandling::ForceFocusAndToFront::get(xContext));
-        pWindow->Show(sal_True, bForceFrontAndFocus ? SHOW_FOREGROUNDTASK : 0 );
+        pWindow->Show(true, bForceFrontAndFocus ? ShowFlags::ForegroundTask : ShowFlags::NONE );
     }
 
 }
 
-//-----------------------------------------------
 void StatusIndicatorFactory::impl_createProgress()
 {
     // SAFE -> ----------------------------------
-    ReadGuard aReadLock(m_aLock);
+    osl::ClearableMutexGuard aReadLock(m_mutex);
 
     css::uno::Reference< css::frame::XFrame >              xFrame (m_xFrame.get()      , css::uno::UNO_QUERY);
     css::uno::Reference< css::awt::XWindow >               xWindow(m_xPluggWindow.get(), css::uno::UNO_QUERY);
 
-    aReadLock.lock();
+    aReadLock.clear();
     // <- SAFE ----------------------------------
 
     css::uno::Reference< css::task::XStatusIndicator > xProgress;
@@ -437,7 +396,7 @@ void StatusIndicatorFactory::impl_createProgress()
     {
         // use vcl based progress implementation in plugged mode
         VCLStatusIndicator* pVCLProgress = new VCLStatusIndicator(xWindow);
-        xProgress = css::uno::Reference< css::task::XStatusIndicator >(static_cast< css::task::XStatusIndicator* >(pVCLProgress), css::uno::UNO_QUERY);
+        xProgress.set(static_cast< css::task::XStatusIndicator* >(pVCLProgress), css::uno::UNO_QUERY);
     }
     else if (xFrame.is())
     {
@@ -446,7 +405,7 @@ void StatusIndicatorFactory::impl_createProgress()
         if (xPropSet.is())
         {
             css::uno::Reference< css::frame::XLayoutManager2 > xLayoutManager;
-            xPropSet->getPropertyValue(FRAME_PROPNAME_LAYOUTMANAGER) >>= xLayoutManager;
+            xPropSet->getPropertyValue(FRAME_PROPNAME_ASCII_LAYOUTMANAGER) >>= xLayoutManager;
             if (xLayoutManager.is())
             {
                 xLayoutManager->lock();
@@ -456,29 +415,24 @@ void StatusIndicatorFactory::impl_createProgress()
 
                 css::uno::Reference< css::ui::XUIElement > xProgressBar = xLayoutManager->getElement(sPROGRESS_RESOURCE);
                 if (xProgressBar.is())
-                    xProgress = css::uno::Reference< css::task::XStatusIndicator >(xProgressBar->getRealInterface(), css::uno::UNO_QUERY);
+                    xProgress.set(xProgressBar->getRealInterface(), css::uno::UNO_QUERY);
                 xLayoutManager->unlock();
             }
         }
     }
 
-    // SAFE -> ----------------------------------
-    WriteGuard aWriteLock(m_aLock);
+    osl::MutexGuard g(m_mutex);
     m_xProgress = xProgress;
-    aWriteLock.lock();
-    // <- SAFE ----------------------------------
 }
 
-//-----------------------------------------------
 void StatusIndicatorFactory::impl_showProgress()
 {
     // SAFE -> ----------------------------------
-    ReadGuard aReadLock(m_aLock);
+    osl::ClearableMutexGuard aReadLock(m_mutex);
 
     css::uno::Reference< css::frame::XFrame >              xFrame (m_xFrame.get()      , css::uno::UNO_QUERY);
-    css::uno::Reference< css::awt::XWindow >               xWindow(m_xPluggWindow.get(), css::uno::UNO_QUERY);
 
-    aReadLock.lock();
+    aReadLock.clear();
     // <- SAFE ----------------------------------
 
     css::uno::Reference< css::task::XStatusIndicator > xProgress;
@@ -490,7 +444,7 @@ void StatusIndicatorFactory::impl_showProgress()
         if (xPropSet.is())
         {
             css::uno::Reference< css::frame::XLayoutManager2 > xLayoutManager;
-            xPropSet->getPropertyValue(FRAME_PROPNAME_LAYOUTMANAGER) >>= xLayoutManager;
+            xPropSet->getPropertyValue(FRAME_PROPNAME_ASCII_LAYOUTMANAGER) >>= xLayoutManager;
             if (xLayoutManager.is())
             {
                 // Be sure that we have always a progress. It can be that our frame
@@ -502,28 +456,23 @@ void StatusIndicatorFactory::impl_showProgress()
 
                 css::uno::Reference< css::ui::XUIElement > xProgressBar = xLayoutManager->getElement(sPROGRESS_RESOURCE);
                 if (xProgressBar.is())
-                    xProgress = css::uno::Reference< css::task::XStatusIndicator >(xProgressBar->getRealInterface(), css::uno::UNO_QUERY);
+                    xProgress.set(xProgressBar->getRealInterface(), css::uno::UNO_QUERY);
             }
         }
 
-        // SAFE -> ----------------------------------
-        WriteGuard aWriteLock(m_aLock);
+        osl::MutexGuard g(m_mutex);
         m_xProgress = xProgress;
-        aWriteLock.lock();
-        // <- SAFE ----------------------------------
     }
 }
 
-//-----------------------------------------------
 void StatusIndicatorFactory::impl_hideProgress()
 {
     // SAFE -> ----------------------------------
-    ReadGuard aReadLock(m_aLock);
+    osl::ClearableMutexGuard aReadLock(m_mutex);
 
     css::uno::Reference< css::frame::XFrame >              xFrame (m_xFrame.get()      , css::uno::UNO_QUERY);
-    css::uno::Reference< css::awt::XWindow >               xWindow(m_xPluggWindow.get(), css::uno::UNO_QUERY);
 
-    aReadLock.lock();
+    aReadLock.clear();
     // <- SAFE ----------------------------------
 
     if (xFrame.is())
@@ -533,44 +482,40 @@ void StatusIndicatorFactory::impl_hideProgress()
         if (xPropSet.is())
         {
             css::uno::Reference< css::frame::XLayoutManager2 > xLayoutManager;
-            xPropSet->getPropertyValue(FRAME_PROPNAME_LAYOUTMANAGER) >>= xLayoutManager;
+            xPropSet->getPropertyValue(FRAME_PROPNAME_ASCII_LAYOUTMANAGER) >>= xLayoutManager;
             if (xLayoutManager.is())
-                xLayoutManager->hideElement( OUString(PROGRESS_RESOURCE) );
+                xLayoutManager->hideElement( PROGRESS_RESOURCE );
         }
     }
 }
 
-//-----------------------------------------------
-void StatusIndicatorFactory::impl_reschedule(sal_Bool bForce)
+void StatusIndicatorFactory::impl_reschedule(bool bForce)
 {
     // SAFE ->
-    ReadGuard aReadLock(m_aLock);
+    osl::ClearableMutexGuard aReadLock(m_mutex);
     if (m_bDisableReschedule)
         return;
-    aReadLock.unlock();
+    aReadLock.clear();
     // <- SAFE
 
-    sal_Bool bReschedule = bForce;
+    bool bReschedule = bForce;
     if (!bReschedule)
     {
-        // SAFE ->
-        WriteGuard aWriteLock(m_aLock);
+        osl::MutexGuard g(m_mutex);
         bReschedule        = m_bAllowReschedule;
-        m_bAllowReschedule = sal_False;
-        aWriteLock.unlock();
-        // <- SAFE
+        m_bAllowReschedule = false;
     }
 
     if (!bReschedule)
         return;
 
     // SAFE ->
-    WriteGuard aGlobalLock(LockHelper::getGlobalLock());
+    osl::ResettableMutexGuard aRescheduleGuard(RescheduleLock::get());
 
     if (m_nInReschedule == 0)
     {
         ++m_nInReschedule;
-        aGlobalLock.unlock();
+        aRescheduleGuard.clear();
         // <- SAFE
 
         {
@@ -579,44 +524,46 @@ void StatusIndicatorFactory::impl_reschedule(sal_Bool bForce)
         }
 
         // SAFE ->
-        aGlobalLock.lock();
+        aRescheduleGuard.reset();
         --m_nInReschedule;
     }
 }
 
-//-----------------------------------------------
 void StatusIndicatorFactory::impl_startWakeUpThread()
 {
-    // SAFE ->
-    WriteGuard aWriteLock(m_aLock);
+    osl::MutexGuard g(m_mutex);
 
     if (m_bDisableReschedule)
         return;
 
-    if (!m_pWakeUp)
+    if (!m_pWakeUp.is())
     {
         m_pWakeUp = new WakeUpThread(this);
-        m_pWakeUp->create();
+        m_pWakeUp->launch();
     }
-    aWriteLock.unlock();
-    // <- SAFE
 }
 
-//-----------------------------------------------
 void StatusIndicatorFactory::impl_stopWakeUpThread()
 {
-    // SAFE ->
-    WriteGuard aWriteLock(m_aLock);
-    if (m_pWakeUp)
+    rtl::Reference<WakeUpThread> wakeUp;
     {
-        // Thread kill itself after terminate()!
-        m_pWakeUp->terminate();
-        m_pWakeUp = 0;
+        osl::MutexGuard g(m_mutex);
+        std::swap(wakeUp, m_pWakeUp);
+    }
+    if (wakeUp.is())
+    {
+        wakeUp->stop();
     }
-    aWriteLock.unlock();
-    // <- SAFE
 }
 
 } // namespace framework
 
+extern "C" SAL_DLLPUBLIC_EXPORT css::uno::XInterface * SAL_CALL
+com_sun_star_comp_framework_StatusIndicatorFactory_get_implementation(
+    css::uno::XComponentContext *context,
+    css::uno::Sequence<css::uno::Any> const &)
+{
+    return cppu::acquire(new framework::StatusIndicatorFactory(context));
+}
+
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
