@@ -20,7 +20,6 @@
 #include <helper/uiconfigelementwrapperbase.hxx>
 #include <general.h>
 #include <properties.h>
-#include <threadhelp/resetableguard.hxx>
 #include <uielement/constitemcontainer.hxx>
 #include <uielement/rootitemcontainer.hxx>
 
@@ -60,17 +59,16 @@ namespace framework
 {
 
 UIConfigElementWrapperBase::UIConfigElementWrapperBase( sal_Int16 nType )
-    :   ThreadHelpBase              ( &Application::GetSolarMutex()                      )
-    ,   ::cppu::OBroadcastHelperVar< ::cppu::OMultiTypeInterfaceContainerHelper, ::cppu::OMultiTypeInterfaceContainerHelper::keyType >( m_aLock.getShareableOslMutex() )
-    ,   ::cppu::OPropertySetHelper  ( *(static_cast< ::cppu::OBroadcastHelper* >(this)) )
+    :   ::cppu::OBroadcastHelperVar< ::cppu::OMultiTypeInterfaceContainerHelper, ::cppu::OMultiTypeInterfaceContainerHelper::keyType >( m_aMutex )
+    ,   ::cppu::OPropertySetHelper  ( *static_cast< ::cppu::OBroadcastHelper* >(this) )
     ,   m_nType                     ( nType                                             )
-    ,   m_bPersistent               ( sal_True                                          )
-    ,   m_bInitialized              ( sal_False                                         )
-    ,   m_bConfigListener           ( sal_False                                         )
-    ,   m_bConfigListening          ( sal_False                                         )
-    ,   m_bDisposed                 ( sal_False                                         )
-    ,   m_bNoClose                  ( sal_False                                         )
-    ,   m_aListenerContainer        ( m_aLock.getShareableOslMutex()                    )
+    ,   m_bPersistent               ( true                                          )
+    ,   m_bInitialized              ( false                                         )
+    ,   m_bConfigListener           ( false                                         )
+    ,   m_bConfigListening          ( false                                         )
+    ,   m_bDisposed                 ( false                                         )
+    ,   m_bNoClose                  ( false                                         )
+    ,   m_aListenerContainer        ( m_aMutex )
 {
 }
 
@@ -78,7 +76,7 @@ UIConfigElementWrapperBase::~UIConfigElementWrapperBase()
 {
 }
 
-Any SAL_CALL UIConfigElementWrapperBase::queryInterface( const Type& _rType ) throw(RuntimeException)
+Any SAL_CALL UIConfigElementWrapperBase::queryInterface( const Type& _rType )
 {
     Any aRet = UIConfigElementWrapperBase_BASE::queryInterface( _rType );
     if ( !aRet.hasValue() )
@@ -86,7 +84,7 @@ Any SAL_CALL UIConfigElementWrapperBase::queryInterface( const Type& _rType ) th
     return aRet;
 }
 
-Sequence< Type > SAL_CALL UIConfigElementWrapperBase::getTypes(  ) throw(RuntimeException)
+Sequence< Type > SAL_CALL UIConfigElementWrapperBase::getTypes(  )
 {
     return comphelper::concatSequences(
         UIConfigElementWrapperBase_BASE::getTypes(),
@@ -95,28 +93,26 @@ Sequence< Type > SAL_CALL UIConfigElementWrapperBase::getTypes(  ) throw(Runtime
 }
 
 // XComponent
-void SAL_CALL UIConfigElementWrapperBase::addEventListener( const ::com::sun::star::uno::Reference< ::com::sun::star::lang::XEventListener >& xListener ) throw (::com::sun::star::uno::RuntimeException)
+void SAL_CALL UIConfigElementWrapperBase::addEventListener( const css::uno::Reference< css::lang::XEventListener >& xListener )
 {
-    m_aListenerContainer.addInterface( ::getCppuType( ( const css::uno::Reference< css::lang::XEventListener >* ) NULL ), xListener );
+    m_aListenerContainer.addInterface( cppu::UnoType<css::lang::XEventListener>::get(), xListener );
 }
 
-void SAL_CALL UIConfigElementWrapperBase::removeEventListener( const ::com::sun::star::uno::Reference< ::com::sun::star::lang::XEventListener >& aListener ) throw (::com::sun::star::uno::RuntimeException)
+void SAL_CALL UIConfigElementWrapperBase::removeEventListener( const css::uno::Reference< css::lang::XEventListener >& aListener )
 {
-    m_aListenerContainer.removeInterface( ::getCppuType( ( const css::uno::Reference< css::lang::XEventListener >* ) NULL ), aListener );
+    m_aListenerContainer.removeInterface( cppu::UnoType<css::lang::XEventListener>::get(), aListener );
 }
 
 // XEventListener
 void SAL_CALL UIConfigElementWrapperBase::disposing( const EventObject& )
-throw( RuntimeException )
 {
-    ResetableGuard aLock( m_aLock );
+    SolarMutexGuard g;
     m_xConfigSource.clear();
 }
 
 void SAL_CALL UIConfigElementWrapperBase::initialize( const Sequence< Any >& aArguments )
-throw ( Exception, RuntimeException )
 {
-    ResetableGuard aLock( m_aLock );
+    SolarMutexGuard g;
 
     if ( !m_bInitialized )
     {
@@ -142,27 +138,27 @@ throw ( Exception, RuntimeException )
             }
         }
 
-        m_bInitialized = sal_True;
+        m_bInitialized = true;
     }
 }
 
 // XUpdatable
-void SAL_CALL UIConfigElementWrapperBase::update() throw (::com::sun::star::uno::RuntimeException)
+void SAL_CALL UIConfigElementWrapperBase::update()
 {
     // can be implemented by derived class
 }
 
-void SAL_CALL UIConfigElementWrapperBase::elementInserted( const ::com::sun::star::ui::ConfigurationEvent& ) throw (::com::sun::star::uno::RuntimeException)
+void SAL_CALL UIConfigElementWrapperBase::elementInserted( const css::ui::ConfigurationEvent& )
 {
     // can be implemented by derived class
 }
 
-void SAL_CALL UIConfigElementWrapperBase::elementRemoved( const ::com::sun::star::ui::ConfigurationEvent& ) throw (::com::sun::star::uno::RuntimeException)
+void SAL_CALL UIConfigElementWrapperBase::elementRemoved( const css::ui::ConfigurationEvent& )
 {
     // can be implemented by derived class
 }
 
-void SAL_CALL UIConfigElementWrapperBase::elementReplaced( const ::com::sun::star::ui::ConfigurationEvent& ) throw (::com::sun::star::uno::RuntimeException)
+void SAL_CALL UIConfigElementWrapperBase::elementReplaced( const css::ui::ConfigurationEvent& )
 {
     // can be implemented by derived class
 }
@@ -171,17 +167,17 @@ void SAL_CALL UIConfigElementWrapperBase::elementReplaced( const ::com::sun::sta
 sal_Bool SAL_CALL UIConfigElementWrapperBase::convertFastPropertyValue( Any&       aConvertedValue ,
                                                                         Any&       aOldValue       ,
                                                                         sal_Int32  nHandle         ,
-                                                                        const Any& aValue             ) throw( com::sun::star::lang::IllegalArgumentException )
+                                                                        const Any& aValue             )
 {
     //  Initialize state with sal_False !!!
     //  (Handle can be invalid)
-    sal_Bool bReturn = sal_False;
+    bool bReturn = false;
 
     switch( nHandle )
     {
         case UIELEMENT_PROPHANDLE_CONFIGLISTENER:
             bReturn = PropHelper::willPropertyBeChanged(
-                        com::sun::star::uno::makeAny(m_bConfigListener),
+                        css::uno::makeAny(m_bConfigListener),
                         aValue,
                         aOldValue,
                         aConvertedValue);
@@ -189,7 +185,7 @@ sal_Bool SAL_CALL UIConfigElementWrapperBase::convertFastPropertyValue( Any&
 
         case UIELEMENT_PROPHANDLE_CONFIGSOURCE:
             bReturn = PropHelper::willPropertyBeChanged(
-                        com::sun::star::uno::makeAny(m_xConfigSource),
+                        css::uno::makeAny(m_xConfigSource),
                         aValue,
                         aOldValue,
                         aConvertedValue);
@@ -199,7 +195,7 @@ sal_Bool SAL_CALL UIConfigElementWrapperBase::convertFastPropertyValue( Any&
         {
             Reference< XFrame > xFrame( m_xWeakFrame );
             bReturn = PropHelper::willPropertyBeChanged(
-                        com::sun::star::uno::makeAny(xFrame),
+                        css::uno::makeAny(xFrame),
                         aValue,
                         aOldValue,
                         aConvertedValue);
@@ -208,7 +204,7 @@ sal_Bool SAL_CALL UIConfigElementWrapperBase::convertFastPropertyValue( Any&
 
         case UIELEMENT_PROPHANDLE_PERSISTENT:
             bReturn = PropHelper::willPropertyBeChanged(
-                        com::sun::star::uno::makeAny(m_bPersistent),
+                        css::uno::makeAny(m_bPersistent),
                         aValue,
                         aOldValue,
                         aConvertedValue);
@@ -216,7 +212,7 @@ sal_Bool SAL_CALL UIConfigElementWrapperBase::convertFastPropertyValue( Any&
 
         case UIELEMENT_PROPHANDLE_RESOURCEURL:
             bReturn = PropHelper::willPropertyBeChanged(
-                        com::sun::star::uno::makeAny(m_aResourceURL),
+                        css::uno::makeAny(m_aResourceURL),
                         aValue,
                         aOldValue,
                         aConvertedValue);
@@ -224,7 +220,7 @@ sal_Bool SAL_CALL UIConfigElementWrapperBase::convertFastPropertyValue( Any&
 
         case UIELEMENT_PROPHANDLE_TYPE :
             bReturn = PropHelper::willPropertyBeChanged(
-                        com::sun::star::uno::makeAny(m_nType),
+                        css::uno::makeAny(m_nType),
                         aValue,
                         aOldValue,
                         aConvertedValue);
@@ -232,7 +228,7 @@ sal_Bool SAL_CALL UIConfigElementWrapperBase::convertFastPropertyValue( Any&
 
         case UIELEMENT_PROPHANDLE_XMENUBAR :
             bReturn = PropHelper::willPropertyBeChanged(
-                        com::sun::star::uno::makeAny(m_xMenuBar),
+                        css::uno::makeAny(m_xMenuBar),
                         aValue,
                         aOldValue,
                         aConvertedValue);
@@ -240,7 +236,7 @@ sal_Bool SAL_CALL UIConfigElementWrapperBase::convertFastPropertyValue( Any&
 
         case UIELEMENT_PROPHANDLE_NOCLOSE:
             bReturn = PropHelper::willPropertyBeChanged(
-                        com::sun::star::uno::makeAny(m_bNoClose),
+                        css::uno::makeAny(m_bNoClose),
                         aValue,
                         aOldValue,
                         aConvertedValue);
@@ -248,11 +244,11 @@ sal_Bool SAL_CALL UIConfigElementWrapperBase::convertFastPropertyValue( Any&
     }
 
     // Return state of operation.
-    return bReturn ;
+    return bReturn;
 }
 
 void SAL_CALL UIConfigElementWrapperBase::setFastPropertyValue_NoBroadcast(   sal_Int32               nHandle ,
-                                                                        const com::sun::star::uno::Any&    aValue  ) throw( com::sun::star::uno::Exception )
+                                                                        const css::uno::Any&    aValue  )
 {
     switch( nHandle )
     {
@@ -272,7 +268,7 @@ void SAL_CALL UIConfigElementWrapperBase::setFastPropertyValue_NoBroadcast(   sa
                             if ( xUIConfig.is() )
                             {
                                 xUIConfig->removeConfigurationListener( Reference< XUIConfigurationListener >( static_cast< OWeakObject* >( this ), UNO_QUERY ));
-                                m_bConfigListening = sal_False;
+                                m_bConfigListening = false;
                             }
                         }
                         catch ( const Exception& )
@@ -290,7 +286,7 @@ void SAL_CALL UIConfigElementWrapperBase::setFastPropertyValue_NoBroadcast(   sa
                             if ( xUIConfig.is() )
                             {
                                 xUIConfig->addConfigurationListener( Reference< XUIConfigurationListener >( static_cast< OWeakObject* >( this ), UNO_QUERY ));
-                                m_bConfigListening = sal_True;
+                                m_bConfigListening = true;
                             }
                         }
                         catch ( const Exception& )
@@ -316,7 +312,7 @@ void SAL_CALL UIConfigElementWrapperBase::setFastPropertyValue_NoBroadcast(   sa
         }
         case UIELEMENT_PROPHANDLE_PERSISTENT:
         {
-            sal_Bool bBool( m_bPersistent );
+            bool bBool( m_bPersistent );
             aValue >>= bBool;
             m_bPersistent = bBool;
             break;
@@ -332,7 +328,7 @@ void SAL_CALL UIConfigElementWrapperBase::setFastPropertyValue_NoBroadcast(   sa
             break;
         case UIELEMENT_PROPHANDLE_NOCLOSE:
         {
-            sal_Bool bBool( m_bNoClose );
+            bool bBool( m_bNoClose );
             aValue >>= bBool;
             m_bNoClose = bBool;
             break;
@@ -340,7 +336,7 @@ void SAL_CALL UIConfigElementWrapperBase::setFastPropertyValue_NoBroadcast(   sa
     }
 }
 
-void SAL_CALL UIConfigElementWrapperBase::getFastPropertyValue( com::sun::star::uno::Any& aValue  ,
+void SAL_CALL UIConfigElementWrapperBase::getFastPropertyValue( css::uno::Any& aValue  ,
                                                                 sal_Int32                 nHandle   ) const
 {
     switch( nHandle )
@@ -377,55 +373,24 @@ void SAL_CALL UIConfigElementWrapperBase::getFastPropertyValue( com::sun::star::
 
 ::cppu::IPropertyArrayHelper& SAL_CALL UIConfigElementWrapperBase::getInfoHelper()
 {
-    // Optimize this method !
-    // We initialize a static variable only one time. And we don't must use a mutex at every call!
-    // For the first call; pInfoHelper is NULL - for the second call pInfoHelper is different from NULL!
-    static ::cppu::OPropertyArrayHelper* pInfoHelper = NULL;
+    // Define static member to give structure of properties to baseclass "OPropertySetHelper".
+    // "impl_getStaticPropertyDescriptor" is a non exported and static function, who will define a static propertytable.
+    // "true" say: Table is sorted by name.
+    static ::cppu::OPropertyArrayHelper ourInfoHelper( impl_getStaticPropertyDescriptor(), true );
 
-    if( pInfoHelper == NULL )
-    {
-        // Ready for multithreading
-        osl::MutexGuard aGuard( osl::Mutex::getGlobalMutex() ) ;
-
-        // Control this pointer again, another instance can be faster then these!
-        if( pInfoHelper == NULL )
-        {
-            // Define static member to give structure of properties to baseclass "OPropertySetHelper".
-            // "impl_getStaticPropertyDescriptor" is a non exported and static funtion, who will define a static propertytable.
-            // "sal_True" say: Table is sorted by name.
-            static ::cppu::OPropertyArrayHelper aInfoHelper( impl_getStaticPropertyDescriptor(), sal_True );
-            pInfoHelper = &aInfoHelper;
-        }
-    }
-
-    return(*pInfoHelper);
+    return ourInfoHelper;
 }
 
-com::sun::star::uno::Reference< com::sun::star::beans::XPropertySetInfo > SAL_CALL UIConfigElementWrapperBase::getPropertySetInfo() throw (::com::sun::star::uno::RuntimeException)
+css::uno::Reference< css::beans::XPropertySetInfo > SAL_CALL UIConfigElementWrapperBase::getPropertySetInfo()
 {
-    // Optimize this method !
-    // We initialize a static variable only one time. And we don't must use a mutex at every call!
-    // For the first call; pInfo is NULL - for the second call pInfo is different from NULL!
-    static com::sun::star::uno::Reference< com::sun::star::beans::XPropertySetInfo >* pInfo = NULL;
+    // Create structure of propertysetinfo for baseclass "OPropertySetHelper".
+    // (Use method "getInfoHelper()".)
+    static css::uno::Reference< css::beans::XPropertySetInfo > xInfo( createPropertySetInfo( getInfoHelper() ) );
 
-    if( pInfo == NULL )
-    {
-        // Ready for multithreading
-        osl::MutexGuard aGuard( osl::Mutex::getGlobalMutex() ) ;
-        // Control this pointer again, another instance can be faster then these!
-        if( pInfo == NULL )
-        {
-            // Create structure of propertysetinfo for baseclass "OPropertySetHelper".
-            // (Use method "getInfoHelper()".)
-            static com::sun::star::uno::Reference< com::sun::star::beans::XPropertySetInfo > xInfo( createPropertySetInfo( getInfoHelper() ) );
-            pInfo = &xInfo;
-        }
-    }
-
-    return (*pInfo);
+    return xInfo;
 }
 
-const com::sun::star::uno::Sequence< com::sun::star::beans::Property > UIConfigElementWrapperBase::impl_getStaticPropertyDescriptor()
+const css::uno::Sequence< css::beans::Property > UIConfigElementWrapperBase::impl_getStaticPropertyDescriptor()
 {
     // Create property array to initialize sequence!
     // Table of all predefined properties of this class. Its used from OPropertySetHelper-class!
@@ -434,33 +399,32 @@ const com::sun::star::uno::Sequence< com::sun::star::beans::Property > UIConfigE
     // ATTENTION:
     //      YOU MUST SORT FOLLOW TABLE BY NAME ALPHABETICAL !!!
 
-    const com::sun::star::beans::Property pProperties[] =
+    const css::beans::Property pProperties[] =
     {
-        com::sun::star::beans::Property( OUString(UIELEMENT_PROPNAME_CONFIGLISTENER), UIELEMENT_PROPHANDLE_CONFIGLISTENER , ::getCppuType((const sal_Bool*)NULL), com::sun::star::beans::PropertyAttribute::TRANSIENT  ),
-        com::sun::star::beans::Property( OUString(UIELEMENT_PROPNAME_CONFIGSOURCE), UIELEMENT_PROPHANDLE_CONFIGSOURCE   , ::getCppuType((const Reference< ::com::sun::star::ui::XUIConfigurationManager >*)NULL), com::sun::star::beans::PropertyAttribute::TRANSIENT  ),
-        com::sun::star::beans::Property( OUString(UIELEMENT_PROPNAME_FRAME), UIELEMENT_PROPHANDLE_FRAME          , ::getCppuType((const Reference< com::sun::star::frame::XFrame >*)NULL), com::sun::star::beans::PropertyAttribute::TRANSIENT | com::sun::star::beans::PropertyAttribute::READONLY ),
-        com::sun::star::beans::Property( OUString(UIELEMENT_PROPNAME_NOCLOSE), UIELEMENT_PROPHANDLE_NOCLOSE        , ::getCppuType((const sal_Bool*)NULL), com::sun::star::beans::PropertyAttribute::TRANSIENT ),
-        com::sun::star::beans::Property( OUString(UIELEMENT_PROPNAME_PERSISTENT), UIELEMENT_PROPHANDLE_PERSISTENT     , ::getCppuType((const sal_Bool*)NULL), com::sun::star::beans::PropertyAttribute::TRANSIENT  ),
-        com::sun::star::beans::Property( OUString(UIELEMENT_PROPNAME_RESOURCEURL), UIELEMENT_PROPHANDLE_RESOURCEURL    , ::getCppuType((const OUString*)NULL), com::sun::star::beans::PropertyAttribute::TRANSIENT | com::sun::star::beans::PropertyAttribute::READONLY ),
-        com::sun::star::beans::Property( OUString(UIELEMENT_PROPNAME_TYPE), UIELEMENT_PROPHANDLE_TYPE           , ::getCppuType((const OUString*)NULL), com::sun::star::beans::PropertyAttribute::TRANSIENT | com::sun::star::beans::PropertyAttribute::READONLY ),
-        com::sun::star::beans::Property( OUString(UIELEMENT_PROPNAME_XMENUBAR), UIELEMENT_PROPHANDLE_XMENUBAR       , ::getCppuType((const Reference< com::sun::star::awt::XMenuBar >*)NULL), com::sun::star::beans::PropertyAttribute::TRANSIENT | com::sun::star::beans::PropertyAttribute::READONLY )
+        css::beans::Property( UIELEMENT_PROPNAME_CONFIGLISTENER, UIELEMENT_PROPHANDLE_CONFIGLISTENER , cppu::UnoType<sal_Bool>::get(), css::beans::PropertyAttribute::TRANSIENT  ),
+        css::beans::Property( UIELEMENT_PROPNAME_CONFIGSOURCE, UIELEMENT_PROPHANDLE_CONFIGSOURCE   , cppu::UnoType<css::ui::XUIConfigurationManager>::get(), css::beans::PropertyAttribute::TRANSIENT  ),
+        css::beans::Property( UIELEMENT_PROPNAME_FRAME, UIELEMENT_PROPHANDLE_FRAME          , cppu::UnoType<css::frame::XFrame>::get(), css::beans::PropertyAttribute::TRANSIENT | css::beans::PropertyAttribute::READONLY ),
+        css::beans::Property( UIELEMENT_PROPNAME_NOCLOSE, UIELEMENT_PROPHANDLE_NOCLOSE        , cppu::UnoType<sal_Bool>::get(), css::beans::PropertyAttribute::TRANSIENT ),
+        css::beans::Property( UIELEMENT_PROPNAME_PERSISTENT, UIELEMENT_PROPHANDLE_PERSISTENT     , cppu::UnoType<sal_Bool>::get(), css::beans::PropertyAttribute::TRANSIENT  ),
+        css::beans::Property( UIELEMENT_PROPNAME_RESOURCEURL, UIELEMENT_PROPHANDLE_RESOURCEURL    , cppu::UnoType<OUString>::get(), css::beans::PropertyAttribute::TRANSIENT | css::beans::PropertyAttribute::READONLY ),
+        css::beans::Property( UIELEMENT_PROPNAME_TYPE, UIELEMENT_PROPHANDLE_TYPE           , cppu::UnoType<OUString>::get(), css::beans::PropertyAttribute::TRANSIENT | css::beans::PropertyAttribute::READONLY ),
+        css::beans::Property( UIELEMENT_PROPNAME_XMENUBAR, UIELEMENT_PROPHANDLE_XMENUBAR       , cppu::UnoType<css::awt::XMenuBar>::get(), css::beans::PropertyAttribute::TRANSIENT | css::beans::PropertyAttribute::READONLY )
     };
     // Use it to initialize sequence!
-    const com::sun::star::uno::Sequence< com::sun::star::beans::Property > lPropertyDescriptor( pProperties, UIELEMENT_PROPCOUNT );
+    const css::uno::Sequence< css::beans::Property > lPropertyDescriptor( pProperties, UIELEMENT_PROPCOUNT );
     // Return "PropertyDescriptor"
     return lPropertyDescriptor;
 }
-void SAL_CALL UIConfigElementWrapperBase::setSettings( const Reference< XIndexAccess >& xSettings ) throw ( RuntimeException )
+void SAL_CALL UIConfigElementWrapperBase::setSettings( const Reference< XIndexAccess >& xSettings )
 {
-    ResetableGuard aLock( m_aLock );
-
+    SolarMutexClearableGuard aLock;
 
     if ( xSettings.is() )
     {
         // Create a copy of the data if the container is not const
         Reference< XIndexReplace > xReplace( xSettings, UNO_QUERY );
         if ( xReplace.is() )
-            m_xConfigData = Reference< XIndexAccess >( static_cast< OWeakObject * >( new ConstItemContainer( xSettings ) ), UNO_QUERY );
+            m_xConfigData.set( static_cast< OWeakObject * >( new ConstItemContainer( xSettings ) ), UNO_QUERY );
         else
             m_xConfigData = xSettings;
 
@@ -469,7 +433,7 @@ void SAL_CALL UIConfigElementWrapperBase::setSettings( const Reference< XIndexAc
             OUString aResourceURL( m_aResourceURL );
             Reference< XUIConfigurationManager > xUICfgMgr( m_xConfigSource );
 
-            aLock.unlock();
+            aLock.clear();
 
             try
             {
@@ -489,10 +453,9 @@ void SAL_CALL UIConfigElementWrapperBase::setSettings( const Reference< XIndexAc
 void UIConfigElementWrapperBase::impl_fillNewData()
 {
 }
-Reference< XIndexAccess > SAL_CALL UIConfigElementWrapperBase::getSettings( sal_Bool bWriteable ) throw ( RuntimeException )
+Reference< XIndexAccess > SAL_CALL UIConfigElementWrapperBase::getSettings( sal_Bool bWriteable )
 {
-    ResetableGuard aLock( m_aLock );
-
+    SolarMutexGuard g;
 
     if ( bWriteable )
         return Reference< XIndexAccess >( static_cast< OWeakObject * >( new RootItemContainer( m_xConfigData ) ), UNO_QUERY );
@@ -500,22 +463,22 @@ Reference< XIndexAccess > SAL_CALL UIConfigElementWrapperBase::getSettings( sal_
     return m_xConfigData;
 }
 
-Reference< XFrame > SAL_CALL UIConfigElementWrapperBase::getFrame() throw (RuntimeException)
+Reference< XFrame > SAL_CALL UIConfigElementWrapperBase::getFrame()
 {
-    ResetableGuard aLock( m_aLock );
+    SolarMutexGuard g;
     Reference< XFrame > xFrame( m_xWeakFrame );
     return xFrame;
 }
 
-OUString SAL_CALL UIConfigElementWrapperBase::getResourceURL() throw (RuntimeException)
+OUString SAL_CALL UIConfigElementWrapperBase::getResourceURL()
 {
-    ResetableGuard aLock( m_aLock );
+    SolarMutexGuard g;
     return m_aResourceURL;
 }
 
-::sal_Int16 SAL_CALL UIConfigElementWrapperBase::getType() throw (RuntimeException)
+::sal_Int16 SAL_CALL UIConfigElementWrapperBase::getType()
 {
-    ResetableGuard aLock( m_aLock );
+    SolarMutexGuard g;
     return m_nType;
 }
 
