@@ -35,11 +35,11 @@
 #include <com/sun/star/frame/XModuleManager2.hpp>
 
 #include <cppuhelper/basemutex.hxx>
-#include <cppuhelper/compbase2.hxx>
+#include <cppuhelper/compbase.hxx>
 #include <cppuhelper/supportsservice.hxx>
 #include <vcl/svapp.hxx>
 
-#include <boost/unordered_map.hpp>
+#include <unordered_map>
 
 using namespace com::sun::star::uno;
 using namespace com::sun::star::io;
@@ -53,7 +53,7 @@ using namespace framework;
 
 namespace {
 
-typedef cppu::WeakComponentImplHelper2<
+typedef cppu::WeakComponentImplHelper<
     css::lang::XServiceInfo,
     css::ui::XModuleUIConfigurationManagerSupplier >
         ModuleUIConfigurationManagerSupplier_BASE;
@@ -62,37 +62,31 @@ class ModuleUIConfigurationManagerSupplier : private cppu::BaseMutex,
                                              public ModuleUIConfigurationManagerSupplier_BASE
 {
 public:
-    ModuleUIConfigurationManagerSupplier( const css::uno::Reference< css::uno::XComponentContext >& rxContext );
-    virtual ~ModuleUIConfigurationManagerSupplier();
+    explicit ModuleUIConfigurationManagerSupplier( const css::uno::Reference< css::uno::XComponentContext >& rxContext );
+    virtual ~ModuleUIConfigurationManagerSupplier() override;
 
-    virtual OUString SAL_CALL getImplementationName()
-        throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE
+    virtual OUString SAL_CALL getImplementationName() override
     {
         return OUString("com.sun.star.comp.framework.ModuleUIConfigurationManagerSupplier");
     }
 
-    virtual sal_Bool SAL_CALL supportsService(OUString const & ServiceName)
-        throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE
+    virtual sal_Bool SAL_CALL supportsService(OUString const & ServiceName) override
     {
         return cppu::supportsService(this, ServiceName);
     }
 
-    virtual css::uno::Sequence<OUString> SAL_CALL getSupportedServiceNames()
-        throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE
+    virtual css::uno::Sequence<OUString> SAL_CALL getSupportedServiceNames() override
     {
-        css::uno::Sequence< OUString > aSeq(1);
-        aSeq[0] = OUString("com.sun.star.ui.ModuleUIConfigurationManagerSupplier");
-        return aSeq;
+        return {"com.sun.star.ui.ModuleUIConfigurationManagerSupplier"};
     }
 
     // XModuleUIConfigurationManagerSupplier
-    virtual css::uno::Reference< css::ui::XUIConfigurationManager > SAL_CALL getUIConfigurationManager( const OUString& ModuleIdentifier )
-        throw (css::container::NoSuchElementException, css::uno::RuntimeException, std::exception) SAL_OVERRIDE;
+    virtual css::uno::Reference< css::ui::XUIConfigurationManager > SAL_CALL getUIConfigurationManager( const OUString& ModuleIdentifier ) override;
 
 private:
-    virtual void SAL_CALL disposing() SAL_OVERRIDE;
+    virtual void SAL_CALL disposing() final override;
 
-    typedef ::boost::unordered_map< OUString, css::uno::Reference< css::ui::XModuleUIConfigurationManager2 >, OUStringHash, ::std::equal_to< OUString > > ModuleToModuleCfgMgr;
+    typedef std::unordered_map< OUString, css::uno::Reference< css::ui::XModuleUIConfigurationManager2 > > ModuleToModuleCfgMgr;
 
 //TODO_AS            void impl_initStorages();
 
@@ -108,12 +102,12 @@ ModuleUIConfigurationManagerSupplier::ModuleUIConfigurationManagerSupplier( cons
 {
     try
     {
-        // Retrieve known modules and insert them into our boost::unordered_map to speed-up access time.
+        // Retrieve known modules and insert them into our unordered_map to speed-up access time.
         Reference< XNameAccess > xNameAccess( m_xModuleMgr, UNO_QUERY_THROW );
         const Sequence< OUString >     aNameSeq   = xNameAccess->getElementNames();
         const OUString*                pNameSeq   = aNameSeq.getConstArray();
         for ( sal_Int32 n = 0; n < aNameSeq.getLength(); n++ )
-            m_aModuleToModuleUICfgMgrMap.insert( ModuleToModuleCfgMgr::value_type(  pNameSeq[n], Reference< XModuleUIConfigurationManager2 >() ));
+            m_aModuleToModuleUICfgMgrMap.emplace( pNameSeq[n], Reference< XModuleUIConfigurationManager2 >() );
     }
     catch(...)
     {
@@ -144,7 +138,6 @@ void SAL_CALL ModuleUIConfigurationManagerSupplier::disposing()
 
 // XModuleUIConfigurationManagerSupplier
 Reference< XUIConfigurationManager > SAL_CALL ModuleUIConfigurationManagerSupplier::getUIConfigurationManager( const OUString& sModuleIdentifier )
-throw ( NoSuchElementException, RuntimeException, std::exception)
 {
     osl::MutexGuard g(rBHelper.rMutex);
     /* SAFE AREA ----------------------------------------------------------------------------------------------- */
@@ -174,7 +167,7 @@ throw ( NoSuchElementException, RuntimeException, std::exception)
         }
         catch( const Exception& )
         {
-            sShort = OUString();
+            sShort.clear();
         }
 
         if (sShort.isEmpty())
