@@ -24,8 +24,7 @@
 #include <framework/addonsoptions.hxx>
 #include <classes/fwkresid.hxx>
 #include <helper/mischelper.hxx>
-#include <framework/menuextensionsupplier.hxx>
-#include <classes/resource.hrc>
+#include <strings.hrc>
 #include <services.h>
 
 #include <com/sun/star/beans/XPropertySet.hpp>
@@ -33,7 +32,6 @@
 #include <com/sun/star/lang/IndexOutOfBoundsException.hpp>
 #include <com/sun/star/lang/XMultiServiceFactory.hpp>
 #include <com/sun/star/lang/DisposedException.hpp>
-#include <com/sun/star/frame/XFramesSupplier.hpp>
 #include <com/sun/star/frame/Desktop.hpp>
 #include <com/sun/star/container/XEnumeration.hpp>
 #include <com/sun/star/util/XStringWidth.hpp>
@@ -97,14 +95,6 @@ namespace framework
 #define aCmdHelpMenu ".uno:HelpMenu"
 #define aSpecialWindowCommand ".uno:WindowList"
 
-static sal_Int16 getImageTypeFromBools( bool bBig )
-{
-    sal_Int16 n( 0 );
-    if ( bBig )
-        n |= css::ui::ImageType::SIZE_LARGE;
-    return n;
-}
-
 MenuBarManager::MenuBarManager(
     const Reference< XComponentContext >& rxContext,
     const Reference< XFrame >& rFrame,
@@ -189,7 +179,7 @@ void MenuBarManager::Destroy()
     if ( !rBHelper.bDisposed )
     {
         // stop asynchronous settings timer and
-        // release defered item container reference
+        // release deferred item container reference
         m_aAsyncSettingsTimer.Stop();
         m_xDeferedItemContainer.clear();
         RemoveListener();
@@ -249,7 +239,6 @@ void SAL_CALL MenuBarManager::disposing()
     m_xGlobalAcceleratorManager.clear();
     m_xModuleAcceleratorManager.clear();
     m_xDocAcceleratorManager.clear();
-    m_xUICommandLabels.clear();
     m_xPopupMenuControllerFactory.clear();
     m_xContext.clear();
 }
@@ -263,7 +252,7 @@ void SAL_CALL MenuBarManager::elementInserted( const css::ui::ConfigurationEvent
         return;
 
     sal_Int16 nImageType = sal_Int16();
-    sal_Int16 nCurrentImageType = getImageTypeFromBools( false );
+    sal_Int16 nCurrentImageType = css::ui::ImageType::SIZE_LARGE;
     if (( Event.aInfo >>= nImageType ) &&
         ( nImageType == nCurrentImageType ))
         RequestImages();
@@ -587,36 +576,6 @@ void SAL_CALL MenuBarManager::disposing( const EventObject& Source )
         m_xModuleImageManager.clear();
 }
 
-void MenuBarManager::CheckAndAddMenuExtension( Menu* pMenu )
-{
-
-    // retrieve menu extension item
-    MenuExtensionItem aMenuItem( GetMenuExtension() );
-    if (( !aMenuItem.aURL.isEmpty() ) &&
-        ( !aMenuItem.aLabel.isEmpty() ))
-    {
-        // remove all old window list entries from menu
-        sal_uInt16 nNewItemId( 0 );
-        sal_uInt16 nInsertPos( MENU_APPEND );
-        sal_uInt16 nBeforePos( MENU_APPEND );
-        OUString aCommandBefore( ".uno:About" );
-        for ( sal_uInt16 n = 0; n < pMenu->GetItemCount(); n++ )
-        {
-            sal_uInt16 nItemId = pMenu->GetItemId( n );
-            nNewItemId = std::max( nItemId, nNewItemId );
-            if ( pMenu->GetItemCommand( nItemId ) == aCommandBefore )
-                nBeforePos = n;
-        }
-        ++nNewItemId;
-
-        if ( nBeforePos != MENU_APPEND )
-            nInsertPos = nBeforePos;
-
-        pMenu->InsertItem(nNewItemId, aMenuItem.aLabel, MenuItemBits::NONE, OString(), nInsertPos);
-        pMenu->SetItemCommand( nNewItemId, aMenuItem.aURL );
-    }
-}
-
 static void lcl_CheckForChildren(Menu* pMenu, sal_uInt16 nItemId)
 {
     if (PopupMenu* pThisPopup = pMenu->GetPopupMenu( nItemId ))
@@ -765,8 +724,8 @@ IMPL_LINK( MenuBarManager, Activate, Menu *, pMenu, bool )
                         // There is no dispatch mechanism for the special window list menu items,
                         // because they are handled directly through XFrame->activate!!!
                         // Don't update dispatches for special file menu items.
-                        if ( !(( pMenuItemHandler->nItemId >= START_ITEMID_WINDOWLIST &&
-                                 pMenuItemHandler->nItemId < END_ITEMID_WINDOWLIST )))
+                        if ( !( pMenuItemHandler->nItemId >= START_ITEMID_WINDOWLIST &&
+                                pMenuItemHandler->nItemId < END_ITEMID_WINDOWLIST ) )
                         {
                             Reference< XDispatch > xMenuItemDispatch;
 
@@ -1019,7 +978,7 @@ bool MenuBarManager::CreatePopupMenuController( MenuItemHandler* pMenuItemHandle
 {
     OUString aItemCommand( pMenuItemHandler->aMenuItemURL );
 
-    // Try instanciate a popup menu controller. It is stored in the menu item handler.
+    // Try instantiate a popup menu controller. It is stored in the menu item handler.
     if ( !m_xPopupMenuControllerFactory.is() )
         return false;
 
@@ -1173,8 +1132,6 @@ void MenuBarManager::FillMenuManager( Menu* pMenu, const Reference< XFrame >& rF
                 // Check if this is the help menu. Add menu item if needed
                 if ( aItemCommand == aCmdHelpMenu )
                 {
-                    // Check if this is the help menu. Add menu item if needed
-                    CheckAndAddMenuExtension( pPopup );
                 }
                 else if ( aItemCommand == aCmdToolsMenu && AddonMenuManager::HasAddonMenuElements() )
                 {
@@ -1182,8 +1139,7 @@ void MenuBarManager::FillMenuManager( Menu* pMenu, const Reference< XFrame >& rF
                     VclPtr<PopupMenu> pSubMenu = AddonMenuManager::CreateAddonMenu(rFrame);
                     if ( pSubMenu && ( pSubMenu->GetItemCount() > 0 ))
                     {
-                        sal_uInt16 nCount = 0;
-                        if ( pPopup->GetItemType( nCount-1 ) != MenuItemType::SEPARATOR )
+                        if ( pPopup->GetItemType( pPopup->GetItemCount() - 1 ) != MenuItemType::SEPARATOR )
                             pPopup->InsertSeparator();
 
                         pPopup->InsertItem( ITEMID_ADDONLIST, OUString() );
@@ -1726,8 +1682,7 @@ void MenuBarManager::GetPopupController( PopupControllerCache& rPopupController
                 else if ( nQueryPart == -1 )
                     aMainURL += aMenuURL.copy( nSchemePart+1 );
 
-                rPopupController.insert( PopupControllerCache::value_type(
-                                           aMainURL, aPopupControllerEntry ));
+                rPopupController.emplace( aMainURL, aPopupControllerEntry );
             }
         }
         if ( pItemHandler->xSubMenuManager.is() )
@@ -1776,7 +1731,6 @@ void MenuBarManager::Init(const Reference< XFrame >& rFrame, Menu* pAddonMenu, b
     m_bIsBookmarkMenu   = true;
     m_bShowMenuImages   = true;
 
-    OUString aModuleIdentifier;
     m_xPopupMenuControllerFactory = frame::thePopupMenuControllerFactory::get(
         ::comphelper::getProcessComponentContext());
 
@@ -1794,7 +1748,7 @@ void MenuBarManager::Init(const Reference< XFrame >& rFrame, Menu* pAddonMenu, b
         {
             Reference< XDispatchProvider > xDispatchProvider;
             MenuBarManager* pSubMenuManager = new MenuBarManager( m_xContext, rFrame, m_xURLTransformer,
-                                                                  xDispatchProvider, aModuleIdentifier, pPopupMenu,
+                                                                  xDispatchProvider, OUString(), pPopupMenu,
                                                                   false );
 
             Reference< XStatusListener > xSubMenuManager( static_cast< OWeakObject *>( pSubMenuManager ), UNO_QUERY );
@@ -1928,7 +1882,7 @@ void MenuBarManager::UpdateSpecialWindowMenu( Menu* pMenu,const Reference< XComp
     }
 }
 
-void MenuBarManager::FillMenuImages(Reference< XFrame >& _xFrame, Menu* _pMenu,bool bShowMenuImages)
+void MenuBarManager::FillMenuImages(Reference< XFrame > const & _xFrame, Menu* _pMenu,bool bShowMenuImages)
 {
     AddonsOptions aAddonOptions;
 
