@@ -21,10 +21,9 @@
 
 #include <algorithm>
 
-#include "services.h"
-#include <classes/resource.hrc>
+#include <services.h>
+#include <strings.hrc>
 #include <classes/fwkresid.hxx>
-#include <framework/imageproducer.hxx>
 #include <framework/sfxhelperfunctions.hxx>
 #include <uiconfiguration/windowstateproperties.hxx>
 
@@ -33,7 +32,6 @@
 #include <com/sun/star/awt/MenuItemStyle.hpp>
 #include <com/sun/star/frame/ModuleManager.hpp>
 #include <com/sun/star/frame/XDispatchProvider.hpp>
-#include <com/sun/star/frame/theUICommandDescription.hpp>
 #include <com/sun/star/container/XNameContainer.hpp>
 #include <com/sun/star/beans/XPropertySet.hpp>
 #include <com/sun/star/frame/XLayoutManager.hpp>
@@ -48,6 +46,7 @@
 #include <vcl/i18nhelp.hxx>
 #include <vcl/image.hxx>
 #include <vcl/settings.hxx>
+#include <vcl/commandinfoprovider.hxx>
 #include <rtl/ustrbuf.hxx>
 #include <toolkit/helper/vclunohelper.hxx>
 #include <vcl/window.hxx>
@@ -66,15 +65,7 @@ using namespace ::com::sun::star::util;
 using namespace ::com::sun::star::container;
 using namespace ::com::sun::star::ui;
 
-static const char CONFIGURE_TOOLBARS_CMD[]      = "ConfigureDialog";
-static const char CONFIGURE_TOOLBARS[]          = ".uno:ConfigureDialog";
-static const char CMD_COLORBAR[]                = ".uno:ColorControl";
-static const char CMD_FORMULABAR[]              = ".uno:InsertFormula";
-static const char CMD_INPUTLINEBAR[]            = ".uno:InputLineVisible";
 static const char CMD_RESTOREVISIBILITY[]       = ".cmd:RestoreVisibility";
-static const char ITEM_DESCRIPTOR_RESOURCEURL[] = "ResourceURL";
-static const char ITEM_DESCRIPTOR_UINAME[]      = "UIName";
-static const char STATIC_PRIVATE_TB_RESOURCE[]  = "private:resource/toolbar/";
 
 static const char STATIC_CMD_PART[]             = ".uno:AvailableToolbars?Toolbar:string=";
 static const char STATIC_INTERNAL_CMD_PART[]    = ".cmd:";
@@ -82,7 +73,7 @@ static const char STATIC_INTERNAL_CMD_PART[]    = ".cmd:";
 namespace framework
 {
 
-typedef std::unordered_map< OUString, OUString, OUStringHash, std::equal_to< OUString > > ToolbarHashMap;
+typedef std::unordered_map< OUString, OUString > ToolbarHashMap;
 
 struct ToolBarEntry
 {
@@ -97,10 +88,7 @@ bool CompareToolBarEntry( const ToolBarEntry& aOne, const ToolBarEntry& aTwo )
 {
     sal_Int32 nComp = aOne.pCollatorWrapper->compareString( aOne.aUIName, aTwo.aUIName );
 
-    if ( nComp < 0 )
-        return true;
-    else
-        return false;
+    return nComp < 0;
 }
 
 Reference< XLayoutManager > getLayoutManagerFromFrame( const Reference< XFrame >& rFrame )
@@ -133,14 +121,13 @@ DEFINE_XSERVICEINFO_MULTISERVICE_2      (   ToolbarsMenuController
 
 DEFINE_INIT_SERVICE                     (   ToolbarsMenuController, {} )
 
-ToolbarsMenuController::ToolbarsMenuController( const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XComponentContext >& xContext ) :
+ToolbarsMenuController::ToolbarsMenuController( const css::uno::Reference< css::uno::XComponentContext >& xContext ) :
     svt::PopupMenuControllerBase( xContext ),
     m_xContext( xContext ),
     m_aPropUIName( "UIName" ),
     m_aPropResourceURL( "ResourceURL" ),
-    m_bModuleIdentified( false ),
     m_bResetActive( false ),
-    m_aIntlWrapper( xContext, Application::GetSettings().GetLanguageTag() )
+    m_aIntlWrapper(SvtSysLocale().GetUILanguageTag())
 {
 }
 
@@ -149,13 +136,13 @@ ToolbarsMenuController::~ToolbarsMenuController()
 }
 
 void ToolbarsMenuController::addCommand(
-    Reference< css::awt::XPopupMenu >& rPopupMenu, const OUString& rCommandURL, const OUString& rLabel )
+    Reference< css::awt::XPopupMenu > const & rPopupMenu, const OUString& rCommandURL, const OUString& rLabel )
 {
     sal_uInt16        nItemId    = m_xPopupMenu->getItemCount()+1;
 
     OUString aLabel;
     if ( rLabel.isEmpty() )
-        aLabel = getUINameFromCommand( rCommandURL );
+        aLabel = vcl::CommandInfoProvider::GetMenuLabelForCommand( rCommandURL, m_aModuleName );
     else
         aLabel = rLabel;
 
@@ -166,7 +153,7 @@ void ToolbarsMenuController::addCommand(
     if ( !bInternal )
     {
         if ( !getDispatchFromCommandURL( rCommandURL ).is() )
-            m_xPopupMenu->enableItem( nItemId, sal_False );
+            m_xPopupMenu->enableItem( nItemId, false );
     }
 
     SolarMutexGuard aSolarMutexGuard;
@@ -175,7 +162,7 @@ void ToolbarsMenuController::addCommand(
     const StyleSettings& rSettings = Application::GetSettings().GetStyleSettings();
 
     if ( rSettings.GetUseImagesInMenus() )
-        aImage = GetImageFromURL( m_xFrame, rCommandURL, false );
+        aImage = vcl::CommandInfoProvider::GetImageForCommand(rCommandURL, m_xFrame);
 
     VCLXPopupMenu* pPopupMenu = static_cast<VCLXPopupMenu *>(VCLXPopupMenu::GetImplementation( rPopupMenu ));
     if ( pPopupMenu )
@@ -209,53 +196,7 @@ Reference< XDispatch > ToolbarsMenuController::getDispatchFromCommandURL( const
         return Reference< XDispatch >();
 }
 
-// private function
-OUString ToolbarsMenuController::getUINameFromCommand( const OUString& rCommandURL )
-{
-    OUString aLabel;
-
-    if ( !m_bModuleIdentified  )
-    {
-        try
-        {
-            Reference< XModuleManager2 > xModuleManager = ModuleManager::create( m_xContext );
-            m_aModuleIdentifier = xModuleManager->identify( m_xFrame );
-            Reference< XNameAccess > xNameAccess = frame::theUICommandDescription::get( m_xContext );
-            xNameAccess->getByName( m_aModuleIdentifier ) >>= m_xUICommandDescription;
-        }
-        catch ( const Exception& )
-        {
-        }
-    }
-
-    if ( m_xUICommandDescription.is() )
-    {
-        try
-        {
-            Sequence< PropertyValue > aPropSeq;
-            OUString             aStr;
-            if ( m_xUICommandDescription->getByName( rCommandURL ) >>= aPropSeq )
-            {
-                for ( sal_Int32 i = 0; i < aPropSeq.getLength(); i++ )
-                {
-                    if ( aPropSeq[i].Name == "Label" )
-                    {
-                        aPropSeq[i].Value >>= aStr;
-                        break;
-                    }
-                }
-            }
-            aLabel = aStr;
-        }
-        catch ( const Exception& )
-        {
-        }
-    }
-
-    return aLabel;
-}
-
-static void fillHashMap( const Sequence< Sequence< ::com::sun::star::beans::PropertyValue > >& rSeqToolBars,
+static void fillHashMap( const Sequence< Sequence< css::beans::PropertyValue > >& rSeqToolBars,
                          ToolbarHashMap& rHashMap )
 {
     for ( sal_Int32 i = 0; i < rSeqToolBars.getLength(); i++ )
@@ -265,20 +206,20 @@ static void fillHashMap( const Sequence< Sequence< ::com::sun::star::beans::Prop
         const PropertyValue* pProperties = rSeqToolBars[i].getConstArray();
         for ( sal_Int32 j = 0; j < rSeqToolBars[i].getLength(); j++ )
         {
-            if ( pProperties[j].Name == ITEM_DESCRIPTOR_RESOURCEURL )
+            if ( pProperties[j].Name == "ResourceURL" )
                 pProperties[j].Value >>= aResourceURL;
-            else if ( pProperties[j].Name == ITEM_DESCRIPTOR_UINAME )
+            else if ( pProperties[j].Name == "UIName" )
                 pProperties[j].Value >>= aUIName;
         }
 
         if ( !aResourceURL.isEmpty() &&
              rHashMap.find( aResourceURL ) == rHashMap.end() )
-            rHashMap.insert( ToolbarHashMap::value_type( aResourceURL, aUIName ));
+            rHashMap.emplace( aResourceURL, aUIName );
     }
 }
 
 // private function
-Sequence< Sequence< com::sun::star::beans::PropertyValue > > ToolbarsMenuController::getLayoutManagerToolbars( const Reference< ::com::sun::star::frame::XLayoutManager >& rLayoutManager )
+Sequence< Sequence< css::beans::PropertyValue > > ToolbarsMenuController::getLayoutManagerToolbars( const Reference< css::frame::XLayoutManager >& rLayoutManager )
 {
     std::vector< ToolBarInfo > aToolBarArray;
     Sequence< Reference< XUIElement > > aUIElements = rLayoutManager->getElements();
@@ -295,7 +236,7 @@ Sequence< Sequence< com::sun::star::beans::PropertyValue > > ToolbarsMenuControl
                 xPropSet->getPropertyValue("Type") >>= nType;
                 xPropSet->getPropertyValue("ResourceURL") >>= aResName;
 
-                if (( nType == ::com::sun::star::ui::UIElementType::TOOLBAR ) &&
+                if (( nType == css::ui::UIElementType::TOOLBAR ) &&
                     !aResName.isEmpty() )
                 {
                     ToolBarInfo aToolBarInfo;
@@ -304,7 +245,7 @@ Sequence< Sequence< com::sun::star::beans::PropertyValue > > ToolbarsMenuControl
 
                     SolarMutexGuard aGuard;
                     Reference< css::awt::XWindow > xWindow( xUIElement->getRealInterface(), UNO_QUERY );
-                    vcl::Window* pWindow = VCLUnoHelper::GetWindow( xWindow );
+                    VclPtr<vcl::Window> pWindow = VCLUnoHelper::GetWindow( xWindow );
                     if ( pWindow )
                         aToolBarInfo.aToolBarUIName = pWindow->GetText();
 
@@ -317,11 +258,11 @@ Sequence< Sequence< com::sun::star::beans::PropertyValue > > ToolbarsMenuControl
         }
     }
 
-    Sequence< com::sun::star::beans::PropertyValue > aTbSeq( 2 );
+    Sequence< css::beans::PropertyValue > aTbSeq( 2 );
     aTbSeq[0].Name = m_aPropUIName;
     aTbSeq[1].Name = m_aPropResourceURL;
 
-    Sequence< Sequence< com::sun::star::beans::PropertyValue > > aSeq( aToolBarArray.size() );
+    Sequence< Sequence< css::beans::PropertyValue > > aSeq( aToolBarArray.size() );
     const sal_uInt32 nCount = aToolBarArray.size();
     for ( sal_uInt32 i = 0; i < nCount; i++ )
     {
@@ -334,7 +275,7 @@ Sequence< Sequence< com::sun::star::beans::PropertyValue > > ToolbarsMenuControl
 }
 
 
-void ToolbarsMenuController::fillPopupMenu( Reference< css::awt::XPopupMenu >& rPopupMenu )
+void ToolbarsMenuController::fillPopupMenu( Reference< css::awt::XPopupMenu > const & rPopupMenu )
 {
     if( SvtMiscOptions().DisableUICustomization() )
         return;
@@ -345,7 +286,6 @@ void ToolbarsMenuController::fillPopupMenu( Reference< css::awt::XPopupMenu >& r
     m_aCommandVector.clear();
 
     // Retrieve layout manager for additional information
-    OUString aEmptyString;
     Reference< XLayoutManager > xLayoutManager( getLayoutManagerFromFrame( m_xFrame ));
 
     m_bResetActive = false;
@@ -355,14 +295,14 @@ void ToolbarsMenuController::fillPopupMenu( Reference< css::awt::XPopupMenu >& r
 
         if ( m_xDocCfgMgr.is() )
         {
-            Sequence< Sequence< com::sun::star::beans::PropertyValue > > aSeqDocToolBars =
+            Sequence< Sequence< css::beans::PropertyValue > > aSeqDocToolBars =
                 m_xDocCfgMgr->getUIElementsInfo( UIElementType::TOOLBAR );
             fillHashMap( aSeqDocToolBars, aToolbarHashMap );
         }
 
         if ( m_xModuleCfgMgr.is() )
         {
-            Sequence< Sequence< com::sun::star::beans::PropertyValue > > aSeqToolBars =
+            Sequence< Sequence< css::beans::PropertyValue > > aSeqToolBars =
                 m_xModuleCfgMgr->getUIElementsInfo( UIElementType::TOOLBAR );
             fillHashMap( aSeqToolBars, aToolbarHashMap );
         }
@@ -370,7 +310,7 @@ void ToolbarsMenuController::fillPopupMenu( Reference< css::awt::XPopupMenu >& r
         std::vector< ToolBarEntry > aSortedTbs;
         OUString               aStaticCmdPart( STATIC_CMD_PART );
 
-        Sequence< Sequence< com::sun::star::beans::PropertyValue > > aSeqFrameToolBars = getLayoutManagerToolbars( xLayoutManager );
+        Sequence< Sequence< css::beans::PropertyValue > > aSeqFrameToolBars = getLayoutManagerToolbars( xLayoutManager );
         fillHashMap( aSeqFrameToolBars, aToolbarHashMap );
 
         ToolbarHashMap::const_iterator pIter = aToolbarHashMap.begin();
@@ -437,15 +377,15 @@ void ToolbarsMenuController::fillPopupMenu( Reference< css::awt::XPopupMenu >& r
             sal_uInt16 nItemCount = m_xPopupMenu->getItemCount();
             m_xPopupMenu->insertItem( nIndex, aSortedTbs[i].aUIName, css::awt::MenuItemStyle::CHECKABLE, nItemCount );
             if ( aSortedTbs[i].bVisible )
-                m_xPopupMenu->checkItem( nIndex, sal_True );
+                m_xPopupMenu->checkItem( nIndex, true );
 
             {
                 SolarMutexGuard aGuard;
                 VCLXPopupMenu* pXPopupMenu = static_cast<VCLXPopupMenu *>(VCLXMenu::GetImplementation( m_xPopupMenu ));
-                PopupMenu* pVCLPopupMenu = pXPopupMenu ? static_cast<PopupMenu *>(pXPopupMenu->GetMenu()) : NULL;
+                PopupMenu* pVCLPopupMenu = pXPopupMenu ? static_cast<PopupMenu *>(pXPopupMenu->GetMenu()) : nullptr;
                 assert(pVCLPopupMenu);
                 if (pVCLPopupMenu)
-                    pVCLPopupMenu->SetUserValue( nIndex, sal_uIntPtr( aSortedTbs[i].bContextSensitive ? 1L : 0L ));
+                    pVCLPopupMenu->SetUserValue( nIndex, sal_uLong( aSortedTbs[i].bContextSensitive ? 1 : 0 ));
             }
 
             // use VCL popup menu pointer to set vital information that are not part of the awt implementation
@@ -473,21 +413,20 @@ void ToolbarsMenuController::fillPopupMenu( Reference< css::awt::XPopupMenu >& r
         {
             if ( m_aModuleIdentifier == "com.sun.star.drawing.DrawingDocument" ||
                  m_aModuleIdentifier == "com.sun.star.presentation.PresentationDocument" )
-                addCommand( m_xPopupMenu, OUString( CMD_COLORBAR ), aEmptyString );
+                addCommand( m_xPopupMenu, ".uno:ColorControl", "" );
             else if ( m_aModuleIdentifier == "com.sun.star.sheet.SpreadsheetDocument" )
-                addCommand( m_xPopupMenu, OUString( CMD_INPUTLINEBAR ), aEmptyString );
+                addCommand( m_xPopupMenu, ".uno:InputLineVisible", "" );
             else
-                addCommand( m_xPopupMenu, OUString( CMD_FORMULABAR ), aEmptyString );
+                addCommand( m_xPopupMenu, ".uno:InsertFormula", "" );
         }
 
         bool          bAddCommand( true );
         SvtCommandOptions aCmdOptions;
-        OUString     aConfigureToolbar( CONFIGURE_TOOLBARS );
 
         if ( aCmdOptions.HasEntries( SvtCommandOptions::CMDOPTION_DISABLED ))
         {
             if ( aCmdOptions.Lookup( SvtCommandOptions::CMDOPTION_DISABLED,
-                                     OUString( CONFIGURE_TOOLBARS_CMD )))
+                                     "ConfigureDialog"))
                 bAddCommand = false;
         }
 
@@ -500,7 +439,7 @@ void ToolbarsMenuController::fillPopupMenu( Reference< css::awt::XPopupMenu >& r
                 m_xPopupMenu->insertSeparator( nItemCount+1 );
             }
 
-            addCommand( m_xPopupMenu, aConfigureToolbar, aEmptyString );
+            addCommand( m_xPopupMenu, ".uno:ConfigureDialog", "" );
         }
 
         // Add separator if no configure has been added
@@ -514,16 +453,16 @@ void ToolbarsMenuController::fillPopupMenu( Reference< css::awt::XPopupMenu >& r
             }
         }
 
-        OUString aLabelStr(FWK_RESSTR(STR_RESTORE_TOOLBARS));
+        OUString aLabelStr(FwkResId(STR_RESTORE_TOOLBARS));
         OUString aRestoreCmd( CMD_RESTOREVISIBILITY );
         addCommand( m_xPopupMenu, aRestoreCmd, aLabelStr );
     }
 }
 
 // XEventListener
-void SAL_CALL ToolbarsMenuController::disposing( const EventObject& ) throw ( RuntimeException, std::exception )
+void SAL_CALL ToolbarsMenuController::disposing( const EventObject& )
 {
-    Reference< css::awt::XMenuListener > xHolder(( OWeakObject *)this, UNO_QUERY );
+    Reference< css::awt::XMenuListener > xHolder(static_cast<OWeakObject *>(this), UNO_QUERY );
 
     osl::MutexGuard aLock( m_aMutex );
     m_xFrame.clear();
@@ -533,12 +472,12 @@ void SAL_CALL ToolbarsMenuController::disposing( const EventObject& ) throw ( Ru
     m_xContext.clear();
 
     if ( m_xPopupMenu.is() )
-        m_xPopupMenu->removeMenuListener( Reference< css::awt::XMenuListener >(( OWeakObject *)this, UNO_QUERY ));
+        m_xPopupMenu->removeMenuListener( Reference< css::awt::XMenuListener >(static_cast<OWeakObject *>(this), UNO_QUERY ));
     m_xPopupMenu.clear();
 }
 
 // XStatusListener
-void SAL_CALL ToolbarsMenuController::statusChanged( const FeatureStateEvent& Event ) throw ( RuntimeException, std::exception )
+void SAL_CALL ToolbarsMenuController::statusChanged( const FeatureStateEvent& Event )
 {
     OUString aFeatureURL( Event.FeatureURL.Complete );
 
@@ -551,9 +490,9 @@ void SAL_CALL ToolbarsMenuController::statusChanged( const FeatureStateEvent& Ev
     {
         SolarMutexGuard aGuard;
         VCLXPopupMenu* pXPopupMenu = static_cast<VCLXPopupMenu *>(VCLXMenu::GetImplementation( xPopupMenu ));
-        PopupMenu*     pVCLPopupMenu = pXPopupMenu ? static_cast<PopupMenu *>(pXPopupMenu->GetMenu()) : NULL;
+        PopupMenu*     pVCLPopupMenu = pXPopupMenu ? static_cast<PopupMenu *>(pXPopupMenu->GetMenu()) : nullptr;
 
-        SAL_WARN_IF(!pVCLPopupMenu, "framework", "worrying lack of popup menu");
+        SAL_WARN_IF(!pVCLPopupMenu, "fwk.uielement", "worrying lack of popup menu");
         if (!pVCLPopupMenu)
             return;
 
@@ -590,7 +529,7 @@ void SAL_CALL ToolbarsMenuController::statusChanged( const FeatureStateEvent& Ev
 }
 
 // XMenuListener
-void SAL_CALL ToolbarsMenuController::itemSelected( const css::awt::MenuEvent& rEvent ) throw (RuntimeException, std::exception)
+void SAL_CALL ToolbarsMenuController::itemSelected( const css::awt::MenuEvent& rEvent )
 {
     Reference< css::awt::XPopupMenu >   xPopupMenu;
     Reference< XComponentContext >      xContext;
@@ -653,7 +592,7 @@ void SAL_CALL ToolbarsMenuController::itemSelected( const css::awt::MenuEvent& r
                                     if ( !bVisible && bContextSensitive && nVisibleIndex >= 0 )
                                     {
                                         // Default is: Every context sensitive toolbar is visible
-                                        aWindowState[nVisibleIndex].Value <<= sal_True;
+                                        aWindowState[nVisibleIndex].Value <<= true;
                                         xNameReplace->replaceByName( aElementName, makeAny( aWindowState ));
                                         bRefreshToolbars = true;
                                     }
@@ -674,7 +613,7 @@ void SAL_CALL ToolbarsMenuController::itemSelected( const css::awt::MenuEvent& r
                                 {
                                     try
                                     {
-                                        xPropSet->setPropertyValue("RefreshContextToolbarVisibility", makeAny( sal_True ));
+                                        xPropSet->setPropertyValue("RefreshContextToolbarVisibility", makeAny( true ));
                                     }
                                     catch ( const RuntimeException& )
                                     {
@@ -713,7 +652,7 @@ void SAL_CALL ToolbarsMenuController::itemSelected( const css::awt::MenuEvent& r
                     pExecuteInfo->xDispatch     = xDispatch;
                     pExecuteInfo->aTargetURL    = aTargetURL;
                     pExecuteInfo->aArgs         = aArgs;
-                    Application::PostUserEvent( LINK(0, ToolbarsMenuController, ExecuteHdl_Impl), pExecuteInfo );
+                    Application::PostUserEvent( LINK(nullptr, ToolbarsMenuController, ExecuteHdl_Impl), pExecuteInfo );
                 }
             }
             else
@@ -725,7 +664,7 @@ void SAL_CALL ToolbarsMenuController::itemSelected( const css::awt::MenuEvent& r
                     sal_Int32 nIndex = aCmd.indexOf( '=' );
                     if (( nIndex > 0 ) && (( nIndex+1 ) < aCmd.getLength() ))
                     {
-                        OUStringBuffer aBuf( STATIC_PRIVATE_TB_RESOURCE );
+                        OUStringBuffer aBuf( "private:resource/toolbar/" );
                         aBuf.append( aCmd.copy( nIndex+1 ));
 
                         bool      bShow( !pVCLPopupMenu->IsItemChecked( rEvent.MenuId ));
@@ -749,7 +688,7 @@ void SAL_CALL ToolbarsMenuController::itemSelected( const css::awt::MenuEvent& r
     }
 }
 
-void SAL_CALL ToolbarsMenuController::itemActivated( const css::awt::MenuEvent& ) throw (RuntimeException, std::exception)
+void SAL_CALL ToolbarsMenuController::itemActivated( const css::awt::MenuEvent& )
 {
     std::vector< OUString >   aCmdVector;
     Reference< XDispatchProvider > xDispatchProvider( m_xFrame, UNO_QUERY );
@@ -774,8 +713,8 @@ void SAL_CALL ToolbarsMenuController::itemActivated( const css::awt::MenuEvent&
             Reference< XDispatch > xDispatch = xDispatchProvider->queryDispatch( aTargetURL, OUString(), 0 );
             if ( xDispatch.is() )
             {
-                xDispatch->addStatusListener( (static_cast< XStatusListener* >(this)), aTargetURL );
-                xDispatch->removeStatusListener( (static_cast< XStatusListener* >(this)), aTargetURL );
+                xDispatch->addStatusListener( static_cast< XStatusListener* >(this), aTargetURL );
+                xDispatch->removeStatusListener( static_cast< XStatusListener* >(this), aTargetURL );
             }
         }
         else if ( aCmdVector[i] == CMD_RESTOREVISIBILITY )
@@ -783,14 +722,14 @@ void SAL_CALL ToolbarsMenuController::itemActivated( const css::awt::MenuEvent&
             // Special code to determine the enable/disable state of this command
             FeatureStateEvent aFeatureStateEvent;
             aFeatureStateEvent.FeatureURL.Complete = aCmdVector[i];
-            aFeatureStateEvent.IsEnabled = isContextSensitiveToolbarNonVisible();
+            aFeatureStateEvent.IsEnabled = m_bResetActive; // is context sensitive toolbar non visible
             statusChanged( aFeatureStateEvent );
         }
     }
 }
 
 // XPopupMenuController
-void SAL_CALL ToolbarsMenuController::setPopupMenu( const Reference< css::awt::XPopupMenu >& xPopupMenu ) throw ( RuntimeException, std::exception )
+void SAL_CALL ToolbarsMenuController::setPopupMenu( const Reference< css::awt::XPopupMenu >& xPopupMenu )
 {
     osl::MutexGuard aLock( m_aMutex );
 
@@ -802,13 +741,13 @@ void SAL_CALL ToolbarsMenuController::setPopupMenu( const Reference< css::awt::X
         SolarMutexGuard aSolarMutexGuard;
 
         m_xPopupMenu = xPopupMenu;
-        m_xPopupMenu->addMenuListener( Reference< css::awt::XMenuListener >( (OWeakObject*)this, UNO_QUERY ));
+        m_xPopupMenu->addMenuListener( Reference< css::awt::XMenuListener >( static_cast<OWeakObject*>(this), UNO_QUERY ));
         fillPopupMenu( m_xPopupMenu );
     }
 }
 
 // XInitialization
-void SAL_CALL ToolbarsMenuController::initialize( const Sequence< Any >& aArguments ) throw ( Exception, RuntimeException, std::exception )
+void SAL_CALL ToolbarsMenuController::initialize( const Sequence< Any >& aArguments )
 {
     osl::MutexGuard aLock( m_aMutex );
     bool bInitalized( m_bInitialized );
@@ -819,7 +758,7 @@ void SAL_CALL ToolbarsMenuController::initialize( const Sequence< Any >& aArgume
         if ( m_bInitialized )
         {
             Reference< XModuleManager2 > xModuleManager = ModuleManager::create( m_xContext );
-            Reference< XNameAccess > xPersistentWindowStateSupplier = ::com::sun::star::ui::theWindowStateConfiguration::get( m_xContext );
+            Reference< XNameAccess > xPersistentWindowStateSupplier = css::ui::theWindowStateConfiguration::get( m_xContext );
 
             // Retrieve persistent window state reference for our module
             OUString aModuleIdentifier;
@@ -851,8 +790,9 @@ void SAL_CALL ToolbarsMenuController::initialize( const Sequence< Any >& aArgume
     }
 }
 
-IMPL_STATIC_LINK( ToolbarsMenuController, ExecuteHdl_Impl, ExecuteInfo*, pExecuteInfo )
+IMPL_STATIC_LINK( ToolbarsMenuController, ExecuteHdl_Impl, void*, p, void )
 {
+    ExecuteInfo* pExecuteInfo = static_cast<ExecuteInfo*>(p);
     try
     {
         // Asynchronous execution as this can lead to our own destruction!
@@ -868,7 +808,6 @@ IMPL_STATIC_LINK( ToolbarsMenuController, ExecuteHdl_Impl, ExecuteInfo*, pExecut
     }
 
     delete pExecuteInfo;
-    return 0;
 }
 
 }
