@@ -85,7 +85,7 @@ HWPDOFuncType HWPDOFuncTbl[] =
     HWPDOFreeFormFunc,
 };
 
-static HMemIODev *hmem = NULL;
+static HMemIODev *hmem = nullptr;
 
 static int count = 0;
 
@@ -107,14 +107,14 @@ static bool SkipPrivateBlock(int type)
     {
         if (!hmem->read4b(n))
             return false;
-        if (hmem->state() || hmem->skipBlock(n) != n)
+        if (hmem->state() || hmem->skipBlock(n) != static_cast<size_t>(n))
             return false;
     }
     if (!hmem->read4b(n))
         return false;
     if (hmem->state())
         return false;
-    return hmem->skipBlock(n) == n;
+    return hmem->skipBlock(n) == static_cast<size_t>(n);
 }
 
 static int SizeExpected;
@@ -299,7 +299,7 @@ static bool LoadCommonHeader(HWPDrawingObject * hdo, unsigned short * link_info)
         hdo->property.contrast = 0;
         hdo->property.greyscale = 0;
     }
-    hdo->property.pPara = NULL;
+    hdo->property.pPara = nullptr;
 
     if( ( size > common_size ) && (hdo->property.flag & HWPDO_FLAG_AS_TEXTBOX) )
     {
@@ -318,13 +318,11 @@ static bool LoadCommonHeader(HWPDrawingObject * hdo, unsigned short * link_info)
 
 static HWPDrawingObject *LoadDrawingObject(void)
 {
-    fprintf(stderr, "LoadDrawingObject\n");
-
     HWPDrawingObject *hdo, *head, *prev;
 
     unsigned short link_info;
 
-    head = prev = NULL;
+    head = prev = nullptr;
     do
     {
         hdo = new HWPDrawingObject;
@@ -342,7 +340,7 @@ static HWPDrawingObject *LoadDrawingObject(void)
         }
         else
         {
-            switch (int res = HWPDOFunc(hdo, OBJFUNC_LOAD, NULL, 0))
+            switch (int res = HWPDOFunc(hdo, OBJFUNC_LOAD, nullptr, 0))
             {
                 case OBJRET_FILE_ERROR:
                     goto error;
@@ -358,12 +356,12 @@ static HWPDrawingObject *LoadDrawingObject(void)
         if (link_info & HDOFILE_HAS_CHILD)
         {
             hdo->child = LoadDrawingObject();
-            if (hdo->child == NULL)
+            if (hdo->child == nullptr)
             {
                 goto error;
             }
         }
-        if (prev == NULL)
+        if (prev == nullptr)
             head = hdo;
         else
             prev->next = hdo;
@@ -376,23 +374,23 @@ static HWPDrawingObject *LoadDrawingObject(void)
 // drawing object can be list.
 // hdo = current item, head = list;
 
-    if (hdo != NULL)
+    if (hdo != nullptr)
     {
         if (hdo->type < 0 || hdo->type >= HWPDO_NITEMS)
         {
             hdo->type = HWPDO_RECT;
         }
 
-        HWPDOFunc(hdo, OBJFUNC_FREE, NULL, 0);
+        HWPDOFunc(hdo, OBJFUNC_FREE, nullptr, 0);
         delete hdo;
     }
     if( prev )
     {
-        prev->next = NULL;
+        prev->next = nullptr;
         return head;
     }
     else
-        return NULL;
+        return nullptr;
 }
 
 
@@ -423,14 +421,14 @@ static bool LoadDrawingObjectBlock(Picture * pic)
         return false;
 
     pic->picinfo.picdraw.hdo = LoadDrawingObject();
-    if (pic->picinfo.picdraw.hdo == NULL)
+    if (pic->picinfo.picdraw.hdo == nullptr)
         return false;
     return true;
 }
 
 // object manipulation function
 static int
-HWPDODefaultFunc(int , HWPDrawingObject * , int cmd, void *, int)
+HWPDODefaultFunc(int cmd)
 {
     if (cmd == OBJFUNC_LOAD)
         return OBJRET_FILE_NO_PRIVATE_BLOCK;
@@ -438,7 +436,7 @@ HWPDODefaultFunc(int , HWPDrawingObject * , int cmd, void *, int)
 }
 
 static int
-HWPDOLineFunc(int type, HWPDrawingObject * hdo, int cmd, void *argp, int argv)
+HWPDOLineFunc(int /*type*/, HWPDrawingObject * hdo, int cmd, void * /*argp*/, int /*argv*/)
 {
     int ret = OBJRET_FILE_OK;
     switch (cmd)
@@ -455,7 +453,7 @@ HWPDOLineFunc(int type, HWPDrawingObject * hdo, int cmd, void *argp, int argv)
             ret = OBJRET_FILE_NO_PRIVATE_BLOCK_2;
             break;
         default:
-            ret = HWPDODefaultFunc(type, hdo, cmd, argp, argv);
+            ret = HWPDODefaultFunc(cmd);
             break;
     }
     return ret;
@@ -465,25 +463,25 @@ HWPDOLineFunc(int type, HWPDrawingObject * hdo, int cmd, void *argp, int argv)
 // rectangle
 
 static int
-HWPDORectFunc(int type, HWPDrawingObject * hdo, int cmd, void *argp, int argv)
+HWPDORectFunc(int /*type*/, HWPDrawingObject * /*hdo*/, int cmd, void * /*argp*/, int /*argv*/)
 {
-    return HWPDODefaultFunc(type, hdo, cmd, argp, argv);
+    return HWPDODefaultFunc(cmd);
 }
 
 
 // ellipse
 
 static int
-HWPDOEllipseFunc(int type, HWPDrawingObject * hdo,
-int cmd, void *argp, int argv)
+HWPDOEllipseFunc(int /*type*/, HWPDrawingObject * /*hdo*/,
+int cmd, void * /*argp*/, int /*argv*/)
 {
-    return HWPDODefaultFunc(type, hdo, cmd, argp, argv);
+    return HWPDODefaultFunc(cmd);
 }
 
 #define WTMM(x)     ((double)(x) / 1800. * 25.4)
 static int
-HWPDOEllipse2Func(int type, HWPDrawingObject * hdo,
-int cmd, void *argp, int argv)
+HWPDOEllipse2Func(int /*type*/, HWPDrawingObject * hdo,
+int cmd, void * /*argp*/, int /*argv*/)
 {
     switch (cmd)
     {
@@ -502,7 +500,7 @@ int cmd, void *argp, int argv)
                 return OBJRET_FILE_ERROR;
             break;
         default:
-            return HWPDODefaultFunc(type, hdo, cmd, argp, argv);
+            return HWPDODefaultFunc(cmd);
     }
     return OBJRET_FILE_OK;
 }
@@ -511,7 +509,7 @@ int cmd, void *argp, int argv)
 // arc
 
 static int
-HWPDOArcFunc(int type, HWPDrawingObject * hdo, int cmd, void *argp, int argv)
+HWPDOArcFunc(int /*type*/, HWPDrawingObject * hdo, int cmd, void * /*argp*/, int /*argv*/)
 {
     switch (cmd)
     {
@@ -526,14 +524,14 @@ HWPDOArcFunc(int type, HWPDrawingObject * hdo, int cmd, void *argp, int argv)
                 return OBJRET_FILE_ERROR;
             break;
         default:
-            return HWPDODefaultFunc(type, hdo, cmd, argp, argv);
+            return HWPDODefaultFunc(cmd);
     }
     return OBJRET_FILE_OK;
 }
 
 
 static int
-HWPDOArc2Func(int type, HWPDrawingObject * hdo, int cmd, void *argp, int argv)
+HWPDOArc2Func(int /*type*/, HWPDrawingObject * /*hdo*/, int cmd, void * /*argp*/, int /*argv*/)
 {
     int ret = OBJRET_FILE_OK;
     switch (cmd)
@@ -542,7 +540,7 @@ HWPDOArc2Func(int type, HWPDrawingObject * hdo, int cmd, void *argp, int argv)
             ret = OBJRET_FILE_NO_PRIVATE_BLOCK;
             break;
         default:
-            ret = HWPDODefaultFunc(type, hdo, cmd, argp, argv);
+            ret = HWPDODefaultFunc(cmd);
             break;
     }
     return ret;
@@ -550,14 +548,14 @@ HWPDOArc2Func(int type, HWPDrawingObject * hdo, int cmd, void *argp, int argv)
 
 
 static int
-HWPDOFreeFormFunc(int type, HWPDrawingObject * hdo,
-int cmd, void *argp, int argv)
+HWPDOFreeFormFunc(int /*type*/, HWPDrawingObject * hdo,
+int cmd, void * /*argp*/, int /*argv*/)
 {
     switch (cmd)
     {
         case OBJFUNC_LOAD:
         {
-            hdo->u.freeform.pt = NULL;
+            hdo->u.freeform.pt = nullptr;
             if (ReadSizeField(4) < 4)
                 return OBJRET_FILE_ERROR;
             if (!hmem->read4b(hdo->u.freeform.npt))
@@ -575,7 +573,7 @@ int cmd, void *argp, int argv)
             {
                 hdo->u.freeform.pt =
                     ::comphelper::newArray_null<ZZPoint>(hdo->u.freeform.npt);
-                if (hdo->u.freeform.pt == NULL)
+                if (hdo->u.freeform.pt == nullptr)
                 {
                     hdo->u.freeform.npt = 0;
                     return OBJRET_FILE_ERROR;
@@ -606,7 +604,7 @@ int cmd, void *argp, int argv)
                 delete[]hdo->u.freeform.pt;
             break;
         default:
-            return HWPDODefaultFunc(type, hdo, cmd, argp, argv);
+            return HWPDODefaultFunc(cmd);
     }
     return OBJRET_FILE_OK;
 }
@@ -625,23 +623,23 @@ static void FreeParaList(HWPPara * para)
 static HWPPara *LoadParaList()
 {
     if (!hmem)
-        return NULL;
+        return nullptr;
 
     HWPFile *hwpf = GetCurrentDoc();
     HIODev *hio = hwpf->SetIODevice(hmem);
 
-    std::list < HWPPara* > plist;
+    std::vector< HWPPara* > plist;
 
     hwpf->ReadParaList(plist);
     hwpf->SetIODevice(hio);
 
-    return plist.size()? plist.front() : NULL;
+    return plist.size()? plist.front() : nullptr;
 }
 
 
 static int
-HWPDOTextBoxFunc(int type, HWPDrawingObject * hdo,
-int cmd, void *argp, int argv)
+HWPDOTextBoxFunc(int /*type*/, HWPDrawingObject * hdo,
+int cmd, void * /*argp*/, int /*argv*/)
 {
     switch (cmd)
     {
@@ -656,11 +654,11 @@ int cmd, void *argp, int argv)
             if (hdo->u.textbox.h)
             {
                 FreeParaList(hdo->u.textbox.h);
-                hdo->u.textbox.h = NULL;
+                hdo->u.textbox.h = nullptr;
             }
             break;
         default:
-            return HWPDODefaultFunc(type, hdo, cmd, argp, argv);
+            return HWPDODefaultFunc(cmd);
     }
     return OBJRET_FILE_OK;
 }
@@ -668,10 +666,10 @@ int cmd, void *argp, int argv)
 
 
 static int
-HWPDOContainerFunc(int type, HWPDrawingObject * hdo,
-int cmd, void *argp, int argv)
+HWPDOContainerFunc(int /*type*/, HWPDrawingObject * /*hdo*/,
+int cmd, void * /*argp*/, int /*argv*/)
 {
-    return HWPDODefaultFunc(type, hdo, cmd, argp, argv);
+    return HWPDODefaultFunc(cmd);
 }
 
 
@@ -690,7 +688,10 @@ HWPDrawingObject::~HWPDrawingObject()
     if (next)
         delete next;
 
-    HWPDOFunc(this, OBJFUNC_FREE, NULL, 0);
+    if (property.pPara)
+        FreeParaList(property.pPara);
+
+    HWPDOFunc(this, OBJFUNC_FREE, nullptr, 0);
 }
 #endif
 
