@@ -25,9 +25,6 @@
 #include "mapping.h"
 #include "hwpeq.h"
 #include <iostream>
-#include <list>
-
-extern std::list<Node*> nodelist;
 
 #ifndef DEBUG
 
@@ -38,7 +35,7 @@ extern std::list<Node*> nodelist;
 #define rchars(x) do { if (m_rxDocumentHandler.is()) m_rxDocumentHandler->characters(x); } while(false)
 #define runistr(x) do { if (m_rxDocumentHandler.is()) m_rxDocumentHandler->characters(x); } while(false)
 #define reucstr(x,y) do { if (m_rxDocumentHandler.is()) m_rxDocumentHandler->characters(OUString(x,y, RTL_TEXTENCODING_EUC_KR)); } while(false)
-#define padd(x,y,z)  pList->addAttribute(x,y,z)
+#define padd(x,y,z)  mxList->addAttribute(x,y,z)
 #else
 static int indent = 0;
 #define inds indent++; for(int i = 0 ; i < indent ; i++) fprintf(stderr," ")
@@ -55,9 +52,9 @@ void Formula::makeMathML(Node *res)
      fprintf(stderr,"<math:math xmlns:math=\"http://www.w3.org/1998/Math/MathML\">\n");
 #else
      padd("xmlns:math", "CDATA", "http://www.w3.org/1998/Math/MathML");
-     rstartEl("math:math", rList);
-     pList->clear();
-     rstartEl("math:semantics", rList);
+     rstartEl("math:math", mxList.get());
+     mxList->clear();
+     rstartEl("math:semantics", mxList.get());
 #endif
      if( tmp->child )
           makeLines( tmp->child );
@@ -95,7 +92,7 @@ void Formula::makeLine(Node *res)
 #ifdef DEBUG
      inds; fprintf(stderr,"<math:mrow>\n");
 #else
-     rstartEl("math:mrow", rList);
+     rstartEl("math:mrow", mxList.get());
 #endif
      if( res->child )
          makeExprList( res->child );
@@ -134,7 +131,7 @@ void Formula::makeExpr(Node *res)
                  inds;
                  fprintf(stderr,"<math:mrow>\n");
 #else
-                 rstartEl("math:mrow", rList);
+                 rstartEl("math:mrow", mxList.get());
 #endif
              }
 
@@ -178,9 +175,8 @@ void Formula::makeExpr(Node *res)
              break;
          case ID_BLOCK:
              makeBlock(tmp);
-             //fall-through
+             break;
          case ID_BEGIN:
-             //fall-through
          case ID_END:
              break;
     }
@@ -198,7 +194,7 @@ void Formula::makeIdentifier(Node *res)
           fprintf(stderr,"<math:mi>%s</math:mi>\n",tmp->value);
           indo;
 #else
-          rstartEl("math:mi", rList);
+          rstartEl("math:mi", mxList.get());
           rchars(OUString::createFromAscii(tmp->value));
           rendEl("math:mi");
 #endif
@@ -207,7 +203,7 @@ void Formula::makeIdentifier(Node *res)
           {
 #ifdef DEBUG
 #else
-                rstartEl("math:mi", rList);
+                rstartEl("math:mi", mxList.get());
                 reucstr(tmp->value, strlen(tmp->value));
                 rendEl("math:mi");
 #endif
@@ -220,7 +216,7 @@ void Formula::makeIdentifier(Node *res)
                   getMathMLEntity(tmp->value).c_str());
           indo;
 #else
-          rstartEl("math:mi", rList);
+          rstartEl("math:mi", mxList.get());
           runistr(reinterpret_cast<sal_Unicode const *>(getMathMLEntity(tmp->value).c_str()));
           rendEl("math:mi");
 #endif
@@ -231,7 +227,7 @@ void Formula::makeIdentifier(Node *res)
           fprintf(stderr,"<math:mn>%s</math:mn>\n",tmp->value);
           indo;
 #else
-          rstartEl("math:mn", rList);
+          rstartEl("math:mn", mxList.get());
           rchars(OUString::createFromAscii(tmp->value));
           rendEl("math:mn");
 #endif
@@ -242,7 +238,7 @@ void Formula::makeIdentifier(Node *res)
 #ifdef DEBUG
           inds; fprintf(stderr,"<math:mo>%s</math:mo>\n",tmp->value); indo;
 #else
-          rstartEl("math:mo", rList);
+          rstartEl("math:mo", mxList.get());
           runistr(reinterpret_cast<sal_Unicode const *>(getMathMLEntity(tmp->value).c_str()));
           rendEl("math:mo");
 #endif
@@ -282,11 +278,11 @@ void Formula::makeSubSup(Node *res)
           fprintf(stderr,"<math:msubsup>\n");
 #else
      if( res->id == ID_SUBEXPR )
-          rstartEl("math:msub", rList);
+          rstartEl("math:msub", mxList.get());
      else if( res->id == ID_SUPEXPR )
-          rstartEl("math:msup", rList);
+          rstartEl("math:msup", mxList.get());
      else
-          rstartEl("math:msubsup", rList);
+          rstartEl("math:msubsup", mxList.get());
 #endif
 
      tmp = tmp->child;
@@ -327,7 +323,7 @@ void Formula::makeFraction(Node *res)
      inds;
      fprintf(stderr,"<math:mfrac>\n");
 #else
-     rstartEl("math:mfrac", rList);
+     rstartEl("math:mfrac", mxList.get());
 #endif
 
      tmp = tmp->child;
@@ -335,7 +331,7 @@ void Formula::makeFraction(Node *res)
      inds;
      fprintf(stderr,"<math:mrow>\n");
 #else
-     rstartEl("math:mrow", rList);
+     rstartEl("math:mrow", mxList.get());
 #endif
 
      if( res->id == ID_FRACTIONEXPR )
@@ -350,7 +346,7 @@ void Formula::makeFraction(Node *res)
      fprintf(stderr,"<math:mrow>\n");
 #else
      rendEl("math:mrow");
-     rstartEl("math:mrow", rList);
+     rstartEl("math:mrow", mxList.get());
 #endif
 
      if( res->id == ID_FRACTIONEXPR )
@@ -386,13 +382,13 @@ void Formula::makeDecoration(Node *res)
      /* FIXME: no idea when 'accent' is true or false. */
      if( isover ){
           padd("accent","CDATA","true");
-          rstartEl("math:mover", rList);
+          rstartEl("math:mover", mxList.get());
      }
      else{
           padd("accentunder","CDATA","true");
-          rstartEl("math:munder", rList);
+          rstartEl("math:munder", mxList.get());
      }
-     pList->clear();
+     mxList->clear();
 #endif
 
      makeBlock(tmp->next);
@@ -403,7 +399,7 @@ void Formula::makeDecoration(Node *res)
              getMathMLEntity(tmp->value).c_str());
      indo;
 #else
-     rstartEl("math:mo", rList);
+     rstartEl("math:mo", mxList.get());
      runistr(reinterpret_cast<sal_Unicode const *>(getMathMLEntity(tmp->value).c_str()));
      rendEl("math:mo");
 #endif
@@ -434,9 +430,9 @@ void Formula::makeRoot(Node *res)
           fprintf(stderr,"<math:mroot>\n");
 #else
      if( tmp->id == ID_SQRTEXPR )
-          rstartEl("math:msqrt", rList);
+          rstartEl("math:msqrt", mxList.get());
      else
-          rstartEl("math:mroot", rList);
+          rstartEl("math:mroot", mxList.get());
 #endif
 
      if( tmp->id == ID_SQRTEXPR ){
@@ -480,14 +476,14 @@ void Formula::makeParenth(Node *res)
      indo; inds;
      fprintf(stderr,"<math:mrow>\n");
 #else
-     rstartEl("math:mrow", rList);
-     rstartEl("math:mo", rList);
+     rstartEl("math:mrow", mxList.get());
+     rstartEl("math:mo", mxList.get());
      if( tmp->id == ID_PARENTH )
           rchars("(");
      else
           rchars("|");
      rendEl("math:mo");
-     rstartEl("math:mrow", rList);
+     rstartEl("math:mrow", mxList.get());
 #endif
 
      if( tmp->child )
@@ -506,7 +502,7 @@ void Formula::makeParenth(Node *res)
      fprintf(stderr,"</math:mrow>\n");
 #else
      rendEl("math:mrow");
-     rstartEl("math:mo", rList);
+     rstartEl("math:mo", mxList.get());
      if( tmp->id == ID_PARENTH )
           rchars(")");
      else
@@ -529,8 +525,8 @@ void Formula::makeFence(Node *res)
              OUString(reinterpret_cast<sal_Unicode const *>(getMathMLEntity(tmp->value).c_str())));
      padd("close", "CDATA",
              OUString(reinterpret_cast<sal_Unicode const *>(getMathMLEntity(tmp->next->next->value).c_str())));
-     rstartEl("math:mfenced", rList);
-     pList->clear();
+     rstartEl("math:mfenced", mxList.get());
+     mxList->clear();
 #endif
 
      makeExprList(tmp->next);
@@ -554,7 +550,7 @@ void Formula::makeBlock(Node *res)
      inds;
      fprintf(stderr,"<math:mrow>\n");
 #else
-     rstartEl("math:mrow", rList);
+     rstartEl("math:mrow", mxList.get());
 #endif
 
      if( res->child )
@@ -568,67 +564,58 @@ void Formula::makeBlock(Node *res)
 #endif
 }
 
-int Formula::parse()
+void Formula::parse()
 {
      Node *res = nullptr;
-     if( !eq ) return 0;
-     if( isHwpEQ ){
-          MzString a;
-         // fprintf(stderr,"\n\n[BEFORE]\n[%s]\n",eq);
-          eq2latex(a,eq);
+     if( !eq ) return;
 
-          int idx=a.find(sal::static_int_cast<char>(0xff));
-          while(idx){
-                //printf("idx = [%d]\n",idx);
-                a.replace(idx,0x20);
-                if((idx = a.find(sal::static_int_cast<char>(0xff),idx+1)) < 0)
-                     break;
-          }
+     MzString a;
+     // fprintf(stderr,"\n\n[BEFORE]\n[%s]\n",eq);
+     eq2latex(a,eq);
 
-          char *buf = static_cast<char *>(malloc(a.length()+1));
-          bool bStart = false;
-          int i, j;
-          for( i = 0, j=0 ; i < a.length() ; i++){ // rtrim and ltrim 32 10 13
-                if( bStart ){
+     int idx=a.find(sal::static_int_cast<char>(0xff));
+     while(idx){
+           //printf("idx = [%d]\n",idx);
+           a.replace(idx,0x20);
+           if((idx = a.find(sal::static_int_cast<char>(0xff),idx+1)) < 0)
+                break;
+     }
+
+     char *buf = static_cast<char *>(malloc(a.length()+1));
+     bool bStart = false;
+     int i, j;
+     for( i = 0, j=0 ; i < a.length() ; i++){ // rtrim and ltrim 32 10 13
+           if( bStart ){
+                buf[j++] = a[i];
+           }
+           else{
+                if( a[i] != 32 && a[i] != 10 && a[i] != 13){
+                     bStart = true;
                      buf[j++] = a[i];
                 }
-                else{
-                     if( a[i] != 32 && a[i] != 10 && a[i] != 13){
-                          bStart = true;
-                          buf[j++] = a[i];
-                     }
-                }
-          }
-          buf[j] = 0;
-          for( i = j-1 ; i >= 0 ; i++ ){
-                if( buf[i] == 32 || buf[i] == 10 || buf[i] == 13 ){
-                     buf[i] = 0;
-                }
-                else
-                     break;
-          }
-         // fprintf(stderr,"\n\n[RESULT]\n[%s]\n",a.c_str());
-          if( buf[0] != '\0' )
-                res = mainParse( a.c_str() );
-          else
-                res = nullptr;
-          free(buf);
+           }
      }
-     else{
-          res = mainParse( eq );
+     buf[j] = 0;
+     for( i = j-1 ; i >= 0 ; i++ ){
+           if( buf[i] == 32 || buf[i] == 10 || buf[i] == 13 ){
+                buf[i] = 0;
+           }
+           else
+                break;
      }
+     // fprintf(stderr,"\n\n[RESULT]\n[%s]\n",a.c_str());
+     if( buf[0] != '\0' )
+           res = mainParse( a.c_str() );
+     else
+           res = nullptr;
+     free(buf);
 
      if( res ){
           makeMathML( res );
      }
-     int count = nodelist.size();
-     for( int i = 0 ; i < count ; i++ ){
-         const Node *tmpNode = nodelist.front();
-         nodelist.pop_front();
-         delete tmpNode;
-     }
-
-     return 0;
+     for (const auto &node : nodelist)
+         delete node;
+     nodelist.clear();
 }
 
 void Formula::trim()
