@@ -22,7 +22,9 @@
 
 #include <sal/config.h>
 
+#include <array>
 #include <list>
+#include <memory>
 
 #include <sal/types.h>
 
@@ -47,16 +49,12 @@ struct HBox
  * Construct a HBox object with parameter hch.
  * @param hch 16bit character being able to have Korean character.
  */
-        HBox( hchar hch );
+        explicit HBox( hchar hch );
         virtual ~HBox();
 /**
  * @returns The Size of HBox object
  */
-        virtual int   WSize();
-/**
- * @returns The Height of HBox object as hunit value.
- */
-        virtual hunit Height(CharShape *csty);
+        int           WSize();
 /**
  * Read properties from HIODevice object like stream, file, memory.
  *
@@ -71,35 +69,31 @@ struct HBox
 };
 
 /**
- * @short Class for saving data to be skipped.
+ * @short Class for skipping data.
  */
 struct SkipData: public HBox
 {
-    ulong data_block_len;
-    hchar dummy;
-    char  *data_block;
-
-    SkipData(hchar);
-    virtual ~SkipData();
-    virtual bool Read(HWPFile &hwpf) SAL_OVERRIDE;
+    explicit SkipData(hchar);
+    virtual ~SkipData() override;
+    virtual bool Read(HWPFile &hwpf) override;
 };
+
 struct DateCode;
 struct FieldCode : public HBox
 {
-    uchar type[2];                    /* 2/0 - 계산식, 3/0-문서요약, 3/1-개인정보, 3/2-만든날짜, 4/0-누름틀 */
-    char *reserved1;
-    unsigned short location_info;     /* 0 - 끝코드, 1 - 시작코드 */
-    char *reserved2;
-    hchar *str1;
-    hchar *str2;
-    hchar *str3;
-    char *bin;
+    uchar type[2];                    /* 2/0 - Formula, 3/0-document summary, 3/1 Personal Information, 3/2-creation date, 4/0-pressing mold */
+    std::array<char, 4> reserved1;
+    unsigned short location_info;     /* 0 - End code, 1 - start code */
+    std::array<char, 22> reserved2;
+    std::unique_ptr<hchar[]> str1;
+    std::unique_ptr<hchar[]> str2;
+    std::unique_ptr<hchar[]> str3;
 
-     DateCode *m_pDate;
+    std::unique_ptr<DateCode> m_pDate;
 
     FieldCode();
-    virtual ~FieldCode();
-    virtual bool Read(HWPFile &hwpf) SAL_OVERRIDE;
+    virtual ~FieldCode() override;
+    virtual bool Read(HWPFile &hwpf) override;
 };
 /**
  * Kind of BOOKMARK
@@ -123,8 +117,8 @@ struct Bookmark: public HBox
     unsigned short    type;
 
     Bookmark();
-    virtual ~Bookmark();
-    virtual bool Read(HWPFile &hwpf) SAL_OVERRIDE;
+    virtual ~Bookmark() override;
+    virtual bool Read(HWPFile &hwpf) override;
 };
 
 // date format(7)
@@ -139,7 +133,7 @@ struct DateFormat: public HBox
     hchar dummy;
 
     DateFormat();
-    virtual bool Read(HWPFile &hwpf) SAL_OVERRIDE;
+    virtual bool Read(HWPFile &hwpf) override;
 };
 
 /**
@@ -161,9 +155,9 @@ struct DateCode: public HBox
     unsigned char key;
 
     DateCode();
-    virtual bool Read(HWPFile &hwpf) SAL_OVERRIDE;
+    virtual bool Read(HWPFile &hwpf) override;
 
-    virtual hchar_string GetString() SAL_OVERRIDE;
+    virtual hchar_string GetString() override;
 };
 
 /**
@@ -176,7 +170,7 @@ struct Tab: public HBox
     hchar dummy;
 
     Tab();
-    virtual bool Read(HWPFile &hwpf) SAL_OVERRIDE;
+    virtual bool Read(HWPFile &hwpf) override;
 };
 
 // tbox(10) TABLE BOX MATH BUTTON HYPERTEXT
@@ -199,21 +193,10 @@ enum
     EQU_CAP_POS
 };
 
-/**
- * Definitions for frame's common 'option' member.
- */
-#define DRAW_FRAME      1                         /* <-> no frame, bit 0 */
-#define NORMAL_PIC      2                         /* <-> reverse,  bit 1 */
-#define FIT_TO_COLUMN   4                         /* fig_xs is columnlen */
-#define UNKNOWN_FILE    8                         /* need check reverse for pcx mono */
-#define HYPERTEXT_FLAG  16
-#define UNKNOWN_SIZE    32
-#define FOPT_TEMP_BIT   0x00010000                /* temporary starts from 16th bits */
-
 struct CellLine
 {
     unsigned char key;
-    unsigned char top;                            // 0 - 라인없음, 1-single, 2-thick, 3-double
+    unsigned char top;                            // 0-No line, 1-single, 2-thick, 3-double
     unsigned char bottom;
     unsigned char left;
     unsigned char right;
@@ -246,7 +229,7 @@ struct Cell                                       // Cell
     unsigned char diagonal;                       // { 0=none,\=1,/=2,X=3}
     unsigned char protect;
 
-    void  Read( HWPFile &hwpf );
+    bool  Read(HWPFile &hwpf);
 };
 
 /**
@@ -261,7 +244,7 @@ struct FBoxStyle
 /**
  * Kind of wrap
  */
-    unsigned char txtflow;                        /* 그림피함. 0-2(자리차지,투명,어울림) */
+    unsigned char txtflow;                        /* Avoid painting. 0-2 (seat occupied, transparency, harmony) */
 /**
  * Horizontal alignment
  */
@@ -279,12 +262,12 @@ struct FBoxStyle
 /**
  * Index of floating object
  */
-    short     boxnum;                             /* 스타오피스에서 스타일 이름으로 사용될 숫자 */
+    short     boxnum;                             /* Numbers used as style-name in Libre Office */
 /**
  * Type of floating object : line, txtbox, image, table, equalizer and button
  */
     unsigned char boxtype;                        // (L)ine, t(X)tbox, Picture - (G)
-    short     cap_len; /* 캡션의 길이 */
+    short     cap_len; /* The length of the caption */
 
     void *cell;
 
@@ -296,7 +279,7 @@ struct FBoxStyle
         , boxnum(0)
         , boxtype(0)
         , cap_len(0)
-        , cell(NULL)
+        , cell(nullptr)
     {
         memset(margin, 0, sizeof(margin));
     }
@@ -322,8 +305,8 @@ struct FBox: public HBox
     char      xpos_type, ypos_type;
     unsigned char smart_linesp;
 
-/*  이 자료는 tbox나 pic에서는 파일에 기록하지 않고 실행시만 있으며,
-    line에서는 파일에 기록한다.
+/* In tbox or pic, this data exists in memory when running, isn't written to a file.
+   But in line, it will be written to a file.
  */
     short     boundsy, boundey;
     unsigned char boundx, draw;
@@ -334,10 +317,8 @@ struct FBox: public HBox
     short     pgx, pgy;                           // physical xpos, ypos
     short     pgno, showpg;                       // pageno where code is
 
-    FBox      *prev, *next;
-
-    FBox( hchar hch );
-    virtual ~FBox();
+    explicit FBox( hchar hch );
+    virtual ~FBox() override;
 };
 
 struct Table;
@@ -351,7 +332,7 @@ struct TxtBox: public FBox
 
     short     dummy1;                             // to not change structure size */
     short     cap_len;
-    short     next;
+    short     next_box;
     short     dummy2;                             // to not change structure size */
     unsigned char reserved1;
 /**
@@ -377,33 +358,22 @@ struct TxtBox: public FBox
  */
     short     protect;                            //1=size lock
 
-    Cell      *cell;
-     Table *m_pTable;
+    std::unique_ptr<Cell[]> cell;
+    Table *m_pTable;
 /**
  * Paragraph list
  */
-    std::list<HWPPara*> *plists;
+    std::vector<std::vector<std::unique_ptr<HWPPara>>> plists;
+
 /**
  * Caption
  */
-    std::list<HWPPara*> caption;
+    std::vector<std::unique_ptr<HWPPara>> caption;
 
     TxtBox();
-    virtual ~TxtBox();
+    virtual ~TxtBox() override;
 
-/**
- * @returns Count of cell.
- */
-    virtual int NCell()   { return nCell; }
-/**
- * This is one of table, text-box, equalizer and button
- * @returns Type of this object.
- */
-    virtual int Type()    { return type;  }
-
-    virtual bool Read(HWPFile &hwpf) SAL_OVERRIDE;
-
-    virtual hunit  Height(CharShape *csty) SAL_OVERRIDE;
+    virtual bool Read(HWPFile &hwpf) override;
 };
 
 #define ALLOWED_GAP 5
@@ -412,27 +382,25 @@ struct TxtBox: public FBox
 
 struct Columns
 {
-     int *data;
+     std::unique_ptr<int[]> data;
      size_t nCount;
      size_t nTotal;
      Columns(){
           nCount = 0;
           nTotal = INIT_SIZE;
-          data = new int[nTotal];
+          data.reset(new int[nTotal]);
      }
-     ~Columns(){ delete[] data; }
 
      void AddColumnsSize(){
-          int *tmp = data;
           if (nTotal + ADD_AMOUNT < nTotal) // overflow
           {
               throw ::std::bad_alloc();
           }
-          data = new int[nTotal + ADD_AMOUNT];
+          int* tmp = new int[nTotal + ADD_AMOUNT];
           for (size_t i = 0 ; i < nTotal ; i++)
-                data[i] = tmp[i];
+                tmp[i] = data[i];
           nTotal += ADD_AMOUNT;
-          delete[] tmp;
+          data.reset(tmp);
      }
 
      void insert(int pos){
@@ -473,27 +441,25 @@ struct Columns
 
 struct Rows
 {
-     int *data;
+     std::unique_ptr<int[]> data;
      size_t nCount;
      size_t nTotal;
      Rows(){
           nCount = 0;
           nTotal = INIT_SIZE;
-          data = new int[nTotal];
+          data.reset( new int[nTotal] );
      }
-     ~Rows(){ delete[] data; }
 
      void AddRowsSize(){
-          int *tmp = data;
           if (nTotal + ADD_AMOUNT < nTotal) // overflow
           {
               throw ::std::bad_alloc();
           }
-          data = new int[nTotal + ADD_AMOUNT];
+          int* tmp = new int[nTotal + ADD_AMOUNT];
           for (size_t i = 0 ; i < nTotal ; i++)
-                data[i] = tmp[i];
+                tmp[i] = data[i];
           nTotal += ADD_AMOUNT;
-          delete[] tmp;
+          data.reset(tmp);
      }
 
      void insert(int pos){
@@ -543,20 +509,15 @@ struct TCell
 
 struct Table
 {
-     Table() : box(NULL) {};
-     ~Table() {
-          std::list<TCell*>::iterator it = cells.begin();
-          for( ; it != cells.end(); ++it)
-                delete *it;
-     };
+     Table() : box(nullptr) {};
 
      Columns columns;
      Rows    rows;
-     std::list<TCell*> cells;
+     std::vector<std::unique_ptr<TCell>> cells;
      TxtBox *box;
 };
 
-/* picture (11) 그림, OLE그림, 삽입그림, 그리기 */
+/* picture (11) graphics, OLE graphics, inserted graphics, drawing */
 enum pictype
 {
     PICTYPE_FILE, PICTYPE_OLE, PICTYPE_EMBED,
@@ -617,7 +578,6 @@ typedef union
     PicDefUnknown     picun;
 } PicDef;
 
-#define PIC_INFO_LEN    348
 /**
  * There are four kinds of image.
  * @li External image
@@ -635,7 +595,7 @@ struct Picture: public FBox
  * follow_block_size is the size information of the Drawing object of hwp.
  * It's value is greater than 0 if the pictype is PICTYPE_DRAW.
  */
-    ulong     follow_block_size;                  /* 추가정보 길이. */
+    uint      follow_block_size;                  /* Additional information length. */
     short     dummy1;                             // to not change structure size */
     short     dummy2;                             // to not change structure size */
     uchar     reserved1;
@@ -661,21 +621,18 @@ struct Picture: public FBox
     PicDef    picinfo;
     char      reserved3[9];
 
-    std::list<HWPPara*> caption;
+    std::vector<std::unique_ptr<HWPPara>> caption;
 /**
  * It's for the Drawing object
  */
-    unsigned char *follow;                        /* 그림종류가 drawing일때, 추가정보. */
+    std::vector<unsigned char> follow;                        /* When the type of image is drawing, gives additional information. */
 
     bool ishyper;
 
     Picture();
-    virtual ~Picture();
+    virtual ~Picture() override;
 
-    virtual int   Type    ();
-    virtual bool Read    (HWPFile &hwpf) SAL_OVERRIDE;
-
-    virtual hunit  Height (CharShape *sty) SAL_OVERRIDE;
+    virtual bool Read    (HWPFile &hwpf) override;
 };
 
 // line (14)
@@ -694,7 +651,7 @@ struct Line: public FBox
 
     Line();
 
-    virtual bool Read(HWPFile &hwpf) SAL_OVERRIDE;
+    virtual bool Read(HWPFile &hwpf) override;
 };
 
 // hidden(15)
@@ -707,12 +664,12 @@ struct Hidden: public HBox
     hchar     dummy;
 
     unsigned char info[8];                        // h, next, dummy
-    std::list<HWPPara*> plist;
+    std::vector<std::unique_ptr<HWPPara>> plist;
 
     Hidden();
-    virtual ~Hidden();
+    virtual ~Hidden() override;
 
-    virtual bool Read(HWPFile &hwpf) SAL_OVERRIDE;
+    virtual bool Read(HWPFile &hwpf) override;
 };
 
 /**
@@ -736,12 +693,12 @@ struct HeaderFooter: public HBox
 /**
  * Paragraph list of header or footer
  */
-    std::list<HWPPara*> plist;
+    std::vector<std::unique_ptr<HWPPara>> plist;
 
     HeaderFooter();
-    virtual ~HeaderFooter();
+    virtual ~HeaderFooter() override;
 
-    virtual bool Read(HWPFile &hwpf) SAL_OVERRIDE;
+    virtual bool Read(HWPFile &hwpf) override;
 };
 
 /**
@@ -769,12 +726,12 @@ struct Footnote: public HBox
 /**
  * Paragraph list of Footnote objects
  */
-    std::list<HWPPara*> plist;
+    std::vector<std::unique_ptr<HWPPara>> plist;
 
     Footnote();
-    virtual ~Footnote();
+    virtual ~Footnote() override;
 
-    virtual bool Read(HWPFile &hwpf) SAL_OVERRIDE;
+    virtual bool Read(HWPFile &hwpf) override;
 };
 
 // auto number(18)
@@ -802,7 +759,7 @@ struct AutoNum: public HBox
 
     AutoNum();
 
-    virtual bool Read(HWPFile &hwpf) SAL_OVERRIDE;
+    virtual bool Read(HWPFile &hwpf) override;
 };
 
 /**
@@ -816,10 +773,10 @@ struct NewNum: public HBox
 
     NewNum();
 
-    virtual bool Read(HWPFile &hwpf) SAL_OVERRIDE;
+    virtual bool Read(HWPFile &hwpf) override;
 };
 
-// page numger(20)
+// page number(20)
 /**
  * @short Input page index in footer or header
  */
@@ -838,14 +795,10 @@ struct ShowPageNum: public HBox
 
     ShowPageNum();
 
-    virtual bool Read(HWPFile &hwpf) SAL_OVERRIDE;
+    virtual bool Read(HWPFile &hwpf) override;
 };
 
-/* 홀수쪽시작 (21) */
-#define HIDE_HD         1                         /* bit 0 */
-#define HIDE_FT         2                         /* bit 1 */
-#define HIDE_PGNUM      4                         /* bit 2 */
-#define HIDE_FRAME      8                         /* bit 3 */
+/* Start odd side (21) */
 /**
  * Controls the display of page number, header, footer and border.
  */
@@ -863,7 +816,7 @@ struct PageNumCtrl: public HBox
 
     PageNumCtrl();
 
-    virtual bool Read(HWPFile &hwpf) SAL_OVERRIDE;
+    virtual bool Read(HWPFile &hwpf) override;
 };
 
 // mail merge(22)
@@ -878,11 +831,11 @@ struct MailMerge: public HBox
 
     MailMerge();
 
-    virtual bool Read(HWPFile &hwpf) SAL_OVERRIDE;
-    virtual hchar_string GetString() SAL_OVERRIDE;
+    virtual bool Read(HWPFile &hwpf) override;
+    virtual hchar_string GetString() override;
 };
 
-// char compositon(23)
+// char composition(23)
 /**
  * The compose struct displays characters at position. The maximum character count for composition is three.
  * @short Composition several characters
@@ -894,7 +847,7 @@ struct Compose: public HBox
 
     Compose();
 
-    virtual bool Read(HWPFile &hwpf) SAL_OVERRIDE;
+    virtual bool Read(HWPFile &hwpf) override;
 };
 
 // hyphen(24)
@@ -911,7 +864,7 @@ struct Hyphen: public HBox
 
     Hyphen();
 
-    virtual bool Read(HWPFile &hwpf) SAL_OVERRIDE;
+    virtual bool Read(HWPFile &hwpf) override;
 };
 
 // toc mark(25)
@@ -927,7 +880,7 @@ struct TocMark: public HBox
 
     TocMark();
 
-    virtual bool Read(HWPFile &hwpf) SAL_OVERRIDE;
+    virtual bool Read(HWPFile &hwpf) override;
 };
 
 // index mark(26)
@@ -945,7 +898,7 @@ struct IndexMark: public HBox
 
     IndexMark();
 
-    virtual bool Read(HWPFile &hwpf) SAL_OVERRIDE;
+    virtual bool Read(HWPFile &hwpf) override;
 };
 
 // outline(28)
@@ -1011,16 +964,16 @@ class Outline: public HBox
 /**
  * decoration character for the level type
  */
-        hchar     deco[MAX_OUTLINE_LEVEL][2];     /* 사용자 정의시 앞뒤 문자 */
+        hchar     deco[MAX_OUTLINE_LEVEL][2];     /* Prefix/postfix for Customize */
         hchar     dummy;
 
         Outline();
 
-        virtual bool Read(HWPFile &hwpf) SAL_OVERRIDE;
+        virtual bool Read(HWPFile &hwpf) override;
         hchar_string GetUnicode() const;
 };
 
-/* 묶음 빈칸(30) */
+/* Bundle of spaces (30) */
 /**
  * The Special space to be treated non-space when a string is
  * cut at the end of line
@@ -1032,10 +985,10 @@ struct KeepSpace: public HBox
 
     KeepSpace();
 
-    virtual bool Read(HWPFile &hwpf) SAL_OVERRIDE;
+    virtual bool Read(HWPFile &hwpf) override;
 };
 
-/* 고정폭 빈칸(31) */
+/* Fixed-width spaces (31) */
 /**
  * @short Space with always same width not relation with fonts.
  */
@@ -1045,7 +998,7 @@ struct FixedSpace: public HBox
 
     FixedSpace();
 
-    virtual bool Read(HWPFile &hwpf) SAL_OVERRIDE;
+    virtual bool Read(HWPFile &hwpf) override;
 };
 #endif // INCLUDED_HWPFILTER_SOURCE_HBOX_H
 
