@@ -29,7 +29,7 @@
 #include "hbox.h"
 #include "hutil.h"
 
-void LineInfo::Read(HWPFile & hwpf, HWPPara *pPara)
+void LineInfo::Read(HWPFile & hwpf, HWPPara const *pPara)
 {
     if (!hwpf.Read2b(pos))
         return;
@@ -87,7 +87,9 @@ HWPPara::~HWPPara()
 
 bool HWPPara::Read(HWPFile & hwpf, unsigned char flag)
 {
-    unsigned char same_cshape;
+    DepthGuard aGuard(hwpf);
+    if (aGuard.toodeep())
+        return false;
     int ii;
     scflag = flag;
 // Paragraph Information
@@ -122,8 +124,8 @@ bool HWPPara::Read(HWPFile & hwpf, unsigned char flag)
     }
 
     if (nch && !reuse_shape){
-         if( pshape->coldef.ncols > 1 ) {
-             hwpf.SetColumnDef(&(pshape->coldef));
+         if( pshape->xColdef->ncols > 1 ) {
+             hwpf.SetColumnDef(pshape->xColdef);
          }
     }
 
@@ -145,6 +147,7 @@ bool HWPPara::Read(HWPFile & hwpf, unsigned char flag)
             cshapep[ii].reset(new CharShape);
             memset(cshapep[ii].get(), 0, sizeof(CharShape));
 
+            unsigned char same_cshape(0);
             hwpf.Read1b(&same_cshape, 1);
             if (!same_cshape)
             {
@@ -229,7 +232,8 @@ std::unique_ptr<HBox> HWPPara::readHBox(HWPFile & hwpf)
                 hbox.reset(new Hidden);
                 break;
             case CH_HEADER_FOOTER:                // 16
-                hbox.reset(new HeaderFooter);
+                if (!hwpf.already_importing_type(CH_HEADER_FOOTER))
+                    hbox.reset(new HeaderFooter);
                 break;
             case CH_FOOTNOTE:                     // 17
                 hbox.reset(new Footnote);
@@ -274,11 +278,19 @@ std::unique_ptr<HBox> HWPPara::readHBox(HWPFile & hwpf)
                 break;
         }
     }
-    if (!hbox || !hbox->Read(hwpf))
+
+    if (!hbox)
+        return nullptr;
+
+    hwpf.push_hpara_type(scflag);
+    bool bRead = hbox->Read(hwpf);
+    hwpf.pop_hpara_type();
+    if (!bRead)
     {
         hbox.reset();
-        return hbox;
+        return nullptr;
     }
+
     if( hh == CH_TEXT_BOX || hh == CH_PICTURE || hh == CH_LINE )
     {
         FBox *fbox = static_cast<FBox *>(hbox.get());
