@@ -19,7 +19,7 @@
 
 #include <config_locales.h>
 
-#include "lrl_include.hxx"
+#include <lrl_include.hxx>
 
 #include <rtl/ustrbuf.hxx>
 #include <i18nlangtag/languagetag.hxx>
@@ -30,10 +30,11 @@
 #include <cppuhelper/supportsservice.hxx>
 
 using namespace ::com::sun::star;
+using namespace ::com::sun::star::i18n;
 using namespace ::com::sun::star::lang;
 using namespace ::com::sun::star::uno;
 
-namespace com { namespace sun { namespace star { namespace i18n {
+namespace i18npool {
 
 Collator_Unicode::Collator_Unicode()
 {
@@ -406,6 +407,6 @@ Collator_Unicode::getSupportedServiceNames()
     return aRet;
 }
 
-} } } }
+}
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
