@@ -16,12 +16,12 @@
  *   except in compliance with the License. You may obtain a copy of
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
-#ifndef INCLUDED_I18NUTIL_CASEFOLDING_DATA_H
-#define INCLUDED_I18NUTIL_CASEFOLDING_DATA_H
+#ifndef INCLUDED_I18NUTIL_SOURCE_UTILITY_WIDTHFOLDING_DATA_H
+#define INCLUDED_I18NUTIL_SOURCE_UTILITY_WIDTHFOLDING_DATA_H
 
 #include <i18nutil/oneToOneMapping.hxx>
 
-namespace com { namespace sun { namespace star { namespace i18n {
+namespace i18nutil {
 
 /*
   Unicode Normalization Forms
@@ -718,6 +718,7 @@ UnicodePairWithFlag half2full[] = {
     { 0x002A, 0xFF0A, HALF2FULL_NORMAL | HALF2FULL_JIS_FUNCTION },  // ASTERISK --> FULLWIDTH ASTERISK
     { 0x002B, 0xFF0B, HALF2FULL_NORMAL | HALF2FULL_JIS_FUNCTION },  // PLUS SIGN --> FULLWIDTH PLUS SIGN
     { 0x002C, 0xFF0C, HALF2FULL_NORMAL | HALF2FULL_JIS_FUNCTION },  // COMMA --> FULLWIDTH COMMA
+    { 0x002D, 0xFF0D, HALF2FULL_NORMAL | HALF2FULL_JIS_FUNCTION },  // MINUS HYPHEN --> FULLWIDTH MINUS HYPHEN
     { 0x002E, 0xFF0E, HALF2FULL_NORMAL | HALF2FULL_JIS_FUNCTION },  // FULL STOP --> FULLWIDTH FULL STOP
     { 0x002F, 0xFF0F, HALF2FULL_NORMAL | HALF2FULL_JIS_FUNCTION },  // SOLIDUS --> FULLWIDTH SOLIDUS
     { 0x0030, 0xFF10, HALF2FULL_NORMAL | HALF2FULL_JIS_FUNCTION },  // DIGIT ZERO --> FULLWIDTH DIGIT ZERO
@@ -946,7 +947,7 @@ UnicodePairWithFlag half2fullJISException[] = {
  };
 
 
-} } } }
+}
 
 #endif
 
