@@ -18,7 +18,7 @@
  */
 
 
-#include "idlc/idlc.hxx"
+#include <idlc.hxx>
 #include <sal/main.h>
 
 #include <string.h>
@@ -72,21 +72,20 @@ SAL_IMPLEMENT_MAIN_WITH_ARGS(argc, argv)
             }
             idlc()->reset();
         }
-        StringVector const & files = options.getInputFiles();
+        std::vector< OString > const & files = options.getInputFiles();
         if ( options.verbose() )
         {
             fprintf( stdout, "%s: compiling %i source files ... \n",
                 options.getProgramName().getStr(), (int)files.size() );
             fflush( stdout );
         }
-        for (StringVector::const_iterator i(files.begin());
+        for (std::vector< OString >::const_iterator i(files.begin());
              i != files.end() && nErrors == 0; ++i)
         {
             OString sysFileName( convertToAbsoluteSystemPath(*i) );
 
             if ( !options.quiet() )
-                fprintf(stdout, "Compiling: %s\n",
-                    (*i).getStr());
+                fprintf(stdout, "Compiling: %s\n", (*i).getStr());
             nErrors = compileFile(&sysFileName);
 
             if ( idlc()->getWarningCount() && !options.quiet() )
@@ -102,7 +101,7 @@ SAL_IMPLEMENT_MAIN_WITH_ARGS(argc, argv)
             OString outputFile;
             if ( options.isValid("-O") )
             {
-                outputFile = (options.getOption("-O"));
+                outputFile = options.getOption("-O");
                 if (!outputFile.endsWith("/")) {
                     outputFile += OString('/');
                 }
