@@ -20,10 +20,10 @@
 #ifndef INCLUDED_RTL_LOCALE_H
 #define INCLUDED_RTL_LOCALE_H
 
-#include <sal/config.h>
+#include "sal/config.h"
 
-#include <rtl/ustring.h>
-#include <sal/saldllapi.h>
+#include "rtl/ustring.h"
+#include "sal/saldllapi.h"
 
 #ifdef __cplusplus
 extern "C" {
@@ -74,31 +74,30 @@ SAL_DLLPUBLIC rtl_Locale * SAL_CALL rtl_locale_register(
 
 /**
     Common method of getting the current default Locale.
-    Used for the presentation: menus, dialogs, etc.
-    Generally set once when your applet or application is initialized,
-    then never reset. (If you do reset the default locale, you
-    probably want to reload your GUI, so that the change is reflected
-    in your interface.)
-    <p>More advanced programs will allow users to use different locales
-    for different fields, e.g. in a spreadsheet.
-    <BR>Note that the initial setting will match the host system.
+
+    @deprecated  LibreOffice itself does not use this anymore, and client code
+    should not have good use for it either.  It may eventually be removed.
  */
 SAL_DLLPUBLIC rtl_Locale * SAL_CALL rtl_locale_getDefault(void);
 
 /**
     Sets the default.
-    Normally set once at the beginning of applet or application,
-    then never reset. <code>setDefault</code> does not reset the host locale.
+
+    <code>setDefault</code> does not reset the host locale.
+
     @param language lowercase two-letter ISO 639-1 or three-letter ISO 639-3 code.
     @param country uppercase two-letter ISO-3166 code.
     @param variant vendor and browser specific code. See class description.
+
+    @deprecated  LibreOffice itself does not use this anymore, and client code
+    should not have good use for it either.  It may eventually be removed.
  */
 SAL_DLLPUBLIC void SAL_CALL rtl_locale_setDefault(
         const sal_Unicode * language, const sal_Unicode * country, const sal_Unicode * variant );
 
 /**
     Getter for programmatic name of field,
-    a lowercased two-letter ISO 639-1 or three-letter ISO 639-3 code.
+    a lowercase two-letter ISO 639-1 or three-letter ISO 639-3 code.
     @see getDisplayLanguage
  */
 SAL_DLLPUBLIC rtl_uString * SAL_CALL rtl_locale_getLanguage( rtl_Locale * This );
@@ -122,7 +121,7 @@ SAL_DLLPUBLIC rtl_uString * SAL_CALL rtl_locale_getVariant( rtl_Locale * This );
 SAL_DLLPUBLIC sal_Int32 SAL_CALL rtl_locale_hashCode( rtl_Locale * This );
 
 /**
-    Returns true if the locals are equal, otherwis false.
+    Returns true if the locals are equal, otherwise false.
  */
 SAL_DLLPUBLIC sal_Int32 SAL_CALL rtl_locale_equals( rtl_Locale * This, rtl_Locale * obj  );
 
