@@ -51,7 +51,7 @@ using namespace ::com::sun::star::io;
 using namespace ::com::sun::star::uno;
 using namespace ::com::sun::star::lang;
 
-#include "services.hxx"
+#include <services.hxx>
 #include "streamhelper.hxx"
 
 namespace io_stm {
@@ -137,22 +137,21 @@ OMarkableOutputStream::OMarkableOutputStream( )
 // XOutputStream
 void OMarkableOutputStream::writeBytes(const Sequence< sal_Int8 >& aData)
 {
-    if( m_bValidStream ) {
-        if( m_mapMarks.empty() && ( m_pBuffer->getSize() == 0 ) ) {
-            // no mark and  buffer active, simple write through
-            m_output->writeBytes( aData );
-        }
-        else {
-            MutexGuard guard( m_mutex );
-            // new data must be buffered
-            m_pBuffer->writeAt( m_nCurrentPos , aData );
-            m_nCurrentPos += aData.getLength();
-            checkMarksAndFlush();
-        }
-    }
-    else {
+    if( !m_bValidStream ) {
         throw NotConnectedException();
     }
+    if( m_mapMarks.empty() && ( m_pBuffer->getSize() == 0 ) ) {
+        // no mark and  buffer active, simple write through
+        m_output->writeBytes( aData );
+    }
+    else {
+        MutexGuard guard( m_mutex );
+        // new data must be buffered
+        m_pBuffer->writeAt( m_nCurrentPos , aData );
+        m_nCurrentPos += aData.getLength();
+        checkMarksAndFlush();
+    }
+
 }
 
 void OMarkableOutputStream::flush()
@@ -174,26 +173,25 @@ void OMarkableOutputStream::flush()
 
 void OMarkableOutputStream::closeOutput()
 {
-    if( m_bValidStream ) {
-        MutexGuard guard( m_mutex );
-        // all marks must be cleared and all
-
-        if( ! m_mapMarks.empty() )
-        {
-            m_mapMarks.clear();
-         }
-        m_nCurrentPos = m_pBuffer->getSize();
-          checkMarksAndFlush();
-
-        m_output->closeOutput();
-
-        setOutputStream( Reference< XOutputStream > () );
-        setPredecessor( Reference < XConnectable >() );
-        setSuccessor( Reference< XConnectable > () );
-    }
-    else {
+    if( !m_bValidStream ) {
         throw NotConnectedException();
     }
+    MutexGuard guard( m_mutex );
+    // all marks must be cleared and all
+
+    if( ! m_mapMarks.empty() )
+    {
+        m_mapMarks.clear();
+     }
+    m_nCurrentPos = m_pBuffer->getSize();
+      checkMarksAndFlush();
+
+    m_output->closeOutput();
+
+    setOutputStream( Reference< XOutputStream > () );
+    setPredecessor( Reference < XConnectable >() );
+    setSuccessor( Reference< XConnectable > () );
+
 }
 
 
@@ -218,10 +216,8 @@ void OMarkableOutputStream::deleteMark(sal_Int32 Mark)
             "MarkableOutputStream::deleteMark unknown mark (" + OUString::number(Mark) + ")",
             *this, 0);
     }
-    else {
-        m_mapMarks.erase( ii );
-        checkMarksAndFlush();
-    }
+    m_mapMarks.erase( ii );
+    checkMarksAndFlush();
 }
 
 void OMarkableOutputStream::jumpToMark(sal_Int32 nMark)
@@ -234,9 +230,7 @@ void OMarkableOutputStream::jumpToMark(sal_Int32 nMark)
             "MarkableOutputStream::jumpToMark unknown mark (" + OUString::number(nMark) + ")",
             *this, 0);
     }
-    else {
-        m_nCurrentPos = (*ii).second;
-    }
+    m_nCurrentPos = (*ii).second;
 }
 
 void OMarkableOutputStream::jumpToFurthest()
@@ -289,7 +283,7 @@ void OMarkableOutputStream::setSuccessor( const Reference< XConnectable > &r )
 
          if( m_succ.is() ) {
               m_succ->setPredecessor( Reference < XConnectable > (
-                  (static_cast< XConnectable *  >(this)) ) );
+                  static_cast< XConnectable *  >(this) ) );
          }
      }
 }
@@ -306,7 +300,7 @@ void OMarkableOutputStream::setPredecessor( const Reference< XConnectable > &r )
         m_pred = r;
         if( m_pred.is() ) {
             m_pred->setSuccessor( Reference < XConnectable > (
-                (static_cast< XConnectable *  >(this )) ) );
+                static_cast< XConnectable *  >(this ) ) );
         }
     }
 }
@@ -410,7 +404,6 @@ class OMarkableInputStream :
 {
 public:
     OMarkableInputStream(  );
-    virtual ~OMarkableInputStream() override;
 
 
 public: // XInputStream
@@ -452,7 +445,7 @@ private:
     Reference< XInputStream > m_input;
     bool m_bValidStream;
 
-    MemRingBuffer *m_pBuffer;
+    std::unique_ptr<MemRingBuffer> m_pBuffer;
     map<sal_Int32,sal_Int32,less< sal_Int32 > > m_mapMarks;
     sal_Int32 m_nCurrentPos;
     sal_Int32 m_nCurrentMark;
@@ -465,14 +458,7 @@ OMarkableInputStream::OMarkableInputStream()
     , m_nCurrentPos(0)
     , m_nCurrentMark(0)
 {
-    m_pBuffer = new MemRingBuffer;
-}
-
-OMarkableInputStream::~OMarkableInputStream()
-{
-    if( m_pBuffer ) {
-        delete m_pBuffer;
-    }
+    m_pBuffer.reset( new MemRingBuffer );
 }
 
 
@@ -482,43 +468,42 @@ sal_Int32 OMarkableInputStream::readBytes(Sequence< sal_Int8 >& aData, sal_Int32
 {
     sal_Int32 nBytesRead;
 
-    if( m_bValidStream ) {
-        MutexGuard guard( m_mutex );
-        if( m_mapMarks.empty() && ! m_pBuffer->getSize() ) {
-            // normal read !
-            nBytesRead = m_input->readBytes( aData, nBytesToRead );
-        }
-        else {
-            // read from buffer
-            sal_Int32 nRead;
-
-            // read enough bytes into buffer
-            if( m_pBuffer->getSize() - m_nCurrentPos < nBytesToRead  ) {
-                sal_Int32 nToRead = nBytesToRead - ( m_pBuffer->getSize() - m_nCurrentPos );
-                nRead = m_input->readBytes( aData , nToRead );
-
-                OSL_ASSERT( aData.getLength() == nRead );
-
-                m_pBuffer->writeAt( m_pBuffer->getSize() , aData );
-
-                if( nRead < nToRead ) {
-                    nBytesToRead = nBytesToRead - (nToRead-nRead);
-                }
-            }
-
-            OSL_ASSERT( m_pBuffer->getSize() - m_nCurrentPos >= nBytesToRead  );
-
-            m_pBuffer->readAt( m_nCurrentPos , aData , nBytesToRead );
-
-            m_nCurrentPos += nBytesToRead;
-            nBytesRead = nBytesToRead;
-        }
-    }
-    else {
+    if( !m_bValidStream ) {
         throw NotConnectedException(
             "MarkableInputStream::readBytes NotConnectedException",
             *this );
     }
+    MutexGuard guard( m_mutex );
+    if( m_mapMarks.empty() && ! m_pBuffer->getSize() ) {
+        // normal read !
+        nBytesRead = m_input->readBytes( aData, nBytesToRead );
+    }
+    else {
+        // read from buffer
+        sal_Int32 nRead;
+
+        // read enough bytes into buffer
+        if( m_pBuffer->getSize() - m_nCurrentPos < nBytesToRead  ) {
+            sal_Int32 nToRead = nBytesToRead - ( m_pBuffer->getSize() - m_nCurrentPos );
+            nRead = m_input->readBytes( aData , nToRead );
+
+            OSL_ASSERT( aData.getLength() == nRead );
+
+            m_pBuffer->writeAt( m_pBuffer->getSize() , aData );
+
+            if( nRead < nToRead ) {
+                nBytesToRead = nBytesToRead - (nToRead-nRead);
+            }
+        }
+
+        OSL_ASSERT( m_pBuffer->getSize() - m_nCurrentPos >= nBytesToRead  );
+
+        m_pBuffer->readAt( m_nCurrentPos , aData , nBytesToRead );
+
+        m_nCurrentPos += nBytesToRead;
+        nBytesRead = nBytesToRead;
+    }
+
     return nBytesRead;
 }
 
@@ -527,46 +512,45 @@ sal_Int32 OMarkableInputStream::readSomeBytes(Sequence< sal_Int8 >& aData, sal_I
 {
 
     sal_Int32 nBytesRead;
-    if( m_bValidStream ) {
-        MutexGuard guard( m_mutex );
-        if( m_mapMarks.empty() && ! m_pBuffer->getSize() ) {
-            // normal read !
-            nBytesRead = m_input->readSomeBytes( aData, nMaxBytesToRead );
-        }
-        else {
-            // read from buffer
-            sal_Int32 nRead = 0;
-            sal_Int32 nInBuffer = m_pBuffer->getSize() - m_nCurrentPos;
-            sal_Int32 nAdditionalBytesToRead = Min(nMaxBytesToRead-nInBuffer,m_input->available());
-            nAdditionalBytesToRead = Max(0 , nAdditionalBytesToRead );
-
-            // read enough bytes into buffer
-            if( 0 == nInBuffer ) {
-                nRead = m_input->readSomeBytes( aData , nMaxBytesToRead );
-            }
-            else if( nAdditionalBytesToRead ) {
-                nRead = m_input->readBytes( aData , nAdditionalBytesToRead );
-            }
-
-            if( nRead ) {
-                aData.realloc( nRead );
-                m_pBuffer->writeAt( m_pBuffer->getSize() , aData );
-            }
-
-            nBytesRead = Min( nMaxBytesToRead , nInBuffer + nRead );
-
-            // now take everything from buffer !
-            m_pBuffer->readAt( m_nCurrentPos , aData , nBytesRead );
-
-            m_nCurrentPos += nBytesRead;
-        }
-    }
-    else
-    {
+    if( !m_bValidStream )    {
         throw NotConnectedException(
             "MarkableInputStream::readSomeBytes NotConnectedException",
             *this );
     }
+
+    MutexGuard guard( m_mutex );
+    if( m_mapMarks.empty() && ! m_pBuffer->getSize() ) {
+        // normal read !
+        nBytesRead = m_input->readSomeBytes( aData, nMaxBytesToRead );
+    }
+    else {
+        // read from buffer
+        sal_Int32 nRead = 0;
+        sal_Int32 nInBuffer = m_pBuffer->getSize() - m_nCurrentPos;
+        sal_Int32 nAdditionalBytesToRead = Min(nMaxBytesToRead-nInBuffer,m_input->available());
+        nAdditionalBytesToRead = Max(0 , nAdditionalBytesToRead );
+
+        // read enough bytes into buffer
+        if( 0 == nInBuffer ) {
+            nRead = m_input->readSomeBytes( aData , nMaxBytesToRead );
+        }
+        else if( nAdditionalBytesToRead ) {
+            nRead = m_input->readBytes( aData , nAdditionalBytesToRead );
+        }
+
+        if( nRead ) {
+            aData.realloc( nRead );
+            m_pBuffer->writeAt( m_pBuffer->getSize() , aData );
+        }
+
+        nBytesRead = Min( nMaxBytesToRead , nInBuffer + nRead );
+
+        // now take everything from buffer !
+        m_pBuffer->readAt( m_nCurrentPos , aData , nBytesRead );
+
+        m_nCurrentPos += nBytesRead;
+    }
+
     return nBytesRead;
 
 
@@ -588,43 +572,36 @@ void OMarkableInputStream::skipBytes(sal_Int32 nBytesToSkip)
 
 sal_Int32 OMarkableInputStream::available()
 {
-    sal_Int32 nAvail;
-    if( m_bValidStream ) {
-        MutexGuard guard( m_mutex );
-        nAvail = m_input->available() + ( m_pBuffer->getSize() - m_nCurrentPos );
-    }
-    else
-    {
+    if( !m_bValidStream )    {
         throw NotConnectedException(
             "MarkableInputStream::available NotConnectedException",
             *this );
     }
 
+    MutexGuard guard( m_mutex );
+    sal_Int32 nAvail = m_input->available() + ( m_pBuffer->getSize() - m_nCurrentPos );
     return nAvail;
 }
 
 
 void OMarkableInputStream::closeInput()
 {
-    if( m_bValidStream ) {
-        MutexGuard guard( m_mutex );
-
-        m_input->closeInput();
-
-        setInputStream( Reference< XInputStream > () );
-        setPredecessor( Reference< XConnectable > () );
-        setSuccessor( Reference< XConnectable >() );
-
-        delete m_pBuffer;
-        m_pBuffer = nullptr;
-        m_nCurrentPos = 0;
-        m_nCurrentMark = 0;
-    }
-    else {
+    if( !m_bValidStream ) {
         throw NotConnectedException(
             "MarkableInputStream::closeInput NotConnectedException",
             *this );
     }
+    MutexGuard guard( m_mutex );
+
+    m_input->closeInput();
+
+    setInputStream( Reference< XInputStream > () );
+    setPredecessor( Reference< XConnectable > () );
+    setSuccessor( Reference< XConnectable >() );
+
+    m_pBuffer.reset();
+    m_nCurrentPos = 0;
+    m_nCurrentMark = 0;
 }
 
 // XMarkable
@@ -650,10 +627,8 @@ void OMarkableInputStream::deleteMark(sal_Int32 Mark)
             "MarkableInputStream::deleteMark unknown mark (" + OUString::number(Mark) + ")",
             *this , 0 );
     }
-    else {
-        m_mapMarks.erase( ii );
-        checkMarksAndFlush();
-    }
+    m_mapMarks.erase( ii );
+    checkMarksAndFlush();
 }
 
 void OMarkableInputStream::jumpToMark(sal_Int32 nMark)
@@ -667,10 +642,7 @@ void OMarkableInputStream::jumpToMark(sal_Int32 nMark)
             "MarkableInputStream::jumpToMark unknown mark (" + OUString::number(nMark) + ")",
             *this , 0 );
     }
-    else
-    {
-        m_nCurrentPos = (*ii).second;
-    }
+    m_nCurrentPos = (*ii).second;
 }
 
 void OMarkableInputStream::jumpToFurthest()
@@ -727,7 +699,7 @@ void OMarkableInputStream::setSuccessor( const Reference< XConnectable > &r )
          if( m_succ.is() ) {
               /// set this instance as the sink !
               m_succ->setPredecessor( Reference< XConnectable > (
-                  (static_cast< XConnectable *  >(this)) ) );
+                  static_cast< XConnectable * >(this) ) );
          }
      }
 }
@@ -745,7 +717,7 @@ void OMarkableInputStream::setPredecessor( const Reference < XConnectable >  &r
         m_pred = r;
         if( m_pred.is() ) {
             m_pred->setSuccessor( Reference< XConnectable > (
-                (static_cast< XConnectable *  >(this)) ) );
+                static_cast< XConnectable * >(this) ) );
         }
     }
 }
