@@ -17,12 +17,13 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "sal/config.h"
+#include <sal/config.h>
 
-#include <osl/diagnose.h>
-#include <osl/module.h>
+#include <osl/module.hxx>
+#include <osl/thread.h>
 
 #include <uno/environment.hxx>
+#include <uno/lbnames.h>
 #include <uno/mapping.hxx>
 
 #include <cppuhelper/factory.hxx>
@@ -32,9 +33,9 @@
 #include <com/sun/star/lang/XServiceInfo.hpp>
 #include <com/sun/star/registry/XRegistryKey.hpp>
 
-#include "jni.h"
-#include "jvmaccess/virtualmachine.hxx"
-#include "jvmaccess/unovirtualmachine.hxx"
+#include <jni.h>
+#include <jvmaccess/virtualmachine.hxx>
+#include <jvmaccess/unovirtualmachine.hxx>
 
 #include "juhx-export-functions.hxx"
 #include "vm.hxx"
@@ -51,37 +52,35 @@ jboolean Java_com_sun_star_comp_helper_SharedLibraryLoader_component_1writeInfo(
     JNIEnv * pJEnv, SAL_UNUSED_PARAMETER jclass, jstring jLibName, jobject jSMgr,
     jobject jRegKey, jobject loader )
 {
-    sal_Bool bRet = sal_False;
+    bool bRet = false;
 
-    const jchar* pJLibName = pJEnv->GetStringChars( jLibName, NULL );
-    OUString aLibName( pJLibName );
-    pJEnv->ReleaseStringChars( jLibName, pJLibName);
+    const jchar* pJLibName = pJEnv->GetStringChars(jLibName, nullptr);
+    OUString aLibName(reinterpret_cast<sal_Unicode const *>(pJLibName));
+    pJEnv->ReleaseStringChars(jLibName, pJLibName);
 
 #ifdef DISABLE_DYNLOADING
     (void) jSMgr;
     (void) jRegKey;
     (void) loader;
 
-    fprintf(stderr, "Hmm, %s called for %s\n", __PRETTY_FUNCTION__, OUStringToOString(pJLibName, RTL_TEXTENCODING_JAVA_UTF8).getStr());
+    fprintf(stderr, "Hmm, %s called for %s\n", __PRETTY_FUNCTION__, OUStringToOString(aLibName, osl_getThreadTextEncoding()).getStr());
 #else
-    oslModule lib = osl_loadModule( aLibName.pData, SAL_LOADMODULE_LAZY | SAL_LOADMODULE_GLOBAL );
-    if (lib)
+    osl::Module lib(aLibName, SAL_LOADMODULE_LAZY | SAL_LOADMODULE_GLOBAL);
+    if (lib.is())
     {
         // ========================= LATEST VERSION =========================
-        OUString aGetEnvName( COMPONENT_GETENV );
-        oslGenericFunction pSym =
-            osl_getFunctionSymbol( lib, aGetEnvName.pData );
+        oslGenericFunction pSym = lib.getFunctionSymbol(COMPONENT_GETENV);
         if (pSym)
         {
             Environment java_env, loader_env;
 
-            const sal_Char * pEnvTypeName = 0;
-            (*((component_getImplementationEnvironmentFunc)pSym))(
-                &pEnvTypeName, (uno_Environment **)&loader_env );
+            const sal_Char * pEnvTypeName = nullptr;
+            (*reinterpret_cast<component_getImplementationEnvironmentFunc>(pSym))(
+                &pEnvTypeName, reinterpret_cast<uno_Environment **>(&loader_env) );
             if (! loader_env.is())
             {
                 OUString aEnvTypeName( OUString::createFromAscii( pEnvTypeName ) );
-                uno_getEnvironment( (uno_Environment **)&loader_env, aEnvTypeName.pData, 0 );
+                uno_getEnvironment( reinterpret_cast<uno_Environment **>(&loader_env), aEnvTypeName.pData, nullptr );
             }
 
             // create vm access
@@ -89,10 +88,9 @@ jboolean Java_com_sun_star_comp_helper_SharedLibraryLoader_component_1writeInfo(
                 ::javaunohelper::create_vm_access( pJEnv, loader ) );
             OUString java_env_name = UNO_LB_JAVA;
             uno_getEnvironment(
-                (uno_Environment **)&java_env, java_env_name.pData, vm_access.get() );
+                reinterpret_cast<uno_Environment **>(&java_env), java_env_name.pData, vm_access.get() );
 
-            OUString aWriteInfoName( COMPONENT_WRITEINFO );
-            pSym = osl_getFunctionSymbol( lib, aWriteInfoName.pData );
+            pSym = lib.getFunctionSymbol(COMPONENT_WRITEINFO);
             if (pSym)
             {
                 if (loader_env.is() && java_env.is())
@@ -103,15 +101,15 @@ jboolean Java_com_sun_star_comp_helper_SharedLibraryLoader_component_1writeInfo(
                     {
                         void * pSMgr =
                             java2dest.mapInterface(
-                                jSMgr, getCppuType((Reference< lang::XMultiServiceFactory > *) 0) );
+                                jSMgr, cppu::UnoType<lang::XMultiServiceFactory>::get());
                         void * pKey =
                             java2dest.mapInterface(
-                                jRegKey, getCppuType((Reference< registry::XRegistryKey > *) 0) );
+                                jRegKey, cppu::UnoType<registry::XRegistryKey>::get());
 
                         uno_ExtEnvironment * env = loader_env.get()->pExtEnv;
                         if (pKey)
                         {
-                            bRet = (*((component_writeInfoFunc)pSym))( pSMgr, pKey );
+                            bRet = (*reinterpret_cast<component_writeInfoFunc>(pSym))( pSMgr, pKey );
 
                             if (env)
                                 (*env->releaseInterface)( env, pKey );
@@ -123,9 +121,10 @@ jboolean Java_com_sun_star_comp_helper_SharedLibraryLoader_component_1writeInfo(
                 }
             }
         }
+        lib.release();
     }
 #endif
-    return bRet == sal_False? JNI_FALSE : JNI_TRUE;
+    return bRet ? JNI_TRUE : JNI_FALSE;
 }
 
 /*
@@ -137,7 +136,9 @@ jobject Java_com_sun_star_comp_helper_SharedLibraryLoader_component_1getFactory(
     JNIEnv * pJEnv, SAL_UNUSED_PARAMETER jclass, jstring jLibName, jstring jImplName,
     jobject jSMgr, jobject jRegKey, jobject loader )
 {
-    const jchar* pJLibName = pJEnv->GetStringChars(jLibName, NULL);
+    const jchar* pJLibName = pJEnv->GetStringChars(jLibName, nullptr);
+    OUString aLibName(reinterpret_cast<sal_Unicode const *>(pJLibName));
+    pJEnv->ReleaseStringChars(jLibName, pJLibName);
 
 #ifdef DISABLE_DYNLOADING
     (void) jImplName;
@@ -145,36 +146,31 @@ jobject Java_com_sun_star_comp_helper_SharedLibraryLoader_component_1getFactory(
     (void) jRegKey;
     (void) loader;
 
-    fprintf(stderr, "Hmm, %s called for %s\n", __PRETTY_FUNCTION__, OUStringToOString(pJLibName, RTL_TEXTENCODING_JAVA_UTF8).getStr());
+    fprintf(stderr, "Hmm, %s called for %s\n", __PRETTY_FUNCTION__, OUStringToOString(aLibName, osl_getThreadTextEncoding()).getStr());
 #endif
 
-    OUString aLibName( pJLibName );
-    pJEnv->ReleaseStringChars( jLibName, pJLibName);
+    aLibName += SAL_DLLEXTENSION;
 
-    aLibName += OUString( SAL_DLLEXTENSION );
-
-    jobject joSLL_cpp = 0;
+    jobject joSLL_cpp = nullptr;
 
 #ifndef DISABLE_DYNLOADING
-    oslModule lib = osl_loadModule( aLibName.pData, SAL_LOADMODULE_LAZY | SAL_LOADMODULE_GLOBAL );
-    if (lib)
+    osl::Module lib(aLibName, SAL_LOADMODULE_LAZY | SAL_LOADMODULE_GLOBAL);
+    if (lib.is())
     {
         // ========================= LATEST VERSION =========================
-        OUString aGetEnvName( COMPONENT_GETENV );
-        oslGenericFunction pSym =
-            osl_getFunctionSymbol( lib, aGetEnvName.pData );
+        oslGenericFunction pSym = lib.getFunctionSymbol(COMPONENT_GETENV);
         if (pSym)
         {
             Environment java_env, loader_env;
 
-            const sal_Char * pEnvTypeName = 0;
-            (*((component_getImplementationEnvironmentFunc)pSym))(
-                &pEnvTypeName, (uno_Environment **)&loader_env );
+            const sal_Char * pEnvTypeName = nullptr;
+            (*reinterpret_cast<component_getImplementationEnvironmentFunc>(pSym))(
+                &pEnvTypeName, reinterpret_cast<uno_Environment **>(&loader_env) );
 
             if (! loader_env.is())
             {
                 OUString aEnvTypeName( OUString::createFromAscii( pEnvTypeName ) );
-                uno_getEnvironment( (uno_Environment **)&loader_env, aEnvTypeName.pData, 0 );
+                uno_getEnvironment( reinterpret_cast<uno_Environment **>(&loader_env), aEnvTypeName.pData, nullptr );
             }
 
             // create vm access
@@ -182,10 +178,9 @@ jobject Java_com_sun_star_comp_helper_SharedLibraryLoader_component_1getFactory(
                 ::javaunohelper::create_vm_access( pJEnv, loader ) );
             OUString java_env_name = UNO_LB_JAVA;
             uno_getEnvironment(
-                (uno_Environment **)&java_env, java_env_name.pData, vm_access.get() );
+                reinterpret_cast<uno_Environment **>(&java_env), java_env_name.pData, vm_access.get() );
 
-            OUString aGetFactoryName( COMPONENT_GETFACTORY );
-            pSym = osl_getFunctionSymbol( lib, aGetFactoryName.pData );
+            pSym = lib.getFunctionSymbol(COMPONENT_GETFACTORY);
             if (pSym)
             {
                 if (loader_env.is() && java_env.is())
@@ -197,14 +192,14 @@ jobject Java_com_sun_star_comp_helper_SharedLibraryLoader_component_1getFactory(
                     {
                         void * pSMgr =
                             java2dest.mapInterface(
-                                jSMgr, ::getCppuType((Reference< lang::XMultiServiceFactory > *) 0) );
+                                jSMgr, cppu::UnoType<lang::XMultiServiceFactory>::get());
                         void * pKey =
                             java2dest.mapInterface(
-                                jRegKey, ::getCppuType((Reference< registry::XRegistryKey > *) 0) );
+                                jRegKey, cppu::UnoType<registry::XRegistryKey>::get());
 
-                        const char* pImplName = pJEnv->GetStringUTFChars( jImplName, NULL );
+                        const char* pImplName = pJEnv->GetStringUTFChars( jImplName, nullptr );
 
-                        void * pSSF = (*((component_getFactoryFunc)pSym))(
+                        void * pSSF = (*reinterpret_cast<component_getFactoryFunc>(pSym))(
                             pImplName, pSMgr, pKey );
 
                         pJEnv->ReleaseStringUTFChars( jImplName, pImplName );
@@ -218,8 +213,8 @@ jobject Java_com_sun_star_comp_helper_SharedLibraryLoader_component_1getFactory(
 
                         if (pSSF)
                         {
-                            jobject jglobal = (jobject) dest2java.mapInterface(
-                                pSSF, getCppuType((Reference< XInterface > *) 0) );
+                            jobject jglobal = static_cast<jobject>(dest2java.mapInterface(
+                                pSSF, cppu::UnoType<XInterface>::get()));
                             joSLL_cpp = pJEnv->NewLocalRef( jglobal );
                             pJEnv->DeleteGlobalRef( jglobal );
                             if (env)
@@ -229,6 +224,7 @@ jobject Java_com_sun_star_comp_helper_SharedLibraryLoader_component_1getFactory(
                 }
             }
         }
+        lib.release();
     }
 #endif
     return joSLL_cpp;
