@@ -48,34 +48,32 @@
 #include <sal/config.h>
 #include <osl/conditn.hxx>
 #include <osl/thread.hxx>
-#include <cppuhelper/implbase4.hxx>
 #include <cppuhelper/implementationentry.hxx>
 #include <cppuhelper/interfacecontainer.h>
 #include <cppuhelper/factory.hxx>
 #include <cppuhelper/supportsservice.hxx>
 #include <i18nlangtag/languagetag.hxx>
 #include <comphelper/processfactory.hxx>
+#include <comphelper/propertysequence.hxx>
 #include <comphelper/extract.hxx>
 
 #include <deque>
 #include <map>
 #include <vector>
 
-#include "linguistic/misc.hxx"
+#include <linguistic/misc.hxx>
 #include "defs.hxx"
 #include "lngopt.hxx"
+#include "lngreg.hxx"
 
 #include "gciterator.hxx"
 
 using namespace linguistic;
 using namespace ::com::sun::star;
 
-// forward declarations
 static OUString GrammarCheckingIterator_getImplementationName() throw();
 static uno::Sequence< OUString > GrammarCheckingIterator_getSupportedServiceNames() throw();
 
-
-
 // white space list: obtained from the fonts.config.txt of a Linux system.
 static const sal_Unicode aWhiteSpaces[] =
 {
@@ -129,7 +127,7 @@ static const sal_Unicode aWhiteSpaces[] =
     0xfffb    /* INTERLINEAR ANNOTATION TERMINATOR */
 };
 
-static const int nWhiteSpaces = sizeof( aWhiteSpaces ) / sizeof( aWhiteSpaces[0] );
+static const int nWhiteSpaces = SAL_N_ELEMENTS( aWhiteSpaces );
 
 static bool lcl_IsWhiteSpace( sal_Unicode cChar )
 {
@@ -161,7 +159,7 @@ static sal_Int32 lcl_SkipWhiteSpaces( const OUString &rText, sal_Int32 nStartPos
     }
     if (bIllegalArgument)
     {
-        DBG_ASSERT( 0, "lcl_SkipWhiteSpaces: illegal arguments" );
+        SAL_WARN( "linguistic", "lcl_SkipWhiteSpaces: illegal arguments" );
     }
 
     sal_Int32 nRes = nStartPos;
@@ -196,7 +194,7 @@ static sal_Int32 lcl_BacktraceWhiteSpaces( const OUString &rText, sal_Int32 nSta
     }
     if (bIllegalArgument)
     {
-        DBG_ASSERT( 0, "lcl_BacktraceWhiteSpaces: illegal arguments" );
+        SAL_WARN( "linguistic", "lcl_BacktraceWhiteSpaces: illegal arguments" );
     }
 
     sal_Int32 nRes = nStartPos;
@@ -222,11 +220,13 @@ static sal_Int32 lcl_BacktraceWhiteSpaces( const OUString &rText, sal_Int32 nSta
 
 extern "C" void lcl_workerfunc (void * gci)
 {
-    ((GrammarCheckingIterator*)gci)->DequeueAndCheck();
+    osl_setThreadName("GrammarCheckingIterator");
+
+    static_cast<GrammarCheckingIterator*>(gci)->DequeueAndCheck();
 }
 
 static lang::Locale lcl_GetPrimaryLanguageOfSentence(
-    uno::Reference< text::XFlatParagraph > xFlatPara,
+    const uno::Reference< text::XFlatParagraph >& xFlatPara,
     sal_Int32 nStartIndex )
 {
     //get the language of the first word
@@ -235,11 +235,10 @@ static lang::Locale lcl_GetPrimaryLanguageOfSentence(
 
 
 GrammarCheckingIterator::GrammarCheckingIterator() :
-    m_bEnd( sal_False ),
+    m_bEnd( false ),
     m_aCurCheckedDocId(),
-    m_bGCServicesChecked( sal_False ),
+    m_bGCServicesChecked( false ),
     m_nDocIdCounter( 0 ),
-    m_nLastEndOfSentencePos( -1 ),
     m_aEventListeners( MyMutex::get() ),
     m_aNotifyListeners( MyMutex::get() )
 {
@@ -258,11 +257,11 @@ void GrammarCheckingIterator::TerminateThread()
     {
         ::osl::Guard< ::osl::Mutex > aGuard( MyMutex::get() );
         t = m_thread;
-        m_thread = 0;
-        m_bEnd = sal_True;
+        m_thread = nullptr;
+        m_bEnd = true;
         m_aWakeUpThread.set();
     }
-    if (t != 0)
+    if (t != nullptr)
     {
         osl_joinWithThread(t);
         osl_destroyThread(t);
@@ -303,11 +302,11 @@ OUString GrammarCheckingIterator::GetOrCreateDocId(
 
 
 void GrammarCheckingIterator::AddEntry(
-    uno::WeakReference< text::XFlatParagraphIterator > xFlatParaIterator,
-    uno::WeakReference< text::XFlatParagraph > xFlatPara,
+    const uno::WeakReference< text::XFlatParagraphIterator >& xFlatParaIterator,
+    const uno::WeakReference< text::XFlatParagraph >& xFlatPara,
     const OUString & rDocId,
     sal_Int32 nStartIndex,
-    sal_Bool bAutomatic )
+    bool bAutomatic )
 {
     // we may not need/have a xFlatParaIterator (e.g. if checkGrammarAtPos was called)
     // but we always need a xFlatPara...
@@ -338,11 +337,11 @@ void GrammarCheckingIterator::ProcessResult(
 {
     DBG_ASSERT( rRes.xFlatParagraph.is(), "xFlatParagraph is missing" );
      //no guard necessary as no members are used
-    sal_Bool bContinueWithNextPara = sal_False;
+    bool bContinueWithNextPara = false;
     if (!rRes.xFlatParagraph.is() || rRes.xFlatParagraph->isModified())
     {
         // if paragraph was modified/deleted meanwhile continue with the next one...
-        bContinueWithNextPara = sal_True;
+        bContinueWithNextPara = true;
     }
     else    // paragraph is still unchanged...
     {
@@ -354,7 +353,6 @@ void GrammarCheckingIterator::ProcessResult(
                              0 <= rRes.nStartOfNextSentencePosition && rRes.nStartOfNextSentencePosition <= nTextLen &&
                              rRes.nStartOfSentencePosition      <= rRes.nBehindEndOfSentencePosition &&
                              rRes.nBehindEndOfSentencePosition  <= rRes.nStartOfNextSentencePosition;
-        (void) bBoundariesOk;
         DBG_ASSERT( bBoundariesOk, "inconsistent sentence boundaries" );
 
         uno::Reference< text::XMultiTextMarkup > xMulti( rRes.xFlatParagraph, uno::UNO_QUERY );
@@ -411,7 +409,7 @@ void GrammarCheckingIterator::ProcessResult(
             if (rRes.xFlatParagraph.is())
                 rRes.xFlatParagraph->setChecked( text::TextMarkupType::PROOFREADING, true );
 
-            bContinueWithNextPara = sal_True;
+            bContinueWithNextPara = true;
         }
     }
 
@@ -431,7 +429,6 @@ void GrammarCheckingIterator::ProcessResult(
 uno::Reference< linguistic2::XProofreader > GrammarCheckingIterator::GetGrammarChecker(
     const lang::Locale &rLocale )
 {
-    (void) rLocale;
     uno::Reference< linguistic2::XProofreader > xRes;
 
     // ---- THREAD SAFE START ----
@@ -441,7 +438,7 @@ uno::Reference< linguistic2::XProofreader > GrammarCheckingIterator::GetGrammarC
     if (!m_bGCServicesChecked)
     {
         GetConfiguredGCSvcs_Impl();
-        m_bGCServicesChecked = sal_True;
+        m_bGCServicesChecked = true;
     }
 
     const LanguageType nLang = LanguageTag::convertToLanguageType( rLocale, false);
@@ -454,7 +451,7 @@ uno::Reference< linguistic2::XProofreader > GrammarCheckingIterator::GetGrammarC
         {
             xRes = aImplNameIt->second;
         }
-        else    // the service is to be instatiated here for the first time...
+        else    // the service is to be instantiated here for the first time...
         {
             try
             {
@@ -475,12 +472,12 @@ uno::Reference< linguistic2::XProofreader > GrammarCheckingIterator::GetGrammarC
                 }
                 else
                 {
-                    DBG_ASSERT( 0, "grammar checker does not support required locale" );
+                    SAL_WARN( "linguistic", "grammar checker does not support required locale" );
                 }
             }
             catch (uno::Exception &)
             {
-                DBG_ASSERT( 0, "instantiating grammar checker failed" );
+                SAL_WARN( "linguistic", "instantiating grammar checker failed" );
             }
         }
     }
@@ -489,6 +486,16 @@ uno::Reference< linguistic2::XProofreader > GrammarCheckingIterator::GetGrammarC
     return xRes;
 }
 
+static uno::Sequence<beans::PropertyValue>
+lcl_makeProperties(uno::Reference<text::XFlatParagraph> const& xFlatPara)
+{
+    uno::Reference<beans::XPropertySet> const xProps(
+            xFlatPara, uno::UNO_QUERY_THROW);
+    return comphelper::InitPropertySequence({
+        { "FieldPositions", xProps->getPropertyValue("FieldPositions") },
+        { "FootnotePositions", xProps->getPropertyValue("FootnotePositions") }
+    });
+}
 
 void GrammarCheckingIterator::DequeueAndCheck()
 {
@@ -512,7 +519,6 @@ void GrammarCheckingIterator::DequeueAndCheck()
             uno::Reference< text::XFlatParagraph > xFlatPara;
             FPEntry aFPEntryItem;
             OUString aCurDocId;
-            sal_Bool bModified = sal_False;
             // ---- THREAD SAFE START ----
             {
                 ::osl::Guard< ::osl::Mutex > aGuard( MyMutex::get() );
@@ -528,75 +534,86 @@ void GrammarCheckingIterator::DequeueAndCheck()
 
             if (xFlatPara.is() && xFPIterator.is())
             {
-                OUString aCurTxt( xFlatPara->getText() );
-                lang::Locale aCurLocale = lcl_GetPrimaryLanguageOfSentence( xFlatPara, aFPEntryItem.m_nStartIndex );
-
-                bModified = xFlatPara->isModified();
-                if (!bModified)
+                try
                 {
-                    // ---- THREAD SAFE START ----
-                    ::osl::ClearableGuard< ::osl::Mutex > aGuard( MyMutex::get() );
+                    OUString aCurTxt( xFlatPara->getText() );
+                    lang::Locale aCurLocale = lcl_GetPrimaryLanguageOfSentence( xFlatPara, aFPEntryItem.m_nStartIndex );
 
-                    sal_Int32 nStartPos = aFPEntryItem.m_nStartIndex;
-                    sal_Int32 nSuggestedEnd = GetSuggestedEndOfSentence( aCurTxt, nStartPos, aCurLocale );
-                    DBG_ASSERT( (nSuggestedEnd == 0 && aCurTxt.isEmpty()) || nSuggestedEnd > nStartPos,
-                            "nSuggestedEndOfSentencePos calculation failed?" );
-
-                    linguistic2::ProofreadingResult aRes;
-
-                    uno::Reference< linguistic2::XProofreader > xGC( GetGrammarChecker( aCurLocale ), uno::UNO_QUERY );
-                    if (xGC.is())
+                    const bool bModified = xFlatPara->isModified();
+                    if (!bModified)
                     {
-                        aGuard.clear();
-                        uno::Sequence< beans::PropertyValue > aEmptyProps;
-                        aRes = xGC->doProofreading( aCurDocId, aCurTxt, aCurLocale, nStartPos, nSuggestedEnd, aEmptyProps );
+                        // ---- THREAD SAFE START ----
+                        ::osl::ClearableGuard< ::osl::Mutex > aGuard( MyMutex::get() );
 
-                        //!! work-around to prevent looping if the grammar checker
-                        //!! failed to properly identify the sentence end
-                        if (
-                            aRes.nBehindEndOfSentencePosition <= nStartPos &&
-                            aRes.nBehindEndOfSentencePosition != nSuggestedEnd
-                           )
+                        sal_Int32 nStartPos = aFPEntryItem.m_nStartIndex;
+                        sal_Int32 nSuggestedEnd = GetSuggestedEndOfSentence( aCurTxt, nStartPos, aCurLocale );
+                        DBG_ASSERT( (nSuggestedEnd == 0 && aCurTxt.isEmpty()) || nSuggestedEnd > nStartPos,
+                                    "nSuggestedEndOfSentencePos calculation failed?" );
+
+                        linguistic2::ProofreadingResult aRes;
+
+                        uno::Reference< linguistic2::XProofreader > xGC( GetGrammarChecker( aCurLocale ), uno::UNO_QUERY );
+                        if (xGC.is())
                         {
-                            DBG_ASSERT( 0, "!! Grammarchecker failed to provide end of sentence !!" );
-                            aRes.nBehindEndOfSentencePosition = nSuggestedEnd;
-                        }
+                            aGuard.clear();
+                            uno::Sequence<beans::PropertyValue> const aProps(
+                                lcl_makeProperties(xFlatPara));
+                            aRes = xGC->doProofreading( aCurDocId, aCurTxt,
+                                                        aCurLocale, nStartPos, nSuggestedEnd, aProps );
 
-                        aRes.xFlatParagraph      = xFlatPara;
-                        aRes.nStartOfSentencePosition = nStartPos;
+                            //!! work-around to prevent looping if the grammar checker
+                            //!! failed to properly identify the sentence end
+                            if (
+                                aRes.nBehindEndOfSentencePosition <= nStartPos &&
+                                aRes.nBehindEndOfSentencePosition != nSuggestedEnd
+                            )
+                            {
+                                SAL_WARN( "linguistic", "!! Grammarchecker failed to provide end of sentence !!" );
+                                aRes.nBehindEndOfSentencePosition = nSuggestedEnd;
+                            }
+
+                            aRes.xFlatParagraph      = xFlatPara;
+                            aRes.nStartOfSentencePosition = nStartPos;
+                        }
+                        else
+                        {
+                            // no grammar checker -> no error
+                            // but we need to provide the data below in order to continue with the next sentence
+                            aRes.aDocumentIdentifier = aCurDocId;
+                            aRes.xFlatParagraph      = xFlatPara;
+                            aRes.aText               = aCurTxt;
+                            aRes.aLocale             = aCurLocale;
+                            aRes.nStartOfSentencePosition       = nStartPos;
+                            aRes.nBehindEndOfSentencePosition   = nSuggestedEnd;
+                        }
+                        aRes.nStartOfNextSentencePosition = lcl_SkipWhiteSpaces( aCurTxt, aRes.nBehindEndOfSentencePosition );
+                        aRes.nBehindEndOfSentencePosition = lcl_BacktraceWhiteSpaces( aCurTxt, aRes.nStartOfNextSentencePosition );
+
+                        //guard has to be cleared as ProcessResult calls out of this class
+                        aGuard.clear();
+                        ProcessResult( aRes, xFPIterator, aFPEntryItem.m_bAutomatic );
+                        // ---- THREAD SAFE END ----
                     }
                     else
                     {
-                        // no grammar checker -> no error
-                        // but we need to provide the data below in order to continue with the next sentence
-                        aRes.aDocumentIdentifier = aCurDocId;
-                        aRes.xFlatParagraph      = xFlatPara;
-                        aRes.aText               = aCurTxt;
-                        aRes.aLocale             = aCurLocale;
-                        aRes.nStartOfSentencePosition       = nStartPos;
-                        aRes.nBehindEndOfSentencePosition   = nSuggestedEnd;
+                        // the paragraph changed meanwhile... (and maybe is still edited)
+                        // thus we simply continue to ask for the next to be checked.
+                        uno::Reference< text::XFlatParagraph > xFlatParaNext( xFPIterator->getNextPara() );
+                        AddEntry( xFPIterator, xFlatParaNext, aCurDocId, 0, aFPEntryItem.m_bAutomatic );
                     }
-                    aRes.nStartOfNextSentencePosition = lcl_SkipWhiteSpaces( aCurTxt, aRes.nBehindEndOfSentencePosition );
-                    aRes.nBehindEndOfSentencePosition = lcl_BacktraceWhiteSpaces( aCurTxt, aRes.nStartOfNextSentencePosition );
-
-                    //guard has to be cleared as ProcessResult calls out of this class
-                    aGuard.clear();
-                    ProcessResult( aRes, xFPIterator, aFPEntryItem.m_bAutomatic );
-                    // ---- THREAD SAFE END ----
                 }
-                else
+                catch (css::uno::Exception & e)
                 {
-                    // the paragraph changed meanwhile... (and maybe is still edited)
-                    // thus we simply continue to ask for the next to be checked.
-                    uno::Reference< text::XFlatParagraph > xFlatParaNext( xFPIterator->getNextPara() );
-                    AddEntry( xFPIterator, xFlatParaNext, aCurDocId, 0, aFPEntryItem.m_bAutomatic );
+                    SAL_WARN(
+                        "linguistic",
+                        "GrammarCheckingIterator::DequeueAndCheck ignoring " << e);
                 }
             }
 
             // ---- THREAD SAFE START ----
             {
                 ::osl::Guard< ::osl::Mutex > aGuard( MyMutex::get() );
-                m_aCurCheckedDocId  = OUString();
+                m_aCurCheckedDocId.clear();
             }
             // ---- THREAD SAFE END ----
         }
@@ -629,13 +646,12 @@ void GrammarCheckingIterator::DequeueAndCheck()
 void SAL_CALL GrammarCheckingIterator::startProofreading(
     const uno::Reference< ::uno::XInterface > & xDoc,
     const uno::Reference< text::XFlatParagraphIteratorProvider > & xIteratorProvider )
-throw (uno::RuntimeException, lang::IllegalArgumentException)
 {
     // get paragraph to start checking with
     const bool bAutomatic = true;
     uno::Reference<text::XFlatParagraphIterator> xFPIterator = xIteratorProvider->getFlatParagraphIterator(
             text::TextMarkupType::PROOFREADING, bAutomatic );
-    uno::Reference< text::XFlatParagraph > xPara( xFPIterator.is()? xFPIterator->getFirstPara() : NULL );
+    uno::Reference< text::XFlatParagraph > xPara( xFPIterator.is()? xFPIterator->getFirstPara() : nullptr );
     uno::Reference< lang::XComponent > xComponent( xDoc, uno::UNO_QUERY );
 
     // ---- THREAD SAFE START ----
@@ -655,14 +671,11 @@ linguistic2::ProofreadingResult SAL_CALL GrammarCheckingIterator::checkSentenceA
     const uno::Reference< uno::XInterface >& xDoc,
     const uno::Reference< text::XFlatParagraph >& xFlatPara,
     const OUString& rText,
-    const lang::Locale& rLocale,
+    const lang::Locale&,
     sal_Int32 nStartOfSentencePos,
     sal_Int32 nSuggestedEndOfSentencePos,
     sal_Int32 nErrorPosInPara )
-throw (lang::IllegalArgumentException, uno::RuntimeException)
 {
-    (void) rLocale;
-
     // for the context menu...
 
     linguistic2::ProofreadingResult aRes;
@@ -696,14 +709,16 @@ throw (lang::IllegalArgumentException, uno::RuntimeException)
             sal_Int32 nEndPos = -1;
             if (xGC.is())
             {
-                uno::Sequence< beans::PropertyValue > aEmptyProps;
-                aTmpRes = xGC->doProofreading( aDocId, rText, aCurLocale, nStartPos, nSuggestedEndOfSentencePos, aEmptyProps );
+                uno::Sequence<beans::PropertyValue> const aProps(
+                        lcl_makeProperties(xFlatPara));
+                aTmpRes = xGC->doProofreading( aDocId, rText,
+                    aCurLocale, nStartPos, nSuggestedEndOfSentencePos, aProps );
 
                 //!! work-around to prevent looping if the grammar checker
                 //!! failed to properly identify the sentence end
                 if (aTmpRes.nBehindEndOfSentencePosition <= nStartPos)
                 {
-                    DBG_ASSERT( 0, "!! Grammarchecker failed to provide end of sentence !!" );
+                    SAL_WARN( "linguistic", "!! Grammarchecker failed to provide end of sentence !!" );
                     aTmpRes.nBehindEndOfSentencePosition = nSuggestedEndOfSentencePos;
                 }
 
@@ -724,7 +739,7 @@ throw (lang::IllegalArgumentException, uno::RuntimeException)
             // prevent endless loop by forcefully advancing if needs be...
             if (nStartPos <= nOldStartOfSentencePos)
             {
-                DBG_ASSERT( 0, "end-of-sentence detection failed?" );
+                SAL_WARN( "linguistic", "end-of-sentence detection failed?" );
                 nStartPos = nOldStartOfSentencePos + 1;
             }
         }
@@ -781,7 +796,6 @@ sal_Int32 GrammarCheckingIterator::GetSuggestedEndOfSentence(
 
 
 void SAL_CALL GrammarCheckingIterator::resetIgnoreRules(  )
-throw (uno::RuntimeException)
 {
     GCReferences_t::iterator aIt( m_aGCReferencesByService.begin() );
     while (aIt != m_aGCReferencesByService.end())
@@ -796,12 +810,11 @@ throw (uno::RuntimeException)
 
 sal_Bool SAL_CALL GrammarCheckingIterator::isProofreading(
     const uno::Reference< uno::XInterface >& xDoc )
-throw (uno::RuntimeException)
 {
     // ---- THREAD SAFE START ----
     ::osl::Guard< ::osl::Mutex > aGuard( MyMutex::get() );
 
-    sal_Bool bRes = sal_False;
+    bool bRes = false;
 
     uno::Reference< lang::XComponent > xComponent( xDoc, uno::UNO_QUERY );
     if (xComponent.is())
@@ -817,8 +830,8 @@ throw (uno::RuntimeException)
             OUString aDocId = aIt->second;
             if (!m_aCurCheckedDocId.isEmpty() && m_aCurCheckedDocId == aDocId)
             {
-                // an entry for that document was dequed and is currently being checked.
-                bRes = sal_True;
+                // an entry for that document was dequeued and is currently being checked.
+                bRes = true;
             }
             else
             {
@@ -829,7 +842,7 @@ throw (uno::RuntimeException)
                 for (sal_Int32 i = 0; i < nSize && !bRes; ++i)
                 {
                     if (aDocId == m_aFPEntriesQueue[i].m_aDocId)
-                        bRes = sal_True;
+                        bRes = true;
                 }
             }
         }
@@ -842,7 +855,6 @@ throw (uno::RuntimeException)
 
 void SAL_CALL GrammarCheckingIterator::processLinguServiceEvent(
     const linguistic2::LinguServiceEvent& rLngSvcEvent )
-throw (uno::RuntimeException)
 {
     if (rLngSvcEvent.nEvent == linguistic2::LinguServiceEventFlags::PROOFREAD_AGAIN)
     {
@@ -860,10 +872,8 @@ throw (uno::RuntimeException)
         }
         catch (const ::uno::Exception &rE)
         {
-             (void) rE;
-             // ignore
-             DBG_WARNING1("processLinguServiceEvent: exception:\n%s",
-                 OUStringToOString(rE.Message, RTL_TEXTENCODING_UTF8).getStr());
+            // ignore
+            SAL_WARN("linguistic", "processLinguServiceEvent: exception: " << rE);
         }
     }
 }
@@ -871,32 +881,29 @@ throw (uno::RuntimeException)
 
 sal_Bool SAL_CALL GrammarCheckingIterator::addLinguServiceEventListener(
     const uno::Reference< linguistic2::XLinguServiceEventListener >& xListener )
-throw (uno::RuntimeException)
 {
     if (xListener.is())
     {
         m_aNotifyListeners.addInterface( xListener );
     }
-    return sal_True;
+    return true;
 }
 
 
 sal_Bool SAL_CALL GrammarCheckingIterator::removeLinguServiceEventListener(
     const uno::Reference< linguistic2::XLinguServiceEventListener >& xListener )
-throw (uno::RuntimeException)
 {
     if (xListener.is())
     {
         m_aNotifyListeners.removeInterface( xListener );
     }
-    return sal_True;
+    return true;
 }
 
 
 void SAL_CALL GrammarCheckingIterator::dispose()
-throw (uno::RuntimeException)
 {
-    lang::EventObject aEvt( (linguistic2::XProofreadingIterator *) this );
+    lang::EventObject aEvt( static_cast<linguistic2::XProofreadingIterator *>(this) );
     m_aEventListeners.disposeAndClear( aEvt );
 
     TerminateThread();
@@ -905,7 +912,7 @@ throw (uno::RuntimeException)
     {
         ::osl::Guard< ::osl::Mutex > aGuard( MyMutex::get() );
 
-        // releaase all UNO references
+        // release all UNO references
 
         m_xBreakIterator.clear();
 
@@ -923,7 +930,6 @@ throw (uno::RuntimeException)
 
 void SAL_CALL GrammarCheckingIterator::addEventListener(
     const uno::Reference< lang::XEventListener >& xListener )
-throw (uno::RuntimeException)
 {
     if (xListener.is())
     {
@@ -934,7 +940,6 @@ throw (uno::RuntimeException)
 
 void SAL_CALL GrammarCheckingIterator::removeEventListener(
     const uno::Reference< lang::XEventListener >& xListener )
-throw (uno::RuntimeException)
 {
     if (xListener.is())
     {
@@ -944,7 +949,6 @@ throw (uno::RuntimeException)
 
 
 void SAL_CALL GrammarCheckingIterator::disposing( const lang::EventObject &rSource )
-throw (uno::RuntimeException)
 {
     // if the component (document) is disposing release all references
     //!! There is no need to remove entries from the queue that are from this document
@@ -965,7 +969,7 @@ throw (uno::RuntimeException)
 }
 
 
-uno::Reference< util::XChangesBatch > GrammarCheckingIterator::GetUpdateAccess() const
+uno::Reference< util::XChangesBatch > const & GrammarCheckingIterator::GetUpdateAccess() const
 {
     if (!m_xUpdateAccess.is())
     {
@@ -979,10 +983,10 @@ uno::Reference< util::XChangesBatch > GrammarCheckingIterator::GetUpdateAccess()
             // get configuration update access
             beans::PropertyValue aValue;
             aValue.Name  = "nodepath";
-            aValue.Value = uno::makeAny( OUString("org.openoffice.Office.Linguistic/ServiceManager") );
+            aValue.Value <<= OUString("org.openoffice.Office.Linguistic/ServiceManager");
             uno::Sequence< uno::Any > aProps(1);
             aProps[0] <<= aValue;
-            m_xUpdateAccess = uno::Reference< util::XChangesBatch >(
+            m_xUpdateAccess.set(
                     xConfigurationProvider->createInstanceWithArguments(
                         "com.sun.star.configuration.ConfigurationUpdateAccess", aProps ),
                         uno::UNO_QUERY_THROW );
@@ -1019,19 +1023,19 @@ void GrammarCheckingIterator::GetConfiguredGCSvcs_Impl()
                 {
                     // only the first entry is used, there should be only one grammar checker per language
                     const OUString aImplName( aImplNames[0] );
-                    const LanguageType nLang = LanguageTag::convertToLanguageTypeWithFallback( pElementNames[i] );
+                    const LanguageType nLang = LanguageTag::convertToLanguageType( pElementNames[i] );
                     aTmpGCImplNamesByLang[ nLang ] = aImplName;
                 }
             }
             else
             {
-                DBG_ASSERT( 0, "failed to get aImplNames. Wrong type?" );
+                SAL_WARN( "linguistic", "failed to get aImplNames. Wrong type?" );
             }
         }
     }
     catch (uno::Exception &)
     {
-        DBG_ASSERT( 0, "exception caught. Failed to get configured services" );
+        SAL_WARN( "linguistic", "exception caught. Failed to get configured services" );
     }
 
     {
@@ -1043,23 +1047,20 @@ void GrammarCheckingIterator::GetConfiguredGCSvcs_Impl()
 }
 
 
-
-
 sal_Bool SAL_CALL GrammarCheckingIterator::supportsService(
     const OUString & rServiceName )
-throw(uno::RuntimeException)
 {
     return cppu::supportsService(this, rServiceName);
 }
 
 
-OUString SAL_CALL GrammarCheckingIterator::getImplementationName(  ) throw (uno::RuntimeException)
+OUString SAL_CALL GrammarCheckingIterator::getImplementationName(  )
 {
     return GrammarCheckingIterator_getImplementationName();
 }
 
 
-uno::Sequence< OUString > SAL_CALL GrammarCheckingIterator::getSupportedServiceNames(  ) throw (uno::RuntimeException)
+uno::Sequence< OUString > SAL_CALL GrammarCheckingIterator::getSupportedServiceNames(  )
 {
     return GrammarCheckingIterator_getSupportedServiceNames();
 }
@@ -1108,14 +1109,6 @@ uno::Sequence< OUString > GrammarCheckingIterator::GetServiceList(
 }
 
 
-LinguDispatcher::DspType GrammarCheckingIterator::GetDspType() const
-{
-    return DSP_GRAMMAR;
-}
-
-
-
-
 static OUString GrammarCheckingIterator_getImplementationName() throw()
 {
     return OUString( "com.sun.star.lingu2.ProofreadingIterator" );
@@ -1124,15 +1117,13 @@ static OUString GrammarCheckingIterator_getImplementationName() throw()
 
 static uno::Sequence< OUString > GrammarCheckingIterator_getSupportedServiceNames() throw()
 {
-    uno::Sequence< OUString > aSNS( 1 );
-    aSNS[0] = "com.sun.star.linguistic2.ProofreadingIterator";
+    uno::Sequence<OUString> aSNS { "com.sun.star.linguistic2.ProofreadingIterator" };
     return aSNS;
 }
 
-
+/// @throws uno::Exception
 static uno::Reference< uno::XInterface > SAL_CALL GrammarCheckingIterator_createInstance(
     const uno::Reference< lang::XMultiServiceFactory > & /*rxSMgr*/ )
-throw(uno::Exception)
 {
     return static_cast< ::cppu::OWeakObject * >(new GrammarCheckingIterator());
 }
@@ -1140,10 +1131,9 @@ throw(uno::Exception)
 
 void * SAL_CALL GrammarCheckingIterator_getFactory(
     const sal_Char *pImplName,
-    lang::XMultiServiceFactory *pServiceManager,
-    void * /*pRegistryKey*/ )
+    lang::XMultiServiceFactory *pServiceManager )
 {
-    void * pRet = 0;
+    void * pRet = nullptr;
     if ( GrammarCheckingIterator_getImplementationName().equalsAscii( pImplName ) )
     {
         uno::Reference< lang::XSingleServiceFactory > xFactory =
