@@ -59,9 +59,9 @@
  */
 
 #include "lwpfribframe.hxx"
-#include "xfilter/xfstylemanager.hxx"
-#include "lwpglobalmgr.hxx"
-#include "xfilter/xfchange.hxx"
+#include <xfilter/xfstylemanager.hxx>
+#include <lwpglobalmgr.hxx>
+#include <xfilter/xfchange.hxx>
 /**
  * @short:   Read frame frib
  */
@@ -115,7 +115,7 @@ void LwpFribFrame::RegisterStyle(LwpFoundry* pFoundry)
             else
             {
                 XFParaStyle* pParaStyle = new XFParaStyle;
-                *pParaStyle = *(pOldStyle);
+                *pParaStyle = *pOldStyle;
                 XFStyleManager* pXFStyleManager = LwpGlobalMgr::GetInstance()->GetXFStyleManager();
                 m_StyleName = pXFStyleManager->AddStyle(pParaStyle).m_pStyle->GetStyleName();
             }
@@ -228,7 +228,7 @@ void LwpFribRubyFrame::RegisterStyle(LwpFoundry* pFoundry)
  *  @descr:  convert Ruby frame
  *
  */
-void LwpFribRubyFrame::XFConvert(XFContentContainer* /*pCont*/)
+void LwpFribRubyFrame::XFConvert()
 {
     LwpRubyLayout* pLayout = GetLayout();
     if (pLayout)
