@@ -67,23 +67,25 @@
 #include "lwpsdwfileloader.hxx"
 #include "bento.hxx"
 
-#include "lwpglobalmgr.hxx"
-#include "xfilter/xfframe.hxx"
-#include "xfilter/xfimage.hxx"
-#include "xfilter/xfimagestyle.hxx"
-#include "xfilter/xfstylemanager.hxx"
-#include "xfilter/xfparagraph.hxx"
-#include "xfilter/xfannotation.hxx"
+#include <lwpglobalmgr.hxx>
+#include "lwpframelayout.hxx"
+
+#include <xfilter/xfframe.hxx>
+#include <xfilter/xfimage.hxx>
+#include <xfilter/xfimagestyle.hxx>
+#include <xfilter/xfstylemanager.hxx>
+#include <xfilter/xfparagraph.hxx>
+#include <xfilter/xfannotation.hxx>
 
 //For chart
-#include "string.h"
+#include <string.h>
 
 #include <osl/thread.h>
 
 #define EF_NONE 0x0000
 #define EF_ODMA 0x0002
 
-LwpGraphicObject::LwpGraphicObject(LwpObjectHeader &objHdr, LwpSvStream* pStrm)
+LwpGraphicObject::LwpGraphicObject(LwpObjectHeader const &objHdr, LwpSvStream* pStrm)
     : LwpGraphicOleObject(objHdr, pStrm)
     , m_nCachedBaseLine(0)
     , m_bIsLinked(0)
@@ -111,6 +113,14 @@ void LwpGraphicObject::Read()
     unsigned char *pServerContext = nullptr;
     if (nServerContextSize > 0)
     {
+        sal_uInt16 nMaxPossibleSize = m_pObjStrm->remainingSize();
+
+        if (nServerContextSize > nMaxPossibleSize)
+        {
+            SAL_WARN("lwp", "stream too short for claimed no of records");
+            nServerContextSize = nMaxPossibleSize;
+        }
+
         pServerContext = new unsigned char[nServerContextSize];
         m_pObjStrm->QuickRead(pServerContext, static_cast<sal_uInt16>(nServerContextSize));
         if (nServerContextSize > 44)
@@ -150,6 +160,14 @@ void LwpGraphicObject::Read()
         sal_uInt32 nFilterContextSize = m_pObjStrm->QuickReaduInt32();
         if (nFilterContextSize > 0)
         {
+            sal_uInt16 nMaxPossibleSize = m_pObjStrm->remainingSize();
+
+            if (nFilterContextSize > nMaxPossibleSize)
+            {
+                SAL_WARN("lwp", "stream too short for claimed no of records");
+                nFilterContextSize = nMaxPossibleSize;
+            }
+
             pFilterContext = new unsigned char[nFilterContextSize];
             m_pObjStrm->QuickRead(pFilterContext, static_cast<sal_uInt16>(nFilterContextSize));
         }
@@ -181,17 +199,13 @@ void LwpGraphicObject::Read()
         m_WatermarkName = m_pObjStrm->QuickReadStringPtr();
     }
 
-    if (pServerContext != nullptr)
-        delete[] pServerContext;
-
-    if (pFilterContext != nullptr)
-        delete[] pFilterContext;
-
+    delete[] pServerContext;
+    delete[] pFilterContext;
 }
 
 void LwpGraphicObject::XFConvert (XFContentContainer* pCont)
 {
-    if ((m_sServerContextFormat[1]=='s'&&m_sServerContextFormat[2]=='d'&&m_sServerContextFormat[3]=='w'))
+    if (m_sServerContextFormat[1]=='s'&&m_sServerContextFormat[2]=='d'&&m_sServerContextFormat[3]=='w')
     {
         std::vector< rtl::Reference<XFFrame> >::iterator iter;
         for (iter = m_vXFDrawObjects.begin(); iter != m_vXFDrawObjects.end(); ++iter)
@@ -199,7 +213,7 @@ void LwpGraphicObject::XFConvert (XFContentContainer* pCont)
             pCont->Add(iter->get());
         }
     }
-    else if (this->IsGrafFormatValid() && !m_vXFDrawObjects.empty())
+    else if (IsGrafFormatValid() && !m_vXFDrawObjects.empty())
     {
         XFImage* pImage = static_cast<XFImage*>(m_vXFDrawObjects.front().get());
 
@@ -211,7 +225,7 @@ void LwpGraphicObject::XFConvert (XFContentContainer* pCont)
         else
         {
             sal_uInt8* pGrafData = nullptr;
-            sal_uInt32 nDataLen = this->GetRawGrafData(pGrafData);
+            sal_uInt32 nDataLen = GetRawGrafData(pGrafData);
 
             if (pGrafData)
             {
@@ -225,14 +239,12 @@ void LwpGraphicObject::XFConvert (XFContentContainer* pCont)
 
         pCont->Add(pImage);
     }
-    else if((m_sServerContextFormat[1]=='t'&&m_sServerContextFormat[2]=='e'&&m_sServerContextFormat[3]=='x'))
+    else if(m_sServerContextFormat[1]=='t'&&m_sServerContextFormat[2]=='e'&&m_sServerContextFormat[3]=='x')
     {
         XFConvertEquation(pCont);
     }
 }
 
-#include "lwpframelayout.hxx"
-
 /**
  * @descr   judge if the graphic format is what we can support: bmp, jpg, wmf, gif, tgf(tif). other format will be filtered to
  *  these formats by Word Pro.
@@ -240,20 +252,13 @@ void LwpGraphicObject::XFConvert (XFContentContainer* pCont)
  */
 bool LwpGraphicObject::IsGrafFormatValid()
 {
-    if ((m_sServerContextFormat[1]=='b'&& m_sServerContextFormat[2]=='m' && m_sServerContextFormat[3]=='p')
+    return (m_sServerContextFormat[1]=='b'&& m_sServerContextFormat[2]=='m' && m_sServerContextFormat[3]=='p')
     || (m_sServerContextFormat[1]=='j' && m_sServerContextFormat[2]=='p' && m_sServerContextFormat[3]=='g')
     || (m_sServerContextFormat[1]=='w' && m_sServerContextFormat[2]=='m' && m_sServerContextFormat[3]=='f')
     || (m_sServerContextFormat[1]=='g' && m_sServerContextFormat[2]=='i' && m_sServerContextFormat[3]=='f')
     || (m_sServerContextFormat[1]=='t' && m_sServerContextFormat[2]=='g' && m_sServerContextFormat[3]=='f')
     || (m_sServerContextFormat[1]=='p' && m_sServerContextFormat[2]=='n' && m_sServerContextFormat[3]=='g')
-    || (m_sServerContextFormat[1]=='e' && m_sServerContextFormat[2]=='p' && m_sServerContextFormat[3]=='s'))
-    {
-        return true;
-    }
-    else
-    {
-        return false;
-    }
+    || (m_sServerContextFormat[1]=='e' && m_sServerContextFormat[2]=='p' && m_sServerContextFormat[3]=='s');
 }
 
 /**
@@ -263,12 +268,12 @@ void LwpGraphicObject::RegisterStyle()
 {
     if (m_sServerContextFormat[1]=='s'&&m_sServerContextFormat[2]=='d'&&m_sServerContextFormat[3]=='w')
     {
-        this->CreateDrawObjects();
+        CreateDrawObjects();
     }
     // test codes for importing pictures
-    else if(this->IsGrafFormatValid())
+    else if(IsGrafFormatValid())
     {
-        this->CreateGrafObject();
+        CreateGrafObject();
     }
 
     if (m_sServerContextFormat[1]=='l'&&m_sServerContextFormat[2]=='c'&&m_sServerContextFormat[3]=='h')
@@ -301,8 +306,8 @@ void LwpGraphicObject::CreateDrawObjects()
 
     SvStream* pDrawObjStream = nullptr;
 
-    // get graphic object's bento objet name
-    LwpObjectID& rMyID = this->GetObjectID();
+    // get graphic object's bento object name
+    LwpObjectID& rMyID = GetObjectID();
     std::string aGrfObjName;
     GetBentoNamebyID(rMyID,  aGrfObjName);
 
@@ -321,7 +326,7 @@ void LwpGraphicObject::CreateDrawObjects()
 /**
  * @descr   create drawing object.
  */
-void LwpGraphicObject::GetBentoNamebyID(LwpObjectID& rMyID, std::string& rName)
+void LwpGraphicObject::GetBentoNamebyID(LwpObjectID const & rMyID, std::string& rName)
 {
     sal_uInt16 nHigh = rMyID.GetHigh();
     sal_uInt16 nLow = rMyID.GetLow();
@@ -353,8 +358,8 @@ sal_uInt32 LwpGraphicObject::GetRawGrafData(sal_uInt8*& pGrafData)
 
     SvStream* pGrafStream = nullptr;
 
-    // get graphic object's bento objet name
-    LwpObjectID& rMyID = this->GetObjectID();
+    // get graphic object's bento object name
+    LwpObjectID& rMyID = GetObjectID();
     std::string aGrfObjName;
     GetBentoNamebyID(rMyID,  aGrfObjName);
 
@@ -367,7 +372,7 @@ sal_uInt32 LwpGraphicObject::GetRawGrafData(sal_uInt8*& pGrafData)
         // read image data
         sal_uInt32 nDataLen = pMemGrafStream->GetEndOfData();
         pGrafData = new sal_uInt8 [nDataLen];
-        pMemGrafStream->Read(pGrafData, nDataLen);
+        pMemGrafStream->ReadBytes(pGrafData, nDataLen);
 
         delete pMemGrafStream;
         pMemGrafStream = nullptr;
@@ -396,8 +401,8 @@ sal_uInt32 LwpGraphicObject::GetGrafData(sal_uInt8*& pGrafData)
 
     SvStream* pGrafStream = nullptr;
 
-    // get graphic object's bento objet name
-    LwpObjectID& rMyID = this->GetObjectID();
+    // get graphic object's bento object name
+    LwpObjectID& rMyID = GetObjectID();
     std::string aGrfObjName;
     GetBentoNamebyID(rMyID,  aGrfObjName);
 
@@ -418,7 +423,7 @@ sal_uInt32 LwpGraphicObject::GetGrafData(sal_uInt8*& pGrafData)
         pGrafStream->Seek(nPos);
 
         pGrafData = new sal_uInt8 [nDataLen];
-        pMemGrafStream->Read(pGrafData, nDataLen);
+        pMemGrafStream->ReadBytes(pGrafData, nDataLen);
 
         delete pMemGrafStream;
         pMemGrafStream = nullptr;
@@ -598,7 +603,7 @@ void LwpGraphicObject::CreateGrafObject()
                         fBottom = fB;
                     }
                 };
-                LwpRect aFrameRect(-fOffsetX, (fDisFrameWidth-fOffsetX), (-fOffsetY), ((fDisFrameHeight-fOffsetY)));
+                LwpRect aFrameRect(-fOffsetX, (fDisFrameWidth-fOffsetX), (-fOffsetY), (fDisFrameHeight-fOffsetY));
                 LwpRect aImageRect(0, fSclGrafWidth, 0, fSclGrafHeight);
                 LwpRect aCropRect;
 
@@ -649,14 +654,14 @@ void LwpGraphicObject::CreateGrafObject()
     pImage->SetAnchorType(enumXFAnchorFrame);
 
     // set object name
-    LwpAtomHolder& rHolder = this->GetName();
+    LwpAtomHolder& rHolder = GetName();
     if ( !rHolder.str().isEmpty() )
     {
         pImage->SetName(rHolder.str());
     }
 
     // insert image object into array
-    m_vXFDrawObjects.push_back(pImage.get());
+    m_vXFDrawObjects.emplace_back(pImage.get());
 
 }
 
@@ -666,7 +671,7 @@ void LwpGraphicObject::CreateGrafObject()
 void LwpGraphicObject::XFConvertEquation(XFContentContainer * pCont)
 {
     sal_uInt8* pGrafData = nullptr;
-    sal_uInt32 nDataLen = this->GetGrafData(pGrafData);
+    sal_uInt32 nDataLen = GetGrafData(pGrafData);
     if(pGrafData)
     {
         //convert equation
@@ -680,25 +685,30 @@ void LwpGraphicObject::XFConvertEquation(XFContentContainer * pCont)
         //                                18,12,0,0,0,0,0.
         //                                 .TCIformat{2}
         //total head length = 45
+        bool bOk = true;
         sal_uInt32 nBegin = 45;
-        sal_uInt32 nEnd = nDataLen -1;
+        sal_uInt32 nEnd = 0;
+        if (nDataLen >= 1)
+            nEnd = nDataLen - 1;
+        else
+            bOk = false;
 
-        if(pGrafData[nEnd] == '$' && pGrafData[nEnd-1]!= '\\')
+        if (bOk && pGrafData[nEnd] == '$' && nEnd > 0 && pGrafData[nEnd-1] != '\\')
         {
             //equation body is contained by '$';
             nBegin++;
             nEnd--;
         }
 
-        if(nEnd >= nBegin)
+        bOk &= nEnd >= nBegin;
+        if (bOk)
         {
-            sal_uInt8* pEquData = new sal_uInt8[nEnd - nBegin + 1];
+            std::unique_ptr<sal_uInt8[]> pEquData( new sal_uInt8[nEnd - nBegin + 1] );
             for(sal_uInt32 nIndex = 0; nIndex < nEnd - nBegin +1 ; nIndex++)
             {
                 pEquData[nIndex] = pGrafData[nBegin + nIndex];
             }
-            pXFNotePara->Add(OUString(reinterpret_cast<char*>(pEquData), (nEnd - nBegin + 1), osl_getThreadTextEncoding()));
-            delete [] pEquData;
+            pXFNotePara->Add(OUString(reinterpret_cast<char*>(pEquData.get()), (nEnd - nBegin + 1), osl_getThreadTextEncoding()));
         }
         pXFNote->Add(pXFNotePara);
 
