@@ -57,29 +57,24 @@
  * @file
  *  For LWP filter architecture prototype
  ************************************************************************/
-/*************************************************************************
- * Change History
- Jan 2005           Created
- ************************************************************************/
 
-#include "lwpobjid.hxx"
-#include "lwpfilehdr.hxx"
-#include "lwpobjfactory.hxx"
-#include "lwpglobalmgr.hxx"
+#include <lwpobjid.hxx>
+#include <lwpfilehdr.hxx>
+#include <lwpobjfactory.hxx>
+#include <lwpglobalmgr.hxx>
 
-LwpObjectID::LwpObjectID(sal_uInt32 low, sal_uInt16 high)
-    :m_nLow(low), m_nHigh(high), m_nIndex(0), m_bIsCompressed(sal_False)
+LwpObjectID::LwpObjectID()
+    :m_nLow(0), m_nHigh(0), m_nIndex(0), m_bIsCompressed(false)
 {
 }
 /**
  * @descr       Read object id with format: low(4bytes)+high(2bytes) from stream
  *          for LWP7 record
 */
-sal_uInt32 LwpObjectID::Read(LwpSvStream *pStrm)
+void LwpObjectID::Read(LwpSvStream *pStrm)
 {
-    *pStrm >> m_nLow;
-    *pStrm >> m_nHigh;
-    return DiskSize();
+    pStrm->ReadUInt32( m_nLow );
+    pStrm->ReadUInt16( m_nHigh );
 }
 /**
  * @descr       Read object id with format: low(4bytes)+high(2bytes) from object stream
@@ -95,32 +90,33 @@ sal_uInt32 LwpObjectID::Read(LwpObjectStream *pObj)
  *          if index>0, lowid is get from time table per the index
 *           else    index+lowid+highid
 */
-sal_uInt32 LwpObjectID::ReadIndexed(LwpSvStream *pStrm)
+void LwpObjectID::ReadIndexed(LwpSvStream *pStrm)
 {
 //note the m_nLow store the index instead of time from the timetable as in LWP
-    m_bIsCompressed = sal_False;
+    m_bIsCompressed = false;
     if( LwpFileHeader::m_nFileRevision < 0x000B)
     {
-        return Read(pStrm);
+        Read(pStrm);
+        return;
     }
 
-    *pStrm >> m_nIndex;
+    pStrm->ReadUInt8( m_nIndex );
 
     if (m_nIndex)
     {
-        m_bIsCompressed = sal_True;
+        m_bIsCompressed = true;
         //m_nLow = index;       //note the m_nLow stores the index instead of the actual time id
         LwpGlobalMgr* pGlobal = LwpGlobalMgr::GetInstance();
         LwpObjectFactory* pFactory = pGlobal->GetLwpObjFactory();
-        LwpIndexManager* pIdxMgr = pFactory->GetIndexManager();
-        m_nLow =  pIdxMgr->GetObjTime( (sal_uInt16)m_nIndex);
+        LwpIndexManager& rIdxMgr = pFactory->GetIndexManager();
+        m_nLow = rIdxMgr.GetObjTime( (sal_uInt16)m_nIndex);
     }
     else
     {
-        *pStrm >> m_nLow;
+        pStrm->ReadUInt32( m_nLow );
     }
-    *pStrm >> m_nHigh;
-    return DiskSizeIndexed();
+    pStrm->ReadUInt16( m_nHigh );
+    DiskSizeIndexed();
 }
 
 /**
@@ -130,7 +126,7 @@ sal_uInt32 LwpObjectID::ReadIndexed(LwpSvStream *pStrm)
 */
 sal_uInt32 LwpObjectID::ReadIndexed(LwpObjectStream *pStrm)
 {
-    m_bIsCompressed = sal_False;
+    m_bIsCompressed = false;
     if(LwpFileHeader::m_nFileRevision < 0x000B)
     {
         return Read(pStrm);
@@ -139,12 +135,12 @@ sal_uInt32 LwpObjectID::ReadIndexed(LwpObjectStream *pStrm)
     m_nIndex = pStrm->QuickReaduInt8();
     if (m_nIndex)
     {
-        m_bIsCompressed = sal_True;
+        m_bIsCompressed = true;
         //m_nLow = index;       //note the m_nLow stores the index instead of the actual time id
         LwpGlobalMgr* pGlobal = LwpGlobalMgr::GetInstance();
         LwpObjectFactory* pFactory = pGlobal->GetLwpObjFactory();
-        LwpIndexManager* pIdxMgr = pFactory->GetIndexManager();
-        m_nLow = pIdxMgr->GetObjTime( (sal_uInt16)m_nIndex);
+        LwpIndexManager& rIdxMgr = pFactory->GetIndexManager();
+        m_nLow = rIdxMgr.GetObjTime( (sal_uInt16)m_nIndex);
     }
     else
         m_nLow = pStrm->QuickReaduInt32();
@@ -157,21 +153,19 @@ sal_uInt32 LwpObjectID::ReadIndexed(LwpObjectStream *pStrm)
  *          else    lowid equals to the lowid of previous low id
  *              and high id = the high id of previous id + diff +1
 */
-sal_uInt32 LwpObjectID::ReadCompressed( LwpObjectStream* pObj, LwpObjectID &prev )
+void LwpObjectID::ReadCompressed( LwpObjectStream* pObj, LwpObjectID const &prev )
 {
     sal_uInt8 diff = pObj->QuickReaduInt8();
-    sal_uInt32 len=1;
 
     if (diff == 255)
     {
-        len += Read(pObj);
+        Read(pObj);
     }
     else
     {
         m_nLow = prev.GetLow();
         m_nHigh = prev.GetHigh() + diff +1;
     }
-    return len;
 }
 /**
  * @descr       return the size of indexed object id
@@ -182,33 +176,26 @@ sal_uInt32 LwpObjectID::DiskSizeIndexed() const
         + ((m_nIndex != 0) ? 0 : sizeof(m_nLow))
         + sizeof(m_nHigh);
 }
-/**
- * @descr       return the size of object id with format: low(4bytes)+high(2bytes)
-*/
-sal_uInt32 LwpObjectID::DiskSize() const
-{
-    return sizeof(m_nLow) + sizeof(m_nHigh);
-}
 /**
  * @descr       get object from object factory per the object id
 */
-LwpObject* LwpObjectID::obj(VO_TYPE tag) const
+rtl::Reference<LwpObject> LwpObjectID::obj(VO_TYPE tag) const
 {
+    if (IsNull())
+    {
+        return nullptr;
+    }
     LwpGlobalMgr* pGlobal = LwpGlobalMgr::GetInstance();
     LwpObjectFactory* pObjMgr = pGlobal->GetLwpObjFactory();
-    if(IsNull())
-    {
-        return NULL;
-    }
-    LwpObject* pObj = pObjMgr->QueryObject(*this);
-    if( tag!=VO_INVALID &&  (pObj) )
+    rtl::Reference<LwpObject> pObj = pObjMgr->QueryObject(*this);
+    if( tag!=VO_INVALID &&  (pObj.is()) )
     {
         if(static_cast<sal_uInt32>(tag) != pObj->GetTag())
         {
-            pObj=NULL;
+            pObj.clear();
         }
     }
-    return(pObj);
+    return pObj;
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
