@@ -63,18 +63,18 @@
 #include "lwppagehint.hxx"
 #include "lwpdivinfo.hxx"
 #include "lwpstory.hxx"
-#include "xfilter/xfstylemanager.hxx"
-#include "xfilter/xfmasterpage.hxx"
-#include "xfilter/xfcontentcontainer.hxx"
-#include "xfilter/xfheader.hxx"
-#include "xfilter/xfheaderstyle.hxx"
-#include "xfilter/xffooterstyle.hxx"
-#include "xfilter/xffooter.hxx"
+#include <xfilter/xfstylemanager.hxx>
+#include <xfilter/xfmasterpage.hxx>
+#include <xfilter/xfcontentcontainer.hxx>
+#include <xfilter/xfheader.hxx>
+#include <xfilter/xfheaderstyle.hxx>
+#include <xfilter/xffooterstyle.hxx>
+#include <xfilter/xffooter.hxx>
 #include <sfx2/printer.hxx>
-#include "lwpchangemgr.hxx"
-#include "lwpglobalmgr.hxx"
+#include <lwpchangemgr.hxx>
+#include <lwpglobalmgr.hxx>
 
-LwpPageLayout::LwpPageLayout(LwpObjectHeader &objHdr, LwpSvStream* pStrm)
+LwpPageLayout::LwpPageLayout(LwpObjectHeader const &objHdr, LwpSvStream* pStrm)
     : LwpLayout(objHdr, pStrm)
     , m_nPrinterBin(0)
     , m_nBdroffset(0)
@@ -422,7 +422,7 @@ bool LwpPageLayout::HasColumns()
 * @descr:   Whether has filler page text in current page layout
 *
 */
-bool LwpPageLayout::HasFillerPageText(LwpFoundry* pFoundry)
+bool LwpPageLayout::HasFillerPageText(LwpFoundry const * pFoundry)
 {
     if(!pFoundry) return false;
 
@@ -495,7 +495,13 @@ LwpHeaderLayout* LwpPageLayout::GetHeaderLayout()
     {
         if (xLay->GetLayoutType() == LWP_HEADER_LAYOUT)
             return dynamic_cast<LwpHeaderLayout*>(xLay.get());
-        xLay.set(dynamic_cast<LwpVirtualLayout*>(xLay->GetNext().obj().get()));
+        rtl::Reference<LwpVirtualLayout> xNext(dynamic_cast<LwpVirtualLayout*>(xLay->GetNext().obj().get()));
+        if (xNext == xLay)
+        {
+            SAL_WARN("lwp", "loop in layout");
+            break;
+        }
+        xLay = xNext;
     }
     return nullptr;
 }
@@ -507,7 +513,13 @@ LwpFooterLayout* LwpPageLayout::GetFooterLayout()
     {
         if (xLay->GetLayoutType() == LWP_FOOTER_LAYOUT)
             return dynamic_cast<LwpFooterLayout*>(xLay.get());
-        xLay.set(dynamic_cast<LwpVirtualLayout*>(xLay->GetNext().obj().get()));
+        rtl::Reference<LwpVirtualLayout> xNext(dynamic_cast<LwpVirtualLayout*>(xLay->GetNext().obj().get()));
+        if (xNext == xLay)
+        {
+            SAL_WARN("lwp", "loop in layout");
+            break;
+        }
+        xLay = xNext;
     }
     return nullptr;
 }
@@ -715,7 +727,7 @@ LwpPara* LwpPageLayout::GetPagePosition()
 
     return nullptr;
 }
-LwpHeaderLayout::LwpHeaderLayout( LwpObjectHeader &objHdr, LwpSvStream* pStrm )
+LwpHeaderLayout::LwpHeaderLayout( LwpObjectHeader const &objHdr, LwpSvStream* pStrm )
     : LwpPlacableLayout(objHdr, pStrm)
     , m_nBorderOffset(0)
 {
@@ -741,7 +753,7 @@ void LwpHeaderLayout::RegisterStyle(XFPageMaster* pm1)
     std::unique_ptr<XFHeaderStyle> xHeaderStyle(new XFHeaderStyle);
 
     //Modify page top margin
-    //page top marging: from top of header to the top edge
+    //page top margin: from top of header to the top edge
     double top = GetMarginsValue(MARGIN_TOP);
     pm1->SetMargins(-1, -1, top, -1);
 
@@ -879,7 +891,7 @@ void LwpHeaderLayout::RegisterStyle(XFMasterPage* mp1)
     mp1->SetHeader(xHeader);
 }
 
-LwpFooterLayout::LwpFooterLayout( LwpObjectHeader &objHdr, LwpSvStream* pStrm )
+LwpFooterLayout::LwpFooterLayout( LwpObjectHeader const &objHdr, LwpSvStream* pStrm )
     : LwpPlacableLayout( objHdr, pStrm )
     , m_nBorderOffset(0)
 {
