@@ -58,22 +58,22 @@
 
 #include "lwpsdwgrouploaderv0102.hxx"
 #include "lwpdrawobj.hxx"
-#include "lwptools.hxx"
+#include <lwptools.hxx>
 #include "lwpcharsetmgr.hxx"
 #include "lwpgrfobj.hxx"
 #include "lwpframelayout.hxx"
 
-#include "xfilter/xfcolor.hxx"
-#include "xfilter/xfdrawline.hxx"
-#include "xfilter/xfdrawpath.hxx"
-#include "xfilter/xfdrawpolyline.hxx"
-#include "xfilter/xfdrawrect.hxx"
-#include "xfilter/xfdrawpolygon.hxx"
-#include "xfilter/xfdrawgroup.hxx"
-#include "xfilter/xfdrawstyle.hxx"
-#include "xfilter/xfdrawlinestyle.hxx"
-#include "xfilter/xfparagraph.hxx"
-#include "xfilter/xfstylemanager.hxx"
+#include <xfilter/xfcolor.hxx>
+#include <xfilter/xfdrawline.hxx>
+#include <xfilter/xfdrawpath.hxx>
+#include <xfilter/xfdrawpolyline.hxx>
+#include <xfilter/xfdrawrect.hxx>
+#include <xfilter/xfdrawpolygon.hxx>
+#include <xfilter/xfdrawgroup.hxx>
+#include <xfilter/xfdrawstyle.hxx>
+#include <xfilter/xfdrawlinestyle.hxx>
+#include <xfilter/xfparagraph.hxx>
+#include <xfilter/xfstylemanager.hxx>
 
 LwpSdwGroupLoaderV0102::LwpSdwGroupLoaderV0102(SvStream* pStream, LwpGraphicObject* pGraphicObj)
     : m_pStream(pStream)
@@ -98,7 +98,7 @@ void LwpSdwGroupLoaderV0102::BeginDrawObjects(std::vector< rtl::Reference<XFFram
 
     //flag
     unsigned char BinSignature[2];
-    m_pStream->Read(BinSignature,2);
+    m_pStream->ReadBytes(BinSignature, 2);
     if (BinSignature[0] != 'S' || BinSignature[1] != 'M')
     {
         assert(false);
@@ -106,7 +106,7 @@ void LwpSdwGroupLoaderV0102::BeginDrawObjects(std::vector< rtl::Reference<XFFram
     }
     //version
     unsigned short nVersion;
-    m_pStream->Read(&nVersion,2);
+    m_pStream->ReadUInt16(nVersion);
     if (nVersion<0x0102)
     {
         assert(false);
@@ -115,16 +115,16 @@ void LwpSdwGroupLoaderV0102::BeginDrawObjects(std::vector< rtl::Reference<XFFram
     // topObj, botObj
     m_pStream->SeekRel(4);
     //record count
-    unsigned short nRecCount;
-    m_pStream->Read(&nRecCount,2);
+    unsigned short nRecCount(0);
+    m_pStream->ReadUInt16(nRecCount);
     // selCount
     m_pStream->SeekRel(2);
     //boundrect
-    unsigned short left,top,right,bottom;
-    m_pStream->Read(&left,2);
-    m_pStream->Read(&top,2);
-    m_pStream->Read(&right,2);
-    m_pStream->Read(&bottom,2);
+    unsigned short left(0),top(0),right(0),bottom(0);
+    m_pStream->ReadUInt16(left);
+    m_pStream->ReadUInt16(top);
+    m_pStream->ReadUInt16(right);
+    m_pStream->ReadUInt16(bottom);
     // fileSize
     m_pStream->SeekRel(2);
 
@@ -197,7 +197,7 @@ void LwpSdwGroupLoaderV0102::BeginDrawObjects(std::vector< rtl::Reference<XFFram
             // placement: centered
             if (xMyFrameLayout->GetScaleCenter())
             {
-                Rectangle aBoundRect(static_cast<long>(left*m_aTransformData.fScaleX + fLeftMargin),
+                tools::Rectangle aBoundRect(static_cast<long>(left*m_aTransformData.fScaleX + fLeftMargin),
                     static_cast<long>(top    * m_aTransformData.fScaleY + fTopMargin),
                     static_cast<long>(right  * m_aTransformData.fScaleX),
                     static_cast<long>(bottom * m_aTransformData.fScaleY));
@@ -222,10 +222,16 @@ void LwpSdwGroupLoaderV0102::BeginDrawObjects(std::vector< rtl::Reference<XFFram
         }
     }
 
+    if (nRecCount > m_pStream->remainingSize())
+    {
+        SAL_WARN("lwp", "stream too short for claimed no of records");
+        nRecCount = m_pStream->remainingSize();
+    }
+
     //load draw object
     for (unsigned short i = 0; i < nRecCount; i++)
     {
-        XFFrame* pXFDrawObj = this->CreateDrawObject();
+        XFFrame* pXFDrawObj = CreateDrawObject();
 
         if (pXFDrawObj)
         {
@@ -243,7 +249,7 @@ XFDrawGroup* LwpSdwGroupLoaderV0102::CreateDrawGroupObject()
 {
     //flag
     unsigned char BinSignature[2];
-    m_pStream->Read(BinSignature,2);
+    m_pStream->ReadBytes(BinSignature, 2);
     if (BinSignature[0] != 'S' || BinSignature[1] != 'M')
     {
         assert(false);
@@ -251,7 +257,7 @@ XFDrawGroup* LwpSdwGroupLoaderV0102::CreateDrawGroupObject()
     }
     //version
     unsigned short nVersion;
-    m_pStream->Read(&nVersion,2);
+    m_pStream->ReadUInt16(nVersion);
     if (nVersion<0x0102)
     {
         assert(false);
@@ -260,25 +266,31 @@ XFDrawGroup* LwpSdwGroupLoaderV0102::CreateDrawGroupObject()
     // topObj, botObj
     m_pStream->SeekRel(4);
     //record count
-    unsigned short nRecCount;
-    m_pStream->Read(&nRecCount,2);
+    unsigned short nRecCount(0);
+    m_pStream->ReadUInt16(nRecCount);
     // selCount
     m_pStream->SeekRel(2);
     //boundrect
-    unsigned short left,top,right,bottom;
-    m_pStream->Read(&left,2);
-    m_pStream->Read(&top,2);
-    m_pStream->Read(&right,2);
-    m_pStream->Read(&bottom,2);
+    unsigned short left(0),top(0),right(0),bottom(0);
+    m_pStream->ReadUInt16(left);
+    m_pStream->ReadUInt16(top);
+    m_pStream->ReadUInt16(right);
+    m_pStream->ReadUInt16(bottom);
     // fileSize
     m_pStream->SeekRel(2);
 
     XFDrawGroup* pXFDrawGroup = new XFDrawGroup();
 
+    if (nRecCount > m_pStream->remainingSize())
+    {
+        SAL_WARN("lwp", "stream too short for claimed no of records");
+        nRecCount = m_pStream->remainingSize();
+    }
+
     //load draw object
     for (unsigned short i = 0; i < nRecCount; i++)
     {
-        XFFrame* pXFDrawObj = this->CreateDrawObject();
+        XFFrame* pXFDrawObj = CreateDrawObject();
 
         if (pXFDrawObj)
         {
@@ -303,8 +315,8 @@ XFDrawGroup* LwpSdwGroupLoaderV0102::CreateDrawGroupObject()
 XFFrame* LwpSdwGroupLoaderV0102::CreateDrawObject()
 {
     //record type
-    unsigned char recType;
-    m_pStream->Read(&recType,1);
+    unsigned char recType(0);
+    m_pStream->ReadUChar(recType);
 
     LwpDrawObj* pDrawObj = nullptr;
     XFFrame* pRetObjct = nullptr;
@@ -369,7 +381,7 @@ XFFrame* LwpSdwGroupLoaderV0102::CreateDrawObject()
         // read out the object header
         pDrawObj = new LwpDrawGroup(m_pStream);
 
-        pRetObjct = this->CreateDrawGroupObject();
+        pRetObjct = CreateDrawGroupObject();
 
         // set anchor type
         pRetObjct->SetAnchorType(enumXFAnchorFrame);
