@@ -57,14 +57,11 @@
  * @file
  *  For LWP filter architecture prototype - table layouts
  */
-/*************************************************************************
- * Change History
- Mar 2005           Created
- ************************************************************************/
-#include "lwpglobalmgr.hxx"
+
+#include <lwpglobalmgr.hxx>
 #include "lwptablelayout.hxx"
-#include "lwpfoundry.hxx"
-#include "lwpobjfactory.hxx"
+#include <lwpfoundry.hxx>
+#include <lwpobjfactory.hxx>
 #include "lwpholder.hxx"
 #include "lwptable.hxx"
 #include "lwptblcell.hxx"
@@ -72,32 +69,29 @@
 #include "lwpdlvlist.hxx"
 #include "lwppara.hxx"
 
-#include "xfilter/xfstylemanager.hxx"
-#include "xfilter/xftablestyle.hxx"
-#include "xfilter/xftable.hxx"
-#include "xfilter/xfrow.hxx"
-#include "xfilter/xfrowstyle.hxx"
-#include "xfilter/xfcell.hxx"
-#include "xfilter/xfcellstyle.hxx"
-#include "xfilter/xfcolstyle.hxx"
-#include "xfilter/xfframestyle.hxx"
-#include "xfilter/xfframe.hxx"
-#include "xfilter/xffloatframe.hxx"
+#include <xfilter/xfstylemanager.hxx>
+#include <xfilter/xftablestyle.hxx>
+#include <xfilter/xftable.hxx>
+#include <xfilter/xfrow.hxx>
+#include <xfilter/xfrowstyle.hxx>
+#include <xfilter/xfcell.hxx>
+#include <xfilter/xfcellstyle.hxx>
+#include <xfilter/xfcolstyle.hxx>
+#include <xfilter/xfframestyle.hxx>
+#include <xfilter/xfframe.hxx>
+#include <xfilter/xffloatframe.hxx>
 #include "lwpframelayout.hxx"
-#include "xfilter/xfparastyle.hxx"
+#include <xfilter/xfparastyle.hxx>
+#include <memory>
 
-LwpSuperTableLayout::LwpSuperTableLayout(LwpObjectHeader &objHdr, LwpSvStream* pStrm)
+LwpSuperTableLayout::LwpSuperTableLayout(LwpObjectHeader const &objHdr, LwpSvStream* pStrm)
     : LwpPlacableLayout(objHdr, pStrm)
 {
-    m_pFrame = new LwpFrame(this);
+    m_pFrame.reset(new LwpFrame(this) );
 }
 
 LwpSuperTableLayout::~LwpSuperTableLayout()
 {
-    if(m_pFrame)
-    {
-        delete m_pFrame;
-    }
 }
 /**
  * @short    Read super table layout record
@@ -130,7 +124,7 @@ LwpTableLayout* LwpSuperTableLayout::GetTableLayout()
         rID = pLayout->GetPrevious();
     }
 
-    return NULL;
+    return nullptr;
 }
 /**
  * @short   Get effective heading table layout, the one just before table layout is the only one which is effective
@@ -155,7 +149,7 @@ LwpTableHeadingLayout* LwpSuperTableLayout::GetTableHeadingLayout()
         rID = pLayout->GetPrevious();
     }
 
-    return NULL;
+    return nullptr;
 }
 /**
  * @short   Register super table layout style
@@ -164,7 +158,7 @@ void LwpSuperTableLayout::RegisterNewStyle()
 {
     // if this layout is style of real table entry
     LwpTableLayout* pTableLayout = GetTableLayout();
-    if (pTableLayout != NULL)
+    if (pTableLayout != nullptr)
     {
         pTableLayout->SetFoundry(m_pFoundry);
         pTableLayout->RegisterStyle();
@@ -266,7 +260,7 @@ double LwpSuperTableLayout::GetTableWidth()
 void LwpSuperTableLayout::ApplyShadow(XFTableStyle *pTableStyle)
 {
     // use shadow property of supertable
-    boost::scoped_ptr<XFShadow> pXFShadow(GetXFShadow());
+    std::unique_ptr<XFShadow> pXFShadow(GetXFShadow());
     if(pXFShadow)
     {
         pTableStyle->SetShadow(pXFShadow->GetPosition(), pXFShadow->GetOffset(), pXFShadow->GetColor());
@@ -279,7 +273,7 @@ void LwpSuperTableLayout::ApplyShadow(XFTableStyle *pTableStyle)
  */
 void LwpSuperTableLayout::ApplyPatternFill(XFTableStyle* pTableStyle)
 {
-    XFBGImage* pXFBGImage = this->GetFillPattern();
+    XFBGImage* pXFBGImage = GetFillPattern();
     if (pXFBGImage)
     {
         pTableStyle->SetBackImage(pXFBGImage);
@@ -293,7 +287,7 @@ void LwpSuperTableLayout::ApplyPatternFill(XFTableStyle* pTableStyle)
  */
 void LwpSuperTableLayout::ApplyBackGround(XFTableStyle* pTableStyle)
 {
-    if (this->IsPatternFill())
+    if (IsPatternFill())
     {
         ApplyPatternFill(pTableStyle);
     }
@@ -383,25 +377,25 @@ void  LwpSuperTableLayout::XFConvertFrame(XFContentContainer* pCont, sal_Int32 n
 {
     if(m_pFrame)
     {
-        XFFrame* pXFFrame = NULL;
+        rtl::Reference<XFFrame> xXFFrame;
         if(nEnd < nStart)
         {
-            pXFFrame = new XFFrame();
+            xXFFrame.set(new XFFrame);
         }
         else
         {
-            pXFFrame = new XFFloatFrame(nStart, nEnd, bAll);
+            xXFFrame.set(new XFFloatFrame(nStart, nEnd, bAll));
         }
 
-        m_pFrame->Parse(pXFFrame, static_cast<sal_uInt16>(nStart));
+        m_pFrame->Parse(xXFFrame.get(), static_cast<sal_uInt16>(nStart));
         //parse table, and add table to frame
         LwpTableLayout * pTableLayout = GetTableLayout();
         if (pTableLayout)
         {
-            pTableLayout->XFConvert(pXFFrame);
+            pTableLayout->XFConvert(xXFFrame.get());
         }
         //add frame to the container
-        pCont ->Add(pXFFrame);
+        pCont->Add(xXFFrame.get());
     }
 
 }
@@ -412,17 +406,16 @@ void  LwpSuperTableLayout::XFConvertFrame(XFContentContainer* pCont, sal_Int32 n
  */
 void  LwpSuperTableLayout::RegisterFrameStyle()
 {
-    XFFrameStyle* pFrameStyle = new XFFrameStyle();
-    m_pFrame->RegisterStyle(pFrameStyle);
+    std::unique_ptr<XFFrameStyle> xFrameStyle(new XFFrameStyle);
+    m_pFrame->RegisterStyle(xFrameStyle);
 }
 
-LwpTableLayout::LwpTableLayout(LwpObjectHeader &objHdr, LwpSvStream* pStrm)
+LwpTableLayout::LwpTableLayout(LwpObjectHeader const &objHdr, LwpSvStream* pStrm)
     : LwpLayout(objHdr, pStrm)
     , m_nRows(0)
     , m_nCols(0)
-    , m_pDefaultCellLayout(NULL)
-    , m_pColumns(NULL)
-    , m_pXFTable(NULL)
+    , m_pDefaultCellLayout(nullptr)
+    , m_pColumns(nullptr)
 {
     m_CellsMap.clear();
 }
@@ -434,7 +427,7 @@ LwpTableLayout::~LwpTableLayout()
     if (m_pColumns)
     {
         delete [] m_pColumns;
-        m_pColumns = NULL;
+        m_pColumns = nullptr;
     }
 }
 
@@ -447,7 +440,7 @@ LwpTableLayout::~LwpTableLayout()
 LwpCellLayout * LwpTableLayout::GetCellByRowCol(sal_uInt16 nRow, sal_uInt16 nCol)
 {
     if (nRow >= m_nRows || nCol >= m_nCols)
-        return NULL;
+        return nullptr;
 
     return m_WordProCellsMap[static_cast<size_t>(nRow)*m_nCols + nCol];
 }
@@ -463,10 +456,7 @@ void LwpTableLayout::TraverseTable()
     sal_uInt32 nCount = m_nRows*m_nCols;
 
     // new cell map nRow*nCOl and initialize
-    for (sal_uInt32 iLoop = 0; iLoop < nCount; ++iLoop)
-    {
-        m_WordProCellsMap.push_back(GetDefaultCellLayout());
-    }
+    m_WordProCellsMap.insert(m_WordProCellsMap.end(), nCount, m_pDefaultCellLayout);
 
     // set value
     LwpObjectID& rRowID = GetChildHead();
@@ -495,7 +485,7 @@ LwpObjectID * LwpTableLayout::SearchCellStoryMap(sal_uInt16 nRow, sal_uInt16 nCo
 {
     if (nRow >= m_nRows || nCol >= m_nCols )
     {
-        return NULL;
+        return nullptr;
     }
 
     LwpCellLayout * pCell = GetCellByRowCol(nRow, nCol);
@@ -505,12 +495,12 @@ LwpObjectID * LwpTableLayout::SearchCellStoryMap(sal_uInt16 nRow, sal_uInt16 nCo
         // maybe default cell layout
         if (nRow != pCell->GetRowID() || nCol != pCell->GetColID())
         {
-            return NULL;
+            return nullptr;
         }
         return &pCell->GetContent();
     }
 
-    return NULL;
+    return nullptr;
 }
 
 /**
@@ -564,11 +554,11 @@ void LwpTableLayout::RegisterColumns()
     sal_uInt16 nCols = m_nCols;
 
     m_pColumns = new LwpColumnLayout *[nCols];
-    sal_Bool * pWidthCalculated = new sal_Bool[nCols];
+    std::unique_ptr<bool[]> pWidthCalculated( new bool[nCols] );
     for(sal_uInt16 i=0;i<nCols; i++)
     {
-        pWidthCalculated[i] = sal_False;
-        m_pColumns[i] = NULL;
+        pWidthCalculated[i] = false;
+        m_pColumns[i] = nullptr;
     }
 
     double dDefaultColumn = pTable->GetWidth();
@@ -585,13 +575,12 @@ void LwpTableLayout::RegisterColumns()
         auto nColId = pColumnLayout->GetColumnID();
         if (nColId >= nCols)
         {
-            delete [] pWidthCalculated;
             throw std::range_error("corrupt LwpTableLayout");
         }
         m_pColumns[nColId] = pColumnLayout;
         if (!pColumnLayout->IsJustifiable())
         {
-            pWidthCalculated[nColId] = sal_True;
+            pWidthCalculated[nColId] = true;
             dTableWidth -= pColumnLayout->GetWidth();
             nJustifiableColumn --;
         }
@@ -606,7 +595,7 @@ void LwpTableLayout::RegisterColumns()
         nJustifiableColumn ++;
         if (m_pColumns[nCols - 1])
         {
-            pWidthCalculated[nCols-1] = sal_False;
+            pWidthCalculated[nCols-1] = false;
             dTableWidth += m_pColumns[nCols-1]->GetWidth();
         }
         else
@@ -646,7 +635,6 @@ void LwpTableLayout::RegisterColumns()
             }
         }
     }
-    delete [] pWidthCalculated;
 }
 /**
  * @short    register all row styles
@@ -655,7 +643,7 @@ void LwpTableLayout::RegisterColumns()
 void LwpTableLayout::RegisterRows()
 {
     LwpTable * pTable = GetTable();
-    if (pTable == NULL)
+    if (pTable == nullptr)
     {
         assert(false);
         return;
@@ -699,15 +687,23 @@ void LwpTableLayout::RegisterStyle()
 
     // get table
     LwpTable * pTable = GetTable();
-    if (pTable == NULL)
+    if (pTable == nullptr)
     {
-        assert(false);
+        SAL_WARN("lwp", "missing table, early return");
         return;
     }
 
     // get row/column number of this table
     m_nRows = pTable->GetRow();
     m_nCols = pTable->GetColumn();
+    //http://www.danielsays.com/ss-gallery-win1x2x3x-lotus-word-pro-96.html
+    //tables with up to 255 rows and 8192 columns
+    //the row limit tallies with the casting of m_nCols to an unsigned char
+    //elsewhere
+    if (m_nRows > MAX_NUM_ROWS)
+        throw std::runtime_error("max legal row exceeded");
+    if (m_nCols > MAX_NUM_COLS)
+        throw std::runtime_error("max legal column exceeded");
 
     // get default cell layout of current table
     LwpObjectID& rID= pTable->GetDefaultCellStyle();
@@ -717,7 +713,7 @@ void LwpTableLayout::RegisterStyle()
     RegisterColumns();
 
     // register style of whole table
-    XFTableStyle * pTableStyle = new XFTableStyle();
+    std::unique_ptr<XFTableStyle> xTableStyle(new XFTableStyle);
 
     sal_uInt8 nType = pSuper->GetRelativeType();
     // If the table is not "with paragraph above" placement, create an frame style
@@ -726,24 +722,22 @@ void LwpTableLayout::RegisterStyle()
         && (!pSuper->GetContainerLayout().is() || !pSuper->GetContainerLayout()->IsCell()) )
     {
         //with para above
-//      pSuper->ApplyBackColor(pTableStyle);
-        pSuper->ApplyBackGround(pTableStyle);
-        pSuper->ApplyWatermark(pTableStyle);
-        pSuper->ApplyShadow(pTableStyle);
-        pSuper->ApplyAlignment(pTableStyle);
-        pTableStyle->SetWidth(pSuper->GetTableWidth());
+        pSuper->ApplyBackGround(xTableStyle.get());
+        pSuper->ApplyWatermark(xTableStyle.get());
+        pSuper->ApplyShadow(xTableStyle.get());
+        pSuper->ApplyAlignment(xTableStyle.get());
+        xTableStyle->SetWidth(pSuper->GetTableWidth());
     }
     else
     {
         pSuper->RegisterFrameStyle();
-        pTableStyle->SetAlign(enumXFAlignCenter);
-        pTableStyle->SetWidth(pSuper->GetTableWidth());
+        xTableStyle->SetAlign(enumXFAlignCenter);
+        xTableStyle->SetWidth(pSuper->GetTableWidth());
     }
     XFStyleManager* pXFStyleManager = LwpGlobalMgr::GetInstance()->GetXFStyleManager();
-    m_StyleName = pXFStyleManager->AddStyle(pTableStyle).m_pStyle->GetStyleName();
+    m_StyleName = pXFStyleManager->AddStyle(xTableStyle.release()).m_pStyle->GetStyleName();
 
-    //convert to OO table now and register row stle
-    // traverse
+    //convert to OO table now and register row style traverse
     TraverseTable();
 
     SplitConflictCells();
@@ -754,13 +748,10 @@ void LwpTableLayout::RegisterStyle()
     // Parse table
     ParseTable();
 
-    //Comment:The old code doesn't check if the LwpFoundry pointer is NULL,
-    //        So the NULL pointer cause sodc frozee. Add code to check the
-    //        the pointer.
-    //New Code
-    if( GetFoundry() && GetTable() )
-
-    PutCellVals( GetFoundry(),GetTable()->GetObjectID() );
+    // the old code doesn't check if the LwpFoundry pointer is NULL,
+    // so the NULL pointer cause sodc freeze. Add code to check the pointer.
+    if (GetFoundry() && GetTable())
+        PutCellVals(GetFoundry(), GetTable()->GetObjectID());
 }
 /**
  * @short   read table layout
@@ -769,11 +760,15 @@ void LwpTableLayout::RegisterStyle()
 void LwpTableLayout::ParseTable()
 {
     // get super table layout
-    LwpSuperTableLayout * pSuper = GetSuperTableLayout();
-    if(!pSuper)
+    LwpSuperTableLayout* pSuper = GetSuperTableLayout();
+    if (!pSuper)
     {
-        assert(false);
-        return;
+        throw std::runtime_error("missing super table");
+    }
+
+    if (m_pXFTable.get())
+    {
+        throw std::runtime_error("this table is already parsed");
     }
 
     // set name of object
@@ -819,7 +814,7 @@ void LwpTableLayout::Read()
     {
         assert(false);
     }
-    m_ColumnLayout.ReadIndexed(m_pObjStrm);
+    m_ColumnLayout.ReadIndexed(m_pObjStrm.get());
 
     m_pObjStrm->SkipExtra();
 }
@@ -832,7 +827,7 @@ void LwpTableLayout::Read()
 void LwpTableLayout::XFConvert(XFContentContainer* pCont)
 {
 
-    pCont->Add(m_pXFTable);
+    pCont->Add(m_pXFTable.get());
 }
 /**
  * @short   convert heading row
@@ -841,17 +836,17 @@ void LwpTableLayout::XFConvert(XFContentContainer* pCont)
  * @param  nEndRow - end heading row ID
  */
 sal_uInt16 LwpTableLayout::ConvertHeadingRow(
-        XFTable* pXFTable,sal_uInt16 nStartHeadRow,sal_uInt16 nEndHeadRow)
+        rtl::Reference<XFTable> const & pXFTable, sal_uInt16 nStartHeadRow, sal_uInt16 nEndHeadRow)
 {
     sal_uInt16 nContentRow;
     sal_uInt8 nCol = static_cast<sal_uInt8>(GetTable()->GetColumn());
-    XFTable* pTmpTable = new XFTable;
+    rtl::Reference<XFTable> pTmpTable( new XFTable );
     XFRow* pXFRow;
 
-    ConvertTable(pTmpTable,nStartHeadRow,nEndHeadRow,0,nCol);
+    ConvertTable(pTmpTable.get(),nStartHeadRow,nEndHeadRow,0,nCol);
 
     sal_uInt16 nRowNum = pTmpTable->GetRowCount();
-    sal_uInt8* CellMark = new sal_uInt8[nRowNum];
+    std::unique_ptr<sal_uInt8[]> CellMark( new sal_uInt8[nRowNum] );
 
     if (nRowNum == 1)
     {
@@ -863,11 +858,11 @@ sal_uInt16 LwpTableLayout::ConvertHeadingRow(
     else
     {
         sal_uInt8 nFirstColSpann = 1;
-        const bool bFindFlag = FindSplitColMark(pTmpTable,CellMark,nFirstColSpann);
+        const bool bFindFlag = FindSplitColMark(pTmpTable.get(),CellMark.get(),nFirstColSpann);
 
         if (bFindFlag)//split to 2 cells
         {
-            SplitRowToCells(pTmpTable,pXFTable,nFirstColSpann,CellMark);
+            SplitRowToCells(pTmpTable.get(),pXFTable,nFirstColSpann,CellMark.get());
             nContentRow = nEndHeadRow;
         }
         else//can not split,the first row will be the heading row,the rest will be content row
@@ -878,16 +873,13 @@ sal_uInt16 LwpTableLayout::ConvertHeadingRow(
             nContentRow = m_RowsMap[0]->GetCurMaxSpannedRows(0,nCol);
         }
     }
-    delete pTmpTable;
-    delete [] CellMark;
     return nContentRow;
 }
 
-void LwpTableLayout::SplitRowToCells(XFTable* pTmpTable,XFTable* pXFTable,
-        sal_uInt8 nFirstColSpann,sal_uInt8* pCellMark)
+void LwpTableLayout::SplitRowToCells(XFTable* pTmpTable, rtl::Reference<XFTable> const & pXFTable,
+        sal_uInt8 nFirstColSpann,const sal_uInt8* pCellMark)
 {
     sal_uInt16 i;
-    sal_uInt8 j;
     sal_uInt16 nRowNum = pTmpTable->GetRowCount();
     sal_uInt8 nCol = static_cast<sal_uInt8>(GetTable()->GetColumn());
 
@@ -920,50 +912,49 @@ void LwpTableLayout::SplitRowToCells(XFTable* pTmpTable,XFTable* pXFTable,
     }
     pXFRow->SetStyleName(pXFStyleManager->AddStyle(pRowStyle).m_pStyle->GetStyleName());
 
-    //construct headong row
-    XFCell* pXFCell1 = new XFCell;
-    XFCell* pXFCell2 = new XFCell;
+    //construct heading row
+    rtl::Reference<XFCell> xXFCell1(new XFCell);
+    rtl::Reference<XFCell> xXFCell2(new XFCell);
     XFTable* pSubTable1 = new XFTable;
     XFTable* pSubTable2 = new XFTable;
-    XFRow* pNewRow;
     XFRow* pOldRow;
-    XFCell* pNewCell;
+    rtl::Reference<XFCell> xNewCell;
 
     for (i=1;i<=nRowNum;i++)
     {
         pOldRow = pTmpTable->GetRow(i);
-        pNewRow = new XFRow;
-        pNewRow->SetStyleName(pOldRow->GetStyleName());
-        for (j=1;j<=pCellMark[i];j++)
+        rtl::Reference<XFRow> xNewRow(new XFRow);
+        xNewRow->SetStyleName(pOldRow->GetStyleName());
+        for (sal_uInt8 j=1;j<=pCellMark[i];j++)
         {
-            pNewCell = pOldRow->GetCell(j);
-            pNewRow->AddCell(pNewCell);
+            xNewCell = pOldRow->GetCell(j);
+            xNewRow->AddCell(xNewCell);
         }
-        pSubTable1->AddRow(pNewRow);
+        pSubTable1->AddRow(xNewRow);
     }
     ConvertColumn(pSubTable1,0,nFirstColSpann);//add column info
 
-    pXFCell1->Add(pSubTable1);
-    pXFCell1->SetColumnSpaned(nFirstColSpann);
-    pXFRow->AddCell(pXFCell1);
+    xXFCell1->Add(pSubTable1);
+    xXFCell1->SetColumnSpaned(nFirstColSpann);
+    pXFRow->AddCell(xXFCell1);
 
     for (i=1;i<=nRowNum;i++)
     {
         pOldRow = pTmpTable->GetRow(i);
-        pNewRow = new XFRow;
-        pNewRow->SetStyleName(pOldRow->GetStyleName());
-        for(j=pCellMark[i]+1;j<=pOldRow->GetCellCount();j++)
+        rtl::Reference<XFRow> xNewRow(new XFRow);
+        xNewRow->SetStyleName(pOldRow->GetStyleName());
+        for(sal_Int32 j=pCellMark[i]+1;j<=pOldRow->GetCellCount();j++)
         {
-            pNewCell = pOldRow->GetCell(j);
-            pNewRow->AddCell(pNewCell);
+            xNewCell = pOldRow->GetCell(j);
+            xNewRow->AddCell(xNewCell);
         }
-        pSubTable2->AddRow(pNewRow);
+        pSubTable2->AddRow(xNewRow);
 
     }
     ConvertColumn(pSubTable2,nFirstColSpann,nCol);//add column info
-    pXFCell2->Add(pSubTable2);
-    pXFCell2->SetColumnSpaned(nCol-nFirstColSpann);
-    pXFRow->AddCell(pXFCell2);
+    xXFCell2->Add(pSubTable2);
+    xXFCell2->SetColumnSpaned(nCol-nFirstColSpann);
+    pXFRow->AddCell(xXFCell2);
 
     pXFTable->AddHeaderRow(pXFRow);
 
@@ -971,7 +962,7 @@ void LwpTableLayout::SplitRowToCells(XFTable* pTmpTable,XFTable* pXFTable,
     for (i=1;i<=nRowNum;i++)
     {
         pOldRow = pTmpTable->GetRow(i);
-        for(j=1;j<=pOldRow->GetCellCount();j++)
+        for(sal_Int32 j=1;j<=pOldRow->GetCellCount();j++)
             pOldRow->RemoveCell(j);
         pTmpTable->RemoveRow(i);
     }
@@ -987,7 +978,6 @@ bool  LwpTableLayout::FindSplitColMark(XFTable* pXFTable, sal_uInt8* pCellMark,
 {
     sal_uInt16 nRowNum = pXFTable->GetRowCount();
     sal_uInt8 nColNum = static_cast<sal_uInt8>(pXFTable->GetColumnCount());
-    sal_uInt8 nCellMark=0;
     sal_uInt8 nCount;
     sal_uInt8 nColSpan;
     bool bFindFlag = false;
@@ -996,14 +986,13 @@ bool  LwpTableLayout::FindSplitColMark(XFTable* pXFTable, sal_uInt8* pCellMark,
     for(sal_uInt8 i=1;i<=nColNum;i++)
     {
         sal_uInt16 nRowLoop;
-        sal_uInt8 nCellLoop;
 
         //find current max column span
         nMaxColSpan = 1;
         for (nRowLoop=1;nRowLoop<=nRowNum;nRowLoop++)
         {
             nColSpan = 0;
-            for(nCellLoop=1; nCellLoop<i+1; nCellLoop++)
+            for(sal_uInt8 nCellLoop=1; nCellLoop<i+1; nCellLoop++)
             {
                 pTmpRow = pXFTable->GetRow(nRowLoop);
                 XFCell* pCell = pTmpRow->GetCell(nCellLoop);
@@ -1022,8 +1011,8 @@ bool  LwpTableLayout::FindSplitColMark(XFTable* pXFTable, sal_uInt8* pCellMark,
         {
             pTmpRow = pXFTable->GetRow(nRowLoop);
             nCount = 0;
-            nCellMark = 0;
-            for (nCellLoop=1; nCellLoop<=pTmpRow->GetCellCount(); nCellLoop++)
+            sal_Int32 nCellMark = 0;
+            for (sal_Int32 nCellLoop=1; nCellLoop<=pTmpRow->GetCellCount(); nCellLoop++)
             {
                 if (nCount>nMaxColSpan)
                     break;
@@ -1062,7 +1051,7 @@ bool  LwpTableLayout::FindSplitColMark(XFTable* pXFTable, sal_uInt8* pCellMark,
  * @param  nStartCol - start column ID
  * @param  nEndCol - end column ID
  */
-void LwpTableLayout::ConvertTable(XFTable* pXFTable,sal_uInt16 nStartRow,
+void LwpTableLayout::ConvertTable(rtl::Reference<XFTable> const & pXFTable, sal_uInt16 nStartRow,
                 sal_uInt16 nEndRow,sal_uInt8 nStartCol,sal_uInt8 nEndCol)
 {
     //out put column info TO BE CHANGED
@@ -1103,10 +1092,8 @@ void LwpTableLayout::ConvertTable(XFTable* pXFTable,sal_uInt16 nStartRow,
 void LwpTableLayout::PutCellVals(LwpFoundry* pFoundry, LwpObjectID aTableID)
 {
 
-    //Comment:The old code doesn't check if the LwpFoundry pointer is NULL,
-    //        So the NULL pointer cause sodc frozee. Add code to check the
-    //        the pointer.
-    //New Code
+    // The old code doesn't check if the LwpFoundry pointer is NULL, so the NULL
+    // pointer cause sodc frozen. Add code to check the pointer.
     if( !pFoundry ) return;
 
     try{
@@ -1116,7 +1103,7 @@ void LwpTableLayout::PutCellVals(LwpFoundry* pFoundry, LwpObjectID aTableID)
         LwpTableRange* pTableRange = pHolder ? dynamic_cast<LwpTableRange*>(pHolder->GetHeadID().obj().get()) : nullptr;
 
         //Look up the table
-        while (NULL!=pTableRange)
+        while (nullptr!=pTableRange)
         {
             LwpObjectID aID = pTableRange->GetTableID();
             if (aID == aTableID)
@@ -1200,7 +1187,7 @@ void LwpTableLayout::PostProcessParagraph(XFCell *pCell, sal_uInt16 nRowID, sal_
         {
             OUString sNumfmt = pCellLayout->GetNumfmtName();
             bool bColorMod = false;
-            XFNumberStyle* pNumStyle = NULL;
+            XFNumberStyle* pNumStyle = nullptr;
             XFStyleManager* pXFStyleManager = LwpGlobalMgr::GetInstance()->GetXFStyleManager();
             if (!sNumfmt.isEmpty())
             {
@@ -1252,7 +1239,7 @@ void LwpTableLayout::PostProcessParagraph(XFCell *pCell, sal_uInt16 nRowID, sal_
  * @short   Parse all cols of table
  * @param  pXFTable - pointer to created XFTable
  */
-void LwpTableLayout::ConvertColumn(XFTable *pXFTable,sal_uInt8 nStartCol,sal_uInt8 nEndCol)
+void LwpTableLayout::ConvertColumn(rtl::Reference<XFTable> const & pXFTable, sal_uInt8 nStartCol, sal_uInt8 nEndCol)
 {
     LwpTable * pTable = GetTable();
     if (!pTable)
@@ -1340,31 +1327,31 @@ void LwpTableLayout::SplitConflictCells()
  * @param   nEndCol  - end column
  * @return   pXFTable
  */
-void LwpTableLayout::ConvertDefaultRow(XFTable* pXFTable,sal_uInt8 nStartCol,
-         sal_uInt8 nEndCol,sal_uInt16 nRowID)
+void LwpTableLayout::ConvertDefaultRow(rtl::Reference<XFTable> const & pXFTable, sal_uInt8 nStartCol,
+         sal_uInt8 nEndCol, sal_uInt16 nRowID)
 {
     // current row doesn't exist in the file
-    XFRow * pRow = new XFRow();
-    pRow->SetStyleName(m_DefaultRowStyleName);
+    rtl::Reference<XFRow> xRow(new XFRow);
+    xRow->SetStyleName(m_DefaultRowStyleName);
 
     for (sal_uInt16 j =0;j < nEndCol-nStartCol; j++)
     {
         // if table has default cell layout, use it to ConvertCell
         // otherwise use blank cell
-        XFCell * pCell = NULL;
+        rtl::Reference<XFCell> xCell;
         if (m_pDefaultCellLayout)
         {
-            pCell = m_pDefaultCellLayout->ConvertCell(
+            xCell = m_pDefaultCellLayout->ConvertCell(
                 GetTable()->GetObjectID(),nRowID,j+nStartCol);
         }
         else
         {
-            pCell = new XFCell();
+            xCell.set(new XFCell);
         }
-        pRow->AddCell(pCell);
+        xRow->AddCell(xCell);
     }
 
-    pXFTable->AddRow(pRow);
+    pXFTable->AddRow(xRow);
 }
 /**
  * @short   set cell map info
@@ -1397,7 +1384,7 @@ XFCell* LwpTableLayout::GetCellsMap(sal_uInt16 nRow,sal_uInt8 nCol)
     std::map<std::pair<sal_uInt16,sal_uInt8>,XFCell*>::iterator iter;
     iter =  m_CellsMap.find(pos);
     if (iter == m_CellsMap.end())
-        return NULL;
+        return nullptr;
     return iter->second;
 }
 /**
@@ -1416,11 +1403,11 @@ XFCell* LwpTableLayout::GetCellsMap(sal_uInt16 nRow,sal_uInt8 nCol)
         rRowID = pRowLayout->GetNext();
         pRowLayout = dynamic_cast<LwpRowLayout *>(rRowID.obj().get());
     }
-    return NULL;
+    return nullptr;
 }
 
 //add end by
-LwpColumnLayout::LwpColumnLayout(LwpObjectHeader &objHdr, LwpSvStream* pStrm)
+LwpColumnLayout::LwpColumnLayout(LwpObjectHeader const &objHdr, LwpSvStream* pStrm)
     : LwpVirtualLayout(objHdr, pStrm)
     , ccolid(0)
     , cwidth(0)
@@ -1430,14 +1417,14 @@ LwpColumnLayout::~LwpColumnLayout()
 {}
 void LwpColumnLayout::Read()
 {
-    LwpObjectStream* pStrm = m_pObjStrm;
+    LwpObjectStream* pStrm = m_pObjStrm.get();
 
     LwpVirtualLayout::Read();
 
     sal_uInt16 colid;
 
     colid = pStrm->QuickReaduInt16();   // forced to lushort
-    ccolid = (sal_uInt8)colid;  // Phillip
+    ccolid = (sal_uInt8)colid;
     cwidth = pStrm->QuickReadInt32();
 
     pStrm->SkipExtra();
@@ -1451,7 +1438,7 @@ void LwpColumnLayout::RegisterStyle(double dCalculatedWidth)
     m_StyleName = pXFStyleManager->AddStyle(pColStyle).m_pStyle->GetStyleName();
 }
 
-LwpTableHeadingLayout::LwpTableHeadingLayout(LwpObjectHeader &objHdr, LwpSvStream* pStrm)
+LwpTableHeadingLayout::LwpTableHeadingLayout(LwpObjectHeader const &objHdr, LwpSvStream* pStrm)
     : LwpTableLayout(objHdr, pStrm)
     , cStartRow(0)
     , cEndRow(0)
@@ -1485,23 +1472,8 @@ void LwpTableHeadingLayout::GetStartEndRow(sal_uInt16& nStartRow, sal_uInt16& nE
     nStartRow = cStartRow;
     nEndRow = cEndRow;
 }
-/**
- * @short   get first row heading layout of table heading
- * @param
- * @return LwpRowHeadingLayout * - pointer to first row heading layout of table heading
- */
-LwpRowHeadingLayout * LwpTableHeadingLayout::GetFirstRowHeadingLayout()
-{
-    LwpObjectID& rID = GetChildHead();
-    if(!rID.IsNull())
-    {
-        LwpRowHeadingLayout * pHeadingRow = dynamic_cast<LwpRowHeadingLayout *>(rID.obj().get());
-        return pHeadingRow;
-    }
-    return NULL;
-}
 
-LwpSuperParallelColumnLayout::LwpSuperParallelColumnLayout(LwpObjectHeader &objHdr, LwpSvStream* pStrm):LwpSuperTableLayout(objHdr, pStrm)
+LwpSuperParallelColumnLayout::LwpSuperParallelColumnLayout(LwpObjectHeader const &objHdr, LwpSvStream* pStrm):LwpSuperTableLayout(objHdr, pStrm)
 {
 }
 LwpSuperParallelColumnLayout::~LwpSuperParallelColumnLayout()
@@ -1514,7 +1486,7 @@ void LwpSuperParallelColumnLayout::Read()
 
 }
 
-LwpSuperGlossaryLayout::LwpSuperGlossaryLayout(LwpObjectHeader &objHdr, LwpSvStream* pStrm):LwpSuperTableLayout(objHdr, pStrm)
+LwpSuperGlossaryLayout::LwpSuperGlossaryLayout(LwpObjectHeader const &objHdr, LwpSvStream* pStrm):LwpSuperTableLayout(objHdr, pStrm)
 {
 }
 
@@ -1528,7 +1500,7 @@ void LwpSuperGlossaryLayout::Read()
     m_pObjStrm->SkipExtra();
 }
 
-LwpParallelColumnsLayout::LwpParallelColumnsLayout(LwpObjectHeader &objHdr, LwpSvStream* pStrm):LwpTableLayout(objHdr, pStrm)
+LwpParallelColumnsLayout::LwpParallelColumnsLayout(LwpObjectHeader const &objHdr, LwpSvStream* pStrm):LwpTableLayout(objHdr, pStrm)
 {
 }
 
