@@ -1,3 +1,4 @@
+/* -*- Mode: Java; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  *  The Contents of this file are made available subject to the terms of
@@ -64,7 +65,7 @@ public class FunctionHelper
 
 
     /**
-     * This convert an URL (formated as a string) to a struct com.sun.star.util.URL.
+     * This convert an URL (formatted as a string) to a struct com.sun.star.util.URL.
      * It use a special service to do that: the URLTransformer.
      * Because some API calls need it and it's not allowed to set "Complete"
      * part of the util struct only. The URL must be parsed.
@@ -111,14 +112,12 @@ public class FunctionHelper
         {
             // Any UNO method of this scope can throw this exception.
             // Reset the return value only.
-            aURL = null;
         }
         catch(com.sun.star.uno.Exception exUno)
         {
             // "createInstance()" method of used service manager can throw it.
             // Then it wasn't possible to get the URL transformer.
             // Return default instead of really parsed URL.
-            aURL = null;
         }
 
         return aURL;
@@ -250,7 +249,7 @@ public class FunctionHelper
             // try new version of creation first: directly using of the window
             // handle. The old implementation of the corresponding toolkit method
             // requires a process ID. If this id isn't the right one a null object
-            // is returned. But normaly nobody outside the office knows this id.
+            // is returned. But normally nobody outside the office knows this id.
             // New version of this method ignore the id parameter and creation will
             // work.
             // Note: You must be sure if your window handle can be really used by
@@ -407,7 +406,7 @@ public class FunctionHelper
         {
             // "createInstance()" method of used service manager can throw it.
             // If it occurred during creation of desktop service the frame already was created.
-            // Free it by decresing his refcount. Changes on the desktop tree couldn't exist.
+            // Free it by decreasing his refcount. Changes on the desktop tree couldn't exist.
             // Without the desktop service that wasn't possible. So no further rollbacks must follow.
             if(xFrame!=null)
             {
@@ -431,7 +430,7 @@ public class FunctionHelper
      * URL too. But nobody guarantee that such notifications will occur.
      * (see dispatchWithNotification() if you interest on that)
      * The returned dispatch object should be hold alive by caller
-     * till he deosn't need it any longer. Otherwise the dispatcher can(!)
+     * till he doesn't need it any longer. Otherwise the dispatcher can(!)
      * die by decreasing his refcount.
      *
      * @param   xFrame      frame which should be the target of this dispatch
@@ -457,7 +456,7 @@ public class FunctionHelper
                 com.sun.star.frame.XDispatchProvider.class,
                 xFrame);
 
-            // Ask himn for right dispatch object for given URL.
+            // Ask him for right dispatch object for given URL.
             // Force given frame as target for following dispatch by using "".
             // It means the same like "_self".
             xDispatcher = xProvider.queryDispatch(aURL,"",0);
@@ -490,50 +489,7 @@ public class FunctionHelper
 
 
 
-    /**
-     * Dispatch an URL to given frame.
-     * Caller can register himself for following result events for dispatched
-     * URL too. Notifications are guaranteed (instead of dispatch())
-     * Returning of the dispatch object isn't necessary.
-     * Nobody must hold it alive longer the dispatch needs.
-     *
-     * @param   xFrame      frame which should be the target of this dispatch
-     * @param   aURL        full parsed and converted office URL for dispatch
-     * @param   lProperties optional arguments for dispatch
-     * @param   xListener   optional listener which is registered automatically for status events
-     *                      (Note: Deregistration is not supported. Dispatcher does it automatically.)
-     */
-    public static void executeWithNotification(com.sun.star.frame.XFrame                  xFrame     ,
-                                               com.sun.star.util.URL                      aURL       ,
-                                               com.sun.star.beans.PropertyValue[]         lProperties,
-                                               com.sun.star.frame.XDispatchResultListener xListener  )
-    {
-        try
-        {
-            // Query the frame for right interface which provides access to all available dispatch objects.
-            com.sun.star.frame.XDispatchProvider xProvider = UnoRuntime.queryInterface(
-                com.sun.star.frame.XDispatchProvider.class,
-                xFrame);
 
-            // Ask himn for right dispatch object for given URL.
-            // Force THIS frame as target for following dispatch.
-            // Attention: The interface XNotifyingDispatch is an optional one!
-            com.sun.star.frame.XDispatch xDispatcher = xProvider.queryDispatch(aURL,"",0);
-            com.sun.star.frame.XNotifyingDispatch xNotifyingDispatcher = UnoRuntime.queryInterface(
-                com.sun.star.frame.XNotifyingDispatch.class,
-                xDispatcher);
-
-            // Dispatch the URL.
-            if(xNotifyingDispatcher!=null)
-                xNotifyingDispatcher.dispatchWithNotification(aURL,lProperties,xListener);
-        }
-        catch(com.sun.star.uno.RuntimeException exUno)
-        {
-            // Any UNO method of this scope can throw this exception.
-            // But there is nothing we can do then.
-            exUno.printStackTrace();
-        }
-    }
 
 
 
@@ -584,7 +540,7 @@ public class FunctionHelper
                 com.sun.star.frame.FrameSearchFlag.CHILDREN,
                 lProperties);
 
-            // dont forget to restore old frame name ...
+            // don't forget to restore old frame name...
             xFrame.setName(sOldName);
         }
         catch(com.sun.star.io.IOException exIO)
@@ -639,7 +595,7 @@ public class FunctionHelper
         try
         {
             // Check for supported model functionality.
-            // Normaly the application documents (text, spreadsheet ...) do so
+            // Normally the application documents (text, spreadsheet ...) do so
             // but some other ones (e.g. db components) doesn't do that.
             // They can't be save then.
             com.sun.star.frame.XModel xModel = UnoRuntime.queryInterface(
@@ -651,7 +607,7 @@ public class FunctionHelper
                 com.sun.star.util.XModifiable xModified = UnoRuntime.queryInterface(
                     com.sun.star.util.XModifiable.class,
                     xModel);
-                if(xModified.isModified()==true)
+                if(xModified.isModified())
                 {
                     com.sun.star.frame.XStorable xStore = UnoRuntime.queryInterface(
                         com.sun.star.frame.XStorable.class,
@@ -696,7 +652,7 @@ public class FunctionHelper
             // First detect factory of this document.
             // Ask for the supported service name of this document.
             // If information is available it can be used to find out which
-            // filter exist for HTML export. Normaly this filter should be searched
+            // filter exist for HTML export. Normally this filter should be searched
             // inside the filter configuration but this little demo doesn't do so.
             // (see service com.sun.star.document.FilterFactory for further
             // information too)
@@ -710,14 +666,14 @@ public class FunctionHelper
             {
                 // Find out possible filter name.
                 String sFilter = null;
-                if(xInfo.supportsService("com.sun.star.text.TextDocument")==true)
-                    sFilter = new String("HTML (StarWriter)");
+                if(xInfo.supportsService("com.sun.star.text.TextDocument"))
+                    sFilter = "HTML (StarWriter)";
                 else
-                if(xInfo.supportsService("com.sun.star.text.WebDocument")==true)
-                    sFilter = new String("HTML");
+                if(xInfo.supportsService("com.sun.star.text.WebDocument"))
+                    sFilter = "HTML";
                 else
-                if(xInfo.supportsService("com.sun.star.sheet.SpreadsheetDocument")==true)
-                    sFilter = new String("HTML (StarCalc)");
+                if(xInfo.supportsService("com.sun.star.sheet.SpreadsheetDocument"))
+                    sFilter = "HTML (StarCalc)";
 
                 // Check for existing state of this filter.
                 if(sFilter!=null)
@@ -731,7 +687,7 @@ public class FunctionHelper
                         xCtx.getServiceManager().createInstanceWithContext(
                             "com.sun.star.document.FilterFactory", xCtx));
 
-                    if(xFilterContainer.hasByName(sFilter)==false)
+                    if(!xFilterContainer.hasByName(sFilter))
                         sFilter=null;
                 }
 
@@ -782,87 +738,16 @@ public class FunctionHelper
 
 
 
-    /**
-     * Try to close the document without any saving of modifications.
-     * We can try it only! Controller and/or model of this document
-     * can disagree with that. But mostly they doesn't do so.
-     *
-     * @param   xDocument   document which should be clcosed
-     */
-    public static void closeDocument(com.sun.star.lang.XComponent xDocument)
-    {
-        try
-        {
-            // Check supported functionality of the document (model or controller).
-            com.sun.star.frame.XModel xModel =
-                UnoRuntime.queryInterface(
-                com.sun.star.frame.XModel.class, xDocument);
-
-            if(xModel!=null)
-            {
-                // It's a full featured office document.
-                // Reset the modify state of it and close it.
-                // Note: Model can disgree by throwing a veto exception.
-                com.sun.star.util.XModifiable xModify =
-                    UnoRuntime.queryInterface(
-                    com.sun.star.util.XModifiable.class, xModel);
-
-                xModify.setModified(false);
-                xDocument.dispose();
-            }
-            else
-            {
-                // It's a document which supports a controller .. or may by a pure
-                // window only. If it's at least a controller - we can try to
-                // suspend him. But - he can disagree with that!
-                com.sun.star.frame.XController xController =
-                    UnoRuntime.queryInterface(
-                    com.sun.star.frame.XController.class, xDocument);
-
-                if(xController!=null)
-                {
-                    if(xController.suspend(true)==true)
-                    {
-                        // Note: Don't dispose the controller - destroy the frame
-                        // to make it right!
-                        com.sun.star.frame.XFrame xFrame = xController.getFrame();
-                        xFrame.dispose();
-                    }
-                }
-            }
-        }
-        catch(com.sun.star.beans.PropertyVetoException exVeto)
-        {
-            // Can be thrown by "setModified()" call on model.
-            // He disagree with our request.
-            // But there is nothing to do then. Following "dispose()" call wasn't
-            // never called (because we catch it before). Closing failed -that's it.
-            exVeto.printStackTrace();
-        }
-        catch(com.sun.star.lang.DisposedException exDisposed)
-        {
-            // If an UNO object was already disposed before - he throw this special
-            // runtime exception. Of course every UNO call must be look for that -
-            // but it's a question of error handling.
-            // For demonstration this exception is handled here.
-            exDisposed.printStackTrace();
-        }
-        catch(com.sun.star.uno.RuntimeException exRuntime)
-        {
-            // Every uno call can throw that.
-            // Do nothing - closing failed - that's it.
-            exRuntime.printStackTrace();
-        }
-    }
 
 
 
-    /**
+
+    /*
      * Try to close the frame instead of the document.
      * It shows the possible interface to do so.
      *
      * @param xFrame
-     *          frame which should be clcosed
+     *          frame which should be closed
      *
      * @return  <TRUE/> in case frame could be closed
      *          <FALSE/> otherwise
@@ -881,8 +766,8 @@ public class FunctionHelper
                 com.sun.star.util.XCloseable.class, xFrame);
             if (xCloseable!=null)
             {
-                // We deliver the owner ship of this frame not to the (possible)
-                // source which throw a CloseVetoException. We whishto have it
+                // We deliver the ownership of this frame not to the (possible)
+                // source which throw a CloseVetoException. We wish to have it
                 // under our own control.
                 try
                 {
@@ -926,7 +811,6 @@ public class FunctionHelper
      * only, it's enough to check the names of existing child frames on the
      * desktop only.
      *
-     * @return [String]
      *          should represent an unique frame name, which currently isn't
      *          used inside the remote office frame tree
      *          (Couldn't guaranteed for a real multithreaded environment.
@@ -957,23 +841,23 @@ public class FunctionHelper
             for (int i=0; i<nCount; ++i )
             {
                 com.sun.star.frame.XFrame xFrame = (com.sun.star.frame.XFrame)AnyConverter.toObject(new com.sun.star.uno.Type(com.sun.star.frame.XFrame.class), xContainer.getByIndex(i));
-                                        sName  = new String(BASEFRAMENAME+mnViewCount);
-                while(sName.compareTo(xFrame.getName())==0)
+                                        sName  = BASEFRAMENAME+mnViewCount;
+                while(sName.equals(xFrame.getName()))
                 {
                     ++mnViewCount;
-                    sName = new String(BASEFRAMENAME+mnViewCount);
+                    sName = BASEFRAMENAME+mnViewCount;
                 }
             }
         }
         catch(com.sun.star.uno.Exception exCreateFailed)
         {
-            sName = new String(BASEFRAMENAME);
+            sName = BASEFRAMENAME;
         }
 
         if (sName==null)
         {
             System.out.println("invalid name!");
-            sName = new String(BASEFRAMENAME);
+            sName = BASEFRAMENAME;
         }
 
         return sName;
@@ -983,8 +867,8 @@ public class FunctionHelper
 
     /**
      * helper to get a file URL selected by user
-     * This method doesn't show any API concepts ...
-     * but is necessary rof this demo application.
+     * This method doesn't show any API concepts...
+     * but is necessary for this demo application.
      *
      * @param   aParent parent window of this dialog
      * @param   bOpen   If it is set to true =>
@@ -1005,7 +889,7 @@ public class FunctionHelper
             aChooser = new JFileChooser(maLastDir);
 
         // decide between file open/save dialog
-        if( bOpen==true )
+        if( bOpen )
             nDecision = aChooser.showOpenDialog(aParent);
         else
             nDecision = aChooser.showSaveDialog(aParent);
@@ -1029,8 +913,8 @@ public class FunctionHelper
             // => correct this problem first, otherwise office can't use these URL's
             if(
                 ( sFileURL                      !=null  ) &&
-                ( sFileURL.startsWith("file:/") ==true  ) &&
-                ( sFileURL.startsWith("file://")==false )
+                ( sFileURL.startsWith("file:/")  ) &&
+                ( !sFileURL.startsWith("file://") )
               )
             {
                 StringBuffer sWorkBuffer = new StringBuffer(sFileURL);
@@ -1051,3 +935,5 @@ public class FunctionHelper
     private static File maLastDir   = null;
     private static int  mnViewCount = 0   ;
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
