@@ -1,3 +1,4 @@
+/* -*- Mode: Java; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  *  The Contents of this file are made available subject to the terms of
@@ -54,12 +55,12 @@ import com.sun.star.uno.UnoRuntime;
  *
  * Further we are frame action listener too.
  * So we can update our status listener connections and
- * internal holded dispatch object automaticly.
+ * internal holded dispatch object automatically.
  *
  * Another reason for such extra class for listening:
- * Most listener callbacks are asynchronoues [oneay] requests.
+ * Most listener callbacks are asynchronous [oneay] requests.
  * And it's not allowed to call back synchronously there.
- * So we must start threads for updating something internaly.
+ * So we must start threads for updating something internally.
  *
  */
 class StatusListener implements com.sun.star.frame.XStatusListener,
@@ -67,22 +68,22 @@ class StatusListener implements com.sun.star.frame.XStatusListener,
                                 IShutdownListener,
                                 IOnewayLink
 {
-    //_____________________
+
 
     /**
      * @member m_rControl           reference to the UI control, which should be updated
      * @member m_sTrueText          this text will be shown at the used UI control as description for an enabled status
      * @member m_sFalseText         this text will be shown at the used UI control as description for an disabled status
      * @member m_xDispatch          if we listen for status events, we must hold the dispatch object alive!
-     * @member m_xFrame             reference to the frame, which can provide new dispatch objects if it's neccessary to update it
+     * @member m_xFrame             reference to the frame, which can provide new dispatch objects if it's necessary to update it
      * @member m_aURL               and of course we must be registered for a special URL
      * @member m_bIsActionListener  indicates if we are currently registered as a listener for frame action events or not
      * @member m_bIsStatusListener  indicates if we are currently registered as a listener for status events or not
-     * @member m_bDead              there exist more then one way to finish an object of this class - we must know it sometimes
+     * @member m_bDead              there exist more than one way to finish an object of this class - we must know it sometimes
      */
-    private Component                    m_rControl         ;
-    private String                       m_sTrueText        ;
-    private String                       m_sFalseText       ;
+    private final Component                    m_rControl         ;
+    private final String                       m_sTrueText        ;
+    private final String                       m_sFalseText       ;
     private com.sun.star.frame.XDispatch m_xDispatch        ;
     private com.sun.star.frame.XFrame    m_xFrame           ;
     private com.sun.star.util.URL        m_aURL             ;
@@ -90,12 +91,12 @@ class StatusListener implements com.sun.star.frame.XStatusListener,
     private boolean                      m_bIsStatusListener;
     private boolean                      m_bDead            ;
 
-    //_____________________
+
 
     /**
      * ctor
      * It initialize an instance of this class only.
-     * We set all neccessary information on our internal member - that's it
+     * We set all necessary information on our internal member - that's it
      */
     StatusListener( /*IN*/ Component                   rControl   ,
                     /*IN*/ String                      sTrueText  ,
@@ -115,16 +116,16 @@ class StatusListener implements com.sun.star.frame.XStatusListener,
         m_aURL = FunctionHelper.parseURL(sURL);
     }
 
-    //_____________________
+
 
     /**
-     * start working as frame action listener realy.
+     * start working as frame action listener really.
      * In case we get such frame action, it indicates that we should
      * update our internal saved dispatch object on which we listen
-     * for status events. So we can do it automaticly. The outside code
+     * for status events. So we can do it automatically. The outside code
      * mustn't check such things. We can work with one frame,
      * till it die. It doesn't matter if he will be used for different
-     * load/save or any other requests. We will be up to date everytime.
+     * load/save or any other requests. We will be up to date every time.
      */
     public void startListening()
     {
@@ -135,7 +136,7 @@ class StatusListener implements com.sun.star.frame.XStatusListener,
                 return;
             if (m_xFrame==null)
                 return;
-            if (m_bIsActionListener==true)
+            if (m_bIsActionListener)
                 return;
             xFrame = m_xFrame;
         }
@@ -146,7 +147,7 @@ class StatusListener implements com.sun.star.frame.XStatusListener,
         }
     }
 
-    //_____________________
+
 
     /**
      * In case we got an oneway listener callback - we had to use the office
@@ -180,16 +181,16 @@ class StatusListener implements com.sun.star.frame.XStatusListener,
         }
     }
 
-    //_____________________
+
 
     /**
      * This is the callback method for such frame action events, we listen for.
      * Because it's a oneway method we start a thread as reaction. This thread call
-     * us back and we can do neccessary things there.
-     * But we shouldn't start such action - if it's not realy neccessary.
-     * So we check before, if we are intereested on this event realy.
+     * us back and we can do necessary things there.
+     * But we shouldn't start such action - if it's not really necessary.
+     * So we check before, if we are interested on this event really.
      *
-     * @see impl_frameAction()
+     * @see #impl_frameAction
      *
      * @param aEvent
      *          describes the action, which triggered this event
@@ -222,13 +223,13 @@ class StatusListener implements com.sun.star.frame.XStatusListener,
         aExecutor.start();
     }
 
-    //_____________________
+
 
     /**
      * This is the callback method for the status we listen for an wish to show it
-     * on our UI control. Of yourse it's a oneway method ... but we doesn't call back
+     * on our UI control. Of course it's a oneway method ... but we don't call back
      * to the office synchronously here. We update our UI only. So we don't leave this
-     * java process. In such case it's not neccessary to use threads to decouple it.
+     * java process. In such case it's not necessary to use threads to decouple it.
      * Do it here and now ...
      *
      * @param aEvent
@@ -241,18 +242,18 @@ class StatusListener implements com.sun.star.frame.XStatusListener,
             if (m_bDead)
                 return;
 
-            // enable/dsiable th control.
-            // Means: If the feature isn't available currently - we can't show an status realy here.
-            // Then we should colorize it gray ...
+            // enable/disable the control.
+            // Means: if the feature isn't available currently - we can't show an status really here.
+            // Then we should colorize it gray...
             m_rControl.setEnabled(aEvent.IsEnabled);
 
             // Only if status is enabled we can look for his value!
             if (aEvent.IsEnabled)
             {
-                // look for the right type ofthe UI control
+                // look for the right type of the UI control
                 // Following actions depend on it.
 
-                //.............................................................
+
                 // it's a check box
                 if (m_rControl instanceof JCheckBox)
                 {
@@ -271,7 +272,7 @@ class StatusListener implements com.sun.star.frame.XStatusListener,
                         aBox.setText(m_sFalseText);
                 }
                 else
-                //.............................................................
+
                 // it's a label
                 if (m_rControl instanceof JLabel)
                 {
@@ -279,7 +280,7 @@ class StatusListener implements com.sun.star.frame.XStatusListener,
 
                     // Detect type of state value
                     // and set it on internal well known UI control
-                    // But do it only, if value realy change.
+                    // But do it only, if value really change.
                     if(aEvent.State instanceof String)
                     {
                         String sState = (String)aEvent.State;
@@ -305,7 +306,7 @@ class StatusListener implements com.sun.star.frame.XStatusListener,
         }
     }
 
-    //_____________________
+
 
     /**
      * Internal call back for frame action events, triggered by the used
@@ -316,7 +317,7 @@ class StatusListener implements com.sun.star.frame.XStatusListener,
      * @param aEvent
      *          describes the action
      */
-    public void impl_frameAction(/*IN*/ com.sun.star.frame.FrameActionEvent aEvent)
+    private void impl_frameAction(/*IN*/ com.sun.star.frame.FrameActionEvent aEvent)
     {
         synchronized(this)
         {
@@ -324,7 +325,7 @@ class StatusListener implements com.sun.star.frame.XStatusListener,
                 return;
         }
         // Don't look for ignoring actions - it was done already inside original frameAction() call!
-        // deregistration as status listener will be done here everytime - but registration only, if necessary!
+        // deregistration as status listener will be done here every time - but registration only, if necessary!
         boolean bRegister = false;
         switch(aEvent.Action.getValue())
         {
@@ -377,14 +378,14 @@ class StatusListener implements com.sun.star.frame.XStatusListener,
         }
     }
 
-    // ____________________
+
 
     /**
      * callback for disposing events
      * Our dispatch or frame object inform us about his following dead ...
-     * So we must forget his reference. But it's not neccessary to
+     * So we must forget his reference. But it's not necessary to
      * remove listener connections here. Because the broadcaster
-     * forget us automaticly. The only thing we have to do: release
+     * forget us automatically. The only thing we have to do: release
      * his reference and let him die!
      *
      * @param aEvent
@@ -414,7 +415,7 @@ class StatusListener implements com.sun.star.frame.XStatusListener,
         shutdown();
     }
 
-    // ____________________
+
 
     /**
      * If this java application shutdown - we must cancel all current existing
@@ -464,3 +465,5 @@ class StatusListener implements com.sun.star.frame.XStatusListener,
         xFrame = null ;
     }
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
