@@ -17,13 +17,15 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "oox/core/fasttokenhandler.hxx"
+#include <oox/core/fasttokenhandler.hxx>
 
 #include <com/sun/star/uno/XComponentContext.hpp>
-#include "oox/helper/helper.hxx"
-#include "oox/token/tokenmap.hxx"
+#include <oox/helper/helper.hxx>
+#include <oox/token/tokenmap.hxx>
 #include <cppuhelper/supportsservice.hxx>
 
+#include <services.hxx>
+
 namespace oox {
 namespace core {
 
@@ -36,12 +38,11 @@ OUString SAL_CALL FastTokenHandler_getImplementationName()
 
 Sequence< OUString > SAL_CALL FastTokenHandler_getSupportedServiceNames()
 {
-    Sequence< OUString > aServiceNames( 1 );
-    aServiceNames[ 0 ] = "com.sun.star.xml.sax.FastTokenHandler";
+    Sequence<OUString> aServiceNames { "com.sun.star.xml.sax.FastTokenHandler" };
     return aServiceNames;
 }
 
-Reference< XInterface > SAL_CALL FastTokenHandler_createInstance( const Reference< XComponentContext >& /*rxContext*/ ) throw (Exception)
+Reference< XInterface > SAL_CALL FastTokenHandler_createInstance( const Reference< XComponentContext >& /*rxContext*/ )
 {
     return static_cast< ::cppu::OWeakObject* >( new FastTokenHandler );
 }
@@ -56,38 +57,27 @@ FastTokenHandler::~FastTokenHandler()
 }
 
 // XServiceInfo
-OUString SAL_CALL FastTokenHandler::getImplementationName() throw (RuntimeException)
+OUString SAL_CALL FastTokenHandler::getImplementationName()
 {
     return FastTokenHandler_getImplementationName();
 }
 
-sal_Bool SAL_CALL FastTokenHandler::supportsService( const OUString& rServiceName ) throw (RuntimeException)
+sal_Bool SAL_CALL FastTokenHandler::supportsService( const OUString& rServiceName )
 {
     return cppu::supportsService(this, rServiceName);
 }
 
-Sequence< OUString > SAL_CALL FastTokenHandler::getSupportedServiceNames() throw (RuntimeException)
+Sequence< OUString > SAL_CALL FastTokenHandler::getSupportedServiceNames()
 {
     return FastTokenHandler_getSupportedServiceNames();
 }
 
-// XFastTokenHandler
-sal_Int32 FastTokenHandler::getToken( const OUString& rIdentifier ) throw( RuntimeException )
-{
-    return mrTokenMap.getTokenFromUnicode( rIdentifier );
-}
-
-OUString FastTokenHandler::getIdentifier( sal_Int32 nToken ) throw( RuntimeException )
-{
-    return mrTokenMap.getUnicodeTokenName( nToken );
-}
-
-Sequence< sal_Int8 > FastTokenHandler::getUTF8Identifier( sal_Int32 nToken ) throw( RuntimeException )
+Sequence< sal_Int8 > FastTokenHandler::getUTF8Identifier( sal_Int32 nToken )
 {
     return mrTokenMap.getUtf8TokenName( nToken );
 }
 
-sal_Int32 FastTokenHandler::getTokenFromUTF8( const Sequence< sal_Int8 >& rIdentifier ) throw( RuntimeException )
+sal_Int32 FastTokenHandler::getTokenFromUTF8( const Sequence< sal_Int8 >& rIdentifier )
 {
     return mrTokenMap.getTokenFromUtf8( rIdentifier );
 }
@@ -97,8 +87,6 @@ sal_Int32 FastTokenHandler::getTokenDirect( const char *pToken, sal_Int32 nLengt
     return mrTokenMap.getTokenFromUTF8( pToken, nLength );
 }
 
-// ============================================================================
-
 } // namespace core
 } // namespace oox
 
