@@ -17,7 +17,7 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "oox/core/filterdetect.hxx"
+#include <oox/core/filterdetect.hxx>
 
 #include <com/sun/star/io/TempFile.hpp>
 #include <com/sun/star/io/XStream.hpp>
@@ -25,15 +25,19 @@
 #include <unotools/mediadescriptor.hxx>
 #include <cppuhelper/supportsservice.hxx>
 
-#include "oox/core/fastparser.hxx"
-#include "oox/helper/attributelist.hxx"
-#include "oox/helper/zipstorage.hxx"
-#include "oox/ole/olestorage.hxx"
+#include <oox/core/fastparser.hxx>
+#include <oox/helper/attributelist.hxx>
+#include <oox/helper/zipstorage.hxx>
+#include <oox/ole/olestorage.hxx>
+#include <oox/token/namespaces.hxx>
+#include <oox/token/tokens.hxx>
 
-#include "oox/crypto/DocumentDecryption.hxx"
+#include <oox/crypto/DocumentDecryption.hxx>
 
 #include <com/sun/star/uri/UriReferenceFactory.hpp>
 
+#include <services.hxx>
+
 namespace oox {
 namespace core {
 
@@ -45,12 +49,12 @@ using namespace ::com::sun::star::xml::sax;
 using namespace ::com::sun::star::uri;
 
 using utl::MediaDescriptor;
-using comphelper::SequenceAsHashMap;
 using comphelper::IDocPasswordVerifier;
 using comphelper::DocPasswordVerifierResult;
 
-FilterDetectDocHandler::FilterDetectDocHandler( const  Reference< XComponentContext >& rxContext, OUString& rFilterName ) :
+FilterDetectDocHandler::FilterDetectDocHandler( const  Reference< XComponentContext >& rxContext, OUString& rFilterName, const OUString& rFileName ) :
     mrFilterName( rFilterName ),
+    maFileName(rFileName),
     mxContext( rxContext )
 {
     maContextStack.reserve( 2 );
@@ -61,23 +65,23 @@ FilterDetectDocHandler::~FilterDetectDocHandler()
 }
 
 void SAL_CALL FilterDetectDocHandler::startDocument()
-    throw (SAXException, RuntimeException)
 {
 }
 
 void SAL_CALL FilterDetectDocHandler::endDocument()
-    throw (SAXException, RuntimeException)
+{
+}
+
+void SAL_CALL FilterDetectDocHandler::processingInstruction( const OUString& /*rTarget*/, const OUString& /*rData*/ )
 {
 }
 
 void SAL_CALL FilterDetectDocHandler::setDocumentLocator( const Reference<XLocator>& /*xLocator*/ )
-    throw (SAXException, RuntimeException)
 {
 }
 
 void SAL_CALL FilterDetectDocHandler::startFastElement(
         sal_Int32 nElement, const Reference< XFastAttributeList >& rAttribs )
-    throw (SAXException,RuntimeException)
 {
     AttributeList aAttribs( rAttribs );
     switch ( nElement )
@@ -107,48 +111,32 @@ void SAL_CALL FilterDetectDocHandler::startFastElement(
 
 void SAL_CALL FilterDetectDocHandler::startUnknownElement(
     const OUString& /*Namespace*/, const OUString& /*Name*/, const Reference<XFastAttributeList>& /*Attribs*/ )
-    throw (SAXException, RuntimeException)
 {
 }
 
 void SAL_CALL FilterDetectDocHandler::endFastElement( sal_Int32 /*nElement*/ )
-    throw (SAXException, RuntimeException)
 {
     maContextStack.pop_back();
 }
 
 void SAL_CALL FilterDetectDocHandler::endUnknownElement(
-    const OUString& /*Namespace*/, const OUString& /*Name*/ ) throw (SAXException, RuntimeException)
+    const OUString& /*Namespace*/, const OUString& /*Name*/ )
 {
 }
 
 Reference<XFastContextHandler> SAL_CALL FilterDetectDocHandler::createFastChildContext(
     sal_Int32 /*Element*/, const Reference<XFastAttributeList>& /*Attribs*/ )
-    throw (SAXException, RuntimeException)
 {
     return this;
 }
 
 Reference<XFastContextHandler> SAL_CALL FilterDetectDocHandler::createUnknownChildContext(
     const OUString& /*Namespace*/, const OUString& /*Name*/, const Reference<XFastAttributeList>& /*Attribs*/)
-    throw (SAXException, RuntimeException)
 {
     return this;
 }
 
 void SAL_CALL FilterDetectDocHandler::characters( const OUString& /*aChars*/ )
-    throw (SAXException, RuntimeException)
-{
-}
-
-void SAL_CALL FilterDetectDocHandler::ignorableWhitespace( const OUString& /*aWhitespaces*/ )
-    throw (SAXException, RuntimeException)
-{
-}
-
-void SAL_CALL FilterDetectDocHandler::processingInstruction(
-    const OUString& /*aTarget*/, const OUString& /*aData*/ )
-    throw (SAXException, RuntimeException)
 {
 }
 
@@ -163,10 +151,10 @@ void FilterDetectDocHandler::parseRelationship( const AttributeList& rAttribs )
         {
              // use '/' to representent the root of the zip package ( and provide a 'file' scheme to
              // keep the XUriReference implementation happy )
-             Reference< XUriReference > xBase = xFactory->parse( OUString("file:///") );
+             Reference< XUriReference > xBase = xFactory->parse( "file:///" );
 
              Reference< XUriReference > xPart = xFactory->parse(  rAttribs.getString( XML_Target, OUString() ) );
-             Reference< XUriReference > xAbs = xFactory->makeAbsolute(  xBase, xPart, sal_True, RelativeUriExcessParentSegments_RETAIN );
+             Reference< XUriReference > xAbs = xFactory->makeAbsolute(  xBase, xPart, true, RelativeUriExcessParentSegments_RETAIN );
 
              if ( xAbs.is() )
                  maTargetPath = xAbs->getPath();
@@ -177,37 +165,45 @@ void FilterDetectDocHandler::parseRelationship( const AttributeList& rAttribs )
     }
 }
 
-OUString FilterDetectDocHandler::getFilterNameFromContentType( const OUString& rContentType ) const
+OUString FilterDetectDocHandler::getFilterNameFromContentType( const OUString& rContentType, const OUString& rFileName )
 {
-    if( rContentType.equalsAscii("application/vnd.openxmlformats-officedocument.wordprocessingml.document.main+xml" ) ||
-        rContentType.equalsAscii("application/vnd.ms-word.document.macroEnabled.main+xml" ) )
+    bool bDocm = rFileName.endsWithIgnoreAsciiCase(".docm");
+
+    if( rContentType == "application/vnd.openxmlformats-officedocument.wordprocessingml.document.main+xml" && !bDocm )
         return OUString( "writer_MS_Word_2007" );
 
-    if( rContentType.equalsAscii("application/vnd.openxmlformats-officedocument.wordprocessingml.template.main+xml") ||
-        rContentType.equalsAscii("application/vnd.ms-word.template.macroEnabledTemplate.main+xml") )
+    if( rContentType == "application/vnd.ms-word.document.macroEnabled.main+xml" || bDocm )
+        return OUString( "writer_MS_Word_2007_VBA" );
+
+    if( rContentType == "application/vnd.openxmlformats-officedocument.wordprocessingml.template.main+xml" ||
+        rContentType == "application/vnd.ms-word.template.macroEnabledTemplate.main+xml" )
         return OUString( "writer_MS_Word_2007_Template" );
 
-    if( rContentType.equalsAscii("application/vnd.openxmlformats-officedocument.spreadsheetml.sheet.main+xml") ||
-        rContentType.equalsAscii("application/vnd.ms-excel.sheet.macroEnabled.main+xml") )
+    if( rContentType == "application/vnd.openxmlformats-officedocument.spreadsheetml.sheet.main+xml")
         return OUString( "MS Excel 2007 XML" );
 
-    if( rContentType.equalsAscii("application/vnd.openxmlformats-officedocument.spreadsheetml.template.main+xml") ||
-        rContentType.equalsAscii("application/vnd.ms-excel.template.macroEnabled.main+xml") )
+    if (rContentType == "application/vnd.ms-excel.sheet.macroEnabled.main+xml")
+        return OUString( "MS Excel 2007 VBA XML" );
+
+    if( rContentType == "application/vnd.openxmlformats-officedocument.spreadsheetml.template.main+xml" ||
+        rContentType == "application/vnd.ms-excel.template.macroEnabled.main+xml" )
         return OUString( "MS Excel 2007 XML Template" );
 
     if ( rContentType == "application/vnd.ms-excel.sheet.binary.macroEnabled.main" )
         return OUString( "MS Excel 2007 Binary" );
 
-    if( rContentType.equalsAscii("application/vnd.openxmlformats-officedocument.presentationml.presentation.main+xml") ||
-        rContentType.equalsAscii("application/vnd.ms-powerpoint.presentation.macroEnabled.main+xml") )
+    if (rContentType == "application/vnd.openxmlformats-officedocument.presentationml.presentation.main+xml")
         return OUString( "MS PowerPoint 2007 XML" );
 
-    if( rContentType.equalsAscii("application/vnd.openxmlformats-officedocument.presentationml.slideshow.main+xml") ||
-        rContentType.equalsAscii("application/vnd.ms-powerpoint.slideshow.macroEnabled.main+xml") )
+    if (rContentType == "application/vnd.ms-powerpoint.presentation.macroEnabled.main+xml")
+        return OUString( "MS PowerPoint 2007 XML VBA" );
+
+    if( rContentType == "application/vnd.openxmlformats-officedocument.presentationml.slideshow.main+xml" ||
+        rContentType == "application/vnd.ms-powerpoint.slideshow.macroEnabled.main+xml" )
         return OUString( "MS PowerPoint 2007 XML AutoPlay" );
 
-    if( rContentType.equalsAscii("application/vnd.openxmlformats-officedocument.presentationml.template.main+xml") ||
-        rContentType.equalsAscii("application/vnd.ms-powerpoint.template.macroEnabled.main+xml") )
+    if( rContentType == "application/vnd.openxmlformats-officedocument.presentationml.template.main+xml" ||
+        rContentType == "application/vnd.ms-powerpoint.template.macroEnabled.main+xml" )
         return OUString( "MS PowerPoint 2007 XML Template" );
 
     return OUString();
@@ -222,21 +218,20 @@ void FilterDetectDocHandler::parseContentTypesDefault( const AttributeList& rAtt
         OUString aExtension = rAttribs.getString( XML_Extension, OUString() );
         sal_Int32 nExtPos = maTargetPath.getLength() - aExtension.getLength();
         if( (nExtPos > 0) && (maTargetPath[ nExtPos - 1 ] == '.') && maTargetPath.match( aExtension, nExtPos ) )
-            mrFilterName = getFilterNameFromContentType( rAttribs.getString( XML_ContentType, OUString() ) );
+            mrFilterName = getFilterNameFromContentType( rAttribs.getString( XML_ContentType, OUString() ), maFileName );
     }
 }
 
 void FilterDetectDocHandler::parseContentTypesOverride( const AttributeList& rAttribs )
 {
-    if( rAttribs.getString( XML_PartName, OUString() ).equals( maTargetPath ) )
-        mrFilterName = getFilterNameFromContentType( rAttribs.getString( XML_ContentType, OUString() ) );
+    if( rAttribs.getString( XML_PartName, OUString() ) == maTargetPath )
+        mrFilterName = getFilterNameFromContentType( rAttribs.getString( XML_ContentType, OUString() ), maFileName );
 }
 
 /* Helper for XServiceInfo */
 Sequence< OUString > FilterDetect_getSupportedServiceNames()
 {
-    Sequence< OUString > aServiceNames( 1 );
-    aServiceNames[ 0 ] = "com.sun.star.frame.ExtendedTypeDetection";
+    Sequence<OUString> aServiceNames { "com.sun.star.frame.ExtendedTypeDetection" };
     return aServiceNames;
 }
 
@@ -247,12 +242,12 @@ OUString FilterDetect_getImplementationName()
 }
 
 /* Helper for registry */
-Reference< XInterface > SAL_CALL FilterDetect_createInstance( const Reference< XComponentContext >& rxContext ) throw( Exception )
+Reference< XInterface > SAL_CALL FilterDetect_createInstance( const Reference< XComponentContext >& rxContext )
 {
     return static_cast< ::cppu::OWeakObject* >( new FilterDetect( rxContext ) );
 }
 
-FilterDetect::FilterDetect( const Reference< XComponentContext >& rxContext ) throw( RuntimeException ) :
+FilterDetect::FilterDetect( const Reference< XComponentContext >& rxContext ) :
     mxContext( rxContext, UNO_SET_THROW )
 {
 }
@@ -275,9 +270,9 @@ class PasswordVerifier : public IDocPasswordVerifier
 public:
     explicit PasswordVerifier( DocumentDecryption& aDecryptor );
 
-    virtual DocPasswordVerifierResult verifyPassword( const OUString& rPassword, Sequence<NamedValue>& rEncryptionData );
+    virtual DocPasswordVerifierResult verifyPassword( const OUString& rPassword, Sequence<NamedValue>& rEncryptionData ) override;
 
-    virtual DocPasswordVerifierResult verifyEncryptionData( const Sequence<NamedValue>& rEncryptionData );
+    virtual DocPasswordVerifierResult verifyEncryptionData( const Sequence<NamedValue>& rEncryptionData ) override;
 private:
     DocumentDecryption& mDecryptor;
 };
@@ -291,20 +286,16 @@ comphelper::DocPasswordVerifierResult PasswordVerifier::verifyPassword( const OU
     if(mDecryptor.generateEncryptionKey(rPassword))
         rEncryptionData = mDecryptor.createEncryptionData(rPassword);
 
-    return rEncryptionData.hasElements() ? comphelper::DocPasswordVerifierResult_OK : comphelper::DocPasswordVerifierResult_WRONG_PASSWORD;
+    return rEncryptionData.hasElements() ? comphelper::DocPasswordVerifierResult::OK : comphelper::DocPasswordVerifierResult::WrongPassword;
 }
 
-comphelper::DocPasswordVerifierResult PasswordVerifier::verifyEncryptionData( const Sequence<NamedValue>& rEncryptionData )
+comphelper::DocPasswordVerifierResult PasswordVerifier::verifyEncryptionData( const Sequence<NamedValue>&  )
 {
-    comphelper::DocPasswordVerifierResult aResult = comphelper::DocPasswordVerifierResult_WRONG_PASSWORD;
-    if (DocumentDecryption::checkEncryptionData(rEncryptionData))
-        aResult = comphelper::DocPasswordVerifierResult_OK;
-    return aResult;
+    return comphelper::DocPasswordVerifierResult::WrongPassword;
 }
 
 } // namespace
 
-
 Reference< XInputStream > FilterDetect::extractUnencryptedPackage( MediaDescriptor& rMediaDescriptor ) const
 {
     // try the plain input stream
@@ -336,7 +327,7 @@ Reference< XInputStream > FilterDetect::extractUnencryptedPackage( MediaDescript
                     feature with password. Try this first before prompting the
                     user for a password. */
                 std::vector<OUString> aDefaultPasswords;
-                aDefaultPasswords.push_back("VelvetSweatshop");
+                aDefaultPasswords.emplace_back("VelvetSweatshop");
 
                 /*  Use the comphelper password helper to request a password.
                     This helper returns either with the correct password
@@ -346,7 +337,7 @@ Reference< XInputStream > FilterDetect::extractUnencryptedPackage( MediaDescript
                 Sequence<NamedValue> aEncryptionData;
                 aEncryptionData = rMediaDescriptor.requestAndVerifyDocPassword(
                                                 aVerifier,
-                                                comphelper::DocPasswordRequestType_MS,
+                                                comphelper::DocPasswordRequestType::MS,
                                                 &aDefaultPasswords );
 
                 if( aEncryptionData.getLength() == 0 )
@@ -377,33 +368,29 @@ Reference< XInputStream > FilterDetect::extractUnencryptedPackage( MediaDescript
 
 // com.sun.star.lang.XServiceInfo interface -----------------------------------
 
-OUString SAL_CALL FilterDetect::getImplementationName() throw( RuntimeException )
+OUString SAL_CALL FilterDetect::getImplementationName()
 {
     return FilterDetect_getImplementationName();
 }
 
-sal_Bool SAL_CALL FilterDetect::supportsService( const OUString& rServiceName ) throw( RuntimeException )
+sal_Bool SAL_CALL FilterDetect::supportsService( const OUString& rServiceName )
 {
     return cppu::supportsService(this, rServiceName);
 }
 
-Sequence< OUString > SAL_CALL FilterDetect::getSupportedServiceNames() throw( RuntimeException )
+Sequence< OUString > SAL_CALL FilterDetect::getSupportedServiceNames()
 {
     return FilterDetect_getSupportedServiceNames();
 }
 
 // com.sun.star.document.XExtendedFilterDetection interface -------------------
 
-OUString SAL_CALL FilterDetect::detect( Sequence< PropertyValue >& rMediaDescSeq ) throw( RuntimeException )
+OUString SAL_CALL FilterDetect::detect( Sequence< PropertyValue >& rMediaDescSeq )
 {
     OUString aFilterName;
     MediaDescriptor aMediaDescriptor( rMediaDescSeq );
 
-    /*  Check that the user has not choosen to abort detection, e.g. by hitting
-        'Cancel' in the password input dialog. This may happen because this
-        filter detection is used by different filters. */
-    bool bAborted = aMediaDescriptor.getUnpackedValueOrDefault( MediaDescriptor::PROP_ABORTED(), false );
-    if( !bAborted ) try
+    try
     {
         aMediaDescriptor.addInputStream();
 
@@ -418,11 +405,15 @@ OUString SAL_CALL FilterDetect::detect( Sequence< PropertyValue >& rMediaDescSeq
         if( aZipStorage.isStorage() )
         {
             // create the fast parser, register the XML namespaces, set document handler
-            FastParser aParser( mxContext );
+            FastParser aParser;
             aParser.registerNamespace( NMSP_packageRel );
             aParser.registerNamespace( NMSP_officeRel );
             aParser.registerNamespace( NMSP_packageContentTypes );
-            aParser.setDocumentHandler( new FilterDetectDocHandler( mxContext, aFilterName ) );
+
+            OUString aFileName;
+            aMediaDescriptor[utl::MediaDescriptor::PROP_URL()] >>= aFileName;
+
+            aParser.setDocumentHandler( new FilterDetectDocHandler( mxContext, aFilterName, aFileName ) );
 
             /*  Parse '_rels/.rels' to get the target path and '[Content_Types].xml'
                 to determine the content type of the part at the target path. */
@@ -432,6 +423,18 @@ OUString SAL_CALL FilterDetect::detect( Sequence< PropertyValue >& rMediaDescSeq
     }
     catch( const Exception& )
     {
+        if ( aMediaDescriptor.getUnpackedValueOrDefault( MediaDescriptor::PROP_ABORTED(), false ) )
+            /*  The user chose to abort detection, e.g. by hitting 'Cancel' in the password input dialog,
+                so we have to return non-empty type name to abort the detection loop. The loading code is
+                supposed to check whether the "Aborted" flag is present in the descriptor, and to not attempt
+                to actually load the file then.
+
+                The returned type name is the one we got as an input, which typically was detected by the flat
+                detection (i.e. by file extension), so normally that's the correct one. Also at this point we
+                already know that the file is OLE encrypted package, so trying with other type detectors doesn't
+                make much sense anyway.
+            */
+            aFilterName = aMediaDescriptor.getUnpackedValueOrDefault( MediaDescriptor::PROP_TYPENAME(), OUString() );
     }
 
     // write back changed media descriptor members
@@ -439,8 +442,6 @@ OUString SAL_CALL FilterDetect::detect( Sequence< PropertyValue >& rMediaDescSeq
     return aFilterName;
 }
 
-// ============================================================================
-
 } // namespace core
 } // namespace oox
 
