@@ -17,7 +17,7 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "oox/drawingml/chart/axisconverter.hxx"
+#include <drawingml/chart/axisconverter.hxx>
 
 #include <com/sun/star/chart/ChartAxisArrangeOrderType.hpp>
 #include <com/sun/star/chart/ChartAxisLabelPosition.hpp>
@@ -32,24 +32,24 @@
 #include <com/sun/star/chart2/XAxis.hpp>
 #include <com/sun/star/chart2/XCoordinateSystem.hpp>
 #include <com/sun/star/chart2/XTitled.hpp>
-#include "oox/drawingml/chart/axismodel.hxx"
-#include "oox/drawingml/chart/titleconverter.hxx"
-#include "oox/drawingml/chart/typegroupconverter.hxx"
-#include "oox/drawingml/lineproperties.hxx"
-#include "comphelper/processfactory.hxx"
+#include <drawingml/chart/axismodel.hxx>
+#include <drawingml/chart/titleconverter.hxx>
+#include <drawingml/chart/typegroupconverter.hxx>
+#include <drawingml/lineproperties.hxx>
+#include <oox/token/namespaces.hxx>
+#include <oox/token/properties.hxx>
+#include <oox/token/tokens.hxx>
+#include <comphelper/processfactory.hxx>
+#include <osl/diagnose.h>
 
 namespace oox {
 namespace drawingml {
 namespace chart {
 
-
-
 using namespace ::com::sun::star::beans;
 using namespace ::com::sun::star::chart2;
 using namespace ::com::sun::star::uno;
 
-
-
 namespace {
 
 inline void lclSetValueOrClearAny( Any& orAny, const OptValue< double >& rofValue )
@@ -78,12 +78,12 @@ sal_Int32 lclGetApiTimeUnit( sal_Int32 nTimeUnit )
 void lclConvertTimeInterval( Any& orInterval, const OptValue< double >& rofUnit, sal_Int32 nTimeUnit )
 {
     if( rofUnit.has() && (1.0 <= rofUnit.get()) && (rofUnit.get() <= SAL_MAX_INT32) )
-        orInterval <<= ::com::sun::star::chart::TimeInterval( static_cast< sal_Int32 >( rofUnit.get() ), lclGetApiTimeUnit( nTimeUnit ) );
+        orInterval <<= css::chart::TimeInterval( static_cast< sal_Int32 >( rofUnit.get() ), lclGetApiTimeUnit( nTimeUnit ) );
     else
         orInterval.clear();
 }
 
-::com::sun::star::chart::ChartAxisLabelPosition lclGetLabelPosition( sal_Int32 nToken )
+css::chart::ChartAxisLabelPosition lclGetLabelPosition( sal_Int32 nToken )
 {
     using namespace ::com::sun::star::chart;
     switch( nToken )
@@ -104,7 +104,7 @@ sal_Int32 lclGetTickMark( sal_Int32 nToken )
         case XML_out:   return OUTER;
         case XML_cross: return INNER | OUTER;
     }
-    return NONE;
+    return css::chart2::TickmarkStyle::NONE;
 }
 
 /**
@@ -129,8 +129,6 @@ bool isPercent( const RefVector<TypeGroupConverter>& rTypeGroups )
 
 } // namespace
 
-
-
 AxisConverter::AxisConverter( const ConverterRoot& rParent, AxisModel& rModel ) :
     ConverterBase< AxisModel >( rParent, rModel )
 {
@@ -173,7 +171,7 @@ void AxisConverter::convertFromModel(
         // axis line and tick label formatting
         rFormatter.convertFormatting( aAxisProp, mrModel.mxShapeProp, mrModel.mxTextProp, OBJECTTYPE_AXIS );
         // tick label rotation
-        rFormatter.convertTextRotation( aAxisProp, mrModel.mxTextProp, true );
+        ObjectFormatter::convertTextRotation( aAxisProp, mrModel.mxTextProp, true );
 
         // tick mark style
         aAxisProp.setProperty( PROP_MajorTickmarks, lclGetTickMark( mrModel.mnMajorTickMark ) );
@@ -380,8 +378,6 @@ void AxisConverter::convertFromModel(
     }
 }
 
-
-
 AxisDispUnitsConverter::AxisDispUnitsConverter( const ConverterRoot& rParent, AxisDispUnitsModel& rModel ) :
     ConverterBase< AxisDispUnitsModel >( rParent, rModel )
 {
@@ -401,7 +397,6 @@ void AxisDispUnitsConverter::convertFromModel( const Reference< XAxis >& rxAxis
     }
 }
 
-
 } // namespace chart
 } // namespace drawingml
 } // namespace oox
