@@ -17,9 +17,11 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "drawingml/textliststylecontext.hxx"
-#include "drawingml/textparagraphpropertiescontext.hxx"
-#include "oox/helper/attributelist.hxx"
+#include <drawingml/textliststylecontext.hxx>
+#include <drawingml/textparagraphpropertiescontext.hxx>
+#include <oox/helper/attributelist.hxx>
+#include <oox/token/namespaces.hxx>
+#include <oox/token/tokens.hxx>
 
 using namespace ::oox::core;
 using namespace ::com::sun::star::uno;
@@ -28,7 +30,7 @@ using namespace ::com::sun::star::xml::sax;
 namespace oox { namespace drawingml {
 
 // CT_TextListStyle
-TextListStyleContext::TextListStyleContext( ContextHandler2Helper& rParent, TextListStyle& rTextListStyle )
+TextListStyleContext::TextListStyleContext( ContextHandler2Helper const & rParent, TextListStyle& rTextListStyle )
 : ContextHandler2( rParent )
 , mrTextListStyle( rTextListStyle )
 {
