@@ -19,12 +19,12 @@
 
 #include "timetargetelementcontext.hxx"
 
-#include "comphelper/anytostring.hxx"
-#include "cppuhelper/exc_hlp.hxx"
+#include <comphelper/anytostring.hxx>
+#include <cppuhelper/exc_hlp.hxx>
 #include <osl/diagnose.h>
 
-#include "oox/helper/attributelist.hxx"
-#include "drawingml/embeddedwavaudiofile.hxx"
+#include <oox/helper/attributelist.hxx>
+#include <drawingml/embeddedwavaudiofile.hxx>
 #include <oox/token/namespaces.hxx>
 #include <oox/token/tokens.hxx>
 
@@ -39,7 +39,7 @@ namespace oox { namespace ppt {
         : public FragmentHandler2
     {
     public:
-        ShapeTargetElementContext( FragmentHandler2& rParent, ShapeTargetElement & aValue )
+        ShapeTargetElementContext( FragmentHandler2 const & rParent, ShapeTargetElement & aValue )
             : FragmentHandler2( rParent )
                 , bTargetSet(false)
                 , maShapeTarget(aValue)
@@ -92,7 +92,7 @@ namespace oox { namespace ppt {
         ShapeTargetElement & maShapeTarget;
     };
 
-    TimeTargetElementContext::TimeTargetElementContext( FragmentHandler2& rParent, const AnimTargetElementPtr & pValue )
+    TimeTargetElementContext::TimeTargetElementContext( FragmentHandler2 const & rParent, const AnimTargetElementPtr & pValue )
         : FragmentHandler2( rParent ),
             mpTarget( pValue )
     {
