@@ -16,24 +16,28 @@
  *   except in compliance with the License. You may obtain a copy of
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
-#include "oox/vml/vmlformatting.hxx"
+#include <oox/vml/vmlformatting.hxx>
 
 #include <com/sun/star/beans/PropertyValue.hpp>
 #include <com/sun/star/beans/XPropertySet.hpp>
+#include <com/sun/star/drawing/XShape.hpp>
 #include <com/sun/star/drawing/EnhancedCustomShapeTextPathMode.hpp>
 #include <com/sun/star/table/ShadowFormat.hpp>
 #include <com/sun/star/text/XTextRange.hpp>
 #include <rtl/strbuf.hxx>
 #include <osl/diagnose.h>
-#include "oox/drawingml/color.hxx"
-#include "oox/drawingml/drawingmltypes.hxx"
-#include "oox/drawingml/fillproperties.hxx"
-#include "oox/drawingml/lineproperties.hxx"
-#include "oox/drawingml/shapepropertymap.hxx"
-#include "oox/helper/attributelist.hxx"
-#include "oox/helper/graphichelper.hxx"
+#include <oox/drawingml/color.hxx>
+#include <oox/drawingml/drawingmltypes.hxx>
+#include <drawingml/fillproperties.hxx>
+#include <drawingml/lineproperties.hxx>
+#include <oox/drawingml/shapepropertymap.hxx>
+#include <oox/helper/attributelist.hxx>
+#include <oox/helper/graphichelper.hxx>
 #include <oox/token/properties.hxx>
 #include <oox/token/tokens.hxx>
+#include <svx/svdtrans.hxx>
+#include <comphelper/propertysequence.hxx>
+#include <vcl/virdev.hxx>
 
 namespace oox {
 namespace vml {
@@ -109,6 +113,30 @@ double ConversionHelper::decodePercent( const OUString& rValue, double fDefValue
     return fDefValue;
 }
 
+sal_Int32 ConversionHelper::decodeRotation( const OUString& rValue )
+{
+    if( rValue.isEmpty() )
+        return 0;
+
+    double fValue = 0.0;
+    double fRotation = 0.0;
+    sal_Int32 nEndPos = 0;
+    if( !lclExtractDouble(fValue, nEndPos, rValue) )
+        return 0;
+
+    if( nEndPos == rValue.getLength() )
+        fRotation = fValue;
+    else if( (nEndPos + 2 == rValue.getLength()) && (rValue[nEndPos] == 'f') && (rValue[nEndPos+1] == 'd') )
+        fRotation = fValue / 65536.0;
+    else
+    {
+        OSL_FAIL("ConversionHelper::decodeRotation - unknown measure unit");
+        return 0;
+    }
+
+    return NormAngle360(fRotation * -100);
+}
+
 sal_Int64 ConversionHelper::decodeMeasureToEmu( const GraphicHelper& rGraphicHelper,
         const OUString& rValue, sal_Int32 nRefValue, bool bPixelX, bool bDefaultAsPixel )
 {
@@ -279,8 +307,8 @@ void ConversionHelper::decodeVmlPath( ::std::vector< ::std::vector< Point > >& r
                      LINE_REL, LINE_ABS, CLOSE, END, UNSUPPORTED };
     VML_State state = START;
 
-    rPointLists.push_back( ::std::vector< Point>() );
-    rFlagLists.push_back( ::std::vector< PolygonFlags >() );
+    rPointLists.emplace_back( );
+    rFlagLists.emplace_back( );
 
     for ( sal_Int32 i = 0; i < rPath.getLength(); i++ )
     {
@@ -311,36 +339,39 @@ void ConversionHelper::decodeVmlPath( ::std::vector< ::std::vector< Point > >& r
             {
                 switch ( state )
                 {
-                case MOVE_REL: // 2* params -> param count reset
+                case MOVE_REL:
+                    aCoordList.resize(2, 0); // 2* params -> param count reset
                     if ( rPointLists.size() > 0 && rPointLists.back().size() > 0 )
                     {
-                        rPointLists.push_back( ::std::vector< Point >() );
-                        rFlagLists.push_back( ::std::vector< PolygonFlags >() );
+                        rPointLists.emplace_back( );
+                        rFlagLists.emplace_back( );
                     }
-                    rPointLists.back().push_back( Point( aCoordList[ 0 ], aCoordList[ 1 ] ) );
+                    rPointLists.back().emplace_back( aCoordList[ 0 ], aCoordList[ 1 ] );
                     rFlagLists.back().push_back( PolygonFlags_NORMAL );
                     aCurrentPoint = rPointLists.back().back();
                     nParamCount = 2;
                     break;
 
-                case MOVE_ABS: // 2 params -> no param count reset
+                case MOVE_ABS:
+                    aCoordList.resize(2, 0); // 2 params -> no param count reset
                     if ( rPointLists.size() > 0 && rPointLists.back().size() > 0 )
                     {
-                        rPointLists.push_back( ::std::vector< Point >() );
-                        rFlagLists.push_back( ::std::vector< PolygonFlags >() );
+                        rPointLists.emplace_back( );
+                        rFlagLists.emplace_back( );
                     }
-                    rPointLists.back().push_back( Point( (aCoordList[ 0 ]), (aCoordList.size() > 1 ? aCoordList[ 1 ] : 0) ) );
+                    rPointLists.back().emplace_back( (aCoordList[ 0 ]), aCoordList[ 1 ] );
                     rFlagLists.back().push_back( PolygonFlags_NORMAL );
                     aCurrentPoint = rPointLists.back().back();
                     break;
 
-                case BEZIER_REL: // 6* params -> param count reset
-                    rPointLists.back().push_back( Point( aCurrentPoint.X + aCoordList[ 0 ],
-                                            aCurrentPoint.Y + aCoordList[ 1 ] ) );
-                    rPointLists.back().push_back( Point( aCurrentPoint.X + aCoordList[ 2 ],
-                                            aCurrentPoint.Y + aCoordList[ 3 ] ) );
-                    rPointLists.back().push_back( Point( aCurrentPoint.X + aCoordList[ 4 ],
-                                            aCurrentPoint.Y + aCoordList[ 5 ] ) );
+                case BEZIER_REL:
+                    aCoordList.resize(6, 0); // 6* params -> param count reset
+                    rPointLists.back().emplace_back( aCurrentPoint.X + aCoordList[ 0 ],
+                                            aCurrentPoint.Y + aCoordList[ 1 ] );
+                    rPointLists.back().emplace_back( aCurrentPoint.X + aCoordList[ 2 ],
+                                            aCurrentPoint.Y + aCoordList[ 3 ] );
+                    rPointLists.back().emplace_back( aCurrentPoint.X + aCoordList[ 4 ],
+                                            aCurrentPoint.Y + aCoordList[ 5 ] );
                     rFlagLists.back().push_back( PolygonFlags_CONTROL );
                     rFlagLists.back().push_back( PolygonFlags_CONTROL );
                     rFlagLists.back().push_back( PolygonFlags_NORMAL );
@@ -348,10 +379,11 @@ void ConversionHelper::decodeVmlPath( ::std::vector< ::std::vector< Point > >& r
                     nParamCount = 6;
                     break;
 
-                case BEZIER_ABS: // 6* params -> param count reset
-                    rPointLists.back().push_back( Point( aCoordList[ 0 ], aCoordList[ 1 ] ) );
-                    rPointLists.back().push_back( Point( aCoordList[ 2 ], aCoordList[ 3 ] ) );
-                    rPointLists.back().push_back( Point( aCoordList[ 4 ], aCoordList[ 5 ] ) );
+                case BEZIER_ABS:
+                    aCoordList.resize(6, 0); // 6* params -> param count reset
+                    rPointLists.back().emplace_back( aCoordList[ 0 ], aCoordList[ 1 ] );
+                    rPointLists.back().emplace_back( aCoordList[ 2 ], aCoordList[ 3 ] );
+                    rPointLists.back().emplace_back( aCoordList[ 4 ], aCoordList[ 5 ] );
                     rFlagLists.back().push_back( PolygonFlags_CONTROL );
                     rFlagLists.back().push_back( PolygonFlags_CONTROL );
                     rFlagLists.back().push_back( PolygonFlags_NORMAL );
@@ -359,16 +391,18 @@ void ConversionHelper::decodeVmlPath( ::std::vector< ::std::vector< Point > >& r
                     nParamCount = 6;
                     break;
 
-                case LINE_REL: // 2* params -> param count reset
-                    rPointLists.back().push_back( Point( aCurrentPoint.X + aCoordList[ 0 ],
-                                            aCurrentPoint.Y + aCoordList[ 1 ] ) );
+                case LINE_REL:
+                    aCoordList.resize(2, 0); // 2* params -> param count reset
+                    rPointLists.back().emplace_back( aCurrentPoint.X + aCoordList[ 0 ],
+                                            aCurrentPoint.Y + aCoordList[ 1 ] );
                     rFlagLists.back().push_back( PolygonFlags_NORMAL );
                     aCurrentPoint = rPointLists.back().back();
                     nParamCount = 2;
                     break;
 
-                case LINE_ABS: // 2* params -> param count reset
-                    rPointLists.back().push_back( Point( aCoordList[ 0 ], (aCoordList.size() > 1 ? aCoordList[ 1 ] : 0) ) );
+                case LINE_ABS:
+                    aCoordList.resize(2, 0); // 2* params -> param count reset
+                    rPointLists.back().emplace_back( aCoordList[ 0 ], (aCoordList.size() > 1 ? aCoordList[ 1 ] : 0) );
                     rFlagLists.back().push_back( PolygonFlags_NORMAL );
                     aCurrentPoint = rPointLists.back().back();
                     nParamCount = 2;
@@ -385,8 +419,8 @@ void ConversionHelper::decodeVmlPath( ::std::vector< ::std::vector< Point > >& r
                     break;
 
                 case END: // 0 param
-                    rPointLists.push_back( ::std::vector< Point >() );
-                    rFlagLists.push_back( ::std::vector< PolygonFlags >() );
+                    rPointLists.emplace_back( );
+                    rFlagLists.emplace_back( );
                     break;
 
                 case START:
@@ -398,7 +432,7 @@ void ConversionHelper::decodeVmlPath( ::std::vector< ::std::vector< Point > >& r
             }
 
             // Allow two-char commands to peek ahead to the next character
-            char nextChar = '\0';
+            sal_Unicode nextChar = '\0';
             if (i+1 < rPath.getLength())
                 nextChar = rPath[i+1];
 
@@ -533,7 +567,7 @@ void lclGetDmlLineDash( OptValue< sal_Int32 >& oroPresetDash, LineProperties::Da
                     aValues.push_back( rDashStyle.getToken( 0, ' ', nIndex ).toInt32() );
                 size_t nPairs = aValues.size() / 2; // ignore last value if size is odd
                 for( size_t nPairIdx = 0; nPairIdx < nPairs; ++nPairIdx )
-                    orCustomDash.push_back( LineProperties::DashStop( aValues[ 2 * nPairIdx ], aValues[ 2 * nPairIdx + 1 ] ) );
+                    orCustomDash.emplace_back( aValues[ 2 * nPairIdx ], aValues[ 2 * nPairIdx + 1 ] );
             }
         }
     }
@@ -682,6 +716,15 @@ void FillModel::assignUsed( const FillModel& rSource )
     moRotate.assignIfUsed( rSource.moRotate );
 }
 
+void lcl_setGradientStop( std::multimap< double, Color >& rMap, const double fKey, const Color& rValue ) {
+    auto aElement = rMap.find( fKey );
+
+    if (aElement != rMap.end())
+        aElement->second = rValue;
+    else
+        rMap.emplace( fKey, rValue );
+}
+
 void FillModel::pushToPropMap( ShapePropertyMap& rPropMap, const GraphicHelper& rGraphicHelper ) const
 {
     /*  Convert VML fill formatting to DrawingML fill formatting and let the
@@ -723,8 +766,10 @@ void FillModel::pushToPropMap( ShapePropertyMap& rPropMap, const GraphicHelper&
                         // simulate axial gradient by 3-step DrawingML gradient
                         const Color& rOuterColor = bOuterToInner ? aColor1 : aColor2;
                         const Color& rInnerColor = bOuterToInner ? aColor2 : aColor1;
-                        aFillProps.maGradientProps.maGradientStops[ 0.0 ] = aFillProps.maGradientProps.maGradientStops[ 1.0 ] = rOuterColor;
-                        aFillProps.maGradientProps.maGradientStops[ 0.5 ] = rInnerColor;
+
+                        lcl_setGradientStop( aFillProps.maGradientProps.maGradientStops, 0.0, rOuterColor);
+                        lcl_setGradientStop( aFillProps.maGradientProps.maGradientStops, 1.0, rOuterColor);
+                        lcl_setGradientStop( aFillProps.maGradientProps.maGradientStops, 0.5, rInnerColor );
                     }
                     else    // focus of -100%, 0%, and 100% is linear gradient
                     {
@@ -736,8 +781,8 @@ void FillModel::pushToPropMap( ShapePropertyMap& rPropMap, const GraphicHelper&
                         if( fFocus < -0.5 || fFocus > 0.5 )
                             (nVmlAngle += 180) %= 360;
                         // set the start and stop colors
-                        aFillProps.maGradientProps.maGradientStops[ 0.0 ] = aColor1;
-                        aFillProps.maGradientProps.maGradientStops[ 1.0 ] = aColor2;
+                        lcl_setGradientStop( aFillProps.maGradientProps.maGradientStops, 0.0, aColor1 );
+                        lcl_setGradientStop( aFillProps.maGradientProps.maGradientStops, 1.0, aColor2 );
                     }
 
                     // VML counts counterclockwise from bottom, DrawingML clockwise from left
@@ -762,8 +807,8 @@ void FillModel::pushToPropMap( ShapePropertyMap& rPropMap, const GraphicHelper&
 
                     // set the start and stop colors (focus of 0% means outer-to-inner)
                     bool bOuterToInner = (-0.5 <= fFocus) && (fFocus <= 0.5);
-                    aFillProps.maGradientProps.maGradientStops[ 0.0 ] = bOuterToInner ? aColor2 : aColor1;
-                    aFillProps.maGradientProps.maGradientStops[ 1.0 ] = bOuterToInner ? aColor1 : aColor2;
+                    lcl_setGradientStop( aFillProps.maGradientProps.maGradientStops, 0.0, bOuterToInner ? aColor2 : aColor1 );
+                    lcl_setGradientStop( aFillProps.maGradientProps.maGradientStops, 1.0, bOuterToInner ? aColor1 : aColor2 );
                 }
             }
             break;
@@ -830,7 +875,7 @@ void ShadowModel::pushToPropMap(ShapePropertyMap& rPropMap, const GraphicHelper&
     aFormat.Location = table::ShadowLocation_BOTTOM_RIGHT;
     // The width of the shadow is the average of the x and y values, see SwWW8ImplReader::MatchSdrItemsIntoFlySet().
     aFormat.ShadowWidth = ((nOffsetX + nOffsetY) / 2);
-    rPropMap.setProperty(PROP_ShadowFormat, uno::makeAny(aFormat));
+    rPropMap.setProperty(PROP_ShadowFormat, aFormat);
 }
 
 TextpathModel::TextpathModel()
@@ -839,15 +884,12 @@ TextpathModel::TextpathModel()
 
 beans::PropertyValue lcl_createTextpathProps()
 {
-    uno::Sequence<beans::PropertyValue> aTextpathPropSeq(4);
-    aTextpathPropSeq[0].Name = "TextPath";
-    aTextpathPropSeq[0].Value <<= true;
-    aTextpathPropSeq[1].Name = "TextPathMode";
-    aTextpathPropSeq[1].Value <<= drawing::EnhancedCustomShapeTextPathMode_SHAPE;
-    aTextpathPropSeq[2].Name = "ScaleX";
-    aTextpathPropSeq[2].Value <<= false;
-    aTextpathPropSeq[3].Name = "SameLetterHeights";
-    aTextpathPropSeq[3].Value <<= false;
+    uno::Sequence<beans::PropertyValue> aTextpathPropSeq( comphelper::InitPropertySequence({
+            { "TextPath", uno::Any(true) },
+            { "TextPathMode", uno::Any(drawing::EnhancedCustomShapeTextPathMode_SHAPE) },
+            { "ScaleX", uno::Any(false) },
+            { "SameLetterHeights", uno::Any(false) }
+        }));
 
     beans::PropertyValue aRet;
     aRet.Name = "TextPath";
@@ -855,8 +897,10 @@ beans::PropertyValue lcl_createTextpathProps()
     return aRet;
 }
 
-void TextpathModel::pushToPropMap(ShapePropertyMap& rPropMap, const uno::Reference<drawing::XShape>& xShape) const
+void TextpathModel::pushToPropMap(ShapePropertyMap& rPropMap, const uno::Reference<drawing::XShape>& xShape, const GraphicHelper& rGraphicHelper) const
 {
+    OUString sFont = "";
+
     if (moString.has())
     {
         uno::Reference<text::XTextRange> xTextRange(xShape, uno::UNO_QUERY);
@@ -882,6 +926,57 @@ void TextpathModel::pushToPropMap(ShapePropertyMap& rPropMap, const uno::Referen
         }
         rPropMap.setAnyProperty(PROP_CustomShapeGeometry, uno::makeAny(aGeomPropSeq));
     }
+    if (moStyle.has())
+    {
+        OUString aStyle = moStyle.get(OUString());
+
+        sal_Int32 nIndex = 0;
+        while( nIndex >= 0 )
+        {
+            OUString aName, aValue;
+            if (ConversionHelper::separatePair(aName, aValue, aStyle.getToken(0, ';', nIndex), ':'))
+            {
+                if (aName == "font-family")
+                {
+                    // remove " (first, and last character)
+                    if (aValue.getLength() > 2)
+                        aValue = aValue.copy(1, aValue.getLength() - 2);
+
+                    uno::Reference<beans::XPropertySet> xPropertySet(xShape, uno::UNO_QUERY);
+                    xPropertySet->setPropertyValue("CharFontName", uno::makeAny(aValue));
+                    sFont = aValue;
+                }
+                else if (aName == "font-size")
+                {
+                    oox::OptValue<OUString> aOptString(aValue);
+                    float nSize = drawingml::convertEmuToPoints(lclGetEmu(rGraphicHelper, aOptString, 1));
+
+                    uno::Reference<beans::XPropertySet> xPropertySet(xShape, uno::UNO_QUERY);
+                    xPropertySet->setPropertyValue("CharHeight", uno::makeAny(nSize));
+                }
+            }
+        }
+    }
+    if (!moTrim.has() || !moTrim.get())
+    {
+        OUString sText = moString.get();
+        double fRatio = 0;
+        VclPtr<VirtualDevice> pDevice = VclPtr<VirtualDevice>::Create();
+        vcl::Font aFont = pDevice->GetFont();
+        aFont.SetFamilyName(sFont);
+        aFont.SetFontSize(Size(0, 96));
+        pDevice->SetFont(aFont);
+
+        auto nTextWidth = pDevice->GetTextWidth(sText);
+        if (nTextWidth)
+        {
+            fRatio = pDevice->GetTextHeight();
+            fRatio /= nTextWidth;
+
+            sal_Int32 nNewHeight = fRatio * xShape->getSize().Width;
+            xShape->setSize(awt::Size(xShape->getSize().Width, nNewHeight));
+        }
+    }
 }
 
 } // namespace vml
