@@ -17,9 +17,11 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
+#include <memory>
 #include <ZipPackageStream.hxx>
 
 #include <com/sun/star/beans/PropertyValue.hpp>
+#include <com/sun/star/packages/NoRawFormatException.hpp>
 #include <com/sun/star/packages/zip/ZipConstants.hpp>
 #include <com/sun/star/embed/StorageFormats.hpp>
 #include <com/sun/star/packages/zip/ZipIOException.hpp>
@@ -139,17 +141,7 @@ void ZipPackageStream::setZipEntryOnLoading( const ZipEntry &rInEntry )
         m_bToBeCompressed = false;
 }
 
-void ZipPackageStream::CloseOwnStreamIfAny()
-{
-    if ( m_xStream.is() )
-    {
-        m_xStream->closeInput();
-        m_xStream.clear();
-        m_bHasSeekable = false;
-    }
-}
-
-uno::Reference< io::XInputStream > ZipPackageStream::GetOwnSeekStream()
+uno::Reference< io::XInputStream > const & ZipPackageStream::GetOwnSeekStream()
 {
     if ( !m_bHasSeekable && m_xStream.is() )
     {
@@ -158,9 +150,7 @@ uno::Reference< io::XInputStream > ZipPackageStream::GetOwnSeekStream()
         // is accessed before commit it MUST be wrapped.
         // Wrap the stream in case it is not seekable
         m_xStream = ::comphelper::OSeekableInputWrapper::CheckSeekableCanWrap( m_xStream, m_xContext );
-        uno::Reference< io::XSeekable > xSeek( m_xStream, UNO_QUERY );
-        if ( !xSeek.is() )
-            throw RuntimeException( THROW_WHERE "The stream must support XSeekable!" );
+        uno::Reference< io::XSeekable > xSeek( m_xStream, UNO_QUERY_THROW );
 
         m_bHasSeekable = true;
     }
@@ -187,7 +177,7 @@ uno::Reference< io::XInputStream > ZipPackageStream::GetRawEncrStreamNoHeaderCop
     // create temporary stream
     uno::Reference < io::XTempFile > xTempFile = io::TempFile::create(m_xContext);
     uno::Reference < io::XOutputStream > xTempOut = xTempFile->getOutputStream();
-    uno::Reference < io::XInputStream > xTempIn = xTempFile->getInputStream();;
+    uno::Reference < io::XInputStream > xTempIn = xTempFile->getInputStream();
     uno::Reference < io::XSeekable > xTempSeek( xTempOut, UNO_QUERY_THROW );
 
     // copy the raw stream to the temporary file starting from the current position
@@ -208,26 +198,27 @@ sal_Int32 ZipPackageStream::GetBlockSize() const
     return GetEncryptionAlgorithm() == css::xml::crypto::CipherID::AES_CBC_W3C_PADDING ? 16 : 8;
 }
 
-::rtl::Reference< EncryptionData > ZipPackageStream::GetEncryptionData( bool bUseWinEncoding )
+::rtl::Reference<EncryptionData> ZipPackageStream::GetEncryptionData(Bugs const bugs)
 {
     ::rtl::Reference< EncryptionData > xResult;
     if ( m_xBaseEncryptionData.is() )
         xResult = new EncryptionData(
             *m_xBaseEncryptionData,
-            GetEncryptionKey( bUseWinEncoding ),
+            GetEncryptionKey(bugs),
             GetEncryptionAlgorithm(),
             m_nImportedChecksumAlgorithm ? m_nImportedChecksumAlgorithm : m_rZipPackage.GetChecksumAlgID(),
             m_nImportedDerivedKeySize ? m_nImportedDerivedKeySize : m_rZipPackage.GetDefaultDerivedKeySize(),
-            GetStartKeyGenID() );
+            GetStartKeyGenID(),
+            bugs != Bugs::None);
 
     return xResult;
 }
 
-uno::Sequence< sal_Int8 > ZipPackageStream::GetEncryptionKey( bool bUseWinEncoding )
+uno::Sequence<sal_Int8> ZipPackageStream::GetEncryptionKey(Bugs const bugs)
 {
     uno::Sequence< sal_Int8 > aResult;
     sal_Int32 nKeyGenID = GetStartKeyGenID();
-    bUseWinEncoding = ( bUseWinEncoding || m_bUseWinEncoding );
+    bool const bUseWinEncoding = (bugs == Bugs::WinEncodingWrongSHA1 || m_bUseWinEncoding);
 
     if ( m_bHaveOwnKey && m_aStorageEncryptionKeys.getLength() )
     {
@@ -236,13 +227,17 @@ uno::Sequence< sal_Int8 > ZipPackageStream::GetEncryptionKey( bool bUseWinEncodi
             aNameToFind = PACKAGE_ENCRYPTIONDATA_SHA256UTF8;
         else if ( nKeyGenID == xml::crypto::DigestID::SHA1 )
         {
-            aNameToFind = bUseWinEncoding ? OUString(PACKAGE_ENCRYPTIONDATA_SHA1MS1252) : OUString(PACKAGE_ENCRYPTIONDATA_SHA1UTF8);
+            aNameToFind = bUseWinEncoding
+                ? OUString(PACKAGE_ENCRYPTIONDATA_SHA1MS1252)
+                : (bugs == Bugs::WrongSHA1)
+                    ? OUString(PACKAGE_ENCRYPTIONDATA_SHA1UTF8)
+                    : OUString(PACKAGE_ENCRYPTIONDATA_SHA1CORRECT);
         }
         else
             throw uno::RuntimeException(THROW_WHERE "No expected key is provided!" );
 
         for ( sal_Int32 nInd = 0; nInd < m_aStorageEncryptionKeys.getLength(); nInd++ )
-            if ( m_aStorageEncryptionKeys[nInd].Name.equals( aNameToFind ) )
+            if ( m_aStorageEncryptionKeys[nInd].Name == aNameToFind )
                 m_aStorageEncryptionKeys[nInd].Value >>= aResult;
 
         // empty keys are not allowed here
@@ -298,16 +293,11 @@ uno::Reference< io::XInputStream > ZipPackageStream::TryToGetRawFromDataStream(
         pPackage->initialize( aArgs );
 
         // create a new package stream
-        uno::Reference< XDataSinkEncrSupport > xNewPackStream( xPackageAsFactory->createInstance(), UNO_QUERY );
-        if ( !xNewPackStream.is() )
-            throw RuntimeException(THROW_WHERE );
-
+        uno::Reference< XDataSinkEncrSupport > xNewPackStream( xPackageAsFactory->createInstance(), UNO_QUERY_THROW );
         xNewPackStream->setDataStream( static_cast< io::XInputStream* >(
                                                     new WrapStreamForShare( GetOwnSeekStream(), m_rZipPackage.GetSharedMutexRef() ) ) );
 
-        uno::Reference< XPropertySet > xNewPSProps( xNewPackStream, UNO_QUERY );
-        if ( !xNewPSProps.is() )
-            throw RuntimeException(THROW_WHERE );
+        uno::Reference< XPropertySet > xNewPSProps( xNewPackStream, UNO_QUERY_THROW );
 
         // copy all the properties of this stream to the new stream
         xNewPSProps->setPropertyValue("MediaType", makeAny( msMediaType ) );
@@ -322,9 +312,7 @@ uno::Reference< io::XInputStream > ZipPackageStream::TryToGetRawFromDataStream(
         uno::Reference< XUnoTunnel > xTunnel;
         Any aRoot = pPackage->getByHierarchicalName("/");
         aRoot >>= xTunnel;
-        uno::Reference< container::XNameContainer > xRootNameContainer( xTunnel, UNO_QUERY );
-        if ( !xRootNameContainer.is() )
-            throw RuntimeException(THROW_WHERE );
+        uno::Reference< container::XNameContainer > xRootNameContainer( xTunnel, UNO_QUERY_THROW );
 
         uno::Reference< XUnoTunnel > xNPSTunnel( xNewPackStream, UNO_QUERY );
         xRootNameContainer->insertByName("dummy", makeAny( xNPSTunnel ) );
@@ -375,7 +363,7 @@ uno::Reference< io::XInputStream > ZipPackageStream::TryToGetRawFromDataStream(
 
 bool ZipPackageStream::ParsePackageRawStream()
 {
-    OSL_ENSURE( GetOwnSeekStream().is(), "A stream must be provided!\n" );
+    OSL_ENSURE( GetOwnSeekStream().is(), "A stream must be provided!" );
 
     if ( !GetOwnSeekStream().is() )
         return false;
@@ -466,9 +454,10 @@ class DeflateThread: public comphelper::ThreadTask
     uno::Reference< io::XInputStream > mxInStream;
 
 public:
-    DeflateThread( ZipOutputEntry *pEntry,
+    DeflateThread( const std::shared_ptr<comphelper::ThreadTaskTag>& pTag, ZipOutputEntry *pEntry,
                    const uno::Reference< io::XInputStream >& xInStream )
-        : mpEntry(pEntry)
+        : comphelper::ThreadTask(pTag)
+        , mpEntry(pEntry)
         , mxInStream(xInStream)
     {}
 
@@ -501,7 +490,7 @@ private:
     }
 };
 
-static void ImplSetStoredData( ZipEntry & rEntry, uno::Reference< io::XInputStream> & rStream )
+static void ImplSetStoredData( ZipEntry & rEntry, uno::Reference< io::XInputStream> const & rStream )
 {
     // It's very annoying that we have to do this, but lots of zip packages
     // don't allow data descriptors for STORED streams, meaning we have to
@@ -518,6 +507,7 @@ bool ZipPackageStream::saveChild(
         std::vector < uno::Sequence < beans::PropertyValue > > &rManList,
         ZipOutputStream & rZipOut,
         const uno::Sequence < sal_Int8 >& rEncryptionKey,
+        sal_Int32 nPBKDF2IterationCount,
         const rtlRandomPool &rRandomPool)
 {
     bool bSuccess = true;
@@ -537,15 +527,14 @@ bool ZipPackageStream::saveChild(
 
     uno::Sequence < beans::PropertyValue > aPropSet (PKG_SIZE_NOENCR_MNFST);
 
-    // if pTempEntry is necessary, it will be released and passed to the ZipOutputStream
-    // and be deleted in the ZipOutputStream destructor
-    std::unique_ptr < ZipEntry > pAutoTempEntry ( new ZipEntry );
-    ZipEntry* pTempEntry = pAutoTempEntry.get();
-
     // In case the entry we are reading is also the entry we are writing, we will
     // store the ZipEntry data in pTempEntry
 
-    ZipPackageFolder::copyZipEntry ( *pTempEntry, aEntry );
+    // if pTempEntry is necessary, it will be released and passed to the ZipOutputStream
+    // and be deleted in the ZipOutputStream destructor
+    std::unique_ptr < ZipEntry > pAutoTempEntry ( new ZipEntry(aEntry) );
+    ZipEntry* pTempEntry = pAutoTempEntry.get();
+
     pTempEntry->sPath = rPath;
     pTempEntry->nPathLen = (sal_Int16)( OUStringToOString( pTempEntry->sPath, RTL_TEXTENCODING_UTF8 ).getLength() );
 
@@ -608,7 +597,7 @@ bool ZipPackageStream::saveChild(
                 if ( !bToBeCompressed || m_bRawStream )
                 {
                     // The raw stream can neither be encrypted nor connected
-                    OSL_ENSURE( !m_bRawStream || !(bToBeCompressed || bToBeEncrypted), "The stream is already encrypted!\n" );
+                    OSL_ENSURE( !m_bRawStream || !(bToBeCompressed || bToBeEncrypted), "The stream is already encrypted!" );
                     xSeek->seek ( m_bRawStream ? m_nMagicalHackPos : 0 );
                     ImplSetStoredData ( *pTempEntry, xStream );
 
@@ -664,8 +653,6 @@ bool ZipPackageStream::saveChild(
                 uno::Sequence < sal_Int8 > aSalt( 16 ), aVector( GetBlockSize() );
                 rtl_random_getBytes ( rRandomPool, aSalt.getArray(), 16 );
                 rtl_random_getBytes ( rRandomPool, aVector.getArray(), aVector.getLength() );
-                sal_Int32 nIterationCount = 1024;
-
                 if ( !m_bHaveOwnKey )
                 {
                     m_aEncryptionKey = rEncryptionKey;
@@ -674,7 +661,7 @@ bool ZipPackageStream::saveChild(
 
                 setInitialisationVector ( aVector );
                 setSalt ( aSalt );
-                setIterationCount ( nIterationCount );
+                setIterationCount(nPBKDF2IterationCount);
             }
 
             // last property is digest, which is inserted later if we didn't have
@@ -689,7 +676,7 @@ bool ZipPackageStream::saveChild(
             aPropSet[PKG_MNFST_ITERATION].Value <<= m_xBaseEncryptionData->m_nIterationCount;
 
             // Need to store the uncompressed size in the manifest
-            OSL_ENSURE( m_nOwnStreamOrigSize >= 0, "The stream size was not correctly initialized!\n" );
+            OSL_ENSURE( m_nOwnStreamOrigSize >= 0, "The stream size was not correctly initialized!" );
             aPropSet[PKG_MNFST_UCOMPSIZE].Name = sSizeProperty;
             aPropSet[PKG_MNFST_UCOMPSIZE].Value <<= m_nOwnStreamOrigSize;
 
@@ -801,7 +788,7 @@ bool ZipPackageStream::saveChild(
         uno::Reference< io::XSeekable > xSeek(xStream, uno::UNO_QUERY);
         // It's not worth to deflate jpegs to save ~1% in a slow process
         // Unfortunately, does not work for streams protected by password
-        if (xSeek.is() && msMediaType.endsWith("/jpeg") && !m_bToBeEncrypted)
+        if (xSeek.is() && msMediaType.endsWith("/jpeg") && !m_bToBeEncrypted && !m_bToBeCompressed)
         {
             ImplSetStoredData(*pTempEntry, xStream);
             xSeek->seek(0);
@@ -844,12 +831,12 @@ bool ZipPackageStream::saveChild(
                     // 2nd parameter is the time to wait between cleanups in 10th of a second.
                     // Both values may be added to the configuration settings if needed.
                     static sal_Int32 nAllowedThreads(comphelper::ThreadPool::getPreferredConcurrency() * 4);
-                    rZipOut.reduceScheduledThreadsToGivenNumberOrLess(nAllowedThreads, 1);
+                    rZipOut.reduceScheduledThreadsToGivenNumberOrLess(nAllowedThreads);
 
                     // Start a new thread deflating this zip entry
                     ZipOutputEntry *pZipEntry = new ZipOutputEntry(
                             m_xContext, *pTempEntry, this, bToBeEncrypted);
-                    rZipOut.addDeflatingThread( pZipEntry, new DeflateThread(pZipEntry, xStream) );
+                    rZipOut.addDeflatingThread( pZipEntry, new DeflateThread(rZipOut.getThreadTaskTag(), pZipEntry, xStream) );
                 }
                 else
                 {
@@ -900,11 +887,16 @@ bool ZipPackageStream::saveChild(
     return bSuccess;
 }
 
-void ZipPackageStream::successfullyWritten( ZipEntry *pEntry )
+void ZipPackageStream::successfullyWritten( ZipEntry const *pEntry )
 {
     if ( !IsPackageMember() )
     {
-        CloseOwnStreamIfAny();
+        if ( m_xStream.is() )
+        {
+            m_xStream->closeInput();
+            m_xStream.clear();
+            m_bHasSeekable = false;
+        }
         SetPackageMember ( true );
     }
 
@@ -916,10 +908,10 @@ void ZipPackageStream::successfullyWritten( ZipEntry *pEntry )
     }
 
     // Then copy it back afterwards...
-    ZipPackageFolder::copyZipEntry( aEntry, *pEntry );
+    aEntry = *pEntry;
 
     // TODO/LATER: get rid of this hack ( the encrypted stream size property is changed during saving )
-    if ( IsEncrypted() )
+    if ( m_bIsEncrypted )
         setSize( m_nOwnStreamOrigSize );
 
     aEntry.nOffset *= -1;
@@ -939,7 +931,6 @@ void ZipPackageStream::SetPackageMember( bool bNewValue )
 
 // XActiveDataSink
 void SAL_CALL ZipPackageStream::setInputStream( const uno::Reference< io::XInputStream >& aStream )
-        throw( RuntimeException, std::exception )
 {
     // if seekable access is required the wrapping will be done on demand
     m_xStream = aStream;
@@ -951,13 +942,12 @@ void SAL_CALL ZipPackageStream::setInputStream( const uno::Reference< io::XInput
 }
 
 uno::Reference< io::XInputStream > SAL_CALL ZipPackageStream::getRawData()
-        throw( RuntimeException )
 {
     try
     {
         if ( IsPackageMember() )
         {
-            return m_rZipPackage.getZipFile().getRawData( aEntry, GetEncryptionData(), m_bIsEncrypted, m_rZipPackage.GetSharedMutexRef() );
+            return m_rZipPackage.getZipFile().getRawData( aEntry, GetEncryptionData(), m_bIsEncrypted, m_rZipPackage.GetSharedMutexRef(), false/*bUseBufferedStream*/ );
         }
         else if ( GetOwnSeekStream().is() )
         {
@@ -973,13 +963,12 @@ uno::Reference< io::XInputStream > SAL_CALL ZipPackageStream::getRawData()
     }
     catch ( Exception & )
     {
-        OSL_FAIL( "Exception is thrown during stream wrapping!\n" );
+        OSL_FAIL( "Exception is thrown during stream wrapping!" );
         return uno::Reference < io::XInputStream > ();
     }
 }
 
 uno::Reference< io::XInputStream > SAL_CALL ZipPackageStream::getInputStream()
-        throw( RuntimeException, std::exception )
 {
     try
     {
@@ -1001,18 +990,13 @@ uno::Reference< io::XInputStream > SAL_CALL ZipPackageStream::getInputStream()
     }
     catch ( Exception &ex )
     {
-        OSL_FAIL( "Exception is thrown during stream wrapping!\n" );
-        OSL_FAIL(OUStringToOString(ex.Message, RTL_TEXTENCODING_UTF8).getStr());
-        (void)ex;
+        SAL_WARN( "package", "Exception is thrown during stream wrapping!" << ex);
         return uno::Reference < io::XInputStream > ();
     }
 }
 
 // XDataSinkEncrSupport
 uno::Reference< io::XInputStream > SAL_CALL ZipPackageStream::getDataStream()
-        throw ( packages::WrongPasswordException, ZipException,
-                io::IOException,
-                RuntimeException, std::exception )
 {
     // There is no stream attached to this object
     if ( m_nStreamMode == PACKAGE_STREAM_NOTSET )
@@ -1027,12 +1011,23 @@ uno::Reference< io::XInputStream > SAL_CALL ZipPackageStream::getDataStream()
         uno::Reference< io::XInputStream > xResult;
         try
         {
-            xResult = m_rZipPackage.getZipFile().getDataStream( aEntry, GetEncryptionData(), m_bIsEncrypted, m_rZipPackage.GetSharedMutexRef() );
+            xResult = m_rZipPackage.getZipFile().getDataStream( aEntry, GetEncryptionData(Bugs::None), m_bIsEncrypted, m_rZipPackage.GetSharedMutexRef() );
         }
         catch( const packages::WrongPasswordException& )
         {
             if ( m_rZipPackage.GetStartKeyGenID() == xml::crypto::DigestID::SHA1 )
             {
+                SAL_WARN("package", "ZipPackageStream::getDataStream(): SHA1 mismatch, trying fallbacks...");
+                try
+                {   // tdf#114939 try with legacy StarOffice SHA1 bug
+                    xResult = m_rZipPackage.getZipFile().getDataStream( aEntry, GetEncryptionData(Bugs::WrongSHA1), m_bIsEncrypted, m_rZipPackage.GetSharedMutexRef() );
+                    return xResult;
+                }
+                catch (const packages::WrongPasswordException&)
+                {
+                    /* ignore and try next... */
+                }
+
                 try
                 {
                     // rhbz#1013844 / fdo#47482 workaround for the encrypted
@@ -1055,7 +1050,7 @@ uno::Reference< io::XInputStream > SAL_CALL ZipPackageStream::getDataStream()
                 // workaround for the encrypted documents generated with the old OOo1.x bug.
                 if ( !m_bUseWinEncoding )
                 {
-                    xResult = m_rZipPackage.getZipFile().getDataStream( aEntry, GetEncryptionData( true ), m_bIsEncrypted, m_rZipPackage.GetSharedMutexRef() );
+                    xResult = m_rZipPackage.getZipFile().getDataStream( aEntry, GetEncryptionData(Bugs::WinEncodingWrongSHA1), m_bIsEncrypted, m_rZipPackage.GetSharedMutexRef() );
                     m_bUseWinEncoding = true;
                 }
                 else
@@ -1067,7 +1062,7 @@ uno::Reference< io::XInputStream > SAL_CALL ZipPackageStream::getDataStream()
         return xResult;
     }
     else if ( m_nStreamMode == PACKAGE_STREAM_RAW )
-        return ZipFile::StaticGetDataFromRawStream( m_xContext, GetOwnSeekStream(), GetEncryptionData() );
+        return ZipFile::StaticGetDataFromRawStream( m_rZipPackage.GetSharedMutexRef(), m_xContext, GetOwnSeekStream(), GetEncryptionData() );
     else if ( GetOwnSeekStream().is() )
     {
         return new WrapStreamForShare( GetOwnSeekStream(), m_rZipPackage.GetSharedMutexRef() );
@@ -1077,9 +1072,6 @@ uno::Reference< io::XInputStream > SAL_CALL ZipPackageStream::getDataStream()
 }
 
 uno::Reference< io::XInputStream > SAL_CALL ZipPackageStream::getRawStream()
-        throw ( packages::NoEncryptionException,
-                io::IOException,
-                uno::RuntimeException, std::exception )
 {
     // There is no stream attached to this object
     if ( m_nStreamMode == PACKAGE_STREAM_NOTSET )
@@ -1110,25 +1102,16 @@ uno::Reference< io::XInputStream > SAL_CALL ZipPackageStream::getRawStream()
 }
 
 void SAL_CALL ZipPackageStream::setDataStream( const uno::Reference< io::XInputStream >& aStream )
-        throw ( io::IOException,
-                RuntimeException, std::exception )
 {
     setInputStream( aStream );
     m_nStreamMode = PACKAGE_STREAM_DATA;
 }
 
 void SAL_CALL ZipPackageStream::setRawStream( const uno::Reference< io::XInputStream >& aStream )
-        throw ( packages::EncryptionNotAllowedException,
-                packages::NoRawFormatException,
-                io::IOException,
-                RuntimeException, std::exception )
 {
     // wrap the stream in case it is not seekable
     uno::Reference< io::XInputStream > xNewStream = ::comphelper::OSeekableInputWrapper::CheckSeekableCanWrap( aStream, m_xContext );
-    uno::Reference< io::XSeekable > xSeek( xNewStream, UNO_QUERY );
-    if ( !xSeek.is() )
-        throw RuntimeException(THROW_WHERE "The stream must support XSeekable!" );
-
+    uno::Reference< io::XSeekable > xSeek( xNewStream, UNO_QUERY_THROW );
     xSeek->seek( 0 );
     uno::Reference< io::XInputStream > xOldStream = m_xStream;
     m_xStream = xNewStream;
@@ -1147,8 +1130,6 @@ void SAL_CALL ZipPackageStream::setRawStream( const uno::Reference< io::XInputSt
 }
 
 uno::Reference< io::XInputStream > SAL_CALL ZipPackageStream::getPlainRawStream()
-        throw ( io::IOException, packages::NoEncryptionException,
-                uno::RuntimeException, std::exception )
 {
     // There is no stream attached to this object
     if ( m_nStreamMode == PACKAGE_STREAM_NOTSET )
@@ -1179,7 +1160,6 @@ uno::Reference< io::XInputStream > SAL_CALL ZipPackageStream::getPlainRawStream(
 // XUnoTunnel
 
 sal_Int64 SAL_CALL ZipPackageStream::getSomething( const Sequence< sal_Int8 >& aIdentifier )
-    throw( RuntimeException, std::exception )
 {
     sal_Int64 nMe = 0;
     if ( aIdentifier.getLength() == 16 &&
@@ -1190,29 +1170,25 @@ sal_Int64 SAL_CALL ZipPackageStream::getSomething( const Sequence< sal_Int8 >& a
 
 // XPropertySet
 void SAL_CALL ZipPackageStream::setPropertyValue( const OUString& aPropertyName, const Any& aValue )
-        throw( beans::UnknownPropertyException, beans::PropertyVetoException, IllegalArgumentException, WrappedTargetException, RuntimeException, std::exception )
 {
     if ( aPropertyName == "MediaType" )
     {
         if ( m_rZipPackage.getFormat() != embed::StorageFormats::PACKAGE && m_rZipPackage.getFormat() != embed::StorageFormats::OFOPXML )
             throw beans::PropertyVetoException(THROW_WHERE );
 
-        if ( aValue >>= msMediaType )
-        {
-            if ( !msMediaType.isEmpty() )
-            {
-                if ( msMediaType.indexOf ( "text" ) != -1
-                 || msMediaType == "application/vnd.sun.star.oleobject" )
-                    m_bToBeCompressed = true;
-                else if ( !m_bCompressedIsSetFromOutside )
-                    m_bToBeCompressed = false;
-            }
-        }
-        else
+        if ( !(aValue >>= msMediaType) )
             throw IllegalArgumentException(THROW_WHERE "MediaType must be a string!",
                                             uno::Reference< XInterface >(),
                                             2 );
 
+        if ( !msMediaType.isEmpty() )
+        {
+            if ( msMediaType.indexOf ( "text" ) != -1
+             || msMediaType == "application/vnd.sun.star.oleobject" )
+                m_bToBeCompressed = true;
+            else if ( !m_bCompressedIsSetFromOutside )
+                m_bToBeCompressed = false;
+        }
     }
     else if ( aPropertyName == "Size" )
     {
@@ -1227,23 +1203,21 @@ void SAL_CALL ZipPackageStream::setPropertyValue( const OUString& aPropertyName,
             throw beans::PropertyVetoException(THROW_WHERE );
 
         bool bEnc = false;
-        if ( aValue >>= bEnc )
-        {
-            // In case of new raw stream, the stream must not be encrypted on storing
-            if ( bEnc && m_nStreamMode == PACKAGE_STREAM_RAW )
-                throw IllegalArgumentException(THROW_WHERE "Raw stream can not be encrypted on storing",
-                                                uno::Reference< XInterface >(),
-                                                2 );
-
-            m_bToBeEncrypted = bEnc;
-            if ( m_bToBeEncrypted && !m_xBaseEncryptionData.is() )
-                m_xBaseEncryptionData = new BaseEncryptionData;
-        }
-        else
+        if ( !(aValue >>= bEnc) )
             throw IllegalArgumentException(THROW_WHERE "Wrong type for Encrypted property!",
                                             uno::Reference< XInterface >(),
                                             2 );
 
+        // In case of new raw stream, the stream must not be encrypted on storing
+        if ( bEnc && m_nStreamMode == PACKAGE_STREAM_RAW )
+            throw IllegalArgumentException(THROW_WHERE "Raw stream can not be encrypted on storing",
+                                            uno::Reference< XInterface >(),
+                                            2 );
+
+        m_bToBeEncrypted = bEnc;
+        if ( m_bToBeEncrypted && !m_xBaseEncryptionData.is() )
+            m_xBaseEncryptionData = new BaseEncryptionData;
+
     }
     else if ( aPropertyName == ENCRYPTION_KEY_PROPERTY )
     {
@@ -1255,20 +1229,18 @@ void SAL_CALL ZipPackageStream::setPropertyValue( const OUString& aPropertyName,
         if ( !( aValue >>= aNewKey ) )
         {
             OUString sTempString;
-            if ( ( aValue >>= sTempString ) )
-            {
-                sal_Int32 nPathLength = sTempString.getLength();
-                Sequence < sal_Int8 > aSequence ( nPathLength );
-                sal_Int8 *pArray = aSequence.getArray();
-                const sal_Unicode *pChar = sTempString.getStr();
-                for ( sal_Int32 i = 0; i < nPathLength; i++ )
-                    pArray[i] = static_cast < const sal_Int8 > ( pChar[i] );
-                aNewKey = aSequence;
-            }
-            else
+            if ( !(aValue >>= sTempString) )
                 throw IllegalArgumentException(THROW_WHERE "Wrong type for EncryptionKey property!",
                                                 uno::Reference< XInterface >(),
                                                 2 );
+
+            sal_Int32 nPathLength = sTempString.getLength();
+            Sequence < sal_Int8 > aSequence ( nPathLength );
+            sal_Int8 *pArray = aSequence.getArray();
+            const sal_Unicode *pChar = sTempString.getStr();
+            for ( sal_Int32 i = 0; i < nPathLength; i++ )
+                pArray[i] = static_cast < sal_Int8 > ( pChar[i] );
+            aNewKey = aSequence;
         }
 
         if ( aNewKey.getLength() )
@@ -1327,28 +1299,25 @@ void SAL_CALL ZipPackageStream::setPropertyValue( const OUString& aPropertyName,
     {
         bool bCompr = false;
 
-        if ( aValue >>= bCompr )
-        {
-            // In case of new raw stream, the stream must not be encrypted on storing
-            if ( bCompr && m_nStreamMode == PACKAGE_STREAM_RAW )
-                throw IllegalArgumentException(THROW_WHERE "Raw stream can not be encrypted on storing",
-                                                uno::Reference< XInterface >(),
-                                                2 );
-
-            m_bToBeCompressed = bCompr;
-            m_bCompressedIsSetFromOutside = true;
-        }
-        else
+        if ( !(aValue >>= bCompr) )
             throw IllegalArgumentException(THROW_WHERE "Wrong type for Compressed property!",
                                             uno::Reference< XInterface >(),
                                             2 );
+
+        // In case of new raw stream, the stream must not be encrypted on storing
+        if ( bCompr && m_nStreamMode == PACKAGE_STREAM_RAW )
+            throw IllegalArgumentException(THROW_WHERE "Raw stream can not be encrypted on storing",
+                                            uno::Reference< XInterface >(),
+                                            2 );
+
+        m_bToBeCompressed = bCompr;
+        m_bCompressedIsSetFromOutside = true;
     }
     else
         throw beans::UnknownPropertyException(THROW_WHERE );
 }
 
 Any SAL_CALL ZipPackageStream::getPropertyValue( const OUString& PropertyName )
-        throw( beans::UnknownPropertyException, WrappedTargetException, RuntimeException, std::exception )
 {
     if ( PropertyName == "MediaType" )
     {
@@ -1389,20 +1358,17 @@ void ZipPackageStream::setSize ( const sal_Int64 nNewSize )
     aEntry.nSize = nNewSize;
 }
 OUString ZipPackageStream::getImplementationName()
-    throw ( RuntimeException, std::exception )
 {
     return OUString ("ZipPackageStream");
 }
 
 Sequence< OUString > ZipPackageStream::getSupportedServiceNames()
-    throw ( RuntimeException, std::exception )
 {
     Sequence<OUString> aNames { "com.sun.star.packages.PackageStream" };
     return aNames;
 }
 
 sal_Bool SAL_CALL ZipPackageStream::supportsService( OUString const & rServiceName )
-    throw ( RuntimeException, std::exception )
 {
     return cppu::supportsService(this, rServiceName);
 }
