@@ -22,12 +22,11 @@
 
 #include "pyuno_impl.hxx"
 
-#include <boost/unordered_map.hpp>
+#include <unordered_map>
 #include <utility>
 
 #include <osl/module.hxx>
 #include <osl/thread.h>
-#include <osl/process.h>
 #include <osl/file.hxx>
 
 #include <typelib/typedescription.hxx>
@@ -41,8 +40,8 @@
 #include <uno/current_context.hxx>
 #include <cppuhelper/bootstrap.hxx>
 
+#include <com/sun/star/lang/XMultiServiceFactory.hpp>
 #include <com/sun/star/reflection/XConstantTypeDescription.hpp>
-#include <com/sun/star/reflection/XIdlReflection.hpp>
 #include <com/sun/star/reflection/XIdlClass.hpp>
 #include <com/sun/star/registry/InvalidRegistryException.hpp>
 
@@ -51,7 +50,6 @@ using osl::Module;
 
 using com::sun::star::uno::Sequence;
 using com::sun::star::uno::Reference;
-using com::sun::star::uno::XInterface;
 using com::sun::star::uno::Any;
 using com::sun::star::uno::makeAny;
 using com::sun::star::uno::UNO_QUERY;
@@ -59,7 +57,6 @@ using com::sun::star::uno::RuntimeException;
 using com::sun::star::uno::TypeDescription;
 using com::sun::star::uno::XComponentContext;
 using com::sun::star::container::NoSuchElementException;
-using com::sun::star::reflection::XIdlReflection;
 using com::sun::star::reflection::XIdlClass;
 using com::sun::star::script::XInvocation2;
 
@@ -84,7 +81,7 @@ class fillStructState
     // Keyword arguments used
     PyObject *used;
     // Which structure members are initialised
-    boost::unordered_map <const OUString, bool, OUStringHash> initialised;
+    std::unordered_map <OUString, bool> initialised;
     // How many positional arguments are consumed
     // This is always the so-many first ones
     sal_Int32 nPosConsumed;
@@ -96,7 +93,7 @@ public:
         , nPosConsumed (0)
     {
         if ( ! used )
-            throw RuntimeException("pyuno._createUnoStructHelper failed to create new dictionary", Reference< XInterface > ());
+            throw RuntimeException("pyuno._createUnoStructHelper failed to create new dictionary");
     }
     ~fillStructState()
     {
@@ -106,27 +103,27 @@ public:
     {
         PyDict_SetItem(used, key, Py_True);
     }
-    void setInitialised(OUString key, sal_Int32 pos = -1)
+    void setInitialised(const OUString& key, sal_Int32 pos = -1)
     {
         if (initialised[key])
         {
             OUStringBuffer buf;
-            buf.appendAscii( "pyuno._createUnoStructHelper: member '");
+            buf.append( "pyuno._createUnoStructHelper: member '");
             buf.append(key);
-            buf.appendAscii( "'");
+            buf.append( "'");
             if ( pos >= 0 )
             {
-                buf.appendAscii( " at position ");
+                buf.append( " at position ");
                 buf.append(pos);
             }
-            buf.appendAscii( " initialised multiple times.");
-            throw RuntimeException(buf.makeStringAndClear(), Reference< XInterface > ());
+            buf.append( " initialised multiple times.");
+            throw RuntimeException(buf.makeStringAndClear());
         }
         initialised[key] = true;
         if ( pos >= 0 )
             ++nPosConsumed;
     }
-    bool isInitialised(OUString key)
+    bool isInitialised(const OUString& key)
     {
         return initialised[key];
     }
@@ -140,13 +137,14 @@ public:
     }
 };
 
-static void fillStruct(
+/// @throws RuntimeException
+void fillStruct(
     const Reference< XInvocation2 > &inv,
     typelib_CompoundTypeDescription *pCompType,
     PyObject *initializer,
     PyObject *kwinitializer,
     fillStructState &state,
-    const Runtime &runtime) throw ( RuntimeException )
+    const Runtime &runtime)
 {
     if( pCompType->pBaseTypeDescription )
         fillStruct( inv, pCompType->pBaseTypeDescription, initializer, kwinitializer, state, runtime );
@@ -173,25 +171,29 @@ static void fillStruct(
         for( int i = 0 ; i < remainingPosInitialisers && i < nMembers ; i ++ )
         {
             const int tupleIndex = state.getCntConsumed();
-            const OUString pMemberName (pCompType->ppMemberNames[i]);
-            state.setInitialised(pMemberName, tupleIndex);
+            const OUString& rMemberName (pCompType->ppMemberNames[i]);
+            state.setInitialised(rMemberName, tupleIndex);
             PyObject *element = PyTuple_GetItem( initializer, tupleIndex );
             Any a = runtime.pyObject2Any( element, ACCEPT_UNO_ANY );
-            inv->setValue( pMemberName, a );
+            inv->setValue( rMemberName, a );
         }
     }
-    for ( int i = 0; i < nMembers ; ++i)
+    if ( PyTuple_Size( initializer ) > 0 )
     {
-        const OUString memberName (pCompType->ppMemberNames[i]);
-        if ( ! state.isInitialised( memberName ) )
+        // Allow partial initialisation when only keyword arguments are given
+        for ( int i = 0; i < nMembers ; ++i)
         {
-            OUStringBuffer buf;
-            buf.appendAscii( "pyuno._createUnoStructHelper: member '");
-            buf.append(memberName);
-            buf.appendAscii( "' of struct type '");
-            buf.append(pCompType->aBase.pTypeName);
-            buf.appendAscii( "' not given a value.");
-            throw RuntimeException(buf.makeStringAndClear(), Reference< XInterface > ());
+            const OUString memberName (pCompType->ppMemberNames[i]);
+            if ( ! state.isInitialised( memberName ) )
+            {
+                OUStringBuffer buf;
+                buf.append( "pyuno._createUnoStructHelper: member '");
+                buf.append(memberName);
+                buf.append( "' of struct type '");
+                buf.append(pCompType->aBase.pTypeName);
+                buf.append( "' not given a value.");
+                throw RuntimeException(buf.makeStringAndClear());
+            }
         }
     }
 }
@@ -210,7 +212,7 @@ OUString getLibDir()
             if( Module::getUrlFromAddress(
                     reinterpret_cast< oslGenericFunction >(getLibDir), libDir ) )
             {
-                libDir = OUString( libDir.getStr(), libDir.lastIndexOf('/' ) );
+                libDir = libDir.copy( 0, libDir.lastIndexOf('/') );
                 OUString name ( "PYUNOLIBDIR" );
                 rtl_bootstrap_set( name.pData, libDir.pData );
             }
@@ -249,29 +251,25 @@ static PyObject* getComponentContext(
         }
         else
         {
-            // cppu::defaultBootstrap_InitialComponentContext expects
-            // command line arguments to be present
-            osl_setCommandArgs(0, 0); // fake it
-
             OUString iniFile;
             if( path.isEmpty() )
             {
                 PyErr_SetString(
                     PyExc_RuntimeError, "osl_getUrlFromAddress fails, that's why I cannot find ini "
                     "file for bootstrapping python uno bridge\n" );
-                return NULL;
+                return nullptr;
             }
 
             OUStringBuffer iniFileName;
             iniFileName.append( path );
-#if HAVE_FEATURE_MACOSX_MACLIKE_APP_STRUCTURE
-            iniFileName.appendAscii( "/../" LIBO_ETC_FOLDER );
+#ifdef MACOSX
+            iniFileName.append( "/../" LIBO_ETC_FOLDER );
 #endif
-            iniFileName.appendAscii( "/" );
-            iniFileName.appendAscii( SAL_CONFIGFILE( "pyuno" ) );
+            iniFileName.append( "/" );
+            iniFileName.append( SAL_CONFIGFILE( "pyuno" ) );
             iniFile = iniFileName.makeStringAndClear();
             osl::DirectoryItem item;
-            if( osl::DirectoryItem::get( iniFile, item ) == item.E_None )
+            if( osl::DirectoryItem::get( iniFile, item ) == osl::FileBase::E_None )
             {
                 // in case pyuno.ini exists, use this file for bootstrapping
                 PyThreadDetach antiguard;
@@ -293,33 +291,33 @@ static PyObject* getComponentContext(
         Runtime runtime;
         ret = runtime.any2PyObject( makeAny( ctx ) );
     }
-    catch (const com::sun::star::registry::InvalidRegistryException &e)
+    catch (const css::registry::InvalidRegistryException &e)
     {
         // can't use raisePyExceptionWithAny() here, because the function
         // does any conversions, which will not work with a
         // wrongly bootstrapped pyuno!
         raisePySystemException( "InvalidRegistryException", e.Message );
     }
-    catch(const com::sun::star::lang::IllegalArgumentException & e)
+    catch(const css::lang::IllegalArgumentException & e)
     {
         raisePySystemException( "IllegalArgumentException", e.Message );
     }
-    catch(const com::sun::star::script::CannotConvertException & e)
+    catch(const css::script::CannotConvertException & e)
     {
         raisePySystemException( "CannotConvertException", e.Message );
     }
-    catch (const com::sun::star::uno::RuntimeException & e)
+    catch (const css::uno::RuntimeException & e)
     {
         raisePySystemException( "RuntimeException", e.Message );
     }
-    catch (const com::sun::star::uno::Exception & e)
+    catch (const css::uno::Exception & e)
     {
         raisePySystemException( "uno::Exception", e.Message );
     }
     return ret.getAcquired();
 }
 
-static PyObject* initPoniesMode(
+static PyObject* initTestEnvironment(
     SAL_UNUSED_PARAMETER PyObject*, SAL_UNUSED_PARAMETER PyObject*)
 {
     // this tries to bootstrap enough of the soffice from python to run
@@ -327,17 +325,17 @@ static PyObject* initPoniesMode(
     // so load "test" library and invoke a function there to do the work
     try
     {
-        PyObject *const ctx(getComponentContext(0, 0));
+        PyObject *const ctx(getComponentContext(nullptr, nullptr));
         if (!ctx) { abort(); }
         Runtime const runtime;
         Any const a(runtime.pyObject2Any(ctx));
         Reference<XComponentContext> xContext;
         a >>= xContext;
         if (!xContext.is()) { abort(); }
-        using com::sun::star::lang::XMultiServiceFactory;
+        using css::lang::XMultiServiceFactory;
         Reference<XMultiServiceFactory> const xMSF(
             xContext->getServiceManager(),
-            com::sun::star::uno::UNO_QUERY_THROW);
+            css::uno::UNO_QUERY_THROW);
         if (!xMSF.is()) { abort(); }
         char *const testlib = getenv("TEST_LIB");
         if (!testlib) { abort(); }
@@ -346,16 +344,17 @@ static PyObject* initPoniesMode(
             .replaceAll(OString('/'), OString('\\'))
 #endif
             ;
-        oslModule const mod( osl_loadModuleAscii(libname.getStr(),
-                                SAL_LOADMODULE_LAZY | SAL_LOADMODULE_GLOBAL) );
-        if (!mod) { abort(); }
+
+        osl::Module &mod = runtime.getImpl()->cargo->testModule;
+        mod.load(OStringToOUString(libname, osl_getThreadTextEncoding()),
+                                SAL_LOADMODULE_LAZY | SAL_LOADMODULE_GLOBAL);
+        if (!mod.is()) { abort(); }
         oslGenericFunction const pFunc(
-                osl_getAsciiFunctionSymbol(mod, "test_init"));
+                mod.getFunctionSymbol("test_init"));
         if (!pFunc) { abort(); }
-        // guess casting pFunc is undefined behavior but don't see a better way
-        ((void (SAL_CALL *)(XMultiServiceFactory*)) pFunc) (xMSF.get());
+        reinterpret_cast<void (SAL_CALL *)(XMultiServiceFactory*)>(pFunc)(xMSF.get());
     }
-    catch (const com::sun::star::uno::Exception &)
+    catch (const css::uno::Exception &)
     {
         abort();
     }
@@ -369,7 +368,7 @@ PyObject * extractOneStringArg( PyObject *args, char const *funcName )
         OStringBuffer buf;
         buf.append( funcName ).append( ": expecting one string argument" );
         PyErr_SetString( PyExc_RuntimeError, buf.getStr() );
-        return NULL;
+        return nullptr;
     }
     PyObject *obj = PyTuple_GetItem( args, 0 );
     if (!PyStr_Check(obj) && !PyUnicode_Check(obj))
@@ -377,7 +376,7 @@ PyObject * extractOneStringArg( PyObject *args, char const *funcName )
         OStringBuffer buf;
         buf.append( funcName ).append( ": expecting one string argument" );
         PyErr_SetString( PyExc_TypeError, buf.getStr());
-        return NULL;
+        return nullptr;
     }
     return obj;
 }
@@ -405,25 +404,22 @@ static PyObject *createUnoStructHelper(
                     if (idl_class.is ())
                     {
                         idl_class->createObject (IdlStruct);
-                        PyUNO *me = (PyUNO*)PyUNO_new_UNCHECKED( IdlStruct, c->xInvocation );
-                        PyRef returnCandidate( (PyObject*)me, SAL_NO_ACQUIRE );
+                        PyRef returnCandidate( PyUNOStruct_new( IdlStruct, c->xInvocation ) );
+                        PyUNO *me = reinterpret_cast<PyUNO*>( returnCandidate.get() );
                         TypeDescription desc( typeName );
                         OSL_ASSERT( desc.is() ); // could already instantiate an XInvocation2 !
 
                         typelib_CompoundTypeDescription *pCompType =
-                            ( typelib_CompoundTypeDescription * ) desc.get();
+                            reinterpret_cast<typelib_CompoundTypeDescription *>(desc.get());
                         fillStructState state;
                         if ( PyTuple_Size( initializer ) > 0 || PyDict_Size( keywordArgs ) > 0 )
                             fillStruct( me->members->xInvocation, pCompType, initializer, keywordArgs, state, runtime );
                         if( state.getCntConsumed() != PyTuple_Size(initializer) )
                         {
-                            OUStringBuffer buf;
-                            buf.appendAscii( "pyuno._createUnoStructHelper: too many ");
-                            buf.appendAscii( "elements in the initializer list, expected " );
-                            buf.append( state.getCntConsumed() );
-                            buf.appendAscii( ", got " );
-                            buf.append( (sal_Int32) PyTuple_Size(initializer) );
-                            throw RuntimeException( buf.makeStringAndClear(), Reference< XInterface > ());
+                            throw RuntimeException( "pyuno._createUnoStructHelper: too many "
+                                "elements in the initializer list, expected " +
+                                OUString::number(state.getCntConsumed()) + ", got " +
+                                OUString::number( PyTuple_Size(initializer) ) );
                         }
                         ret = PyRef( PyTuple_Pack(2, returnCandidate.get(), state.getUsed()), SAL_NO_ACQUIRE);
                     }
@@ -453,15 +449,15 @@ static PyObject *createUnoStructHelper(
             PyErr_SetString (PyExc_AttributeError, "pyuno._createUnoStructHelper: expects exactly two non-keyword arguments:\n\tStructure Name\n\tinitialiser tuple; may be the empty tuple");
         }
     }
-    catch( const com::sun::star::uno::RuntimeException & e )
+    catch( const css::uno::RuntimeException & e )
     {
         raisePyExceptionWithAny( makeAny( e ) );
     }
-    catch( const com::sun::star::script::CannotConvertException & e )
+    catch( const css::script::CannotConvertException & e )
     {
         raisePyExceptionWithAny( makeAny( e ) );
     }
-    catch( const com::sun::star::uno::Exception & e )
+    catch( const css::uno::Exception & e )
     {
         raisePyExceptionWithAny( makeAny( e ) );
     }
@@ -471,7 +467,7 @@ static PyObject *createUnoStructHelper(
 static PyObject *getTypeByName(
     SAL_UNUSED_PARAMETER PyObject *, PyObject *args )
 {
-    PyObject * ret = NULL;
+    PyObject * ret = nullptr;
 
     try
     {
@@ -485,7 +481,7 @@ static PyObject *getTypeByName(
             {
                 Runtime runtime;
                 ret = PyUNO_Type_new(
-                    name, (com::sun::star::uno::TypeClass)typeDesc.get()->eTypeClass, runtime );
+                    name, (css::uno::TypeClass)typeDesc.get()->eTypeClass, runtime );
             }
             else
             {
@@ -505,7 +501,7 @@ static PyObject *getTypeByName(
 static PyObject *getConstantByName(
     SAL_UNUSED_PARAMETER PyObject *, PyObject *args )
 {
-    PyObject *ret = 0;
+    PyObject *ret = nullptr;
     try
     {
         char *name;
@@ -519,10 +515,7 @@ static PyObject *getConstantByName(
                       typeName)
                   >>= td))
             {
-                OUStringBuffer buf;
-                buf.appendAscii( "pyuno.getConstantByName: " ).append( typeName );
-                buf.appendAscii( "is not a constant" );
-                throw RuntimeException(buf.makeStringAndClear(), Reference< XInterface > () );
+                throw RuntimeException( "pyuno.getConstantByName: " + typeName + "is not a constant" );
             }
             PyRef constant = runtime.any2PyObject( td->getConstantValue() );
             ret = constant.getAcquired();
@@ -532,14 +525,14 @@ static PyObject *getConstantByName(
     {
         // to the python programmer, this is a runtime exception,
         // do not support tweakings with the type system
-        RuntimeException runExc( e.Message, Reference< XInterface > () );
+        RuntimeException runExc( e.Message );
         raisePyExceptionWithAny( makeAny( runExc ) );
     }
-    catch(const com::sun::star::script::CannotConvertException & e)
+    catch(const css::script::CannotConvertException & e)
     {
         raisePyExceptionWithAny( makeAny( e ) );
     }
-    catch(const com::sun::star::lang::IllegalArgumentException & e)
+    catch(const css::lang::IllegalArgumentException & e)
     {
         raisePyExceptionWithAny( makeAny( e ) );
     }
@@ -557,7 +550,7 @@ static PyObject *checkType( SAL_UNUSED_PARAMETER PyObject *, PyObject *args )
         OStringBuffer buf;
         buf.append( "pyuno.checkType : expecting one uno.Type argument" );
         PyErr_SetString( PyExc_RuntimeError, buf.getStr() );
-        return NULL;
+        return nullptr;
     }
     PyObject *obj = PyTuple_GetItem( args, 0 );
 
@@ -568,7 +561,7 @@ static PyObject *checkType( SAL_UNUSED_PARAMETER PyObject *, PyObject *args )
     catch(const  RuntimeException & e)
     {
         raisePyExceptionWithAny( makeAny( e ) );
-        return NULL;
+        return nullptr;
     }
     Py_INCREF( Py_None );
     return Py_None;
@@ -581,7 +574,7 @@ static PyObject *checkEnum( SAL_UNUSED_PARAMETER PyObject *, PyObject *args )
         OStringBuffer buf;
         buf.append( "pyuno.checkType : expecting one uno.Type argument" );
         PyErr_SetString( PyExc_RuntimeError, buf.getStr() );
-        return NULL;
+        return nullptr;
     }
     PyObject *obj = PyTuple_GetItem( args, 0 );
 
@@ -592,7 +585,7 @@ static PyObject *checkEnum( SAL_UNUSED_PARAMETER PyObject *, PyObject *args )
     catch(const RuntimeException & e)
     {
         raisePyExceptionWithAny( makeAny( e) );
-        return NULL;
+        return nullptr;
     }
     Py_INCREF( Py_None );
     return Py_None;
@@ -602,7 +595,7 @@ static PyObject *getClass( SAL_UNUSED_PARAMETER PyObject *, PyObject *args )
 {
     PyObject *obj = extractOneStringArg( args, "pyuno.getClass");
     if( ! obj )
-        return NULL;
+        return nullptr;
 
     try
     {
@@ -613,13 +606,9 @@ static PyObject *getClass( SAL_UNUSED_PARAMETER PyObject *, PyObject *args )
     }
     catch(const RuntimeException & e)
     {
-        // NOOPT !!!
-        // gcc 3.2.3 crashes here in the regcomp test scenario
-        // only since migration to python 2.3.4 ???? strange thing
-        // optimization switched off for this module !
         raisePyExceptionWithAny( makeAny(e) );
     }
-    return NULL;
+    return nullptr;
 }
 
 static PyObject *isInterface( SAL_UNUSED_PARAMETER PyObject *, PyObject *args )
@@ -638,7 +627,7 @@ static PyObject * generateUuid(
     SAL_UNUSED_PARAMETER PyObject *, SAL_UNUSED_PARAMETER PyObject * )
 {
     Sequence< sal_Int8 > seq( 16 );
-    rtl_createUuid( (sal_uInt8*)seq.getArray() , 0 , sal_False );
+    rtl_createUuid( reinterpret_cast<sal_uInt8*>(seq.getArray()) , nullptr , false );
     PyRef ret;
     try
     {
@@ -657,7 +646,7 @@ static PyObject *systemPathToFileUrl(
 {
     PyObject *obj = extractOneStringArg( args, "pyuno.systemPathToFileUrl" );
     if( ! obj )
-        return NULL;
+        return nullptr;
 
     OUString sysPath = pyString2ustring( obj );
     OUString url;
@@ -666,14 +655,14 @@ static PyObject *systemPathToFileUrl(
     if( e != osl::FileBase::E_None )
     {
         OUStringBuffer buf;
-        buf.appendAscii( "Couldn't convert " );
+        buf.append( "Couldn't convert " );
         buf.append( sysPath );
-        buf.appendAscii( " to a file url for reason (" );
+        buf.append( " to a file url for reason (" );
         buf.append( (sal_Int32) e );
-        buf.appendAscii( ")" );
+        buf.append( ")" );
         raisePyExceptionWithAny(
-            makeAny( RuntimeException( buf.makeStringAndClear(), Reference< XInterface > () )));
-        return NULL;
+            makeAny( RuntimeException( buf.makeStringAndClear() )));
+        return nullptr;
     }
     return ustring2PyUnicode( url ).getAcquired();
 }
@@ -683,7 +672,7 @@ static PyObject * fileUrlToSystemPath(
 {
     PyObject *obj = extractOneStringArg( args, "pyuno.fileUrlToSystemPath" );
     if( ! obj )
-        return NULL;
+        return nullptr;
 
     OUString url = pyString2ustring( obj );
     OUString sysPath;
@@ -692,14 +681,14 @@ static PyObject * fileUrlToSystemPath(
     if( e != osl::FileBase::E_None )
     {
         OUStringBuffer buf;
-        buf.appendAscii( "Couldn't convert file url " );
+        buf.append( "Couldn't convert file url " );
         buf.append( sysPath );
-        buf.appendAscii( " to a system path for reason (" );
+        buf.append( " to a system path for reason (" );
         buf.append( (sal_Int32) e );
-        buf.appendAscii( ")" );
+        buf.append( ")" );
         raisePyExceptionWithAny(
-            makeAny( RuntimeException( buf.makeStringAndClear(), Reference< XInterface > () )));
-        return NULL;
+            makeAny( RuntimeException( buf.makeStringAndClear() )));
+        return nullptr;
     }
     return ustring2PyUnicode( sysPath ).getAcquired();
 }
@@ -715,27 +704,27 @@ static PyObject * absolutize( SAL_UNUSED_PARAMETER PyObject *, PyObject * args )
         if( e != osl_File_E_None )
         {
             OUStringBuffer buf;
-            buf.appendAscii( "Couldn't absolutize " );
+            buf.append( "Couldn't absolutize " );
             buf.append( ouRel );
-            buf.appendAscii( " using root " );
+            buf.append( " using root " );
             buf.append( ouPath );
-            buf.appendAscii( " for reason (" );
+            buf.append( " for reason (" );
             buf.append( (sal_Int32) e );
-            buf.appendAscii( ")" );
+            buf.append( ")" );
 
             PyErr_SetString(
                 PyExc_OSError,
                 OUStringToOString(buf.makeStringAndClear(),osl_getThreadTextEncoding()).getStr());
-            return 0;
+            return nullptr;
         }
         return ustring2PyUnicode( ret ).getAcquired();
     }
-    return 0;
+    return nullptr;
 }
 
 static PyObject * invoke(SAL_UNUSED_PARAMETER PyObject *, PyObject *args)
 {
-    PyObject *ret = 0;
+    PyObject *ret = nullptr;
     if(PyTuple_Check(args) && PyTuple_Size(args) == 3)
     {
         PyObject *object = PyTuple_GetItem(args, 0);
@@ -783,9 +772,9 @@ static PyObject *getCurrentContext(
     {
         Runtime runtime;
         ret = runtime.any2PyObject(
-            makeAny( com::sun::star::uno::getCurrentContext() ) );
+            makeAny( css::uno::getCurrentContext() ) );
     }
-    catch( const com::sun::star::uno::Exception & e )
+    catch( const css::uno::Exception & e )
     {
         raisePyExceptionWithAny( makeAny( e ) );
     }
@@ -804,11 +793,11 @@ static PyObject *setCurrentContext(
             Runtime runtime;
             Any a = runtime.pyObject2Any( PyTuple_GetItem( args, 0 ) );
 
-            Reference< com::sun::star::uno::XCurrentContext > context;
+            Reference< css::uno::XCurrentContext > context;
 
             if( (a.hasValue() && (a >>= context)) || ! a.hasValue() )
             {
-                ret = com::sun::star::uno::setCurrentContext( context ) ? Py_True : Py_False;
+                ret = css::uno::setCurrentContext( context ) ? Py_True : Py_False;
             }
             else
             {
@@ -828,7 +817,7 @@ static PyObject *setCurrentContext(
                 PyExc_RuntimeError, buf.makeStringAndClear().getStr() );
         }
     }
-    catch( const com::sun::star::uno::Exception & e )
+    catch( const css::uno::Exception & e )
     {
         raisePyExceptionWithAny( makeAny( e ) );
     }
@@ -839,23 +828,23 @@ static PyObject *setCurrentContext(
 
 struct PyMethodDef PyUNOModule_methods [] =
 {
-    {"experimentalExtraMagic", initPoniesMode, METH_VARARGS, NULL},
-    {"getComponentContext", getComponentContext, METH_VARARGS, NULL},
-    {"_createUnoStructHelper", reinterpret_cast<PyCFunction>(createUnoStructHelper), METH_VARARGS | METH_KEYWORDS, NULL},
-    {"getTypeByName", getTypeByName, METH_VARARGS, NULL},
-    {"getConstantByName", getConstantByName, METH_VARARGS, NULL},
-    {"getClass", getClass, METH_VARARGS, NULL},
-    {"checkEnum", checkEnum, METH_VARARGS, NULL},
-    {"checkType", checkType, METH_VARARGS, NULL},
-    {"generateUuid", generateUuid, METH_VARARGS, NULL},
-    {"systemPathToFileUrl", systemPathToFileUrl, METH_VARARGS, NULL},
-    {"fileUrlToSystemPath", fileUrlToSystemPath, METH_VARARGS, NULL},
-    {"absolutize", absolutize, METH_VARARGS | METH_KEYWORDS, NULL},
-    {"isInterface", isInterface, METH_VARARGS, NULL},
-    {"invoke", invoke, METH_VARARGS | METH_KEYWORDS, NULL},
-    {"setCurrentContext", setCurrentContext, METH_VARARGS, NULL},
-    {"getCurrentContext", getCurrentContext, METH_VARARGS, NULL},
-    {NULL, NULL, 0, NULL}
+    {"private_initTestEnvironment", initTestEnvironment, METH_VARARGS, nullptr},
+    {"getComponentContext", getComponentContext, METH_VARARGS, nullptr},
+    {"_createUnoStructHelper", reinterpret_cast<PyCFunction>(createUnoStructHelper), METH_VARARGS | METH_KEYWORDS, nullptr},
+    {"getTypeByName", getTypeByName, METH_VARARGS, nullptr},
+    {"getConstantByName", getConstantByName, METH_VARARGS, nullptr},
+    {"getClass", getClass, METH_VARARGS, nullptr},
+    {"checkEnum", checkEnum, METH_VARARGS, nullptr},
+    {"checkType", checkType, METH_VARARGS, nullptr},
+    {"generateUuid", generateUuid, METH_VARARGS, nullptr},
+    {"systemPathToFileUrl", systemPathToFileUrl, METH_VARARGS, nullptr},
+    {"fileUrlToSystemPath", fileUrlToSystemPath, METH_VARARGS, nullptr},
+    {"absolutize", absolutize, METH_VARARGS | METH_KEYWORDS, nullptr},
+    {"isInterface", isInterface, METH_VARARGS, nullptr},
+    {"invoke", invoke, METH_VARARGS | METH_KEYWORDS, nullptr},
+    {"setCurrentContext", setCurrentContext, METH_VARARGS, nullptr},
+    {"getCurrentContext", getCurrentContext, METH_VARARGS, nullptr},
+    {nullptr, nullptr, 0, nullptr}
 };
 
 }
@@ -865,19 +854,20 @@ extern "C"
 PyObject* PyInit_pyuno()
 {
     PyUNO_initType();
+    PyUNOStruct_initType();
     // noop when called already, otherwise needed to allow multiple threads
     PyEval_InitThreads();
     static struct PyModuleDef moduledef =
     {
         PyModuleDef_HEAD_INIT,
         "pyuno",             // module name
-        0,                   // module documentation
+        nullptr,                   // module documentation
         -1,                  // module keeps state in global variables,
         PyUNOModule_methods, // modules methods
-        0,                   // m_reload (must be 0)
-        0,                   // m_traverse
-        0,                   // m_clear
-        0,                   // m_free
+        nullptr,                   // m_reload (must be 0)
+        nullptr,                   // m_traverse
+        nullptr,                   // m_clear
+        nullptr,                   // m_free
     };
     return PyModule_Create(&moduledef);
 }
@@ -885,6 +875,7 @@ PyObject* PyInit_pyuno()
 void initpyuno()
 {
     PyUNO_initType();
+    PyUNOStruct_initType();
     PyEval_InitThreads();
     Py_InitModule ("pyuno", PyUNOModule_methods);
 }
