@@ -29,23 +29,9 @@
 #include <rtl/ustrbuf.hxx>
 #include <osl/time.h>
 
-#include <com/sun/star/beans/XMaterialHolder.hpp>
-
-
-
-using com::sun::star::uno::TypeDescription;
 using com::sun::star::uno::Sequence;
-using com::sun::star::uno::Reference;
-using com::sun::star::uno::XInterface;
 using com::sun::star::uno::Any;
-using com::sun::star::uno::Type;
-using com::sun::star::uno::UNO_QUERY;
-using com::sun::star::uno::TypeClass;
 using com::sun::star::uno::RuntimeException;
-using com::sun::star::uno::XComponentContext;
-using com::sun::star::lang::XSingleServiceFactory;
-using com::sun::star::script::XTypeConverter;
-using com::sun::star::beans::XMaterialHolder;
 
 namespace pyuno
 {
@@ -53,8 +39,12 @@ PyRef ustring2PyUnicode( const OUString & str )
 {
     PyRef ret;
 #if Py_UNICODE_SIZE == 2
-    // YD force conversion since python/2 uses wchar_t
-    ret = PyRef( PyUnicode_FromUnicode( (const Py_UNICODE*)str.getStr(), str.getLength() ), SAL_NO_ACQUIRE );
+#ifdef MACOSX
+    ret = PyRef( PyUnicode_FromUnicode( reinterpret_cast<const unsigned short *>(str.getStr()), str.getLength() ), SAL_NO_ACQUIRE );
+#else
+    static_assert(sizeof (wchar_t) == Py_UNICODE_SIZE, "bad assumption");
+    ret = PyRef( PyUnicode_FromUnicode( reinterpret_cast<wchar_t const *>(str.getStr()), str.getLength() ), SAL_NO_ACQUIRE );
+#endif
 #else
     OString sUtf8(OUStringToOString(str, RTL_TEXTENCODING_UTF8));
     ret = PyRef( PyUnicode_DecodeUTF8( sUtf8.getStr(), sUtf8.getLength(), nullptr) , SAL_NO_ACQUIRE );
@@ -74,7 +64,8 @@ OUString pyString2ustring( PyObject *pystr )
     if( PyUnicode_Check( pystr ) )
     {
 #if Py_UNICODE_SIZE == 2
-    ret = OUString( (sal_Unicode * ) PyUnicode_AS_UNICODE( pystr ) );
+    ret = OUString(
+        reinterpret_cast<sal_Unicode const *>(PyUnicode_AS_UNICODE( pystr )) );
 #else
 #if PY_MAJOR_VERSION >= 3
     Py_ssize_t size(0);
@@ -100,25 +91,20 @@ OUString pyString2ustring( PyObject *pystr )
 }
 
 PyRef getObjectFromUnoModule( const Runtime &runtime, const char * func )
-    throw ( RuntimeException )
 {
     PyRef object(PyDict_GetItemString( runtime.getImpl()->cargo->getUnoModule().get(), func ) );
     if( !object.is() )
     {
-        OUStringBuffer buf;
-        buf.append( "couldn't find core function " );
-        buf.appendAscii( func );
-        throw RuntimeException(buf.makeStringAndClear());
+        throw RuntimeException("couldn't find core function " + OUString::createFromAscii(func));
     }
     return object;
 }
 
 
-
 // Logging
 
 
-bool isLog( RuntimeCargo * cargo, sal_Int32 loglevel )
+bool isLog( RuntimeCargo const * cargo, sal_Int32 loglevel )
 {
     return cargo && cargo->logFile && loglevel <= cargo->logLevel;
 }
