@@ -20,7 +20,6 @@ package mod._sc;
 
 import java.io.PrintWriter;
 
-import lib.StatusException;
 import lib.TestCase;
 import lib.TestEnvironment;
 import lib.TestParameters;
@@ -30,7 +29,6 @@ import com.sun.star.awt.Rectangle;
 import com.sun.star.container.XEnumerationAccess;
 import com.sun.star.container.XIndexAccess;
 import com.sun.star.lang.XComponent;
-import com.sun.star.lang.XMultiServiceFactory;
 import com.sun.star.sheet.XCellRangeAddressable;
 import com.sun.star.sheet.XSpreadsheet;
 import com.sun.star.sheet.XSpreadsheetDocument;
@@ -51,52 +49,31 @@ public class ScIndexEnumeration_TableChartsEnumeration extends TestCase {
     /**
     * Creates Spreadsheet document.
     */
-    protected void initialize( TestParameters tParam, PrintWriter log ) {
+    @Override
+    protected void initialize( TestParameters tParam, PrintWriter log ) throws Exception {
         // get a soffice factory object
-        SOfficeFactory SOF = SOfficeFactory.getFactory( (XMultiServiceFactory)tParam.getMSF());
-
-        try {
-            log.println( "creating a sheetdocument" );
-            xSheetDoc = SOF.createCalcDoc(null);
-        } catch (com.sun.star.uno.Exception e) {
-            // Some exception occurs.FAILED
-            e.printStackTrace( log );
-            throw new StatusException( "Couldn't create document", e );
-        }
+        SOfficeFactory SOF = SOfficeFactory.getFactory( tParam.getMSF());
+        log.println( "creating a sheetdocument" );
+        xSheetDoc = SOF.createCalcDoc(null);
     }
 
     /**
     * Disposes Spreadsheet document.
     */
+    @Override
     protected void cleanup( TestParameters tParam, PrintWriter log ) {
         log.println( "    disposing xSheetDoc " );
         XComponent oComp = UnoRuntime.queryInterface(XComponent.class, xSheetDoc);
         util.DesktopTools.closeDoc(oComp);
     }
 
-    protected synchronized TestEnvironment createTestEnvironment(TestParameters Param, PrintWriter log) {
-
-        XSpreadsheet oSheet=null;
-
-        try {
-            log.println("Getting spreadsheet") ;
-            XSpreadsheets oSheets = xSheetDoc.getSheets() ;
-            XIndexAccess oIndexSheets = UnoRuntime.queryInterface(XIndexAccess.class, oSheets);
-            oSheet = (XSpreadsheet) AnyConverter.toObject(
-                    new Type(XSpreadsheet.class),oIndexSheets.getByIndex(0));
-        } catch (com.sun.star.lang.WrappedTargetException e) {
-            log.println("Couldn't get Sheet ");
-            e.printStackTrace(log);
-            throw new StatusException("Couldn't get sheet", e);
-        } catch (com.sun.star.lang.IndexOutOfBoundsException e) {
-            log.println("Couldn't get Sheet ");
-            e.printStackTrace(log);
-            throw new StatusException("Couldn't get sheet", e);
-        } catch (com.sun.star.lang.IllegalArgumentException e) {
-            log.println("Couldn't get Sheet ");
-            e.printStackTrace(log);
-            throw new StatusException("Couldn't get sheet", e);
-        }
+    @Override
+    protected TestEnvironment createTestEnvironment(TestParameters Param, PrintWriter log) throws Exception {
+        log.println("Getting spreadsheet") ;
+        XSpreadsheets oSheets = xSheetDoc.getSheets() ;
+        XIndexAccess oIndexSheets = UnoRuntime.queryInterface(XIndexAccess.class, oSheets);
+        XSpreadsheet oSheet = (XSpreadsheet) AnyConverter.toObject(
+                new Type(XSpreadsheet.class),oIndexSheets.getByIndex(0));
 
         log.println("Creating the Header") ;
 
@@ -185,9 +162,6 @@ public class ScIndexEnumeration_TableChartsEnumeration extends TestCase {
 
         TestEnvironment tEnv = new TestEnvironment(oObj);
 
-//        tEnv.addObjRelation("RECT", oRect);
-//        tEnv.addObjRelation("ADDR", oAddr);
-
         return tEnv;
     }
 
@@ -202,18 +176,13 @@ public class ScIndexEnumeration_TableChartsEnumeration extends TestCase {
     * a double-value in the cell else it inserts a formula in the cell
     */
     public static void insertIntoCell(
-        int CellX, int CellY, String theValue, XSpreadsheet TT1, String flag) {
+        int CellX, int CellY, String theValue, XSpreadsheet TT1, String flag)
+            throws com.sun.star.lang.IndexOutOfBoundsException {
 
-        XCell oCell = null;
-
-        try {
-            oCell = TT1.getCellByPosition(CellX, CellY);
-        } catch (com.sun.star.lang.IndexOutOfBoundsException ex) {
-            System.out.println("Could not get Cell");
-        }
+        XCell oCell = TT1.getCellByPosition(CellX, CellY);
 
         if (flag.equals("V")) {
-            oCell.setValue(new Float(theValue).floatValue());
+            oCell.setValue(Float.parseFloat(theValue));
         } else {
             oCell.setFormula(theValue);
         }
