@@ -19,7 +19,6 @@ package mod._svtools;
 
 import java.io.PrintWriter;
 
-import lib.StatusException;
 import lib.TestCase;
 import lib.TestEnvironment;
 import lib.TestParameters;
@@ -45,16 +44,15 @@ import com.sun.star.view.XSelectionSupplier;
 
 public class AccessibleBrowseBox extends TestCase {
 
-    static XDesktop the_Desk;
+    static XDesktop xDesktop;
     static XTextDocument xTextDoc;
 
     /**
      * Creates the Desktop service (<code>com.sun.star.frame.Desktop</code>).
      */
     @Override
-    protected void initialize(TestParameters Param, PrintWriter log) {
-        the_Desk = UnoRuntime.queryInterface(
-            XDesktop.class, DesktopTools.createDesktop(Param.getMSF()));
+    protected void initialize(TestParameters Param, PrintWriter log) throws Exception {
+        xDesktop = DesktopTools.createDesktop(Param.getMSF());
     }
 
     /**
@@ -84,7 +82,7 @@ public class AccessibleBrowseBox extends TestCase {
      * @see #getTestEnvironment
      */
     @Override
-    protected TestEnvironment createTestEnvironment(TestParameters tParam, PrintWriter log) {
+    protected TestEnvironment createTestEnvironment(TestParameters tParam, PrintWriter log) throws Exception {
 
         log.println("creating a test environment");
 
@@ -93,16 +91,10 @@ public class AccessibleBrowseBox extends TestCase {
         }
         SOfficeFactory SOF = SOfficeFactory.getFactory(tParam.getMSF());
 
-        try {
-            log.println("creating a text document");
-            xTextDoc = SOF.createTextDoc(null);
-        } catch (com.sun.star.uno.Exception e) {
-            // Some exception occurs.FAILED
-            e.printStackTrace(log);
-            throw new StatusException("Couldn't create document", e);
-        }
+        log.println("creating a text document");
+        xTextDoc = SOF.createTextDoc(null);
 
-        shortWait();
+        util.utils.waitForEventIdle(tParam.getMSF());
 
         XModel aModel1 = UnoRuntime.queryInterface(XModel.class, xTextDoc);
 
@@ -121,9 +113,9 @@ public class AccessibleBrowseBox extends TestCase {
         PropertyValue[] noArgs = new PropertyValue[0];
         getting.dispatch(the_url, noArgs);
 
-        shortWait();
+        util.utils.waitForEventIdle(tParam.getMSF());
 
-        XFrame the_frame1 = the_Desk.getCurrentFrame();
+        XFrame the_frame1 = xDesktop.getCurrentFrame();
 
         if (the_frame1 == null) {
             log.println("Current frame was not found !!!");
@@ -148,9 +140,7 @@ public class AccessibleBrowseBox extends TestCase {
 
         final PropertyValue[] fParams = params;
 
-        shortWait();
-
-        new AccessibilityTools();
+        util.utils.waitForEventIdle(tParam.getMSF());
 
         XWindow xWindow = secondController.getFrame().getContainerWindow();
 
@@ -179,16 +169,4 @@ public class AccessibleBrowseBox extends TestCase {
 
         return tEnv;
     }
-
-    /**
-     * Sleeps for 0.5 sec. to allow StarOffice to react on <code>
-     * reset</code> call.
-     */
-    private void shortWait() {
-        try {
-            Thread.sleep(5000);
-        } catch (InterruptedException e) {
-            System.out.println("While waiting :" + e);
-        }
-    }
 }
