@@ -27,7 +27,6 @@ import com.sun.star.awt.XWindowPeer;
 import com.sun.star.drawing.XControlShape;
 import com.sun.star.frame.XController;
 import com.sun.star.frame.XFrame;
-import com.sun.star.lang.XMultiServiceFactory;
 import com.sun.star.text.XTextDocument;
 import com.sun.star.uno.UnoRuntime;
 import com.sun.star.uno.XInterface;
@@ -35,11 +34,9 @@ import com.sun.star.view.XControlAccess;
 
 import java.io.PrintWriter;
 
-import lib.StatusException;
 import lib.TestCase;
 import lib.TestEnvironment;
 import lib.TestParameters;
-
 import util.FormTools;
 import util.SOfficeFactory;
 import util.WriterTools;
@@ -50,22 +47,18 @@ public class UnoControlDateField extends TestCase {
     private static XTextDocument xTextDoc;
     private static XTextDocument xTD2;
 
-    protected void initialize(TestParameters Param, PrintWriter log) {
+    @Override
+    protected void initialize(TestParameters Param, PrintWriter log) throws Exception {
         SOfficeFactory SOF = SOfficeFactory.getFactory(
-                                     (XMultiServiceFactory) Param.getMSF());
+                                     Param.getMSF());
 
-        try {
-            log.println("creating a textdocument");
-            xTextDoc = SOF.createTextDoc(null);
-            xTD2 = WriterTools.createTextDoc(
-                           (XMultiServiceFactory) Param.getMSF());
-        } catch (com.sun.star.uno.Exception e) {
-            // Some exception occurs.FAILED
-            e.printStackTrace(log);
-            throw new StatusException("Couldn't create document", e);
-        }
+        log.println("creating a textdocument");
+        xTextDoc = SOF.createTextDoc(null);
+        xTD2 = WriterTools.createTextDoc(
+                       Param.getMSF());
     }
 
+    @Override
     protected void cleanup(TestParameters tParam, PrintWriter log) {
         log.println("    disposing xTextDoc ");
 
@@ -73,8 +66,9 @@ public class UnoControlDateField extends TestCase {
         util.DesktopTools.closeDoc(xTD2);
     }
 
+    @Override
     protected TestEnvironment createTestEnvironment(TestParameters Param,
-                                                    PrintWriter log) {
+                                                    PrintWriter log) throws Exception {
         XInterface oObj = null;
         XWindowPeer the_win = null;
         XToolkit the_kit = null;
@@ -99,17 +93,11 @@ public class UnoControlDateField extends TestCase {
                                             xTextDoc.getCurrentController());
 
         //get the DateFieldControl for the needed Object relations
-        try {
-            oObj = the_access.getControl(the_Model);
-            the_win = the_access.getControl(the_Model).getPeer();
-            the_kit = the_win.getToolkit();
-            aDevice = the_kit.createScreenCompatibleDevice(200, 200);
-            aGraphic = aDevice.createGraphics();
-        } catch (Exception e) {
-            log.println("Couldn't get DateFieldControl");
-            e.printStackTrace(log);
-            throw new StatusException("Couldn't get DateFieldControl", e);
-        }
+        oObj = the_access.getControl(the_Model);
+        the_win = the_access.getControl(the_Model).getPeer();
+        the_kit = the_win.getToolkit();
+        aDevice = the_kit.createScreenCompatibleDevice(200, 200);
+        aGraphic = aDevice.createGraphics();
 
         log.println(
                 "creating a new environment for UnoControlDateField object");
@@ -129,14 +117,9 @@ public class UnoControlDateField extends TestCase {
 
         System.out.println("ImplementationName: " + utils.getImplName(oObj));
 
-        try {
-            XController aController = xTD2.getCurrentController();
-            XFrame aFrame = aController.getFrame();
-            anotherWindow = aFrame.getComponentWindow();
-        } catch (Exception e) {
-            e.printStackTrace(log);
-            throw new StatusException("Couldn't create XWindow", e);
-        }
+        XController aController = xTD2.getCurrentController();
+        XFrame aFrame = aController.getFrame();
+        anotherWindow = aFrame.getComponentWindow();
 
 
         // Object Relation for XWindow
