@@ -24,17 +24,16 @@
 #include <sal/macros.h>
 #include <osl/endian.h>
 #include <rtl/alloc.h>
-#include "rtl/string.hxx"
-#include "rtl/ustring.hxx"
+#include <rtl/string.hxx>
+#include <rtl/ustring.hxx>
 
 #include "reflwrit.hxx"
-#include "registry/version.h"
-#include "registry/writer.h"
+#include <registry/version.h>
+#include <registry/writer.h>
 
 #include "reflcnst.hxx"
 
 
-
 namespace {
 
 inline OString toByteString(rtl_uString const * str) {
@@ -188,7 +187,7 @@ struct CPInfo
 
     CPInfo(CPInfoTag tag, struct CPInfo* prev);
 
-    sal_uInt32 getBlopSize();
+    sal_uInt32 getBlopSize() const;
 
     sal_uInt32 toBlop(sal_uInt8* buffer);
 };
@@ -205,7 +204,7 @@ CPInfo::CPInfo(CPInfoTag tag, struct CPInfo* prev)
     }
 }
 
-sal_uInt32 CPInfo::getBlopSize()
+sal_uInt32 CPInfo::getBlopSize() const
 {
     sal_uInt32 size = sizeof(sal_uInt32) /* size */ + sizeof(sal_uInt16) /* tag */;
 
@@ -431,7 +430,6 @@ public:
     RTParamMode m_mode;
 
     ParamEntry();
-    ~ParamEntry();
 
     void setData(const OString& typeName,
                  const OString& name,
@@ -443,10 +441,6 @@ ParamEntry::ParamEntry()
 {
 }
 
-ParamEntry::~ParamEntry()
-{
-}
-
 void ParamEntry::setData(const OString& typeName,
                          const OString& name,
                          RTParamMode    mode)
@@ -472,7 +466,6 @@ public:
     RTFieldAccess   m_access;
 
     ReferenceEntry();
-    ~ReferenceEntry();
 
     void setData(const OString&     name,
                  RTReferenceType    refType,
@@ -486,10 +479,6 @@ ReferenceEntry::ReferenceEntry()
 {
 }
 
-ReferenceEntry::~ReferenceEntry()
-{
-}
-
 void ReferenceEntry::setData(const OString&    name,
                              RTReferenceType   refType,
                              const OString&    doku,
@@ -521,7 +510,6 @@ public:
     OString         m_doku;
 
     MethodEntry();
-    ~MethodEntry();
 
     void setData(const OString&    name,
                  const OString&    returnTypeName,
@@ -530,7 +518,7 @@ public:
                  sal_uInt16        excCount,
                  const OString&    doku);
 
-    void setExcName(sal_uInt16 excIndex, const OString& name);
+    void setExcName(sal_uInt16 excIndex, const OString& name) const;
 
 protected:
 
@@ -545,10 +533,6 @@ MethodEntry::MethodEntry()
 {
 }
 
-MethodEntry::~MethodEntry()
-{
-}
-
 void MethodEntry::setData(const OString&    name,
                           const OString&    returnTypeName,
                           RTMethodMode      mode,
@@ -566,7 +550,7 @@ void MethodEntry::setData(const OString&    name,
     reallocExcs(excCount);
 }
 
-void MethodEntry::setExcName(sal_uInt16 excIndex, const OString& name)
+void MethodEntry::setExcName(sal_uInt16 excIndex, const OString& name) const
 {
     if (excIndex < m_excCount)
     {
@@ -638,8 +622,8 @@ public:
     RTTypeClass         m_typeClass;
     OString             m_typeName;
     sal_uInt16          m_nSuperTypes;
-    OString*            m_superTypeNames;
-    RTUik*              m_pUik;
+    std::unique_ptr<OString[]>
+                        m_superTypeNames;
     OString             m_doku;
     OString             m_fileName;
     sal_uInt16          m_fieldCount;
@@ -665,7 +649,7 @@ public:
 
     ~TypeWriter();
 
-    void setSuperType(sal_uInt16 index, OString const & name);
+    void setSuperType(sal_uInt16 index, OString const & name) const;
 
     void createBlop(); // throws std::bad_alloc
 };
@@ -687,7 +671,6 @@ TypeWriter::TypeWriter(typereg_Version version,
             RTTypeClass | (published ? RT_TYPE_PUBLISHED : 0)))
      , m_typeName(typeName)
     , m_nSuperTypes(superTypeCount)
-    , m_pUik(nullptr)
     , m_doku(documentation)
     , m_fileName(fileName)
     , m_fieldCount(fieldCount)
@@ -700,10 +683,7 @@ TypeWriter::TypeWriter(typereg_Version version,
 {
     if (m_nSuperTypes > 0)
     {
-        m_superTypeNames = new OString[m_nSuperTypes];
-    } else
-    {
-        m_superTypeNames = nullptr;
+        m_superTypeNames.reset( new OString[m_nSuperTypes] );
     }
 
     if (m_fieldCount)
@@ -718,9 +698,6 @@ TypeWriter::TypeWriter(typereg_Version version,
 
 TypeWriter::~TypeWriter()
 {
-    if (m_superTypeNames)
-        delete[] m_superTypeNames;
-
     if (m_fieldCount)
         delete[] m_fields;
 
@@ -729,12 +706,9 @@ TypeWriter::~TypeWriter()
 
     if (m_referenceCount)
         delete[] m_references;
-
-    if (m_pUik)
-        delete m_pUik;
 }
 
-void TypeWriter::setSuperType(sal_uInt16 index, OString const & name)
+void TypeWriter::setSuperType(sal_uInt16 index, OString const & name) const
 {
     m_superTypeNames[index] = name;
 }
@@ -754,7 +728,6 @@ void TypeWriter::createBlop()
     CPInfo  root(CP_TAG_INVALID, nullptr);
     sal_uInt16  cpIndexThisName = 0;
     sal_uInt16* cpIndexSuperNames = nullptr;
-    sal_uInt16  cpIndexUik = 0;
     sal_uInt16  cpIndexDoku = 0;
     sal_uInt16  cpIndexFileName = 0;
     CPInfo* pInfo = nullptr;
@@ -791,14 +764,6 @@ void TypeWriter::createBlop()
         }
     }
 
-    // create CP entry for uik
-    if (m_pUik != nullptr)
-    {
-        pInfo = new CPInfo(CP_TAG_UIK, pInfo);
-        pInfo->m_value.aUik = m_pUik;
-        cpIndexUik = pInfo->m_index;
-    }
-
     // create CP entry for doku
     if (!m_doku.isEmpty())
     {
@@ -893,7 +858,7 @@ void TypeWriter::createBlop()
 
     if (m_methodCount)
     {
-        sal_uInt16* pMethodEntrySize = new sal_uInt16[m_methodCount];
+        std::unique_ptr<sal_uInt16[]> pMethodEntrySize( new sal_uInt16[m_methodCount] );
         sal_uInt16  cpIndexName = 0;
         sal_uInt16  cpIndexReturn = 0;
         sal_uInt16  cpIndexDoku2 = 0;
@@ -1001,8 +966,6 @@ void TypeWriter::createBlop()
                 cpIndexName = 0;
             }
         }
-
-        delete[] pMethodEntrySize;
     }
 
     // reference blop
@@ -1084,7 +1047,7 @@ void TypeWriter::createBlop()
     pBuffer += writeUINT16(pBuffer, (sal_uInt16)RT_UNO_IDL);
     pBuffer += writeUINT16(pBuffer, (sal_uInt16)m_typeClass);
     pBuffer += writeUINT16(pBuffer, cpIndexThisName);
-    pBuffer += writeUINT16(pBuffer, cpIndexUik);
+    pBuffer += writeUINT16(pBuffer, 0); // cpIndexUik
     pBuffer += writeUINT16(pBuffer, cpIndexDoku);
     pBuffer += writeUINT16(pBuffer, cpIndexFileName);
 
@@ -1181,10 +1144,10 @@ sal_Bool TYPEREG_CALLTYPE typereg_writer_setFieldData(
 
 static void TYPEREG_CALLTYPE setFieldData(TypeWriterImpl    hEntry,
                                           sal_uInt16        index,
-                                          rtl_uString*      name,
-                                          rtl_uString*      typeName,
-                                          rtl_uString*      doku,
-                                          rtl_uString*      fileName,
+                                          rtl_uString const * name,
+                                          rtl_uString const * typeName,
+                                          rtl_uString const * doku,
+                                          rtl_uString const * fileName,
                                           RTFieldAccess     access,
                                           RTValueType       valueType,
                                           RTConstValueUnion constValue)
@@ -1212,12 +1175,12 @@ sal_Bool TYPEREG_CALLTYPE typereg_writer_setMethodData(
 }
 
 sal_Bool TYPEREG_CALLTYPE typereg_writer_setMethodParameterData(
-    void * handle, sal_uInt16 methodIndex, sal_uInt16 parameterIndex,
+    void const * handle, sal_uInt16 methodIndex, sal_uInt16 parameterIndex,
     RTParamMode flags, rtl_uString const * name, rtl_uString const * typeName)
     SAL_THROW_EXTERN_C()
 {
     try {
-        static_cast< TypeWriter * >(handle)->
+        static_cast< TypeWriter const * >(handle)->
             m_methods[methodIndex].m_params[parameterIndex].setData(
                 toByteString(typeName), toByteString(name), flags);
     } catch (std::bad_alloc &) {
@@ -1227,12 +1190,12 @@ sal_Bool TYPEREG_CALLTYPE typereg_writer_setMethodParameterData(
 }
 
 sal_Bool TYPEREG_CALLTYPE typereg_writer_setMethodExceptionTypeName(
-    void * handle, sal_uInt16 methodIndex, sal_uInt16 exceptionIndex,
+    void const * handle, sal_uInt16 methodIndex, sal_uInt16 exceptionIndex,
     rtl_uString const * typeName)
     SAL_THROW_EXTERN_C()
 {
     try {
-        static_cast< TypeWriter * >(handle)->m_methods[methodIndex].setExcName(
+        static_cast< TypeWriter const * >(handle)->m_methods[methodIndex].setExcName(
             exceptionIndex, toByteString(typeName));
     } catch (std::bad_alloc &) {
         return false;
@@ -1305,11 +1268,11 @@ void TYPEREG_CALLTYPE typereg_writer_destroy(void * handle) SAL_THROW_EXTERN_C()
 }
 
 sal_Bool TYPEREG_CALLTYPE typereg_writer_setSuperTypeName(
-    void * handle, sal_uInt16 index, rtl_uString const * typeName)
+    void const * handle, sal_uInt16 index, rtl_uString const * typeName)
     SAL_THROW_EXTERN_C()
 {
     try {
-        static_cast< TypeWriter * >(handle)->setSuperType(
+        static_cast< TypeWriter const * >(handle)->setSuperType(
             index, toByteString(typeName));
     } catch (std::bad_alloc &) {
         return false;
@@ -1318,15 +1281,15 @@ sal_Bool TYPEREG_CALLTYPE typereg_writer_setSuperTypeName(
 }
 
 static TypeWriterImpl TYPEREG_CALLTYPE createEntry(
-    RTTypeClass typeClass, rtl_uString * typeName, rtl_uString * superTypeName,
-    sal_uInt16 fieldCount, sal_uInt16 methodCount, sal_uInt16 referenceCount)
+    RTTypeClass typeClass, rtl_uString const * typeName, rtl_uString const * superTypeName,
+    sal_uInt16 fieldCount)
 {
     OUString empty;
     sal_uInt16 superTypeCount = rtl_uString_getLength(superTypeName) == 0
         ? 0 : 1;
     TypeWriterImpl t = typereg_writer_create(
         TYPEREG_VERSION_0, empty.pData, empty.pData, typeClass, false, typeName,
-        superTypeCount, fieldCount, methodCount, referenceCount);
+        superTypeCount, fieldCount, 0/*methodCount*/, 0/*referenceCount*/);
     if (superTypeCount > 0) {
         typereg_writer_setSuperTypeName(t, 0, superTypeName);
     }
@@ -1338,17 +1301,13 @@ static TypeWriterImpl TYPEREG_CALLTYPE createEntry(
 RegistryTypeWriter::RegistryTypeWriter(RTTypeClass               RTTypeClass,
                                               const rtl::OUString&    typeName,
                                               const rtl::OUString&    superTypeName,
-                                              sal_uInt16                fieldCount,
-                                              sal_uInt16                methodCount,
-                                              sal_uInt16                referenceCount)
+                                              sal_uInt16                fieldCount)
     : m_hImpl(nullptr)
 {
     m_hImpl = createEntry(RTTypeClass,
                                   typeName.pData,
                                   superTypeName.pData,
-                                  fieldCount,
-                                  methodCount,
-                                  referenceCount);
+                                  fieldCount);
 }
 
 RegistryTypeWriter::~RegistryTypeWriter()
