@@ -41,12 +41,11 @@ namespace rptxml
 OXMLReport::OXMLReport( ORptFilter& rImport,
                 sal_uInt16 nPrfx, const OUString& rLName,
                 const Reference< XAttributeList > & _xAttrList
-                ,const uno::Reference< report::XReportDefinition >& _xComponent
-                ,OXMLTable* _pContainer) :
-    OXMLReportElementBase( rImport, nPrfx, rLName,_xComponent.get(),_pContainer)
-    ,m_xComponent(_xComponent)
+                ,const uno::Reference< report::XReportDefinition >& _xComponent) :
+    OXMLReportElementBase( rImport, nPrfx, rLName,_xComponent.get(),nullptr)
+    ,m_xReportDefinition(_xComponent)
 {
-    OSL_ENSURE(m_xComponent.is(),"No Report definition!");
+    OSL_ENSURE(m_xReportDefinition.is(),"No Report definition!");
 
     impl_initRuntimeDefaults();
 
@@ -68,29 +67,30 @@ OXMLReport::OXMLReport( ORptFilter& rImport,
             {
                 case XML_TOK_COMMAND_TYPE:
                     {
-                        sal_uInt16 nRet = static_cast<sal_uInt16>(sdb::CommandType::COMMAND);
-                        const SvXMLEnumMapEntry* aXML_EnumMap = OXMLHelper::GetCommandTypeOptions();
-                        SvXMLUnitConverter::convertEnum( nRet, sValue, aXML_EnumMap );
-                        m_xComponent->setCommandType(nRet);
+                        sal_Int32 nRet = sdb::CommandType::COMMAND;
+                        const SvXMLEnumMapEntry<sal_Int32>* aXML_EnumMap = OXMLHelper::GetCommandTypeOptions();
+                        bool bConvertOk = SvXMLUnitConverter::convertEnum( nRet, sValue, aXML_EnumMap );
+                        SAL_WARN_IF(!bConvertOk, "reportdesign", "convertEnum failed");
+                        m_xReportDefinition->setCommandType(nRet);
                     }
                     break;
                 case XML_TOK_COMMAND:
-                    m_xComponent->setCommand(sValue);
+                    m_xReportDefinition->setCommand(sValue);
                     break;
                 case XML_TOK_FILTER:
-                    m_xComponent->setFilter(sValue);
+                    m_xReportDefinition->setFilter(sValue);
                     break;
                 case XML_TOK_CAPTION:
-                    m_xComponent->setCaption(sValue);
+                    m_xReportDefinition->setCaption(sValue);
                     break;
                 case XML_TOK_ESCAPE_PROCESSING:
-                    m_xComponent->setEscapeProcessing(sValue == s_sTRUE);
+                    m_xReportDefinition->setEscapeProcessing(sValue == s_sTRUE);
                     break;
                 case XML_TOK_REPORT_MIMETYPE:
-                    m_xComponent->setMimeType(sValue);
+                    m_xReportDefinition->setMimeType(sValue);
                     break;
                 case XML_TOK_REPORT_NAME:
-                    m_xComponent->setName(sValue);
+                    m_xReportDefinition->setName(sValue);
                     break;
                 default:
                     break;
@@ -99,7 +99,7 @@ OXMLReport::OXMLReport( ORptFilter& rImport,
     }
     catch(Exception&)
     {
-        OSL_FAIL("Exception catched while filling the report definition props");
+        OSL_FAIL("Exception caught while filling the report definition props");
     }
 }
 
@@ -109,16 +109,15 @@ OXMLReport::~OXMLReport()
 }
 
 
-
 void OXMLReport::impl_initRuntimeDefaults() const
 {
-    OSL_PRECOND( m_xComponent.is(), "OXMLReport::impl_initRuntimeDefaults: no component!" );
-    if ( !m_xComponent.is() )
+    OSL_PRECOND( m_xReportDefinition.is(), "OXMLReport::impl_initRuntimeDefaults: no component!" );
+    if ( !m_xReportDefinition.is() )
         return;
 
     try
     {
-        m_xComponent->setCommandType( sdb::CommandType::COMMAND );
+        m_xReportDefinition->setCommandType( sdb::CommandType::COMMAND );
     }
     catch( const Exception& )
     {
@@ -127,15 +126,14 @@ void OXMLReport::impl_initRuntimeDefaults() const
 }
 
 
-
-SvXMLImportContext* OXMLReport::CreateChildContext(
+SvXMLImportContextRef OXMLReport::CreateChildContext(
         sal_uInt16 nPrefix,
         const OUString& rLocalName,
         const Reference< XAttributeList > & xAttrList )
 {
-    SvXMLImportContext *pContext = _CreateChildContext(nPrefix,rLocalName,xAttrList);
-    if ( pContext )
-        return pContext;
+    SvXMLImportContextRef xContext = CreateChildContext_(nPrefix,rLocalName,xAttrList);
+    if (xContext)
+        return xContext;
     const SvXMLTokenMap&    rTokenMap   = m_rImport.GetReportElemTokenMap();
 
     switch( rTokenMap.Get( nPrefix, rLocalName ) )
@@ -143,65 +141,64 @@ SvXMLImportContext* OXMLReport::CreateChildContext(
         case XML_TOK_REPORT_FUNCTION:
             {
                 m_rImport.GetProgressBarHelper()->Increment( PROGRESS_BAR_STEP );
-                pContext = new OXMLFunction( m_rImport, nPrefix, rLocalName,xAttrList,m_xComponent.get(),true);
+                xContext = new OXMLFunction( m_rImport, nPrefix, rLocalName,xAttrList,m_xReportDefinition.get(),true);
             }
             break;
         case XML_TOK_MASTER_DETAIL_FIELDS:
                 m_rImport.GetProgressBarHelper()->Increment( PROGRESS_BAR_STEP );
-                pContext = new OXMLMasterFields(m_rImport, nPrefix, rLocalName,xAttrList ,this);
+                xContext = new OXMLMasterFields(m_rImport, nPrefix, rLocalName,xAttrList ,this);
             break;
         case XML_TOK_REPORT_HEADER:
             {
                 m_rImport.GetProgressBarHelper()->Increment( PROGRESS_BAR_STEP );
-                m_xComponent->setReportHeaderOn(sal_True);
-                pContext = new OXMLSection( m_rImport, nPrefix, rLocalName,xAttrList ,m_xComponent->getReportHeader());
+                m_xReportDefinition->setReportHeaderOn(true);
+                xContext = new OXMLSection( m_rImport, nPrefix, rLocalName,xAttrList, m_xReportDefinition->getReportHeader());
             }
             break;
         case XML_TOK_PAGE_HEADER:
             {
                 m_rImport.GetProgressBarHelper()->Increment( PROGRESS_BAR_STEP );
-                m_xComponent->setPageHeaderOn(sal_True);
-                pContext = new OXMLSection( m_rImport, nPrefix, rLocalName,xAttrList ,m_xComponent->getPageHeader());
+                m_xReportDefinition->setPageHeaderOn(true);
+                xContext = new OXMLSection( m_rImport, nPrefix, rLocalName,xAttrList, m_xReportDefinition->getPageHeader());
             }
             break;
         case XML_TOK_GROUP:
             m_rImport.GetProgressBarHelper()->Increment( PROGRESS_BAR_STEP );
-            pContext = new OXMLGroup( m_rImport, nPrefix, rLocalName,xAttrList);
+            xContext = new OXMLGroup( m_rImport, nPrefix, rLocalName,xAttrList);
             break;
         case XML_TOK_DETAIL:
             {
                 m_rImport.GetProgressBarHelper()->Increment( PROGRESS_BAR_STEP );
-                pContext = new OXMLSection( m_rImport, nPrefix, rLocalName,xAttrList ,m_xComponent->getDetail());
+                xContext = new OXMLSection( m_rImport, nPrefix, rLocalName,xAttrList, m_xReportDefinition->getDetail());
             }
             break;
         case XML_TOK_PAGE_FOOTER:
             {
                 m_rImport.GetProgressBarHelper()->Increment( PROGRESS_BAR_STEP );
-                m_xComponent->setPageFooterOn(sal_True);
-                pContext = new OXMLSection( m_rImport, nPrefix, rLocalName,xAttrList ,m_xComponent->getPageFooter(),false);
+                m_xReportDefinition->setPageFooterOn(true);
+                xContext = new OXMLSection( m_rImport, nPrefix, rLocalName,xAttrList, m_xReportDefinition->getPageFooter(),false);
             }
             break;
         case XML_TOK_REPORT_FOOTER:
             {
                 m_rImport.GetProgressBarHelper()->Increment( PROGRESS_BAR_STEP );
-                m_xComponent->setReportFooterOn(sal_True);
-                pContext = new OXMLSection( m_rImport, nPrefix, rLocalName,xAttrList ,m_xComponent->getReportFooter());
+                m_xReportDefinition->setReportFooterOn(true);
+                xContext = new OXMLSection( m_rImport, nPrefix, rLocalName,xAttrList, m_xReportDefinition->getReportFooter());
             }
             break;
         default:
             break;
     }
 
-    if( !pContext )
-        pContext = new SvXMLImportContext( GetImport(), nPrefix, rLocalName );
+    if (!xContext)
+        xContext = new SvXMLImportContext( GetImport(), nPrefix, rLocalName );
 
-
-    return pContext;
+    return xContext;
 }
 
 void OXMLReport::EndElement()
 {
-    Reference< XFunctions > xFunctions = m_xComponent->getFunctions();
+    Reference< XFunctions > xFunctions = m_xReportDefinition->getFunctions();
     const ORptFilter::TGroupFunctionMap& aFunctions = m_rImport.getFunctions();
     ORptFilter::TGroupFunctionMap::const_iterator aIter = aFunctions.begin();
     const ORptFilter::TGroupFunctionMap::const_iterator aEnd = aFunctions.end();
@@ -209,9 +206,9 @@ void OXMLReport::EndElement()
         xFunctions->insertByIndex(xFunctions->getCount(),uno::makeAny(aIter->second));
 
     if ( !m_aMasterFields.empty() )
-        m_xComponent->setMasterFields(Sequence< OUString>(&*m_aMasterFields.begin(),m_aMasterFields.size()));
+        m_xReportDefinition->setMasterFields(Sequence< OUString>(&*m_aMasterFields.begin(),m_aMasterFields.size()));
     if ( !m_aDetailFields.empty() )
-        m_xComponent->setDetailFields(Sequence< OUString>(&*m_aDetailFields.begin(),m_aDetailFields.size()));
+        m_xReportDefinition->setDetailFields(Sequence< OUString>(&*m_aDetailFields.begin(),m_aDetailFields.size()));
 }
 
 void OXMLReport::addMasterDetailPair(const ::std::pair< OUString,OUString >& _aPair)
