@@ -17,13 +17,15 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
+#include <FunctionHelper.hxx>
+
+#include <osl/diagnose.h>
+#include <formula/funcvarargs.h>
 
-#include "FunctionHelper.hxx"
 
-// =============================================================================
 namespace rptui
 {
-// =============================================================================
+
     using namespace ::com::sun::star;
 
 FunctionManager::FunctionManager(const uno::Reference< report::meta::XFunctionManager>& _xMgr)
@@ -50,43 +52,30 @@ sal_Unicode FunctionManager::getSingleToken(const formula::IFunctionManager::ETo
     }
     return 0;
 }
-// -----------------------------------------------------------------------------
+
 sal_uInt32 FunctionManager::getCount() const
 {
     return m_xMgr->getCount();
 }
-// -----------------------------------------------------------------------------
+
 const formula::IFunctionCategory* FunctionManager::getCategory(sal_uInt32 _nPos) const
 {
     if ( _nPos >= m_aCategoryIndex.size() )
     {
         uno::Reference< report::meta::XFunctionCategory> xCategory = m_xMgr->getCategory(_nPos);
-        ::boost::shared_ptr< FunctionCategory > pCategory(new FunctionCategory(this,_nPos + 1,xCategory));
-        m_aCategoryIndex.push_back( m_aCategories.insert(TCategoriesMap::value_type(xCategory->getName(),pCategory)).first );
+        std::shared_ptr< FunctionCategory > pCategory(new FunctionCategory(this,_nPos + 1,xCategory));
+        m_aCategoryIndex.push_back( m_aCategories.emplace(xCategory->getName(),pCategory).first );
     }
     return m_aCategoryIndex[_nPos]->second.get();
 }
-// -----------------------------------------------------------------------------
-const formula::IFunctionDescription* FunctionManager::getFunctionByName(const OUString& _sFunctionName) const
-{
-    const formula::IFunctionDescription* pDesc = NULL;
-    try
-    {
-        pDesc = get(m_xMgr->getFunctionByName(_sFunctionName)).get();
-    }
-    catch(uno::Exception&)
-    {
-    }
-    return pDesc;
-}
-// -----------------------------------------------------------------------------
+
 void FunctionManager::fillLastRecentlyUsedFunctions(::std::vector< const formula::IFunctionDescription*>& /*_rLastRUFunctions*/) const
 {
 }
-// -----------------------------------------------------------------------------
-::boost::shared_ptr< FunctionDescription > FunctionManager::get(const uno::Reference< report::meta::XFunctionDescription>& _xFunctionDescription) const
+
+std::shared_ptr< FunctionDescription > FunctionManager::get(const uno::Reference< report::meta::XFunctionDescription>& _xFunctionDescription) const
 {
-    ::boost::shared_ptr< FunctionDescription > pDesc;
+    std::shared_ptr< FunctionDescription > pDesc;
     if ( _xFunctionDescription.is() )
     {
         const OUString sFunctionName = _xFunctionDescription->getName();
@@ -98,16 +87,16 @@ void FunctionManager::fillLastRecentlyUsedFunctions(::std::vector< const formula
             TCategoriesMap::iterator aCategoryFind = m_aCategories.find(sCategoryName);
             if ( aCategoryFind == m_aCategories.end() )
             {
-                aCategoryFind = m_aCategories.insert(TCategoriesMap::value_type(sCategoryName,::boost::shared_ptr< FunctionCategory > (new FunctionCategory(this,xCategory->getNumber() + 1,xCategory)))).first;
+                aCategoryFind = m_aCategories.emplace(sCategoryName,std::make_shared< FunctionCategory > (this,xCategory->getNumber() + 1,xCategory)).first;
                 m_aCategoryIndex.push_back( aCategoryFind );
             }
-            aFunctionFind = m_aFunctions.insert(TFunctionsMap::value_type(sFunctionName,::boost::shared_ptr<FunctionDescription>(new FunctionDescription(aCategoryFind->second.get(),_xFunctionDescription)))).first;
+            aFunctionFind = m_aFunctions.emplace(sFunctionName,std::make_shared<FunctionDescription>(aCategoryFind->second.get(),_xFunctionDescription)).first;
         }
         pDesc = aFunctionFind->second;
     }
     return pDesc;
 }
-// -----------------------------------------------------------------------------
+
 FunctionCategory::FunctionCategory(const FunctionManager* _pFMgr,sal_uInt32 _nPos,const uno::Reference< report::meta::XFunctionCategory>& _xCategory)
 : m_xCategory(_xCategory)
 ,m_nFunctionCount(_xCategory->getCount())
@@ -115,38 +104,33 @@ FunctionCategory::FunctionCategory(const FunctionManager* _pFMgr,sal_uInt32 _nPo
 ,m_pFunctionManager(_pFMgr)
 {
 }
-// -----------------------------------------------------------------------------
+
 sal_uInt32 FunctionCategory::getCount() const
 {
     return m_nFunctionCount;
 }
-// -----------------------------------------------------------------------------
+
 const formula::IFunctionDescription* FunctionCategory::getFunction(sal_uInt32 _nPos) const
 {
     if ( _nPos >= m_aFunctions.size() && _nPos < m_nFunctionCount )
     {
         uno::Reference< report::meta::XFunctionDescription> xFunctionDescription = m_xCategory->getFunction(_nPos);
-        ::boost::shared_ptr< FunctionDescription > pFunction = m_pFunctionManager->get(xFunctionDescription);
+        std::shared_ptr< FunctionDescription > pFunction = m_pFunctionManager->get(xFunctionDescription);
         m_aFunctions.push_back( pFunction );
     }
     return m_aFunctions[_nPos].get();
 }
-// -----------------------------------------------------------------------------
+
 sal_uInt32 FunctionCategory::getNumber() const
 {
     return m_nNumber;
 }
-// -----------------------------------------------------------------------------
-const formula::IFunctionManager* FunctionCategory::getFunctionManager() const
-{
-    return m_pFunctionManager;
-}
-// -----------------------------------------------------------------------------
+
 OUString FunctionCategory::getName() const
 {
     return m_xCategory->getName();
 }
-// -----------------------------------------------------------------------------
+
 FunctionDescription::FunctionDescription(const formula::IFunctionCategory* _pFunctionCategory,const uno::Reference< report::meta::XFunctionDescription>& _xFunctionDescription)
 : m_xFunctionDescription(_xFunctionDescription)
 , m_pFunctionCategory(_pFunctionCategory)
@@ -157,29 +141,28 @@ OUString FunctionDescription::getFunctionName() const
 {
     return m_xFunctionDescription->getName();
 }
-// -----------------------------------------------------------------------------
+
 const formula::IFunctionCategory* FunctionDescription::getCategory() const
 {
     return m_pFunctionCategory;
 }
-// -----------------------------------------------------------------------------
+
 OUString FunctionDescription::getDescription() const
 {
     return m_xFunctionDescription->getDescription();
 }
-// -----------------------------------------------------------------------------
-xub_StrLen FunctionDescription::getSuppressedArgumentCount() const
+
+sal_Int32 FunctionDescription::getSuppressedArgumentCount() const
 {
-    return static_cast<xub_StrLen>(m_aParameter.getLength());
+    return m_aParameter.getLength();
 }
-// -----------------------------------------------------------------------------
+
 OUString FunctionDescription::getFormula(const ::std::vector< OUString >& _aArguments) const
 {
     OUString sFormula;
     try
     {
-        const OUString *pArguments = _aArguments.empty() ? 0 : &_aArguments[0];
-        sFormula = m_xFunctionDescription->createFormula(uno::Sequence< OUString >(pArguments, _aArguments.size()));
+        sFormula = m_xFunctionDescription->createFormula(uno::Sequence< OUString >(_aArguments.data(), _aArguments.size()));
     }
     catch(const uno::Exception&)
     {
@@ -187,58 +170,93 @@ OUString FunctionDescription::getFormula(const ::std::vector< OUString >& _aArgu
     }
     return sFormula;
 }
-// -----------------------------------------------------------------------------
+
 void FunctionDescription::fillVisibleArgumentMapping(::std::vector<sal_uInt16>& _rArguments) const
 {
     const sal_Int32 nCount = m_aParameter.getLength();
-    for(sal_uInt16 i = 0;i < nCount; ++i)
+    for(sal_Int32 i = 0;i < nCount; ++i)
     {
         _rArguments.push_back(i);
     }
 }
-// -----------------------------------------------------------------------------
+
 void FunctionDescription::initArgumentInfo()  const
 {
 }
-// -----------------------------------------------------------------------------
+
 OUString FunctionDescription::getSignature() const
 {
     return m_xFunctionDescription->getSignature();
 }
-// -----------------------------------------------------------------------------
+
 OString FunctionDescription::getHelpId() const
 {
     return OString();
 }
-// -----------------------------------------------------------------------------
+
+bool FunctionDescription::isHidden() const
+{
+    return false;
+}
+
 sal_uInt32 FunctionDescription::getParameterCount() const
 {
     return m_aParameter.getLength();
 }
-// -----------------------------------------------------------------------------
+
+sal_uInt32 FunctionDescription::getVarArgsStart() const
+{
+    /* XXX there are no variable number of arguments, are there? Nevertheless
+     * consider the varargs handling of the Function Wizard and return a value
+     * within the bounds of parameters. */
+    // Don't use defines/constants that could change in future, parameter count
+    // could be part of an implicit stable API.
+    // offapi/com/sun/star/report/meta/XFunctionDescription.idl doesn't tell.
+    const sal_uInt32 nVarArgs30 = 30;           // ugly hard coded old VAR_ARGS of formula::ParaWin
+    const sal_uInt32 nPairedVarArgs60 = 60;     // ugly hard coded old PAIRED_VAR_ARGS of formula::ParaWin
+    const sal_uInt32 nVarArgs255 = 255;         // ugly hard coded new VAR_ARGS of formula::ParaWin
+    const sal_uInt32 nPairedVarArgs510 = 510;   // ugly hard coded new PAIRED_VAR_ARGS of formula::ParaWin
+    sal_uInt32 nLen = m_aParameter.getLength();
+    // If the value of VAR_ARGS changes then adapt *and* maintain implicit API
+    // stability, ie. old code using the old VAR_ARGS and PAIRED_VAR_ARGS
+    // values must still be handled. It is *not* sufficient to simply change
+    // the values here.
+    static_assert(nVarArgs255 == VAR_ARGS && nPairedVarArgs510 == PAIRED_VAR_ARGS,
+            "VAR_ARGS or PAIRED_VAR_ARGS has unexpected value");
+    if (nLen >= nPairedVarArgs510)
+        nLen -= nPairedVarArgs510;
+    else if (nLen >= nVarArgs255)
+        nLen -= nVarArgs255;
+    else if (nLen >= nPairedVarArgs60)
+        nLen -= nPairedVarArgs60;
+    else if (nLen >= nVarArgs30)
+        nLen -= nVarArgs30;
+    return nLen ? nLen - 1 : 0;
+}
+
 OUString FunctionDescription::getParameterName(sal_uInt32 _nPos) const
 {
     if ( _nPos < static_cast<sal_uInt32>(m_aParameter.getLength()) )
         return m_aParameter[_nPos].Name;
     return OUString();
 }
-// -----------------------------------------------------------------------------
+
 OUString FunctionDescription::getParameterDescription(sal_uInt32 _nPos) const
 {
     if ( _nPos < static_cast<sal_uInt32>(m_aParameter.getLength()) )
         return m_aParameter[_nPos].Description;
     return OUString();
 }
-// -----------------------------------------------------------------------------
+
 bool FunctionDescription::isParameterOptional(sal_uInt32 _nPos) const
 {
     if ( _nPos < static_cast<sal_uInt32>(m_aParameter.getLength()) )
         return m_aParameter[_nPos].IsOptional;
     return false;
 }
-// -----------------------------------------------------------------------------
-// =============================================================================
+
+
 } // rptui
-// =============================================================================
+
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
