@@ -17,27 +17,27 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "DesignView.hxx"
-#include "ReportController.hxx"
+#include <DesignView.hxx>
+#include <ReportController.hxx>
 #include <comphelper/types.hxx>
 #include <svtools/acceleratorexecute.hxx>
 #include <unotools/syslocale.hxx>
 #include <unotools/viewoptions.hxx>
-#include "RptDef.hxx"
-#include "UITools.hxx"
-#include "RptObject.hxx"
-#include "propbrw.hxx"
+#include <RptDef.hxx>
+#include <UITools.hxx>
+#include <RptObject.hxx>
+#include <propbrw.hxx>
 #include <toolkit/helper/convert.hxx>
-#include "helpids.hrc"
-#include "SectionView.hxx"
-#include "ReportSection.hxx"
-#include "rptui_slotid.hrc"
+#include <helpids.h>
+#include <SectionView.hxx>
+#include <ReportSection.hxx>
+#include <rptui_slotid.hrc>
 #include <svx/svxids.hrc>
-#include "AddField.hxx"
-#include "ScrollHelper.hxx"
-#include "Navigator.hxx"
-#include "SectionWindow.hxx"
-#include "RptResId.hrc"
+#include <AddField.hxx>
+#include <ScrollHelper.hxx>
+#include <Navigator.hxx>
+#include <SectionWindow.hxx>
+#include <strings.hrc>
 
 #include <vcl/settings.hxx>
 #include <vcl/svapp.hxx>
@@ -115,7 +115,6 @@ ODesignView::ODesignView(   vcl::Window* pParent,
     m_aSplitWin->SetAlign(WindowAlign::Left);
     m_aSplitWin->Show();
 
-    m_aMarkIdle.SetPriority( TaskPriority::LOW );
     m_aMarkIdle.SetInvokeHandler( LINK( this, ODesignView, MarkTimeout ) );
 }
 
@@ -407,8 +406,6 @@ IMPL_LINK_NOARG( ODesignView, SplitHdl, SplitWindow*, void )
 
     if ( (aOutputSize.Width() - nTest) >= nMinWidth && nTest > m_aScrollWindow->getMaxMarkerWidth() )
     {
-        long nOldSplitPos = getController().getSplitPos();
-        (void)nOldSplitPos;
         getController().setSplitPos(nTest);
     }
 }
@@ -586,11 +583,11 @@ void ODesignView::alignMarkedObjects(ControlModification _nControlModification,b
 
 bool ODesignView::handleKeyEvent(const KeyEvent& _rEvent)
 {
-    if ( (m_pPropWin && m_pPropWin->HasChildPathFocus()) )
+    if ( m_pPropWin && m_pPropWin->HasChildPathFocus() )
         return false;
-    if ( (m_pAddField && m_pAddField->HasChildPathFocus()) )
+    if ( m_pAddField && m_pAddField->HasChildPathFocus() )
         return false;
-    if ( (m_pReportExplorer && m_pReportExplorer->HasChildPathFocus()) )
+    if ( m_pReportExplorer && m_pReportExplorer->HasChildPathFocus() )
         return false;
     return m_aScrollWindow->handleKeyEvent(_rEvent);
 }
