@@ -16,15 +16,15 @@
  *   except in compliance with the License. You may obtain a copy of
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
-#include "StartMarker.hxx"
+#include <StartMarker.hxx>
 #include <vcl/image.hxx>
 #include <vcl/svapp.hxx>
-#include "RptResId.hrc"
-#include "ModuleHelper.hxx"
-#include "ColorChanger.hxx"
-#include "ReportDefines.hxx"
-#include "SectionWindow.hxx"
-#include "helpids.hrc"
+#include <strings.hrc>
+#include <bitmaps.hlst>
+#include <ColorChanger.hxx>
+#include <ReportDefines.hxx>
+#include <SectionWindow.hxx>
+#include <helpids.h>
 #include <vcl/help.hxx>
 #include <vcl/gradient.hxx>
 #include <vcl/lineinfo.hxx>
@@ -32,7 +32,6 @@
 
 #include <toolkit/helper/vclunohelper.hxx>
 #include <unotools/syslocale.hxx>
-#include <svl/smplhint.hxx>
 
 #define CORNER_SPACE     5
 
@@ -54,8 +53,6 @@ OStartMarker::OStartMarker(OSectionWindow* _pParent,const OUString& _sColorEntry
 ,m_pParent(_pParent)
 ,m_bShowRuler(true)
 {
-    SetUniqueId(HID_RPT_STARTMARKER);
-
     osl_atomic_increment(&s_nImageRefCount);
     initDefaultNodeImages();
     ImplInitSettings();
@@ -72,7 +69,7 @@ OStartMarker::OStartMarker(OSectionWindow* _pParent,const OUString& _sColorEntry
     m_aVRuler->SetMargin1();
     m_aVRuler->SetMargin2();
     const MeasurementSystem eSystem = SvtSysLocale().GetLocaleData().getMeasurementSystemEnum();
-    m_aVRuler->SetUnit(MEASURE_METRIC == eSystem ? FUNIT_CM : FUNIT_INCH);
+    m_aVRuler->SetUnit(MeasurementSystem::Metric == eSystem ? FUNIT_CM : FUNIT_INCH);
     EnableChildTransparentMode();
     SetParentClipMode( ParentClipMode::NoClip );
     SetPaintTransparent( true );
@@ -104,10 +101,9 @@ sal_Int32 OStartMarker::getMinHeight() const
     return LogicToPixel(Size(0, m_aText->GetTextHeight())).Height() + long(aExtraWidth);
 }
 
-void OStartMarker::Paint(vcl::RenderContext& rRenderContext, const Rectangle& /*rRect*/)
+void OStartMarker::Paint(vcl::RenderContext& rRenderContext, const tools::Rectangle& /*rRect*/)
 {
     Size aSize(GetOutputSizePixel());
-    long nSize = aSize.Width();
     const long nCornerWidth = long(CORNER_SPACE * double(GetMapMode().GetScaleX()));
 
     if (isCollapsed())
@@ -117,13 +113,13 @@ void OStartMarker::Paint(vcl::RenderContext& rRenderContext, const Rectangle& /*
     else
     {
         const long nVRulerWidth = m_aVRuler->GetSizePixel().Width();
-        nSize = aSize.Width() - nVRulerWidth;
+        long nSize = aSize.Width() - nVRulerWidth;
         aSize.Width() += nCornerWidth;
-        rRenderContext.SetClipRegion(vcl::Region(rRenderContext.PixelToLogic(Rectangle(Point(),
+        rRenderContext.SetClipRegion(vcl::Region(rRenderContext.PixelToLogic(tools::Rectangle(Point(),
                                                                              Size(nSize, aSize.Height())))));
     }
 
-    Rectangle aWholeRect(Point(), aSize);
+    tools::Rectangle aWholeRect(Point(), aSize);
     {
         const ColorChanger aColors(&rRenderContext, m_nTextBoundaries, m_nColor);
         tools::PolyPolygon aPoly;
@@ -137,7 +133,7 @@ void OStartMarker::Paint(vcl::RenderContext& rRenderContext, const Rectangle& /*
         aStartColor.RGBtoHSB(nHue, nSat, nBri);
         nSat += 40;
         Color aEndColor(Color::HSBtoRGB(nHue, nSat, nBri));
-        Gradient aGradient(GradientStyle_LINEAR,aStartColor,aEndColor);
+        Gradient aGradient(GradientStyle::Linear,aStartColor,aEndColor);
         aGradient.SetSteps(static_cast<sal_uInt16>(aSize.Height()));
 
         rRenderContext.DrawGradient(PixelToLogic(aPoly) ,aGradient);
@@ -145,12 +141,12 @@ void OStartMarker::Paint(vcl::RenderContext& rRenderContext, const Rectangle& /*
     if (m_bMarked)
     {
         const long nCornerHeight = long(CORNER_SPACE * double(GetMapMode().GetScaleY()));
-        Rectangle aRect(Point(nCornerWidth, nCornerHeight),
+        tools::Rectangle aRect(Point(nCornerWidth, nCornerHeight),
                         Size(aSize.Width() - nCornerWidth - nCornerWidth,
                              aSize.Height() - nCornerHeight - nCornerHeight));
         ColorChanger aColors(&rRenderContext, COL_WHITE, COL_WHITE);
         rRenderContext.DrawPolyLine( tools::Polygon(rRenderContext.PixelToLogic(aRect)),
-                                    LineInfo(LINE_SOLID, 2));
+                                    LineInfo(LineStyle::Solid, 2));
     }
 }
 
@@ -174,7 +170,7 @@ void OStartMarker::MouseButtonUp( const MouseEvent& rMEvt )
     const Size aOutputSize = GetOutputSizePixel();
     if( aPos.X() > aOutputSize.Width() || aPos.Y() > aOutputSize.Height() )
         return;
-    Rectangle aRect(m_aImage->GetPosPixel(),m_aImage->GetSizePixel());
+    tools::Rectangle aRect(m_aImage->GetPosPixel(),m_aImage->GetSizePixel());
     if ( rMEvt.GetClicks() == 2 || aRect.IsInside( aPos ) )
     {
         m_bCollapsed = !m_bCollapsed;
@@ -198,8 +194,8 @@ void OStartMarker::initDefaultNodeImages()
 {
     if ( !s_pDefCollapsed )
     {
-        s_pDefCollapsed     = new Image( ModuleRes( RID_IMG_TREENODE_COLLAPSED      ) );
-        s_pDefExpanded      = new Image( ModuleRes( RID_IMG_TREENODE_EXPANDED       ) );
+        s_pDefCollapsed = new Image(BitmapEx(RID_BMP_TREENODE_COLLAPSED));
+        s_pDefExpanded = new Image(BitmapEx(RID_BMP_TREENODE_EXPANDED));
     }
 
     Image* pImage = m_bCollapsed ? s_pDefCollapsed : s_pDefExpanded;
@@ -237,14 +233,13 @@ void OStartMarker::Resize()
     aImageSize.Width() = long(aImageSize.Width() * (double)rMapMode.GetScaleX());
     aImageSize.Height() = long(aImageSize.Height() * (double)rMapMode.GetScaleY());
 
-    Fraction aExtraWidth(long(REPORT_EXTRA_SPACE));
-    aExtraWidth *= rMapMode.GetScaleX();
+    long nExtraWidth = long(REPORT_EXTRA_SPACE * rMapMode.GetScaleX());
 
-    Point aPos(aImageSize.Width() + (long)(aExtraWidth + aExtraWidth), aExtraWidth);
+    Point aPos(aImageSize.Width() + (nExtraWidth * 2), nExtraWidth);
     const long nHeight = ::std::max<sal_Int32>(nOutputHeight - 2*aPos.Y(),LogicToPixel(Size(0,m_aText->GetTextHeight())).Height());
     m_aText->SetPosSizePixel(aPos,Size(aRulerPos.X() - aPos.X(),nHeight));
 
-    aPos.X() = aExtraWidth;
+    aPos.X() = nExtraWidth;
     aPos.Y() += static_cast<sal_Int32>((LogicToPixel(Size(0,m_aText->GetTextHeight())).Height() - aImageSize.Height()) * 0.5) ;
     m_aImage->SetPosSizePixel(aPos,aImageSize);
 }
@@ -257,8 +252,7 @@ void OStartMarker::setTitle(const OUString& _sTitle)
 void OStartMarker::Notify(SfxBroadcaster & rBc, SfxHint const & rHint)
 {
     OColorListener::Notify(rBc, rHint);
-    const SfxSimpleHint* pSimpleHint = dynamic_cast<const SfxSimpleHint*>(&rHint);
-    if (pSimpleHint && pSimpleHint->GetId() == SFX_HINT_COLORS_CHANGED)
+    if (rHint.GetId() == SfxHintId::ColorsChanged)
     {
         setColor();
         Invalidate(InvalidateFlags::Children);
@@ -275,8 +269,8 @@ void OStartMarker::RequestHelp( const HelpEvent& rHEvt )
 {
     if( !m_aText->GetText().isEmpty())
     {
-        // Hilfe anzeigen
-        Rectangle aItemRect(rHEvt.GetMousePosPixel(),Size(GetSizePixel().Width(),getMinHeight()));
+        // show help
+        tools::Rectangle aItemRect(rHEvt.GetMousePosPixel(),Size(GetSizePixel().Width(),getMinHeight()));
         Point aPt = OutputToScreenPixel( aItemRect.TopLeft() );
         aItemRect.Left()   = aPt.X();
         aItemRect.Top()    = aPt.Y();
