@@ -23,6 +23,10 @@ import java.lang.reflect.Array;
 import java.lang.reflect.Constructor;
 import java.util.ArrayList;
 import java.util.Iterator;
+import java.util.UUID;
+import java.util.WeakHashMap;
+
+import com.sun.star.lib.uno.typedesc.FieldDescription;
 import com.sun.star.lib.uno.typedesc.TypeDescription;
 import com.sun.star.lib.util.WeakMap;
 
@@ -31,7 +35,7 @@ import com.sun.star.lib.util.WeakMap;
  *
  * <p>The methods <code>queryInterface</code> and <code>areSame</code> delegate
  * calls to the implementing objects and are used instead of casts,
- * <code>instanceof</code>, <code>==</code>, and <code>equals</code>.<p>
+ * <code>instanceof</code>, <code>==</code>, and <code>equals</code>.</p>
  *
  * <p>For historic reasons, this class is not <code>final</code>, and has a
  * <code>public</code> constructor.  These artifacts are considered mistakes,
@@ -104,7 +108,16 @@ public class UnoRuntime {
         if (object instanceof IQueryInterface) {
             oid = ((IQueryInterface) object).getOid();
         }
-        return oid == null ? object.hashCode() + oidSuffix : oid;
+        if (oid == null) {
+            synchronized (oidMap) {
+                 oid = oidMap.get(object);
+                 if (oid == null) {
+                     oid = UUID.randomUUID().toString() + oidSuffix;
+                     oidMap.put(object, oid);
+                 }
+            }
+        }
+        return oid;
     }
 
     /**
@@ -160,6 +173,7 @@ public class UnoRuntime {
      * Queries the given UNO object for the given Java class (which must
      * represent a UNO interface type).
      *
+     * @param <T> the requested UNO interface type.
      * @param zInterface a Java class representing a UNO interface type
      * @param object a reference to any Java object representing (a facet of) a
      * UNO object; may be <code>null</code>
@@ -242,12 +256,12 @@ public class UnoRuntime {
             return v1 == v2;
         case TypeClass.STRUCT_value:
         case TypeClass.EXCEPTION_value:
-            IFieldDescription[] fs;
+            FieldDescription[] fs;
             try {
                 fs = TypeDescription.getTypeDescription(t).
                     getFieldDescriptions();
             } catch (ClassNotFoundException e) {
-                throw new java.lang.RuntimeException(e.toString());
+                throw new java.lang.RuntimeException(e);
             }
             for (int i = 0; i< fs.length; ++i) {
                 Type ft = new Type(fs[i].getTypeDescription());
@@ -263,7 +277,7 @@ public class UnoRuntime {
                         return false;
                     }
                 } catch (IllegalAccessException e) {
-                    throw new java.lang.RuntimeException(e.toString());
+                    throw new java.lang.RuntimeException(e);
                 }
             }
             return true;
@@ -306,16 +320,16 @@ public class UnoRuntime {
         case TypeClass.BOOLEAN_value:
             return Boolean.FALSE;
         case TypeClass.BYTE_value:
-            return new Byte((byte) 0);
+            return Byte.valueOf((byte) 0);
         case TypeClass.SHORT_value:
         case TypeClass.UNSIGNED_SHORT_value:
-            return new Short((short) 0);
+            return Short.valueOf((short) 0);
         case TypeClass.LONG_value:
         case TypeClass.UNSIGNED_LONG_value:
-            return new Integer(0);
+            return Integer.valueOf(0);
         case TypeClass.HYPER_value:
         case TypeClass.UNSIGNED_HYPER_value:
-            return new Long(0L);
+            return Long.valueOf(0);
         case TypeClass.FLOAT_value:
             return new Float(0.0f);
         case TypeClass.DOUBLE_value:
@@ -338,7 +352,7 @@ public class UnoRuntime {
             } catch (java.lang.RuntimeException e) {
                 throw e;
             } catch (java.lang.Exception e) {
-                throw new java.lang.RuntimeException(e.toString());
+                throw new java.lang.RuntimeException(e);
             }
         case TypeClass.ENUM_value:
             try {
@@ -347,7 +361,7 @@ public class UnoRuntime {
             } catch (java.lang.RuntimeException e) {
                 throw e;
             } catch (java.lang.Exception e) {
-                throw new java.lang.RuntimeException(e.toString());
+                throw new java.lang.RuntimeException(e);
             }
         default:
             throw new IllegalArgumentException(
@@ -382,8 +396,11 @@ public class UnoRuntime {
      * previously set context will be removed
     */
     public static void setCurrentContext(XCurrentContext context) {
-        // optimize this by using Java 1.5 ThreadLocal.remove if context == null
-        currentContext.set(context);
+        if (context == null) {
+            currentContext.remove();
+        } else {
+            currentContext.set(context);
+        }
     }
 
     /**
@@ -398,6 +415,8 @@ public class UnoRuntime {
      *
      * @param name the name of the environment
      * @param context the context of the environment
+     * @throws Exception if something goes awry.
+     * @return an environment.
      * @see com.sun.star.uno.IEnvironment
      *
      * @deprecated As of UDK&nbsp;3.2.0, this method is deprecated, without
@@ -437,6 +456,7 @@ public class UnoRuntime {
      * @param from the source environment
      * @param to the target environment
      * @param args the initial arguments for the bridge
+     * @throws Exception if something goes awry.
      * @return the requested bridge
      * @see #getBridgeByName
      * @see com.sun.star.uno.IBridge
@@ -493,6 +513,7 @@ public class UnoRuntime {
      * @param to the name of the target environment
      * @param toContext the context for the target environment
      * @param args the initial arguments for the bridge
+     * @throws Exception if something goes awry.
      * @return the requested bridge
      * @see #getBridge
      * @see #getEnvironment
@@ -543,6 +564,7 @@ public class UnoRuntime {
      *
      * @param from the source environment
      * @param to the target environment
+     * @throws Exception if something goes awry.
      * @return the requested mapping
      * @see com.sun.star.uno.IEnvironment
      * @see com.sun.star.uno.IMapping
@@ -572,6 +594,7 @@ public class UnoRuntime {
      *
      * @param from the name of the source environment
      * @param to the name of the target environment
+     * @throws Exception if something goes awry.
      * @return the requested mapping
      * @see #getEnvironment
      * @see #getMapping
@@ -591,10 +614,14 @@ public class UnoRuntime {
      *
      * <p>Releases all references to bridges and environments.</p>
      *
+     * @return true if another thread didn't re-insert some bridge or
+     *         environment before the method returns.  Why that information
+     *         would be useful is anybody's guess.
+     *
      * @deprecated As of UDK&nbsp;3.2.0, this method is deprecated, without
      * offering a replacement.
      */
-    static public boolean reset() {
+    public static boolean reset() {
         synchronized (bridges) {
             for (Iterator<java.lang.ref.WeakReference<IBridge>> i = bridges.values().iterator(); i.hasNext();) {
                 IBridge b = WeakMap.getValue(i.next());
@@ -624,7 +651,7 @@ public class UnoRuntime {
     /**
      * @deprecated As of UDK&nbsp;3.2.0, do not use this internal field.
      */
-    static public final boolean DEBUG = false;
+    public static final boolean DEBUG = false;
 
     private static final class BridgeTurner implements IBridge {
         public BridgeTurner(IBridge bridge) {
@@ -674,6 +701,7 @@ public class UnoRuntime {
         private final IBridge bridge;
     }
 
+    private static final WeakHashMap<Object,String> oidMap = new WeakHashMap<Object,String>();
     private static final String uniqueKeyHostPrefix
     = Integer.toString(new Object().hashCode(), 16) + ":";
     private static final Object uniqueKeyLock = new Object();
