@@ -20,17 +20,15 @@
 // include files
 
 #include <sal/types.h>
-#include "cppunit/TestAssert.h"
-#include "cppunit/TestFixture.h"
-#include "cppunit/extensions/HelperMacros.h"
-#include "cppunit/plugin/TestPlugIn.h"
+#include <cppunit/TestAssert.h>
+#include <cppunit/TestFixture.h>
+#include <cppunit/extensions/HelperMacros.h>
+#include <cppunit/plugin/TestPlugIn.h>
 #include <rtl/ustring.hxx>
 
 #include <osl/test/uniquepipename.hxx>
 #include <osl/thread.hxx>
 
-#include <osl/mutex.hxx>
-
 #include <osl/pipe.hxx>
 #include <osl/time.h>
 
@@ -119,7 +117,7 @@ namespace osl_Pipe
     class ctors : public CppUnit::TestFixture
     {
     public:
-        bool bRes, bRes1;
+        bool bRes, bRes1, bRes2;
 
         void ctors_none( )
             {
@@ -167,29 +165,28 @@ namespace osl_Pipe
                                         bRes );
             }
 
-        /**  tester comment:
-
-        When test the following two constructors, don't know how to test the
-        acquire and no acquire action. possible plans:
-        1.release one handle and check the other( did not success since the
-        other still exist and valid. )
-        2. release one handle twice to see getLastError( )(the getLastError
-        always returns invalidError(LINUX)).
-        */
-
+        /* Note: DO NOT DO THIS - I have very deliberately caused send to FAIL, *on purpose* as this is the
+           only sane way to test noacquire. This is a terrible misuse of no-acquire, but in this case is
+           needed only so we can test to make sure no-acquire is working!
+         */
         void ctors_no_acquire( )
             {
                 /// create a pipe.
-                ::osl::Pipe aPipe( test::uniquePipeName(aTestPipeName), osl_Pipe_CREATE );
-                osl_acquirePipe(aPipe.getHandle());
+                OUString aPipeName(test::uniquePipeName(aTestPipeName));
+                oslPipe handle(osl_createPipe(aPipeName.pData, osl_Pipe_CREATE, nullptr));
                 /// constructs a pipe reference without acquiring the handle.
-                ::osl::Pipe aNoAcquirePipe( aPipe.getHandle( ), SAL_NO_ACQUIRE );
+                std::unique_ptr<osl::Pipe> xNoAcquirePipe(new osl::Pipe(handle, SAL_NO_ACQUIRE));
 
-                bRes = aNoAcquirePipe.is( );
-                ///aPipe.clear( );
-                ///bRes1 = aNoAcquirePipe.is( );
+                StreamPipe aStreamPipe(handle);
+                xNoAcquirePipe.reset();
+                int nRet = aStreamPipe.send("a", 1);
 
-                CPPUNIT_ASSERT_MESSAGE( "#test comment#: test constructor with no acquire of handle, only validation test, do not know how to test no acquire.",
+                if (nRet >= 0)
+                    bRes = false;
+                else
+                    bRes = true;
+
+                CPPUNIT_ASSERT_MESSAGE( "#test comment#: test constructor with no acquire of handle, deleted nonacquired pipe but could still send on original pipe!.",
                                         bRes );
             }
 
@@ -197,15 +194,20 @@ namespace osl_Pipe
             {
                 /// create a base pipe.
                 ::osl::Pipe aPipe( test::uniquePipeName(aTestPipeName), osl_Pipe_CREATE );
-                /// constructs two pipes without acquiring the handle on the base pipe.
+                /// constructs two pipes, the second acquires the first pipe's handle.
                 ::osl::Pipe aAcquirePipe( aPipe.getHandle( ) );
                 ::osl::Pipe aAcquirePipe1( nullptr );
 
-                bRes = aAcquirePipe.is( );
-                bRes1 = aAcquirePipe1.is( );
+                bRes = aAcquirePipe.is();
+                bRes1 = aAcquirePipe1.is();
+                bRes2 = aPipe == aAcquirePipe;
 
-                CPPUNIT_ASSERT_MESSAGE( "#test comment#: test constructor with no acquire of handle.only validation test, do not know how to test no acquire.",
-                                        bRes && !bRes1 );
+                CPPUNIT_ASSERT_MESSAGE( "#test comment#: test constructor with acquire of handle, original pipe does not exist.",
+                                        bRes );
+                CPPUNIT_ASSERT_MESSAGE( "#test comment#: test constructor with acquire of handle, copied pipe does not exist",
+                                        !bRes1 );
+
+                CPPUNIT_ASSERT_MESSAGE( "#test comment#: test pipes should have same handle", bRes2);
             }
 
         CPPUNIT_TEST_SUITE( ctors );
@@ -216,7 +218,7 @@ namespace osl_Pipe
         CPPUNIT_TEST( ctors_no_acquire );
         CPPUNIT_TEST( ctors_acquire );
         CPPUNIT_TEST_SUITE_END( );
-    }; // class ctors
+    };
 
     /** testing the method:
         inline sal_Bool SAL_CALL is() const;
@@ -259,7 +261,7 @@ namespace osl_Pipe
         CPPUNIT_TEST( is_003 );
         CPPUNIT_TEST( is_004 );
         CPPUNIT_TEST_SUITE_END( );
-    }; // class is
+    };
 
     /** testing the methods:
         inline sal_Bool create( const ::rtl::OUString & strName,
@@ -287,7 +289,9 @@ namespace osl_Pipe
                 aPipe.clear( );
 
                 CPPUNIT_ASSERT_MESSAGE( "#test comment#: test creation.",
-                                        bRes && !bRes1);
+                                        bRes);
+                CPPUNIT_ASSERT_MESSAGE( "#test comment#: test creation.",
+                                        !bRes1);
             }
 
         void create_named_security_002( )
@@ -299,7 +303,9 @@ namespace osl_Pipe
                 aPipe.clear( );
 
                 CPPUNIT_ASSERT_MESSAGE( "#test comment#: test creation and open.",
-                                        bRes && bRes1);
+                                        bRes);
+                CPPUNIT_ASSERT_MESSAGE( "#test comment#: test creation and open.",
+                                        bRes1);
             }
 
         void create_named_001( )
@@ -310,7 +316,9 @@ namespace osl_Pipe
                 aPipe.clear( );
 
                 CPPUNIT_ASSERT_MESSAGE( "#test comment#: test creation.",
-                                        bRes && !bRes1);
+                                        bRes);
+                CPPUNIT_ASSERT_MESSAGE( "#test comment#: test creation.",
+                                        !bRes1);
             }
 
         void create_named_002( )
@@ -321,7 +329,9 @@ namespace osl_Pipe
                 aPipe.clear( );
 
                 CPPUNIT_ASSERT_MESSAGE( "#test comment#: test creation and open.",
-                                        bRes && bRes1);
+                                        bRes);
+                CPPUNIT_ASSERT_MESSAGE( "#test comment#: test creation and open.",
+                                        bRes1);
             }
 
         void create_named_003( )
@@ -341,7 +351,7 @@ namespace osl_Pipe
         CPPUNIT_TEST( create_named_002 );
         CPPUNIT_TEST( create_named_003 );
         CPPUNIT_TEST_SUITE_END( );
-    }; // class create
+    };
 
     /** testing the method:
         inline void SAL_CALL clear();
@@ -365,7 +375,7 @@ namespace osl_Pipe
         CPPUNIT_TEST_SUITE( clear );
         CPPUNIT_TEST( clear_001 );
         CPPUNIT_TEST_SUITE_END( );
-    }; // class clear
+    };
 
     /** testing the methods:
         inline Pipe& SAL_CALL operator= (const Pipe& pipe);
@@ -387,7 +397,9 @@ namespace osl_Pipe
                 aPipe1.close( );
 
                 CPPUNIT_ASSERT_MESSAGE( "#test comment#: test assign with reference.",
-                                        bRes && bRes1 );
+                                        bRes );
+                CPPUNIT_ASSERT_MESSAGE( "#test comment#: test assign with reference.",
+                                        bRes1 );
             }
 
         void assign_handle( )
@@ -401,14 +413,16 @@ namespace osl_Pipe
                 aPipe1.close( );
 
                 CPPUNIT_ASSERT_MESSAGE( "#test comment#: test assign with handle.",
-                                        bRes && bRes1 );
+                                        bRes );
+                CPPUNIT_ASSERT_MESSAGE( "#test comment#: test assign with handle.",
+                                        bRes1 );
             }
 
         CPPUNIT_TEST_SUITE( assign );
         CPPUNIT_TEST( assign_ref );
         CPPUNIT_TEST( assign_handle );
         CPPUNIT_TEST_SUITE_END( );
-    }; // class assign
+    };
 
     /** testing the method:
         inline sal_Bool SAL_CALL isValid() const;
@@ -449,14 +463,16 @@ namespace osl_Pipe
                 aPipe2.close( );
 
                 CPPUNIT_ASSERT_MESSAGE( "#test comment#: test isEqual(),create one copy instance, and compare.",
-                                        bRes && !bRes1 );
+                                        bRes );
+                CPPUNIT_ASSERT_MESSAGE( "#test comment#: test isEqual(),create one copy instance, and compare.",
+                                        !bRes1 );
             }
 
         CPPUNIT_TEST_SUITE( isEqual );
         CPPUNIT_TEST( isEqual_001 );
         CPPUNIT_TEST( isEqual_002 );
         CPPUNIT_TEST_SUITE_END( );
-    }; // class isEqual
+    };
 
     /** testing the method:
         inline void SAL_CALL close();
@@ -476,7 +492,9 @@ namespace osl_Pipe
                 bRes1 = aPipe.is( );
 
                 CPPUNIT_ASSERT_MESSAGE( "#test comment#: difference between close and clear.",
-                                        bRes && !bRes1);
+                                        bRes);
+                CPPUNIT_ASSERT_MESSAGE( "#test comment#: difference between close and clear.",
+                                        !bRes1);
             }
 
         void close_002( )
@@ -493,7 +511,7 @@ namespace osl_Pipe
         CPPUNIT_TEST( close_001 );
         CPPUNIT_TEST( close_002 );
         CPPUNIT_TEST_SUITE_END( );
-    }; // class close
+    };
 
     /** testing the method:
         inline oslPipeError SAL_CALL accept(StreamPipe& Connection);
@@ -536,7 +554,7 @@ namespace osl_Pipe
         CPPUNIT_TEST( getError_001 );
         CPPUNIT_TEST( getError_002 );
         CPPUNIT_TEST_SUITE_END( );
-    }; // class getError
+    };
 
     /** testing the method:
         inline oslPipe SAL_CALL getHandle() const;
@@ -546,7 +564,7 @@ namespace osl_Pipe
     public:
         bool bRes, bRes1;
 
-        void getHandle_001( )
+        void getHandle_equalityOperatorAgainstSelf( )
             {
                 ::osl::Pipe aPipe( test::uniquePipeName(aTestPipeName), osl_Pipe_OPEN );
                 bRes = aPipe == aPipe.getHandle( );
@@ -556,7 +574,7 @@ namespace osl_Pipe
                                         bRes );
             }
 
-        void getHandle_002( )
+        void getHandle_equalityOperatorAgainstDerivedPipe( )
             {
                 ::osl::Pipe aPipe( test::uniquePipeName(aTestPipeName), osl_Pipe_CREATE );
                 ::osl::Pipe aPipe1( aPipe.getHandle( ) );
@@ -569,10 +587,10 @@ namespace osl_Pipe
             }
 
         CPPUNIT_TEST_SUITE( getHandle );
-        CPPUNIT_TEST( getHandle_001 );
-        CPPUNIT_TEST( getHandle_002 );
+        CPPUNIT_TEST( getHandle_equalityOperatorAgainstSelf );
+        CPPUNIT_TEST( getHandle_equalityOperatorAgainstDerivedPipe );
         CPPUNIT_TEST_SUITE_END( );
-    }; // class getHandle
+    };
 
     CPPUNIT_TEST_SUITE_REGISTRATION(osl_Pipe::ctors);
     CPPUNIT_TEST_SUITE_REGISTRATION(osl_Pipe::is);
@@ -617,7 +635,9 @@ namespace osl_StreamPipe
                 aStreamPipe1.clear( );
 
                 CPPUNIT_ASSERT_MESSAGE( "#test comment#: test constructor with no parameter, before and after assign.",
-                                        !bRes && bRes1 );
+                                        !bRes );
+                CPPUNIT_ASSERT_MESSAGE( "#test comment#: test constructor with no parameter, before and after assign.",
+                                        bRes1 );
             }
 
         void ctors_handle( )
@@ -708,12 +728,12 @@ namespace osl_StreamPipe
         CPPUNIT_TEST( ctors_name_option_security );
         CPPUNIT_TEST( ctors_no_acquire );
         CPPUNIT_TEST_SUITE_END( );
-    }; // class ctors
+    };
 
     /** testing the methods:
         inline StreamPipe & SAL_CALL operator=(oslPipe Pipe);
         inline StreamPipe& SAL_CALL operator=(const Pipe& pipe);
-        mindy: not implementated in osl/pipe.hxx, so remove the cases
+        mindy: not implemented in osl/pipe.hxx, so remove the cases
     */
 
     /** wait _nSec seconds.
@@ -736,9 +756,6 @@ namespace osl_StreamPipe
         sal_Char buf[256];
         Pipe_DataSink_Thread( ) { }
 
-        virtual ~Pipe_DataSink_Thread( ) override
-            {
-            }
     protected:
         void SAL_CALL run( ) override
             {
@@ -800,7 +817,7 @@ namespace osl_StreamPipe
                 {
                     //start server and wait for connection.
                     printf("accept\n");
-                    if ( osl_Pipe_E_None != aListenPipe.accept( aConnectionPipe ) )
+                    if ( aListenPipe.accept( aConnectionPipe ) != osl_Pipe_E_None )
                     {
                         printf("pipe accept failed!");
                         return;
@@ -849,7 +866,8 @@ namespace osl_StreamPipe
 
                 int nCompare1 = strcmp( myDataSinkThread.buf, m_pTestString1.getStr() );
                 int nCompare2 = strcmp( myDataSourceThread.buf, m_pTestString2.getStr() );
-                CPPUNIT_ASSERT_MESSAGE( "test send/recv/write/read.", nCompare1 == 0 && nCompare2 == 0 );
+                CPPUNIT_ASSERT_EQUAL_MESSAGE( "test send/recv/write/read.", 0, nCompare1 );
+                CPPUNIT_ASSERT_EQUAL_MESSAGE( "test send/recv/write/read.", 0, nCompare2 );
             }
         //close pipe when accept
         void recv_002()
@@ -869,7 +887,7 @@ namespace osl_StreamPipe
         CPPUNIT_TEST( recv_001 );
         CPPUNIT_TEST( recv_002 );
         CPPUNIT_TEST_SUITE_END( );
-    }; // class recv
+    };
 
     CPPUNIT_TEST_SUITE_REGISTRATION(osl_StreamPipe::ctors);
 //CPPUNIT_TEST_SUITE_REGISTRATION(osl_StreamPipe::assign);
@@ -877,6 +895,4 @@ namespace osl_StreamPipe
 
 } // namespace osl_StreamPipe
 
-CPPUNIT_PLUGIN_IMPLEMENT();
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
