@@ -17,34 +17,23 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-//------------------------------------------------------------------------
-// header file
-//------------------------------------------------------------------------
-#ifdef WNT
+#include <algorithm>
+#ifdef _WIN32
+#if !defined WIN32_LEAN_AND_MEAN
+# define WIN32_LEAN_AND_MEAN
+#endif
 #include <windows.h>
 #undef min
 #endif
-#include <osl_Security_Const.h>
+#include "osl_Security_Const.h"
 #include <osl/thread.h>
 #include <rtl/process.h>
 #include <rtl/strbuf.hxx>
+#include <o3tl/char16_t2wchar_t.hxx>
 
 using namespace osl;
 using namespace rtl;
 
-
-//------------------------------------------------------------------------
-// helper functions and classes
-//------------------------------------------------------------------------
-
-/** print Boolean value.
-*/
-inline void printBool( sal_Bool bOk )
-{
-    //t_print("#printBool# " );
-    ( sal_True == bOk ) ? t_print("TRUE!\n" ): t_print("FALSE!\n" );
-}
-
 /** print a UNI_CODE String.
 */
 inline void printUString( const ::rtl::OUString & str )
@@ -56,10 +45,7 @@ inline void printUString( const ::rtl::OUString & str )
     t_print("%s\n", aString.getStr( ) );
 }
 
-
-//------------------------------------------------------------------------
 // test code start here
-//------------------------------------------------------------------------
 
 namespace osl_Security
 {
@@ -70,14 +56,14 @@ namespace osl_Security
     class ctors : public CppUnit::TestFixture
     {
     public:
-        sal_Bool bRes, bRes1;
+        bool bRes, bRes1;
 
         void ctors_001( )
         {
             ::osl::Security aSec;
 
             CPPUNIT_ASSERT_MESSAGE( "#test comment#: create a security  its handle should not be NULL.",
-                                    aSec.getHandle( ) != NULL );
+                                    aSec.getHandle( ) != nullptr );
         }
 
         CPPUNIT_TEST_SUITE( ctors );
@@ -85,7 +71,6 @@ namespace osl_Security
         CPPUNIT_TEST_SUITE_END( );
     }; // class ctors
 
-
     /** testing the methods:
         inline sal_Bool SAL_CALL logonUser(const ::rtl::OUString& strName,
                                        const ::rtl::OUString& strPasswd);
@@ -96,7 +81,7 @@ namespace osl_Security
     class logonUser : public CppUnit::TestFixture
     {
     public:
-        sal_Bool bRes;
+        bool bRes;
 
         void logonUser_user_pwd( )
         {
@@ -104,7 +89,7 @@ namespace osl_Security
             bRes = aSec.logonUser( aLogonUser, aLogonPasswd );
 
             CPPUNIT_ASSERT_MESSAGE( "#test comment#: check logon user through forwarded user name, pwd, passed in (UNX), failed in (W32).",
-                                    ( sal_True == bRes )  );
+                                    bRes );
         }
 
         void logonUser_user_pwd_server( )
@@ -113,17 +98,16 @@ namespace osl_Security
             bRes = aSec.logonUser( aLogonUser, aLogonPasswd, aFileServer );
 
             CPPUNIT_ASSERT_MESSAGE( "#test comment#: check logon user through forwarded user name, pwd and server name, failed in (UNX)(W32).",
-                                    ( sal_True == bRes )  );
+                                    bRes );
         }
 
-
         CPPUNIT_TEST_SUITE( logonUser );
-        if  ( !aStringForward.isEmpty() && aStringForward.indexOf( (sal_Unicode)' ' ) != -1 && ( aStringForward.indexOf( ( sal_Unicode ) ' ' ) ==  aStringForward.lastIndexOf( ( sal_Unicode ) ' ' ) ) )
+        if  ( !aStringForward.isEmpty() && aStringForward.indexOf( ' ' ) != -1 && ( aStringForward.indexOf( ' ' ) ==  aStringForward.lastIndexOf( ' ' ) ) )
         /// if user name and passwd are forwarded
         {
             CPPUNIT_TEST( logonUser_user_pwd );
         }
-        if  ( !aStringForward.isEmpty() && aStringForward.indexOf( (sal_Unicode)' ' ) != -1 && ( aStringForward.indexOf( ( sal_Unicode ) ' ' ) !=  aStringForward.lastIndexOf( ( sal_Unicode ) ' ' ) ) )
+        if  ( !aStringForward.isEmpty() && aStringForward.indexOf( ' ' ) != -1 && ( aStringForward.indexOf( ' ' ) !=  aStringForward.lastIndexOf( ' ' ) ) )
         /// if user name and passwd and file server are forwarded
         {
             CPPUNIT_TEST( logonUser_user_pwd_server );
@@ -131,14 +115,13 @@ namespace osl_Security
         CPPUNIT_TEST_SUITE_END( );
     }; // class logonUser
 
-
     /** testing the method:
         inline sal_Bool Security::getUserIdent( rtl::OUString& strIdent) const
     */
     class getUserIdent : public CppUnit::TestFixture
     {
     public:
-        sal_Bool bRes, bRes1;
+        bool bRes, bRes1;
 
         void getUserIdent_001( )
         {
@@ -154,7 +137,8 @@ namespace osl_Security
             aMessage.append(", bRes: ");
             aMessage.append(bRes);
 
-            CPPUNIT_ASSERT_MESSAGE( aMessage.getStr(), strUserID.equals(strID) && (bRes == sal_True));
+            CPPUNIT_ASSERT_EQUAL_MESSAGE( aMessage.getStr(), strUserID, strID );
+            CPPUNIT_ASSERT_MESSAGE( aMessage.getStr(), bRes );
         }
 
         CPPUNIT_TEST_SUITE( getUserIdent );
@@ -162,19 +146,18 @@ namespace osl_Security
         CPPUNIT_TEST_SUITE_END( );
     }; // class getUserIdent
 
-
     /** testing the method:
         inline sal_Bool SAL_CALL getUserName( ::rtl::OUString& strName) const;
     */
     class getUserName : public CppUnit::TestFixture
     {
     public:
-        sal_Bool bRes, bRes1;
+        bool bRes, bRes1;
 
         void getUserName_001( )
         {
             ::osl::Security aSec;
-#ifdef WNT
+#ifdef _WIN32
             ::rtl::OUString strName( strUserName ), strGetName;
 #else
             ::rtl::OUString strName( strUserName ), strGetName;
@@ -187,7 +170,9 @@ namespace osl_Security
                 nPos = strGetName.indexOf(strName);
             }
             CPPUNIT_ASSERT_MESSAGE( "#test comment#: get UserName and compare it with names got at the beginning of the test.",
-                                    ( nPos >= 0 ) && ( sal_True == bRes ) );
+                                    ( nPos >= 0 ) );
+            CPPUNIT_ASSERT_MESSAGE( "#test comment#: get UserName and compare it with names got at the beginning of the test.",
+                                    bRes );
         }
 
         CPPUNIT_TEST_SUITE( getUserName );
@@ -195,14 +180,13 @@ namespace osl_Security
         CPPUNIT_TEST_SUITE_END( );
     }; // class getUserName
 
-
     /** testing the method:
         inline sal_Bool Security::getConfigDir( rtl::OUString& strDirectory ) const
     */
     class getConfigDir : public CppUnit::TestFixture
     {
     public:
-        sal_Bool bRes, bRes1;
+        bool bRes, bRes1;
 
         void getConfigDir_001( )
         {
@@ -210,8 +194,7 @@ namespace osl_Security
             ::rtl::OUString strConfig;
             bRes = aSec.getConfigDir( strConfig );
 
-            CPPUNIT_ASSERT_MESSAGE( "failed to find a ConfigDir!",
-                                     ( sal_True == bRes ));
+            CPPUNIT_ASSERT_MESSAGE( "failed to find a ConfigDir!", bRes );
         }
 
         CPPUNIT_TEST_SUITE( getConfigDir );
@@ -225,15 +208,15 @@ namespace osl_Security
     class isAdministrator : public CppUnit::TestFixture
     {
     public:
-        sal_Bool bRes;
+        bool bRes;
 
         void isAdministrator_001( )
         {
             ::osl::Security aSec;
             bRes = aSec.isAdministrator(  );
 
-            CPPUNIT_ASSERT_MESSAGE( "#test comment#: check if the user is administrator at beginning, compare here.",
-                                     bRes == isAdmin );
+            CPPUNIT_ASSERT_EQUAL_MESSAGE( "#test comment#: check if the user is administrator at beginning, compare here.",
+                                     isAdmin, bRes );
         }
 
         CPPUNIT_TEST_SUITE( isAdministrator );
@@ -247,15 +230,15 @@ namespace osl_Security
     class getHandle : public CppUnit::TestFixture
     {
     public:
-        sal_Bool bRes;
+        bool bRes;
 
         void getHandle_001( )
         {
             ::osl::Security aSec;
-            bRes = aSec.isAdministrator( ) == osl_isAdministrator( aSec.getHandle( ) );
+            bRes = aSec.isAdministrator( ) == bool(osl_isAdministrator( aSec.getHandle( ) ));
 
             CPPUNIT_ASSERT_MESSAGE( "#test comment#: use getHandle function to call C API.",
-                                     bRes == sal_True );
+                                     bRes );
         }
 
         CPPUNIT_TEST_SUITE( getHandle );
@@ -263,7 +246,6 @@ namespace osl_Security
         CPPUNIT_TEST_SUITE_END( );
     }; // class getHandle
 
-
     class UserProfile : public CppUnit::TestFixture
     {
     public:
@@ -271,9 +253,9 @@ namespace osl_Security
         void loadUserProfile( )
             {
                 ::osl::Security aSec;
-                sal_Bool bValue = osl_loadUserProfile(aSec.getHandle());
+                bool bValue = osl_loadUserProfile(aSec.getHandle());
 
-                CPPUNIT_ASSERT_MESSAGE( "empty function.", bValue == sal_False );
+                CPPUNIT_ASSERT_MESSAGE( "empty function.", !bValue );
             }
 
         void unloadUserProfile( )
@@ -303,7 +285,7 @@ namespace osl_Security
 
                 oslSecurityError erg = osl_loginUserOnFileServer(suUserName.pData, suPassword.pData, suFileServer.pData, &pSec);
 
-                CPPUNIT_ASSERT_MESSAGE( "empty function.", erg == osl_Security_E_UserUnknown );
+                CPPUNIT_ASSERT_EQUAL_MESSAGE( "empty function.", osl_Security_E_UserUnknown, erg );
             }
 
         CPPUNIT_TEST_SUITE( loginUserOnFileServer );
@@ -311,7 +293,6 @@ namespace osl_Security
         CPPUNIT_TEST_SUITE_END( );
     }; // class loginUserOnFileServer
 
-// -----------------------------------------------------------------------------
 CPPUNIT_TEST_SUITE_REGISTRATION(osl_Security::ctors);
 CPPUNIT_TEST_SUITE_REGISTRATION(osl_Security::logonUser);
 CPPUNIT_TEST_SUITE_REGISTRATION(osl_Security::getUserIdent);
@@ -322,11 +303,8 @@ CPPUNIT_TEST_SUITE_REGISTRATION(osl_Security::getHandle);
 CPPUNIT_TEST_SUITE_REGISTRATION(osl_Security::UserProfile);
 CPPUNIT_TEST_SUITE_REGISTRATION(osl_Security::loginUserOnFileServer);
 
-// -----------------------------------------------------------------------------
-
 } // namespace osl_Security
 
-
 /* This defines an own TestPlugIn implementation with an own initialize()
     method that will be called after loading the PlugIn
     */
@@ -337,17 +315,16 @@ class MyTestPlugInImpl: public CPPUNIT_NS::TestPlugInDefaultImpl
     public:
     MyTestPlugInImpl() {};
     void initialize( CPPUNIT_NS::TestFactoryRegistry *registry,
-                   const CPPUNIT_NS::PlugInParameters &parameters );
+                   const CPPUNIT_NS::PlugInParameters &parameters ) override;
 };
 
-
 void MyTestPlugInImpl::initialize( CPPUNIT_NS::TestFactoryRegistry *,
                    const CPPUNIT_NS::PlugInParameters & )
 {
     /// start message
     t_print("#Initializing ...\n" );
     t_print("#\n#logonUser function need root/Administrator account to test.\n" );
-    t_print("#You can test by login with root/Administrator, and excute:\n" );
+    t_print("#You can test by login with root/Administrator, and execute:\n" );
     t_print("#testshl2 -forward \"username password\" ../../../wntmsci9/bin/Security.dll\n" );
     t_print("#      where username and password are forwarded account info.\n" );
     t_print("#if no text forwarded, this function will be skipped.\n" );
@@ -356,9 +333,8 @@ void MyTestPlugInImpl::initialize( CPPUNIT_NS::TestFactoryRegistry *,
 #if ( defined UNX )
     /// some initialization work for UNIX OS
 
-
     struct passwd* pw;
-    CPPUNIT_ASSERT_MESSAGE( "getpwuid: no password entry\n",( pw = getpwuid( getuid() ) ) != NULL );
+    CPPUNIT_ASSERT_MESSAGE( "getpwuid: no password entry\n",( pw = getpwuid( getuid() ) ) != nullptr );
 
     /// get user ID;
     strUserID = OUString::number( getuid( ) );
@@ -370,61 +346,60 @@ void MyTestPlugInImpl::initialize( CPPUNIT_NS::TestFactoryRegistry *,
     char *pw_dir = pw->pw_dir;
     if( getenv( "FAKEROOTKEY" ) )
         pw_dir = getenv("HOME");
-    CPPUNIT_ASSERT_MESSAGE( "#Convert from system path to URL failed.",
-                            ::osl::File::E_None == ::osl::File::getFileURLFromSystemPath( ::rtl::OUString::createFromAscii( pw_dir ), strHomeDirectory ) );
+    CPPUNIT_ASSERT_EQUAL_MESSAGE( "#Convert from system path to URL failed.",
+                            ::osl::File::E_None, ::osl::File::getFileURLFromSystemPath( ::rtl::OUString::createFromAscii( pw_dir ), strHomeDirectory ) );
 
     /// get config directory;
     strConfigDirectory = strHomeDirectory.copy(0);
 
     /// is administrator;
     if( !getuid( ) )
-        isAdmin = sal_True;
+        isAdmin = true;
 
 #endif
-#if defined ( WNT )
+#if defined(_WIN32)
     /// some initialization work for Windows OS
 
-
     /// Get the user name, computer name, user home directory.
-    LPTSTR lpszSystemInfo;      // pointer to system information string
+    LPWSTR lpszSystemInfo;      // pointer to system information string
     DWORD cchBuff = BUFSIZE;    // size of computer or user name
-    TCHAR tchBuffer[BUFSIZE];   // buffer for string
+    WCHAR wchBuffer[BUFSIZE];   // buffer for string
+
+    lpszSystemInfo = wchBuffer;
+    if( GetUserNameW(lpszSystemInfo, &cchBuff) )
+        strUserName = o3tl::toU(lpszSystemInfo);
 
-    lpszSystemInfo = tchBuffer;
     cchBuff = BUFSIZE;
-    if( GetUserNameA(lpszSystemInfo, &cchBuff) )
-        strUserName = ::rtl::OUString::createFromAscii( lpszSystemInfo );
-
-    if( GetComputerName(lpszSystemInfo, &cchBuff) )
-        strComputerName = ::rtl::OUString::createFromAscii( lpszSystemInfo );
+    if( GetComputerNameW(lpszSystemInfo, &cchBuff) )
+        strComputerName = o3tl::toU(lpszSystemInfo);
 
     /// Get user home directory.
     HKEY hRegKey;
-    sal_Char PathA[_MAX_PATH];
-    ::rtl::OUString strHome;
-    if (RegOpenKey(HKEY_CURRENT_USER,  "Software\\Microsoft\\Windows\\CurrentVersion\\Explorer\\Shell Folders",  &hRegKey) == ERROR_SUCCESS)
+    if (RegOpenKeyW(HKEY_CURRENT_USER, L"Software\\Microsoft\\Windows\\CurrentVersion\\Explorer\\Shell Folders", &hRegKey) == ERROR_SUCCESS)
     {
-        LONG lRet, lSize = sizeof(PathA);
+        sal_Unicode PathW[_MAX_PATH];
+        LSTATUS lRet;
+        DWORD lSize = sizeof(PathW);
         DWORD Type;
 
-        lRet = RegQueryValueEx(hRegKey, "AppData", NULL, &Type, ( unsigned char * )PathA, ( unsigned long * )&lSize);
-        if ( ( lRet == ERROR_SUCCESS ) && ( Type == REG_SZ ) &&  ( _access( PathA, 0 ) == 0 ) )
+        lRet = RegQueryValueExW(hRegKey, L"AppData", nullptr, &Type, reinterpret_cast<unsigned char *>(PathW), &lSize);
+        if ( ( lRet == ERROR_SUCCESS ) && ( Type == REG_SZ ) &&  ( _waccess( o3tl::toW(PathW), 0 ) == 0 ) )
         {
-            CPPUNIT_ASSERT_MESSAGE( "#Convert from system path to URL failed.",
-                                    ::osl::File::E_None == ::osl::File::getFileURLFromSystemPath( ::rtl::OUString::createFromAscii( PathA ), strConfigDirectory ) );
+            CPPUNIT_ASSERT_EQUAL_MESSAGE( "#Convert from system path to URL failed.",
+                                    ::osl::File::E_None, ::osl::File::getFileURLFromSystemPath( PathW, strConfigDirectory ) );
         }
 
-        lRet = RegQueryValueEx(hRegKey, "Personal", NULL, &Type, ( unsigned char * )PathA, ( unsigned long * )&lSize);
-        if ( ( lRet == ERROR_SUCCESS ) && ( Type == REG_SZ ) &&  ( _access( PathA, 0 ) == 0 ) )
+        lSize = sizeof(PathW);
+        lRet = RegQueryValueExW(hRegKey, L"Personal", nullptr, &Type, reinterpret_cast<unsigned char *>(PathW), &lSize);
+        if ( ( lRet == ERROR_SUCCESS ) && ( Type == REG_SZ ) &&  ( _waccess( o3tl::toW(PathW), 0 ) == 0 ) )
         {
-            CPPUNIT_ASSERT_MESSAGE( "#Convert from system path to URL failed.",
-                                    ::osl::File::E_None == ::osl::File::getFileURLFromSystemPath( ::rtl::OUString::createFromAscii( PathA ), strHomeDirectory ) );
+            CPPUNIT_ASSERT_EQUAL_MESSAGE( "#Convert from system path to URL failed.",
+                                    ::osl::File::E_None, ::osl::File::getFileURLFromSystemPath( PathW, strHomeDirectory ) );
         }
 
         RegCloseKey(hRegKey);
     }
 
-
     /// Get user Security ID:
 
     // Create buffers that may be large enough. If a buffer is too small, the count parameter will be set to the size needed.
@@ -433,19 +408,19 @@ void MyTestPlugInImpl::initialize( CPPUNIT_NS::TestFactoryRegistry *,
     DWORD dwSidBufferSize = INITIAL_SIZE;
     DWORD cchDomainName = 0;
     DWORD dwDomainBufferSize = INITIAL_SIZE;
-    WCHAR * wszDomainName = NULL;
+    WCHAR * wszDomainName = nullptr;
     SID_NAME_USE eSidType;
     DWORD dwErrorCode = 0;
 
-    LPCWSTR wszAccName = ( LPWSTR ) strUserName.getStr( );
+    LPCWSTR wszAccName = o3tl::toW(strUserName.getStr( ));
 
     // Create buffers for the SID and the domain name.
-    PSID pSid = (PSID) new BYTE[dwSidBufferSize];
-    CPPUNIT_ASSERT_MESSAGE("# creating SID buffer failed.\n", pSid!= NULL );
+    PSID pSid = static_cast<PSID>(new BYTE[dwSidBufferSize]);
+    CPPUNIT_ASSERT_MESSAGE("# creating SID buffer failed.\n", pSid!= nullptr );
     memset( pSid, 0, dwSidBufferSize);
 
     wszDomainName = new WCHAR[dwDomainBufferSize];
-    CPPUNIT_ASSERT_MESSAGE("# creating Domain name buffer failed.\n", wszDomainName != NULL );
+    CPPUNIT_ASSERT_MESSAGE("# creating Domain name buffer failed.\n", wszDomainName != nullptr );
     memset(wszDomainName, 0, dwDomainBufferSize*sizeof(WCHAR));
 
     // Obtain the SID for the account name passed.
@@ -455,7 +430,7 @@ void MyTestPlugInImpl::initialize( CPPUNIT_NS::TestFactoryRegistry *,
         cbSid = dwSidBufferSize;
         cchDomainName = dwDomainBufferSize;
         if (LookupAccountNameW(
-                           NULL,            // Computer name. NULL for the local computer
+                           nullptr,            // Computer name. NULL for the local computer
                            wszAccName,
                            pSid,          // Pointer to the SID buffer. Use NULL to get the size needed,
                            &cbSid,          // Size of the SID buffer needed.
@@ -478,8 +453,8 @@ void MyTestPlugInImpl::initialize( CPPUNIT_NS::TestFactoryRegistry *,
                 // Reallocate memory for the SID buffer.
                 wprintf(L"# The SID buffer was too small. It will be reallocated.\n");
                 FreeSid( pSid);
-                pSid = (PSID) new BYTE[cbSid];
-                CPPUNIT_ASSERT_MESSAGE("# re-creating SID buffer failed.\n",  pSid!= NULL );
+                pSid = static_cast<PSID>(new BYTE[cbSid]);
+                CPPUNIT_ASSERT_MESSAGE("# re-creating SID buffer failed.\n",  pSid!= nullptr );
                 memset( pSid, 0, cbSid);
                 dwSidBufferSize = cbSid;
             }
@@ -489,7 +464,7 @@ void MyTestPlugInImpl::initialize( CPPUNIT_NS::TestFactoryRegistry *,
                 wprintf(L"# The domain name buffer was too small. It will be reallocated.\n");
                 delete [] wszDomainName;
                 wszDomainName = new WCHAR[cchDomainName];
-                CPPUNIT_ASSERT_MESSAGE("# re-creating domain name buffer failed.\n", wszDomainName!= NULL );
+                CPPUNIT_ASSERT_MESSAGE("# re-creating domain name buffer failed.\n", wszDomainName!= nullptr );
                 memset(wszDomainName, 0, cchDomainName*sizeof(WCHAR));
                 dwDomainBufferSize = cchDomainName;
             }
@@ -507,7 +482,7 @@ void MyTestPlugInImpl::initialize( CPPUNIT_NS::TestFactoryRegistry *,
     DWORD dwSidRev=SID_REVISION;
     DWORD dwCounter;
     DWORD dwSidSize;
-    sal_Char    *Ident;
+    wchar_t *Ident;
 
     /* obtain SidIdentifierAuthority */
     psia=GetSidIdentifierAuthority(pSid);
@@ -516,16 +491,16 @@ void MyTestPlugInImpl::initialize( CPPUNIT_NS::TestFactoryRegistry *,
     dwSubAuthorities=std::min((int) *GetSidSubAuthorityCount(pSid), 5);
 
     /* buffer length: S-SID_REVISION- + identifierauthority- + subauthorities- + NULL */
-    Ident=(sal_Char * )malloc(88*sizeof(sal_Char));
+    Ident=static_cast<wchar_t *>(malloc(88*sizeof(wchar_t)));
 
     /* prepare S-SID_REVISION- */
-    dwSidSize=wsprintf(Ident, TEXT("S-%lu-"), dwSidRev);
+    dwSidSize=wsprintfW(Ident, L"S-%lu-", dwSidRev);
 
     /* prepare SidIdentifierAuthority */
     if ((psia->Value[0] != 0) || (psia->Value[1] != 0))
     {
-        dwSidSize+=wsprintf(Ident + strlen(Ident),
-                    TEXT("0x%02hx%02hx%02hx%02hx%02hx%02hx"),
+        dwSidSize+=wsprintfW(Ident + wcslen(Ident),
+                    L"0x%02hx%02hx%02hx%02hx%02hx%02hx",
                     (sal_uInt16)psia->Value[0],
                     (sal_uInt16)psia->Value[1],
                     (sal_uInt16)psia->Value[2],
@@ -535,8 +510,8 @@ void MyTestPlugInImpl::initialize( CPPUNIT_NS::TestFactoryRegistry *,
     }
     else
     {
-        dwSidSize+=wsprintf(Ident + strlen(Ident),
-                    TEXT("%lu"),
+        dwSidSize+=wsprintfW(Ident + wcslen(Ident),
+                    L"%lu",
                     (sal_uInt32)(psia->Value[5]      )   +
                     (sal_uInt32)(psia->Value[4] <<  8)   +
                     (sal_uInt32)(psia->Value[3] << 16)   +
@@ -546,17 +521,16 @@ void MyTestPlugInImpl::initialize( CPPUNIT_NS::TestFactoryRegistry *,
     /* loop through SidSubAuthorities */
     for (dwCounter=0; dwCounter < dwSubAuthorities; dwCounter++)
     {
-        dwSidSize+=wsprintf(Ident + dwSidSize, TEXT("-%lu"),
+        dwSidSize+=wsprintfW(Ident + dwSidSize, L"-%lu",
                     *GetSidSubAuthority(pSid, dwCounter) );
     }
 
-    strUserID = ::rtl::OUString::createFromAscii( Ident );
+    strUserID = o3tl::toU(Ident);
 
     free(Ident);
-    delete [] reinterpret_cast<BYTE*>(pSid);
+    delete [] static_cast<BYTE*>(pSid);
     delete [] wszDomainName;
 
-
     /// check if logged in user is administrator:
 
     BOOL b;
@@ -571,52 +545,52 @@ void MyTestPlugInImpl::initialize( CPPUNIT_NS::TestFactoryRegistry *,
         &AdministratorsGroup);
     if(b)
     {
-        if (!CheckTokenMembership( NULL, AdministratorsGroup, &b))
+        if (!CheckTokenMembership( nullptr, AdministratorsGroup, &b))
         {
              b = FALSE;
         }
         FreeSid(AdministratorsGroup);
     }
 
-    isAdmin = ( sal_Bool )b;
+    isAdmin = b;
 
 #endif
 
     /// print the information.
-    t_print("#\n#Retrived system information is below:\n");
+    t_print("#\n#Retrieved system information is below:\n");
 
     t_print("Computer Name:              ");
     if ( strComputerName.isEmpty())
-        t_print("Not retrived\n" );
+        t_print("Not retrieved\n" );
     else
         printUString( strComputerName );
 
     t_print("Current User Name:          ");
     if ( strUserName.isEmpty())
-        t_print("Not retrived\n" );
+        t_print("Not retrieved\n" );
     else
         printUString( strUserName );
 
     t_print("Current User Home Directory:");
     if ( strHomeDirectory.isEmpty())
-        t_print("Not retrived\n" );
+        t_print("Not retrieved\n" );
     else
         printUString( strHomeDirectory );
 
     t_print("Current Config Directory:   ");
     if ( strConfigDirectory.isEmpty())
-        t_print("Not retrived\n" );
+        t_print("Not retrieved\n" );
     else
         printUString( strConfigDirectory );
 
     t_print("Current UserID:             ");
     if ( strUserID.isEmpty())
-        t_print("Not retrived\n" );
+        t_print("Not retrieved\n" );
     else
         printUString( strUserID );
 
     t_print("Current User is:            ");
-    if ( isAdmin == sal_False )
+    if ( !isAdmin )
         t_print("NOT Administrator.\n" );
     else
         t_print("Administrator.\n" );
@@ -629,7 +603,7 @@ void MyTestPlugInImpl::initialize( CPPUNIT_NS::TestFactoryRegistry *,
     {
         rtl::OUString arg;
         rtl_getAppCommandArg(i, &arg.pData);
-        if( !arg.isEmpty() && arg[ 0 ] == '-' )
+        if( arg.startsWith("-") )
             continue;
         if( argsCount >= 3 )
         {
@@ -680,5 +654,4 @@ void MyTestPlugInImpl::initialize( CPPUNIT_NS::TestFactoryRegistry *,
 CPPUNIT_PLUGIN_EXPORTED_FUNCTION_IMPL( MyTestPlugInImpl );
 CPPUNIT_PLUGIN_IMPLEMENT_MAIN();
 
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
