@@ -53,15 +53,6 @@ class valueOf : public CppUnit::TestFixture
         }
 
 public:
-    // initialise your test code values here.
-    void setUp()
-    {
-    }
-
-    void tearDown()
-    {
-    }
-
     // insert your test code here.
     void valueOf_float_test_001()
     {
@@ -173,7 +164,6 @@ public:
             valueOf_double_test(nValue);
         }
 
-
     // Change the following lines only, if you add, remove or rename
     // member functions of the current class,
     // because these macros are need by auto register mechanism.
@@ -198,9 +188,8 @@ public:
     CPPUNIT_TEST_SUITE_END();
 }; // class valueOf
 
-// -----------------------------------------------------------------------------
 // - toDouble (tests)
-// -----------------------------------------------------------------------------
+
 class toDouble : public CppUnit::TestFixture
 {
 
@@ -211,17 +200,6 @@ public:
             // testPrecision a;
         }
 
-
-
-    // initialise your test code values here.
-    void setUp()
-        {
-        }
-
-    void tearDown()
-        {
-        }
-
     void toDouble_test_impl(rtl::OString const& _sValue)
         {
             double nValueATOF = atof( _sValue.getStr() );
@@ -351,25 +329,12 @@ public:
     CPPUNIT_TEST_SUITE_END();
 }; // class toDouble
 
-// -----------------------------------------------------------------------------
 // - getToken (tests)
-// -----------------------------------------------------------------------------
+
 class getToken : public CppUnit::TestFixture
 {
 
 public:
-
-    // initialise your test code values here.
-    void setUp()
-        {
-        }
-
-    void tearDown()
-        {
-        }
-
-    // -----------------------------------------------------------------------------
-
     void getToken_000()
         {
             rtl::OString sTokenStr;
@@ -453,7 +418,6 @@ public:
             CPPUNIT_ASSERT_MESSAGE("index should be negative", nIndex == -1);
         }
 
-
     CPPUNIT_TEST_SUITE(getToken);
     CPPUNIT_TEST(getToken_000);
     CPPUNIT_TEST(getToken_001);
@@ -463,26 +427,16 @@ public:
     CPPUNIT_TEST_SUITE_END();
 }; // class getToken
 
-// -----------------------------------------------------------------------------
 // testing the method replaceAt( sal_Int32 index, sal_Int32 count,
 // const OString& newStr )
-// -----------------------------------------------------------------------------
 
 // Developer note: Mindy Liu, 2004-04-23
-// stollen from sal/qa/rtl_strings/rtl_OString.cxx
+// stolen from sal/qa/rtl_strings/rtl_OString.cxx
 
 class replaceAt : public CppUnit::TestFixture
 {
 
 public:
-    // initialise your test code values here.
-    void setUp()
-        {
-        }
-
-    void tearDown()
-        {
-        }
     sal_Bool check_replaceAt( const rtl::OString* expVal, const rtl::OString* input,
         const rtl::OString* newStr, sal_Int32  index, sal_Int32 count)
     {
@@ -494,7 +448,6 @@ public:
         sal_Bool bRes = ( expVal->compareTo(aStr1) == 0 );
         return bRes;
     }
-    // -----------------------------------------------------------------------------
 
    void replaceAt_001()
         {
@@ -532,7 +485,6 @@ public:
             CPPUNIT_ASSERT_MESSAGE("replace with null string", bRes == sal_True);
         }
 
-
     CPPUNIT_TEST_SUITE(replaceAt);
     CPPUNIT_TEST(replaceAt_001);
     CPPUNIT_TEST(replaceAt_002);
@@ -542,8 +494,6 @@ public:
     CPPUNIT_TEST_SUITE_END();
 }; // class replaceAt
 
-
-// -----------------------------------------------------------------------------
 CPPUNIT_TEST_SUITE_REGISTRATION(rtl_OString::valueOf);
 CPPUNIT_TEST_SUITE_REGISTRATION(rtl_OString::toDouble);
 CPPUNIT_TEST_SUITE_REGISTRATION(rtl_OString::getToken);
@@ -551,9 +501,6 @@ CPPUNIT_TEST_SUITE_REGISTRATION(rtl_OString::replaceAt);
 
 } // namespace rtl_OString
 
-
-// -----------------------------------------------------------------------------
-
 // this macro creates an empty function, which will called by the RegisterAllFunctions()
 // to let the user the possibility to also register some functions by hand.
 CPPUNIT_PLUGIN_IMPLEMENT();
