@@ -82,7 +82,6 @@ namespace rtl_str
     CPPUNIT_TEST_SUITE_END();
 }; // class compare
 
-
     class compareIgnoreAsciiCase : public CppUnit::TestFixture
     {
     public:
@@ -121,7 +120,7 @@ namespace rtl_str
                 rtl::OString aStr2 = "LINE MUST BE EQUAL.";
 
                 sal_Int32 nValue = rtl_str_compareIgnoreAsciiCase( aStr1.getStr(), aStr2.getStr());
-                CPPUNIT_ASSERT_MESSAGE("compare failed, strings are equal (if case insensitve).", nValue == 0);
+                CPPUNIT_ASSERT_MESSAGE("compare failed, strings are equal (if case insensitive).", nValue == 0);
             }
 
         void compare_003()
@@ -147,8 +146,6 @@ namespace rtl_str
     CPPUNIT_TEST_SUITE_END();
     }; // class compareIgnoreAsciiCase
 
-// -----------------------------------------------------------------------------
-
     class shortenedCompareIgnoreAsciiCase_WithLength : public CppUnit::TestFixture
     {
     public:
@@ -191,7 +188,7 @@ namespace rtl_str
                 sal_Int32 nValue = rtl_str_shortenedCompareIgnoreAsciiCase_WithLength( aStr1.getStr(), aStr1.getLength(),
                                                                                        aStr2.getStr(), aStr2.getLength(),
                                                                                        aStr1.getLength());
-                CPPUNIT_ASSERT_MESSAGE("compare failed, strings are equal (if case insensitve).", nValue == 0);
+                CPPUNIT_ASSERT_MESSAGE("compare failed, strings are equal (if case insensitive).", nValue == 0);
             }
 
         void compare_003()
@@ -231,9 +228,6 @@ namespace rtl_str
     CPPUNIT_TEST_SUITE_END();
 }; // class compare
 
-
-// -----------------------------------------------------------------------------
-
     class hashCode : public CppUnit::TestFixture
     {
     public:
@@ -285,9 +279,6 @@ namespace rtl_str
         CPPUNIT_TEST_SUITE_END();
     }; // class compare
 
-
-// -----------------------------------------------------------------------------
-
     class indexOfChar : public CppUnit::TestFixture
     {
     public:
@@ -333,7 +324,6 @@ namespace rtl_str
         CPPUNIT_TEST_SUITE_END();
     }; // class compare
 
-// -----------------------------------------------------------------------------
     class lastIndexOfChar : public CppUnit::TestFixture
     {
     public:
@@ -379,9 +369,6 @@ namespace rtl_str
         CPPUNIT_TEST_SUITE_END();
     }; // class lastIndexOfChar
 
-
-// -----------------------------------------------------------------------------
-
     class indexOfStr : public CppUnit::TestFixture
     {
     public:
@@ -432,8 +419,6 @@ namespace rtl_str
         CPPUNIT_TEST(indexOfStr_002);
         CPPUNIT_TEST_SUITE_END();
     }; // class compare
-// -----------------------------------------------------------------------------
-
 
     class lastIndexOfStr : public CppUnit::TestFixture
     {
@@ -497,8 +482,6 @@ namespace rtl_str
         CPPUNIT_TEST_SUITE_END();
     }; // class lastIndexOfStr
 
-// -----------------------------------------------------------------------------
-
     class replaceChar : public CppUnit::TestFixture
     {
     public:
@@ -533,8 +516,6 @@ namespace rtl_str
         CPPUNIT_TEST_SUITE_END();
     }; // class replaceChar
 
-// -----------------------------------------------------------------------------
-
     class replaceChar_WithLength : public CppUnit::TestFixture
     {
     public:
@@ -574,9 +555,6 @@ namespace rtl_str
         CPPUNIT_TEST_SUITE_END();
     }; // class replaceChar
 
-
-// -----------------------------------------------------------------------------
-
     class toAsciiLowerCase : public CppUnit::TestFixture
     {
     public:
@@ -611,7 +589,6 @@ namespace rtl_str
         CPPUNIT_TEST_SUITE_END();
     }; // class replaceChar
 
-
     class toAsciiLowerCase_WithLength : public CppUnit::TestFixture
     {
     public:
@@ -647,8 +624,6 @@ namespace rtl_str
         CPPUNIT_TEST_SUITE_END();
     }; // class replaceChar
 
-// -----------------------------------------------------------------------------
-
     class toAsciiUpperCase : public CppUnit::TestFixture
     {
     public:
@@ -683,7 +658,6 @@ namespace rtl_str
         CPPUNIT_TEST_SUITE_END();
     }; // class replaceChar
 
-
     class toAsciiUpperCase_WithLength : public CppUnit::TestFixture
     {
     public:
@@ -719,9 +693,6 @@ namespace rtl_str
         CPPUNIT_TEST_SUITE_END();
     }; // class replaceChar
 
-
-    // -----------------------------------------------------------------------------
-
     class trim_WithLength : public CppUnit::TestFixture
     {
       public:
@@ -740,10 +711,9 @@ namespace rtl_str
         void trim_WithLength_001()
         {
             char const *pStr = "  trim this";
-            sal_Char *pStr2 = (sal_Char*)malloc(strlen(pStr) + 1);
+            sal_Char *pStr2 = strdup(pStr);
             if (pStr2)
             {
-                strcpy(pStr2, pStr);
                 rtl_str_trim_WithLength( pStr2, 2 );
 
                 CPPUNIT_ASSERT_MESSAGE("string should be empty", strlen(pStr2) == 0);
@@ -754,10 +724,9 @@ namespace rtl_str
         void trim_WithLength_002()
         {
             char const *pStr = "trim this";
-            sal_Char *pStr2 = (sal_Char*)malloc(strlen(pStr) + 1);
+            sal_Char *pStr2 = strdup(pStr);
             if (pStr2)
             {
-                strcpy(pStr2, pStr);
                 rtl_str_trim_WithLength( pStr2, 5 );
 
                 CPPUNIT_ASSERT_MESSAGE("string should contain 'trim'", strlen(pStr2) == 4);
@@ -768,7 +737,7 @@ namespace rtl_str
         void trim_WithLength_003()
         {
             char const *pStr = "     trim   this";
-            sal_Char *pStr2 = (sal_Char*)malloc(strlen(pStr) + 1);
+            sal_Char *pStr2 = strdup(pStr);
             if (pStr2)
             {
                 strcpy(pStr2, pStr);
@@ -782,10 +751,9 @@ namespace rtl_str
         void trim_WithLength_004()
         {
             char const *pStr = "\r\n\t \n\r    trim  \n this";
-            sal_Char *pStr2 = (sal_Char*)malloc(strlen(pStr) + 1);
+            sal_Char *pStr2 = strdup(pStr);
             if (pStr2)
             {
-                strcpy(pStr2, pStr);
                 rtl_str_trim_WithLength( pStr2, 17 );
 
                 CPPUNIT_ASSERT_MESSAGE("string should contain 'trim'", strlen(pStr2) == 4);
@@ -796,10 +764,9 @@ namespace rtl_str
         void trim_WithLength_005()
         {
             char const *pStr = "\r\n\t \n\r    trim \t this \n\r\t\t     ";
-            sal_Char *pStr2 = (sal_Char*)malloc(strlen(pStr) + 1);
+            sal_Char *pStr2 = strdup(pStr);
             if (pStr2)
             {
-                strcpy(pStr2, pStr);
                 rtl_str_trim_WithLength( pStr2, strlen(pStr2) );
 
                 CPPUNIT_ASSERT_MESSAGE("string should contain 'trim'", strlen(pStr2) == 11);
@@ -822,8 +789,6 @@ namespace rtl_str
         CPPUNIT_TEST_SUITE_END();
     };
 
-    // -----------------------------------------------------------------------------
-
     class valueOfChar : public CppUnit::TestFixture
     {
       public:
@@ -854,7 +819,6 @@ namespace rtl_str
         CPPUNIT_TEST_SUITE_END();
     };
 
-// -----------------------------------------------------------------------------
 CPPUNIT_TEST_SUITE_REGISTRATION(rtl_str::compare);
 CPPUNIT_TEST_SUITE_REGISTRATION(rtl_str::compareIgnoreAsciiCase);
 CPPUNIT_TEST_SUITE_REGISTRATION(rtl_str::shortenedCompareIgnoreAsciiCase_WithLength);
@@ -878,8 +842,6 @@ CPPUNIT_TEST_SUITE_REGISTRATION(rtl_str::valueOfChar);
 
 } // namespace rtl_str
 
-// -----------------------------------------------------------------------------
-
 // this macro creates an empty function, which will called by the RegisterAllFunctions()
 // to let the user the possibility to also register some functions by hand.
 CPPUNIT_PLUGIN_IMPLEMENT();
