@@ -32,9 +32,9 @@
 #include <com/sun/star/util/Duration.hpp>
 #include <com/sun/star/util/MeasureUnit.hpp>
 
-#include "sax/tools/converter.hxx"
+#include <sax/tools/converter.hxx>
 #include <comphelper/sequence.hxx>
-#include "sal/log.hxx"
+#include <sal/log.hxx>
 
 
 using namespace ::com::sun::star;
@@ -79,7 +79,7 @@ private:
 void doTest(util::Duration const & rid, char const*const pis,
         char const*const i_pos = nullptr)
 {
-    char const*const pos((i_pos) ? i_pos : pis);
+    char const*const pos(i_pos ? i_pos : pis);
     util::Duration od;
     OUString is(::rtl::OUString::createFromAscii(pis));
     SAL_INFO("sax.cppunit","about to convert '" << is << "'");
@@ -155,11 +155,11 @@ bool eqDateTime(const util::DateTime& a, const util::DateTime& b) {
 void doTest(util::DateTime const & rdt, char const*const pis,
         char const*const i_pos = nullptr)
 {
-    char const*const pos((i_pos) ? i_pos : pis);
+    char const*const pos(i_pos ? i_pos : pis);
     OUString is(OUString::createFromAscii(pis));
     util::DateTime odt;
     SAL_INFO("sax.cppunit","about to convert '" << is << "'");
-    bool bSuccess( Converter::parseDateTime(odt, nullptr, is) );
+    bool bSuccess( Converter::parseDateTime(odt, is) );
     SAL_INFO("sax.cppunit","Y:" << odt.Year << " M:" << odt.Month << " D:" << odt.Day << "  H:" << odt.Hours << " M:" << odt.Minutes << " S:" << odt.Seconds << " nS:" << odt.NanoSeconds << " UTC: " << (bool)odt.IsUTC);
     CPPUNIT_ASSERT(bSuccess);
     CPPUNIT_ASSERT(eqDateTime(rdt, odt));
@@ -173,8 +173,7 @@ void doTest(util::DateTime const & rdt, char const*const pis,
 void doTestDateTimeF(char const*const pis)
 {
     util::DateTime odt;
-    bool bSuccess = Converter::parseDateTime(odt, nullptr,
-            OUString::createFromAscii(pis));
+    bool bSuccess = Converter::parseDateTime(odt, OUString::createFromAscii(pis));
     SAL_INFO("sax.cppunit","Y:" << odt.Year << " M:" << odt.Month << " D:" << odt.Day << "  H:" << odt.Hours << "H M:" << odt.Minutes << " S:" << odt.Seconds << " nS:" << odt.NanoSeconds);
     CPPUNIT_ASSERT(!bSuccess);
 }
@@ -250,16 +249,16 @@ void ConverterTest::testDateTime()
 void doTestTime(util::DateTime const & rdt, char const*const pis,
         char const*const i_pos = nullptr)
 {
-    char const*const pos((i_pos) ? i_pos : pis);
+    char const*const pos(i_pos ? i_pos : pis);
     OUString is(OUString::createFromAscii(pis));
     util::DateTime odt;
     SAL_INFO("sax.cppunit","about to convert '" << is << "'");
-    bool bSuccess( Converter::parseTimeOrDateTime(odt, nullptr, is) );
+    bool bSuccess( Converter::parseTimeOrDateTime(odt, is) );
     SAL_INFO("sax.cppunit","Y:" << odt.Year << " M:" << odt.Month << " D:" << odt.Day << "  H:" << odt.Hours << " M:" << odt.Minutes << " S:" << odt.Seconds << " nS:" << odt.NanoSeconds << " UTC: " << (bool)odt.IsUTC);
     CPPUNIT_ASSERT(bSuccess);
     CPPUNIT_ASSERT(eqDateTime(rdt, odt));
     OUStringBuffer buf;
-    Converter::convertTimeOrDateTime(buf, odt, nullptr);
+    Converter::convertTimeOrDateTime(buf, odt);
     SAL_INFO("sax.cppunit","" << buf.toString());
     CPPUNIT_ASSERT_EQUAL(OUString::createFromAscii(pos),
                          buf.makeStringAndClear());
@@ -268,8 +267,7 @@ void doTestTime(util::DateTime const & rdt, char const*const pis,
 void doTestTimeF(char const*const pis)
 {
     util::DateTime odt;
-    bool bSuccess = Converter::parseTimeOrDateTime(odt, nullptr,
-            OUString::createFromAscii(pis));
+    bool bSuccess = Converter::parseTimeOrDateTime(odt, OUString::createFromAscii(pis));
     SAL_INFO("sax.cppunit","Y:" << odt.Year << " M:" << odt.Month << " D:" << odt.Day << "  H:" << odt.Hours << "H M:" << odt.Minutes << " S:" << odt.Seconds << " nS:" << odt.NanoSeconds);
     CPPUNIT_ASSERT_MESSAGE(pis, !bSuccess);
 }
