@@ -31,6 +31,9 @@ void Test::testSort()
 {
     m_pDoc->InsertTab(0, "test1");
 
+    // We need a drawing layer in order to create caption objects.
+    m_pDoc->InitDrawLayer(&getDocShell());
+
     ScRange aDataRange;
     ScAddress aPos(0,0,0);
     {
@@ -43,7 +46,7 @@ void Test::testSort()
 
         clearRange(m_pDoc, ScRange(0, 0, 0, 1, SAL_N_ELEMENTS(aData), 0));
         aDataRange = insertRangeData(m_pDoc, aPos, aData, SAL_N_ELEMENTS(aData));
-        CPPUNIT_ASSERT_MESSAGE("failed to insert range data at correct position", aDataRange.aStart == aPos);
+        CPPUNIT_ASSERT_EQUAL_MESSAGE("failed to insert range data at correct position", aPos, aDataRange.aStart);
     }
 
     // Insert note in cell B2.
@@ -61,7 +64,7 @@ void Test::testSort()
     aSortData.maKeyState[0].nField = 1;
     aSortData.maKeyState[0].bAscending = true;
 
-    m_pDoc->Sort(0, aSortData, false, true, NULL, NULL);
+    m_pDoc->Sort(0, aSortData, false, true, nullptr, nullptr);
 
     double nVal = m_pDoc->GetValue(1,0,0);
     ASSERT_DOUBLES_EQUAL(nVal, 1.0);
@@ -75,8 +78,8 @@ void Test::testSort()
         // 0 = empty cell
         const char* aData[][1] = {
             { "Title" },
-            { 0 },
-            { 0 },
+            { nullptr },
+            { nullptr },
             { "12" },
             { "b" },
             { "1" },
@@ -85,7 +88,7 @@ void Test::testSort()
         };
 
         aDataRange = insertRangeData(m_pDoc, aPos, aData, SAL_N_ELEMENTS(aData));
-        CPPUNIT_ASSERT_MESSAGE("failed to insert range data at correct position", aDataRange.aStart == aPos);
+        CPPUNIT_ASSERT_EQUAL_MESSAGE("failed to insert range data at correct position", aPos, aDataRange.aStart);
     }
 
     aSortData.nCol1 = aDataRange.aStart.Col();
@@ -94,7 +97,7 @@ void Test::testSort()
     aSortData.nRow2 = aDataRange.aEnd.Row();
     aSortData.bHasHeader = true;
     aSortData.maKeyState[0].nField = 0;
-    m_pDoc->Sort(0, aSortData, false, true, NULL, NULL);
+    m_pDoc->Sort(0, aSortData, false, true, nullptr, nullptr);
 
     // Title should stay at the top, numbers should be sorted numerically,
     // numbers always come before strings, and empty cells always occur at the
@@ -141,7 +144,7 @@ void Test::testSortHorizontal()
 
     // Insert raw data into A1:D4.
     ScRange aDataRange = insertRangeData(m_pDoc, ScAddress(0,0,0), aData, SAL_N_ELEMENTS(aData));
-    CPPUNIT_ASSERT_EQUAL(OUString("A1:D4"), aDataRange.Format(SCA_VALID));
+    CPPUNIT_ASSERT_EQUAL(OUString("A1:D4"), aDataRange.Format(ScRefFlags::VALID));
 
     // Check the formula values.
     CPPUNIT_ASSERT_EQUAL(OUString("Yes-No"), m_pDoc->GetString(ScAddress(3,1,0)));
@@ -182,12 +185,9 @@ void Test::testSortHorizontal()
         CPPUNIT_ASSERT_MESSAGE("Table output check failed", bSuccess);
     }
 
-    if (!checkFormula(*m_pDoc, ScAddress(1,1,0), "CONCATENATE(C2;\"-\";D2)"))
-        CPPUNIT_FAIL("Wrong formula!");
-    if (!checkFormula(*m_pDoc, ScAddress(1,2,0), "CONCATENATE(C3;\"-\";D3)"))
-        CPPUNIT_FAIL("Wrong formula!");
-    if (!checkFormula(*m_pDoc, ScAddress(1,3,0), "CONCATENATE(C4;\"-\";D4)"))
-        CPPUNIT_FAIL("Wrong formula!");
+    ASSERT_FORMULA_EQUAL(*m_pDoc, ScAddress(1,1,0), "CONCATENATE(C2;\"-\";D2)", "Wrong formula!");
+    ASSERT_FORMULA_EQUAL(*m_pDoc, ScAddress(1,2,0), "CONCATENATE(C3;\"-\";D3)", "Wrong formula!");
+    ASSERT_FORMULA_EQUAL(*m_pDoc, ScAddress(1,3,0), "CONCATENATE(C4;\"-\";D4)", "Wrong formula!");
 
     m_pDoc->DeleteTab(0);
 }
@@ -378,7 +378,7 @@ void Test::testSortWithFormulaRefs()
         "=IF($List1.A7<>\"\";$List1.A7;\"\")",
     };
 
-    const char* aTextData[4] = {
+    const char* const aTextData[4] = {
         "bob",
         "tim",
         "brian",
@@ -398,7 +398,7 @@ void Test::testSortWithFormulaRefs()
     for (SCROW i = 1; i <= 4; ++i)
         m_pDoc->SetString( 0, i, 0, OUString::createFromAscii(aTextData[i-1]) );
 
-    // Insert forumulas in A1:A6 on the 2nd sheet.
+    // Insert formulas in A1:A6 on the 2nd sheet.
     for (size_t i = 0; i < SAL_N_ELEMENTS(aFormulaData); ++i)
         m_pDoc->SetString( 0, i, 1, OUString::createFromAscii(aFormulaData[i]) );
 
@@ -411,7 +411,7 @@ void Test::testSortWithFormulaRefs()
     aSortData.maKeyState[0].bDoSort = true;
     aSortData.maKeyState[0].nField = 0;
 
-    m_pDoc->Sort(0, aSortData, false, true, NULL, NULL);
+    m_pDoc->Sort(0, aSortData, false, true, nullptr, nullptr);
 
     for (size_t i = 0; i < SAL_N_ELEMENTS(aResults); ++i)
     {
@@ -446,7 +446,7 @@ void Test::testSortWithStrings()
     aParam.maKeyState[0].bAscending = true;
     aParam.maKeyState[0].nField = 1;
 
-    m_pDoc->Sort(0, aParam, false, true, NULL, NULL);
+    m_pDoc->Sort(0, aParam, false, true, nullptr, nullptr);
 
     CPPUNIT_ASSERT_EQUAL(OUString("Header"), m_pDoc->GetString(ScAddress(1,1,0)));
     CPPUNIT_ASSERT_EQUAL(OUString("Val1"), m_pDoc->GetString(ScAddress(1,2,0)));
@@ -454,7 +454,7 @@ void Test::testSortWithStrings()
 
     aParam.maKeyState[0].bAscending = false;
 
-    m_pDoc->Sort(0, aParam, false, true, NULL, NULL);
+    m_pDoc->Sort(0, aParam, false, true, nullptr, nullptr);
 
     CPPUNIT_ASSERT_EQUAL(OUString("Header"), m_pDoc->GetString(ScAddress(1,1,0)));
     CPPUNIT_ASSERT_EQUAL(OUString("Val2"), m_pDoc->GetString(ScAddress(1,2,0)));
@@ -477,7 +477,7 @@ void Test::testSortInFormulaGroup()
         { 0, 2, "20" },  { 1, 2, "=A3" },
         { 0, 3, "10" },  { 1, 3, "=A4+1" }, // swap across groups
         { 0, 4, "2"  },  { 1, 4, "=A5+1" },
-        { 0, 5, "101" }, { 1, 5, "=A6" }, // swap inside contiguious group
+        { 0, 5, "101" }, { 1, 5, "=A6" }, // swap inside contiguous group
         { 0, 6, "100" }, { 1, 6, "=A7" },
         { 0, 7, "102" }, { 1, 7, "=A8" },
         { 0, 8, "104" }, { 1, 8, "=A9" },
@@ -499,7 +499,7 @@ void Test::testSortInFormulaGroup()
     aSortData.maKeyState[0].nField = 0;
     aSortData.maKeyState[0].bAscending = true;
 
-    m_pDoc->Sort(0, aSortData, false, true, NULL, NULL);
+    m_pDoc->Sort(0, aSortData, false, true, nullptr, nullptr);
 
     static struct {
         SCCOL nCol;
@@ -543,7 +543,7 @@ void Test::testSortWithCellFormats()
                 return false;
             }
 
-            const SfxPoolItem* pItem = NULL;
+            const SfxPoolItem* pItem = nullptr;
             if (!pPat->GetItemSet().HasItem(ATTR_FONT_WEIGHT, &pItem))
             {
                 cerr << "Pattern does not have a font weight item, but it should." << endl;
@@ -569,7 +569,7 @@ void Test::testSortWithCellFormats()
                 return false;
             }
 
-            const SfxPoolItem* pItem = NULL;
+            const SfxPoolItem* pItem = nullptr;
             if (!pPat->GetItemSet().HasItem(ATTR_FONT_POSTURE, &pItem))
             {
                 cerr << "Pattern does not have a font posture item, but it should." << endl;
@@ -595,7 +595,7 @@ void Test::testSortWithCellFormats()
                 return false;
             }
 
-            const SfxPoolItem* pItem = NULL;
+            const SfxPoolItem* pItem = nullptr;
             if (pPat->GetItemSet().HasItem(ATTR_FONT_WEIGHT, &pItem))
             {
                 // Check if the font weight is applied.
@@ -611,7 +611,7 @@ void Test::testSortWithCellFormats()
                 // Check if the italics is applied.
                 if (static_cast<const SvxPostureItem*>(pItem)->GetEnumValue() == ITALIC_NORMAL)
                 {
-                    cerr << "This cell is bold, but shouldn't." << endl;
+                    cerr << "This cell is italic, but shouldn't." << endl;
                     return false;
                 }
             }
@@ -763,8 +763,7 @@ void Test::testSortRefUpdate()
     }
 
     // C2 should now point to A4.
-    if (!checkFormula(*m_pDoc, ScAddress(2,1,0), "R[2]C[-2]"))
-        CPPUNIT_FAIL("Wrong formula in C2!");
+    ASSERT_FORMULA_EQUAL(*m_pDoc, ScAddress(2,1,0), "R[2]C[-2]", "Wrong formula in C2!");
 
     // Undo the sort.
     SfxUndoManager* pUndoMgr = m_pDoc->GetUndoManager();
@@ -787,8 +786,7 @@ void Test::testSortRefUpdate()
     }
 
     // C2 should now point to A2.
-    if (!checkFormula(*m_pDoc, ScAddress(2,1,0), "RC[-2]"))
-        CPPUNIT_FAIL("Wrong formula in C2!");
+    ASSERT_FORMULA_EQUAL(*m_pDoc, ScAddress(2,1,0), "RC[-2]", "Wrong formula in C2!");
 
     // Redo.
     pUndoMgr->Redo();
@@ -809,8 +807,7 @@ void Test::testSortRefUpdate()
     }
 
     // C2 should now point to A4.
-    if (!checkFormula(*m_pDoc, ScAddress(2,1,0), "R[2]C[-2]"))
-        CPPUNIT_FAIL("Wrong formula in C2!");
+    ASSERT_FORMULA_EQUAL(*m_pDoc, ScAddress(2,1,0), "R[2]C[-2]", "Wrong formula in C2!");
 
     // Undo again.
     pUndoMgr->Undo();
@@ -864,7 +861,7 @@ void Test::testSortRefUpdate2()
         { "2", "=RC[-1]" },
         { "6", "=RC[-1]" },
         { "4", "=RC[-1]" },
-        { 0, 0 } // terminator
+        { nullptr, nullptr } // terminator
     };
 
     for (SCROW i = 0; aData[i][0]; ++i)
@@ -913,8 +910,7 @@ void Test::testSortRefUpdate2()
     // Formulas in column B should still point to their respective left neighbor cell.
     for (SCROW i = 1; i <= 4; ++i)
     {
-        if (!checkFormula(*m_pDoc, ScAddress(1,i,0), "RC[-1]"))
-            CPPUNIT_FAIL("Wrong formula!");
+        ASSERT_FORMULA_EQUAL(*m_pDoc, ScAddress(1,i,0), "RC[-1]", "Wrong formula!");
     }
 
     // Undo and check the result in column B.
@@ -951,7 +947,7 @@ void Test::testSortRefUpdate3()
         "2",
         "=A4+10",
         "=A2+A4",
-        0 // terminator
+        nullptr // terminator
     };
 
     for (SCROW i = 0; pData[i]; ++i)
@@ -994,12 +990,9 @@ void Test::testSortRefUpdate3()
     CPPUNIT_ASSERT_EQUAL(12.0, m_pDoc->GetValue(ScAddress(0,5,0)));
 
     // Make sure the formula cells have been adjusted correctly.
-    if (!checkFormula(*m_pDoc, ScAddress(0,3,0), "A2+A3"))
-        CPPUNIT_FAIL("Wrong formula in A4.");
-    if (!checkFormula(*m_pDoc, ScAddress(0,4,0), "A2+10"))
-        CPPUNIT_FAIL("Wrong formula in A5.");
-    if (!checkFormula(*m_pDoc, ScAddress(0,5,0), "A3+10"))
-        CPPUNIT_FAIL("Wrong formula in A6.");
+    ASSERT_FORMULA_EQUAL(*m_pDoc, ScAddress(0,3,0), "A2+A3", "Wrong formula in A4.");
+    ASSERT_FORMULA_EQUAL(*m_pDoc, ScAddress(0,4,0), "A2+10", "Wrong formula in A5.");
+    ASSERT_FORMULA_EQUAL(*m_pDoc, ScAddress(0,5,0), "A3+10", "Wrong formula in A6.");
 
     // Undo and check the result.
     SfxUndoManager* pUndoMgr = m_pDoc->GetUndoManager();
@@ -1062,7 +1055,7 @@ void Test::testSortRefUpdate4_Impl()
         ScAddress aPos(0,0,nTab);
         clearRange(m_pDoc, ScRange(0, 0, nTab, 1, SAL_N_ELEMENTS(aData), nTab));
         aLesson1Range = insertRangeData(m_pDoc, aPos, aData, SAL_N_ELEMENTS(aData));
-        CPPUNIT_ASSERT_MESSAGE("failed to insert range data at correct position", aLesson1Range.aStart == aPos);
+        CPPUNIT_ASSERT_EQUAL_MESSAGE("failed to insert range data at correct position", aPos, aLesson1Range.aStart);
     }
 
     ScRange aLesson2Range;
@@ -1080,7 +1073,7 @@ void Test::testSortRefUpdate4_Impl()
         ScAddress aPos(0,0,nTab);
         clearRange(m_pDoc, ScRange(0, 0, nTab, 1, SAL_N_ELEMENTS(aData), nTab));
         aLesson2Range = insertRangeData(m_pDoc, aPos, aData, SAL_N_ELEMENTS(aData));
-        CPPUNIT_ASSERT_MESSAGE("failed to insert range data at correct position", aLesson2Range.aStart == aPos);
+        CPPUNIT_ASSERT_EQUAL_MESSAGE("failed to insert range data at correct position", aPos, aLesson2Range.aStart);
     }
 
     ScRange aSortRange;
@@ -1098,7 +1091,7 @@ void Test::testSortRefUpdate4_Impl()
         ScAddress aPos(0,0,nTab);
         clearRange(m_pDoc, ScRange(0, 0, nTab, 1, SAL_N_ELEMENTS(aData), nTab));
         aSortRange = insertRangeData(m_pDoc, aPos, aData, SAL_N_ELEMENTS(aData));
-        CPPUNIT_ASSERT_MESSAGE("failed to insert range data at correct position", aSortRange.aStart == aPos);
+        CPPUNIT_ASSERT_EQUAL_MESSAGE("failed to insert range data at correct position", aPos, aSortRange.aStart);
     }
 
     ScDBDocFunc aFunc(getDocShell());
@@ -1148,8 +1141,7 @@ void Test::testSortRefUpdate4_Impl()
         {
             for (SCCOL nCol=0; nCol < 4; ++nCol)
             {
-                if (!checkFormula(*m_pDoc, ScAddress(nCol,nRow+1,0), aCheck[nRow][nCol]))
-                    CPPUNIT_FAIL(OString("Wrong formula in " + OString('A'+nCol) + OString::number(nRow+2) + ".").getStr());
+                ASSERT_FORMULA_EQUAL(*m_pDoc, ScAddress(nCol,nRow+1,0), aCheck[nRow][nCol], OString("Wrong formula in " + OString('A'+nCol) + OString::number(nRow+2) + ".").getStr());
             }
         }
 
@@ -1220,8 +1212,7 @@ void Test::testSortRefUpdate4_Impl()
         {
             for (SCCOL nCol=0; nCol < 4; ++nCol)
             {
-                if (!checkFormula(*m_pDoc, ScAddress(nCol,nRow+1,0), aCheck[nRow][nCol]))
-                    CPPUNIT_FAIL(OString("Wrong formula in " + OString('A'+nCol) + OString::number(nRow+2) + ".").getStr());
+                ASSERT_FORMULA_EQUAL(*m_pDoc, ScAddress(nCol,nRow+1,0), aCheck[nRow][nCol], OString("Wrong formula in " + OString('A'+nCol) + OString::number(nRow+2) + ".").getStr());
             }
         }
     }
@@ -1265,7 +1256,7 @@ void Test::testSortRefUpdate5()
         ScAddress aPos(0,0,nTab);
         clearRange(m_pDoc, ScRange(0, 0, nTab, 2, SAL_N_ELEMENTS(aData), nTab));
         aSortRange = insertRangeData(m_pDoc, aPos, aData, SAL_N_ELEMENTS(aData));
-        CPPUNIT_ASSERT_MESSAGE("failed to insert range data at correct position", aSortRange.aStart == aPos);
+        CPPUNIT_ASSERT_EQUAL_MESSAGE("failed to insert range data at correct position", aPos, aSortRange.aStart);
 
         // Actual results and expected sorted results.
         for (SCROW nRow=0; nRow < static_cast<SCROW>(SAL_N_ELEMENTS(aValCheck)); ++nRow)
@@ -1314,8 +1305,7 @@ void Test::testSortRefUpdate5()
     };
     for (SCROW nRow=0; nRow < static_cast<SCROW>(SAL_N_ELEMENTS(aFormulaCheck)); ++nRow)
     {
-        if (!checkFormula(*m_pDoc, ScAddress(1,nRow+1,0), aFormulaCheck[nRow]))
-            CPPUNIT_FAIL(OString("Wrong formula in B" + OString::number(nRow+2) + ".").getStr());
+        ASSERT_FORMULA_EQUAL(*m_pDoc, ScAddress(1,nRow+1,0), aFormulaCheck[nRow], OString("Wrong formula in B" + OString::number(nRow+2) + ".").getStr());
     }
 
     // Undo and check the result.
@@ -1357,7 +1347,7 @@ void Test::testSortRefUpdate6()
 
     ScAddress aPos(0,0,0);
     ScRange aDataRange = insertRangeData(m_pDoc, aPos, aData, SAL_N_ELEMENTS(aData));
-    CPPUNIT_ASSERT(aDataRange.aStart == aPos);
+    CPPUNIT_ASSERT_EQUAL(aPos, aDataRange.aStart);
 
     {
         // Expected output table content.  0 = empty cell
@@ -1405,12 +1395,9 @@ void Test::testSortRefUpdate6()
     }
 
     // Make sure that the formulas in C2:C4 are not adjusted.
-    if (!checkFormula(*m_pDoc, ScAddress(2,1,0), "C1+B2"))
-        CPPUNIT_FAIL("Wrong formula!");
-    if (!checkFormula(*m_pDoc, ScAddress(2,2,0), "C2+B3"))
-        CPPUNIT_FAIL("Wrong formula!");
-    if (!checkFormula(*m_pDoc, ScAddress(2,3,0), "C3+B4"))
-        CPPUNIT_FAIL("Wrong formula!");
+    ASSERT_FORMULA_EQUAL(*m_pDoc, ScAddress(2,1,0), "C1+B2", "Wrong formula!");
+    ASSERT_FORMULA_EQUAL(*m_pDoc, ScAddress(2,2,0), "C2+B3", "Wrong formula!");
+    ASSERT_FORMULA_EQUAL(*m_pDoc, ScAddress(2,3,0), "C3+B4", "Wrong formula!");
 
     // Undo and check.
     SfxUndoManager* pUndoMgr = m_pDoc->GetUndoManager();
@@ -1491,19 +1478,19 @@ void Test::testSortBroadcaster()
 
     {
         const char* aData[][7] = {
-            { "1",   0, 0, "=B1", "=$B$1", "=SUM(A1:B1)", "=SUM($A$1:$B$1)" },
-            { "2", "8", 0, "=B2", "=$B$2", "=SUM(A2:B2)", "=SUM($A$2:$B$2)" },
+            { "1",   nullptr, nullptr, "=B1", "=$B$1", "=SUM(A1:B1)", "=SUM($A$1:$B$1)" },
+            { "2", "8", nullptr, "=B2", "=$B$2", "=SUM(A2:B2)", "=SUM($A$2:$B$2)" },
         };
 
         ScAddress aPos(0,0,0);
         ScRange aDataRange = insertRangeData(m_pDoc, aPos, aData, SAL_N_ELEMENTS(aData));
-        CPPUNIT_ASSERT(aDataRange.aStart == aPos);
+        CPPUNIT_ASSERT_EQUAL(aPos, aDataRange.aStart);
 
         {
             // Expected output table content.  0 = empty cell
             const char* aOutputCheck[][7] = {
-                { "1",   0, 0, "0", "0",  "1",  "1" },
-                { "2", "8", 0, "8", "8", "10", "10" },
+                { "1",   nullptr, nullptr, "0", "0",  "1",  "1" },
+                { "2", "8", nullptr, "8", "8", "10", "10" },
             };
 
             bool bSuccess = checkOutput<7>(m_pDoc, aDataRange, aOutputCheck, "Initial value");
@@ -1533,8 +1520,8 @@ void Test::testSortBroadcaster()
         {
             // Expected output table content.  0 = empty cell
             const char* aOutputCheck[][7] = {
-                { "2", "8", 0, "8", "8", "10", "10" },
-                { "1",   0, 0, "0", "0",  "1",  "1" },
+                { "2", "8", nullptr, "8", "8", "10", "10" },
+                { "1",   nullptr, nullptr, "0", "0",  "1",  "1" },
             };
 
             bool bSuccess = checkOutput<7>(m_pDoc, aDataRange, aOutputCheck, "Sorted without reference update");
@@ -1542,22 +1529,14 @@ void Test::testSortBroadcaster()
         }
 
         // Make sure that the formulas in D1:G2 are not adjusted.
-        if (!checkFormula(*m_pDoc, ScAddress(3,0,0), "B1"))
-            CPPUNIT_FAIL("Wrong formula!");
-        if (!checkFormula(*m_pDoc, ScAddress(3,1,0), "B2"))
-            CPPUNIT_FAIL("Wrong formula!");
-        if (!checkFormula(*m_pDoc, ScAddress(4,0,0), "$B$1"))
-            CPPUNIT_FAIL("Wrong formula!");
-        if (!checkFormula(*m_pDoc, ScAddress(4,1,0), "$B$2"))
-            CPPUNIT_FAIL("Wrong formula!");
-        if (!checkFormula(*m_pDoc, ScAddress(5,0,0), "SUM(A1:B1)"))
-            CPPUNIT_FAIL("Wrong formula!");
-        if (!checkFormula(*m_pDoc, ScAddress(5,1,0), "SUM(A2:B2)"))
-            CPPUNIT_FAIL("Wrong formula!");
-        if (!checkFormula(*m_pDoc, ScAddress(6,0,0), "SUM($A$1:$B$1)"))
-            CPPUNIT_FAIL("Wrong formula!");
-        if (!checkFormula(*m_pDoc, ScAddress(6,1,0), "SUM($A$2:$B$2)"))
-            CPPUNIT_FAIL("Wrong formula!");
+        ASSERT_FORMULA_EQUAL(*m_pDoc, ScAddress(3,0,0), "B1", "Wrong formula!");
+        ASSERT_FORMULA_EQUAL(*m_pDoc, ScAddress(3,1,0), "B2", "Wrong formula!");
+        ASSERT_FORMULA_EQUAL(*m_pDoc, ScAddress(4,0,0), "$B$1", "Wrong formula!");
+        ASSERT_FORMULA_EQUAL(*m_pDoc, ScAddress(4,1,0), "$B$2", "Wrong formula!");
+        ASSERT_FORMULA_EQUAL(*m_pDoc, ScAddress(5,0,0), "SUM(A1:B1)", "Wrong formula!");
+        ASSERT_FORMULA_EQUAL(*m_pDoc, ScAddress(5,1,0), "SUM(A2:B2)", "Wrong formula!");
+        ASSERT_FORMULA_EQUAL(*m_pDoc, ScAddress(6,0,0), "SUM($A$1:$B$1)", "Wrong formula!");
+        ASSERT_FORMULA_EQUAL(*m_pDoc, ScAddress(6,1,0), "SUM($A$2:$B$2)", "Wrong formula!");
 
         // Enter new value and check that it is broadcasted. First in empty cell.
         m_pDoc->SetString(1,1,0, "16");
@@ -1587,8 +1566,8 @@ void Test::testSortBroadcaster()
     {
         const char* aData[][2] = {
             { "1", "2" },
-            {   0, "8" },
-            { 0, 0 },
+            {   nullptr, "8" },
+            { nullptr, nullptr },
             { "=A6",             "=B6" },
             { "=$A$6",           "=$B$6" },
             { "=SUM(A5:A6)",     "=SUM(B5:B6)" },
@@ -1597,14 +1576,14 @@ void Test::testSortBroadcaster()
 
         ScAddress aPos(0,4,0);
         ScRange aDataRange = insertRangeData(m_pDoc, aPos, aData, SAL_N_ELEMENTS(aData));
-        CPPUNIT_ASSERT(aDataRange.aStart == aPos);
+        CPPUNIT_ASSERT_EQUAL(aPos, aDataRange.aStart);
 
         {
             // Expected output table content.  0 = empty cell
             const char* aOutputCheck[][2] = {
                 { "1", "2" },
-                {   0, "8" },
-                { 0, 0 },
+                {   nullptr, "8" },
+                { nullptr, nullptr },
                 { "0",  "8" },
                 { "0",  "8" },
                 { "1", "10" },
@@ -1639,8 +1618,8 @@ void Test::testSortBroadcaster()
             // Expected output table content.  0 = empty cell
             const char* aOutputCheck[][2] = {
                 { "2", "1" },
-                { "8",   0 },
-                { 0, 0 },
+                { "8",   nullptr },
+                { nullptr, nullptr },
                 { "8",  "0" },
                 { "8",  "0" },
                 { "10", "1" },
@@ -1652,22 +1631,14 @@ void Test::testSortBroadcaster()
         }
 
         // Make sure that the formulas in A8:B11 are not adjusted.
-        if (!checkFormula(*m_pDoc, ScAddress(0,7,0), "A6"))
-            CPPUNIT_FAIL("Wrong formula!");
-        if (!checkFormula(*m_pDoc, ScAddress(1,7,0), "B6"))
-            CPPUNIT_FAIL("Wrong formula!");
-        if (!checkFormula(*m_pDoc, ScAddress(0,8,0), "$A$6"))
-            CPPUNIT_FAIL("Wrong formula!");
-        if (!checkFormula(*m_pDoc, ScAddress(1,8,0), "$B$6"))
-            CPPUNIT_FAIL("Wrong formula!");
-        if (!checkFormula(*m_pDoc, ScAddress(0,9,0), "SUM(A5:A6)"))
-            CPPUNIT_FAIL("Wrong formula!");
-        if (!checkFormula(*m_pDoc, ScAddress(1,9,0), "SUM(B5:B6)"))
-            CPPUNIT_FAIL("Wrong formula!");
-        if (!checkFormula(*m_pDoc, ScAddress(0,10,0), "SUM($A$5:$A$6)"))
-            CPPUNIT_FAIL("Wrong formula!");
-        if (!checkFormula(*m_pDoc, ScAddress(1,10,0), "SUM($B$5:$B$6)"))
-            CPPUNIT_FAIL("Wrong formula!");
+        ASSERT_FORMULA_EQUAL(*m_pDoc, ScAddress(0,7,0), "A6", "Wrong formula!");
+        ASSERT_FORMULA_EQUAL(*m_pDoc, ScAddress(1,7,0), "B6", "Wrong formula!");
+        ASSERT_FORMULA_EQUAL(*m_pDoc, ScAddress(0,8,0), "$A$6", "Wrong formula!");
+        ASSERT_FORMULA_EQUAL(*m_pDoc, ScAddress(1,8,0), "$B$6", "Wrong formula!");
+        ASSERT_FORMULA_EQUAL(*m_pDoc, ScAddress(0,9,0), "SUM(A5:A6)", "Wrong formula!");
+        ASSERT_FORMULA_EQUAL(*m_pDoc, ScAddress(1,9,0), "SUM(B5:B6)", "Wrong formula!");
+        ASSERT_FORMULA_EQUAL(*m_pDoc, ScAddress(0,10,0), "SUM($A$5:$A$6)", "Wrong formula!");
+        ASSERT_FORMULA_EQUAL(*m_pDoc, ScAddress(1,10,0), "SUM($B$5:$B$6)", "Wrong formula!");
 
         // Enter new value and check that it is broadcasted. First in empty cell.
         m_pDoc->SetString(1,5,0, "16");
@@ -1695,6 +1666,78 @@ void Test::testSortBroadcaster()
     m_pDoc->DeleteTab(0);
 }
 
+// tdf#99417 check that formulas are tracked that *only* indirectly depend on
+// sorted data and no other broadcasting than BroadcastBroadcasters is
+// involved (for which this test can not be included in testSortBroadcaster()).
+void Test::testSortBroadcastBroadcaster()
+{
+    SortRefNoUpdateSetter aUpdateSet;
+
+    sc::AutoCalcSwitch aACSwitch(*m_pDoc, true); // turn auto calc on.
+    m_pDoc->InsertTab(0, "Sort");
+
+    {
+        const char* aData[][3] = {
+            { "1", "=A1", "=B1" },
+            { "2", "=A2", "=B2" },
+        };
+
+        ScAddress aPos(0,0,0);
+        ScRange aDataRange = insertRangeData(m_pDoc, aPos, aData, SAL_N_ELEMENTS(aData));
+        CPPUNIT_ASSERT_EQUAL(aPos, aDataRange.aStart);
+
+        {
+            // Expected output table content.  0 = empty cell
+            const char* aOutputCheck[][3] = {
+                { "1", "1", "1" },
+                { "2", "2", "2" },
+            };
+
+            bool bSuccess = checkOutput<3>(m_pDoc, aDataRange, aOutputCheck, "Initial value");
+            CPPUNIT_ASSERT_MESSAGE("Table output check failed", bSuccess);
+        }
+
+        // Sort A1:A2.
+        m_pDoc->SetAnonymousDBData(
+                0, new ScDBData(STR_DB_LOCAL_NONAME, 0, 0, 0, 0, 1));
+
+        ScDBDocFunc aFunc(getDocShell());
+
+        // Sort A1:A2 by column A descending.
+        ScSortParam aSortData;
+        aSortData.nCol1 = 0;
+        aSortData.nCol2 = 0;
+        aSortData.nRow1 = 0;
+        aSortData.nRow2 = 1;
+        aSortData.bHasHeader = false;
+        aSortData.bByRow = true;
+        aSortData.maKeyState[0].bDoSort = true;
+        aSortData.maKeyState[0].nField = 0;
+        aSortData.maKeyState[0].bAscending = false;
+        bool bSorted = aFunc.Sort(0, aSortData, true, true, true);
+        CPPUNIT_ASSERT(bSorted);
+
+        {
+            // Expected output table content.  0 = empty cell
+            const char* aOutputCheck[][3] = {
+                { "2", "2", "2" },
+                { "1", "1", "1" },
+            };
+
+            bool bSuccess = checkOutput<3>(m_pDoc, aDataRange, aOutputCheck, "Sorted without reference update");
+            CPPUNIT_ASSERT_MESSAGE("Table output check failed", bSuccess);
+        }
+
+        // Make sure that the formulas in B1:C2 are not adjusted.
+        ASSERT_FORMULA_EQUAL(*m_pDoc, ScAddress(1,0,0), "A1", "Wrong formula!");
+        ASSERT_FORMULA_EQUAL(*m_pDoc, ScAddress(1,1,0), "A2", "Wrong formula!");
+        ASSERT_FORMULA_EQUAL(*m_pDoc, ScAddress(2,0,0), "B1", "Wrong formula!");
+        ASSERT_FORMULA_EQUAL(*m_pDoc, ScAddress(2,1,0), "B2", "Wrong formula!");
+    }
+
+    m_pDoc->DeleteTab(0);
+}
+
 void Test::testSortOutOfPlaceResult()
 {
     m_pDoc->InsertTab(0, "Sort");
@@ -1707,7 +1750,7 @@ void Test::testSortOutOfPlaceResult()
         "2",
         "9",
         "-2",
-        0 // terminator
+        nullptr // terminator
     };
 
     // source data in A1:A6.
@@ -1781,7 +1824,7 @@ void Test::testSortPartialFormulaGroup()
         {  "8", "=RC[-1]" },
         { "47", "=RC[-1]" },
         { "28", "=RC[-1]" },
-        { 0, 0 } // terminator
+        { nullptr, nullptr } // terminator
     };
 
     // A1:B6.
@@ -1799,7 +1842,7 @@ void Test::testSortPartialFormulaGroup()
     const ScFormulaCell* pFC = m_pDoc->GetFormulaCell(ScAddress(1,1,0));
     CPPUNIT_ASSERT(pFC);
     CPPUNIT_ASSERT_MESSAGE("This formula cell should be the first in a group.", pFC->IsSharedTop());
-    CPPUNIT_ASSERT_MESSAGE("Incorrect formula group length.", pFC->GetSharedLength() == 5);
+    CPPUNIT_ASSERT_EQUAL_MESSAGE("Incorrect formula group length.", static_cast<SCROW>(5), pFC->GetSharedLength());
 
     ScDBDocFunc aFunc(getDocShell());
 
