@@ -7,16 +7,17 @@
  * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  */
 
-#include "cellvalue.hxx"
-#include "document.hxx"
-#include "column.hxx"
-#include "formulacell.hxx"
+#include <cellvalue.hxx>
+#include <document.hxx>
+#include <column.hxx>
+#include <formulacell.hxx>
 #include <editeng/editobj.hxx>
 #include <editeng/editstat.hxx>
-#include "stringutil.hxx"
-#include "editutil.hxx"
-#include "tokenarray.hxx"
+#include <stringutil.hxx>
+#include <editutil.hxx>
+#include <tokenarray.hxx>
 #include <formula/token.hxx>
+#include <formula/errorcodes.hxx>
 #include <svl/sharedstring.hxx>
 
 namespace {
@@ -33,8 +34,8 @@ CellType adjustCellType( CellType eOrig )
     return eOrig;
 }
 
-template<typename _T>
-OUString getString( const _T& rVal )
+template<typename T>
+OUString getString( const T& rVal )
 {
     if (rVal.meType == CELLTYPE_STRING)
         return rVal.mpString->getString();
@@ -63,6 +64,9 @@ bool equalsFormulaCells( const ScFormulaCell* p1, const ScFormulaCell* p2 )
     if (pCode1->GetLen() != pCode2->GetLen())
         return false;
 
+    if (pCode1->GetCodeError() != pCode2->GetCodeError())
+        return false;
+
     sal_uInt16 n = pCode1->GetLen();
     formula::FormulaToken** ppToken1 = pCode1->GetArray();
     formula::FormulaToken** ppToken2 = pCode2->GetArray();
@@ -75,8 +79,8 @@ bool equalsFormulaCells( const ScFormulaCell* p1, const ScFormulaCell* p2 )
     return true;
 }
 
-template<typename _T>
-bool equalsWithoutFormatImpl( const _T& left, const _T& right )
+template<typename T>
+bool equalsWithoutFormatImpl( const T& left, const T& right )
 {
     CellType eType1 = adjustCellType(left.meType);
     CellType eType2 = adjustCellType(right.meType);
@@ -103,7 +107,7 @@ bool equalsWithoutFormatImpl( const _T& left, const _T& right )
     return false;
 }
 
-static void commitToColumn( const ScCellValue& rCell, ScColumn& rColumn, SCROW nRow )
+void commitToColumn( const ScCellValue& rCell, ScColumn& rColumn, SCROW nRow )
 {
     switch (rCell.meType)
     {
@@ -154,8 +158,8 @@ bool hasNumericImpl( CellType eType, ScFormulaCell* pFormula )
     }
 }
 
-template<typename _CellT>
-OUString getStringImpl( const _CellT& rCell, const ScDocument* pDoc )
+template<typename CellT>
+OUString getStringImpl( const CellT& rCell, const ScDocument* pDoc )
 {
     switch (rCell.meType)
     {
@@ -175,6 +179,27 @@ OUString getStringImpl( const _CellT& rCell, const ScDocument* pDoc )
     return EMPTY_OUSTRING;
 }
 
+template<typename CellT>
+OUString getRawStringImpl( const CellT& rCell, const ScDocument* pDoc )
+{
+    switch (rCell.meType)
+    {
+        case CELLTYPE_VALUE:
+            return OUString::number(rCell.mfValue);
+        case CELLTYPE_STRING:
+            return rCell.mpString->getString();
+        case CELLTYPE_EDIT:
+            if (rCell.mpEditText)
+                return ScEditUtil::GetString(*rCell.mpEditText, pDoc);
+        break;
+        case CELLTYPE_FORMULA:
+            return rCell.mpFormula->GetRawString().getString();
+        default:
+            ;
+    }
+    return EMPTY_OUSTRING;
+}
+
 }
 
 ScCellValue::ScCellValue() : meType(CELLTYPE_NONE), mfValue(0.0) {}
@@ -246,30 +271,6 @@ void ScCellValue::clear()
     mfValue = 0.0;
 }
 
-void ScCellValue::set( const ScRefCellValue& rCell )
-{
-    clear();
-
-    meType = rCell.meType;
-    switch (meType)
-    {
-        case CELLTYPE_VALUE:
-            mfValue = rCell.mfValue;
-        break;
-        case CELLTYPE_STRING:
-            mpString = new svl::SharedString(*rCell.mpString);
-        break;
-        case CELLTYPE_EDIT:
-            mpEditText = rCell.mpEditText->Clone();
-        break;
-        case CELLTYPE_FORMULA:
-            mpFormula = rCell.mpFormula->Clone();
-        break;
-        default:
-            ;
-    }
-}
-
 void ScCellValue::set( double fValue )
 {
     clear();
@@ -309,8 +310,7 @@ void ScCellValue::assign( const ScDocument& rDoc, const ScAddress& rPos )
 {
     clear();
 
-    ScRefCellValue aRefVal;
-    aRefVal.assign(const_cast<ScDocument&>(rDoc), rPos);
+    ScRefCellValue aRefVal(const_cast<ScDocument&>(rDoc), rPos);
 
     meType = aRefVal.meType;
     switch (meType)
@@ -333,7 +333,7 @@ void ScCellValue::assign( const ScDocument& rDoc, const ScAddress& rPos )
     }
 }
 
-void ScCellValue::assign( const ScCellValue& rOther, ScDocument& rDestDoc, int nCloneFlags )
+void ScCellValue::assign(const ScCellValue& rOther, ScDocument& rDestDoc, ScCloneFlags nCloneFlags)
 {
     clear();
 
@@ -349,8 +349,8 @@ void ScCellValue::assign( const ScCellValue& rOther, ScDocument& rDestDoc, int n
             ScFieldEditEngine& rEngine = rDestDoc.GetEditEngine();
             if (rOther.mpEditText->HasOnlineSpellErrors())
             {
-                sal_uLong nControl = rEngine.GetControlWord();
-                const sal_uLong nSpellControl = EE_CNTRL_ONLINESPELLING | EE_CNTRL_ALLOWBIGOBJS;
+                EEControlBits nControl = rEngine.GetControlWord();
+                const EEControlBits nSpellControl = EEControlBits::ONLINESPELLING | EEControlBits::ALLOWBIGOBJS;
                 bool bNewControl = ((nControl & nSpellControl) != nSpellControl);
                 if (bNewControl)
                     rEngine.SetControlWord(nControl | nSpellControl);
@@ -514,13 +514,9 @@ ScRefCellValue::ScRefCellValue( const svl::SharedString* pString ) : meType(CELL
 ScRefCellValue::ScRefCellValue( const EditTextObject* pEditText ) : meType(CELLTYPE_EDIT), mpEditText(pEditText) {}
 ScRefCellValue::ScRefCellValue( ScFormulaCell* pFormula ) : meType(CELLTYPE_FORMULA), mpFormula(pFormula) {}
 
-// It should be enough to copy the double value, which is at least as large
-// as the pointer values.
-ScRefCellValue::ScRefCellValue( const ScRefCellValue& r ) : meType(r.meType), mfValue(r.mfValue) {}
-
-ScRefCellValue::~ScRefCellValue()
+ScRefCellValue::ScRefCellValue( ScDocument& rDoc, const ScAddress& rPos )
 {
-    clear();
+    assign( rDoc, rPos);
 }
 
 void ScRefCellValue::clear()
@@ -570,6 +566,11 @@ bool ScRefCellValue::hasNumeric() const
     return hasNumericImpl(meType, mpFormula);
 }
 
+bool ScRefCellValue::hasError() const
+{
+    return meType == CELLTYPE_FORMULA && mpFormula->GetErrCode() != FormulaError::NONE;
+}
+
 double ScRefCellValue::getValue()
 {
     switch (meType)
@@ -584,11 +585,30 @@ double ScRefCellValue::getValue()
     return 0.0;
 }
 
+double ScRefCellValue::getRawValue() const
+{
+    switch (meType)
+    {
+        case CELLTYPE_VALUE:
+            return mfValue;
+        case CELLTYPE_FORMULA:
+            return mpFormula->GetRawValue();
+        default:
+            ;
+    }
+    return 0.0;
+}
+
 OUString ScRefCellValue::getString( const ScDocument* pDoc )
 {
     return getStringImpl(*this, pDoc);
 }
 
+OUString ScRefCellValue::getRawString( const ScDocument* pDoc ) const
+{
+    return getRawStringImpl(*this, pDoc);
+}
+
 bool ScRefCellValue::isEmpty() const
 {
     return meType == CELLTYPE_NONE;
@@ -610,20 +630,4 @@ bool ScRefCellValue::equalsWithoutFormat( const ScRefCellValue& r ) const
     return equalsWithoutFormatImpl(*this, r);
 }
 
-ScRefCellValue& ScRefCellValue::operator= ( const ScRefCellValue& r )
-{
-    ScRefCellValue aTmp(r);
-    swap(aTmp);
-    return *this;
-}
-
-void ScRefCellValue::swap( ScRefCellValue& r )
-{
-    std::swap(meType, r.meType);
-
-    // double is 8 bytes, whereas a pointer may be 4 or 8 bytes depending on
-    // the platform. Swap by double values.
-    std::swap(mfValue, r.mfValue);
-}
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
