@@ -17,13 +17,13 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "dptabdat.hxx"
+#include <dptabdat.hxx>
 
-#include "global.hxx"
-#include "dpfilteredcache.hxx"
-#include "dptabres.hxx"
-#include "document.hxx"
-#include "dpobject.hxx"
+#include <global.hxx>
+#include <dpfilteredcache.hxx>
+#include <dptabres.hxx>
+#include <document.hxx>
+#include <dpobject.hxx>
 
 #include <rtl/math.hxx>
 #include <osl/diagnose.h>
@@ -42,7 +42,7 @@ ScDPTableData::CalcInfo::CalcInfo() :
 {
 }
 
-ScDPTableData::ScDPTableData(ScDocument* pDoc) :
+ScDPTableData::ScDPTableData(const ScDocument* pDoc) :
     mpDoc(pDoc)
 {
     nLastDateVal = nLastHier = nLastLevel = nLastRet = -1;      // invalid
@@ -66,7 +66,7 @@ long ScDPTableData::GetDatePart( long nDateVal, long nHierarchy, long nLevel )
         return nLastRet;
 
     Date aDate( 30,12,1899 );                   //TODO: get from source data (and cache here)
-    aDate += nDateVal;
+    aDate.AddDays( nDateVal);
 
     long nRet = 0;
     switch (nHierarchy)
@@ -110,7 +110,7 @@ bool ScDPTableData::IsRepeatIfEmpty()
     return false;
 }
 
-sal_uLong ScDPTableData::GetNumberFormat(long)
+sal_uInt32 ScDPTableData::GetNumberFormat(long)
 {
     return 0;           // default format
 }
@@ -160,7 +160,7 @@ void ScDPTableData::FillRowDataFromCacheTable(sal_Int32 nRow, const ScDPFiltered
     for (sal_Int32 i = 0; i < n; ++i)
     {
         long nDim = rInfo.aDataSrcCols[i];
-        rData.aValues.push_back( ScDPValue() );
+        rData.aValues.emplace_back( );
         // #i111435# GetItemData needs dimension indexes including groups,
         // so the index must be checked here (groups aren't useful as data fields).
         if ( nDim < nCacheColumnCount )
