@@ -17,7 +17,7 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "scitems.hxx"
+#include <scitems.hxx>
 #include <comphelper/string.hxx>
 #include <svx/algitem.hxx>
 #include <editeng/boxitem.hxx>
@@ -42,35 +42,31 @@
 #include <rtl/math.hxx>
 #include <unotools/charclass.hxx>
 
-#include "attrib.hxx"
-#include "patattr.hxx"
-#include "formulacell.hxx"
-#include "table.hxx"
-#include "globstr.hrc"
-#include "global.hxx"
-#include "document.hxx"
-#include "autoform.hxx"
-#include "userlist.hxx"
-#include "zforauto.hxx"
-#include "subtotal.hxx"
+#include <attrib.hxx>
+#include <patattr.hxx>
+#include <formulacell.hxx>
+#include <table.hxx>
+#include <globstr.hrc>
+#include <global.hxx>
+#include <document.hxx>
+#include <autoform.hxx>
+#include <userlist.hxx>
+#include <zforauto.hxx>
+#include <subtotal.hxx>
 #include <formula/errorcodes.hxx>
-#include "rangenam.hxx"
-#include "docpool.hxx"
-#include "progress.hxx"
-#include "segmenttree.hxx"
-#include "conditio.hxx"
-#include "editutil.hxx"
+#include <rangenam.hxx>
+#include <docpool.hxx>
+#include <progress.hxx>
+#include <segmenttree.hxx>
+#include <conditio.hxx>
+#include <editutil.hxx>
 #include <columnspanset.hxx>
 #include <listenercontext.hxx>
 
 #include <math.h>
 #include <memory>
 
-// STATIC DATA -----------------------------------------------------------
-
-#define _D_MAX_LONG_  (double) 0x7fffffff
-
-extern sal_uInt16 nScFillModeMouseModifier;     // global.cxx
+#define D_MAX_LONG_  (double) 0x7fffffff
 
 namespace {
 
@@ -82,10 +78,10 @@ short lcl_DecompValueString( OUString& rValue, sal_Int32& nVal, sal_uInt16* pMin
         return 0;
     }
     const sal_Unicode* p = rValue.getStr();
-    sal_Int32 nNeg = 0;
+    sal_Int32 nSign = 0;
     sal_Int32 nNum = 0;
-    if ( p[nNum] == '-' )
-        nNum = nNeg = 1;
+    if ( p[nNum] == '-' || p[nNum] == '+' )
+        nNum = nSign = 1;
     while ( p[nNum] && CharClass::isAsciiNumeric( OUString(p[nNum]) ) )
         nNum++;
 
@@ -95,34 +91,37 @@ short lcl_DecompValueString( OUString& rValue, sal_Int32& nVal, sal_uInt16* pMin
     // #i5550# If there are numbers at the beginning and the end,
     // prefer the one at the beginning only if it's followed by a space.
     // Otherwise, use the number at the end, to enable things like IP addresses.
-    if ( nNum > nNeg && ( cNext == 0 || cNext == ' ' || !CharClass::isAsciiNumeric(OUString(cLast)) ) )
+    if ( nNum > nSign && ( cNext == 0 || cNext == ' ' || !CharClass::isAsciiNumeric(OUString(cLast)) ) )
     {   // number at the beginning
         nVal = rValue.copy( 0, nNum ).toInt32();
         //  any number with a leading zero sets the minimum number of digits
-        if ( p[nNeg] == '0' && pMinDigits && ( nNum - nNeg > *pMinDigits ) )
-            *pMinDigits = nNum - nNeg;
+        if ( p[nSign] == '0' && pMinDigits && ( nNum - nSign > *pMinDigits ) )
+            *pMinDigits = nNum - nSign;
         rValue = rValue.copy(nNum);
         return -1;
     }
     else
     {
-        nNeg = 0;
+        nSign = 0;
         sal_Int32 nEnd = nNum = rValue.getLength() - 1;
         while ( nNum && CharClass::isAsciiNumeric( OUString(p[nNum]) ) )
             nNum--;
-        if ( p[nNum] == '-' )
+        if ( p[nNum] == '-' || p[nNum] == '+' )
         {
             nNum--;
-            nNeg = 1;
+            nSign = 1;
         }
-        if ( nNum < nEnd - nNeg )
+        if ( nNum < nEnd - nSign )
         {   // number at the end
             nVal = rValue.copy( nNum + 1 ).toInt32();
             //  any number with a leading zero sets the minimum number of digits
-            if ( p[nNum+1+nNeg] == '0' && pMinDigits && ( nEnd - nNum - nNeg > *pMinDigits ) )
-                *pMinDigits = nEnd - nNum - nNeg;
+            if ( p[nNum+1+nSign] == '0' && pMinDigits && ( nEnd - nNum - nSign > *pMinDigits ) )
+                *pMinDigits = nEnd - nNum - nSign;
             rValue = rValue.copy(0, nNum + 1);
-            return 1;
+            if (nSign) // use the return value = 2 to put back the '+'
+                return 2;
+            else
+                return 1;
         }
     }
     nVal = 0;
@@ -172,7 +171,7 @@ void setSuffixCell(
     aEngine.SetEditTextObjectPool(rDoc.GetEditPool());
 
     SfxItemSet aAttr = aEngine.GetEmptyItemSet();
-    aAttr.Put( SvxEscapementItem( SVX_ESCAPEMENT_SUPERSCRIPT, EE_CHAR_ESCAPEMENT));
+    aAttr.Put( SvxEscapementItem( SvxEscapement::Superscript, EE_CHAR_ESCAPEMENT));
     aEngine.SetText( aValue );
     aEngine.QuickInsertText(
         aOrdinalSuffix,
@@ -219,7 +218,7 @@ double approxDiff( double a, double b )
     // the exponent of the error magnitude and round accordingly.
     const double e = fabs(d - c);
     const double fExp = floor( log10( e));
-    return rtl::math::round( c, -(static_cast<int>(fExp))-1);
+    return rtl::math::round( c, -static_cast<int>(fExp)-1);
 }
 }
 
@@ -234,7 +233,7 @@ void ScTable::FillAnalyse( SCCOL nCol1, SCROW nRow1, SCCOL nCol2, SCROW nRow2,
     rMinDigits = 0;
     rListData = nullptr;
     rCmd = FILL_SIMPLE;
-    if ( (nScFillModeMouseModifier & KEY_MOD1) )
+    if ( nScFillModeMouseModifier & KEY_MOD1 )
         return ;        // Ctrl-key: Copy
 
     SCCOL nAddX;
@@ -261,20 +260,23 @@ void ScTable::FillAnalyse( SCCOL nCol1, SCROW nRow1, SCCOL nCol2, SCROW nRow2,
 
     if (eCellType == CELLTYPE_VALUE)
     {
+        double fVal;
         sal_uInt32 nFormat = static_cast<const SfxUInt32Item*>(GetAttr(nCol,nRow,ATTR_VALUE_FORMAT))->GetValue();
-        bool bDate = ( pDocument->GetFormatTable()->GetType(nFormat) == css::util::NumberFormat::DATE );
+        const sal_Int16 nFormatType = pDocument->GetFormatTable()->GetType(nFormat);
+        bool bDate = (nFormatType  == css::util::NumberFormat::DATE );
+        bool bBooleanCell = (!bDate && nFormatType == css::util::NumberFormat::LOGICAL);
         if (bDate)
         {
             if (nCount > 1)
             {
                 double nVal;
-                Date aNullDate = *pDocument->GetFormatTable()->GetNullDate();
+                Date aNullDate = pDocument->GetFormatTable()->GetNullDate();
                 Date aDate1 = aNullDate;
                 nVal = aFirstCell.mfValue;
-                aDate1 += (long)nVal;
+                aDate1.AddDays(nVal);
                 Date aDate2 = aNullDate;
                 nVal = GetValue(nCol+nAddX, nRow+nAddY);
-                aDate2 += (long)nVal;
+                aDate2.AddDays(nVal);
                 if ( aDate1 != aDate2 )
                 {
                     long nCmpInc = 0;
@@ -296,13 +298,13 @@ void ScTable::FillAnalyse( SCCOL nCol1, SCROW nRow1, SCCOL nCol2, SCROW nRow2,
                     nCol = sal::static_int_cast<SCCOL>( nCol + nAddX );
                     nRow = sal::static_int_cast<SCROW>( nRow + nAddY );
                     bool bVal = true;
-                    for (sal_uInt16 i=1; i<nCount && bVal; i++)
+                    for (SCSIZE i=1; i<nCount && bVal; i++)
                     {
                         ScRefCellValue aCell = GetCellValue(nCol,nRow);
                         if (aCell.meType == CELLTYPE_VALUE)
                         {
                             nVal = aCell.mfValue;
-                            aDate2 = aNullDate + (long) nVal;
+                            aDate2 = aNullDate + static_cast<sal_Int32>(nVal);
                             if ( eType == FILL_DAY )
                             {
                                 if ( aDate2-aDate1 != nCmpInc )
@@ -343,6 +345,10 @@ void ScTable::FillAnalyse( SCCOL nCol1, SCROW nRow1, SCCOL nCol2, SCROW nRow2,
                 rInc = 1.0;
             }
         }
+        else if (bBooleanCell && ((fVal = aFirstCell.mfValue) == 0.0 || fVal == 1.0))
+        {
+            // Nothing, rInc stays 0.0, no specific fill mode.
+        }
         else
         {
             if (nCount > 1)
@@ -353,7 +359,7 @@ void ScTable::FillAnalyse( SCCOL nCol1, SCROW nRow1, SCCOL nCol2, SCROW nRow2,
                 nCol = sal::static_int_cast<SCCOL>( nCol + nAddX );
                 nRow = sal::static_int_cast<SCROW>( nRow + nAddY );
                 bool bVal = true;
-                for (sal_uInt16 i=1; i<nCount && bVal; i++)
+                for (SCSIZE i=1; i<nCount && bVal; i++)
                 {
                     ScRefCellValue aCell = GetCellValue(nCol,nRow);
                     if (aCell.meType == CELLTYPE_VALUE)
@@ -362,6 +368,10 @@ void ScTable::FillAnalyse( SCCOL nCol1, SCROW nRow1, SCCOL nCol2, SCROW nRow2,
                         double nDiff = approxDiff( nVal2, nVal1);
                         if ( !::rtl::math::approxEqual( nDiff, rInc, 13 ) )
                             bVal = false;
+                        else if ((nVal2 == 0.0 || nVal2 == 1.0) &&
+                                (pDocument->GetFormatTable()->GetType(GetNumberFormat(nCol,nRow)) ==
+                                 css::util::NumberFormat::LOGICAL))
+                            bVal = false;
                         nVal1 = nVal2;
                     }
                     else
@@ -401,9 +411,9 @@ void ScTable::FillAnalyse( SCCOL nCol1, SCROW nRow1, SCCOL nCol2, SCROW nRow2,
             (void)rListData->GetSubIndex(aStr, rListIndex, bMatchCase);
             nCol = sal::static_int_cast<SCCOL>( nCol + nAddX );
             nRow = sal::static_int_cast<SCROW>( nRow + nAddY );
-            for (sal_uInt16 i=1; i<nCount && rListData; i++)
+            for (SCSIZE i=1; i<nCount && rListData; i++)
             {
-                (void)GetString(nCol, nRow, aStr);
+                GetString(nCol, nRow, aStr);
                 if (!rListData->GetSubIndex(aStr, rListIndex, bMatchCase))
                     rListData = nullptr;
                 nCol = sal::static_int_cast<SCCOL>( nCol + nAddX );
@@ -428,7 +438,7 @@ void ScTable::FillAnalyse( SCCOL nCol1, SCROW nRow1, SCCOL nCol2, SCROW nRow2,
                     nCol = sal::static_int_cast<SCCOL>( nCol + nAddX );
                     nRow = sal::static_int_cast<SCROW>( nRow + nAddY );
                     bool bVal = true;
-                    for (sal_uInt16 i=1; i<nCount && bVal; i++)
+                    for (SCSIZE i=1; i<nCount && bVal; i++)
                     {
                         ScRefCellValue aCell = GetCellValue(nCol, nRow);
                         CellType eType = aCell.meType;
@@ -466,7 +476,7 @@ void ScTable::FillAnalyse( SCCOL nCol1, SCROW nRow1, SCCOL nCol2, SCROW nRow2,
 }
 
 void ScTable::FillFormula(
-    ScFormulaCell* pSrcCell, SCCOL nDestCol, SCROW nDestRow, bool bLast )
+    const ScFormulaCell* pSrcCell, SCCOL nDestCol, SCROW nDestRow, bool bLast )
 {
 
     pDocument->SetNoListening( true );  // still the wrong reference
@@ -474,7 +484,7 @@ void ScTable::FillFormula(
     ScFormulaCell* pDestCell = new ScFormulaCell( *pSrcCell, *pDocument, aAddr );
     aCol[nDestCol].SetFormulaCell(nDestRow, pDestCell);
 
-    if ( bLast && pDestCell->GetMatrixFlag() )
+    if ( bLast && pDestCell->GetMatrixFlag() != ScMatrixMode::NONE )
     {
         ScAddress aOrg;
         if ( pDestCell->GetMatrixOrigin( aOrg ) )
@@ -482,7 +492,7 @@ void ScTable::FillFormula(
             if ( nDestCol >= aOrg.Col() && nDestRow >= aOrg.Row() )
             {
                 ScFormulaCell* pOrgCell = pDocument->GetFormulaCell(aOrg);
-                if (pOrgCell && pOrgCell->GetMatrixFlag() == MM_FORMULA)
+                if (pOrgCell && pOrgCell->GetMatrixFlag() == ScMatrixMode::Formula)
                 {
                     pOrgCell->SetMatColsRows(
                         nDestCol - aOrg.Col() + 1,
@@ -490,7 +500,7 @@ void ScTable::FillFormula(
                 }
                 else
                 {
-                    OSL_FAIL( "FillFormula: MatrixOrigin no forumla cell with MM_FORMULA" );
+                    OSL_FAIL( "FillFormula: MatrixOrigin no formula cell with ScMatrixMode::Formula" );
                 }
             }
             else
@@ -632,7 +642,7 @@ void ScTable::FillAuto( SCCOL nCol1, SCROW nRow1, SCCOL nCol2, SCROW nRow2,
                         pNewPattern = nullptr;
                 }
 
-                const ScCondFormatItem& rCondFormatItem = static_cast<const ScCondFormatItem&>(pSrcPattern->GetItem(ATTR_CONDITIONAL));
+                const ScCondFormatItem& rCondFormatItem = pSrcPattern->GetItem(ATTR_CONDITIONAL);
                 const std::vector<sal_uInt32>& rCondFormatIndex = rCondFormatItem.GetCondFormatData();
 
                 if ( bVertical && nISrcStart == nISrcEnd && !bHasFiltered )
@@ -675,7 +685,7 @@ void ScTable::FillAuto( SCCOL nCol1, SCROW nRow1, SCCOL nCol2, SCROW nRow2,
                     // Transfer template too
                     //TODO: Merge ApplyPattern to AttrArray ??
                     if ( pStyleSheet )
-                        aCol[nCol].ApplyStyle( static_cast<SCROW>(nRow), *pStyleSheet );
+                        aCol[nCol].ApplyStyle( static_cast<SCROW>(nRow), pStyleSheet );
 
                     //  Use ApplyPattern instead of SetPattern to keep old MergeFlags
                     if ( pNewPattern )
@@ -824,7 +834,7 @@ OUString ScTable::GetAutoFillPreview( const ScRange& rSource, SCCOL nEndX, SCROW
         bOk = false;
     else if ( nEndX == nCol2 )                  // to up / down
     {
-        nEndX = nCol2 = nCol1;                  // use only first column
+        nCol2 = nCol1;                          // use only first column
         nSrcCount = nRow2 - nRow1 + 1;
         nIndex = ((long)nEndY) - nRow1;         // can be negative
         if ( nEndY >= nRow1 )
@@ -929,25 +939,45 @@ OUString ScTable::GetAutoFillPreview( const ScRange& rSource, SCCOL nEndX, SCROW
                             short nFlag = lcl_DecompValueString( aValue, nVal, &nCellDigits );
                             if ( nFlag < 0 )
                             {
-                                if (aValue.equals( ScGlobal::GetOrdinalSuffix( nVal)))
+                                if (aValue == ScGlobal::GetOrdinalSuffix( nVal))
                                     aValue = ScGlobal::GetOrdinalSuffix( nVal + nDelta);
-
                                 aValue = lcl_ValueString( nVal + nDelta, nCellDigits ) + aValue;
                             }
                             else if ( nFlag > 0 )
-                                aValue += lcl_ValueString( nVal + nDelta, nCellDigits );
+                            {
+                                sal_Int32 nNextValue;
+                                if ( nVal < 0 )
+                                    nNextValue = nVal - nDelta;
+                                else
+                                    nNextValue = nVal + nDelta;
+                                if ( nFlag == 2 && nNextValue >= 0 ) // Put back the '+'
+                                    aValue += "+";
+                                aValue += lcl_ValueString( nNextValue, nCellDigits );
+                            }
                         }
                     }
                     break;
                     case CELLTYPE_VALUE:
                     {
+                        sal_uInt32 nNumFmt = GetNumberFormat( nSrcX, nSrcY );
                         //  overflow is possible...
                         double nVal = aCell.mfValue;
                         if ( !(nScFillModeMouseModifier & KEY_MOD1) )
-                            nVal += (double) nDelta;
+                        {
+                            if (nVal == 0.0 || nVal == 1.0)
+                            {
+                                bool bBooleanCell = (pDocument->GetFormatTable()->GetType( nNumFmt) ==
+                                        css::util::NumberFormat::LOGICAL);
+                                if (!bBooleanCell)
+                                    nVal += (double) nDelta;
+                            }
+                            else
+                            {
+                                nVal += (double) nDelta;
+                            }
+                        }
 
                         Color* pColor;
-                        sal_uLong nNumFmt = GetNumberFormat( nSrcX, nSrcY );
                         pDocument->GetFormatTable()->GetOutputString( nVal, nNumFmt, aValue, &pColor );
                     }
                     break;
@@ -1019,19 +1049,23 @@ OUString ScTable::GetAutoFillPreview( const ScRange& rSource, SCCOL nEndX, SCROW
                 {
                     if ( nHeadNoneTail < 0 )
                     {
-                        if (aValue.equals( ScGlobal::GetOrdinalSuffix( nVal)))
+                        if (aValue == ScGlobal::GetOrdinalSuffix( nVal))
                             aValue = ScGlobal::GetOrdinalSuffix( (sal_Int32)nStart );
 
                         aValue = lcl_ValueString( (sal_Int32)nStart, nMinDigits ) + aValue;
                     }
                     else
+                    {
+                        if ( nHeadNoneTail == 2 && nStart >= 0 ) // Put back the '+'
+                            aValue += "+";
                         aValue += lcl_ValueString( (sal_Int32)nStart, nMinDigits );
+                    }
                 }
                 else
                 {
                     //TODO: get number format according to Index?
                     Color* pColor;
-                    sal_uLong nNumFmt = GetNumberFormat( nCol1, nRow1 );
+                    sal_uInt32 nNumFmt = GetNumberFormat( nCol1, nRow1 );
                     pDocument->GetFormatTable()->GetOutputString( nStart, nNumFmt, aValue, &pColor );
                 }
             }
@@ -1058,28 +1092,28 @@ void ScTable::IncDate(double& rVal, sal_uInt16& nDayOfMonth, double nStep, FillD
     const sal_uInt16 nMaxYear = 9956;
 
     long nInc = (long) nStep;       // upper/lower limits ?
-    Date aNullDate = *pDocument->GetFormatTable()->GetNullDate();
+    Date aNullDate = pDocument->GetFormatTable()->GetNullDate();
     Date aDate = aNullDate;
-    aDate += (long)rVal;
+    aDate.AddDays(rVal);
     switch (eCmd)
     {
         case FILL_WEEKDAY:
             {
-                aDate += nInc;
+                aDate.AddDays(nInc);
                 DayOfWeek eWeekDay = aDate.GetDayOfWeek();
                 if (nInc >= 0)
                 {
                     if (eWeekDay == SATURDAY)
-                        aDate += 2;
+                        aDate.AddDays(2);
                     else if (eWeekDay == SUNDAY)
-                        aDate += 1;
+                        aDate.AddDays(1);
                 }
                 else
                 {
                     if (eWeekDay == SATURDAY)
-                        aDate -= 1;
+                        aDate.AddDays(-1);
                     else if (eWeekDay == SUNDAY)
-                        aDate -= 2;
+                        aDate.AddDays(-2);
                 }
             }
             break;
@@ -1146,7 +1180,7 @@ void ScTable::IncDate(double& rVal, sal_uInt16& nDayOfMonth, double nStep, FillD
 
 namespace {
 
-bool HiddenRowColumn(ScTable* pTable, SCCOLROW nRowColumn, bool bVertical, SCCOLROW& rLastPos)
+bool HiddenRowColumn(const ScTable* pTable, SCCOLROW nRowColumn, bool bVertical, SCCOLROW& rLastPos)
 {
     bool bHidden = false;
     if(bVertical)
@@ -1191,7 +1225,7 @@ void ScTable::FillFormulaVertical(
             if (nRowStart >= 0)
             {
                 nRowEnd = rInner - 1;
-                aSpans.push_back(sc::RowSpan(nRowStart, nRowEnd));
+                aSpans.emplace_back(nRowStart, nRowEnd);
                 nRowStart = -1;
             }
             rInner = nHiddenLast;
@@ -1205,14 +1239,14 @@ void ScTable::FillFormulaVertical(
     if (nRowStart >= 0)
     {
         nRowEnd = rInner - 1;
-        aSpans.push_back(sc::RowSpan(nRowStart, nRowEnd));
+        aSpans.emplace_back(nRowStart, nRowEnd);
     }
 
     if (aSpans.empty())
         return;
 
-    aCol[nCol].DeleteRanges(aSpans, InsertDeleteFlags::VALUE | InsertDeleteFlags::DATETIME | InsertDeleteFlags::STRING | InsertDeleteFlags::FORMULA | InsertDeleteFlags::OUTLINE, false);
-    aCol[nCol].CloneFormulaCell(rSrcCell, sc::CellTextAttr(), aSpans, nullptr);
+    aCol[nCol].DeleteRanges(aSpans, InsertDeleteFlags::VALUE | InsertDeleteFlags::DATETIME | InsertDeleteFlags::STRING | InsertDeleteFlags::FORMULA | InsertDeleteFlags::OUTLINE);
+    aCol[nCol].CloneFormulaCell(rSrcCell, sc::CellTextAttr(), aSpans);
 
     std::shared_ptr<sc::ColumnBlockPositionSet> pSet(new sc::ColumnBlockPositionSet(*pDocument));
     sc::StartListeningContext aStartCxt(*pDocument, pSet);
@@ -1233,7 +1267,7 @@ void ScTable::FillFormulaVertical(
 }
 
 void ScTable::FillSeriesSimple(
-    ScCellValue& rSrcCell, SCCOLROW& rInner, SCCOLROW nIMin, SCCOLROW nIMax,
+    const ScCellValue& rSrcCell, SCCOLROW& rInner, SCCOLROW nIMin, SCCOLROW nIMax,
     SCCOLROW& rCol, SCCOLROW& rRow, bool bVertical, ScProgress* pProgress, sal_uLong& rProgress )
 {
     bool bHidden = false;
@@ -1320,7 +1354,7 @@ void ScTable::FillAutoSimple(
 {
     SCCOLROW nSource = nISrcStart;
     double nDelta;
-    if ( (nScFillModeMouseModifier & KEY_MOD1) )
+    if ( nScFillModeMouseModifier & KEY_MOD1 )
         nDelta = 0.0;
     else if ( bPositive )
         nDelta = 1.0;
@@ -1328,6 +1362,7 @@ void ScTable::FillAutoSimple(
         nDelta = -1.0;
     sal_uLong nFormulaCounter = nActFormCnt;
     bool bGetCell = true;
+    bool bBooleanCell = false;
     sal_uInt16 nCellDigits = 0;
     short nHeadNoneTail = 0;
     sal_Int32 nStringValue = 0;
@@ -1359,9 +1394,16 @@ void ScTable::FillAutoSimple(
                         FillFormulaVertical(*aSrcCell.mpFormula, rInner, rCol, nIStart, nIEnd, pProgress, rProgress);
                         return;
                     }
+                    bBooleanCell = (pDocument->GetFormatTable()->GetType(
+                                aCol[rCol].GetNumberFormat( pDocument->GetNonThreadedContext(), nSource)) == css::util::NumberFormat::LOGICAL);
+
                 }
                 else                // rInner&:=nCol, rOuter&:=nRow
+                {
                     aSrcCell = aCol[nSource].GetCellValue(rRow);
+                    bBooleanCell = (pDocument->GetFormatTable()->GetType(
+                                aCol[nSource].GetNumberFormat( pDocument->GetNonThreadedContext(), rRow)) == css::util::NumberFormat::LOGICAL);
+                }
 
                 bGetCell = false;
                 if (!aSrcCell.isEmpty())
@@ -1380,8 +1422,8 @@ void ScTable::FillAutoSimple(
                                 nHeadNoneTail = lcl_DecompValueString(
                                         aValue, nStringValue, &nCellDigits );
 
-                                bIsOrdinalSuffix = aValue.equals(
-                                        ScGlobal::GetOrdinalSuffix( nStringValue));
+                                bIsOrdinalSuffix = aValue ==
+                                        ScGlobal::GetOrdinalSuffix(nStringValue);
                             }
                             break;
                         default:
@@ -1395,18 +1437,24 @@ void ScTable::FillAutoSimple(
             switch (aSrcCell.meType)
             {
                 case CELLTYPE_VALUE:
-                    aCol[rCol].SetValue(rRow, aSrcCell.mfValue + nDelta);
+                    {
+                        double fVal;
+                        if (bBooleanCell && ((fVal = aSrcCell.mfValue) == 0.0 || fVal == 1.0))
+                            aCol[rCol].SetValue(rRow, aSrcCell.mfValue);
+                        else
+                            aCol[rCol].SetValue(rRow, aSrcCell.mfValue + nDelta);
+                    }
                     break;
                 case CELLTYPE_STRING:
                 case CELLTYPE_EDIT:
                     if ( nHeadNoneTail )
                     {
-                        // #i48009# with the "nStringValue+(long)nDelta" expression within the
-                        // lcl_ValueString calls, gcc 3.4.1 makes wrong optimizations (ok in 3.4.3),
-                        // so nNextValue is now calculated ahead.
-                        sal_Int32 nNextValue = nStringValue+(sal_Int32)nDelta;
+                        sal_Int32 nNextValue;
+                        if (nStringValue < 0)
+                            nNextValue = nStringValue - (sal_Int32)nDelta;
+                        else
+                            nNextValue = nStringValue + (sal_Int32)nDelta;
 
-                        OUString aStr;
                         if ( nHeadNoneTail < 0 )
                         {
                             setSuffixCell(
@@ -1416,12 +1464,17 @@ void ScTable::FillAutoSimple(
                         }
                         else
                         {
-                            aStr = aValue + lcl_ValueString( nNextValue, nCellDigits );
+                            OUString aStr;
+                            if (nHeadNoneTail == 2 && nNextValue >= 0) // Put back the '+'
+                                aStr = aValue + "+" + lcl_ValueString(nNextValue, nCellDigits);
+                            else
+                                aStr = aValue + lcl_ValueString(nNextValue, nCellDigits);
+
                             aCol[rCol].SetRawString(rRow, aStr);
                         }
                     }
                     else
-                        aSrcCell.commit(aCol[rCol], rRow);
+                      aSrcCell.commit(aCol[rCol], rRow);
 
                     break;
                 case CELLTYPE_FORMULA :
@@ -1594,7 +1647,7 @@ void ScTable::FillSeries( SCCOL nCol1, SCROW nRow1, SCCOL nCol2, SCROW nRow2,
         {
             const ScPatternAttr* pSrcPattern = aCol[nCol].GetPattern(static_cast<SCROW>(nRow));
 
-            const ScCondFormatItem& rCondFormatItem = static_cast<const ScCondFormatItem&>(pSrcPattern->GetItem(ATTR_CONDITIONAL));
+            const ScCondFormatItem& rCondFormatItem = pSrcPattern->GetItem(ATTR_CONDITIONAL);
             const std::vector<sal_uInt32>& rCondFormatIndex = rCondFormatItem.GetCondFormatData();
 
             if (bVertical)
@@ -1604,7 +1657,7 @@ void ScTable::FillSeries( SCCOL nCol1, SCROW nRow1, SCCOL nCol2, SCROW nRow2,
                 if(!bIsFiltered)
                 {
                     aCol[nCol].SetPatternArea( static_cast<SCROW>(nIMin),
-                            static_cast<SCROW>(nIMax), *pSrcPattern, true );
+                            static_cast<SCROW>(nIMax), *pSrcPattern );
 
                     for(std::vector<sal_uInt32>::const_iterator itr = rCondFormatIndex.begin(), itrEnd = rCondFormatIndex.end();
                             itr != itrEnd; ++itr)
@@ -1624,8 +1677,8 @@ void ScTable::FillSeries( SCCOL nCol1, SCROW nRow1, SCCOL nCol2, SCROW nRow2,
                     {
                         if(!RowHidden(nAtRow))
                         {
-                            aCol[nCol].SetPatternArea( static_cast<SCROW>(nAtRow),
-                                    static_cast<SCROW>(nAtRow), *pSrcPattern, true);
+                            aCol[nCol].SetPatternArea( nAtRow,
+                                    nAtRow, *pSrcPattern);
                             for(std::vector<sal_uInt32>::const_iterator itr = rCondFormatIndex.begin(), itrEnd = rCondFormatIndex.end();
                                     itr != itrEnd; ++itr)
                             {
@@ -1646,7 +1699,7 @@ void ScTable::FillSeries( SCCOL nCol1, SCROW nRow1, SCCOL nCol2, SCROW nRow2,
                 for (SCCOL nAtCol = static_cast<SCCOL>(nIMin); nAtCol <= sal::static_int_cast<SCCOL>(nIMax); nAtCol++)
                     if(!ColHidden(nAtCol))
                     {
-                        aCol[nAtCol].SetPattern(static_cast<SCROW>(nRow), *pSrcPattern, true);
+                        aCol[nAtCol].SetPattern(static_cast<SCROW>(nRow), *pSrcPattern);
                         for(std::vector<sal_uInt32>::const_iterator itr = rCondFormatIndex.begin(), itrEnd = rCondFormatIndex.end();
                                 itr != itrEnd; ++itr)
                         {
@@ -1708,7 +1761,7 @@ void ScTable::FillSeries( SCCOL nCol1, SCROW nRow1, SCCOL nCol2, SCROW nRow2,
                                         bError = true;
                                     break;
                                 case FILL_DATE:
-                                    if (fabs(nVal) > _D_MAX_LONG_)
+                                    if (fabs(nVal) > D_MAX_LONG_)
                                         bError = true;
                                     else
                                         IncDate(nVal, nDayOfMonth, nStepValue, eFillDateCmd);
@@ -1738,9 +1791,9 @@ void ScTable::FillSeries( SCCOL nCol1, SCROW nRow1, SCCOL nCol2, SCROW nRow2,
                         }
 
                         if (bError)
-                            aCol[nCol].SetError(static_cast<SCROW>(nRow), errNoValue);
+                            aCol[nCol].SetError(static_cast<SCROW>(nRow), FormulaError::NoValue);
                         else if (bOverflow)
-                            aCol[nCol].SetError(static_cast<SCROW>(nRow), errIllegalFPOperation);
+                            aCol[nCol].SetError(static_cast<SCROW>(nRow), FormulaError::IllegalFPOperation);
                         else
                             aCol[nCol].SetValue(static_cast<SCROW>(nRow), nVal);
                     }
@@ -1788,8 +1841,8 @@ void ScTable::FillSeries( SCCOL nCol1, SCROW nRow1, SCCOL nCol2, SCROW nRow2,
                     bool bError = false;
                     bool bOverflow = false;
 
-                    bool bIsOrdinalSuffix = aValue.equals( ScGlobal::GetOrdinalSuffix(
-                                (sal_Int32)nStartVal));
+                    bool bIsOrdinalSuffix = aValue == ScGlobal::GetOrdinalSuffix(
+                                (sal_Int32)nStartVal);
 
                     rInner = nIStart;
                     while (true)        // #i53728# with "for (;;)" old solaris/x86 compiler mis-optimizes
@@ -1840,9 +1893,9 @@ void ScTable::FillSeries( SCCOL nCol1, SCROW nRow1, SCCOL nCol2, SCROW nRow2,
                             }
 
                             if (bError)
-                                aCol[nCol].SetError(static_cast<SCROW>(nRow), errNoValue);
+                                aCol[nCol].SetError(static_cast<SCROW>(nRow), FormulaError::NoValue);
                             else if (bOverflow)
-                                aCol[nCol].SetError(static_cast<SCROW>(nRow), errIllegalFPOperation);
+                                aCol[nCol].SetError(static_cast<SCROW>(nRow), FormulaError::IllegalFPOperation);
                             else
                             {
                                 nStringValue = (sal_Int32)nVal;
@@ -1856,7 +1909,10 @@ void ScTable::FillSeries( SCCOL nCol1, SCROW nRow1, SCCOL nCol2, SCROW nRow2,
                                 }
                                 else
                                 {
-                                    aStr = aValue;
+                                    if (nHeadNoneTail == 2 && nStringValue >= 0) // Put back the '+'
+                                        aStr = aValue + "+";
+                                    else
+                                        aStr = aValue;
                                     aStr += lcl_ValueString( nStringValue, nMinDigits );
                                     aCol[nCol].SetRawString(static_cast<SCROW>(nRow), aStr);
                                 }
@@ -2038,8 +2094,8 @@ void ScTable::AutoFormat( SCCOL nStartCol, SCROW nStartRow, SCCOL nEndCol, SCROW
                 } // if not equal Column
             } // if not all equal
 
-            for (sal_uInt8 j = 0; j < 16; ++j)
-                delete pPatternAttrs[j];
+            for (ScPatternAttr* pPatternAttr : pPatternAttrs)
+                delete pPatternAttr;
         } // if AutoFormatData != NULL
     } // if ValidColRow
 }
@@ -2189,7 +2245,7 @@ void ScTable::GetAutoFormatData(SCCOL nStartCol, SCROW nStartRow, SCCOL nEndCol,
     }
 }
 
-void ScTable::SetError( SCCOL nCol, SCROW nRow, sal_uInt16 nError)
+void ScTable::SetError( SCCOL nCol, SCROW nRow, FormulaError nError)
 {
     if (ValidColRow(nCol, nRow))
         aCol[nCol].SetError( nRow, nError );
@@ -2197,7 +2253,7 @@ void ScTable::SetError( SCCOL nCol, SCROW nRow, sal_uInt16 nError)
 
 void ScTable::UpdateInsertTabAbs(SCTAB nTable)
 {
-    for (SCCOL i=0; i <= MAXCOL; i++)
+    for (SCCOL i=0; i < aCol.size(); i++)
         aCol[i].UpdateInsertTabAbs(nTable);
 }
 
@@ -2243,23 +2299,22 @@ bool ScTable::GetNextSpellingCell(SCCOL& rCol, SCROW& rRow, bool bInSel,
     return false;
 }
 
-bool ScTable::TestTabRefAbs(SCTAB nTable) const
+void ScTable::TestTabRefAbs(SCTAB nTable) const
 {
-    for (SCCOL i=0; i <= MAXCOL; i++)
+    for (SCCOL i=0; i < aCol.size(); i++)
         if (aCol[i].TestTabRefAbs(nTable))
-            return true;
-    return false;
+            return;
 }
 
 void ScTable::CompileDBFormula( sc::CompileFormulaContext& rCxt )
 {
-    for (SCCOL i = 0; i <= MAXCOL; ++i)
+    for (SCCOL i = 0; i < aCol.size(); ++i)
         aCol[i].CompileDBFormula(rCxt);
 }
 
 void ScTable::CompileColRowNameFormula( sc::CompileFormulaContext& rCxt )
 {
-    for (SCCOL i = 0; i <= MAXCOL; ++i)
+    for (SCCOL i = 0; i < aCol.size(); ++i)
         aCol[i].CompileColRowNameFormula(rCxt);
 }
 
