@@ -17,16 +17,19 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "tabprotection.hxx"
+#include <tabprotection.hxx>
 #include <svl/PasswordHelper.hxx>
 #include <comphelper/docpasswordhelper.hxx>
-#include "document.hxx"
+#include <osl/diagnose.h>
+#include <document.hxx>
 
 #include <vector>
 
 #define DEBUG_TAB_PROTECTION 0
 
 #define URI_SHA1 "http://www.w3.org/2000/09/xmldsig#sha1"
+#define URI_SHA256_ODF12 "http://www.w3.org/2000/09/xmldsig#sha256"
+#define URI_SHA256_W3C "http://www.w3.org/2001/04/xmlenc#sha256"
 #define URI_XLS_LEGACY "http://docs.oasis-open.org/office/ns/table/legacy-hash-excel"
 
 using namespace ::com::sun::star;
@@ -61,6 +64,8 @@ OUString ScPassHashHelper::getHashURI(ScPasswordHash eHash)
 {
     switch (eHash)
     {
+        case PASSHASH_SHA256:
+            return OUString(URI_SHA256_ODF12);
         case PASSHASH_SHA1:
             return OUString(URI_SHA1);
         case PASSHASH_XL:
@@ -74,6 +79,8 @@ OUString ScPassHashHelper::getHashURI(ScPasswordHash eHash)
 
 ScPasswordHash ScPassHashHelper::getHashTypeFromURI(const OUString& rURI)
 {
+    if (rURI == URI_SHA256_ODF12 || rURI == URI_SHA256_W3C)
+        return PASSHASH_SHA256;
     if ( rURI == URI_SHA1 )
         return PASSHASH_SHA1;
     else if ( rURI == URI_XLS_LEGACY )
@@ -88,38 +95,38 @@ ScPassHashProtectable::~ScPassHashProtectable()
 class ScTableProtectionImpl
 {
 public:
-    static Sequence<sal_Int8> hashPassword(const OUString& aPassText, ScPasswordHash eHash = PASSHASH_SHA1);
-    static Sequence<sal_Int8> hashPassword(const Sequence<sal_Int8>& rPassHash, ScPasswordHash eHash = PASSHASH_SHA1);
+    static Sequence<sal_Int8> hashPassword(const OUString& aPassText, ScPasswordHash eHash);
+    static Sequence<sal_Int8> hashPassword(const Sequence<sal_Int8>& rPassHash, ScPasswordHash eHash);
 
     explicit ScTableProtectionImpl(SCSIZE nOptSize);
     explicit ScTableProtectionImpl(const ScTableProtectionImpl& r);
 
-    bool isProtected() const;
+    bool isProtected() const { return mbProtected;}
     bool isProtectedWithPass() const;
     void setProtected(bool bProtected);
 
-    bool isPasswordEmpty() const;
-    bool hasPasswordHash(ScPasswordHash eHash, ScPasswordHash eHash2 = PASSHASH_UNSPECIFIED) const;
+    bool isPasswordEmpty() const { return mbEmptyPass;}
+    bool hasPasswordHash(ScPasswordHash eHash, ScPasswordHash eHash2) const;
     void setPassword(const OUString& aPassText);
-    ::com::sun::star::uno::Sequence<sal_Int8> getPasswordHash(
-        ScPasswordHash eHash, ScPasswordHash eHash2 = PASSHASH_UNSPECIFIED) const;
+    css::uno::Sequence<sal_Int8> getPasswordHash(
+        ScPasswordHash eHash, ScPasswordHash eHash2) const;
     void setPasswordHash(
-        const ::com::sun::star::uno::Sequence<sal_Int8>& aPassword,
-        ScPasswordHash eHash = PASSHASH_SHA1, ScPasswordHash eHash2 = PASSHASH_UNSPECIFIED);
+        const css::uno::Sequence<sal_Int8>& aPassword,
+        ScPasswordHash eHash, ScPasswordHash eHash2);
     bool verifyPassword(const OUString& aPassText) const;
 
     bool isOptionEnabled(SCSIZE nOptId) const;
     void setOption(SCSIZE nOptId, bool bEnabled);
 
     void setEnhancedProtection( const ::std::vector< ScEnhancedProtection > & rProt );
-    const ::std::vector< ScEnhancedProtection > & getEnhancedProtection() const;
-    bool updateReference( UpdateRefMode, ScDocument*, const ScRange& rWhere, SCsCOL nDx, SCsROW nDy, SCsTAB nDz );
+    const ::std::vector< ScEnhancedProtection > & getEnhancedProtection() const { return maEnhancedProtection;}
+    bool updateReference( UpdateRefMode, const ScDocument*, const ScRange& rWhere, SCCOL nDx, SCROW nDy, SCTAB nDz );
     bool isBlockEditable( const ScRange& rRange ) const;
     bool isSelectionEditable( const ScRangeList& rRangeList ) const;
 
 private:
     OUString maPassText;
-    ::com::sun::star::uno::Sequence<sal_Int8>   maPassHash;
+    css::uno::Sequence<sal_Int8>   maPassHash;
     ::std::vector<bool> maOptions;
     bool mbEmptyPass;
     bool mbProtected;
@@ -134,11 +141,17 @@ Sequence<sal_Int8> ScTableProtectionImpl::hashPassword(const OUString& aPassText
     switch (eHash)
     {
         case PASSHASH_XL:
-            aHash = ::comphelper::DocPasswordHelper::GetXLHashAsSequence( aPassText, RTL_TEXTENCODING_UTF8 );
+            aHash = ::comphelper::DocPasswordHelper::GetXLHashAsSequence( aPassText );
         break;
         case PASSHASH_SHA1:
             SvPasswordHelper::GetHashPassword(aHash, aPassText);
         break;
+        case PASSHASH_SHA1_UTF8:
+            SvPasswordHelper::GetHashPasswordSHA1UTF8(aHash, aPassText);
+        break;
+        case PASSHASH_SHA256:
+            SvPasswordHelper::GetHashPasswordSHA256(aHash, aPassText);
+        break;
         default:
             ;
     }
@@ -189,11 +202,6 @@ ScTableProtectionImpl::ScTableProtectionImpl(const ScTableProtectionImpl& r) :
 {
 }
 
-bool ScTableProtectionImpl::isProtected() const
-{
-    return mbProtected;
-}
-
 bool ScTableProtectionImpl::isProtectedWithPass() const
 {
     if (!mbProtected)
@@ -224,11 +232,6 @@ void ScTableProtectionImpl::setPassword(const OUString& aPassText)
     }
 }
 
-bool ScTableProtectionImpl::isPasswordEmpty() const
-{
-    return mbEmptyPass;
-}
-
 bool ScTableProtectionImpl::hasPasswordHash(ScPasswordHash eHash, ScPasswordHash eHash2) const
 {
     if (mbEmptyPass)
@@ -255,7 +258,7 @@ Sequence<sal_Int8> ScTableProtectionImpl::getPasswordHash(
     Sequence<sal_Int8> aPassHash;
 
     if (mbEmptyPass)
-        // Flaged as empty.
+        // Flagged as empty.
         return aPassHash;
 
     if (!maPassText.isEmpty())
@@ -309,7 +312,7 @@ bool ScTableProtectionImpl::verifyPassword(const OUString& aPassText) const
 {
 #if DEBUG_TAB_PROTECTION
     fprintf(stdout, "ScTableProtectionImpl::verifyPassword: input = '%s'\n",
-            OUStringToOString(OUString(aPassText), RTL_TEXTENCODING_UTF8).getStr());
+            OUStringToOString(aPassText, RTL_TEXTENCODING_UTF8).getStr());
 #endif
 
     if (mbEmptyPass)
@@ -329,7 +332,20 @@ bool ScTableProtectionImpl::verifyPassword(const OUString& aPassText) const
     printf("\n");
 #endif
 
-    return aHash == maPassHash;
+    if (aHash == maPassHash)
+    {
+        return true;
+    }
+
+    // tdf#115483 compat hack for ODF 1.2; for now UTF8-SHA1 passwords are only
+    // verified, not generated
+    if (meHash1 == PASSHASH_SHA1 && meHash2 == PASSHASH_UNSPECIFIED)
+    {
+        Sequence<sal_Int8> const aHash2 = hashPassword(aPassText, PASSHASH_SHA1_UTF8);
+        return aHash2 == maPassHash;
+    }
+
+    return false;
 }
 
 bool ScTableProtectionImpl::isOptionEnabled(SCSIZE nOptId) const
@@ -359,19 +375,14 @@ void ScTableProtectionImpl::setEnhancedProtection( const ::std::vector< ScEnhanc
     maEnhancedProtection = rProt;
 }
 
-const ::std::vector< ScEnhancedProtection > & ScTableProtectionImpl::getEnhancedProtection() const
-{
-    return maEnhancedProtection;
-}
-
-bool ScTableProtectionImpl::updateReference( UpdateRefMode eMode, ScDocument* pDoc,
-        const ScRange& rWhere, SCsCOL nDx, SCsROW nDy, SCsTAB nDz )
+bool ScTableProtectionImpl::updateReference( UpdateRefMode eMode, const ScDocument* pDoc,
+        const ScRange& rWhere, SCCOL nDx, SCROW nDy, SCTAB nDz )
 {
     bool bChanged = false;
     for (::std::vector<ScEnhancedProtection>::iterator it(maEnhancedProtection.begin());
             it != maEnhancedProtection.end(); ++it)
     {
-        if ((*it).maRangeList.Is())
+        if ((*it).maRangeList.is())
             bChanged |= (*it).maRangeList->UpdateReference( eMode, pDoc, rWhere, nDx, nDy, nDz);
     }
     return bChanged;
@@ -396,7 +407,7 @@ bool ScTableProtectionImpl::isBlockEditable( const ScRange& rRange ) const
     for (::std::vector<ScEnhancedProtection>::const_iterator it(maEnhancedProtection.begin()),
             itEnd(maEnhancedProtection.end()); it != itEnd; ++it)
     {
-        if (!(*it).hasSecurityDescriptor() && (*it).maRangeList.Is())
+        if (!(*it).hasSecurityDescriptor() && (*it).maRangeList.is())
         {
             if ((*it).maRangeList->In( rRange))
             {
@@ -416,7 +427,7 @@ bool ScTableProtectionImpl::isBlockEditable( const ScRange& rRange ) const
     for (::std::vector<ScEnhancedProtection>::const_iterator it(maEnhancedProtection.begin()),
             itEnd(maEnhancedProtection.end()); it != itEnd; ++it)
     {
-        if (!(*it).hasSecurityDescriptor() && (*it).maRangeList.Is())
+        if (!(*it).hasSecurityDescriptor() && (*it).maRangeList.is())
         {
             ScRangeList aList( (*it).maRangeList->GetIntersectedRange( rRange));
             if (aList.size() == 1 && *aList[0] == rRange)
@@ -437,7 +448,7 @@ bool ScTableProtectionImpl::isBlockEditable( const ScRange& rRange ) const
     for (::std::vector<ScEnhancedProtection>::const_iterator it(maEnhancedProtection.begin()),
             itEnd(maEnhancedProtection.end()); it != itEnd; ++it)
     {
-        if (!(*it).hasSecurityDescriptor() && (*it).maRangeList.Is())
+        if (!(*it).hasSecurityDescriptor() && (*it).maRangeList.is())
         {
             // Ranges are editable if no password is assigned.
             if (!(*it).hasPassword())
@@ -452,10 +463,7 @@ bool ScTableProtectionImpl::isBlockEditable( const ScRange& rRange ) const
         }
     }
     ScRangeList aResultList( aRangeList.GetIntersectedRange( rRange));
-    if (aResultList.size() == 1 && *aResultList[0] == rRange)
-        return true;
-
-    return false;
+    return aResultList.size() == 1 && *aResultList[0] == rRange;
 }
 
 bool ScTableProtectionImpl::isSelectionEditable( const ScRangeList& rRangeList ) const
@@ -471,7 +479,6 @@ bool ScTableProtectionImpl::isSelectionEditable( const ScRangeList& rRangeList )
     return true;
 }
 
-
 ScDocProtection::ScDocProtection() :
     mpImpl(new ScTableProtectionImpl(static_cast<SCSIZE>(ScDocProtection::NONE)))
 {
@@ -632,8 +639,8 @@ const ::std::vector< ScEnhancedProtection > & ScTableProtection::getEnhancedProt
     return mpImpl->getEnhancedProtection();
 }
 
-bool ScTableProtection::updateReference( UpdateRefMode eMode, ScDocument* pDoc, const ScRange& rWhere,
-        SCsCOL nDx, SCsROW nDy, SCsTAB nDz )
+bool ScTableProtection::updateReference( UpdateRefMode eMode, const ScDocument* pDoc, const ScRange& rWhere,
+        SCCOL nDx, SCROW nDy, SCTAB nDz )
 {
     return mpImpl->updateReference( eMode, pDoc, rWhere, nDx, nDy, nDz);
 }
