@@ -21,34 +21,33 @@
 
 #include <com/sun/star/uno/Any.hxx>
 #include <com/sun/star/uno/Sequence.hxx>
-#include "cfgids.hxx"
-#include "appoptio.hxx"
-#include "rechead.hxx"
-#include "scresid.hxx"
-#include "global.hxx"
-#include "userlist.hxx"
-#include "sc.hrc"
-#include <formula/compiler.hrc>
-#include "miscuno.hxx"
+#include <appoptio.hxx>
+#include <rechead.hxx>
+#include <scresid.hxx>
+#include <global.hxx>
+#include <userlist.hxx>
+#include <sc.hrc>
+#include <formula/compiler.hxx>
+#include <miscuno.hxx>
+#include <memory>
 
 using namespace utl;
 using namespace com::sun::star::uno;
 
 //      ScAppOptions - Applikations-Optionen
 
-ScAppOptions::ScAppOptions() : pLRUList( NULL )
+ScAppOptions::ScAppOptions() : pLRUList( nullptr )
 {
     SetDefaults();
 }
 
-ScAppOptions::ScAppOptions( const ScAppOptions& rCpy ) : pLRUList( NULL )
+ScAppOptions::ScAppOptions( const ScAppOptions& rCpy ) : pLRUList( nullptr )
 {
     *this = rCpy;
 }
 
 ScAppOptions::~ScAppOptions()
 {
-    delete [] pLRUList;
 }
 
 void ScAppOptions::SetDefaults()
@@ -59,14 +58,13 @@ void ScAppOptions::SetDefaults()
         eMetric     = FUNIT_INCH;           // default for others
 
     nZoom           = 100;
-    eZoomType       = SVX_ZOOM_PERCENT;
-    bSynchronizeZoom = sal_True;
-    nStatusFunc     = SUBTOTAL_FUNC_SUM;
-    bAutoComplete   = sal_True;
-    bDetectiveAuto  = sal_True;
+    eZoomType       = SvxZoomType::PERCENT;
+    bSynchronizeZoom = true;
+    nStatusFunc     = ( 1 << SUBTOTAL_FUNC_SUM );
+    bAutoComplete   = true;
+    bDetectiveAuto  = true;
 
-    delete [] pLRUList;
-    pLRUList = new sal_uInt16[5];               // sinnvoll vorbelegen
+    pLRUList.reset( new sal_uInt16[5] );               // sinnvoll vorbelegen
     pLRUList[0] = SC_OPCODE_SUM;
     pLRUList[1] = SC_OPCODE_AVERAGE;
     pLRUList[2] = SC_OPCODE_MIN;
@@ -88,13 +86,13 @@ void ScAppOptions::SetDefaults()
     meKeyBindingType     = ScOptionsUtil::KEY_DEFAULT;
 }
 
-const ScAppOptions& ScAppOptions::operator=( const ScAppOptions& rCpy )
+ScAppOptions& ScAppOptions::operator=( const ScAppOptions& rCpy )
 {
     eMetric         = rCpy.eMetric;
     eZoomType       = rCpy.eZoomType;
     bSynchronizeZoom = rCpy.bSynchronizeZoom;
     nZoom           = rCpy.nZoom;
-    SetLRUFuncList( rCpy.pLRUList, rCpy.nLRUFuncCount );
+    SetLRUFuncList( rCpy.pLRUList.get(), rCpy.nLRUFuncCount );
     nStatusFunc     = rCpy.nStatusFunc;
     bAutoComplete   = rCpy.bAutoComplete;
     bDetectiveAuto  = rCpy.bDetectiveAuto;
@@ -112,19 +110,17 @@ const ScAppOptions& ScAppOptions::operator=( const ScAppOptions& rCpy )
 
 void ScAppOptions::SetLRUFuncList( const sal_uInt16* pList, const sal_uInt16 nCount )
 {
-    delete [] pLRUList;
-
     nLRUFuncCount = nCount;
 
     if ( nLRUFuncCount > 0 )
     {
-        pLRUList = new sal_uInt16[nLRUFuncCount];
+        pLRUList.reset( new sal_uInt16[nLRUFuncCount] );
 
         for ( sal_uInt16 i=0; i<nLRUFuncCount; i++ )
             pLRUList[i] = pList[i];
     }
     else
-        pLRUList = NULL;
+        pLRUList.reset();
 }
 
 //  Config Item containing app options
@@ -138,13 +134,11 @@ static void lcl_SetLastFunctions( ScAppOptions& rOpt, const Any& rValue )
         if ( nCount < USHRT_MAX )
         {
             const sal_Int32* pArray = aSeq.getConstArray();
-            sal_uInt16* pUShorts = new sal_uInt16[nCount];
+            std::unique_ptr<sal_uInt16[]> pUShorts(new sal_uInt16[nCount]);
             for (long i=0; i<nCount; i++)
                 pUShorts[i] = (sal_uInt16) pArray[i];
 
-            rOpt.SetLRUFuncList( pUShorts, sal::static_int_cast<sal_uInt16>(nCount) );
-
-            delete[] pUShorts;
+            rOpt.SetLRUFuncList( pUShorts.get(), sal::static_int_cast<sal_uInt16>(nCount) );
         }
     }
 }
@@ -175,8 +169,8 @@ static void lcl_SetSortList( const Any& rValue )
         ScUserList aList;
 
         //  if setting is "default", keep default values from ScUserList ctor
-        //! mark "default" in a safe way
-        sal_Bool bDefault = ( nCount == 1 && pArray[0] == "NULL" );
+        //TODO: mark "default" in a safe way
+        bool bDefault = ( nCount == 1 && pArray[0] == "NULL" );
 
         if (!bDefault)
         {
@@ -202,7 +196,7 @@ static void lcl_GetSortList( Any& rDest )
         Sequence<OUString> aSeq( nCount );
         OUString* pArray = aSeq.getArray();
         for (size_t i=0; i<nCount; ++i)
-            pArray[i] = (*pUserList)[sal::static_int_cast<sal_uInt16>(i)]->GetString();
+            pArray[i] = (*pUserList)[sal::static_int_cast<sal_uInt16>(i)].GetString();
         rDest <<= aSeq;
     }
     else
@@ -216,14 +210,13 @@ static void lcl_GetSortList( Any& rDest )
 #define SCLAYOUTOPT_ZOOMVAL         2
 #define SCLAYOUTOPT_ZOOMTYPE        3
 #define SCLAYOUTOPT_SYNCZOOM        4
-#define SCLAYOUTOPT_COUNT           5
+#define SCLAYOUTOPT_STATUSBARMULTI  5
 
 #define CFGPATH_INPUT       "Office.Calc/Input"
 
 #define SCINPUTOPT_LASTFUNCS        0
 #define SCINPUTOPT_AUTOINPUT        1
 #define SCINPUTOPT_DET_AUTO         2
-#define SCINPUTOPT_COUNT            3
 
 #define CFGPATH_REVISION    "Office.Calc/Revision/Color"
 
@@ -231,157 +224,107 @@ static void lcl_GetSortList( Any& rDest )
 #define SCREVISOPT_INSERTION        1
 #define SCREVISOPT_DELETION         2
 #define SCREVISOPT_MOVEDENTRY       3
-#define SCREVISOPT_COUNT            4
 
 #define CFGPATH_CONTENT     "Office.Calc/Content/Update"
 
 #define SCCONTENTOPT_LINK           0
-#define SCCONTENTOPT_COUNT          1
 
 #define CFGPATH_SORTLIST    "Office.Calc/SortList"
 
 #define SCSORTLISTOPT_LIST          0
-#define SCSORTLISTOPT_COUNT         1
 
 #define CFGPATH_MISC        "Office.Calc/Misc"
 
 #define SCMISCOPT_DEFOBJWIDTH       0
 #define SCMISCOPT_DEFOBJHEIGHT      1
 #define SCMISCOPT_SHOWSHAREDDOCWARN 2
-#define SCMISCOPT_COUNT             3
 
 #define CFGPATH_COMPAT      "Office.Calc/Compatibility"
 
 #define SCCOMPATOPT_KEY_BINDING     0
-#define SCCOMPATOPT_COUNT           1
+
+// Default value of Layout/Other/StatusbarMultiFunction
+#define SCLAYOUTOPT_STATUSBARMULTI_DEFAULTVAL         514
+// Default value of Layout/Other/StatusbarFunction
+#define SCLAYOUTOPT_STATUSBAR_DEFAULTVAL              1
+// Legacy default value of Layout/Other/StatusbarFunction
+// prior to multiple statusbar functions feature addition
+#define SCLAYOUTOPT_STATUSBAR_DEFAULTVAL_LEGACY       9
+
+static sal_uInt32 lcl_ConvertStatusBarFuncSetToSingle( sal_uInt32 nFuncSet )
+{
+    if ( !nFuncSet )
+        return 0;
+    for ( sal_uInt32 nFunc = 1; nFunc < 32; ++nFunc )
+        if ( nFuncSet & ( 1 << nFunc ) )
+            return nFunc;
+    return 0;
+}
 
 Sequence<OUString> ScAppCfg::GetLayoutPropertyNames()
 {
-    static const char* aPropNames[] =
-    {
-        "Other/MeasureUnit/NonMetric",  // SCLAYOUTOPT_MEASURE
-        "Other/StatusbarFunction",      // SCLAYOUTOPT_STATUSBAR
-        "Zoom/Value",                   // SCLAYOUTOPT_ZOOMVAL
-        "Zoom/Type",                    // SCLAYOUTOPT_ZOOMTYPE
-        "Zoom/Synchronize"              // SCLAYOUTOPT_SYNCZOOM
-    };
-    Sequence<OUString> aNames(SCLAYOUTOPT_COUNT);
-    OUString* pNames = aNames.getArray();
-    for(int i = 0; i < SCLAYOUTOPT_COUNT; i++)
-        pNames[i] = OUString::createFromAscii(aPropNames[i]);
+    const bool bIsMetric = ScOptionsUtil::IsMetricSystem();
 
-    //  adjust for metric system
-    if (ScOptionsUtil::IsMetricSystem())
-        pNames[SCLAYOUTOPT_MEASURE] = "Other/MeasureUnit/Metric";
-
-    return aNames;
+    return {(bIsMetric ? OUString("Other/MeasureUnit/Metric")
+                       : OUString("Other/MeasureUnit/NonMetric")),  // SCLAYOUTOPT_MEASURE
+             "Other/StatusbarFunction",                             // SCLAYOUTOPT_STATUSBAR
+             "Zoom/Value",                                          // SCLAYOUTOPT_ZOOMVAL
+             "Zoom/Type",                                           // SCLAYOUTOPT_ZOOMTYPE
+             "Zoom/Synchronize",                                    // SCLAYOUTOPT_SYNCZOOM
+             "Other/StatusbarMultiFunction"};                       // SCLAYOUTOPT_STATUSBARMULTI
 }
 
 Sequence<OUString> ScAppCfg::GetInputPropertyNames()
 {
-    static const char* aPropNames[] =
-    {
-        "LastFunctions",            // SCINPUTOPT_LASTFUNCS
-        "AutoInput",                // SCINPUTOPT_AUTOINPUT
-        "DetectiveAuto"             // SCINPUTOPT_DET_AUTO
-    };
-    Sequence<OUString> aNames(SCINPUTOPT_COUNT);
-    OUString* pNames = aNames.getArray();
-    for(int i = 0; i < SCINPUTOPT_COUNT; i++)
-        pNames[i] = OUString::createFromAscii(aPropNames[i]);
-
-    return aNames;
+    return {"LastFunctions",            // SCINPUTOPT_LASTFUNCS
+            "AutoInput",                // SCINPUTOPT_AUTOINPUT
+            "DetectiveAuto"};           // SCINPUTOPT_DET_AUTO
 }
 
 Sequence<OUString> ScAppCfg::GetRevisionPropertyNames()
 {
-    static const char* aPropNames[] =
-    {
-        "Change",                   // SCREVISOPT_CHANGE
-        "Insertion",                // SCREVISOPT_INSERTION
-        "Deletion",                 // SCREVISOPT_DELETION
-        "MovedEntry"                // SCREVISOPT_MOVEDENTRY
-    };
-    Sequence<OUString> aNames(SCREVISOPT_COUNT);
-    OUString* pNames = aNames.getArray();
-    for(int i = 0; i < SCREVISOPT_COUNT; i++)
-        pNames[i] = OUString::createFromAscii(aPropNames[i]);
-
-    return aNames;
+    return {"Change",                   // SCREVISOPT_CHANGE
+            "Insertion",                // SCREVISOPT_INSERTION
+            "Deletion",                 // SCREVISOPT_DELETION
+            "MovedEntry"};              // SCREVISOPT_MOVEDENTRY
 }
 
 Sequence<OUString> ScAppCfg::GetContentPropertyNames()
 {
-    static const char* aPropNames[] =
-    {
-        "Link"                      // SCCONTENTOPT_LINK
-    };
-    Sequence<OUString> aNames(SCCONTENTOPT_COUNT);
-    OUString* pNames = aNames.getArray();
-    for(int i = 0; i < SCCONTENTOPT_COUNT; i++)
-        pNames[i] = OUString::createFromAscii(aPropNames[i]);
-
-    return aNames;
+    return {"Link"};                    // SCCONTENTOPT_LINK
 }
 
 Sequence<OUString> ScAppCfg::GetSortListPropertyNames()
 {
-    static const char* aPropNames[] =
-    {
-        "List"                      // SCSORTLISTOPT_LIST
-    };
-    Sequence<OUString> aNames(SCSORTLISTOPT_COUNT);
-    OUString* pNames = aNames.getArray();
-    for(int i = 0; i < SCSORTLISTOPT_COUNT; i++)
-        pNames[i] = OUString::createFromAscii(aPropNames[i]);
-
-    return aNames;
+    return {"List"};                    // SCSORTLISTOPT_LIST
 }
 
 Sequence<OUString> ScAppCfg::GetMiscPropertyNames()
 {
-    static const char* aPropNames[] =
-    {
-        "DefaultObjectSize/Width",      // SCMISCOPT_DEFOBJWIDTH
-        "DefaultObjectSize/Height",     // SCMISCOPT_DEFOBJHEIGHT
-        "SharedDocument/ShowWarning"    // SCMISCOPT_SHOWSHAREDDOCWARN
-    };
-    Sequence<OUString> aNames(SCMISCOPT_COUNT);
-    OUString* pNames = aNames.getArray();
-    for(int i = 0; i < SCMISCOPT_COUNT; i++)
-        pNames[i] = OUString::createFromAscii(aPropNames[i]);
-
-    return aNames;
+    return {"DefaultObjectSize/Width",      // SCMISCOPT_DEFOBJWIDTH
+            "DefaultObjectSize/Height",     // SCMISCOPT_DEFOBJHEIGHT
+            "SharedDocument/ShowWarning"};  // SCMISCOPT_SHOWSHAREDDOCWARN
 }
 
 Sequence<OUString> ScAppCfg::GetCompatPropertyNames()
 {
-    static const char* aPropNames[] =
-    {
-        "KeyBindings/BaseGroup"         // SCCOMPATOPT_KEY_BINDING
-    };
-    Sequence<OUString> aNames(SCCOMPATOPT_COUNT);
-    OUString* pNames = aNames.getArray();
-    for (int i = 0; i < SCCOMPATOPT_COUNT; ++i)
-        pNames[i] = OUString::createFromAscii(aPropNames[i]);
-
-    return aNames;
+    return {"KeyBindings/BaseGroup"};   // SCCOMPATOPT_KEY_BINDING
 }
 
 ScAppCfg::ScAppCfg() :
-    aLayoutItem( OUString( CFGPATH_LAYOUT ) ),
-    aInputItem( OUString( CFGPATH_INPUT ) ),
-    aRevisionItem( OUString( CFGPATH_REVISION ) ),
-    aContentItem( OUString( CFGPATH_CONTENT ) ),
-    aSortListItem( OUString( CFGPATH_SORTLIST ) ),
-    aMiscItem( OUString( CFGPATH_MISC ) ),
-    aCompatItem( OUString(CFGPATH_COMPAT ) )
+    aLayoutItem( CFGPATH_LAYOUT ),
+    aInputItem( CFGPATH_INPUT ),
+    aRevisionItem( CFGPATH_REVISION ),
+    aContentItem( CFGPATH_CONTENT ),
+    aSortListItem( CFGPATH_SORTLIST ),
+    aMiscItem( CFGPATH_MISC ),
+    aCompatItem( CFGPATH_COMPAT )
 {
     sal_Int32 nIntVal = 0;
 
     Sequence<OUString> aNames;
     Sequence<Any> aValues;
-    const Any* pValues = NULL;
+    const Any* pValues = nullptr;
 
     aNames = GetLayoutPropertyNames();
     aValues = aLayoutItem.GetProperties(aNames);
@@ -390,6 +333,9 @@ ScAppCfg::ScAppCfg() :
     OSL_ENSURE(aValues.getLength() == aNames.getLength(), "GetProperties failed");
     if(aValues.getLength() == aNames.getLength())
     {
+        sal_uInt32 nStatusBarFuncSingle = 0;
+        sal_uInt32 nStatusBarFuncMulti = 0;
+        sal_uInt32 nUIntValTmp = 0;
         for(int nProp = 0; nProp < aNames.getLength(); nProp++)
         {
             OSL_ENSURE(pValues[nProp].hasValue(), "property value missing");
@@ -401,7 +347,12 @@ ScAppCfg::ScAppCfg() :
                         if (pValues[nProp] >>= nIntVal) SetAppMetric( (FieldUnit) nIntVal );
                         break;
                     case SCLAYOUTOPT_STATUSBAR:
-                        if (pValues[nProp] >>= nIntVal) SetStatusFunc( (sal_uInt16) nIntVal );
+                        if ( pValues[SCLAYOUTOPT_STATUSBAR] >>= nUIntValTmp )
+                            nStatusBarFuncSingle = nUIntValTmp;
+                        break;
+                    case SCLAYOUTOPT_STATUSBARMULTI:
+                        if ( pValues[SCLAYOUTOPT_STATUSBARMULTI] >>= nUIntValTmp )
+                            nStatusBarFuncMulti = nUIntValTmp;
                         break;
                     case SCLAYOUTOPT_ZOOMVAL:
                         if (pValues[nProp] >>= nIntVal) SetZoom( (sal_uInt16) nIntVal );
@@ -415,6 +366,19 @@ ScAppCfg::ScAppCfg() :
                 }
             }
         }
+
+        if ( nStatusBarFuncMulti != SCLAYOUTOPT_STATUSBARMULTI_DEFAULTVAL )
+            SetStatusFunc( nStatusBarFuncMulti );
+        else if ( nStatusBarFuncSingle != SCLAYOUTOPT_STATUSBAR_DEFAULTVAL &&
+                  nStatusBarFuncSingle != SCLAYOUTOPT_STATUSBAR_DEFAULTVAL_LEGACY )
+        {
+            if ( nStatusBarFuncSingle )
+                SetStatusFunc( 1 << nStatusBarFuncSingle );
+            else
+                SetStatusFunc( 0 );
+        }
+        else
+            SetStatusFunc( SCLAYOUTOPT_STATUSBARMULTI_DEFAULTVAL );
     }
     aLayoutItem.SetCommitLink( LINK( this, ScAppCfg, LayoutCommitHdl ) );
 
@@ -576,7 +540,7 @@ ScAppCfg::ScAppCfg() :
     }
     aCompatItem.SetCommitLink( LINK(this, ScAppCfg, CompatCommitHdl) );
 }
- IMPL_LINK_NOARG(ScAppCfg, LayoutCommitHdl)
+ IMPL_LINK_NOARG(ScAppCfg, LayoutCommitHdl, ScLinkConfigItem&, void)
 {
     Sequence<OUString> aNames = GetLayoutPropertyNames();
     Sequence<Any> aValues(aNames.getLength());
@@ -590,7 +554,7 @@ ScAppCfg::ScAppCfg() :
                 pValues[nProp] <<= (sal_Int32) GetAppMetric();
                 break;
             case SCLAYOUTOPT_STATUSBAR:
-                pValues[nProp] <<= (sal_Int32) GetStatusFunc();
+                pValues[nProp] <<= lcl_ConvertStatusBarFuncSetToSingle( GetStatusFunc() );
                 break;
             case SCLAYOUTOPT_ZOOMVAL:
                 pValues[nProp] <<= (sal_Int32) GetZoom();
@@ -599,16 +563,17 @@ ScAppCfg::ScAppCfg() :
                 pValues[nProp] <<= (sal_Int32) GetZoomType();
                 break;
             case SCLAYOUTOPT_SYNCZOOM:
-                ScUnoHelpFunctions::SetBoolInAny( pValues[nProp], GetSynchronizeZoom() );
+                pValues[nProp] <<= GetSynchronizeZoom();
+                break;
+            case SCLAYOUTOPT_STATUSBARMULTI:
+                pValues[nProp] <<= GetStatusFunc();
                 break;
         }
     }
     aLayoutItem.PutProperties(aNames, aValues);
-
-    return 0;
 }
 
-IMPL_LINK_NOARG(ScAppCfg, InputCommitHdl)
+IMPL_LINK_NOARG(ScAppCfg, InputCommitHdl, ScLinkConfigItem&, void)
 {
     Sequence<OUString> aNames = GetInputPropertyNames();
     Sequence<Any> aValues(aNames.getLength());
@@ -622,19 +587,17 @@ IMPL_LINK_NOARG(ScAppCfg, InputCommitHdl)
                 lcl_GetLastFunctions( pValues[nProp], *this );
                 break;
             case SCINPUTOPT_AUTOINPUT:
-                ScUnoHelpFunctions::SetBoolInAny( pValues[nProp], GetAutoComplete() );
+                pValues[nProp] <<= GetAutoComplete();
                 break;
             case SCINPUTOPT_DET_AUTO:
-                ScUnoHelpFunctions::SetBoolInAny( pValues[nProp], GetDetectiveAuto() );
+                pValues[nProp] <<= GetDetectiveAuto();
                 break;
         }
     }
     aInputItem.PutProperties(aNames, aValues);
-
-    return 0;
 }
 
-IMPL_LINK_NOARG(ScAppCfg, RevisionCommitHdl)
+IMPL_LINK_NOARG(ScAppCfg, RevisionCommitHdl, ScLinkConfigItem&, void)
 {
     Sequence<OUString> aNames = GetRevisionPropertyNames();
     Sequence<Any> aValues(aNames.getLength());
@@ -659,11 +622,9 @@ IMPL_LINK_NOARG(ScAppCfg, RevisionCommitHdl)
         }
     }
     aRevisionItem.PutProperties(aNames, aValues);
-
-    return 0;
 }
 
-IMPL_LINK_NOARG(ScAppCfg, ContentCommitHdl)
+IMPL_LINK_NOARG(ScAppCfg, ContentCommitHdl, ScLinkConfigItem&, void)
 {
     Sequence<OUString> aNames = GetContentPropertyNames();
     Sequence<Any> aValues(aNames.getLength());
@@ -679,11 +640,9 @@ IMPL_LINK_NOARG(ScAppCfg, ContentCommitHdl)
         }
     }
     aContentItem.PutProperties(aNames, aValues);
-
-    return 0;
 }
 
-IMPL_LINK_NOARG(ScAppCfg, SortListCommitHdl)
+IMPL_LINK_NOARG(ScAppCfg, SortListCommitHdl, ScLinkConfigItem&, void)
 {
     Sequence<OUString> aNames = GetSortListPropertyNames();
     Sequence<Any> aValues(aNames.getLength());
@@ -699,11 +658,9 @@ IMPL_LINK_NOARG(ScAppCfg, SortListCommitHdl)
         }
     }
     aSortListItem.PutProperties(aNames, aValues);
-
-    return 0;
 }
 
-IMPL_LINK_NOARG(ScAppCfg, MiscCommitHdl)
+IMPL_LINK_NOARG(ScAppCfg, MiscCommitHdl, ScLinkConfigItem&, void)
 {
     Sequence<OUString> aNames = GetMiscPropertyNames();
     Sequence<Any> aValues(aNames.getLength());
@@ -714,22 +671,20 @@ IMPL_LINK_NOARG(ScAppCfg, MiscCommitHdl)
         switch(nProp)
         {
             case SCMISCOPT_DEFOBJWIDTH:
-                pValues[nProp] <<= (sal_Int32) GetDefaultObjectSizeWidth();
+                pValues[nProp] <<= GetDefaultObjectSizeWidth();
                 break;
             case SCMISCOPT_DEFOBJHEIGHT:
-                pValues[nProp] <<= (sal_Int32) GetDefaultObjectSizeHeight();
+                pValues[nProp] <<= GetDefaultObjectSizeHeight();
                 break;
             case SCMISCOPT_SHOWSHAREDDOCWARN:
-                ScUnoHelpFunctions::SetBoolInAny( pValues[nProp], GetShowSharedDocumentWarning() );
+                pValues[nProp] <<= GetShowSharedDocumentWarning();
                 break;
         }
     }
     aMiscItem.PutProperties(aNames, aValues);
-
-    return 0;
 }
 
-IMPL_LINK_NOARG(ScAppCfg, CompatCommitHdl)
+IMPL_LINK_NOARG(ScAppCfg, CompatCommitHdl, ScLinkConfigItem&, void)
 {
     Sequence<OUString> aNames = GetCompatPropertyNames();
     Sequence<Any> aValues(aNames.getLength());
@@ -745,12 +700,11 @@ IMPL_LINK_NOARG(ScAppCfg, CompatCommitHdl)
         }
     }
     aCompatItem.PutProperties(aNames, aValues);
-    return 0;
 }
 
 void ScAppCfg::SetOptions( const ScAppOptions& rNew )
 {
-    *(ScAppOptions*)this = rNew;
+    *static_cast<ScAppOptions*>(this) = rNew;
     OptionsChanged();
 }
 
