@@ -20,14 +20,13 @@
 #include <memory>
 #include <vcl/svapp.hxx>
 
-#include "chartlis.hxx"
-#include "brdcst.hxx"
-#include "document.hxx"
-#include "reftokenhelper.hxx"
+#include <chartlis.hxx>
+#include <brdcst.hxx>
+#include <document.hxx>
+#include <reftokenhelper.hxx>
 
 using namespace com::sun::star;
 using ::std::vector;
-using ::std::unary_function;
 using ::std::for_each;
 
 // Update chart listeners quickly, to get a similar behavior to loaded charts
@@ -237,7 +236,7 @@ void ScChartListener::SetRangeList( const ScRangeListRef& rNew )
 
 namespace {
 
-class StartEndListening : public unary_function<ScTokenRef, void>
+class StartEndListening
 {
 public:
     StartEndListening(ScDocument* pDoc, ScChartListener& rParent, bool bStart) :
@@ -503,7 +502,7 @@ void ScChartListenerCollection::ChangeListening( const OUString& rName,
 
 namespace {
 
-class InsertChartListener : public std::unary_function<ScChartListener*, void>
+class InsertChartListener
 {
     ScChartListenerCollection::ListenersType& mrListeners;
 public:
@@ -646,7 +645,7 @@ void ScChartListenerCollection::SetDiffDirty(
     for (auto const& it : m_Listeners)
     {
         ScChartListener *const pCL = it.second.get();
-        OSL_ASSERT(pCL);
+        assert(pCL);
         const ScChartListener* pCLCmp = rCmp.findByName(pCL->GetName());
         if (!pCLCmp || *pCL != *pCLCmp)
         {
