@@ -21,17 +21,18 @@
 
 #include <svl/zforlist.hxx>
 #include <osl/diagnose.h>
-#include "attrib.hxx"
-#include "dif.hxx"
-#include "docpool.hxx"
-#include "document.hxx"
-#include "filter.hxx"
-#include "fprogressbar.hxx"
-#include "ftools.hxx"
-#include "patattr.hxx"
-#include "scerrors.hxx"
-#include "scitems.hxx"
-#include "stringutil.hxx"
+#include <attrib.hxx>
+#include <dif.hxx>
+#include <docpool.hxx>
+#include <document.hxx>
+#include <filter.hxx>
+#include <fprogressbar.hxx>
+#include <ftools.hxx>
+#include <patattr.hxx>
+#include <scerrors.hxx>
+#include <scitems.hxx>
+#include <stringutil.hxx>
+#include <table.hxx>
 #include <memory>
 
 const sal_Unicode pKeyTABLE[]   = { 'T', 'A', 'B', 'L', 'E', 0 };
@@ -47,7 +48,7 @@ const sal_Unicode pKeyNA[]      = { 'N', 'A', 0 };
 const sal_Unicode pKeyV[]       = { 'V', 0 };
 const sal_Unicode pKey1_0[]     = { '1', ',', '0', 0 };
 
-FltError ScFormatFilterPluginImpl::ScImportDif(SvStream& rIn, ScDocument* pDoc, const ScAddress& rInsPos,
+ErrCode ScFormatFilterPluginImpl::ScImportDif(SvStream& rIn, ScDocument* pDoc, const ScAddress& rInsPos,
                         const rtl_TextEncoding eVon )
 {
     DifParser   aDifParser( rIn, *pDoc, eVon );
@@ -79,7 +80,7 @@ FltError ScFormatFilterPluginImpl::ScImportDif(SvStream& rIn, ScDocument* pDoc,
                 if( aDifParser.nVector != 0 || aDifParser.nVal != 1 )
                     bSyntErrWarn = true;
                 if( bData )
-                    pDoc->RenameTab( nBaseTab, aData );
+                    pDoc->RenameTab( nBaseTab, aData);
             }
                 break;
             case T_VECTORS:
@@ -211,20 +212,20 @@ FltError ScFormatFilterPluginImpl::ScImportDif(SvStream& rIn, ScDocument* pDoc,
         aAttrCache.Apply( *pDoc, nBaseTab );
     }
     else
-        return eERR_FORMAT;
+        return SCERR_IMPORT_FORMAT;
 
     if( bSyntErrWarn )
 
-        // FIXME: Add proper Warnung!
-        return eERR_RNGOVRFLW;
+        // FIXME: Add proper warning!
+        return SCWARN_IMPORT_RANGE_OVERFLOW;
 
     else if( bOverflowWarn )
-        return eERR_RNGOVRFLW;
+        return SCWARN_IMPORT_RANGE_OVERFLOW;
     else
-        return eERR_OK;
+        return ERRCODE_NONE;
 }
 
-DifParser::DifParser( SvStream& rNewIn, ScDocument& rDoc, rtl_TextEncoding e )
+DifParser::DifParser( SvStream& rNewIn, const ScDocument& rDoc, rtl_TextEncoding e )
     : fVal(0.0)
     , nVector(0)
     , nVal(0)
@@ -545,7 +546,7 @@ DATASET DifParser::GetNextDataset()
                         while ( bContinue )
                         {
                             aData = aData + "\n";
-                            bContinue = !rIn.IsEof() && ReadNextLine( aLine );
+                            bContinue = !rIn.eof() && ReadNextLine( aLine );
                             if( bContinue )
                             {
                                 nLineLength = aLine.getLength();
@@ -575,7 +576,7 @@ DATASET DifParser::GetNextDataset()
     if( eRet == D_UNKNOWN )
         ReadNextLine( aLine );
 
-    if( rIn.IsEof() )
+    if( rIn.eof() )
         eRet = D_EOD;
 
     return eRet;
@@ -641,7 +642,7 @@ void DifColumn::SetNumFormat( SCROW nRow, const sal_uInt32 nNumFormat )
 
 void DifColumn::NewEntry( const SCROW nPos, const sal_uInt32 nNumFormat )
 {
-    maEntries.push_back(ENTRY());
+    maEntries.emplace_back();
     mpAkt = &maEntries.back();
     mpAkt->nStart = mpAkt->nEnd = nPos;
     mpAkt->nNumFormat = nNumFormat;
@@ -668,38 +669,28 @@ void DifColumn::Apply( ScDocument& rDoc, const SCCOL nCol, const SCTAB nTab )
 
 DifAttrCache::DifAttrCache()
 {
-    ppCols = new DifColumn *[ MAXCOL + 1 ];
-    for( SCCOL nCnt = 0 ; nCnt <= MAXCOL ; nCnt++ )
-        ppCols[ nCnt ] = nullptr;
 }
 
 DifAttrCache::~DifAttrCache()
 {
-    for( SCCOL nCnt = 0 ; nCnt <= MAXCOL ; nCnt++ )
-    {
-        if( ppCols[ nCnt ] )
-            delete ppCols[ nCnt ];
-    }
-
-    delete[] ppCols;
 }
 
 void DifAttrCache::SetNumFormat( const SCCOL nCol, const SCROW nRow, const sal_uInt32 nNumFormat )
 {
     OSL_ENSURE( ValidCol(nCol), "-DifAttrCache::SetNumFormat(): Col too big!" );
 
-    if( !ppCols[ nCol ] )
-        ppCols[ nCol ] = new DifColumn;
+    if( !maColMap.count(nCol) )
+        maColMap[ nCol ].reset( new DifColumn );
 
-    ppCols[ nCol ]->SetNumFormat( nRow, nNumFormat );
+    maColMap[ nCol ]->SetNumFormat( nRow, nNumFormat );
 }
 
 void DifAttrCache::Apply( ScDocument& rDoc, SCTAB nTab )
 {
-    for( SCCOL nCol = 0 ; nCol <= MAXCOL ; nCol++ )
+    for( SCCOL nCol : rDoc.GetColumnsRange(nTab, 0, MAXCOL) )
     {
-        if( ppCols[ nCol ] )
-            ppCols[ nCol ]->Apply( rDoc, nCol, nTab );
+        if( maColMap.count(nCol) )
+            maColMap[ nCol ]->Apply( rDoc, nCol, nTab );
     }
 }
 
