@@ -17,37 +17,30 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
+#include <formel.hxx>
 
-#include "formel.hxx"
+#include <o3tl/make_unique.hxx>
 
-_ScRangeListTabs::_ScRangeListTabs()
+ScRangeListTabs::ScRangeListTabs()
 {
 }
 
-_ScRangeListTabs::~_ScRangeListTabs()
+ScRangeListTabs::~ScRangeListTabs()
 {
 }
 
-
-void _ScRangeListTabs::Append( const ScAddress& aSRD, SCTAB nTab, const bool b )
+void ScRangeListTabs::Append( const ScAddress& aSRD, SCTAB nTab )
 {
     ScAddress a = aSRD;
 
-    if( b )
-    {
-        if (a.Tab() > MAXTAB)
-            a.SetTab(MAXTAB);
+    if (a.Tab() > MAXTAB)
+        a.SetTab(MAXTAB);
 
-        if (a.Col() > MAXCOL)
-            a.SetCol(MAXCOL);
+    if (a.Col() > MAXCOL)
+        a.SetCol(MAXCOL);
 
-        if (a.Row() > MAXROW)
-            a.SetRow(MAXROW);
-    }
-    else
-    {
-        OSL_ENSURE( ValidTab(a.Tab()), "-_ScRangeListTabs::Append(): A lie has no crash!" );
-    }
+    if (a.Row() > MAXROW)
+        a.SetRow(MAXROW);
 
     if( nTab == SCTAB_MAX)
         return;
@@ -57,12 +50,12 @@ void _ScRangeListTabs::Append( const ScAddress& aSRD, SCTAB nTab, const bool b )
     if (nTab < 0 || MAXTAB < nTab)
         return;
 
-    TabRangeType::iterator itr = maTabRanges.find(nTab);
-    if (itr == maTabRanges.end())
+    TabRangeType::iterator itr = m_TabRanges.find(nTab);
+    if (itr == m_TabRanges.end())
     {
         // No entry for this table yet.  Insert a new one.
         std::pair<TabRangeType::iterator, bool> r =
-            maTabRanges.insert(nTab, new RangeListType);
+            m_TabRanges.insert(std::make_pair(nTab, o3tl::make_unique<RangeListType>()));
 
         if (!r.second)
             // Insertion failed.
@@ -73,50 +66,38 @@ void _ScRangeListTabs::Append( const ScAddress& aSRD, SCTAB nTab, const bool b )
     itr->second->push_back(ScRange(a.Col(),a.Row(),a.Tab()));
 }
 
-void _ScRangeListTabs::Append( const ScRange& aCRD, SCTAB nTab, bool b )
+void ScRangeListTabs::Append( const ScRange& aCRD, SCTAB nTab )
 {
     ScRange a = aCRD;
 
-    if( b )
-    {
-        // ignore 3D ranges
-        if (a.aStart.Tab() != a.aEnd.Tab())
-            return;
+    // ignore 3D ranges
+    if (a.aStart.Tab() != a.aEnd.Tab())
+        return;
 
-        if (a.aStart.Tab() > MAXTAB)
-            a.aStart.SetTab(MAXTAB);
-        else if (a.aStart.Tab() < 0)
-            a.aStart.SetTab(0);
+    if (a.aStart.Tab() > MAXTAB)
+        a.aStart.SetTab(MAXTAB);
+    else if (a.aStart.Tab() < 0)
+        a.aStart.SetTab(0);
 
-        if (a.aStart.Col() > MAXCOL)
-            a.aStart.SetCol(MAXCOL);
-        else if (a.aStart.Col() < 0)
-            a.aStart.SetCol(0);
+    if (a.aStart.Col() > MAXCOL)
+        a.aStart.SetCol(MAXCOL);
+    else if (a.aStart.Col() < 0)
+        a.aStart.SetCol(0);
 
-        if (a.aStart.Row() > MAXROW)
-            a.aStart.SetRow(MAXROW);
-        else if (a.aStart.Row() < 0)
-            a.aStart.SetRow(0);
+    if (a.aStart.Row() > MAXROW)
+        a.aStart.SetRow(MAXROW);
+    else if (a.aStart.Row() < 0)
+        a.aStart.SetRow(0);
 
-        if (a.aEnd.Col() > MAXCOL)
-            a.aEnd.SetCol(MAXCOL);
-        else if (a.aEnd.Col() < 0)
-            a.aEnd.SetCol(0);
+    if (a.aEnd.Col() > MAXCOL)
+        a.aEnd.SetCol(MAXCOL);
+    else if (a.aEnd.Col() < 0)
+        a.aEnd.SetCol(0);
 
-        if (a.aEnd.Row() > MAXROW)
-            a.aEnd.SetRow(MAXROW);
-        else if (a.aEnd.Row() < 0)
-            a.aEnd.SetRow(0);
-    }
-#if 0 // no members 'Ref1' or 'Ref2' in 'ScRange'
-    else
-    {
-        OSL_ENSURE( ValidTab(a.Ref1.nTab),
-            "-_ScRangeListTabs::Append(): Luegen haben kurze Abstuerze!" );
-        OSL_ENSURE( a.Ref1.nTab == a.Ref2.nTab,
-            "+_ScRangeListTabs::Append(): 3D-Ranges werden in SC nicht unterstuetzt!" );
-    }
-#endif
+    if (a.aEnd.Row() > MAXROW)
+        a.aEnd.SetRow(MAXROW);
+    else if (a.aEnd.Row() < 0)
+        a.aEnd.SetRow(0);
 
     if( nTab == SCTAB_MAX)
         return;
@@ -127,12 +108,12 @@ void _ScRangeListTabs::Append( const ScRange& aCRD, SCTAB nTab, bool b )
     if (nTab < 0 || MAXTAB < nTab)
         return;
 
-    TabRangeType::iterator itr = maTabRanges.find(nTab);
-    if (itr == maTabRanges.end())
+    TabRangeType::iterator itr = m_TabRanges.find(nTab);
+    if (itr == m_TabRanges.end())
     {
         // No entry for this table yet.  Insert a new one.
         std::pair<TabRangeType::iterator, bool> r =
-            maTabRanges.insert(nTab, new RangeListType);
+            m_TabRanges.insert(std::make_pair(nTab, o3tl::make_unique<RangeListType>()));
 
         if (!r.second)
             // Insertion failed.
@@ -143,26 +124,26 @@ void _ScRangeListTabs::Append( const ScRange& aCRD, SCTAB nTab, bool b )
     itr->second->push_back(a);
 }
 
-const ScRange* _ScRangeListTabs::First( SCTAB n )
+const ScRange* ScRangeListTabs::First( SCTAB n )
 {
-    OSL_ENSURE( ValidTab(n), "-_ScRangeListTabs::First(): Good bye!" );
+    OSL_ENSURE( ValidTab(n), "-ScRangeListTabs::First(): Good bye!" );
 
-    TabRangeType::iterator itr = maTabRanges.find(n);
-    if (itr == maTabRanges.end())
+    TabRangeType::iterator itr = m_TabRanges.find(n);
+    if (itr == m_TabRanges.end())
         // No range list exists for this table.
-        return NULL;
+        return nullptr;
 
     const RangeListType& rList = *itr->second;
     maItrCur = rList.begin();
     maItrCurEnd = rList.end();
-    return rList.empty() ? NULL : &(*maItrCur);
+    return rList.empty() ? nullptr : &(*maItrCur);
 }
 
-const ScRange* _ScRangeListTabs::Next ()
+const ScRange* ScRangeListTabs::Next ()
 {
     ++maItrCur;
     if (maItrCur == maItrCurEnd)
-        return NULL;
+        return nullptr;
 
     return &(*maItrCur);
 }
@@ -170,28 +151,25 @@ const ScRange* _ScRangeListTabs::Next ()
 ConverterBase::ConverterBase( svl::SharedStringPool& rSPool, sal_uInt16 nNewBuffer ) :
     aPool(rSPool),
     aEingPos( 0, 0, 0 ),
-    eStatus( ConvOK ),
-    nBufferSize( nNewBuffer )
+    eStatus( ConvErr::OK )
 {
     OSL_ENSURE( nNewBuffer > 0, "ConverterBase::ConverterBase - nNewBuffer == 0!" );
-    pBuffer = new sal_Char[ nNewBuffer ];
+    pBuffer.reset( new sal_Char[ nNewBuffer ] );
 }
 
 ConverterBase::~ConverterBase()
 {
-    delete[] pBuffer;
 }
 
 void ConverterBase::Reset()
 {
-    eStatus = ConvOK;
+    eStatus = ConvErr::OK;
     aPool.Reset();
     aStack.Reset();
 }
 
-
-ExcelConverterBase::ExcelConverterBase( svl::SharedStringPool& rSPool, sal_uInt16 nNewBuffer ) :
-    ConverterBase(rSPool, nNewBuffer)
+ExcelConverterBase::ExcelConverterBase( svl::SharedStringPool& rSPool ) :
+    ConverterBase(rSPool, 512)
 {
 }
 
@@ -211,9 +189,8 @@ void ExcelConverterBase::Reset()
     aEingPos.Set( 0, 0, 0 );
 }
 
-
-LotusConverterBase::LotusConverterBase( SvStream &rStr, svl::SharedStringPool& rSPool, sal_uInt16 nNewBuffers ) :
-    ConverterBase(rSPool, nNewBuffers),
+LotusConverterBase::LotusConverterBase( SvStream &rStr, svl::SharedStringPool& rSPool  ) :
+    ConverterBase(rSPool, 128),
     aIn( rStr ),
     nBytesLeft( 0 )
 {
