@@ -18,11 +18,11 @@
  */
 
 #include <memory>
-#include "imp_op.hxx"
+#include <imp_op.hxx>
 
 #include <filter/msfilter/countryid.hxx>
 
-#include "scitems.hxx"
+#include <scitems.hxx>
 #include <editeng/eeitem.hxx>
 
 #include <editeng/editdata.hxx>
@@ -38,46 +38,46 @@
 
 #include <sfx2/objsh.hxx>
 #include <tools/urlobj.hxx>
-#include "docuno.hxx"
+#include <docuno.hxx>
 
-#include "formulacell.hxx"
-#include "document.hxx"
-#include "rangenam.hxx"
-#include "compiler.hxx"
-#include "patattr.hxx"
-#include "attrib.hxx"
-#include "globstr.hrc"
-#include "global.hxx"
-#include "markdata.hxx"
-#include "olinetab.hxx"
-#include "stlsheet.hxx"
-#include "stlpool.hxx"
-#include "viewopti.hxx"
-#include "docoptio.hxx"
-#include "scextopt.hxx"
-#include "editutil.hxx"
-#include "filtopt.hxx"
-#include "scerrors.hxx"
-#include "unonames.hxx"
-#include "paramisc.hxx"
-#include "postit.hxx"
+#include <formulacell.hxx>
+#include <document.hxx>
+#include <rangenam.hxx>
+#include <compiler.hxx>
+#include <patattr.hxx>
+#include <attrib.hxx>
+#include <globstr.hrc>
+#include <global.hxx>
+#include <markdata.hxx>
+#include <olinetab.hxx>
+#include <stlsheet.hxx>
+#include <stlpool.hxx>
+#include <viewopti.hxx>
+#include <docoptio.hxx>
+#include <scextopt.hxx>
+#include <editutil.hxx>
+#include <filtopt.hxx>
+#include <scerrors.hxx>
+#include <unonames.hxx>
+#include <paramisc.hxx>
+#include <postit.hxx>
 
-#include "fapihelper.hxx"
-#include "namebuff.hxx"
-#include "xltools.hxx"
-#include "xltable.hxx"
-#include "xlview.hxx"
-#include "xltracer.hxx"
-#include "xihelper.hxx"
-#include "xipage.hxx"
-#include "xiview.hxx"
-#include "xilink.hxx"
-#include "xiescher.hxx"
-#include "xicontent.hxx"
+#include <fapihelper.hxx>
+#include <namebuff.hxx>
+#include <xltools.hxx>
+#include <xltable.hxx>
+#include <xlview.hxx>
+#include <xltracer.hxx>
+#include <xihelper.hxx>
+#include <xipage.hxx>
+#include <xiview.hxx>
+#include <xilink.hxx>
+#include <xiescher.hxx>
+#include <xicontent.hxx>
 
-#include "excimp8.hxx"
-#include "excform.hxx"
-#include "documentimport.hxx"
+#include <excimp8.hxx>
+#include <excform.hxx>
+#include <documentimport.hxx>
 
 #if defined(_WIN32)
 #include <math.h>
@@ -99,9 +99,9 @@ ImportTyp::~ImportTyp()
 {
 }
 
-FltError ImportTyp::Read()
+ErrCode ImportTyp::Read()
 {
-    return eERR_INTERN;
+    return SCERR_IMPORT_INTERNAL;
 }
 
 ImportExcel::ImportExcel( XclImpRootData& rImpData, SvStream& rStrm ):
@@ -166,8 +166,7 @@ void ImportExcel::SetLastFormula( SCCOL nCol, SCROW nRow, double fVal, sal_uInt1
     if (it == maLastFormulaCells.end())
     {
         std::pair<LastFormulaMapType::iterator, bool> r =
-            maLastFormulaCells.insert(
-                LastFormulaMapType::value_type(nCol, LastFormula()));
+            maLastFormulaCells.emplace(nCol, LastFormula());
         it = r.first;
     }
 
@@ -349,7 +348,7 @@ void ImportExcel::ReadLabel()
             0x0204      8       2 byte      16-bit length, unicode string */
         bool bBiff2 = maStrm.GetRecId() == EXC_ID2_LABEL;
         sal_uInt16 nXFIdx = ReadXFIndex( aScPos, bBiff2 );
-        XclStrFlags nFlags = (bBiff2 && (GetBiff() <= EXC_BIFF5)) ? EXC_STR_8BITLENGTH : EXC_STR_DEFAULT;
+        XclStrFlags nFlags = (bBiff2 && (GetBiff() <= EXC_BIFF5)) ? XclStrFlags::EightBitLength : XclStrFlags::NONE;
         XclImpString aString;
 
         // #i63105# use text encoding from FONT record
@@ -862,6 +861,7 @@ void ImportExcel::Shrfmla()
 
     ScFormulaCell* pCell = new ScFormulaCell(pD, aPos, *pErgebnis);
     pCell->GetCode()->WrapReference(aPos, EXC_MAXCOL8, EXC_MAXROW8);
+    rDoc.getDoc().CheckLinkFormulaNeedingCheck( *pCell->GetCode());
     rDoc.getDoc().EnsureTable(aPos.Tab());
     rDoc.setFormulaCell(aPos, pCell);
     pCell->SetNeedNumberFormat(false);
