@@ -26,7 +26,7 @@
 #include <svtools/ctrltool.hxx>
 #include <svx/svdotext.hxx>
 #include <editeng/outlobj.hxx>
-#include "scitems.hxx"
+#include <scitems.hxx>
 #include <editeng/fhgtitem.hxx>
 #include <editeng/flstitem.hxx>
 #include <editeng/colritem.hxx>
@@ -35,18 +35,18 @@
 #include <editeng/escapementitem.hxx>
 #include <editeng/svxfont.hxx>
 
-#include "document.hxx"
-#include "docpool.hxx"
-#include "formulacell.hxx"
-#include "editutil.hxx"
-#include "patattr.hxx"
-#include "scmatrix.hxx"
-#include "xestyle.hxx"
-#include "fprogressbar.hxx"
-#include "xltracer.hxx"
-#include "xecontent.hxx"
-#include "xelink.hxx"
-#include "xehelper.hxx"
+#include <document.hxx>
+#include <docpool.hxx>
+#include <formulacell.hxx>
+#include <editutil.hxx>
+#include <patattr.hxx>
+#include <scmatrix.hxx>
+#include <xestyle.hxx>
+#include <fprogressbar.hxx>
+#include <xltracer.hxx>
+#include <xecontent.hxx>
+#include <xelink.hxx>
+#include <xehelper.hxx>
 
 using ::com::sun::star::uno::Reference;
 using ::com::sun::star::i18n::XBreakIterator;
@@ -424,7 +424,7 @@ XclExpStringRef lclCreateFormattedString(
 
     // font buffer and helper item set for edit engine -> Calc item conversion
     XclExpFontBuffer& rFontBuffer = rRoot.GetFontBuffer();
-    SfxItemSet aItemSet( *rRoot.GetDoc().GetPool(), ATTR_PATTERN_START, ATTR_PATTERN_END );
+    SfxItemSet aItemSet( *rRoot.GetDoc().GetPool(), svl::Items<ATTR_PATTERN_START, ATTR_PATTERN_END>{} );
 
     // script type handling
     Reference< XBreakIterator > xBreakIt = rRoot.GetDoc().GetBreakIterator();
@@ -453,7 +453,7 @@ XclExpStringRef lclCreateFormattedString(
             ScPatternAttr::GetFromEditItemSet( aItemSet, aEditSet );
 
             // get escapement value
-            short nEsc = GETITEM( aEditSet, SvxEscapementItem, EE_CHAR_ESCAPEMENT ).GetEsc();
+            short nEsc = aEditSet.Get( EE_CHAR_ESCAPEMENT ).GetEsc();
 
             // process text fields
             bool bIsHyperlink = false;
@@ -497,7 +497,7 @@ XclExpStringRef lclCreateFormattedString(
                 // add escapement
                 aFont.SetEscapement( nEsc );
                 // modify automatic font color for hyperlinks
-                if( bIsHyperlink && (GETITEM( aItemSet, SvxColorItem, ATTR_FONT_COLOR ).GetValue().GetColor() == COL_AUTO) )
+                if( bIsHyperlink && aItemSet.Get( ATTR_FONT_COLOR ).GetValue().GetColor() == COL_AUTO)
                     aFont.SetColor( Color( COL_LIGHTBLUE ) );
 
                 // insert font into buffer
@@ -678,7 +678,7 @@ void XclExpHFConverter::AppendPortion( const EditTextObject* pTextObj, sal_Unico
 
     OUString aText;
     sal_Int32 nHeight = 0;
-    SfxItemSet aItemSet( *GetDoc().GetPool(), ATTR_PATTERN_START, ATTR_PATTERN_END );
+    SfxItemSet aItemSet( *GetDoc().GetPool(), svl::Items<ATTR_PATTERN_START, ATTR_PATTERN_END>{} );
 
     // edit engine
     bool bOldUpdateMode = mrEE.GetUpdateMode();
@@ -735,7 +735,7 @@ void XclExpHFConverter::AppendPortion( const EditTextObject* pTextObj, sal_Unico
                                  (aFontData.mbItalic != aNewData.mbItalic);
                 if( bNewFont || (bNewStyle && pFontList) )
                 {
-                    aParaText = "&\"" + OUString(aNewData.maName);
+                    aParaText = "&\"" + aNewData.maName;
                     if( pFontList )
                     {
                         FontMetric aFontMetric( pFontList->Get(
@@ -752,7 +752,7 @@ void XclExpHFConverter::AppendPortion( const EditTextObject* pTextObj, sal_Unico
                 // height
                 // is calculated wrong in ScPatternAttr::GetFromEditItemSet, because already in twips and not 100thmm
                 // -> get it directly from edit engine item set
-                aNewData.mnHeight = ulimit_cast< sal_uInt16 >( GETITEM( aEditSet, SvxFontHeightItem, EE_CHAR_FONTHEIGHT ).GetHeight() );
+                aNewData.mnHeight = ulimit_cast< sal_uInt16 >( aEditSet.Get( EE_CHAR_FONTHEIGHT ).GetHeight() );
                 (aNewData.mnHeight += 10) /= 20;
                 bool bFontHtChanged = (aFontData.mnHeight != aNewData.mnHeight);
                 if( bFontHtChanged )
@@ -782,7 +782,7 @@ void XclExpHFConverter::AppendPortion( const EditTextObject* pTextObj, sal_Unico
                     aParaText += "&S";
 
                 // super/sub script
-                const SvxEscapementItem& rEscapeItem = GETITEM( aEditSet, SvxEscapementItem, EE_CHAR_ESCAPEMENT );
+                const SvxEscapementItem& rEscapeItem = aEditSet.Get( EE_CHAR_ESCAPEMENT );
                 aNewData.SetScEscapement( rEscapeItem.GetEsc() );
                 if( aFontData.mnEscapem != aNewData.mnEscapem )
                 {
@@ -822,14 +822,14 @@ void XclExpHFConverter::AppendPortion( const EditTextObject* pTextObj, sal_Unico
                         {
                             switch( pFileField->GetFormat() )
                             {
-                                case SVXFILEFORMAT_NAME_EXT:
-                                case SVXFILEFORMAT_NAME:
+                                case SvxFileFormat::NameAndExt:
+                                case SvxFileFormat::NameOnly:
                                     aParaText += "&F";
                                 break;
-                                case SVXFILEFORMAT_PATH:
+                                case SvxFileFormat::PathOnly:
                                     aParaText += "&Z";
                                 break;
-                                case SVXFILEFORMAT_FULLPATH:
+                                case SvxFileFormat::PathFull:
                                     aParaText += "&Z&F";
                                 break;
                                 default:
@@ -888,13 +888,13 @@ OUString lclEncodeDosUrl(
         OUString aOldUrl = rUrl;
         aBuf.append(EXC_URLSTART_ENCODED);
 
-        if ( aOldUrl.getLength() > 2 && aOldUrl.copy(0,2) == "\\\\" )
+        if ( aOldUrl.getLength() > 2 && aOldUrl.startsWith("\\\\") )
         {
             // UNC
             aBuf.append(EXC_URL_DOSDRIVE).append('@');
             aOldUrl = aOldUrl.copy(2);
         }
-        else if ( aOldUrl.getLength() > 2 && aOldUrl.copy(1,2) == ":\\" )
+        else if ( aOldUrl.getLength() > 2 && aOldUrl.match(":\\", 1) )
         {
             // drive letter
             sal_Unicode cThisDrive = rBase.isEmpty() ? ' ' : rBase[0];
@@ -916,7 +916,7 @@ OUString lclEncodeDosUrl(
         sal_Int32 nPos = -1;
         while((nPos = aOldUrl.indexOf('\\')) != -1)
         {
-            if ( aOldUrl.copy(0,2) == ".." )
+            if ( aOldUrl.startsWith("..") )
                 // parent dir (NOTE: the MS-XLS spec doesn't mention this, and
                 // Excel seems confused by this token).
                 aBuf.append(EXC_URL_PARENTDIR);
@@ -1036,7 +1036,7 @@ void XclExpCachedMatrix::Save( XclExpStream& rStrm ) const
             }
             else if( ScMatrix::IsNonValueType( nMatVal.nType ) )
             {
-                XclExpString aStr( nMatVal.GetString().getString(), EXC_STR_DEFAULT );
+                XclExpString aStr( nMatVal.GetString().getString(), XclStrFlags::NONE );
                 rStrm.SetSliceSize( 6 );
                 rStrm << EXC_CACHEDVAL_STRING << aStr;
             }
