@@ -17,20 +17,21 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "xename.hxx"
+#include <xename.hxx>
 
 #include <map>
 
-#include "globstr.hrc"
-#include "document.hxx"
-#include "rangenam.hxx"
-#include "dbdata.hxx"
-#include "xehelper.hxx"
-#include "xelink.hxx"
-#include "globalnames.hxx"
-#include "excrecds.hxx"
+#include <globstr.hrc>
+#include <document.hxx>
+#include <rangenam.hxx>
+#include <dbdata.hxx>
+#include <xehelper.hxx>
+#include <xelink.hxx>
+#include <globalnames.hxx>
+#include <excrecds.hxx>
 
 #include <formula/grammar.hxx>
+#include <oox/export/utils.hxx>
 
 using namespace ::oox;
 
@@ -46,7 +47,7 @@ public:
     explicit            XclExpName( const XclExpRoot& rRoot, sal_Unicode cBuiltIn );
 
     /** Sets a token array containing the definition of this name. */
-    void                SetTokenArray( XclTokenArrayRef xTokArr );
+    void                SetTokenArray( const XclTokenArrayRef& xTokArr );
     /** Changes this defined name to be local on the specified Calc sheet. */
     void                SetLocalTab( SCTAB nScTab );
     /** Hides or unhides the defined name. */
@@ -61,18 +62,18 @@ public:
     void                SetSymbol( const OUString& rValue );
 
     /** Returns the original name (title) of this defined name. */
-    inline const OUString& GetOrigName() const { return maOrigName; }
+    const OUString& GetOrigName() const { return maOrigName; }
     /** Returns the Excel built-in name index of this defined name.
         @return  The built-in name index or EXC_BUILTIN_UNKNOWN for user-defined names. */
-    inline sal_Unicode  GetBuiltInName() const { return mcBuiltIn; }
+    sal_Unicode  GetBuiltInName() const { return mcBuiltIn; }
 
     /** Returns the token array for this defined name. */
-    inline XclTokenArrayRef GetTokenArray() const { return mxTokArr; }
+    const XclTokenArrayRef& GetTokenArray() const { return mxTokArr; }
 
     /** Returns true, if this is a document-global defined name. */
-    inline bool         IsGlobal() const { return mnXclTab == EXC_NAME_GLOBAL; }
+    bool         IsGlobal() const { return mnXclTab == EXC_NAME_GLOBAL; }
     /** Returns the Calc sheet of a local defined name. */
-    inline SCTAB        GetScTab() const { return mnScTab; }
+    SCTAB        GetScTab() const { return mnScTab; }
 
     /** Returns true, if this defined name is volatile. */
     bool                IsVolatile() const;
@@ -117,10 +118,10 @@ public:
     sal_uInt16          InsertName( SCTAB nTab, sal_uInt16 nScNameIdx );
 
     /** Inserts a new built-in defined name. */
-    sal_uInt16          InsertBuiltInName( sal_Unicode cBuiltIn, XclTokenArrayRef xTokArr, SCTAB nScTab, const ScRangeList& aRangeList );
-    sal_uInt16          InsertBuiltInName( sal_Unicode cBuiltIn, XclTokenArrayRef xTokArr, const ScRange& aRange );
+    sal_uInt16          InsertBuiltInName( sal_Unicode cBuiltIn, const XclTokenArrayRef& xTokArr, SCTAB nScTab, const ScRangeList& aRangeList );
+    sal_uInt16          InsertBuiltInName( sal_Unicode cBuiltIn, const XclTokenArrayRef& xTokArr, const ScRange& aRange );
     /** Inserts a new defined name. Sets another unused name, if rName already exists. */
-    sal_uInt16          InsertUniqueName( const OUString& rName, XclTokenArrayRef xTokArr, SCTAB nScTab );
+    sal_uInt16          InsertUniqueName( const OUString& rName, const XclTokenArrayRef& xTokArr, SCTAB nScTab );
     /** Returns index of an existing name, or creates a name without definition. */
     sal_uInt16          InsertRawName( const OUString& rName );
     /** Searches or inserts a defined name describing a macro name.
@@ -156,13 +157,13 @@ private:
 
     /** Returns the index of an existing built-in NAME record with the passed definition, otherwise 0. */
     sal_uInt16          FindBuiltInNameIdx( const OUString& rName,
-                            const XclTokenArray& rTokArr, bool bDBRange ) const;
+                            const XclTokenArray& rTokArr ) const;
     /** Returns an unused name for the passed name. */
     OUString            GetUnusedName( const OUString& rName ) const;
 
     /** Appends a new NAME record to the record list.
         @return  The 1-based NAME record index used elsewhere in the Excel file. */
-    sal_uInt16          Append( XclExpNameRef xName );
+    sal_uInt16          Append( const XclExpNameRef& xName );
     /** Creates a new NAME record for the passed user-defined name.
         @return  The 1-based NAME record index used elsewhere in the Excel file. */
     sal_uInt16          CreateName( SCTAB nTab, const ScRangeData& rRangeData );
@@ -189,7 +190,7 @@ XclExpName::XclExpName( const XclExpRoot& rRoot, const OUString& rName ) :
     XclExpRecord( EXC_ID_NAME ),
     XclExpRoot( rRoot ),
     maOrigName( rName ),
-    mxName( XclExpStringHelper::CreateString( rRoot, rName, EXC_STR_8BITLENGTH ) ),
+    mxName( XclExpStringHelper::CreateString( rRoot, rName, XclStrFlags::EightBitLength ) ),
     mcBuiltIn( EXC_BUILTIN_UNKNOWN ),
     mnScTab( SCTAB_GLOBAL ),
     mnFlags( EXC_NAME_DEFAULT ),
@@ -215,18 +216,18 @@ XclExpName::XclExpName( const XclExpRoot& rRoot, sal_Unicode cBuiltIn ) :
     if( (GetBiff() <= EXC_BIFF5) && (cBuiltIn == EXC_BUILTIN_FILTERDATABASE) )
     {
         OUString aName( XclTools::GetXclBuiltInDefName( EXC_BUILTIN_FILTERDATABASE ) );
-        mxName = XclExpStringHelper::CreateString( rRoot, aName, EXC_STR_8BITLENGTH );
+        mxName = XclExpStringHelper::CreateString( rRoot, aName, XclStrFlags::EightBitLength );
         maOrigName = XclTools::GetXclBuiltInDefName( cBuiltIn );
     }
     else
     {
         maOrigName =  XclTools::GetBuiltInDefNameXml( cBuiltIn ) ;
-        mxName = XclExpStringHelper::CreateString( rRoot, cBuiltIn, EXC_STR_8BITLENGTH );
+        mxName = XclExpStringHelper::CreateString( rRoot, cBuiltIn, XclStrFlags::EightBitLength );
         ::set_flag( mnFlags, EXC_NAME_BUILTIN );
     }
 }
 
-void XclExpName::SetTokenArray( XclTokenArrayRef xTokArr )
+void XclExpName::SetTokenArray( const XclTokenArrayRef& xTokArr )
 {
     mxTokArr = xTokArr;
 }
@@ -300,16 +301,16 @@ void XclExpName::SaveXml( XclExpXmlStream& rStrm )
             // OOXTODO: XML_comment, "",
             // OOXTODO: XML_customMenu, "",
             // OOXTODO: XML_description, "",
-            XML_function, XclXmlUtils::ToPsz( ::get_flag( mnFlags, EXC_NAME_VB ) ),
+            XML_function, ToPsz( ::get_flag( mnFlags, EXC_NAME_VB ) ),
             // OOXTODO: XML_functionGroupId, "",
             // OOXTODO: XML_help, "",
-            XML_hidden, XclXmlUtils::ToPsz( ::get_flag( mnFlags, EXC_NAME_HIDDEN ) ),
+            XML_hidden, ToPsz( ::get_flag( mnFlags, EXC_NAME_HIDDEN ) ),
             XML_localSheetId, mnScTab == SCTAB_GLOBAL ? nullptr : OString::number( mnScTab ).getStr(),
             XML_name, XclXmlUtils::ToOString( maOrigName ).getStr(),
             // OOXTODO: XML_publishToServer, "",
             // OOXTODO: XML_shortcutKey, "",
             // OOXTODO: XML_statusBar, "",
-            XML_vbProcedure, XclXmlUtils::ToPsz( ::get_flag( mnFlags, EXC_NAME_VB ) ),
+            XML_vbProcedure, ToPsz( ::get_flag( mnFlags, EXC_NAME_VB ) ),
             // OOXTODO: XML_workbookParameter, "",
             // OOXTODO: XML_xlm, "",
             FSEND );
@@ -364,29 +365,29 @@ sal_uInt16 XclExpNameManagerImpl::InsertName( SCTAB nTab, sal_uInt16 nScNameIdx
     return nNameIdx;
 }
 
-sal_uInt16 XclExpNameManagerImpl::InsertBuiltInName( sal_Unicode cBuiltIn, XclTokenArrayRef xTokArr, const ScRange& aRange )
+sal_uInt16 XclExpNameManagerImpl::InsertBuiltInName( sal_Unicode cBuiltIn, const XclTokenArrayRef& xTokArr, const ScRange& aRange )
 {
     XclExpNameRef xName( new XclExpName( GetRoot(), cBuiltIn ) );
     xName->SetTokenArray( xTokArr );
     xName->SetLocalTab( aRange.aStart.Tab() );
-    OUString sSymbol(aRange.Format(SCR_ABS_3D, &GetDocRef(), ScAddress::Details( ::formula::FormulaGrammar::CONV_XL_A1)));
+    OUString sSymbol(aRange.Format(ScRefFlags::RANGE_ABS_3D, &GetDocRef(), ScAddress::Details( ::formula::FormulaGrammar::CONV_XL_A1)));
     xName->SetSymbol( sSymbol );
     return Append( xName );
 }
 
-sal_uInt16 XclExpNameManagerImpl::InsertBuiltInName( sal_Unicode cBuiltIn, XclTokenArrayRef xTokArr, SCTAB nScTab, const ScRangeList& rRangeList )
+sal_uInt16 XclExpNameManagerImpl::InsertBuiltInName( sal_Unicode cBuiltIn, const XclTokenArrayRef& xTokArr, SCTAB nScTab, const ScRangeList& rRangeList )
 {
     XclExpNameRef xName( new XclExpName( GetRoot(), cBuiltIn ) );
     xName->SetTokenArray( xTokArr );
     xName->SetLocalTab( nScTab );
     OUString sSymbol;
-    rRangeList.Format( sSymbol, SCR_ABS_3D, &GetDocRef(), ::formula::FormulaGrammar::CONV_XL_A1 );
+    rRangeList.Format( sSymbol, ScRefFlags::RANGE_ABS_3D, &GetDocRef(), ::formula::FormulaGrammar::CONV_XL_A1 );
     xName->SetSymbol( sSymbol );
     return Append( xName );
 }
 
 sal_uInt16 XclExpNameManagerImpl::InsertUniqueName(
-        const OUString& rName, XclTokenArrayRef xTokArr, SCTAB nScTab )
+        const OUString& rName, const XclTokenArrayRef& xTokArr, SCTAB nScTab )
 {
     OSL_ENSURE( !rName.isEmpty(), "XclExpNameManagerImpl::InsertUniqueName - empty name" );
     XclExpNameRef xName( new XclExpName( GetRoot(), GetUnusedName( rName ) ) );
@@ -471,12 +472,11 @@ sal_uInt16 XclExpNameManagerImpl::FindNamedExpIndex( SCTAB nTab, sal_uInt16 nScI
 }
 
 sal_uInt16 XclExpNameManagerImpl::FindBuiltInNameIdx(
-        const OUString& rName, const XclTokenArray& rTokArr, bool bDBRange ) const
+        const OUString& rName, const XclTokenArray& rTokArr ) const
 {
     /*  Get built-in index from the name. Special case: the database range
         'unnamed' will be mapped to Excel's built-in '_FilterDatabase' name. */
-    sal_Unicode cBuiltIn = (bDBRange && (rName == STR_DB_LOCAL_NONAME)) ?
-        EXC_BUILTIN_FILTERDATABASE : XclTools::GetBuiltInDefNameIndex( rName );
+    sal_Unicode cBuiltIn = XclTools::GetBuiltInDefNameIndex( rName );
 
     if( cBuiltIn < EXC_BUILTIN_UNKNOWN )
     {
@@ -516,7 +516,7 @@ OUString XclExpNameManagerImpl::GetUnusedName( const OUString& rName ) const
     return aNewName;
 }
 
-sal_uInt16 XclExpNameManagerImpl::Append( XclExpNameRef xName )
+sal_uInt16 XclExpNameManagerImpl::Append( const XclExpNameRef& xName )
 {
     if( maNameList.GetSize() == 0xFFFF )
         return 0;
@@ -557,7 +557,7 @@ sal_uInt16 XclExpNameManagerImpl::CreateName( SCTAB nTab, const ScRangeData& rRa
             cannot be done earlier. If a built-in name is found, the created NAME
             record for this name and all following records in the list must be
             deleted, otherwise they may contain wrong name list indexes. */
-        sal_uInt16 nBuiltInIdx = FindBuiltInNameIdx( rName, *xTokArr, false );
+        sal_uInt16 nBuiltInIdx = FindBuiltInNameIdx( rName, *xTokArr );
         if( nBuiltInIdx != 0 )
         {
             // delete the new NAME records
@@ -652,7 +652,8 @@ void XclExpNameManagerImpl::CreateUserNames()
     ScRangeName::TabNameCopyMap::iterator tabIt = rLocalNames.begin(), tabItEnd = rLocalNames.end();
     for (; tabIt != tabItEnd; ++tabIt)
     {
-        itr = tabIt->second->begin(), itrEnd = tabIt->second->end();
+        itr = tabIt->second->begin();
+        itrEnd = tabIt->second->end();
         for (; itr != itrEnd; ++itr)
         {
             // skip definitions of shared formulas
@@ -700,7 +701,7 @@ sal_uInt16 XclExpNameManager::InsertBuiltInName( sal_Unicode cBuiltIn, const ScR
 }
 
 sal_uInt16 XclExpNameManager::InsertUniqueName(
-        const OUString& rName, XclTokenArrayRef xTokArr, SCTAB nScTab )
+        const OUString& rName, const XclTokenArrayRef& xTokArr, SCTAB nScTab )
 {
     return mxImpl->InsertUniqueName( rName, xTokArr, nScTab );
 }
