@@ -17,7 +17,7 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "xepivot.hxx"
+#include <xepivot.hxx>
 #include <com/sun/star/sheet/DataPilotFieldSortInfo.hpp>
 #include <com/sun/star/sheet/DataPilotFieldAutoShowInfo.hpp>
 #include <com/sun/star/sheet/DataPilotFieldLayoutInfo.hpp>
@@ -31,21 +31,21 @@
 #include <tools/date.hxx>
 #include <svl/zformat.hxx>
 #include <sot/storage.hxx>
-#include "document.hxx"
-#include "dpobject.hxx"
-#include "dpsave.hxx"
-#include "dpdimsave.hxx"
-#include "dpshttab.hxx"
-#include "globstr.hrc"
-#include "fapihelper.hxx"
-#include "xestring.hxx"
-#include "xelink.hxx"
-#include "dputil.hxx"
+#include <document.hxx>
+#include <dpobject.hxx>
+#include <dpsave.hxx>
+#include <dpdimsave.hxx>
+#include <dpshttab.hxx>
+#include <globstr.hrc>
+#include <fapihelper.hxx>
+#include <xestring.hxx>
+#include <xelink.hxx>
+#include <dputil.hxx>
+#include <generalfunction.hxx>
 
 using namespace ::oox;
 
 using ::com::sun::star::sheet::DataPilotFieldOrientation;
-using ::com::sun::star::sheet::DataPilotFieldOrientation_HIDDEN;
 using ::com::sun::star::sheet::DataPilotFieldOrientation_ROW;
 using ::com::sun::star::sheet::DataPilotFieldOrientation_COLUMN;
 using ::com::sun::star::sheet::DataPilotFieldOrientation_PAGE;
@@ -99,18 +99,18 @@ XclExpPCItem::XclExpPCItem( const OUString& rText ) :
         SetEmpty();
 }
 
-XclExpPCItem::XclExpPCItem( double fValue ) :
+XclExpPCItem::XclExpPCItem( double fValue, const OUString& rText ) :
     XclExpRecord( EXC_ID_SXDOUBLE, 8 )
 {
-    SetDouble( fValue );
+    SetDouble( fValue, rText );
     mnTypeFlag = (fValue - floor( fValue ) == 0.0) ?
         EXC_PCITEM_DATA_INTEGER : EXC_PCITEM_DATA_DOUBLE;
 }
 
-XclExpPCItem::XclExpPCItem( const DateTime& rDateTime ) :
+XclExpPCItem::XclExpPCItem( const DateTime& rDateTime, const OUString& rText ) :
     XclExpRecord( EXC_ID_SXDATETIME, 8 )
 {
-    SetDateTime( rDateTime );
+    SetDateTime( rDateTime, rText );
     mnTypeFlag = EXC_PCITEM_DATA_DATE;
 }
 
@@ -121,11 +121,11 @@ XclExpPCItem::XclExpPCItem( sal_Int16 nValue ) :
     SetInteger( nValue );
 }
 
-XclExpPCItem::XclExpPCItem( bool bValue ) :
+XclExpPCItem::XclExpPCItem( bool bValue, const OUString& rText ) :
     XclExpRecord( EXC_ID_SXBOOLEAN, 2 ),
     mnTypeFlag( EXC_PCITEM_DATA_STRING )
 {
-    SetBool( bValue );
+    SetBool( bValue, rText );
 }
 
 bool XclExpPCItem::EqualsText( const OUString& rText ) const
@@ -165,7 +165,7 @@ void XclExpPCItem::WriteBody( XclExpStream& rStrm )
     else if( const DateTime* pDateTime = GetDateTime() )
     {
         sal_uInt16 nYear = static_cast< sal_uInt16 >( pDateTime->GetYear() );
-        sal_uInt16 nMonth = static_cast< sal_uInt16 >( pDateTime->GetMonth() );
+        sal_uInt16 nMonth = pDateTime->GetMonth();
         sal_uInt8 nDay = static_cast< sal_uInt8 >( pDateTime->GetDay() );
         sal_uInt8 nHour = static_cast< sal_uInt8 >( pDateTime->GetHour() );
         sal_uInt8 nMin = static_cast< sal_uInt8 >( pDateTime->GetMin() );
@@ -275,7 +275,7 @@ sal_uInt16 XclExpPCField::GetItemIndex( const OUString& rItemName ) const
     return EXC_PC_NOITEM;
 }
 
-sal_Size XclExpPCField::GetIndexSize() const
+std::size_t XclExpPCField::GetIndexSize() const
 {
     return Has16BitIndexes() ? 2 : 1;
 }
@@ -337,20 +337,20 @@ void XclExpPCField::InitStandardField( const ScRange& rRange )
     // loop over all cells, create pivot cache items
     for( aPos.IncRow(); (aPos.Row() <= rRange.aEnd.Row()) && (maOrigItemList.GetSize() < EXC_PC_MAXITEMCOUNT); aPos.IncRow() )
     {
+        OUString aText = rDoc.GetString(aPos.Col(), aPos.Row(), aPos.Tab());
         if( rDoc.HasValueData( aPos.Col(), aPos.Row(), aPos.Tab() ) )
         {
             double fValue = rDoc.GetValue( aPos );
-            short nFmtType = rFormatter.GetType( rDoc.GetNumberFormat( aPos ) );
+            short nFmtType = rFormatter.GetType( rDoc.GetNumberFormat( rDoc.GetNonThreadedContext(), aPos ) );
             if( nFmtType == css::util::NumberFormat::LOGICAL )
-                InsertOrigBoolItem( fValue != 0 );
+                InsertOrigBoolItem( fValue != 0, aText );
             else if( nFmtType & css::util::NumberFormat::DATETIME )
-                InsertOrigDateTimeItem( GetDateTimeFromDouble( ::std::max( fValue, 0.0 ) ) );
+                InsertOrigDateTimeItem( GetDateTimeFromDouble( ::std::max( fValue, 0.0 ) ), aText );
             else
-                InsertOrigDoubleItem( fValue );
+                InsertOrigDoubleItem( fValue, aText );
         }
         else
         {
-            OUString aText = rDoc.GetString(aPos.Col(), aPos.Row(), aPos.Tab());
             InsertOrigTextItem( aText );
         }
     }
@@ -464,7 +464,7 @@ void XclExpPCField::InsertOrigTextItem( const OUString& rText )
         InsertOrigItem( new XclExpPCItem( aShortText ) );
 }
 
-void XclExpPCField::InsertOrigDoubleItem( double fValue )
+void XclExpPCField::InsertOrigDoubleItem( double fValue, const OUString& rText )
 {
     size_t nPos = 0;
     bool bFound = false;
@@ -472,10 +472,10 @@ void XclExpPCField::InsertOrigDoubleItem( double fValue )
         if( (bFound = maOrigItemList.GetRecord( nPos )->EqualsDouble( fValue )) )
             InsertItemArrayIndex( nPos );
     if( !bFound )
-        InsertOrigItem( new XclExpPCItem( fValue ) );
+        InsertOrigItem( new XclExpPCItem( fValue, rText ) );
 }
 
-void XclExpPCField::InsertOrigDateTimeItem( const DateTime& rDateTime )
+void XclExpPCField::InsertOrigDateTimeItem( const DateTime& rDateTime, const OUString& rText )
 {
     size_t nPos = 0;
     bool bFound = false;
@@ -483,10 +483,10 @@ void XclExpPCField::InsertOrigDateTimeItem( const DateTime& rDateTime )
         if( (bFound = maOrigItemList.GetRecord( nPos )->EqualsDateTime( rDateTime )) )
             InsertItemArrayIndex( nPos );
     if( !bFound )
-        InsertOrigItem( new XclExpPCItem( rDateTime ) );
+        InsertOrigItem( new XclExpPCItem( rDateTime, rText ) );
 }
 
-void XclExpPCField::InsertOrigBoolItem( bool bValue )
+void XclExpPCField::InsertOrigBoolItem( bool bValue, const OUString& rText )
 {
     size_t nPos = 0;
     bool bFound = false;
@@ -494,7 +494,7 @@ void XclExpPCField::InsertOrigBoolItem( bool bValue )
         if( (bFound = maOrigItemList.GetRecord( nPos )->EqualsBool( bValue )) )
             InsertItemArrayIndex( nPos );
     if( !bFound )
-        InsertOrigItem( new XclExpPCItem( bValue ) );
+        InsertOrigItem( new XclExpPCItem( bValue, rText ) );
 }
 
 sal_uInt16 XclExpPCField::InsertGroupItem( XclExpPCItem* pNewItem )
@@ -526,12 +526,12 @@ void XclExpPCField::InsertNumDateGroupItems( const ScDPObject& rDPObj, const ScD
             aTmpDim.SetDateDimension();
         const std::vector<SCROW>& aMemberIds = aTmpDim.GetNumEntries(
             static_cast<SCCOL>(nDim), pCache);
-        for ( size_t  nIdx = 0 ; nIdx < aMemberIds.size(); nIdx++ )
+        for (SCROW nMemberId : aMemberIds)
         {
-            const ScDPItemData* pData = aDPData.GetMemberById(nDim , aMemberIds[nIdx]);
+            const ScDPItemData* pData = aDPData.GetMemberById(nDim, nMemberId);
             if ( pData )
             {
-                OUString aStr = pCache->GetFormattedString(nDim, *pData);
+                OUString aStr = pCache->GetFormattedString(nDim, *pData, false);
                 InsertGroupItem(new XclExpPCItem(aStr));
             }
         }
@@ -724,11 +724,6 @@ void XclExpPivotCache::SaveXml( XclExpXmlStream& /*rStrm*/ )
 {
 }
 
-XclExpPCField* XclExpPivotCache::GetFieldAcc( sal_uInt16 nFieldIdx )
-{
-    return maFieldList.GetRecord( nFieldIdx ).get();
-}
-
 void XclExpPivotCache::AddFields( const ScDPObject& rDPObj )
 {
     AddStdFields( rDPObj );
@@ -761,7 +756,7 @@ void XclExpPivotCache::AddGroupFields( const ScDPObject& rDPObj )
             // loop over all existing standard fields to find their group fields
             for( sal_uInt16 nFieldIdx = 0; nFieldIdx < maPCInfo.mnStdFields; ++nFieldIdx )
             {
-                if( XclExpPCField* pCurrStdField = GetFieldAcc( nFieldIdx ) )
+                if( XclExpPCField* pCurrStdField = maFieldList.GetRecord( nFieldIdx ).get() )
                 {
                     const ScDPSaveGroupDimension* pGroupDim = pSaveDimData->GetGroupDimForBase( pCurrStdField->GetFieldName() );
                     XclExpPCField* pLastGroupField = pCurrStdField;
@@ -810,7 +805,7 @@ void XclExpPivotCache::WriteCacheStream()
 {
     tools::SvRef<SotStorage> xSvStrg = OpenStorage( EXC_STORAGE_PTCACHE );
     tools::SvRef<SotStorageStream> xSvStrm = OpenStream( xSvStrg, ScfTools::GetHexStr( maPCInfo.mnStrmId ) );
-    if( xSvStrm.Is() )
+    if( xSvStrm.is() )
     {
         XclExpStream aStrm( *xSvStrm, GetRoot() );
         // SXDB
@@ -845,7 +840,7 @@ void XclExpPivotCache::WriteSxindexlistList( XclExpStream& rStrm ) const
 {
     if( HasItemIndexList() )
     {
-        sal_Size nRecSize = 0;
+        std::size_t nRecSize = 0;
         size_t nPos, nSize = maFieldList.GetSize();
         for( nPos = 0; nPos < nSize; ++nPos )
             nRecSize += maFieldList.GetRecord( nPos )->GetIndexSize();
@@ -865,29 +860,28 @@ void XclExpPivotCache::WriteSxindexlistList( XclExpStream& rStrm ) const
 namespace {
 
 /** Returns a display string for a data field containing the field name and aggregation function. */
-OUString lclGetDataFieldCaption( const OUString& rFieldName, GeneralFunction eFunc )
+OUString lclGetDataFieldCaption( const OUString& rFieldName, ScGeneralFunction eFunc )
 {
     OUString aCaption;
 
-    sal_uInt16 nResIdx = 0;
-    using namespace ::com::sun::star::sheet;
+    const char* pResIdx = nullptr;
     switch( eFunc )
     {
-        case GeneralFunction_SUM:       nResIdx = STR_FUN_TEXT_SUM;     break;
-        case GeneralFunction_COUNT:     nResIdx = STR_FUN_TEXT_COUNT;   break;
-        case GeneralFunction_AVERAGE:   nResIdx = STR_FUN_TEXT_AVG;     break;
-        case GeneralFunction_MAX:       nResIdx = STR_FUN_TEXT_MAX;     break;
-        case GeneralFunction_MIN:       nResIdx = STR_FUN_TEXT_MIN;     break;
-        case GeneralFunction_PRODUCT:   nResIdx = STR_FUN_TEXT_PRODUCT; break;
-        case GeneralFunction_COUNTNUMS: nResIdx = STR_FUN_TEXT_COUNT;   break;
-        case GeneralFunction_STDEV:     nResIdx = STR_FUN_TEXT_STDDEV;  break;
-        case GeneralFunction_STDEVP:    nResIdx = STR_FUN_TEXT_STDDEV;  break;
-        case GeneralFunction_VAR:       nResIdx = STR_FUN_TEXT_VAR;     break;
-        case GeneralFunction_VARP:      nResIdx = STR_FUN_TEXT_VAR;     break;
+        case ScGeneralFunction::SUM:       pResIdx = STR_FUN_TEXT_SUM;     break;
+        case ScGeneralFunction::COUNT:     pResIdx = STR_FUN_TEXT_COUNT;   break;
+        case ScGeneralFunction::AVERAGE:   pResIdx = STR_FUN_TEXT_AVG;     break;
+        case ScGeneralFunction::MAX:       pResIdx = STR_FUN_TEXT_MAX;     break;
+        case ScGeneralFunction::MIN:       pResIdx = STR_FUN_TEXT_MIN;     break;
+        case ScGeneralFunction::PRODUCT:   pResIdx = STR_FUN_TEXT_PRODUCT; break;
+        case ScGeneralFunction::COUNTNUMS: pResIdx = STR_FUN_TEXT_COUNT;   break;
+        case ScGeneralFunction::STDEV:     pResIdx = STR_FUN_TEXT_STDDEV;  break;
+        case ScGeneralFunction::STDEVP:    pResIdx = STR_FUN_TEXT_STDDEV;  break;
+        case ScGeneralFunction::VAR:       pResIdx = STR_FUN_TEXT_VAR;     break;
+        case ScGeneralFunction::VARP:      pResIdx = STR_FUN_TEXT_VAR;     break;
         default:;
     }
-    if( nResIdx )
-        aCaption = ScGlobal::GetRscString( nResIdx ) + " - ";
+    if (pResIdx)
+        aCaption = ScGlobal::GetRscString(pResIdx) + " - ";
     aCaption += rFieldName;
     return aCaption;
 }
@@ -903,13 +897,13 @@ XclExpPTItem::XclExpPTItem( const XclExpPCField& rCacheField, sal_uInt16 nCacheI
     maItemInfo.maVisName.mbUseCache = mpCacheItem != nullptr;
 }
 
-XclExpPTItem::XclExpPTItem( sal_uInt16 nItemType, sal_uInt16 nCacheIdx, bool bUseCache ) :
+XclExpPTItem::XclExpPTItem( sal_uInt16 nItemType, sal_uInt16 nCacheIdx ) :
     XclExpRecord( EXC_ID_SXVI, 8 ),
     mpCacheItem( nullptr )
 {
     maItemInfo.mnType = nItemType;
     maItemInfo.mnCacheIdx = nCacheIdx;
-    maItemInfo.maVisName.mbUseCache = bUseCache;
+    maItemInfo.maVisName.mbUseCache = true;
 }
 
 OUString XclExpPTItem::GetItemName() const
@@ -926,7 +920,7 @@ void XclExpPTItem::SetPropertiesFromMember( const ScDPSaveMember& rSaveMem )
 
     // visible name
     const OUString* pVisName = rSaveMem.GetLayoutName();
-    if (pVisName && !pVisName->equals(GetItemName()))
+    if (pVisName && *pVisName != GetItemName())
         maItemInfo.SetVisName(*pVisName);
 }
 
@@ -1000,7 +994,7 @@ static OUString lcl_convertCalcSubtotalName(const OUString& rName)
 void XclExpPTField::SetPropertiesFromDim( const ScDPSaveDimension& rSaveDim )
 {
     // orientation
-    DataPilotFieldOrientation eOrient = static_cast< DataPilotFieldOrientation >( rSaveDim.GetOrientation() );
+    DataPilotFieldOrientation eOrient = rSaveDim.GetOrientation();
     OSL_ENSURE( eOrient != DataPilotFieldOrientation_DATA, "XclExpPTField::SetPropertiesFromDim - called for data field" );
     maFieldInfo.AddApiOrient( eOrient );
 
@@ -1009,7 +1003,7 @@ void XclExpPTField::SetPropertiesFromDim( const ScDPSaveDimension& rSaveDim )
 
     // visible name
     const OUString* pLayoutName = rSaveDim.GetLayoutName();
-    if (pLayoutName && !pLayoutName->equals(GetFieldName()))
+    if (pLayoutName && *pLayoutName != GetFieldName())
         maFieldInfo.SetVisName(*pLayoutName);
 
     const OUString* pSubtotalName = rSaveDim.GetSubtotalName();
@@ -1067,7 +1061,7 @@ void XclExpPTField::SetPropertiesFromDim( const ScDPSaveDimension& rSaveDim )
 
 void XclExpPTField::SetDataPropertiesFromDim( const ScDPSaveDimension& rSaveDim )
 {
-    maDataInfoVec.push_back( XclPTDataFieldInfo() );
+    maDataInfoVec.emplace_back( );
     XclPTDataFieldInfo& rDataInfo = maDataInfoVec.back();
     rDataInfo.mnField = GetFieldIndex();
 
@@ -1075,7 +1069,7 @@ void XclExpPTField::SetDataPropertiesFromDim( const ScDPSaveDimension& rSaveDim
     maFieldInfo.AddApiOrient( DataPilotFieldOrientation_DATA );
 
     // aggregation function
-    GeneralFunction eFunc = static_cast< GeneralFunction >( rSaveDim.GetFunction() );
+    ScGeneralFunction eFunc = rSaveDim.GetFunction();
     rDataInfo.SetApiAggFunc( eFunc );
 
     // visible name
@@ -1156,7 +1150,7 @@ XclExpPTItem* XclExpPTField::GetItemAcc( const OUString& rName )
 
 void XclExpPTField::AppendSubtotalItem( sal_uInt16 nItemType )
 {
-    maItemList.AppendNewRecord( new XclExpPTItem( nItemType, EXC_SXVI_DEFAULT_CACHE, true ) );
+    maItemList.AppendNewRecord( new XclExpPTItem( nItemType, EXC_SXVI_DEFAULT_CACHE ) );
     ++maFieldInfo.mnItemCount;
 }
 
@@ -1174,7 +1168,7 @@ void XclExpPTField::WriteSxvdex( XclExpStream& rStrm ) const
     rStrm.EndRecord();
 }
 
-XclExpPivotTable::XclExpPivotTable( const XclExpRoot& rRoot, const ScDPObject& rDPObj, const XclExpPivotCache& rPCache, size_t ) :
+XclExpPivotTable::XclExpPivotTable( const XclExpRoot& rRoot, const ScDPObject& rDPObj, const XclExpPivotCache& rPCache ) :
     XclExpRoot( rRoot ),
     mrPCache( rPCache ),
     maDataOrientField( *this, EXC_SXIVD_DATA ),
@@ -1310,10 +1304,8 @@ void XclExpPivotTable::SetPropertiesFromDP( const ScDPSaveData& rSaveData )
     ::set_flag( maPTExtInfo.mnFlags, EXC_SXEX_DRILLDOWN, rSaveData.GetDrillDown() );
     mbFilterBtn = rSaveData.GetFilterButton();
     const ScDPSaveDimension* pDim = rSaveData.GetExistingDataLayoutDimension();
-    if (!pDim)
-        return;
 
-    const OUString* pLayoutName = pDim->GetLayoutName();
+    const OUString* pLayoutName = pDim ? pDim->GetLayoutName() : nullptr;
     if (pLayoutName)
         maPTInfo.maDataName = *pLayoutName;
     else
@@ -1328,7 +1320,7 @@ void XclExpPivotTable::SetFieldPropertiesFromDim( const ScDPSaveDimension& rSave
         pField->SetPropertiesFromDim( rSaveDim );
 
         // update the corresponding field position list
-        DataPilotFieldOrientation eOrient = static_cast< DataPilotFieldOrientation >( rSaveDim.GetOrientation() );
+        DataPilotFieldOrientation eOrient = rSaveDim.GetOrientation();
         sal_uInt16 nFieldIdx = pField->GetFieldIndex();
         bool bDataLayout = nFieldIdx == EXC_SXIVD_DATA;
         bool bMultiData = maDataFields.size() > 1;
@@ -1364,7 +1356,7 @@ void XclExpPivotTable::SetDataFieldPropertiesFromDim( const ScDPSaveDimension& r
         // field properties
         pField->SetDataPropertiesFromDim( rSaveDim );
         // update the data field position list
-        maDataFields.push_back( XclPTDataFieldPos( pField->GetFieldIndex(), pField->GetLastDataInfoIndex() ) );
+        maDataFields.emplace_back( pField->GetFieldIndex(), pField->GetLastDataInfoIndex() );
     }
 }
 
@@ -1437,9 +1429,9 @@ void XclExpPivotTable::Finalize()
     maPTInfo.mnDataRows = rnXclRow2 - rnDataXclRow + 1;
 
     // first heading
-    maPTInfo.mnFirstHeadRow = rnXclRow1;
+    maPTInfo.mnFirstHeadRow = rnXclRow1 + 1;
     if (bExtraHeaderRow)
-        maPTInfo.mnFirstHeadRow += 2;
+        maPTInfo.mnFirstHeadRow += 1;
 }
 
 // records ----------------------------------------------------------------
@@ -1492,7 +1484,7 @@ void XclExpPivotTable::WriteSxli( XclExpStream& rStrm, sal_uInt16 nLineCount, sa
 {
     if( nLineCount > 0 )
     {
-        sal_Size nLineSize = 8 + 2 * nIndexCount;
+        std::size_t nLineSize = 8 + 2 * nIndexCount;
         rStrm.StartRecord( EXC_ID_SXLI, nLineSize * nLineCount );
 
         /*  Excel expects the records to be filled completely, do not
@@ -1523,14 +1515,14 @@ void XclExpPivotTable::WriteQsiSxTag( XclExpStream& rStrm ) const
 {
     rStrm.StartRecord( 0x0802, 32 );
 
-    sal_uInt16 nRecordType = 0x0802;
-    sal_uInt16 nDummyFlags = 0x0000;
-    sal_uInt16 nTableType  = 1; // 0 = query table : 1 = pivot table
+    sal_uInt16 const nRecordType = 0x0802;
+    sal_uInt16 const nDummyFlags = 0x0000;
+    sal_uInt16 const nTableType  = 1; // 0 = query table : 1 = pivot table
 
     rStrm << nRecordType << nDummyFlags << nTableType;
 
     // General flags
-    sal_uInt16 nFlags = 0x0001;
+    sal_uInt16 const nFlags = 0x0001;
 #if 0
     // for doc purpose
     sal_uInt16 nFlags = 0x0000;
@@ -1546,7 +1538,7 @@ void XclExpPivotTable::WriteQsiSxTag( XclExpStream& rStrm ) const
 
     // Feature-specific options.  The value differs depending on the table
     // type, but we assume the table type is always pivot table.
-    sal_uInt32 nOptions = 0x00000000;
+    sal_uInt32 const nOptions = 0x00000000;
 #if 0
     // documentation for which bit is for what
     bool bNoStencil = false;
@@ -1560,19 +1552,12 @@ void XclExpPivotTable::WriteQsiSxTag( XclExpStream& rStrm ) const
 #endif
     rStrm << nOptions;
 
-    enum ExcelVersion
-    {
-        Excel2000 = 0,
-        ExcelXP   = 1,
-        Excel2003 = 2,
-        Excel2007 = 3
-    };
-    ExcelVersion eXclVer = Excel2000;
-    sal_uInt8 nOffsetBytes = 16;
-    rStrm << static_cast<sal_uInt8>(eXclVer)  // version table last refreshed
-          << static_cast<sal_uInt8>(eXclVer)  // minimum version to refresh
+    sal_uInt8 eXclVer = 0; // Excel2000
+    sal_uInt8 const nOffsetBytes = 16;
+    rStrm << eXclVer  // version table last refreshed
+          << eXclVer  // minimum version to refresh
           << nOffsetBytes
-          << static_cast<sal_uInt8>(eXclVer); // first version created
+          << eXclVer; // first version created
 
     rStrm << XclExpString(maPTInfo.maTableName);
     rStrm << static_cast<sal_uInt16>(0x0001); // no idea what this is for.
@@ -1624,8 +1609,7 @@ void XclExpPivotRecWrapper::Save( XclExpStream& rStrm )
 } // namespace
 
 XclExpPivotTableManager::XclExpPivotTableManager( const XclExpRoot& rRoot ) :
-    XclExpRoot( rRoot ),
-    mbShareCaches( true )
+    XclExpRoot( rRoot )
 {
 }
 
@@ -1636,7 +1620,7 @@ void XclExpPivotTableManager::CreatePivotTables()
         {
             ScDPObject& rDPObj = (*pDPColl)[ nDPObj ];
             if( const XclExpPivotCache* pPCache = CreatePivotCache( rDPObj ) )
-                maPTableList.AppendNewRecord( new XclExpPivotTable( GetRoot(), rDPObj, *pPCache, nDPObj ) );
+                maPTableList.AppendNewRecord( new XclExpPivotTable( GetRoot(), rDPObj, *pPCache ) );
         }
 }
 
@@ -1672,22 +1656,19 @@ const XclExpPivotCache* XclExpPivotTableManager::CreatePivotCache( const ScDPObj
         (i.e. grouping info, calculated fields). If the passed DataPilot object
         or the found cache contains this data, do not share the cache with
         multiple pivot tables. */
-    if( mbShareCaches )
+    if( const ScDPSaveData* pSaveData = rDPObj.GetSaveData() )
     {
-        if( const ScDPSaveData* pSaveData = rDPObj.GetSaveData() )
+        const ScDPDimensionSaveData* pDimSaveData = pSaveData->GetExistingDimensionData();
+        // no dimension save data at all or save data does not contain grouping info
+        if( !pDimSaveData || !pDimSaveData->HasGroupDimensions() )
         {
-            const ScDPDimensionSaveData* pDimSaveData = pSaveData->GetExistingDimensionData();
-            // no dimension save data at all or save data does not contain grouping info
-            if( !pDimSaveData || !pDimSaveData->HasGroupDimensions() )
+            // check all existing pivot caches
+            for( size_t nPos = 0, nSize = maPCacheList.GetSize(); nPos < nSize; ++nPos )
             {
-                // check all existing pivot caches
-                for( size_t nPos = 0, nSize = maPCacheList.GetSize(); nPos < nSize; ++nPos )
-                {
-                    XclExpPivotCacheRef xPCache = maPCacheList.GetRecord( nPos );
-                    // pivot cache does not have grouping info and source data is equal
-                    if( !xPCache->HasAddFields() && xPCache->HasEqualDataSource( rDPObj ) )
-                        return xPCache.get();
-                }
+                XclExpPivotCacheRef xPCache = maPCacheList.GetRecord( nPos );
+                // pivot cache does not have grouping info and source data is equal
+                if( !xPCache->HasAddFields() && xPCache->HasEqualDataSource( rDPObj ) )
+                    return xPCache.get();
             }
         }
     }
