@@ -17,8 +17,7 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-
-#include "xipivot.hxx"
+#include <xipivot.hxx>
 
 #include <com/sun/star/sheet/DataPilotFieldSortInfo.hpp>
 #include <com/sun/star/sheet/DataPilotFieldAutoShowInfo.hpp>
@@ -29,32 +28,31 @@
 #include <svl/zformat.hxx>
 #include <svl/intitem.hxx>
 
-#include "document.hxx"
-#include "formulacell.hxx"
-#include "dpsave.hxx"
-#include "dpdimsave.hxx"
-#include "dpobject.hxx"
-#include "dpshttab.hxx"
-#include "dpoutputgeometry.hxx"
-#include "scitems.hxx"
-#include "attrib.hxx"
+#include <document.hxx>
+#include <formulacell.hxx>
+#include <dpsave.hxx>
+#include <dpdimsave.hxx>
+#include <dpobject.hxx>
+#include <dpshttab.hxx>
+#include <dpoutputgeometry.hxx>
+#include <scitems.hxx>
+#include <attrib.hxx>
 
-#include "xltracer.hxx"
-#include "xistream.hxx"
-#include "xihelper.hxx"
-#include "xilink.hxx"
-#include "xiescher.hxx"
+#include <xltracer.hxx>
+#include <xistream.hxx>
+#include <xihelper.hxx>
+#include <xilink.hxx>
+#include <xiescher.hxx>
 
-//! TODO ExcelToSc usage
-#include "excform.hxx"
-#include "xltable.hxx"
-#include "documentimport.hxx"
+//TODO ExcelToSc usage
+#include <excform.hxx>
+#include <xltable.hxx>
+#include <documentimport.hxx>
 
 #include <vector>
 
 using namespace com::sun::star;
 
-using ::com::sun::star::sheet::DataPilotFieldOrientation;
 using ::com::sun::star::sheet::DataPilotFieldOrientation_DATA;
 using ::com::sun::star::sheet::DataPilotFieldSortInfo;
 using ::com::sun::star::sheet::DataPilotFieldAutoShowInfo;
@@ -62,9 +60,7 @@ using ::com::sun::star::sheet::DataPilotFieldLayoutInfo;
 using ::com::sun::star::sheet::DataPilotFieldReference;
 using ::std::vector;
 
-// ============================================================================
 // Pivot cache
-// ============================================================================
 
 XclImpPCItem::XclImpPCItem( XclImpStream& rStrm )
 {
@@ -104,15 +100,15 @@ void XclImpPCItem::WriteToSource( XclImpRoot& rRoot, const ScAddress& rScPos ) c
     else if( const sal_Int16* pnValue = GetInteger() )
         rDoc.setNumericCell(rScPos, *pnValue);
     else if( const bool* pbValue = GetBool() )
-        lclSetValue( rRoot, rScPos, *pbValue ? 1.0 : 0.0, NUMBERFORMAT_LOGICAL );
+        lclSetValue( rRoot, rScPos, *pbValue ? 1.0 : 0.0, css::util::NumberFormat::LOGICAL );
     else if( const DateTime* pDateTime = GetDateTime() )
     {
         // set number format date, time, or date/time, depending on the value
         double fValue = rRoot.GetDoubleFromDateTime( *pDateTime );
         double fInt = 0.0;
         double fFrac = modf( fValue, &fInt );
-        short nFormatType = ((fFrac == 0.0) && (fInt != 0.0)) ? NUMBERFORMAT_DATE :
-            ((fInt == 0.0) ? NUMBERFORMAT_TIME : NUMBERFORMAT_DATETIME);
+        short nFormatType = ((fFrac == 0.0) && (fInt != 0.0)) ? css::util::NumberFormat::DATE :
+            ((fInt == 0.0) ? css::util::NumberFormat::TIME : css::util::NumberFormat::DATETIME);
         lclSetValue( rRoot, rScPos, fValue, nFormatType );
     }
     else if( const sal_uInt16* pnError = GetError() )
@@ -120,7 +116,7 @@ void XclImpPCItem::WriteToSource( XclImpRoot& rRoot, const ScAddress& rScPos ) c
         double fValue;
         sal_uInt8 nErrCode = static_cast< sal_uInt8 >( *pnError );
         const ScTokenArray* pScTokArr = rRoot.GetOldFmlaConverter().GetBoolErr(
-            XclTools::ErrorToEnum( fValue, EXC_BOOLERR_ERROR, nErrCode ) );
+            XclTools::ErrorToEnum( fValue, true, nErrCode ) );
         ScFormulaCell* pCell = pScTokArr ? new ScFormulaCell(&rDoc.getDoc(), rScPos, *pScTokArr) : new ScFormulaCell(&rDoc.getDoc(), rScPos);
         pCell->SetHybridDouble( fValue );
         rDoc.setFormulaCell(rScPos, pCell);
@@ -162,19 +158,21 @@ void XclImpPCItem::ReadSxdatetime( XclImpStream& rStrm )
     OSL_ENSURE( rStrm.GetRecSize() == 8, "XclImpPCItem::ReadSxdatetime - wrong record size" );
     sal_uInt16 nYear, nMonth;
     sal_uInt8 nDay, nHour, nMin, nSec;
-    rStrm >> nYear >> nMonth >> nDay >> nHour >> nMin >> nSec;
-    SetDateTime( DateTime( Date( nDay, nMonth, nYear ), Time( nHour, nMin, nSec ) ) );
+    nYear = rStrm.ReaduInt16();
+    nMonth = rStrm.ReaduInt16();
+    nDay = rStrm.ReaduInt8();
+    nHour = rStrm.ReaduInt8();
+    nMin = rStrm.ReaduInt8();
+    nSec = rStrm.ReaduInt8();
+    SetDateTime( DateTime( Date( nDay, nMonth, nYear ), tools::Time( nHour, nMin, nSec ) ) );
 }
 
 void XclImpPCItem::ReadSxempty( XclImpStream& rStrm )
 {
-    (void)rStrm;    // avoid compiler warning
     OSL_ENSURE( rStrm.GetRecSize() == 0, "XclImpPCItem::ReadSxempty - wrong record size" );
     SetEmpty();
 }
 
-// ============================================================================
-
 XclImpPCField::XclImpPCField( const XclImpRoot& rRoot, XclImpPivotCache& rPCache, sal_uInt16 nFieldIdx ) :
     XclPCField( EXC_PCFIELD_UNKNOWN, nFieldIdx ),
     XclImpRoot( rRoot ),
@@ -204,19 +202,19 @@ const OUString& XclImpPCField::GetFieldName( const ScfStringVec& rVisNames ) con
 const XclImpPCField* XclImpPCField::GetGroupBaseField() const
 {
     OSL_ENSURE( IsGroupChildField(), "XclImpPCField::GetGroupBaseField - this field type does not have a base field" );
-    return IsGroupChildField() ? mrPCache.GetField( maFieldInfo.mnGroupBase ) : 0;
+    return IsGroupChildField() ? mrPCache.GetField( maFieldInfo.mnGroupBase ) : nullptr;
 }
 
 const XclImpPCItem* XclImpPCField::GetItem( sal_uInt16 nItemIdx ) const
 {
-    return (nItemIdx < maItems.size()) ? maItems[ nItemIdx ].get() : 0;
+    return (nItemIdx < maItems.size()) ? maItems[ nItemIdx ].get() : nullptr;
 }
 
 const XclImpPCItem* XclImpPCField::GetLimitItem( sal_uInt16 nItemIdx ) const
 {
     OSL_ENSURE( nItemIdx < 3, "XclImpPCField::GetLimitItem - invalid item index" );
     OSL_ENSURE( nItemIdx < maNumGroupItems.size(), "XclImpPCField::GetLimitItem - no item found" );
-    return (nItemIdx < maNumGroupItems.size()) ? maNumGroupItems[ nItemIdx ].get() : 0;
+    return (nItemIdx < maNumGroupItems.size()) ? maNumGroupItems[ nItemIdx ].get() : nullptr;
 }
 
 void XclImpPCField::WriteFieldNameToSource( SCCOL nScCol, SCTAB nScTab )
@@ -382,7 +380,7 @@ void XclImpPCField::ReadSxgroupinfo( XclImpStream& rStrm )
     size_t nSize = rStrm.GetRecLeft() / 2;
     maGroupOrder.resize( nSize, 0 );
     for( size_t nIdx = 0; nIdx < nSize; ++nIdx )
-        rStrm >> maGroupOrder[ nIdx ];
+        maGroupOrder[ nIdx ] = rStrm.ReaduInt16();
 }
 
 // grouping -------------------------------------------------------------------
@@ -414,7 +412,7 @@ void XclImpPCField::ConvertStdGroupField( ScDPSaveData& rSaveData, const ScfStri
             aGroupItems.reserve( maItems.size() );
             // initialize with own item names
             for( XclImpPCItemVec::const_iterator aIt = maItems.begin(), aEnd = maItems.end(); aIt != aEnd; ++aIt )
-                aGroupItems.push_back( ScDPSaveGroupItem( (*aIt)->ConvertToText() ) );
+                aGroupItems.emplace_back( (*aIt)->ConvertToText() );
 
             // *** iterate over all base items, set their names at corresponding own items ***
             for( sal_uInt16 nItemIdx = 0, nItemCount = static_cast< sal_uInt16 >( maGroupOrder.size() ); nItemIdx < nItemCount; ++nItemIdx )
@@ -488,10 +486,10 @@ void XclImpPCField::ConvertDateGroupField( ScDPSaveData& rSaveData, const ScfStr
 ScDPNumGroupInfo XclImpPCField::GetScNumGroupInfo() const
 {
     ScDPNumGroupInfo aNumInfo;
-    aNumInfo.mbEnable = sal_True;
+    aNumInfo.mbEnable = true;
     aNumInfo.mbDateValues = false;
-    aNumInfo.mbAutoStart = sal_True;
-    aNumInfo.mbAutoEnd = sal_True;
+    aNumInfo.mbAutoStart = true;
+    aNumInfo.mbAutoEnd = true;
 
     if( const double* pfMinValue = GetNumGroupLimit( EXC_SXFIELD_INDEX_MIN ) )
     {
@@ -512,10 +510,10 @@ ScDPNumGroupInfo XclImpPCField::GetScNumGroupInfo() const
 ScDPNumGroupInfo XclImpPCField::GetScDateGroupInfo() const
 {
     ScDPNumGroupInfo aDateInfo;
-    aDateInfo.mbEnable = sal_True;
+    aDateInfo.mbEnable = true;
     aDateInfo.mbDateValues = false;
-    aDateInfo.mbAutoStart = sal_True;
-    aDateInfo.mbAutoEnd = sal_True;
+    aDateInfo.mbAutoStart = true;
+    aDateInfo.mbAutoEnd = true;
 
     if( const DateTime* pMinDate = GetDateGroupLimit( EXC_SXFIELD_INDEX_MIN ) )
     {
@@ -531,7 +529,7 @@ ScDPNumGroupInfo XclImpPCField::GetScDateGroupInfo() const
     if( const sal_Int16* pnStepValue = GetDateGroupStep() )
     {
         aDateInfo.mfStep = *pnStepValue;
-        aDateInfo.mbDateValues = sal_True;
+        aDateInfo.mbDateValues = true;
     }
 
     return aDateInfo;
@@ -545,7 +543,7 @@ const double* XclImpPCField::GetNumGroupLimit( sal_uInt16 nLimitIdx ) const
         OSL_ENSURE( pItem->GetDouble(), "XclImpPCField::GetNumGroupLimit - SXDOUBLE item expected" );
         return pItem->GetDouble();
     }
-    return 0;
+    return nullptr;
 }
 
 const DateTime* XclImpPCField::GetDateGroupLimit( sal_uInt16 nLimitIdx ) const
@@ -556,7 +554,7 @@ const DateTime* XclImpPCField::GetDateGroupLimit( sal_uInt16 nLimitIdx ) const
         OSL_ENSURE( pItem->GetDateTime(), "XclImpPCField::GetDateGroupLimit - SXDATETIME item expected" );
         return pItem->GetDateTime();
     }
-    return 0;
+    return nullptr;
 }
 
 const sal_Int16* XclImpPCField::GetDateGroupStep() const
@@ -574,16 +572,14 @@ const sal_Int16* XclImpPCField::GetDateGroupStep() const
                 {
                     OSL_ENSURE( *pnStep > 0, "XclImpPCField::GetDateGroupStep - invalid step count" );
                     // return nothing for step count 1 - this is also a standard date group in Excel
-                    return (*pnStep > 1) ? pnStep : 0;
+                    return (*pnStep > 1) ? pnStep : nullptr;
                 }
             }
         }
     }
-    return 0;
+    return nullptr;
 }
 
-// ============================================================================
-
 XclImpPivotCache::XclImpPivotCache( const XclImpRoot& rRoot ) :
     XclImpRoot( rRoot ),
     maSrcRange( ScAddress::INITIALIZE_INVALID ),
@@ -599,26 +595,21 @@ XclImpPivotCache::~XclImpPivotCache()
 
 // data access ----------------------------------------------------------------
 
-sal_uInt16 XclImpPivotCache::GetFieldCount() const
-{
-    return static_cast< sal_uInt16 >( maFields.size() );
-}
-
 const XclImpPCField* XclImpPivotCache::GetField( sal_uInt16 nFieldIdx ) const
 {
-    return (nFieldIdx < maFields.size()) ? maFields[ nFieldIdx ].get() : 0;
+    return (nFieldIdx < maFields.size()) ? maFields[ nFieldIdx ].get() : nullptr;
 }
 
 // records --------------------------------------------------------------------
 
 void XclImpPivotCache::ReadSxidstm( XclImpStream& rStrm )
 {
-    rStrm >> mnStrmId;
+    mnStrmId = rStrm.ReaduInt16();
 }
 
 void XclImpPivotCache::ReadSxvs( XclImpStream& rStrm )
 {
-    rStrm >> mnSrcType;
+    mnSrcType = rStrm.ReaduInt16();
     GetTracer().TracePivotDataSource( mnSrcType != EXC_SXVS_SHEET );
 }
 
@@ -652,15 +643,15 @@ void XclImpPivotCache::ReadDConName( XclImpStream& rStrm )
     // indicates that the name has a workbook scope.  For now, we only support
     // internal defined name with a workbook scope.
     sal_uInt16 nFlag;
-    rStrm >> nFlag;
+    nFlag = rStrm.ReaduInt16();
     mbSelfRef = (nFlag == 0);
 
     if (!mbSelfRef)
         // External name is not supported yet.
-        maSrcRangeName = OUString();
+        maSrcRangeName.clear();
 }
 
-void XclImpPivotCache::ReadPivotCacheStream( XclImpStream& rStrm )
+void XclImpPivotCache::ReadPivotCacheStream( const XclImpStream& rStrm )
 {
     if( (mnSrcType != EXC_SXVS_SHEET) && (mnSrcType != EXC_SXVS_EXTERN) )
         return;
@@ -705,7 +696,7 @@ void XclImpPivotCache::ReadPivotCacheStream( XclImpStream& rStrm )
 
         nScTab = rDoc.GetTableCount();
         rDoc.MakeTable( nScTab );
-        OUStringBuffer aDummyName(OUString("DPCache"));
+        OUStringBuffer aDummyName("DPCache");
         if( maTabName.getLength() > 0 )
             aDummyName.append( '_' ).append( maTabName );
         OUString aName = aDummyName.makeStringAndClear();
@@ -717,9 +708,9 @@ void XclImpPivotCache::ReadPivotCacheStream( XclImpStream& rStrm )
     }
 
     // open pivot cache storage stream
-    SotStorageRef xSvStrg = OpenStorage( EXC_STORAGE_PTCACHE );
-    SotStorageStreamRef xSvStrm = OpenStream( xSvStrg, ScfTools::GetHexStr( mnStrmId ) );
-    if( !xSvStrm.Is() )
+    tools::SvRef<SotStorage> xSvStrg = OpenStorage( EXC_STORAGE_PTCACHE );
+    tools::SvRef<SotStorageStream> xSvStrm = OpenStream( xSvStrg, ScfTools::GetHexStr( mnStrmId ) );
+    if( !xSvStrm.is() )
         return;
 
     // create Excel record stream object
@@ -747,7 +738,7 @@ void XclImpPivotCache::ReadPivotCacheStream( XclImpStream& rStrm )
             case EXC_ID_SXFIELD:
             {
                 xCurrField.reset();
-                sal_uInt16 nNewFieldIdx = GetFieldCount();
+                sal_uInt16 nNewFieldIdx = static_cast< sal_uInt16 >( maFields.size() );
                 if( nNewFieldIdx < EXC_PC_MAXFIELDCOUNT )
                 {
                     xCurrField.reset( new XclImpPCField( GetRoot(), *this, nNewFieldIdx ) );
@@ -837,14 +828,14 @@ void XclImpPivotCache::ReadPivotCacheStream( XclImpStream& rStrm )
             break;
 
             default:
-                OSL_TRACE( "XclImpPivotCache::ReadPivotCacheStream - unknown record 0x%04hX", aPCStrm.GetRecId() );
+                SAL_WARN("sc.filter",  "XclImpPivotCache::ReadPivotCacheStream - unknown record 0x" << std::hex << aPCStrm.GetRecId() );
         }
     }
 
     OSL_ENSURE( maPCInfo.mnTotalFields == maFields.size(),
         "XclImpPivotCache::ReadPivotCacheStream - field count mismatch" );
 
-    if (HasCacheRecords())
+    if (static_cast<bool>(maPCInfo.mnFlags & EXC_SXDB_SAVEDATA))
     {
         SCROW nNewEnd = maSrcRange.aStart.Row() + maPCInfo.mnSrcRecs;
         maSrcRange.aEnd.SetRow(nNewEnd);
@@ -862,11 +853,6 @@ void XclImpPivotCache::ReadPivotCacheStream( XclImpStream& rStrm )
     }
 }
 
-bool XclImpPivotCache::HasCacheRecords() const
-{
-    return static_cast<bool>(maPCInfo.mnFlags & EXC_SXDB_SAVEDATA);
-}
-
 bool XclImpPivotCache::IsRefreshOnLoad() const
 {
     return static_cast<bool>(maPCInfo.mnFlags & EXC_SXDB_REFRESH_LOAD);
@@ -880,9 +866,7 @@ bool XclImpPivotCache::IsValid() const
     return maSrcRange.IsValid();
 }
 
-// ============================================================================
 // Pivot table
-// ============================================================================
 
 XclImpPTItem::XclImpPTItem( const XclImpPCField* pCacheField ) :
     mpCacheField( pCacheField )
@@ -893,9 +877,52 @@ const OUString* XclImpPTItem::GetItemName() const
 {
     if( mpCacheField )
         if( const XclImpPCItem* pCacheItem = mpCacheField->GetItem( maItemInfo.mnCacheIdx ) )
-            //! TODO: use XclImpPCItem::ConvertToText(), if all conversions are available
-            return pCacheItem->IsEmpty() ? NULL : pCacheItem->GetText();
-    return 0;
+            //TODO: use XclImpPCItem::ConvertToText(), if all conversions are available
+            return pCacheItem->IsEmpty() ? nullptr : pCacheItem->GetText();
+    return nullptr;
+}
+
+std::pair<bool, OUString> XclImpPTItem::GetItemName(const ScDPSaveDimension& rSaveDim, ScDPObject* pObj, const XclImpRoot& rRoot) const
+{
+    if(!mpCacheField)
+        return std::pair<bool, OUString>(false, OUString());
+
+    const XclImpPCItem* pCacheItem = mpCacheField->GetItem( maItemInfo.mnCacheIdx );
+    if(!pCacheItem)
+        return std::pair<bool, OUString>(false, OUString());
+
+    OUString sItemName;
+    if(pCacheItem->GetType() == EXC_PCITEM_TEXT || pCacheItem->GetType() == EXC_PCITEM_ERROR)
+    {
+        const OUString* pItemName = pCacheItem->GetText();
+        if(!pItemName)
+            return std::pair<bool, OUString>(false, OUString());
+        sItemName = *pItemName;
+    }
+    else if (pCacheItem->GetType() == EXC_PCITEM_DOUBLE)
+    {
+        sItemName = pObj->GetFormattedString(rSaveDim.GetName(), *pCacheItem->GetDouble());
+    }
+    else if (pCacheItem->GetType() == EXC_PCITEM_INTEGER)
+    {
+        sItemName = pObj->GetFormattedString(rSaveDim.GetName(), static_cast<double>(*pCacheItem->GetInteger()));
+    }
+    else if (pCacheItem->GetType() == EXC_PCITEM_BOOL)
+    {
+        sItemName = pObj->GetFormattedString(rSaveDim.GetName(), static_cast<double>(*pCacheItem->GetBool()));
+    }
+    else if (pCacheItem->GetType() == EXC_PCITEM_DATETIME)
+    {
+        sItemName = pObj->GetFormattedString(rSaveDim.GetName(), rRoot.GetDoubleFromDateTime(*pCacheItem->GetDateTime()));
+    }
+    else if (pCacheItem->GetType() == EXC_PCITEM_EMPTY)
+    {
+        // sItemName is an empty string
+    }
+    else // EXC_PCITEM_INVALID
+        return std::pair<bool, OUString>(false, OUString());
+
+    return std::pair<bool, OUString>(true, sItemName);
 }
 
 void XclImpPTItem::ReadSxvi( XclImpStream& rStrm )
@@ -903,20 +930,23 @@ void XclImpPTItem::ReadSxvi( XclImpStream& rStrm )
     rStrm >> maItemInfo;
 }
 
-void XclImpPTItem::ConvertItem( ScDPSaveDimension& rSaveDim ) const
+void XclImpPTItem::ConvertItem( ScDPSaveDimension& rSaveDim, ScDPObject* pObj, const XclImpRoot& rRoot ) const
 {
-    if (const OUString* pItemName = GetItemName())
+    // Find member and set properties
+    std::pair<bool, OUString> aReturnedName = GetItemName(rSaveDim, pObj, rRoot);
+    if(aReturnedName.first)
     {
-        ScDPSaveMember& rMember = *rSaveDim.GetMemberByName( *pItemName );
-        rMember.SetIsVisible( !::get_flag( maItemInfo.mnFlags, EXC_SXVI_HIDDEN ) );
-        rMember.SetShowDetails( !::get_flag( maItemInfo.mnFlags, EXC_SXVI_HIDEDETAIL ) );
-        if (maItemInfo.HasVisName())
-            rMember.SetLayoutName(*maItemInfo.GetVisName());
+        ScDPSaveMember* pMember = rSaveDim.GetExistingMemberByName(aReturnedName.second);
+        if(pMember)
+        {
+            pMember->SetIsVisible( !::get_flag( maItemInfo.mnFlags, EXC_SXVI_HIDDEN ) );
+            pMember->SetShowDetails( !::get_flag( maItemInfo.mnFlags, EXC_SXVI_HIDEDETAIL ) );
+            if (maItemInfo.HasVisName())
+                pMember->SetLayoutName(*maItemInfo.GetVisName());
+        }
     }
 }
 
-// ============================================================================
-
 XclImpPTField::XclImpPTField( const XclImpPivotTable& rPTable, sal_uInt16 nCacheIdx ) :
     mrPTable( rPTable )
 {
@@ -928,7 +958,7 @@ XclImpPTField::XclImpPTField( const XclImpPivotTable& rPTable, sal_uInt16 nCache
 const XclImpPCField* XclImpPTField::GetCacheField() const
 {
     XclImpPivotCacheRef xPCache = mrPTable.GetPivotCache();
-    return xPCache ? xPCache->GetField( maFieldInfo.mnCacheIdx ) : 0;
+    return xPCache ? xPCache->GetField( maFieldInfo.mnCacheIdx ) : nullptr;
 }
 
 OUString XclImpPTField::GetFieldName() const
@@ -945,13 +975,13 @@ OUString XclImpPTField::GetVisFieldName() const
 
 const XclImpPTItem* XclImpPTField::GetItem( sal_uInt16 nItemIdx ) const
 {
-    return (nItemIdx < maItems.size()) ? maItems[ nItemIdx ].get() : 0;
+    return (nItemIdx < maItems.size()) ? maItems[ nItemIdx ].get() : nullptr;
 }
 
 const OUString* XclImpPTField::GetItemName( sal_uInt16 nItemIdx ) const
 {
     const XclImpPTItem* pItem = GetItem( nItemIdx );
-    return pItem ? pItem->GetItemName() : 0;
+    return pItem ? pItem->GetItemName() : nullptr;
 }
 
 // records --------------------------------------------------------------------
@@ -980,7 +1010,7 @@ void XclImpPTField::ConvertRowColField( ScDPSaveData& rSaveData ) const
     OSL_ENSURE( maFieldInfo.mnAxes & EXC_SXVD_AXIS_ROWCOL, "XclImpPTField::ConvertRowColField - no row/column field" );
     // special data orientation field?
     if( maFieldInfo.mnCacheIdx == EXC_SXIVD_DATA )
-        rSaveData.GetDataLayoutDimension()->SetOrientation( static_cast< sal_uInt16 >( maFieldInfo.GetApiOrient( EXC_SXVD_AXIS_ROWCOL ) ) );
+        rSaveData.GetDataLayoutDimension()->SetOrientation( maFieldInfo.GetApiOrient( EXC_SXVD_AXIS_ROWCOL ) );
     else
         ConvertRCPField( rSaveData );
 }
@@ -995,12 +1025,7 @@ void XclImpPTField::SetPageFieldInfo( const XclPTPageFieldInfo& rPageInfo )
 void XclImpPTField::ConvertPageField( ScDPSaveData& rSaveData ) const
 {
     OSL_ENSURE( maFieldInfo.mnAxes & EXC_SXVD_AXIS_PAGE, "XclImpPTField::ConvertPageField - no page field" );
-    if( ScDPSaveDimension* pSaveDim = ConvertRCPField( rSaveData ) )
-    {
-        const OUString* pName = GetItemName( maPageInfo.mnSelItem );
-        if (pName)
-            pSaveDim->SetCurrentPage(pName);
-    }
+    ConvertRCPField( rSaveData );
 }
 
 // hidden fields --------------------------------------------------------------
@@ -1015,35 +1040,41 @@ void XclImpPTField::ConvertHiddenField( ScDPSaveData& rSaveData ) const
 
 bool XclImpPTField::HasDataFieldInfo() const
 {
-    return !maDataInfoList.empty();
+    return !maDataInfoVector.empty();
 }
 
 void XclImpPTField::AddDataFieldInfo( const XclPTDataFieldInfo& rDataInfo )
 {
     OSL_ENSURE( maFieldInfo.mnAxes & EXC_SXVD_AXIS_DATA, "XclImpPTField::AddDataFieldInfo - no data field" );
-    maDataInfoList.push_back( rDataInfo );
+    maDataInfoVector.push_back( rDataInfo );
 }
 
 void XclImpPTField::ConvertDataField( ScDPSaveData& rSaveData ) const
 {
     OSL_ENSURE( maFieldInfo.mnAxes & EXC_SXVD_AXIS_DATA, "XclImpPTField::ConvertDataField - no data field" );
-    OSL_ENSURE( !maDataInfoList.empty(), "XclImpPTField::ConvertDataField - no data field info" );
-    if (maDataInfoList.empty())
+    OSL_ENSURE( !maDataInfoVector.empty(), "XclImpPTField::ConvertDataField - no data field info" );
+    if (maDataInfoVector.empty())
         return;
 
     OUString aFieldName = GetFieldName();
     if (aFieldName.isEmpty())
         return;
 
-    XclPTDataFieldInfoList::const_iterator aIt = maDataInfoList.begin(), aEnd = maDataInfoList.end();
+    ScDPSaveDimension* pSaveDim = rSaveData.GetNewDimensionByName(aFieldName);
+    if (!pSaveDim)
+    {
+        SAL_WARN("sc.filter","XclImpPTField::ConvertDataField - field name not found: " << aFieldName);
+        return;
+    }
 
-    ScDPSaveDimension& rSaveDim = *rSaveData.GetNewDimensionByName(aFieldName);
-    ConvertDataField( rSaveDim, *aIt );
+    auto aIt = maDataInfoVector.begin(), aEnd = maDataInfoVector.end();
+
+    ConvertDataField( *pSaveDim, *aIt );
 
     // multiple data fields -> clone dimension
     for( ++aIt; aIt != aEnd; ++aIt )
     {
-        ScDPSaveDimension& rDupDim = rSaveData.DuplicateDimension( rSaveDim );
+        ScDPSaveDimension& rDupDim = rSaveData.DuplicateDimension( *pSaveDim );
         ConvertDataFieldInfo( rDupDim, *aIt );
     }
 }
@@ -1072,27 +1103,24 @@ static OUString lcl_convertExcelSubtotalName(const OUString& rName)
     return aBuf.makeStringAndClear();
 }
 
-ScDPSaveDimension* XclImpPTField::ConvertRCPField( ScDPSaveData& rSaveData ) const
+void XclImpPTField::ConvertRCPField( ScDPSaveData& rSaveData ) const
 {
     const OUString& rFieldName = GetFieldName();
     if( rFieldName.isEmpty() )
-        return 0;
+        return;
 
     const XclImpPCField* pCacheField = GetCacheField();
     if( !pCacheField || !pCacheField->IsSupportedField() )
-        return 0;
+        return;
 
     ScDPSaveDimension* pTest = rSaveData.GetNewDimensionByName(rFieldName);
     if (!pTest)
-        return NULL;
+        return;
 
     ScDPSaveDimension& rSaveDim = *pTest;
 
     // orientation
-    rSaveDim.SetOrientation( static_cast< sal_uInt16 >( maFieldInfo.GetApiOrient( EXC_SXVD_AXIS_ROWCOLPAGE ) ) );
-
-    // general field info
-    ConvertFieldInfo( rSaveDim );
+    rSaveDim.SetOrientation( maFieldInfo.GetApiOrient( EXC_SXVD_AXIS_ROWCOLPAGE ) );
 
     // visible name
     if (const OUString* pVisName = maFieldInfo.GetVisName())
@@ -1103,7 +1131,7 @@ ScDPSaveDimension* XclImpPTField::ConvertRCPField( ScDPSaveData& rSaveData ) con
     XclPTSubtotalVec aSubtotalVec;
     maFieldInfo.GetSubtotals( aSubtotalVec );
     if( !aSubtotalVec.empty() )
-        rSaveDim.SetSubTotals( static_cast< long >( aSubtotalVec.size() ), &aSubtotalVec[ 0 ] );
+        rSaveDim.SetSubTotals( aSubtotalVec );
 
     // sorting
     DataPilotFieldSortInfo aSortInfo;
@@ -1135,22 +1163,42 @@ ScDPSaveDimension* XclImpPTField::ConvertRCPField( ScDPSaveData& rSaveData ) con
         OUString aSubName = lcl_convertExcelSubtotalName(*maFieldExtInfo.mpFieldTotalName);
         rSaveDim.SetSubtotalName(aSubName);
     }
-
-    return &rSaveDim;
 }
 
-void XclImpPTField::ConvertFieldInfo( ScDPSaveDimension& rSaveDim ) const
+void XclImpPTField::ConvertFieldInfo( const ScDPSaveData& rSaveData, ScDPObject* pObj, const XclImpRoot& rRoot, bool bPageField ) const
 {
-    rSaveDim.SetShowEmpty( ::get_flag( maFieldExtInfo.mnFlags, EXC_SXVDEX_SHOWALL ) );
-    ConvertItems( rSaveDim );
+    const OUString& rFieldName = GetFieldName();
+    if( rFieldName.isEmpty() )
+        return;
+
+    const XclImpPCField* pCacheField = GetCacheField();
+    if( !pCacheField || !pCacheField->IsSupportedField() )
+        return;
+
+    ScDPSaveDimension* pSaveDim = rSaveData.GetExistingDimensionByName(rFieldName);
+    if (!pSaveDim)
+        return;
+
+    pSaveDim->SetShowEmpty( ::get_flag( maFieldExtInfo.mnFlags, EXC_SXVDEX_SHOWALL ) );
+    for( XclImpPTItemVec::const_iterator aIt = maItems.begin(), aEnd = maItems.end(); aIt != aEnd; ++aIt )
+        (*aIt)->ConvertItem( *pSaveDim, pObj, rRoot );
+
+    if(bPageField && maPageInfo.mnSelItem != EXC_SXPI_ALLITEMS)
+    {
+        const XclImpPTItem* pItem = GetItem( maPageInfo.mnSelItem );
+        if(pItem)
+        {
+            std::pair<bool, OUString> aReturnedName = pItem->GetItemName(*pSaveDim, pObj, rRoot);
+            if(aReturnedName.first)
+                pSaveDim->SetCurrentPage(&aReturnedName.second);
+        }
+    }
 }
 
 void XclImpPTField::ConvertDataField( ScDPSaveDimension& rSaveDim, const XclPTDataFieldInfo& rDataInfo ) const
 {
     // orientation
     rSaveDim.SetOrientation( DataPilotFieldOrientation_DATA );
-    // general field info
-    ConvertFieldInfo( rSaveDim );
     // extended data field info
     ConvertDataFieldInfo( rSaveDim, rDataInfo );
 }
@@ -1163,7 +1211,7 @@ void XclImpPTField::ConvertDataFieldInfo( ScDPSaveDimension& rSaveDim, const Xcl
         rSaveDim.SetLayoutName(*pVisName);
 
     // aggregation function
-    rSaveDim.SetFunction( static_cast< sal_uInt16 >( rDataInfo.GetApiAggFunc() ) );
+    rSaveDim.SetFunction( rDataInfo.GetApiAggFunc() );
 
     // result field reference
     sal_Int32 nRefType = rDataInfo.GetApiRefType();
@@ -1185,18 +1233,10 @@ void XclImpPTField::ConvertDataFieldInfo( ScDPSaveDimension& rSaveDim, const Xcl
     rSaveDim.SetReferenceValue(&aFieldRef);
 }
 
-void XclImpPTField::ConvertItems( ScDPSaveDimension& rSaveDim ) const
-{
-    for( XclImpPTItemVec::const_iterator aIt = maItems.begin(), aEnd = maItems.end(); aIt != aEnd; ++aIt )
-        (*aIt)->ConvertItem( rSaveDim );
-}
-
-// ============================================================================
-
 XclImpPivotTable::XclImpPivotTable( const XclImpRoot& rRoot ) :
     XclImpRoot( rRoot ),
     maDataOrientField( *this, EXC_SXIVD_DATA ),
-    mpDPObj(NULL)
+    mpDPObj(nullptr)
 {
 }
 
@@ -1214,20 +1254,20 @@ sal_uInt16 XclImpPivotTable::GetFieldCount() const
 const XclImpPTField* XclImpPivotTable::GetField( sal_uInt16 nFieldIdx ) const
 {
     return (nFieldIdx == EXC_SXIVD_DATA) ? &maDataOrientField :
-        ((nFieldIdx < maFields.size()) ? maFields[ nFieldIdx ].get() : 0);
+        ((nFieldIdx < maFields.size()) ? maFields[ nFieldIdx ].get() : nullptr);
 }
 
 XclImpPTField* XclImpPivotTable::GetFieldAcc( sal_uInt16 nFieldIdx )
 {
     // do not return maDataOrientField
-    return (nFieldIdx < maFields.size()) ? maFields[ nFieldIdx ].get() : 0;
+    return (nFieldIdx < maFields.size()) ? maFields[ nFieldIdx ].get() : nullptr;
 }
 
 const XclImpPTField* XclImpPivotTable::GetDataField( sal_uInt16 nDataFieldIdx ) const
 {
     if( nDataFieldIdx < maOrigDataFields.size() )
         return GetField( maOrigDataFields[ nDataFieldIdx ] );
-    return 0;
+    return nullptr;
 }
 
 OUString XclImpPivotTable::GetDataFieldName( sal_uInt16 nDataFieldIdx ) const
@@ -1285,7 +1325,7 @@ void XclImpPivotTable::ReadSxivd( XclImpStream& rStrm )
     mxCurrField.reset();
 
     // find the index vector to fill (row SXIVD doesn't exist without row fields)
-    ScfUInt16Vec* pFieldVec = 0;
+    ScfUInt16Vec* pFieldVec = nullptr;
     if( maRowFields.empty() && (maPTInfo.mnRowFields > 0) )
         pFieldVec = &maRowFields;
     else if( maColFields.empty() && (maPTInfo.mnColFields > 0) )
@@ -1299,7 +1339,7 @@ void XclImpPivotTable::ReadSxivd( XclImpStream& rStrm )
         for( sal_uInt16 nIdx = 0; nIdx < nSize; ++nIdx )
         {
             sal_uInt16 nFieldIdx;
-            rStrm >> nFieldIdx;
+            nFieldIdx = rStrm.ReaduInt16();
             pFieldVec->push_back( nFieldIdx );
 
             // set orientation at special data orientation field
@@ -1356,7 +1396,10 @@ void XclImpPivotTable::ReadSxViewEx9( XclImpStream& rStrm )
     rStrm >> maPTViewEx9Info;
 }
 
-// ----------------------------------------------------------------------------
+void XclImpPivotTable::ReadSxAddl( XclImpStream& rStrm )
+{
+    rStrm >> maPTAddlInfo;
+}
 
 void XclImpPivotTable::Convert()
 {
@@ -1371,6 +1414,8 @@ void XclImpPivotTable::Convert()
     aSaveData.SetColumnGrand( ::get_flag( maPTInfo.mnFlags, EXC_SXVIEW_COLGRAND ) );
     aSaveData.SetFilterButton( false );
     aSaveData.SetDrillDown( ::get_flag( maPTExtInfo.mnFlags, EXC_SXEX_DRILLDOWN ) );
+    aSaveData.SetIgnoreEmptyRows( false );
+    aSaveData.SetRepeatIfEmpty( false );
 
     // *** fields ***
 
@@ -1409,7 +1454,7 @@ void XclImpPivotTable::Convert()
     // *** insert into Calc document ***
 
     // create source descriptor
-    ScSheetSourceDesc aDesc(GetDocPtr());
+    ScSheetSourceDesc aDesc(&GetDocRef());
     const OUString& rSrcName = mxPCache->GetSourceRangeName();
     if (!rSrcName.isEmpty())
         // Range name is the data source.
@@ -1422,12 +1467,12 @@ void XclImpPivotTable::Convert()
     ScRange aOutRange( maOutScRange );
     if( !maPageFields.empty() )
     {
-        SCsROW nDecRows = ::std::min< SCsROW >( aOutRange.aStart.Row(), maPageFields.size() + 1 );
+        SCROW nDecRows = ::std::min< SCROW >( aOutRange.aStart.Row(), maPageFields.size() + 1 );
         aOutRange.aStart.IncRow( -nDecRows );
     }
 
     // create the DataPilot
-    ScDPObject* pDPObj = new ScDPObject( GetDocPtr() );
+    ScDPObject* pDPObj = new ScDPObject( &GetDocRef() );
     pDPObj->SetName( maPTInfo.maTableName );
     if (!maPTInfo.maDataName.isEmpty())
         aSaveData.GetDataLayoutDimension()->SetLayoutName(maPTInfo.maDataName);
@@ -1443,6 +1488,7 @@ void XclImpPivotTable::Convert()
     GetDoc().GetDPCollection()->InsertNewTable(pDPObj);
     mpDPObj = pDPObj;
 
+    ApplyFieldInfo();
     ApplyMergeFlags(aOutRange, aSaveData);
 }
 
@@ -1459,7 +1505,7 @@ void XclImpPivotTable::MaybeRefresh()
 
 void XclImpPivotTable::ApplyMergeFlags(const ScRange& rOutRange, const ScDPSaveData& rSaveData)
 {
-    // Apply merge flags for varoius datapilot controls.
+    // Apply merge flags for various datapilot controls.
 
     ScDPOutputGeometry aGeometry(rOutRange, false);
     aGeometry.setColumnFieldCount(maPTInfo.mnColFields);
@@ -1467,6 +1513,14 @@ void XclImpPivotTable::ApplyMergeFlags(const ScRange& rOutRange, const ScDPSaveD
     aGeometry.setDataFieldCount(maPTInfo.mnDataFields);
     aGeometry.setRowFieldCount(maPTInfo.mnRowFields);
 
+    // Make sure we set headerlayout when input file has additional raw header
+    if(maPTInfo.mnColFields == 0)
+    {
+        mpDPObj->SetHeaderLayout( maPTInfo.mnFirstHeadRow - 2 == static_cast<sal_uInt16>(aGeometry.getRowFieldHeaderRow()) );
+    }
+    aGeometry.setHeaderLayout(mpDPObj->GetHeaderLayout());
+    aGeometry.setCompactMode(maPTAddlInfo.mbCompactMode);
+
     ScDocument& rDoc = GetDoc();
 
     vector<const ScDPSaveDimension*> aFieldDims;
@@ -1476,12 +1530,12 @@ void XclImpPivotTable::ApplyMergeFlags(const ScRange& rOutRange, const ScDPSaveD
     vector<ScAddress>::const_iterator itr = aFieldBtns.begin(), itrEnd = aFieldBtns.end();
     for (; itr != itrEnd; ++itr)
     {
-        rDoc.ApplyFlagsTab(itr->Col(), itr->Row(), itr->Col(), itr->Row(), itr->Tab(), SC_MF_BUTTON);
+        rDoc.ApplyFlagsTab(itr->Col(), itr->Row(), itr->Col(), itr->Row(), itr->Tab(), ScMF::Button);
 
-        sal_uInt16 nMFlag = SC_MF_BUTTON_POPUP;
+        ScMF nMFlag = ScMF::ButtonPopup;
         OUString aName = rDoc.GetString(itr->Col(), itr->Row(), itr->Tab());
         if (rSaveData.HasInvisibleMember(aName))
-            nMFlag |= SC_MF_HIDDEN_MEMBER;
+            nMFlag |= ScMF::HiddenMember;
 
         rDoc.ApplyFlagsTab(itr->Col()+1, itr->Row(), itr->Col()+1, itr->Row(), itr->Tab(), nMFlag);
     }
@@ -1495,37 +1549,63 @@ void XclImpPivotTable::ApplyMergeFlags(const ScRange& rOutRange, const ScDPSaveD
         vector<const ScDPSaveDimension*>::const_iterator itDim = aFieldDims.begin();
         for (; itr != itrEnd; ++itr, ++itDim)
         {
-            sal_Int16 nMFlag = SC_MF_BUTTON;
+            ScMF nMFlag = ScMF::Button;
             const ScDPSaveDimension* pDim = *itDim;
             if (pDim->HasInvisibleMember())
-                nMFlag |= SC_MF_HIDDEN_MEMBER;
+                nMFlag |= ScMF::HiddenMember;
             if (!pDim->IsDataLayout())
-                nMFlag |= SC_MF_BUTTON_POPUP;
+                nMFlag |= ScMF::ButtonPopup;
             rDoc.ApplyFlagsTab(itr->Col(), itr->Row(), itr->Col(), itr->Row(), itr->Tab(), nMFlag);
         }
     }
 
     aGeometry.getRowFieldPositions(aFieldBtns);
     rSaveData.GetAllDimensionsByOrientation(sheet::DataPilotFieldOrientation_ROW, aFieldDims);
-    if (aFieldBtns.size() == aFieldDims.size())
+    if ((aFieldBtns.size() == aFieldDims.size()) || (maPTAddlInfo.mbCompactMode && aFieldBtns.size() == 1))
     {
         itr    = aFieldBtns.begin();
         itrEnd = aFieldBtns.end();
         vector<const ScDPSaveDimension*>::const_iterator itDim = aFieldDims.begin();
         for (; itr != itrEnd; ++itr, ++itDim)
         {
-            sal_Int16 nMFlag = SC_MF_BUTTON;
+            ScMF nMFlag = ScMF::Button;
             const ScDPSaveDimension* pDim = *itDim;
             if (pDim->HasInvisibleMember())
-                nMFlag |= SC_MF_HIDDEN_MEMBER;
+                nMFlag |= ScMF::HiddenMember;
             if (!pDim->IsDataLayout())
-                nMFlag |= SC_MF_BUTTON_POPUP;
+                nMFlag |= ScMF::ButtonPopup;
             rDoc.ApplyFlagsTab(itr->Col(), itr->Row(), itr->Col(), itr->Row(), itr->Tab(), nMFlag);
         }
     }
 }
 
-// ============================================================================
+
+void XclImpPivotTable::ApplyFieldInfo()
+{
+    mpDPObj->BuildAllDimensionMembers();
+    ScDPSaveData& rSaveData = *mpDPObj->GetSaveData();
+
+    // row fields
+    for( auto aIt = maRowFields.begin(), aEnd = maRowFields.end(); aIt != aEnd; ++aIt )
+        if( const XclImpPTField* pField = GetField( *aIt ) )
+            pField->ConvertFieldInfo( rSaveData, mpDPObj, *this );
+
+    // column fields
+    for( auto aIt = maColFields.begin(), aEnd = maColFields.end(); aIt != aEnd; ++aIt )
+        if( const XclImpPTField* pField = GetField( *aIt ) )
+            pField->ConvertFieldInfo( rSaveData, mpDPObj, *this );
+
+    // page fields
+    for( auto aIt = maPageFields.begin(), aEnd = maPageFields.end(); aIt != aEnd; ++aIt )
+        if( const XclImpPTField* pField = GetField( *aIt ) )
+            pField->ConvertFieldInfo( rSaveData, mpDPObj, *this, true );
+
+    // hidden fields
+    for( sal_uInt16 nField = 0, nCount = GetFieldCount(); nField < nCount; ++nField )
+        if( const XclImpPTField* pField = GetField( nField ) )
+            if (!pField->GetAxes())
+                pField->ConvertFieldInfo( rSaveData, mpDPObj, *this );
+}
 
 XclImpPivotTableManager::XclImpPivotTableManager( const XclImpRoot& rRoot ) :
     XclImpRoot( rRoot )
@@ -1628,9 +1708,13 @@ void XclImpPivotTableManager::ReadSxViewEx9( XclImpStream& rStrm )
         maPTables.back()->ReadSxViewEx9( rStrm );
 }
 
-// ----------------------------------------------------------------------------
+void XclImpPivotTableManager::ReadSxAddl( XclImpStream& rStrm )
+{
+    if( !maPTables.empty() )
+        maPTables.back()->ReadSxAddl( rStrm );
+}
 
-void XclImpPivotTableManager::ReadPivotCaches( XclImpStream& rStrm )
+void XclImpPivotTableManager::ReadPivotCaches( const XclImpStream& rStrm )
 {
     for( XclImpPivotCacheVec::iterator aIt = maPCaches.begin(), aEnd = maPCaches.end(); aIt != aEnd; ++aIt )
         (*aIt)->ReadPivotCacheStream( rStrm );
@@ -1648,6 +1732,4 @@ void XclImpPivotTableManager::MaybeRefreshPivotTables()
         (*aIt)->MaybeRefresh();
 }
 
-// ============================================================================
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
