@@ -17,7 +17,7 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "xlchart.hxx"
+#include <xlchart.hxx>
 
 #include <com/sun/star/container/XNameContainer.hpp>
 #include <com/sun/star/awt/Size.hpp>
@@ -45,10 +45,10 @@
 #include <svx/xbtmpit.hxx>
 #include <svx/unomid.hxx>
 #include <filter/msfilter/escherex.hxx>
-#include <editeng/memberids.hrc>
-#include "global.hxx"
-#include "xlroot.hxx"
-#include "xlstyle.hxx"
+#include <editeng/memberids.h>
+#include <global.hxx>
+#include <xlroot.hxx>
+#include <xlstyle.hxx>
 
 using namespace com::sun::star;
 using ::com::sun::star::uno::Any;
@@ -448,9 +448,8 @@ static const XclChFormatInfo spFmtInfos[] =
 
 XclChFormatInfoProvider::XclChFormatInfoProvider()
 {
-    const XclChFormatInfo* pEnd = STATIC_ARRAY_END( spFmtInfos );
-    for( const XclChFormatInfo* pIt = spFmtInfos; pIt != pEnd; ++pIt )
-        maInfoMap[ pIt->meObjType ] = pIt;
+    for(auto const &rIt : spFmtInfos)
+        maInfoMap[ rIt.meObjType ] = &rIt;
 }
 
 const XclChFormatInfo& XclChFormatInfoProvider::GetFormatInfo( XclChObjectType eObjType ) const
@@ -515,9 +514,8 @@ void XclChExtTypeInfo::Set( const XclChTypeInfo& rTypeInfo, bool b3dChart, bool
 
 XclChTypeInfoProvider::XclChTypeInfoProvider()
 {
-    const XclChTypeInfo* pEnd = STATIC_ARRAY_END( spTypeInfos );
-    for( const XclChTypeInfo* pIt = spTypeInfos; pIt != pEnd; ++pIt )
-        maInfoMap[ pIt->meTypeId ] = pIt;
+    for(const auto &rIt : spTypeInfos)
+        maInfoMap[ rIt.meTypeId ] = &rIt;
 }
 
 const XclChTypeInfo& XclChTypeInfoProvider::GetTypeInfo( XclChTypeId eTypeId ) const
@@ -529,27 +527,27 @@ const XclChTypeInfo& XclChTypeInfoProvider::GetTypeInfo( XclChTypeId eTypeId ) c
 
 const XclChTypeInfo& XclChTypeInfoProvider::GetTypeInfoFromRecId( sal_uInt16 nRecId ) const
 {
-    const XclChTypeInfo* pEnd = STATIC_ARRAY_END( spTypeInfos );
-    for( const XclChTypeInfo* pIt = spTypeInfos; pIt != pEnd; ++pIt )
-        if( pIt->mnRecId == nRecId )
-            return *pIt;
+    for(const auto &rIt : spTypeInfos)
+    {
+        if(rIt.mnRecId == nRecId)
+            return rIt;
+    }
     OSL_FAIL( "XclChTypeInfoProvider::GetTypeInfoFromRecId - unknown record id" );
     return GetTypeInfo( EXC_CHTYPEID_UNKNOWN );
 }
 
 const XclChTypeInfo& XclChTypeInfoProvider::GetTypeInfoFromService( const OUString& rServiceName ) const
 {
-    const XclChTypeInfo* pEnd = STATIC_ARRAY_END( spTypeInfos );
-    for( const XclChTypeInfo* pIt = spTypeInfos; pIt != pEnd; ++pIt )
-        if( rServiceName.equalsAscii( pIt->mpcServiceName ) )
-            return *pIt;
+    for(auto const &rIt : spTypeInfos)
+        if( rServiceName.equalsAscii( rIt.mpcServiceName ) )
+            return rIt;
     OSL_FAIL( "XclChTypeInfoProvider::GetTypeInfoFromService - unknown service name" );
     return GetTypeInfo( EXC_CHTYPEID_UNKNOWN );
 }
 
 // Property helpers ===========================================================
 
-XclChObjectTable::XclChObjectTable( Reference< XMultiServiceFactory > xFactory,
+XclChObjectTable::XclChObjectTable( Reference< XMultiServiceFactory > const & xFactory,
         const OUString& rServiceName, const OUString& rObjNameBase ) :
     mxFactory( xFactory ),
     maServiceName( rServiceName ),
@@ -859,7 +857,6 @@ void XclChPropSetHelper::ReadMarkerProperties(
         XclChMarkerFormat& rMarkerFmt, const ScfPropertySet& rPropSet, sal_uInt16 nFormatIdx )
 {
     namespace cssc = ::com::sun::star::chart2;
-    namespace cssa = ::com::sun::star::awt;
     cssc::Symbol aApiSymbol;
     if( rPropSet.GetProperty( aApiSymbol, EXC_CHPROP_SYMBOL ) )
     {
@@ -995,7 +992,6 @@ void XclChPropSetHelper::WriteAreaProperties( ScfPropertySet& rPropSet,
     namespace cssd = ::com::sun::star::drawing;
     cssd::FillStyle eFillStyle = cssd::FillStyle_NONE;
     Color aColor;
-    sal_Int16 nTransparency = 0;
 
     // fill color
     if( rAreaFmt.mnPattern != EXC_PATT_NONE )
@@ -1007,28 +1003,28 @@ void XclChPropSetHelper::WriteAreaProperties( ScfPropertySet& rPropSet,
     // write the properties
     ScfPropSetHelper& rAreaHlp = GetAreaHelper( ePropMode );
     rAreaHlp.InitializeWrite();
-    rAreaHlp << eFillStyle << aColor << nTransparency;
+    rAreaHlp << eFillStyle << aColor << sal_Int16(0)/*nTransparency*/;
     rAreaHlp.WriteToPropertySet( rPropSet );
 }
 
 void XclChPropSetHelper::WriteEscherProperties( ScfPropertySet& rPropSet,
-        XclChObjectTable& rGradientTable, XclChObjectTable& /*rHatchTable*/, XclChObjectTable& rBitmapTable,
+        XclChObjectTable& rGradientTable, XclChObjectTable& rBitmapTable,
         const XclChEscherFormat& rEscherFmt, const XclChPicFormat* pPicFmt,
         sal_uInt32 nDffFillType, XclChPropertyMode ePropMode )
 {
     if( rEscherFmt.mxItemSet )
     {
-        if( const XFillStyleItem* pStyleItem = static_cast< const XFillStyleItem* >( rEscherFmt.mxItemSet->GetItem( XATTR_FILLSTYLE, false ) ) )
+        if( const XFillStyleItem* pStyleItem = rEscherFmt.mxItemSet->GetItem<XFillStyleItem>( XATTR_FILLSTYLE, false ) )
         {
             switch( pStyleItem->GetValue() )
             {
                 case drawing::FillStyle_SOLID:
                     // #i84812# Excel 2007 writes Escher properties for solid fill
-                    if( const XFillColorItem* pColorItem = static_cast< const XFillColorItem* >( rEscherFmt.mxItemSet->GetItem( XATTR_FILLCOLOR, false ) ) )
+                    if( const XFillColorItem* pColorItem = rEscherFmt.mxItemSet->GetItem<XFillColorItem>( XATTR_FILLCOLOR, false ) )
                     {
                         namespace cssd = ::com::sun::star::drawing;
                         // get solid transparence too
-                        const XFillTransparenceItem* pTranspItem = static_cast< const XFillTransparenceItem* >( rEscherFmt.mxItemSet->GetItem( XATTR_FILLTRANSPARENCE, false ) );
+                        const XFillTransparenceItem* pTranspItem = rEscherFmt.mxItemSet->GetItem<XFillTransparenceItem>( XATTR_FILLTRANSPARENCE, false );
                         sal_uInt16 nTransp = pTranspItem ? pTranspItem->GetValue() : 0;
                         ScfPropSetHelper& rAreaHlp = GetAreaHelper( ePropMode );
                         rAreaHlp.InitializeWrite();
@@ -1037,7 +1033,7 @@ void XclChPropSetHelper::WriteEscherProperties( ScfPropertySet& rPropSet,
                     }
                 break;
                 case drawing::FillStyle_GRADIENT:
-                    if( const XFillGradientItem* pGradItem = static_cast< const XFillGradientItem* >( rEscherFmt.mxItemSet->GetItem( XATTR_FILLGRADIENT, false ) ) )
+                    if( const XFillGradientItem* pGradItem = rEscherFmt.mxItemSet->GetItem<XFillGradientItem>( XATTR_FILLGRADIENT, false ) )
                     {
                         Any aGradientAny;
                         if( pGradItem->QueryValue( aGradientAny, MID_FILLGRADIENT ) )
@@ -1055,7 +1051,7 @@ void XclChPropSetHelper::WriteEscherProperties( ScfPropertySet& rPropSet,
                     }
                 break;
                 case drawing::FillStyle_BITMAP:
-                    if( const XFillBitmapItem* pBmpItem = static_cast< const XFillBitmapItem* >( rEscherFmt.mxItemSet->GetItem( XATTR_FILLBITMAP, false ) ) )
+                    if( const XFillBitmapItem* pBmpItem = rEscherFmt.mxItemSet->GetItem<XFillBitmapItem>( XATTR_FILLBITMAP, false ) )
                     {
                         Any aBitmapAny;
                         if( pBmpItem->QueryValue( aBitmapAny, MID_GRAFURL ) )
@@ -1240,7 +1236,7 @@ XclChRootData::~XclChRootData()
 {
 }
 
-void XclChRootData::InitConversion( const XclRoot& rRoot, const Reference< XChartDocument >& rxChartDoc, const Rectangle& rChartRect )
+void XclChRootData::InitConversion( const XclRoot& rRoot, const Reference< XChartDocument >& rxChartDoc, const tools::Rectangle& rChartRect )
 {
     // remember chart document reference and chart shape position/size
     OSL_ENSURE( rxChartDoc.is(), "XclChRootData::InitConversion - missing chart document" );
