@@ -17,7 +17,7 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "scitems.hxx"
+#include <scitems.hxx>
 #include <comphelper/string.hxx>
 #include <editeng/eeitem.hxx>
 
@@ -28,6 +28,7 @@
 #include <editeng/boxitem.hxx>
 #include <editeng/brushitem.hxx>
 #include <editeng/colritem.hxx>
+#include <editeng/crossedoutitem.hxx>
 #include <editeng/fhgtitem.hxx>
 #include <editeng/fontitem.hxx>
 #include <editeng/postitem.hxx>
@@ -49,33 +50,33 @@
 #include <vcl/outdev.hxx>
 #include <stdio.h>
 
-#include "htmlexp.hxx"
-#include "filter.hxx"
-#include "global.hxx"
-#include "postit.hxx"
-#include "document.hxx"
-#include "attrib.hxx"
-#include "patattr.hxx"
-#include "stlpool.hxx"
-#include "scresid.hxx"
-#include "formulacell.hxx"
-#include "cellform.hxx"
-#include "docoptio.hxx"
-#include "editutil.hxx"
-#include "ftools.hxx"
-#include "cellvalue.hxx"
+#include <htmlexp.hxx>
+#include <filter.hxx>
+#include <global.hxx>
+#include <postit.hxx>
+#include <document.hxx>
+#include <attrib.hxx>
+#include <patattr.hxx>
+#include <stlpool.hxx>
+#include <scresid.hxx>
+#include <formulacell.hxx>
+#include <cellform.hxx>
+#include <docoptio.hxx>
+#include <editutil.hxx>
+#include <ftools.hxx>
+#include <cellvalue.hxx>
 
 #include <editeng/flditem.hxx>
 #include <editeng/borderline.hxx>
 #include <unotools/syslocale.hxx>
 
-// Without sc.hrc: error C2679: binary '=' : no operator defined which takes a
+// Without strings.hrc: error C2679: binary '=' : no operator defined which takes a
 // right-hand operand of type 'const class String (__stdcall *)(class ScResId)'
 // at
 // const String aStrTable( ScResId( SCSTR_TABLE ) ); aStrOut = aStrTable;
 // ?!???
-#include "sc.hrc"
-#include "globstr.hrc"
+#include <strings.hrc>
+#include <globstr.hrc>
 
 #include <com/sun/star/uno/Reference.h>
 #include <com/sun/star/document/XDocumentProperties.hpp>
@@ -87,15 +88,9 @@ using namespace ::com::sun::star;
 
 const static sal_Char sMyBegComment[]   = "<!-- ";
 const static sal_Char sMyEndComment[]   = " -->";
-const static sal_Char sFontFamily[]     = "font-family:";
-const static sal_Char sFontSize[]       = "font-size:";
 const static sal_Char sDisplay[]        = "display:";
 const static sal_Char sBorder[]         = "border:";
-const static sal_Char sPadding[]        = "padding:";
-const static sal_Char sPosition[]       = "position:";
 const static sal_Char sBackground[]     = "background:";
-const static sal_Char sWidth[]          = "width:";
-const static sal_Char sHeight[]         = "height:";
 
 const sal_uInt16 ScHTMLExport::nDefaultFontSize[SC_HTML_FONTSIZES] =
 {
@@ -131,14 +126,13 @@ const sal_Char ScHTMLExport::sIndentSource[nIndentMax+1] =
 
 #define GLOBSTR(id) ScGlobal::GetRscString( id )
 
-FltError ScFormatFilterPluginImpl::ScExportHTML( SvStream& rStrm, const OUString& rBaseURL, ScDocument* pDoc,
+void ScFormatFilterPluginImpl::ScExportHTML( SvStream& rStrm, const OUString& rBaseURL, ScDocument* pDoc,
         const ScRange& rRange, const rtl_TextEncoding /*eNach*/, bool bAll,
         const OUString& rStreamPath, OUString& rNonConvertibleChars, const OUString& rFilterOptions )
 {
     ScHTMLExport aEx( rStrm, rBaseURL, pDoc, rRange, bAll, rStreamPath, rFilterOptions );
-    FltError nErr = aEx.Write();
+    aEx.Write();
     rNonConvertibleChars = aEx.GetNonConvertibleChars();
-    return nErr;
 }
 
 static OString lcl_getColGroupString(sal_Int32 nSpan, sal_Int32 nWidth)
@@ -190,16 +184,12 @@ static void lcl_AddStamp( OUString& rStr, const OUString& rName,
 
 static OString lcl_makeHTMLColorTriplet(const Color& rColor)
 {
-    OStringBuffer aStr( "\"#" );
+    sal_Char    buf[24];
+
     // <font COLOR="#00FF40">hello</font>
-    sal_Char    buf[64];
-    sal_Char*   p = buf;
-    p += sprintf( p, "%02X", rColor.GetRed() );
-    p += sprintf( p, "%02X", rColor.GetGreen() );
-    p += sprintf( p, "%02X", rColor.GetBlue() );
-    aStr.append(buf);
-    aStr.append('\"');
-    return aStr.makeStringAndClear();
+    snprintf( buf, 24, "\"#%02X%02X%02X\"", rColor.GetRed(), rColor.GetGreen(), rColor.GetBlue() );
+
+    return OString(buf);
 }
 
 ScHTMLExport::ScHTMLExport( SvStream& rStrmP, const OUString& rBaseURL, ScDocument* pDocP,
@@ -215,7 +205,6 @@ ScHTMLExport::ScHTMLExport( SvStream& rStrmP, const OUString& rBaseURL, ScDocume
     bTabHasGraphics( false ),
     bTabAlignedLeft( false ),
     bCalcAsShown( pDocP->GetDocOptions().IsCalcAsShown() ),
-    bTableDataWidth( true ),
     bTableDataHeight( true ),
     mbSkipImages ( false ),
     mbSkipHeaderFooter( false )
@@ -253,18 +242,6 @@ ScHTMLExport::ScHTMLExport( SvStream& rStrmP, const OUString& rBaseURL, ScDocume
         if ( !IsEmptyTable( nTab ) )
             nUsedTables++;
     }
-
-    // Content-Id for Mail export?
-    SfxObjectShell* pDocSh = pDoc->GetDocumentShell();
-    if ( pDocSh )
-    {
-        const SfxPoolItem* pItem = pDocSh->GetItem( SID_ORIGURL );
-        if( pItem )
-        {
-            aCId = static_cast<const SfxStringItem *>(pItem)->GetValue();
-            OSL_ENSURE( !aCId.isEmpty(), "CID without length!" );
-        }
-    }
 }
 
 ScHTMLExport::~ScHTMLExport()
@@ -297,7 +274,7 @@ sal_uInt16 ScHTMLExport::ToPixel( sal_uInt16 nVal )
     if( nVal )
     {
         nVal = (sal_uInt16)pAppWin->LogicToPixel(
-                    Size( nVal, nVal ), MapMode( MAP_TWIP ) ).Width();
+                    Size( nVal, nVal ), MapMode( MapUnit::MapTwip ) ).Width();
         if( !nVal ) // If there's a Twip there should also be a Pixel
             nVal = 1;
     }
@@ -307,7 +284,7 @@ sal_uInt16 ScHTMLExport::ToPixel( sal_uInt16 nVal )
 Size ScHTMLExport::MMToPixel( const Size& rSize )
 {
     Size aSize( rSize );
-    aSize = pAppWin->LogicToPixel( rSize, MapMode( MAP_100TH_MM ) );
+    aSize = pAppWin->LogicToPixel( rSize, MapMode( MapUnit::Map100thMM ) );
     // If there's something there should also be a Pixel
     if ( !aSize.Width() && rSize.Width() )
         aSize.Width() = 1;
@@ -316,7 +293,7 @@ Size ScHTMLExport::MMToPixel( const Size& rSize )
     return aSize;
 }
 
-sal_uLong ScHTMLExport::Write()
+void ScHTMLExport::Write()
 {
     if (!mbSkipHeaderFooter)
     {
@@ -330,8 +307,6 @@ sal_uLong ScHTMLExport::Write()
     OUT_LF();
     if (!mbSkipHeaderFooter)
         TAG_OFF_LF( OOO_STRING_SVTOOLS_HTML_html );
-
-    return rStrm.GetError();
 }
 
 void ScHTMLExport::WriteHeader()
@@ -344,7 +319,6 @@ void ScHTMLExport::WriteHeader()
     }
     else
     {
-        using namespace ::com::sun::star;
         uno::Reference<document::XDocumentPropertiesSupplier> xDPS(
             pDoc->GetDocumentShell()->GetModel(), uno::UNO_QUERY_THROW);
         uno::Reference<document::XDocumentProperties> xDocProps
@@ -374,7 +348,8 @@ void ScHTMLExport::WriteHeader()
     rStrm.WriteCharPtr( OOO_STRING_SVTOOLS_HTML_body ).WriteCharPtr( "," ).WriteCharPtr( OOO_STRING_SVTOOLS_HTML_division ).WriteCharPtr( "," ).WriteCharPtr( OOO_STRING_SVTOOLS_HTML_table ).WriteCharPtr( "," )
        .WriteCharPtr( OOO_STRING_SVTOOLS_HTML_thead ).WriteCharPtr( "," ).WriteCharPtr( OOO_STRING_SVTOOLS_HTML_tbody ).WriteCharPtr( "," ).WriteCharPtr( OOO_STRING_SVTOOLS_HTML_tfoot ).WriteCharPtr( "," )
        .WriteCharPtr( OOO_STRING_SVTOOLS_HTML_tablerow ).WriteCharPtr( "," ).WriteCharPtr( OOO_STRING_SVTOOLS_HTML_tableheader ).WriteCharPtr( "," )
-       .WriteCharPtr( OOO_STRING_SVTOOLS_HTML_tabledata ).WriteCharPtr( "," ).WriteCharPtr( OOO_STRING_SVTOOLS_HTML_parabreak ).WriteCharPtr( " { " ).WriteCharPtr( sFontFamily );
+       .WriteCharPtr( OOO_STRING_SVTOOLS_HTML_tabledata ).WriteCharPtr( "," ).WriteCharPtr( OOO_STRING_SVTOOLS_HTML_parabreak )
+       .WriteCharPtr( " { " ).WriteCharPtr( "font-family:" );
     sal_Int32 nFonts = comphelper::string::getTokenCount(aHTMLStyle.aFontFamilyName, ';');
     if ( nFonts == 1 )
     {
@@ -386,7 +361,7 @@ void ScHTMLExport::WriteHeader()
     {   // Fontlist, VCL: Semicolon as separator
         // CSS1: Comma as separator and every single font name quoted
         const OUString& rList = aHTMLStyle.aFontFamilyName;
-        for ( sal_Int32 j = 0, nPos = 0; j < (sal_Int32) nFonts; j++ )
+        for ( sal_Int32 j = 0, nPos = 0; j < nFonts; j++ )
         {
             rStrm.WriteChar( '\"' );
             OUT_STR( rList.getToken( 0, ';', nPos ) );
@@ -395,7 +370,7 @@ void ScHTMLExport::WriteHeader()
                 rStrm.WriteCharPtr( ", " );
         }
     }
-    rStrm.WriteCharPtr( "; " ).WriteCharPtr( sFontSize )
+    rStrm.WriteCharPtr( "; " ).WriteCharPtr( "font-size:" )
        .WriteCharPtr( GetFontSizeCss( ( sal_uInt16 ) aHTMLStyle.nFontHeight ) ).WriteCharPtr( " }" );
 
     OUT_LF();
@@ -405,10 +380,10 @@ void ScHTMLExport::WriteHeader()
     rStrm.WriteCharPtr( OOO_STRING_SVTOOLS_HTML_anchor ).WriteCharPtr(".comment-indicator:hover")
        .WriteCharPtr(" + ").WriteCharPtr( OOO_STRING_SVTOOLS_HTML_comment2 ).WriteCharPtr(" { ")
        .WriteCharPtr(sBackground).WriteCharPtr("#ffd").WriteCharPtr("; ")
-       .WriteCharPtr(sPosition).WriteCharPtr("absolute").WriteCharPtr("; ")
+       .WriteCharPtr("position:").WriteCharPtr("absolute").WriteCharPtr("; ")
        .WriteCharPtr(sDisplay).WriteCharPtr("block").WriteCharPtr("; ")
        .WriteCharPtr(sBorder).WriteCharPtr("1px solid black").WriteCharPtr("; ")
-       .WriteCharPtr(sPadding).WriteCharPtr("0.5em").WriteCharPtr("; ")
+       .WriteCharPtr("padding:").WriteCharPtr("0.5em").WriteCharPtr("; ")
        .WriteCharPtr(" } ");
 
     OUT_LF();
@@ -418,8 +393,8 @@ void ScHTMLExport::WriteHeader()
         .WriteCharPtr(sBackground).WriteCharPtr("red").WriteCharPtr("; ")
         .WriteCharPtr(sDisplay).WriteCharPtr("inline-block").WriteCharPtr("; ")
         .WriteCharPtr(sBorder).WriteCharPtr("1px solid black").WriteCharPtr("; ")
-        .WriteCharPtr(sWidth).WriteCharPtr("0.5em").WriteCharPtr("; ")
-        .WriteCharPtr(sHeight).WriteCharPtr("0.5em").WriteCharPtr("; ")
+        .WriteCharPtr("width:").WriteCharPtr("0.5em").WriteCharPtr("; ")
+        .WriteCharPtr("height:").WriteCharPtr("0.5em").WriteCharPtr("; ")
         .WriteCharPtr(" } ");
 
     OUT_LF();
@@ -476,10 +451,10 @@ const SfxItemSet& ScHTMLExport::PageDefaults( SCTAB nTab )
     // remember defaults for compare in WriteCell
     if ( !aHTMLStyle.bInitialized )
     {
-        pStylePool->SetSearchMask( SFX_STYLE_FAMILY_PARA );
+        pStylePool->SetSearchMask( SfxStyleFamily::Para );
         pStyleSheet = pStylePool->Find(
                 ScGlobal::GetRscString(STR_STYLENAME_STANDARD),
-                SFX_STYLE_FAMILY_PARA );
+                SfxStyleFamily::Para );
         OSL_ENSURE( pStyleSheet, "ParaStyle not found! :-(" );
         if (!pStyleSheet)
             pStyleSheet = pStylePool->First();
@@ -499,15 +474,15 @@ const SfxItemSet& ScHTMLExport::PageDefaults( SCTAB nTab )
 
     // Page style sheet printer settings, e.g. for background graphics.
     // There's only one background graphic in HTML!
-    pStylePool->SetSearchMask( SFX_STYLE_FAMILY_PAGE );
-    pStyleSheet = pStylePool->Find( pDoc->GetPageStyle( nTab ), SFX_STYLE_FAMILY_PAGE );
+    pStylePool->SetSearchMask( SfxStyleFamily::Page );
+    pStyleSheet = pStylePool->Find( pDoc->GetPageStyle( nTab ), SfxStyleFamily::Page );
     OSL_ENSURE( pStyleSheet, "PageStyle not found! :-(" );
     if (!pStyleSheet)
         pStyleSheet = pStylePool->First();
     const SfxItemSet& rSet = pStyleSheet->GetItemSet();
     if ( !aHTMLStyle.bInitialized )
     {
-        const SvxBrushItem* pBrushItem = static_cast<const SvxBrushItem*>(&rSet.Get( ATTR_BACKGROUND ));
+        const SvxBrushItem* pBrushItem = &rSet.Get( ATTR_BACKGROUND );
         aHTMLStyle.aBackgroundColor = pBrushItem->GetColor();
         aHTMLStyle.bInitialized = true;
     }
@@ -535,37 +510,37 @@ OString ScHTMLExport::BorderToStyle(const char* pBorderName,
             append("px ");
         switch (pLine->GetBorderLineStyle())
         {
-            case table::BorderLineStyle::SOLID:
+            case SvxBorderLineStyle::SOLID:
                 aOut.append("solid");
                 break;
-            case table::BorderLineStyle::DOTTED:
+            case SvxBorderLineStyle::DOTTED:
                 aOut.append("dotted");
                 break;
-            case table::BorderLineStyle::DASHED:
-            case table::BorderLineStyle::DASH_DOT:
-            case table::BorderLineStyle::DASH_DOT_DOT:
+            case SvxBorderLineStyle::DASHED:
+            case SvxBorderLineStyle::DASH_DOT:
+            case SvxBorderLineStyle::DASH_DOT_DOT:
                 aOut.append("dashed");
                 break;
-            case table::BorderLineStyle::DOUBLE:
-            case table::BorderLineStyle::DOUBLE_THIN:
-            case table::BorderLineStyle::THINTHICK_SMALLGAP:
-            case table::BorderLineStyle::THINTHICK_MEDIUMGAP:
-            case table::BorderLineStyle::THINTHICK_LARGEGAP:
-            case table::BorderLineStyle::THICKTHIN_SMALLGAP:
-            case table::BorderLineStyle::THICKTHIN_MEDIUMGAP:
-            case table::BorderLineStyle::THICKTHIN_LARGEGAP:
+            case SvxBorderLineStyle::DOUBLE:
+            case SvxBorderLineStyle::DOUBLE_THIN:
+            case SvxBorderLineStyle::THINTHICK_SMALLGAP:
+            case SvxBorderLineStyle::THINTHICK_MEDIUMGAP:
+            case SvxBorderLineStyle::THINTHICK_LARGEGAP:
+            case SvxBorderLineStyle::THICKTHIN_SMALLGAP:
+            case SvxBorderLineStyle::THICKTHIN_MEDIUMGAP:
+            case SvxBorderLineStyle::THICKTHIN_LARGEGAP:
                 aOut.append("double");
                 break;
-            case table::BorderLineStyle::EMBOSSED:
+            case SvxBorderLineStyle::EMBOSSED:
                 aOut.append("ridge");
                 break;
-            case table::BorderLineStyle::ENGRAVED:
+            case SvxBorderLineStyle::ENGRAVED:
                 aOut.append("groove");
                 break;
-            case table::BorderLineStyle::OUTSET:
+            case SvxBorderLineStyle::OUTSET:
                 aOut.append("outset");
                 break;
-            case table::BorderLineStyle::INSET:
+            case SvxBorderLineStyle::INSET:
                 aOut.append("inset");
                 break;
             default:
@@ -589,7 +564,7 @@ OString ScHTMLExport::BorderToStyle(const char* pBorderName,
 void ScHTMLExport::WriteBody()
 {
     const SfxItemSet& rSet = PageDefaults( bAll ? 0 : aRange.aStart.Tab() );
-    const SvxBrushItem* pBrushItem = static_cast<const SvxBrushItem*>(&rSet.Get( ATTR_BACKGROUND ));
+    const SvxBrushItem* pBrushItem = &rSet.Get( ATTR_BACKGROUND );
 
     // default text color black
     if (!mbSkipHeaderFooter)
@@ -611,15 +586,13 @@ void ScHTMLExport::WriteBody()
                     {
                         // Save graphic as (JPG) file
                         aGrfNm = aStreamPath;
-                        sal_uInt16 nErr = XOutBitmap::WriteGraphic( *pGrf, aGrfNm,
-                            "JPG", XOUTBMP_USE_NATIVE_IF_POSSIBLE );
+                        ErrCode nErr = XOutBitmap::WriteGraphic( *pGrf, aGrfNm,
+                            "JPG", XOutFlags::UseNativeIfPossible );
                         if( !nErr ) // Contains errors, as we have nothing to output
                         {
                             aGrfNm = URIHelper::SmartRel2Abs(
                                     INetURLObject(aBaseURL),
                                     aGrfNm, URIHelper::GetMaybeFileHdl());
-                            if ( HasCId() )
-                                MakeCIdURL( aGrfNm );
                             aLink = aGrfNm;
                         }
                     }
@@ -627,11 +600,9 @@ void ScHTMLExport::WriteBody()
                 else
                 {
                     aGrfNm = aLink;
-                    if( bCopyLocalFileToINet || HasCId() )
+                    if( bCopyLocalFileToINet )
                     {
                         CopyLocalFileToINet( aGrfNm, aStreamPath );
-                        if ( HasCId() )
-                            MakeCIdURL( aGrfNm );
                     }
                     else
                         aGrfNm = URIHelper::SmartRel2Abs(
@@ -807,7 +778,6 @@ void ScHTMLExport::WriteTables()
         // IncIndent(1); TAG_ON_LF( OOO_STRING_SVTOOLS_HTML_tbody );
         // At least old (3.x, 4.x?) Netscape doesn't follow <TABLE COLS=n> and
         // <COL WIDTH=x> specified, but needs a width at every column.
-        bTableDataWidth = true;     // widths in first row
         bool bHasHiddenRows = pDoc->HasHiddenRows(nStartRow, nEndRow, nTab);
         for ( SCROW nRow=nStartRow; nRow<=nEndRow; nRow++ )
         {
@@ -830,7 +800,6 @@ void ScHTMLExport::WriteTables()
                 WriteCell( nCol2, nRow, nTab );
                 bTableDataHeight = false;
             }
-            bTableDataWidth = false;    // widths only in first row
 
             if ( nRow == nEndRow )
                 IncIndent(-1);
@@ -873,7 +842,7 @@ void ScHTMLExport::WriteCell( SCCOL nCol, SCROW nRow, SCTAB nTab )
     const ScPatternAttr* pAttr = pDoc->GetPattern( nCol, nRow, nTab );
     const SfxItemSet* pCondItemSet = pDoc->GetCondResult( nCol, nRow, nTab );
 
-    const ScMergeFlagAttr& rMergeFlagAttr = static_cast<const ScMergeFlagAttr&>( pAttr->GetItem( ATTR_MERGE_FLAG, pCondItemSet ) );
+    const ScMergeFlagAttr& rMergeFlagAttr = pAttr->GetItem( ATTR_MERGE_FLAG, pCondItemSet );
     if ( rMergeFlagAttr.IsOverlapped() )
         return ;
 
@@ -900,7 +869,7 @@ void ScHTMLExport::WriteCell( SCCOL nCol, SCROW nRow, SCTAB nTab )
 
     ScRefCellValue aCell(*pDoc, aPos);
 
-    sal_uLong nFormat = pAttr->GetNumberFormat( pFormatter );
+    sal_uInt32 nFormat = pAttr->GetNumberFormat( pFormatter );
     bool bValueData = aCell.hasNumeric();
     SvtScriptType nScriptType = SvtScriptType::NONE;
     if (!aCell.isEmpty())
@@ -934,7 +903,7 @@ void ScHTMLExport::WriteCell( SCCOL nCol, SCROW nRow, SCTAB nTab )
     const sal_Char* pChar;
     sal_uInt16 nHeightPixel;
 
-    const ScMergeAttr& rMergeAttr = static_cast<const ScMergeAttr&>( pAttr->GetItem( ATTR_MERGE, pCondItemSet ) );
+    const ScMergeAttr& rMergeAttr = pAttr->GetItem( ATTR_MERGE, pCondItemSet );
     if ( pGraphEntry || rMergeAttr.IsMerged() )
     {
         SCCOL nC, jC;
@@ -942,7 +911,7 @@ void ScHTMLExport::WriteCell( SCCOL nCol, SCROW nRow, SCTAB nTab )
         sal_uLong v;
         if ( pGraphEntry )
             nC = std::max( SCCOL(pGraphEntry->aRange.aEnd.Col() - nCol + 1),
-                SCCOL(rMergeAttr.GetColMerge()) );
+                           rMergeAttr.GetColMerge() );
         else
             nC = rMergeAttr.GetColMerge();
         if ( nC > 1 )
@@ -956,7 +925,7 @@ void ScHTMLExport::WriteCell( SCCOL nCol, SCROW nRow, SCTAB nTab )
 
         if ( pGraphEntry )
             nR = std::max( SCROW(pGraphEntry->aRange.aEnd.Row() - nRow + 1),
-                SCROW(rMergeAttr.GetRowMerge()) );
+                           rMergeAttr.GetRowMerge() );
         else
             nR = rMergeAttr.GetRowMerge();
         if ( nR > 1 )
@@ -996,20 +965,23 @@ void ScHTMLExport::WriteCell( SCCOL nCol, SCROW nRow, SCTAB nTab )
         pAttr->GetItem( ScGlobal::GetScriptedWhichID( nScriptType,
                     ATTR_FONT_POSTURE), pCondItemSet) );
 
-    const SvxUnderlineItem& rUnderlineItem = static_cast<const SvxUnderlineItem&>(
-        pAttr->GetItem( ATTR_FONT_UNDERLINE, pCondItemSet ) );
+    const SvxUnderlineItem& rUnderlineItem =
+        pAttr->GetItem( ATTR_FONT_UNDERLINE, pCondItemSet );
 
-    const SvxColorItem& rColorItem = static_cast<const SvxColorItem&>( pAttr->GetItem(
-            ATTR_FONT_COLOR, pCondItemSet ) );
+    const SvxCrossedOutItem& rCrossedOutItem =
+        pAttr->GetItem( ATTR_FONT_CROSSEDOUT, pCondItemSet );
 
-    const SvxHorJustifyItem& rHorJustifyItem = static_cast<const SvxHorJustifyItem&>(
-        pAttr->GetItem( ATTR_HOR_JUSTIFY, pCondItemSet ) );
+    const SvxColorItem& rColorItem = pAttr->GetItem(
+            ATTR_FONT_COLOR, pCondItemSet );
 
-    const SvxVerJustifyItem& rVerJustifyItem = static_cast<const SvxVerJustifyItem&>(
-        pAttr->GetItem( ATTR_VER_JUSTIFY, pCondItemSet ) );
+    const SvxHorJustifyItem& rHorJustifyItem =
+        pAttr->GetItem( ATTR_HOR_JUSTIFY, pCondItemSet );
 
-    const SvxBrushItem& rBrushItem = static_cast<const SvxBrushItem&>( pAttr->GetItem(
-            ATTR_BACKGROUND, pCondItemSet ) );
+    const SvxVerJustifyItem& rVerJustifyItem =
+        pAttr->GetItem( ATTR_VER_JUSTIFY, pCondItemSet );
+
+    const SvxBrushItem& rBrushItem = pAttr->GetItem(
+            ATTR_BACKGROUND, pCondItemSet );
 
     Color aBgColor;
     if ( rBrushItem.GetColor().GetTransparency() == 255 )
@@ -1017,10 +989,11 @@ void ScHTMLExport::WriteCell( SCCOL nCol, SCROW nRow, SCTAB nTab )
     else
         aBgColor = rBrushItem.GetColor();
 
-    bool bBold          = ( WEIGHT_BOLD     <= rWeightItem.GetWeight() );
-    bool bItalic        = ( ITALIC_NONE     != rPostureItem.GetPosture() );
-    bool bUnderline     = ( UNDERLINE_NONE  != rUnderlineItem.GetLineStyle() );
-    bool bSetFontColor  = ( COL_AUTO        != rColorItem.GetValue().GetColor() );  // default is AUTO now
+    bool bBold          = ( WEIGHT_BOLD      <= rWeightItem.GetWeight() );
+    bool bItalic        = ( ITALIC_NONE      != rPostureItem.GetPosture() );
+    bool bUnderline     = ( LINESTYLE_NONE   != rUnderlineItem.GetLineStyle() );
+    bool bCrossedOut    = ( STRIKEOUT_SINGLE <= rCrossedOutItem.GetStrikeout() );
+    bool bSetFontColor  = ( COL_AUTO         != rColorItem.GetValue().GetColor() );  // default is AUTO now
     bool bSetFontName   = ( aHTMLStyle.aFontFamilyName  != rFontItem.GetFamilyName() );
     sal_uInt16 nSetFontSizeNumber = 0;
     sal_uInt32 nFontHeight = rFontHeightItem.GetHeight();
@@ -1039,14 +1012,14 @@ void ScHTMLExport::WriteCell( SCCOL nCol, SCROW nRow, SCTAB nTab )
 
     switch( rHorJustifyItem.GetValue() )
     {
-        case SVX_HOR_JUSTIFY_STANDARD:
+        case SvxCellHorJustify::Standard:
             pChar = (bValueData ? OOO_STRING_SVTOOLS_HTML_AL_right : OOO_STRING_SVTOOLS_HTML_AL_left);
             break;
-        case SVX_HOR_JUSTIFY_CENTER:    pChar = OOO_STRING_SVTOOLS_HTML_AL_center;  break;
-        case SVX_HOR_JUSTIFY_BLOCK:     pChar = OOO_STRING_SVTOOLS_HTML_AL_justify; break;
-        case SVX_HOR_JUSTIFY_RIGHT:     pChar = OOO_STRING_SVTOOLS_HTML_AL_right;   break;
-        case SVX_HOR_JUSTIFY_LEFT:
-        case SVX_HOR_JUSTIFY_REPEAT:
+        case SvxCellHorJustify::Center:    pChar = OOO_STRING_SVTOOLS_HTML_AL_center;  break;
+        case SvxCellHorJustify::Block:     pChar = OOO_STRING_SVTOOLS_HTML_AL_justify; break;
+        case SvxCellHorJustify::Right:     pChar = OOO_STRING_SVTOOLS_HTML_AL_right;   break;
+        case SvxCellHorJustify::Left:
+        case SvxCellHorJustify::Repeat:
         default:                        pChar = OOO_STRING_SVTOOLS_HTML_AL_left;    break;
     }
 
@@ -1055,10 +1028,10 @@ void ScHTMLExport::WriteCell( SCCOL nCol, SCROW nRow, SCTAB nTab )
 
     switch( rVerJustifyItem.GetValue() )
     {
-        case SVX_VER_JUSTIFY_TOP:       pChar = OOO_STRING_SVTOOLS_HTML_VA_top;     break;
-        case SVX_VER_JUSTIFY_CENTER:    pChar = OOO_STRING_SVTOOLS_HTML_VA_middle;  break;
-        case SVX_VER_JUSTIFY_BOTTOM:    pChar = OOO_STRING_SVTOOLS_HTML_VA_bottom;  break;
-        case SVX_VER_JUSTIFY_STANDARD:
+        case SvxCellVerJustify::Top:       pChar = OOO_STRING_SVTOOLS_HTML_VA_top;     break;
+        case SvxCellVerJustify::Center:    pChar = OOO_STRING_SVTOOLS_HTML_VA_middle;  break;
+        case SvxCellVerJustify::Bottom:    pChar = OOO_STRING_SVTOOLS_HTML_VA_bottom;  break;
+        case SvxCellVerJustify::Standard:
         default:                        pChar = nullptr;
     }
     if ( pChar )
@@ -1122,6 +1095,7 @@ void ScHTMLExport::WriteCell( SCCOL nCol, SCROW nRow, SCTAB nTab )
     if ( bBold )        TAG_ON( OOO_STRING_SVTOOLS_HTML_bold );
     if ( bItalic )      TAG_ON( OOO_STRING_SVTOOLS_HTML_italic );
     if ( bUnderline )   TAG_ON( OOO_STRING_SVTOOLS_HTML_underline );
+    if ( bCrossedOut )  TAG_ON( OOO_STRING_SVTOOLS_HTML_strikethrough );
 
     if ( bSetFont )
     {
@@ -1140,7 +1114,7 @@ void ScHTMLExport::WriteCell( SCCOL nCol, SCROW nRow, SCTAB nTab )
             else
             {   // Font list, VCL: Semicolon as separator, HTML: Comma
                 const OUString& rList = rFontItem.GetFamilyName();
-                for ( sal_Int32 j = 0, nPos = 0; j < (sal_Int32)nFonts; j++ )
+                for ( sal_Int32 j = 0, nPos = 0; j < nFonts; j++ )
                 {
                     OString aTmpStr = HTMLOutFuncs::ConvertStringToHTML(
                         rList.getToken( 0, ';', nPos ), eDestEnc,
@@ -1181,7 +1155,7 @@ void ScHTMLExport::WriteCell( SCCOL nCol, SCROW nRow, SCTAB nTab )
             bFieldText = WriteFieldText(aCell.mpEditText);
             if ( bFieldText )
                 break;
-            //! else: fallthru
+            SAL_FALLTHROUGH;
         default:
             ScCellFormat::GetString(aCell, nFormat, aStrOut, &pColor, *pFormatter, pDoc);
     }
@@ -1194,8 +1168,7 @@ void ScHTMLExport::WriteCell( SCCOL nCol, SCROW nRow, SCTAB nTab )
         }
         else
         {
-            OUString aStr = aStrOut;
-            sal_Int32 nPos = aStr.indexOf( '\n' );
+            sal_Int32 nPos = aStrOut.indexOf( '\n' );
             if ( nPos == -1 )
             {
                 OUT_STR( aStrOut );
@@ -1205,13 +1178,13 @@ void ScHTMLExport::WriteCell( SCCOL nCol, SCROW nRow, SCTAB nTab )
                 sal_Int32 nStartPos = 0;
                 do
                 {
-                    OUString aSingleLine = aStr.copy( nStartPos, nPos - nStartPos );
+                    OUString aSingleLine = aStrOut.copy( nStartPos, nPos - nStartPos );
                     OUT_STR( aSingleLine );
                     TAG_ON( OOO_STRING_SVTOOLS_HTML_linebreak );
                     nStartPos = nPos + 1;
                 }
-                while( ( nPos = aStr.indexOf( '\n', nStartPos ) ) != -1 );
-                OUString aSingleLine = aStr.copy( nStartPos, aStr.getLength() - nStartPos );
+                while( ( nPos = aStrOut.indexOf( '\n', nStartPos ) ) != -1 );
+                OUString aSingleLine = aStrOut.copy( nStartPos );
                 OUT_STR( aSingleLine );
             }
         }
@@ -1220,6 +1193,7 @@ void ScHTMLExport::WriteCell( SCCOL nCol, SCROW nRow, SCTAB nTab )
         WriteGraphEntry( pGraphEntry );
 
     if ( bSetFont )     TAG_OFF( OOO_STRING_SVTOOLS_HTML_font );
+    if ( bCrossedOut )  TAG_OFF( OOO_STRING_SVTOOLS_HTML_strikethrough );
     if ( bUnderline )   TAG_OFF( OOO_STRING_SVTOOLS_HTML_underline );
     if ( bItalic )      TAG_OFF( OOO_STRING_SVTOOLS_HTML_italic );
     if ( bBold )        TAG_OFF( OOO_STRING_SVTOOLS_HTML_bold );
@@ -1287,18 +1261,16 @@ bool ScHTMLExport::WriteFieldText( const EditTextObject* pData )
     return bFields;
 }
 
-bool ScHTMLExport::CopyLocalFileToINet( OUString& rFileNm,
-        const OUString& rTargetNm, bool bFileToFile )
+void ScHTMLExport::CopyLocalFileToINet( OUString& rFileNm,
+        const OUString& rTargetNm )
 {
-    bool bRet = false;
     INetURLObject aFileUrl, aTargetUrl;
     aFileUrl.SetSmartURL( rFileNm );
     aTargetUrl.SetSmartURL( rTargetNm );
     if( INetProtocol::File == aFileUrl.GetProtocol() &&
-        ( (bFileToFile && INetProtocol::File == aTargetUrl.GetProtocol()) ||
-          (!bFileToFile && INetProtocol::File != aTargetUrl.GetProtocol() &&
-                           INetProtocol::Ftp <= aTargetUrl.GetProtocol() &&
-                           INetProtocol::Javascript >= aTargetUrl.GetProtocol()) ) )
+        ( INetProtocol::File != aTargetUrl.GetProtocol() &&
+          INetProtocol::Ftp <= aTargetUrl.GetProtocol() &&
+          INetProtocol::Javascript >= aTargetUrl.GetProtocol())  )
     {
         if( pFileNameMap )
         {
@@ -1307,44 +1279,33 @@ bool ScHTMLExport::CopyLocalFileToINet( OUString& rFileNm,
             if( it != pFileNameMap->end() )
             {
                 rFileNm = it->second;
-                return true;
+                return;
             }
         }
         else
         {
-            pFileNameMap.reset( new std::map<OUString, OUString>() );
+            pFileNameMap.reset( new std::map<OUString, OUString> );
         }
 
+        bool bRet = false;
         SvFileStream aTmp( aFileUrl.PathToFileName(), StreamMode::READ );
 
         OUString aSrc = rFileNm;
         OUString aDest = aTargetUrl.GetPartBeforeLastName();
         aDest += aFileUrl.GetName();
 
-        if( bFileToFile )
+        SfxMedium aMedium( aDest, StreamMode::WRITE | StreamMode::SHARE_DENYNONE );
+
         {
-            INetURLObject aCpyURL( aDest );
-            SvFileStream aCpy( aCpyURL.PathToFileName(), StreamMode::WRITE );
+            SvFileStream aCpy( aMedium.GetPhysicalName(), StreamMode::WRITE );
             aCpy.WriteStream( aTmp );
-
-            aCpy.Close();
-            bRet = SVSTREAM_OK == aCpy.GetError();
         }
-        else
-        {
-            SfxMedium aMedium( aDest, StreamMode::WRITE | StreamMode::SHARE_DENYNONE );
 
-            {
-                SvFileStream aCpy( aMedium.GetPhysicalName(), StreamMode::WRITE );
-                aCpy.WriteStream( aTmp );
-            }
+        // Take over
+        aMedium.Close();
+        aMedium.Commit();
 
-            // Take over
-            aMedium.Close();
-            aMedium.Commit();
-
-            bRet = 0 == aMedium.GetError();
-        }
+        bRet = ERRCODE_NONE == aMedium.GetError();
 
         if( bRet )
         {
@@ -1352,23 +1313,6 @@ bool ScHTMLExport::CopyLocalFileToINet( OUString& rFileNm,
             rFileNm = aDest;
         }
     }
-
-    return bRet;
-}
-
-void ScHTMLExport::MakeCIdURL( OUString& rURL )
-{
-    if( aCId.isEmpty() )
-        return;
-
-    INetURLObject aURLObj( rURL );
-    if( INetProtocol::File != aURLObj.GetProtocol() )
-        return;
-
-    OUString aLastName( aURLObj.GetLastName().toAsciiLowerCase() );
-    OSL_ENSURE( !aLastName.isEmpty(), "filename without length!" );
-
-    rURL = "cid:" + aLastName + "." + aCId;
 }
 
 void ScHTMLExport::IncIndent( short nVal )
