@@ -17,79 +17,79 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "workbookfragment.hxx"
+#include <workbookfragment.hxx>
 
-#include <com/sun/star/table/CellAddress.hpp>
-#include "oox/core/filterbase.hxx"
-#include "oox/drawingml/themefragmenthandler.hxx"
-#include "oox/helper/attributelist.hxx"
-#include "oox/helper/progressbar.hxx"
-#include "oox/helper/propertyset.hxx"
-#include "oox/ole/olestorage.hxx"
+#include <oox/core/filterbase.hxx>
+#include <oox/core/xmlfilterbase.hxx>
+#include <oox/drawingml/themefragmenthandler.hxx>
+#include <oox/helper/attributelist.hxx>
+#include <oox/helper/progressbar.hxx>
+#include <oox/helper/propertyset.hxx>
+#include <oox/ole/olestorage.hxx>
+#include <oox/token/namespaces.hxx>
+#include <oox/token/tokens.hxx>
 
-#include "biffinputstream.hxx"
-#include "chartsheetfragment.hxx"
-#include "connectionsfragment.hxx"
-#include "externallinkbuffer.hxx"
-#include "externallinkfragment.hxx"
-#include "formulabuffer.hxx"
-#include "pivotcachebuffer.hxx"
-#include "sharedstringsbuffer.hxx"
-#include "sharedstringsfragment.hxx"
-#include "revisionfragment.hxx"
-#include "stylesfragment.hxx"
-#include "tablebuffer.hxx"
-#include "themebuffer.hxx"
-#include "viewsettings.hxx"
-#include "workbooksettings.hxx"
-#include "worksheetbuffer.hxx"
-#include "worksheethelper.hxx"
-#include "worksheetfragment.hxx"
-#include "sheetdatacontext.hxx"
-#include "threadpool.hxx"
-#include "officecfg/Office/Common.hxx"
+#include <chartsheetfragment.hxx>
+#include <connectionsfragment.hxx>
+#include <externallinkbuffer.hxx>
+#include <externallinkfragment.hxx>
+#include <formulabuffer.hxx>
+#include <pivotcachebuffer.hxx>
+#include <sharedstringsbuffer.hxx>
+#include <sharedstringsfragment.hxx>
+#include <revisionfragment.hxx>
+#include <stylesfragment.hxx>
+#include <tablebuffer.hxx>
+#include <themebuffer.hxx>
+#include <viewsettings.hxx>
+#include <workbooksettings.hxx>
+#include <worksheetbuffer.hxx>
+#include <worksheethelper.hxx>
+#include <worksheetfragment.hxx>
+#include <sheetdatacontext.hxx>
+#include <extlstcontext.hxx>
+#include <officecfg/Office/Common.hxx>
 
-#include "document.hxx"
-#include "docsh.hxx"
-#include "calcconfig.hxx"
+#include <document.hxx>
+#include <docsh.hxx>
+#include <calcconfig.hxx>
+#include <globstr.hrc>
 
 #include <vcl/svapp.hxx>
 #include <vcl/timer.hxx>
+#include <vcl/msgbox.hxx>
 
 #include <oox/core/fastparser.hxx>
-#include <comphelper/processfactory.hxx>
-#include <officecfg/Office/Calc.hxx>
 #include <salhelper/thread.hxx>
+#include <comphelper/threadpool.hxx>
 #include <osl/conditn.hxx>
 
+#include <algorithm>
 #include <queue>
-#include <boost/scoped_ptr.hpp>
+#include <thread>
+#include <memory>
 
-#include "oox/ole/vbaproject.hxx"
+#include <oox/ole/vbaproject.hxx>
+
+#include <comphelper/processfactory.hxx>
+#include <officecfg/Office/Calc.hxx>
 
 namespace oox {
 namespace xls {
 
-// ============================================================================
-
 using namespace ::com::sun::star::io;
 using namespace ::com::sun::star::table;
 using namespace ::com::sun::star::uno;
-using namespace ::com::sun::star::sheet;
 using namespace ::oox::core;
 
 using ::oox::drawingml::ThemeFragmentHandler;
 
-// ============================================================================
-
 namespace {
 
 const double PROGRESS_LENGTH_GLOBALS        = 0.1;      /// 10% of progress bar for globals import.
 
 } // namespace
 
-// ============================================================================
-
 WorkbookFragment::WorkbookFragment( const WorkbookHelper& rHelper, const OUString& rFragmentPath ) :
     WorkbookFragmentBase( rHelper, rFragmentPath )
 {
@@ -116,6 +116,8 @@ ContextHandlerRef WorkbookFragment::onCreateContext( sal_Int32 nElement, const A
                 case XLS_TOKEN( workbookPr ):           getWorkbookSettings().importWorkbookPr( rAttribs );     break;
                 case XLS_TOKEN( calcPr ):               getWorkbookSettings().importCalcPr( rAttribs );         break;
                 case XLS_TOKEN( oleSize ):              getViewSettings().importOleSize( rAttribs );            break;
+
+                case XLS_TOKEN( extLst ):               return new ExtLstGlobalWorkbookContext( *this );
             }
         break;
 
@@ -135,7 +137,7 @@ ContextHandlerRef WorkbookFragment::onCreateContext( sal_Int32 nElement, const A
             if( nElement == XLS_TOKEN( pivotCache ) ) importPivotCache( rAttribs );
         break;
     }
-    return 0;
+    return nullptr;
 }
 
 void WorkbookFragment::onCharacters( const OUString& rChars )
@@ -189,7 +191,7 @@ ContextHandlerRef WorkbookFragment::onCreateRecordContext( sal_Int32 nRecId, Seq
         case BIFF12_ID_PIVOTCACHES:
             if( nRecId == BIFF12_ID_PIVOTCACHE ) importPivotCache( rStrm );
     }
-    return 0;
+    return nullptr;
 }
 
 const RecordInfo* WorkbookFragment::getRecordInfos() const
@@ -213,37 +215,39 @@ namespace {
 typedef std::pair<WorksheetGlobalsRef, FragmentHandlerRef> SheetFragmentHandler;
 typedef std::vector<SheetFragmentHandler> SheetFragmentVector;
 
-class WorkerThread : public ThreadTask
+class WorkerThread : public comphelper::ThreadTask
 {
     sal_Int32 &mrSheetsLeft;
     WorkbookFragment& mrWorkbookHandler;
     rtl::Reference<FragmentHandler> mxHandler;
 
 public:
-    WorkerThread( WorkbookFragment& rWorkbookHandler,
+    WorkerThread( const std::shared_ptr<comphelper::ThreadTaskTag> & pTag,
+                  WorkbookFragment& rWorkbookHandler,
                   const rtl::Reference<FragmentHandler>& xHandler,
                   sal_Int32 &rSheetsLeft ) :
+        comphelper::ThreadTask( pTag ),
         mrSheetsLeft( rSheetsLeft ),
         mrWorkbookHandler( rWorkbookHandler ),
         mxHandler( xHandler )
     {
     }
 
-    virtual void doWork()
+    virtual void doWork() override
     {
         // We hold the solar mutex in all threads except for
         // the small safe section of the inner loop in
         // sheetdatacontext.cxx
-        SAL_INFO( "sc.filter",  "start wait on solar\n" );
-        SolarMutexGuard maGuard;
-        SAL_INFO( "sc.filter",  "got solar\n" );
+        SAL_INFO( "sc.filter",  "start wait on solar" );
+        SolarMutexGuard aGuard;
+        SAL_INFO( "sc.filter",  "got solar" );
 
-        boost::scoped_ptr<oox::core::FastParser> xParser(
-                mrWorkbookHandler.getOoxFilter().createParser() );
+        std::unique_ptr<oox::core::FastParser> xParser(
+                oox::core::XmlFilterBase::createParser() );
 
-        SAL_INFO( "sc.filter",  "start import\n" );
+        SAL_INFO( "sc.filter",  "start import" );
         mrWorkbookHandler.importOoxFragment( mxHandler, *xParser );
-        SAL_INFO( "sc.filter",  "end import, release solar\n" );
+        SAL_INFO( "sc.filter",  "end import, release solar" );
         mrSheetsLeft--;
         assert( mrSheetsLeft >= 0 );
         if( mrSheetsLeft == 0 )
@@ -251,7 +255,7 @@ public:
     }
 };
 
-class ProgressBarTimer : Timer
+class ProgressBarTimer : private Timer
 {
     // FIXME: really we should unify all sheet loading
     // progress reporting into something pleasant.
@@ -260,17 +264,18 @@ class ProgressBarTimer : Timer
         double mfPosition;
         ISegmentProgressBarRef mxWrapped;
     public:
-        ProgressWrapper( const ISegmentProgressBarRef &xRef ) :
-            mxWrapped( xRef )
+        explicit ProgressWrapper(const ISegmentProgressBarRef &xRef)
+            : mfPosition(0.0)
+            , mxWrapped(xRef)
         {
         }
-        virtual ~ProgressWrapper() {}
+
         // IProgressBar
-        virtual double getPosition() const { return mfPosition; }
-        virtual void   setPosition( double fPosition ) { mfPosition = fPosition; }
+        virtual double getPosition() const override { return mfPosition; }
+        virtual void   setPosition( double fPosition ) override { mfPosition = fPosition; }
         // ISegmentProgressBar
-        virtual double getFreeLength() const { return 0.0; }
-        virtual ISegmentProgressBarRef createSegment( double /* fLength */ )
+        virtual double getFreeLength() const override { return 0.0; }
+        virtual ISegmentProgressBarRef createSegment( double /* fLength */ ) override
         {
             return ISegmentProgressBarRef();
         }
@@ -285,7 +290,7 @@ public:
     {
         SetTimeout( 500 );
     }
-    virtual ~ProgressBarTimer()
+    virtual ~ProgressBarTimer() override
     {
         aSegments.clear();
     }
@@ -294,65 +299,47 @@ public:
         aSegments.push_back( ISegmentProgressBarRef( new ProgressWrapper( xProgress ) ) );
         return aSegments.back();
     }
-    virtual void Timeout()
+    virtual void Invoke() override
     {
-        for( size_t i = 0; i < aSegments.size(); i++)
-            static_cast< ProgressWrapper *>( aSegments[ i ].get() )->UpdateBar();
+        for(std::shared_ptr<ISegmentProgressBar> & pSegment : aSegments)
+            static_cast< ProgressWrapper *>( pSegment.get() )->UpdateBar();
     }
 };
 
 void importSheetFragments( WorkbookFragment& rWorkbookHandler, SheetFragmentVector& rSheets )
 {
-    sal_Int32 nThreads = std::min( rSheets.size(), (size_t) 4 /* FIXME: ncpus/2 */ );
+    rWorkbookHandler.getDocImport().initForSheets();
 
-    Reference< XComponentContext > xContext = comphelper::getProcessComponentContext();
+    // test sequential read in this mode
+    comphelper::ThreadPool &rSharedPool = comphelper::ThreadPool::getSharedOptimalPool();
+    std::shared_ptr<comphelper::ThreadTaskTag> pTag = comphelper::ThreadPool::createThreadTaskTag();
 
-    // Force threading off unless experimental mode or env. var is set.
-    if( !officecfg::Office::Common::Misc::ExperimentalMode::get( xContext ) )
-        nThreads = 0;
-
-    const char *pEnv;
-    if( ( pEnv = getenv( "SC_IMPORT_THREADS" ) ) )
-        nThreads = rtl_str_toInt32( pEnv, 10 );
-
-    if( nThreads != 0 )
+    sal_Int32 nSheetsLeft = 0;
+    ProgressBarTimer aProgressUpdater;
+    SheetFragmentVector::iterator it = rSheets.begin(), itEnd = rSheets.end();
+    for( ; it != itEnd; ++it )
     {
-        // test sequential read in this mode
-        if( nThreads < 0)
-            nThreads = 0;
-        ThreadPool aPool( nThreads );
+         // getting at the WorksheetGlobals is rather unpleasant
+         IWorksheetProgress *pProgress = WorksheetHelper::getWorksheetInterface( it->first );
+         pProgress->setCustomRowProgress(
+                     aProgressUpdater.wrapProgress(
+                             pProgress->getRowProgress() ) );
+         rSharedPool.pushTask( new WorkerThread( pTag, rWorkbookHandler, it->second,
+                                           /* ref */ nSheetsLeft ) );
+         nSheetsLeft++;
+     }
 
-        sal_Int32 nSheetsLeft = 0;
-        ProgressBarTimer aProgressUpdater;
-        SheetFragmentVector::iterator it = rSheets.begin(), itEnd = rSheets.end();
-        for( ; it != itEnd; ++it )
-        {
-            // getting at the WorksheetGlobals is rather unpleasant
-            IWorksheetProgress *pProgress = WorksheetHelper::getWorksheetInterface( it->first );
-            pProgress->setCustomRowProgress(
-                        aProgressUpdater.wrapProgress(
-                                pProgress->getRowProgress() ) );
-            aPool.pushTask( new WorkerThread( rWorkbookHandler, it->second,
-                                              /* ref */ nSheetsLeft ) );
-            nSheetsLeft++;
-        }
+     // coverity[loop_top] - this isn't an infinite loop where nSheetsLeft gets decremented by the above threads
+     while( nSheetsLeft > 0)
+     {
+         // This is a much more controlled re-enterancy hazard than
+         // allowing a yield deeper inside the filter code for progress
+         // bar updating.
+         Application::Yield();
+     }
+     rSharedPool.waitUntilDone(pTag);
 
-        while( nSheetsLeft > 0)
-        {
-            // This is a much more controlled re-enterancy hazard than
-            // allowing a yield deeper inside the filter code for progress
-            // bar updating.
-            Application::Yield();
-        }
-        // join all the threads:
-        aPool.waitUntilWorkersDone();
-    }
-    else
-    {
-        SheetFragmentVector::iterator it = rSheets.begin(), itEnd = rSheets.end();
-        for( ; it != itEnd; ++it )
-            rWorkbookHandler.importOoxFragment( it->second );
-    }
+     // threads joined in ThreadPool destructor
 }
 
 }
@@ -386,16 +373,13 @@ void WorkbookFragment::finalizeImport()
         importOoxFragment( new ConnectionsFragment( *this, aConnFragmentPath ) );
     xGlobalSegment->setPosition( 1.0 );
 
-
     /*  Create fragments for all sheets, before importing them. Needed to do
         some preprocessing in the fragment constructors, e.g. loading the table
         fragments for all sheets that are needed before the cell formulas are
         loaded. Additionally, the instances of the WorkbookGlobals structures
         have to be stored for every sheet. */
-    typedef ::std::pair< WorksheetGlobalsRef, FragmentHandlerRef > SheetFragmentHandler;
-    typedef ::std::vector< SheetFragmentHandler > SheetFragmentVector;
     SheetFragmentVector aSheetFragments;
-    std::vector<WorksheetHelper*> maHelpers;
+    std::vector<WorksheetHelper*> aHelpers;
     WorksheetBuffer& rWorksheets = getWorksheets();
     sal_Int32 nWorksheetCount = rWorksheets.getWorksheetCount();
     for( sal_Int32 nWorksheet = 0; nWorksheet < nWorksheetCount; ++nWorksheet )
@@ -409,27 +393,27 @@ void WorkbookFragment::finalizeImport()
             OSL_ENSURE( !aFragmentPath.isEmpty(), "WorkbookFragment::finalizeImport - cannot access sheet fragment" );
             if( !aFragmentPath.isEmpty() )
             {
-                // leave space for formula processing ( calcuate the segments as
+                // leave space for formula processing ( calculate the segments as
                 // if there is an extra sheet )
                 double fSegmentLength = getProgressBar().getFreeLength() / (nWorksheetCount - ( nWorksheet - 1) );
                 ISegmentProgressBarRef xSheetSegment = getProgressBar().createSegment( fSegmentLength );
 
                 // get the sheet type according to the relations type
-                WorksheetType eSheetType = SHEETTYPE_EMPTYSHEET;
+                WorksheetType eSheetType = WorksheetType::Empty;
                 if( pRelation->maType == CREATE_OFFICEDOC_RELATION_TYPE( "worksheet" ) ||
                         pRelation->maType == CREATE_OFFICEDOC_RELATION_TYPE_STRICT( "worksheet" ))
-                    eSheetType = SHEETTYPE_WORKSHEET;
+                    eSheetType = WorksheetType::Work;
                 else if( pRelation->maType == CREATE_OFFICEDOC_RELATION_TYPE( "chartsheet" ) ||
                         pRelation->maType == CREATE_OFFICEDOC_RELATION_TYPE_STRICT( "chartsheet" ))
-                    eSheetType = SHEETTYPE_CHARTSHEET;
+                    eSheetType = WorksheetType::Chart;
                 else if( (pRelation->maType == CREATE_MSOFFICE_RELATION_TYPE( "xlMacrosheet" )) ||
                          (pRelation->maType == CREATE_MSOFFICE_RELATION_TYPE( "xlIntlMacrosheet" )) )
-                    eSheetType = SHEETTYPE_MACROSHEET;
+                    eSheetType = WorksheetType::Macro;
                 else if( pRelation->maType == CREATE_OFFICEDOC_RELATION_TYPE( "dialogsheet" ) ||
                         pRelation->maType == CREATE_OFFICEDOC_RELATION_TYPE_STRICT(" dialogsheet" ))
-                    eSheetType = SHEETTYPE_DIALOGSHEET;
-                OSL_ENSURE( eSheetType != SHEETTYPE_EMPTYSHEET, "WorkbookFragment::finalizeImport - unknown sheet type" );
-                if( eSheetType != SHEETTYPE_EMPTYSHEET )
+                    eSheetType = WorksheetType::Dialog;
+                OSL_ENSURE( eSheetType != WorksheetType::Empty, "WorkbookFragment::finalizeImport - unknown sheet type" );
+                if( eSheetType != WorksheetType::Empty )
                 {
                     // create the WorksheetGlobals object
                     WorksheetGlobalsRef xSheetGlob = WorksheetHelper::constructGlobals( *this, xSheetSegment, eSheetType, nCalcSheet );
@@ -440,23 +424,24 @@ void WorkbookFragment::finalizeImport()
                         ::rtl::Reference< WorksheetFragmentBase > xFragment;
                         switch( eSheetType )
                         {
-                            case SHEETTYPE_WORKSHEET:
-                            case SHEETTYPE_MACROSHEET:
-                            case SHEETTYPE_DIALOGSHEET:
+                            case WorksheetType::Work:
+                            case WorksheetType::Macro:
+                            case WorksheetType::Dialog:
                                 xFragment.set( new WorksheetFragment( *xSheetGlob, aFragmentPath ) );
                             break;
-                            case SHEETTYPE_CHARTSHEET:
+                            case WorksheetType::Chart:
                                 xFragment.set( new ChartsheetFragment( *xSheetGlob, aFragmentPath ) );
                             break;
-                            default:
-                                OSL_ENSURE( false, "WorkbookFragment::finalizeImport - unexpected sheet type" );
+                            // coverity[dead_error_begin] - following conditions exist to avoid compiler warning
+                            case WorksheetType::Empty:
+                                break;
                         }
 
                         // insert the fragment into the map
                         if( xFragment.is() )
                         {
-                            aSheetFragments.push_back( SheetFragmentHandler( xSheetGlob, xFragment.get() ) );
-                            maHelpers.push_back(xFragment.get());
+                            aSheetFragments.emplace_back( xSheetGlob, xFragment.get() );
+                            aHelpers.push_back(xFragment.get());
                         }
                     }
                 }
@@ -465,11 +450,12 @@ void WorkbookFragment::finalizeImport()
     }
 
     // setup structure sizes for the number of sheets
-    getFormulaBuffer().SetSheetCount( aSheetFragments.size() );
+    getFormulaBuffer().SetSheetCount( nWorksheetCount );
 
-    // create all defined names and database ranges
-    getDefinedNames().finalizeImport();
+    // create all database ranges and defined names, in that order
     getTables().finalizeImport();
+    getTables().applyTableColumns();
+    getDefinedNames().finalizeImport();
     // open the VBA project storage
     OUString aVbaFragmentPath = getFragmentPathFromFirstType( CREATE_MSOFFICE_RELATION_TYPE( "vbaProject" ) );
     if( !aVbaFragmentPath.isEmpty() )
@@ -486,7 +472,20 @@ void WorkbookFragment::finalizeImport()
     // load all worksheets
     importSheetFragments(*this, aSheetFragments);
 
-    for( std::vector<WorksheetHelper*>::iterator aIt = maHelpers.begin(), aEnd = maHelpers.end(); aIt != aEnd; ++aIt )
+    sal_Int16 nActiveSheet = getViewSettings().getActiveCalcSheet();
+    getWorksheets().finalizeImport( nActiveSheet );
+
+    // final conversions, e.g. calculation settings and view settings
+    finalizeWorkbookImport();
+    //
+    //stop preventing establishment of listeners as is done in
+    //ScDocShell::AfterXMLLoading() for ods
+    getScDocument().SetInsertingFromOtherDoc(false);
+    getDocImport().finalize();
+
+    recalcFormulaCells();
+
+    for( std::vector<WorksheetHelper*>::iterator aIt = aHelpers.begin(), aEnd = aHelpers.end(); aIt != aEnd; ++aIt )
     {
         (*aIt)->finalizeDrawingImport();
     }
@@ -498,16 +497,71 @@ void WorkbookFragment::finalizeImport()
         aIt->first.reset();
     }
 
-    // final conversions, e.g. calculation settings and view settings
-    finalizeWorkbookImport();
-
     OUString aRevHeadersPath = getFragmentPathFromFirstType(CREATE_OFFICEDOC_RELATION_TYPE("revisionHeaders"));
     if (!aRevHeadersPath.isEmpty())
     {
-        boost::scoped_ptr<oox::core::FastParser> xParser(getOoxFilter().createParser());
+        std::unique_ptr<oox::core::FastParser> xParser(oox::core::XmlFilterBase::createParser());
         rtl::Reference<oox::core::FragmentHandler> xFragment(new RevisionHeadersFragment(*this, aRevHeadersPath));
         importOoxFragment(xFragment, *xParser);
     }
+
+    // attach macros to registered objects now that all objects have been created.
+    getBaseFilter().getVbaProject().attachMacros();
+}
+
+namespace {
+
+ScDocShell& getDocShell(const ScDocument& rDoc)
+{
+    return static_cast<ScDocShell&>(*rDoc.GetDocumentShell());
+}
+
+}
+
+void WorkbookFragment::recalcFormulaCells()
+{
+    // Recalculate formula cells.
+    ScDocument& rDoc = getScDocument();
+    ScDocShell& rDocSh = getDocShell(rDoc);
+    Reference< XComponentContext > xContext = comphelper::getProcessComponentContext();
+    ScRecalcOptions nRecalcMode =
+        static_cast<ScRecalcOptions>(officecfg::Office::Calc::Formula::Load::OOXMLRecalcMode::get(xContext));
+    bool bHardRecalc = false;
+    if (nRecalcMode == RECALC_ASK)
+    {
+        if (rDoc.IsUserInteractionEnabled())
+        {
+            // Ask the user if full re-calculation is desired.
+            ScopedVclPtrInstance<QueryBox> aBox(
+                ScDocShell::GetActiveDialogParent(), MessBoxStyle::YesNo | MessBoxStyle::DefaultYes,
+                ScGlobal::GetRscString(STR_QUERY_FORMULA_RECALC_ONLOAD_XLS));
+            aBox->SetCheckBoxText(ScGlobal::GetRscString(STR_ALWAYS_PERFORM_SELECTED));
+
+            sal_Int32 nRet = aBox->Execute();
+            bHardRecalc = nRet == RET_YES;
+
+            if (aBox->GetCheckBoxState())
+            {
+                // Always perform selected action in the future.
+                std::shared_ptr<comphelper::ConfigurationChanges> batch(comphelper::ConfigurationChanges::create());
+                officecfg::Office::Calc::Formula::Load::OOXMLRecalcMode::set(sal_Int32(0), batch);
+                ScFormulaOptions aOpt = SC_MOD()->GetFormulaOptions();
+                aOpt.SetOOXMLRecalcOptions(bHardRecalc ? RECALC_ALWAYS : RECALC_NEVER);
+                /* XXX  is this really supposed to set the ScModule options?
+                 *      Not the ScDocShell options? */
+                SC_MOD()->SetFormulaOptions(aOpt);
+
+                batch->commit();
+            }
+        }
+    }
+    else if (nRecalcMode == RECALC_ALWAYS)
+        bHardRecalc = true;
+
+    if (bHardRecalc)
+        rDocSh.DoHardRecalc();
+    else
+        rDoc.CalcFormulaTree(false, true, false);
 }
 
 // private --------------------------------------------------------------------
