@@ -26,16 +26,16 @@
 #include "xmlexprt.hxx"
 #include "XMLExportIterator.hxx"
 #include "XMLConverter.hxx"
-#include "unonames.hxx"
-#include "dbdata.hxx"
-#include "document.hxx"
-#include "globstr.hrc"
-#include "globalnames.hxx"
+#include <unonames.hxx>
+#include <dbdata.hxx>
+#include <document.hxx>
+#include <globstr.hrc>
+#include <globalnames.hxx>
 #include "XMLExportSharedData.hxx"
-#include "rangeutl.hxx"
-#include "subtotalparam.hxx"
-#include "queryparam.hxx"
-#include "queryentry.hxx"
+#include <rangeutl.hxx>
+#include <subtotalparam.hxx>
+#include <queryparam.hxx>
+#include <queryentry.hxx>
 #include <sortparam.hxx>
 
 #include <svx/dataaccessdescriptor.hxx>
@@ -113,7 +113,7 @@ ScMyEmptyDatabaseRangesContainer ScXMLExportDatabaseRanges::GetEmptyDatabaseRang
 
 namespace {
 
-class WriteDatabaseRange : public ::std::unary_function<ScDBData, void>
+class WriteDatabaseRange
 {
     ScXMLExport& mrExport;
     ScDocument* mpDoc;
@@ -420,7 +420,7 @@ private:
         return OUString("=");
     }
 
-    class WriteSetItem : public std::unary_function<ScQueryEntry::Item, void>
+    class WriteSetItem
     {
         ScXMLExport& mrExport;
     public:
@@ -466,7 +466,7 @@ private:
         else
         {
             // Multi-item condition.
-            OSL_ASSERT(rItems.size() > 1);
+            assert( rItems.size() > 1 && "rItems should have more than 1 element");
 
             // Store the 1st value for backward compatibility.
             const ScQueryEntry::Item& rItem = rItems.front();
@@ -694,7 +694,7 @@ void ScXMLExportDatabaseRanges::WriteDatabaseRanges()
     {
         const ScDBData* p = pDoc->GetAnonymousDBData(i);
         if (p)
-            aSheetDBs.insert(SheetLocalDBs::value_type(i, p));
+            aSheetDBs.emplace(i, p);
     }
 
     bool bHasRanges = !aSheetDBs.empty();
