@@ -18,25 +18,18 @@
  */
 
 #include "XMLExportIterator.hxx"
-#include <com/sun/star/text/XSimpleText.hpp>
-#include <com/sun/star/sheet/XCellAddressable.hpp>
-#include <com/sun/star/sheet/CellFlags.hpp>
-#include <com/sun/star/sheet/XSheetAnnotationsSupplier.hpp>
-#include <com/sun/star/container/XEnumerationAccess.hpp>
 #include <xmloff/xmlnmspe.hxx>
-#include "dociter.hxx"
-#include "convuno.hxx"
+#include <dociter.hxx>
+#include <convuno.hxx>
 #include "xmlexprt.hxx"
 #include "XMLExportSharedData.hxx"
 #include "XMLStylesExportHelper.hxx"
-#include "document.hxx"
+#include <document.hxx>
 
 #include <algorithm>
 
 using namespace ::com::sun::star;
 
-//==============================================================================
-
 ScMyIteratorBase::ScMyIteratorBase()
 {
 }
@@ -45,29 +38,21 @@ ScMyIteratorBase::~ScMyIteratorBase()
 {
 }
 
-void ScMyIteratorBase::UpdateAddress( table::CellAddress& rCellAddress )
+void ScMyIteratorBase::UpdateAddress( ScAddress& rCellAddress )
 {
-    table::CellAddress aNewAddr( rCellAddress );
+    ScAddress aNewAddr( rCellAddress );
     if( GetFirstAddress( aNewAddr ) )
     {
-        if( (aNewAddr.Sheet == rCellAddress.Sheet) &&
-            ((aNewAddr.Row < rCellAddress.Row) ||
-            ((aNewAddr.Row == rCellAddress.Row) && (aNewAddr.Column < rCellAddress.Column))) )
+        if( ( aNewAddr.Tab() == rCellAddress.Tab() ) &&
+            ( ( aNewAddr.Row() < rCellAddress.Row() ) ||
+            ( ( aNewAddr.Row() == rCellAddress.Row() ) && ( aNewAddr.Col() < rCellAddress.Col() ) ) ) )
             rCellAddress = aNewAddr;
     }
 }
 
-
-//==============================================================================
-
-bool ScMyShape::operator<(const ScMyShape& aShape) const
+inline bool ScMyShape::operator<(const ScMyShape& aShape) const
 {
-    if( aAddress.Tab() != aShape.aAddress.Tab() )
-        return (aAddress.Tab() < aShape.aAddress.Tab());
-    else if( aAddress.Row() != aShape.aAddress.Row() )
-        return (aAddress.Row() < aShape.aAddress.Row());
-    else
-        return (aAddress.Col() < aShape.aAddress.Col());
+    return aAddress.lessThanByRow( aShape.aAddress );
 }
 
 ScMyShapesContainer::ScMyShapesContainer()
@@ -84,13 +69,13 @@ void ScMyShapesContainer::AddNewShape( const ScMyShape& aShape )
     aShapeList.push_back(aShape);
 }
 
-bool ScMyShapesContainer::GetFirstAddress( table::CellAddress& rCellAddress )
+bool ScMyShapesContainer::GetFirstAddress( ScAddress& rCellAddress )
 {
-    sal_Int32 nTable(rCellAddress.Sheet);
+    SCTAB nTable( rCellAddress.Tab() );
     if( !aShapeList.empty() )
     {
-        ScUnoConversion::FillApiAddress( rCellAddress, aShapeList.begin()->aAddress );
-        return (nTable == rCellAddress.Sheet);
+        rCellAddress = aShapeList.begin()->aAddress;
+        return ( nTable == rCellAddress.Tab() );
     }
     return false;
 }
@@ -98,12 +83,10 @@ bool ScMyShapesContainer::GetFirstAddress( table::CellAddress& rCellAddress )
 void ScMyShapesContainer::SetCellData( ScMyCell& rMyCell )
 {
     rMyCell.aShapeList.clear();
-    ScAddress aAddress;
-    ScUnoConversion::FillScAddress( aAddress, rMyCell.aCellAddress );
 
     ScMyShapeList::iterator aItr(aShapeList.begin());
     ScMyShapeList::iterator aEndItr(aShapeList.end());
-    while( (aItr != aEndItr) && (aItr->aAddress == aAddress) )
+    while( (aItr != aEndItr) && (aItr->aAddress == rMyCell.maCellAddress) )
     {
         rMyCell.aShapeList.push_back(*aItr);
         aItr = aShapeList.erase(aItr);
@@ -114,7 +97,7 @@ void ScMyShapesContainer::SetCellData( ScMyCell& rMyCell )
 void ScMyShapesContainer::SkipTable(SCTAB nSkip)
 {
     ScMyShapeList::iterator aItr = aShapeList.begin();
-    while( (aItr != aShapeList.end()) && (aItr->aAddress.Tab() == nSkip) )
+    while( ( aItr != aShapeList.end() ) && ( aItr->aAddress.Tab() == nSkip ) )
         aItr = aShapeList.erase(aItr);
 }
 
@@ -123,14 +106,9 @@ void ScMyShapesContainer::Sort()
     aShapeList.sort();
 }
 
-bool ScMyNoteShape::operator<(const ScMyNoteShape& aNote) const
+inline bool ScMyNoteShape::operator<(const ScMyNoteShape& aNote) const
 {
-    if( aPos.Tab() != aNote.aPos.Tab() )
-        return (aPos.Tab() < aNote.aPos.Tab());
-    else if( aPos.Row() != aNote.aPos.Row() )
-        return (aPos.Row() < aNote.aPos.Row());
-    else
-        return (aPos.Col() < aNote.aPos.Col());
+    return aPos.lessThanByRow( aNote.aPos );
 }
 
 ScMyNoteShapesContainer::ScMyNoteShapesContainer()
@@ -147,24 +125,21 @@ void ScMyNoteShapesContainer::AddNewNote( const ScMyNoteShape& aNote )
     aNoteShapeList.push_back(aNote);
 }
 
-bool ScMyNoteShapesContainer::GetFirstAddress( table::CellAddress& rCellAddress )
+bool ScMyNoteShapesContainer::GetFirstAddress( ScAddress& rCellAddress )
 {
-    sal_Int16 nTable = rCellAddress.Sheet;
+    SCTAB nTable = rCellAddress.Tab();
     if( !aNoteShapeList.empty() )
     {
-        ScUnoConversion::FillApiAddress( rCellAddress, aNoteShapeList.begin()->aPos );
-        return (nTable == rCellAddress.Sheet);
+        rCellAddress = aNoteShapeList.begin()->aPos;
+        return ( nTable == rCellAddress.Tab() );
     }
     return false;
 }
 
 void ScMyNoteShapesContainer::SetCellData( ScMyCell& rMyCell )
 {
-    ScAddress aAddress;
-    ScUnoConversion::FillScAddress( aAddress, rMyCell.aCellAddress );
-
     ScMyNoteShapeList::iterator aItr = aNoteShapeList.begin();
-    while( (aItr != aNoteShapeList.end()) && (aItr->aPos == aAddress) )
+    while( (aItr != aNoteShapeList.end()) && (aItr->aPos == rMyCell.maCellAddress) )
     {
         aItr = aNoteShapeList.erase(aItr);
     }
@@ -173,7 +148,7 @@ void ScMyNoteShapesContainer::SetCellData( ScMyCell& rMyCell )
 void ScMyNoteShapesContainer::SkipTable(SCTAB nSkip)
 {
     ScMyNoteShapeList::iterator aItr = aNoteShapeList.begin();
-    while( (aItr != aNoteShapeList.end()) && (aItr->aPos.Tab() == nSkip) )
+    while( (aItr != aNoteShapeList.end() ) && ( aItr->aPos.Tab() == nSkip ) )
         aItr = aNoteShapeList.erase(aItr);
 }
 
@@ -182,19 +157,11 @@ void ScMyNoteShapesContainer::Sort()
     aNoteShapeList.sort();
 }
 
-//==============================================================================
-
-bool ScMyMergedRange::operator<(const ScMyMergedRange& aRange) const
+inline bool ScMyMergedRange::operator<(const ScMyMergedRange& aRange) const
 {
-    if( aCellRange.Sheet != aRange.aCellRange.Sheet )
-        return (aCellRange.Sheet < aRange.aCellRange.Sheet);
-    else if( aCellRange.StartRow != aRange.aCellRange.StartRow )
-        return (aCellRange.StartRow < aRange.aCellRange.StartRow);
-    else
-        return (aCellRange.StartColumn < aRange.aCellRange.StartColumn);
+    return aCellRange.aStart.lessThanByRow( aRange.aCellRange.aStart );
 }
 
-
 ScMyMergedRangesContainer::ScMyMergedRangesContainer()
     : aRangeList()
 {
@@ -204,34 +171,37 @@ ScMyMergedRangesContainer::~ScMyMergedRangesContainer()
 {
 }
 
-void ScMyMergedRangesContainer::AddRange(const table::CellRangeAddress aMergedRange)
+void ScMyMergedRangesContainer::AddRange(const ScRange& rMergedRange)
 {
-    sal_Int32 nStartRow(aMergedRange.StartRow);
-    sal_Int32 nEndRow(aMergedRange.EndRow);
+    SCROW nStartRow( rMergedRange.aStart.Row() );
+    SCROW nEndRow( rMergedRange.aEnd.Row() );
 
     ScMyMergedRange aRange;
     aRange.bIsFirst = true;
-    aRange.aCellRange = aMergedRange;
-    aRange.aCellRange.EndRow = nStartRow;
+
+    aRange.aCellRange = rMergedRange;
+
+    aRange.aCellRange.aEnd.SetRow( nStartRow );
     aRange.nRows = nEndRow - nStartRow + 1;
     aRangeList.push_back( aRange );
 
     aRange.bIsFirst = false;
     aRange.nRows = 0;
-    for( sal_Int32 nRow = nStartRow + 1; nRow <= nEndRow; ++nRow )
+    for( SCROW nRow = nStartRow + 1; nRow <= nEndRow; ++nRow )
     {
-        aRange.aCellRange.StartRow = aRange.aCellRange.EndRow = nRow;
+        aRange.aCellRange.aStart.SetRow( nRow );
+        aRange.aCellRange.aEnd.SetRow( nRow );
         aRangeList.push_back(aRange);
     }
 }
 
-bool ScMyMergedRangesContainer::GetFirstAddress( table::CellAddress& rCellAddress )
+bool ScMyMergedRangesContainer::GetFirstAddress( ScAddress& rCellAddress )
 {
-    sal_Int32 nTable(rCellAddress.Sheet);
+    SCTAB nTable( rCellAddress.Tab() );
     if( !aRangeList.empty() )
     {
-        ScUnoConversion::FillApiStartAddress( rCellAddress, aRangeList.begin()->aCellRange );
-        return (nTable == rCellAddress.Sheet);
+        rCellAddress = aRangeList.begin()->aCellRange.aStart;
+        return ( nTable == rCellAddress.Tab() );
     }
     return false;
 }
@@ -242,18 +212,16 @@ void ScMyMergedRangesContainer::SetCellData( ScMyCell& rMyCell )
     ScMyMergedRangeList::iterator aItr(aRangeList.begin());
     if( aItr != aRangeList.end() )
     {
-        table::CellAddress aFirstAddress;
-        ScUnoConversion::FillApiStartAddress( aFirstAddress, aItr->aCellRange );
-        if( aFirstAddress == rMyCell.aCellAddress )
+        if( aItr->aCellRange.aStart == rMyCell.aCellAddress )
         {
             rMyCell.aMergeRange = aItr->aCellRange;
             if (aItr->bIsFirst)
-                rMyCell.aMergeRange.EndRow = rMyCell.aMergeRange.StartRow + aItr->nRows - 1;
+                rMyCell.aMergeRange.aEnd.SetRow( rMyCell.aMergeRange.aStart.Row() + aItr->nRows - 1 );
             rMyCell.bIsMergedBase = aItr->bIsFirst;
             rMyCell.bIsCovered = !aItr->bIsFirst;
-            if( aItr->aCellRange.StartColumn < aItr->aCellRange.EndColumn )
+            if( aItr->aCellRange.aStart.Col() < aItr->aCellRange.aEnd.Col() )
             {
-                ++(aItr->aCellRange.StartColumn);
+                aItr->aCellRange.aStart.IncCol( 1 );
                 aItr->bIsFirst = false;
             }
             else
@@ -265,7 +233,7 @@ void ScMyMergedRangesContainer::SetCellData( ScMyCell& rMyCell )
 void ScMyMergedRangesContainer::SkipTable(SCTAB nSkip)
 {
     ScMyMergedRangeList::iterator aItr = aRangeList.begin();
-    while( (aItr != aRangeList.end()) && (aItr->aCellRange.Sheet == nSkip) )
+    while( ( aItr != aRangeList.end() ) && ( aItr->aCellRange.aStart.Tab() == nSkip ) )
         aItr = aRangeList.erase(aItr);
 }
 
@@ -274,8 +242,6 @@ void ScMyMergedRangesContainer::Sort()
     aRangeList.sort();
 }
 
-//==============================================================================
-
 bool ScMyAreaLink::Compare( const ScMyAreaLink& rAreaLink ) const
 {
     return  (GetRowCount() == rAreaLink.GetRowCount()) &&
@@ -285,14 +251,9 @@ bool ScMyAreaLink::Compare( const ScMyAreaLink& rAreaLink ) const
             (sSourceStr == rAreaLink.sSourceStr);
 }
 
-bool ScMyAreaLink::operator<(const ScMyAreaLink& rAreaLink ) const
+inline bool ScMyAreaLink::operator<(const ScMyAreaLink& rAreaLink ) const
 {
-    if( aDestRange.Sheet != rAreaLink.aDestRange.Sheet )
-        return (aDestRange.Sheet < rAreaLink.aDestRange.Sheet);
-    else if( aDestRange.StartRow != rAreaLink.aDestRange.StartRow )
-        return (aDestRange.StartRow < rAreaLink.aDestRange.StartRow);
-    else
-        return (aDestRange.StartColumn < rAreaLink.aDestRange.StartColumn);
+    return aDestRange.aStart.lessThanByRow( rAreaLink.aDestRange.aStart );
 }
 
 ScMyAreaLinksContainer::ScMyAreaLinksContainer() :
@@ -304,13 +265,13 @@ ScMyAreaLinksContainer::~ScMyAreaLinksContainer()
 {
 }
 
-bool ScMyAreaLinksContainer::GetFirstAddress( table::CellAddress& rCellAddress )
+bool ScMyAreaLinksContainer::GetFirstAddress( ScAddress& rCellAddress )
 {
-    sal_Int32 nTable(rCellAddress.Sheet);
+    SCTAB nTable( rCellAddress.Tab() );
     if( !aAreaLinkList.empty() )
     {
-        ScUnoConversion::FillApiStartAddress( rCellAddress, aAreaLinkList.begin()->aDestRange );
-        return (nTable == rCellAddress.Sheet);
+        rCellAddress = aAreaLinkList.begin()->aDestRange.aStart;
+        return ( nTable == rCellAddress.Tab() );
     }
     return false;
 }
@@ -321,9 +282,7 @@ void ScMyAreaLinksContainer::SetCellData( ScMyCell& rMyCell )
     ScMyAreaLinkList::iterator aItr(aAreaLinkList.begin());
     if( aItr != aAreaLinkList.end() )
     {
-        table::CellAddress aAddress;
-        ScUnoConversion::FillApiStartAddress( aAddress, aItr->aDestRange );
-        if( aAddress == rMyCell.aCellAddress )
+        if( aItr->aDestRange.aStart == rMyCell.aCellAddress )
         {
             rMyCell.bHasAreaLink = true;
             rMyCell.aAreaLink = *aItr;
@@ -331,8 +290,7 @@ void ScMyAreaLinksContainer::SetCellData( ScMyCell& rMyCell )
             bool bFound = true;
             while (aItr != aAreaLinkList.end() && bFound)
             {
-                ScUnoConversion::FillApiStartAddress( aAddress, aItr->aDestRange );
-                if (aAddress == rMyCell.aCellAddress)
+                if ( aItr->aDestRange.aStart == rMyCell.aCellAddress )
                 {
                     OSL_FAIL("more than one linked range on one cell");
                     aItr = aAreaLinkList.erase( aItr );
@@ -347,7 +305,7 @@ void ScMyAreaLinksContainer::SetCellData( ScMyCell& rMyCell )
 void ScMyAreaLinksContainer::SkipTable(SCTAB nSkip)
 {
     ScMyAreaLinkList::iterator aItr = aAreaLinkList.begin();
-    while( (aItr != aAreaLinkList.end()) && (aItr->aDestRange.Sheet == nSkip) )
+    while( ( aItr != aAreaLinkList.end() ) && ( aItr->aDestRange.aStart.Tab() == nSkip ) )
         aItr = aAreaLinkList.erase(aItr);
 }
 
@@ -356,23 +314,6 @@ void ScMyAreaLinksContainer::Sort()
     aAreaLinkList.sort();
 }
 
-//==============================================================================
-
-ScMyCellRangeAddress::ScMyCellRangeAddress(const table::CellRangeAddress& rRange)
-    : table::CellRangeAddress(rRange)
-{
-}
-
-bool ScMyCellRangeAddress::operator<(const ScMyCellRangeAddress& rRange ) const
-{
-    if( Sheet != rRange.Sheet )
-        return (Sheet < rRange.Sheet);
-    else if( StartRow != rRange.StartRow )
-        return (StartRow < rRange.StartRow);
-    else
-        return (StartColumn < rRange.StartColumn);
-}
-
 ScMyEmptyDatabaseRangesContainer::ScMyEmptyDatabaseRangesContainer()
     : aDatabaseList()
 {
@@ -384,23 +325,25 @@ ScMyEmptyDatabaseRangesContainer::~ScMyEmptyDatabaseRangesContainer()
 
 void ScMyEmptyDatabaseRangesContainer::AddNewEmptyDatabaseRange(const table::CellRangeAddress& aCellRange)
 {
-    sal_Int32 nStartRow(aCellRange.StartRow);
-    sal_Int32 nEndRow(aCellRange.EndRow);
-    ScMyCellRangeAddress aRange( aCellRange );
-    for( sal_Int32 nRow = nStartRow; nRow <= nEndRow; ++nRow )
+    SCROW nStartRow(aCellRange.StartRow);
+    SCROW nEndRow(aCellRange.EndRow);
+    ScRange aRange( aCellRange.StartColumn, aCellRange.StartRow, aCellRange.Sheet,
+                      aCellRange.EndColumn, aCellRange.EndRow, aCellRange.Sheet );
+    for( SCROW nRow = nStartRow; nRow <= nEndRow; ++nRow )
     {
-        aRange.StartRow = aRange.EndRow = nRow;
+        aRange.aStart.SetRow( nRow );
+        aRange.aEnd.SetRow( nRow );
         aDatabaseList.push_back( aRange );
     }
 }
 
-bool ScMyEmptyDatabaseRangesContainer::GetFirstAddress( table::CellAddress& rCellAddress )
+bool ScMyEmptyDatabaseRangesContainer::GetFirstAddress( ScAddress& rCellAddress )
 {
-    sal_Int32 nTable(rCellAddress.Sheet);
+    SCTAB nTable( rCellAddress.Tab() );
     if( !aDatabaseList.empty() )
     {
-        ScUnoConversion::FillApiStartAddress( rCellAddress, *(aDatabaseList.begin()) );
-        return (nTable == rCellAddress.Sheet);
+        rCellAddress = aDatabaseList.begin()->aStart;
+        return ( nTable == rCellAddress.Tab() );
     }
     return false;
 }
@@ -411,13 +354,11 @@ void ScMyEmptyDatabaseRangesContainer::SetCellData( ScMyCell& rMyCell )
     ScMyEmptyDatabaseRangeList::iterator aItr(aDatabaseList.begin());
     if( aItr != aDatabaseList.end() )
     {
-        table::CellAddress aFirstAddress;
-        ScUnoConversion::FillApiStartAddress( aFirstAddress, *aItr );
-        if( aFirstAddress == rMyCell.aCellAddress )
+        if( aItr->aStart == rMyCell.aCellAddress )
         {
             rMyCell.bHasEmptyDatabase = true;
-            if( aItr->StartColumn < aItr->EndColumn )
-                ++(aItr->StartColumn);
+            if( aItr->aStart.Col() < aItr->aEnd.Col() )
+                aItr->aStart.SetCol( aItr->aStart.Col() + 1 );
             else
                 aDatabaseList.erase(aItr);
         }
@@ -427,7 +368,7 @@ void ScMyEmptyDatabaseRangesContainer::SetCellData( ScMyCell& rMyCell )
 void ScMyEmptyDatabaseRangesContainer::SkipTable(SCTAB nSkip)
 {
     ScMyEmptyDatabaseRangeList::iterator aItr = aDatabaseList.begin();
-    while( (aItr != aDatabaseList.end()) && (aItr->Sheet == nSkip) )
+    while( ( aItr != aDatabaseList.end() ) && ( aItr->aStart.Tab() == nSkip ) )
         aItr = aDatabaseList.erase(aItr);
 }
 
@@ -436,16 +377,9 @@ void ScMyEmptyDatabaseRangesContainer::Sort()
     aDatabaseList.sort();
 }
 
-//==============================================================================
-
-bool ScMyDetectiveObj::operator<( const ScMyDetectiveObj& rDetObj) const
+inline bool ScMyDetectiveObj::operator<( const ScMyDetectiveObj& rDetObj) const
 {
-    if( aPosition.Sheet != rDetObj.aPosition.Sheet )
-        return (aPosition.Sheet < rDetObj.aPosition.Sheet);
-    else if( aPosition.Row != rDetObj.aPosition.Row )
-        return (aPosition.Row < rDetObj.aPosition.Row);
-    else
-        return (aPosition.Column < rDetObj.aPosition.Column);
+    return aPosition.lessThanByRow( rDetObj.aPosition );
 }
 
 ScMyDetectiveObjContainer::ScMyDetectiveObjContainer() :
@@ -469,32 +403,33 @@ void ScMyDetectiveObjContainer::AddObject( ScDetectiveObjType eObjType, const SC
         ScMyDetectiveObj aDetObj;
         aDetObj.eObjType = eObjType;
         if( eObjType == SC_DETOBJ_TOOTHERTAB )
-            ScUnoConversion::FillApiAddress( aDetObj.aPosition, rSourceRange.aStart );
+            aDetObj.aPosition = rSourceRange.aStart;
         else
-            ScUnoConversion::FillApiAddress( aDetObj.aPosition, rPosition );
-        ScUnoConversion::FillApiRange( aDetObj.aSourceRange, rSourceRange );
+            aDetObj.aPosition = rPosition;
+        aDetObj.aSourceRange = rSourceRange;
 
         // #111064#; take the sheet where the object is found and not the sheet given in the ranges, because they are not always true
         if (eObjType != SC_DETOBJ_FROMOTHERTAB)
         {
             // if the ObjType == SC_DETOBJ_FROMOTHERTAB then the SourceRange is not used and so it has not to be tested and changed
-            OSL_ENSURE(aDetObj.aPosition.Sheet == aDetObj.aSourceRange.Sheet, "It seems to be possible to have different sheets");
-            aDetObj.aSourceRange.Sheet = nSheet;
+            OSL_ENSURE(aDetObj.aPosition.Tab() == aDetObj.aSourceRange.aStart.Tab(), "It seems to be possible to have different sheets");
+            aDetObj.aSourceRange.aStart.SetTab( nSheet );
+            aDetObj.aSourceRange.aEnd.SetTab( nSheet );
         }
-        aDetObj.aPosition.Sheet = nSheet;
+        aDetObj.aPosition.SetTab( nSheet );
 
         aDetObj.bHasError = bHasError;
         aDetectiveObjList.push_back( aDetObj );
     }
 }
 
-bool ScMyDetectiveObjContainer::GetFirstAddress( table::CellAddress& rCellAddress )
+bool ScMyDetectiveObjContainer::GetFirstAddress( ScAddress& rCellAddress )
 {
-    sal_Int32 nTable(rCellAddress.Sheet);
+    SCTAB nTable( rCellAddress.Tab() );
     if( !aDetectiveObjList.empty() )
     {
         rCellAddress = aDetectiveObjList.begin()->aPosition;
-        return (nTable == rCellAddress.Sheet);
+        return ( nTable == rCellAddress.Tab() );
     }
     return false;
 }
@@ -515,7 +450,7 @@ void ScMyDetectiveObjContainer::SetCellData( ScMyCell& rMyCell )
 void ScMyDetectiveObjContainer::SkipTable(SCTAB nSkip)
 {
     ScMyDetectiveObjList::iterator aItr = aDetectiveObjList.begin();
-    while( (aItr != aDetectiveObjList.end()) && (aItr->aPosition.Sheet == nSkip) )
+    while( ( aItr != aDetectiveObjList.end() ) && ( aItr->aPosition.Tab() == nSkip ) )
         aItr = aDetectiveObjList.erase(aItr);
 }
 
@@ -524,16 +459,9 @@ void ScMyDetectiveObjContainer::Sort()
     aDetectiveObjList.sort();
 }
 
-//==============================================================================
-
-bool ScMyDetectiveOp::operator<( const ScMyDetectiveOp& rDetOp) const
+inline bool ScMyDetectiveOp::operator<( const ScMyDetectiveOp& rDetOp) const
 {
-    if( aPosition.Sheet != rDetOp.aPosition.Sheet )
-        return (aPosition.Sheet < rDetOp.aPosition.Sheet);
-    else if( aPosition.Row != rDetOp.aPosition.Row )
-        return (aPosition.Row < rDetOp.aPosition.Row);
-    else
-        return (aPosition.Column < rDetOp.aPosition.Column);
+    return aPosition.lessThanByRow( rDetOp.aPosition );
 }
 
 ScMyDetectiveOpContainer::ScMyDetectiveOpContainer() :
@@ -549,18 +477,18 @@ void ScMyDetectiveOpContainer::AddOperation( ScDetOpType eOpType, const ScAddres
 {
     ScMyDetectiveOp aDetOp;
     aDetOp.eOpType = eOpType;
-    ScUnoConversion::FillApiAddress( aDetOp.aPosition, rPosition );
+    aDetOp.aPosition = rPosition;
     aDetOp.nIndex = nIndex;
     aDetectiveOpList.push_back( aDetOp );
 }
 
-bool ScMyDetectiveOpContainer::GetFirstAddress( table::CellAddress& rCellAddress )
+bool ScMyDetectiveOpContainer::GetFirstAddress( ScAddress& rCellAddress )
 {
-    sal_Int32 nTable(rCellAddress.Sheet);
+    SCTAB nTable( rCellAddress.Tab() );
     if( !aDetectiveOpList.empty() )
     {
         rCellAddress = aDetectiveOpList.begin()->aPosition;
-        return (nTable == rCellAddress.Sheet);
+        return ( nTable == rCellAddress.Tab() );
     }
     return false;
 }
@@ -581,7 +509,7 @@ void ScMyDetectiveOpContainer::SetCellData( ScMyCell& rMyCell )
 void ScMyDetectiveOpContainer::SkipTable(SCTAB nSkip)
 {
     ScMyDetectiveOpList::iterator aItr = aDetectiveOpList.begin();
-    while( (aItr != aDetectiveOpList.end()) && (aItr->aPosition.Sheet == nSkip) )
+    while( (aItr != aDetectiveOpList.end()) && (aItr->aPosition.Tab() == nSkip) )
         aItr = aDetectiveOpList.erase(aItr);
 }
 
@@ -590,12 +518,14 @@ void ScMyDetectiveOpContainer::Sort()
     aDetectiveOpList.sort();
 }
 
-//==============================================================================
-
 ScMyCell::ScMyCell() :
     aShapeList(),
     aDetectiveObjVec(),
+    pNote(nullptr),
     nValidationIndex(-1),
+    nStyleIndex(-1),
+    nNumberFormat(-1),
+    nType(table::CellContentType_EMPTY),
     bIsAutoStyle( false ),
     bHasShape( false ),
     bIsMergedBase( false ),
@@ -614,18 +544,17 @@ ScMyCell::~ScMyCell()
 {
 }
 
-//==============================================================================
-
 ScMyNotEmptyCellsIterator::ScMyNotEmptyCellsIterator(ScXMLExport& rTempXMLExport)
-    : pShapes(NULL),
-    pNoteShapes(NULL),
-    pEmptyDatabaseRanges(NULL),
-    pMergedRanges(NULL),
-    pAreaLinks(NULL),
-    pDetectiveObj(NULL),
-    pDetectiveOp(NULL),
+    : pShapes(nullptr),
+    pNoteShapes(nullptr),
+    pEmptyDatabaseRanges(nullptr),
+    pMergedRanges(nullptr),
+    pAreaLinks(nullptr),
+    pDetectiveObj(nullptr),
+    pDetectiveOp(nullptr),
     rExport(rTempXMLExport),
-    mpCell(NULL),
+    nCellCol(0),
+    nCellRow(0),
     nCurrentTable(SCTAB_MAX)
 {
 }
@@ -638,45 +567,41 @@ ScMyNotEmptyCellsIterator::~ScMyNotEmptyCellsIterator()
 void ScMyNotEmptyCellsIterator::Clear()
 {
     mpCellItr.reset();
-    pShapes = NULL;
-    pNoteShapes = NULL;
-    pMergedRanges = NULL;
-    pAreaLinks = NULL;
-    pEmptyDatabaseRanges = NULL;
-    pDetectiveObj = NULL;
-    pDetectiveOp = NULL;
+    pShapes = nullptr;
+    pNoteShapes = nullptr;
+    pMergedRanges = nullptr;
+    pAreaLinks = nullptr;
+    pEmptyDatabaseRanges = nullptr;
+    pDetectiveObj = nullptr;
+    pDetectiveOp = nullptr;
     nCurrentTable = SCTAB_MAX;
 }
 
-void ScMyNotEmptyCellsIterator::UpdateAddress( table::CellAddress& rAddress )
+void ScMyNotEmptyCellsIterator::UpdateAddress( ScAddress& rAddress )
 {
     if (mpCellItr->GetPos(nCellCol, nCellRow))
     {
-        rAddress.Column = nCellCol;
-        rAddress.Row = nCellRow;
+        rAddress.SetCol( nCellCol );
+        rAddress.SetRow( nCellRow );
     }
 }
 
-void ScMyNotEmptyCellsIterator::SetCellData( ScMyCell& rMyCell, const table::CellAddress& rAddress )
+void ScMyNotEmptyCellsIterator::SetCellData( ScMyCell& rMyCell, const ScAddress& rAddress )
 {
     rMyCell.maBaseCell.clear();
     rMyCell.aCellAddress = rAddress;
-    ScUnoConversion::FillScAddress(rMyCell.maCellAddress, rMyCell.aCellAddress);
+    rMyCell.maCellAddress = rMyCell.aCellAddress;
 
-    if( (nCellCol == rAddress.Column) && (nCellRow == rAddress.Row) )
+    if( ( nCellCol == rAddress.Col() ) && ( nCellRow == rAddress.Row() ) )
     {
-        mpCell = mpCellItr->GetNext(nCellCol, nCellRow);
-        if (mpCell)
-            rMyCell.maBaseCell = *mpCell;
+        const ScRefCellValue* pCell = mpCellItr->GetNext(nCellCol, nCellRow);
+        if (pCell)
+            rMyCell.maBaseCell = *pCell;
     }
 
     rMyCell.bIsMatrixCovered = false;
     rMyCell.bIsMatrixBase = false;
 
-    bool bIsMatrixBase = false;
-
-    ScAddress aScAddress;
-    ScUnoConversion::FillScAddress( aScAddress, rMyCell.aCellAddress );
     switch (rMyCell.maBaseCell.meType)
     {
         case CELLTYPE_VALUE:
@@ -694,20 +619,20 @@ void ScMyNotEmptyCellsIterator::SetCellData( ScMyCell& rMyCell, const table::Cel
     }
 
     if (rMyCell.maBaseCell.meType == CELLTYPE_FORMULA)
-        if( rExport.IsMatrix( aScAddress, rMyCell.aMatrixRange, bIsMatrixBase ) )
+    {
+        bool bIsMatrixBase = false;
+        if (rExport.IsMatrix(rMyCell.maCellAddress, rMyCell.aMatrixRange, bIsMatrixBase))
         {
             rMyCell.bIsMatrixBase = bIsMatrixBase;
             rMyCell.bIsMatrixCovered = !bIsMatrixBase;
         }
+    }
 }
 
 void ScMyNotEmptyCellsIterator::HasAnnotation(ScMyCell& aCell)
 {
     aCell.bHasAnnotation = false;
-    ScAddress aAddress;
-    ScUnoConversion::FillScAddress( aAddress, aCell.aCellAddress );
-
-    ScPostIt* pNote = rExport.GetDocument()->GetNote(aAddress);
+    ScPostIt* pNote = rExport.GetDocument()->GetNote(aCell.maCellAddress);
 
     if(pNote)
     {
@@ -716,13 +641,12 @@ void ScMyNotEmptyCellsIterator::HasAnnotation(ScMyCell& aCell)
     }
 }
 
-
 void ScMyNotEmptyCellsIterator::SetCurrentTable(const SCTAB nTable,
-    uno::Reference<sheet::XSpreadsheet>& rxTable)
+    const uno::Reference<sheet::XSpreadsheet>& rxTable)
 {
-    aLastAddress.Row = 0;
-    aLastAddress.Column = 0;
-    aLastAddress.Sheet = nTable;
+    aLastAddress.SetRow( 0 );
+    aLastAddress.SetCol( 0 );
+    aLastAddress.SetTab( nTable );
     if (nCurrentTable != nTable)
     {
         nCurrentTable = nTable;
@@ -761,7 +685,7 @@ void ScMyNotEmptyCellsIterator::SkipTable(SCTAB nSkip)
 
 bool ScMyNotEmptyCellsIterator::GetNext(ScMyCell& aCell, ScFormatRangeStyles* pCellStyles)
 {
-    table::CellAddress  aAddress( nCurrentTable, MAXCOL + 1, MAXROW + 1 );
+    ScAddress  aAddress( MAXCOL + 1, MAXROW + 1, nCurrentTable );
 
     UpdateAddress( aAddress );
 
@@ -780,7 +704,7 @@ bool ScMyNotEmptyCellsIterator::GetNext(ScMyCell& aCell, ScFormatRangeStyles* pC
     if( pDetectiveOp )
         pDetectiveOp->UpdateAddress( aAddress );
 
-    bool bFoundCell((aAddress.Column <= MAXCOL) && (aAddress.Row <= MAXROW));
+    bool bFoundCell( ( aAddress.Col() <= MAXCOL ) && ( aAddress.Row() <= MAXROW ) );
     if( bFoundCell )
     {
         SetCellData( aCell, aAddress );
@@ -802,9 +726,9 @@ bool ScMyNotEmptyCellsIterator::GetNext(ScMyCell& aCell, ScFormatRangeStyles* pC
         HasAnnotation( aCell );
         bool bIsAutoStyle;
         // Ranges before the previous cell are not needed by ExportFormatRanges anymore and can be removed
-        sal_Int32 nRemoveBeforeRow = aLastAddress.Row;
-        aCell.nStyleIndex = pCellStyles->GetStyleNameIndex(aCell.aCellAddress.Sheet,
-            aCell.aCellAddress.Column, aCell.aCellAddress.Row,
+        SCROW nRemoveBeforeRow = aLastAddress.Row();
+        aCell.nStyleIndex = pCellStyles->GetStyleNameIndex(aCell.maCellAddress.Tab(),
+            aCell.maCellAddress.Col(), aCell.maCellAddress.Row(),
             bIsAutoStyle, aCell.nValidationIndex, aCell.nNumberFormat, nRemoveBeforeRow);
         aLastAddress = aCell.aCellAddress;
         aCell.bIsAutoStyle = bIsAutoStyle;
@@ -816,9 +740,4 @@ bool ScMyNotEmptyCellsIterator::GetNext(ScMyCell& aCell, ScFormatRangeStyles* pC
     return bFoundCell;
 }
 
-const ScRefCellValue* ScMyNotEmptyCellsIterator::GetCell() const
-{
-    return mpCell;
-}
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
