@@ -20,16 +20,12 @@
 #include "XMLTableShapesContext.hxx"
 #include "XMLTableShapeImportHelper.hxx"
 #include "xmlimprt.hxx"
-#include "document.hxx"
-#include <com/sun/star/drawing/XDrawPageSupplier.hpp>
+#include <document.hxx>
 
 using namespace com::sun::star;
 
-ScXMLTableShapesContext::ScXMLTableShapesContext( ScXMLImport& rImport,
-                                      sal_uInt16 nPrfx,
-                                      const OUString& rLName,
-                                      const css::uno::Reference<css::xml::sax::XAttributeList>& /* xAttrList */ ) :
-    SvXMLImportContext( rImport, nPrfx, rLName )
+ScXMLTableShapesContext::ScXMLTableShapesContext( ScXMLImport& rImport ) :
+    ScXMLImportContext( rImport )
 {
     // here are no attributes
 }
@@ -38,23 +34,20 @@ ScXMLTableShapesContext::~ScXMLTableShapesContext()
 {
 }
 
-SvXMLImportContext *ScXMLTableShapesContext::CreateChildContext( sal_uInt16 nPrefix,
+SvXMLImportContextRef ScXMLTableShapesContext::CreateChildContext( sal_uInt16 nPrefix,
                                             const OUString& rLName,
                                             const css::uno::Reference<css::xml::sax::XAttributeList>& xAttrList )
 {
-    SvXMLImportContext *pContext(nullptr);
+    SvXMLImportContext *pContext = nullptr;
 
-    if (!pContext)
+    ScXMLImport& rXMLImport(GetScImport());
+    uno::Reference<drawing::XShapes> xShapes (rXMLImport.GetTables().GetCurrentXShapes());
+    if (xShapes.is())
     {
-        ScXMLImport& rXMLImport(GetScImport());
-        uno::Reference<drawing::XShapes> xShapes (rXMLImport.GetTables().GetCurrentXShapes());
-        if (xShapes.is())
-        {
-            XMLTableShapeImportHelper* pTableShapeImport(static_cast<XMLTableShapeImportHelper*>(rXMLImport.GetShapeImport().get()));
-            pTableShapeImport->SetOnTable(true);
-            pContext = rXMLImport.GetShapeImport()->CreateGroupChildContext(
-                rXMLImport, nPrefix, rLName, xAttrList, xShapes);
-        }
+        XMLTableShapeImportHelper* pTableShapeImport(static_cast<XMLTableShapeImportHelper*>(rXMLImport.GetShapeImport().get()));
+        pTableShapeImport->SetOnTable(true);
+        pContext = rXMLImport.GetShapeImport()->CreateGroupChildContext(
+            rXMLImport, nPrefix, rLName, xAttrList, xShapes);
     }
 
     if( !pContext )
@@ -63,8 +56,4 @@ SvXMLImportContext *ScXMLTableShapesContext::CreateChildContext( sal_uInt16 nPre
     return pContext;
 }
 
-void ScXMLTableShapesContext::EndElement()
-{
-}
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
