@@ -17,23 +17,23 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "AccessibleDocument.hxx"
-#include "AccessibleSpreadsheet.hxx"
-#include "tabvwsh.hxx"
-#include "AccessibilityHints.hxx"
-#include "document.hxx"
-#include "drwlayer.hxx"
-#include "shapeuno.hxx"
-#include "DrawModelBroadcaster.hxx"
-#include "drawview.hxx"
-#include "gridwin.hxx"
-#include "AccessibleEditObject.hxx"
-#include "userdat.hxx"
-#include "scresid.hxx"
-#include "scres.hrc"
-#include "strings.hxx"
-#include "table.hxx"
-#include "markdata.hxx"
+#include <AccessibleDocument.hxx>
+#include <AccessibleSpreadsheet.hxx>
+#include <tabvwsh.hxx>
+#include <AccessibilityHints.hxx>
+#include <document.hxx>
+#include <drwlayer.hxx>
+#include <shapeuno.hxx>
+#include <DrawModelBroadcaster.hxx>
+#include <drawview.hxx>
+#include <gridwin.hxx>
+#include <AccessibleEditObject.hxx>
+#include <userdat.hxx>
+#include <scresid.hxx>
+#include <strings.hrc>
+#include <strings.hxx>
+#include <table.hxx>
+#include <markdata.hxx>
 
 #include <com/sun/star/accessibility/AccessibleEventId.hpp>
 #include <com/sun/star/accessibility/AccessibleStateType.hpp>
@@ -71,10 +71,10 @@
 #include <list>
 #include <algorithm>
 
-#include "AccessibleCell.hxx"
+#include <AccessibleCell.hxx>
 
 #include <svx/unoapi.hxx>
-#include "scmod.hxx"
+#include <scmod.hxx>
 
 #ifdef indices
 #undef indices
@@ -146,7 +146,7 @@ struct ScShapeDataLess
         {
             uno::Any aPropAny = xProps->getPropertyValue(msLayerId);
             sal_Int16 nLayerID = 0;
-            if( (aPropAny >>= nLayerID) )
+            if( aPropAny >>= nLayerID )
             {
                 if (SdrLayerID(nLayerID) == SC_LAYER_BACK)
                     bResult = true;
@@ -213,7 +213,7 @@ struct DeselectShape
 struct SelectShape
 {
     uno::Reference < drawing::XShapes > xShapes;
-    explicit SelectShape(uno::Reference<drawing::XShapes>& xTemp) : xShapes(xTemp) {}
+    explicit SelectShape(const uno::Reference<drawing::XShapes>& xTemp) : xShapes(xTemp) {}
     void operator() (const ScAccessibleShapeData* pAccShapeData) const
     {
         if (pAccShapeData && pAccShapeData->bSelectable)
@@ -392,7 +392,7 @@ void ScChildrenShapes::SetDrawBroadcaster()
         SfxBroadcaster* pDrawBC = rViewData.GetDocument()->GetDrawBroadcaster();
         if (pDrawBC)
         {
-            StartListening(*pDrawBC, true);
+            StartListening(*pDrawBC, DuplicateHandling::Prevent);
 
             maShapeTreeInfo.SetModelBroadcaster( new ScDrawModelBroadcaster(rViewData.GetDocument()->GetDrawLayer()) );
             maShapeTreeInfo.SetSdrView(rViewData.GetScDrawView());
@@ -968,7 +968,7 @@ bool ScChildrenShapes::FindSelectedShapesChanges(const uno::Reference<drawing::X
     SortedShapes::iterator aDataItr(maZOrderedShapes.begin());
     SortedShapes::const_iterator aDataEndItr(maZOrderedShapes.end());
     SortedShapes::const_iterator aFocusedItr = aDataEndItr;
-    while((aDataItr != aDataEndItr))
+    while(aDataItr != aDataEndItr)
     {
         if (*aDataItr) // is it really a shape or only the sheet
         {
@@ -987,7 +987,7 @@ bool ScChildrenShapes::FindSelectedShapesChanges(const uno::Reference<drawing::X
                         (*aDataItr)->pAccShape->SetState(AccessibleStateType::SELECTED);
                         (*aDataItr)->pAccShape->SetState(AccessibleStateType::FOCUSED);
                         bResult = true;
-                        vecSelectedShapeAdd.push_back((*aDataItr));
+                        vecSelectedShapeAdd.push_back(*aDataItr);
                     }
                     aFocusedItr = aDataItr;
                 }
@@ -1203,8 +1203,7 @@ void ScChildrenShapes::SetAnchor(const uno::Reference<drawing::XShape>& xShape,
         if ((pAddress && pData->pRelationCell && (*pAddress != *(pData->pRelationCell))) ||
             (!pAddress && pData->pRelationCell) || (pAddress && !pData->pRelationCell))
         {
-            if (pData->pRelationCell)
-                delete pData->pRelationCell;
+            delete pData->pRelationCell;
             pData->pRelationCell = pAddress;
             if (pData->pAccShape.is())
                 pData->pAccShape->SetRelationSet(GetRelationSet(pData));
@@ -1558,7 +1557,7 @@ void ScAccessibleDocument::Notify( SfxBroadcaster& rBC, const SfxHint& rHint )
             if (mpChildrenShapes)
                 mpChildrenShapes->SetDrawBroadcaster();
         }
-        else if ((rHint.GetId() == SfxHintId::ScAccEnterEditMode)) // this event comes only on creating edit field of a cell
+        else if (rHint.GetId() == SfxHintId::ScAccEnterEditMode) // this event comes only on creating edit field of a cell
         {
             if (mpViewShell->GetViewData().GetEditActivePart() == meSplitPos)
             {
@@ -2190,7 +2189,7 @@ bool ScAccessibleDocument::IsTableSelected() const
         //#103800#; use a copy of MarkData
         ScMarkData aMarkData(mpViewShell->GetViewData().GetMarkData());
         aMarkData.MarkToMulti();
-        if (aMarkData.IsAllMarked(ScRange(ScAddress(0, 0, nTab),ScAddress(MAXCOL, MAXROW, nTab))))
+        if (aMarkData.IsAllMarked( ScRange( 0, 0, nTab, MAXCOL, MAXROW, nTab)))
             bResult = true;
     }
     return bResult;
