@@ -17,15 +17,15 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "AccessibleSpreadsheet.hxx"
-#include "AccessibilityHints.hxx"
-#include "AccessibleCell.hxx"
-#include "AccessibleDocument.hxx"
-#include "tabvwsh.hxx"
-#include "document.hxx"
-#include "hints.hxx"
-#include "scmod.hxx"
-#include "markdata.hxx"
+#include <AccessibleSpreadsheet.hxx>
+#include <AccessibilityHints.hxx>
+#include <AccessibleCell.hxx>
+#include <AccessibleDocument.hxx>
+#include <tabvwsh.hxx>
+#include <document.hxx>
+#include <hints.hxx>
+#include <scmod.hxx>
+#include <markdata.hxx>
 #include <gridwin.hxx>
 
 #include <unotools/accessiblestatesethelper.hxx>
@@ -37,8 +37,8 @@
 #include <tools/gen.hxx>
 #include <svtools/colorcfg.hxx>
 #include <vcl/svapp.hxx>
-#include "scresid.hxx"
-#include "sc.hrc"
+#include <scresid.hxx>
+#include <strings.hrc>
 
 #include <algorithm>
 
@@ -106,7 +106,7 @@ ScMyAddress ScAccessibleSpreadsheet::CalcScAddressFromRangeList(ScRangeList *pMa
                     ScRange *p = *vi;
                     if ( row >= p->aStart.Row() && row <= p->aEnd.Row())
                     {
-                        m_vecTempCol.push_back(std::make_pair(p->aStart.Col(),p->aEnd.Col()));
+                        m_vecTempCol.emplace_back(p->aStart.Col(),p->aEnd.Col());
                     }
                 }
             }
@@ -129,7 +129,7 @@ ScMyAddress ScAccessibleSpreadsheet::CalcScAddressFromRangeList(ScRangeList *pMa
     return ScMyAddress(0,0,maActiveCell.Tab());
 }
 
-bool ScAccessibleSpreadsheet::CalcScRangeDifferenceMax(ScRange *pSrc, ScRange *pDest, int nMax, VEC_MYADDR &vecRet, int &nSize)
+bool ScAccessibleSpreadsheet::CalcScRangeDifferenceMax(const ScRange *pSrc, const ScRange *pDest, int nMax, VEC_MYADDR &vecRet, int &nSize)
 {
     //Src Must be :Src > Dest
     if (pDest->In(*pSrc))
@@ -151,7 +151,7 @@ bool ScAccessibleSpreadsheet::CalcScRangeDifferenceMax(ScRange *pSrc, ScRange *p
             {
                 for (sal_uInt16 col = pDest->aStart.Col(); col <=  pDest->aEnd.Col();++col)
                 {
-                    vecRet.push_back(ScMyAddress(col,row,pDest->aStart.Tab()));
+                    vecRet.emplace_back(col,row,pDest->aStart.Tab());
                 }
             }
         }
@@ -218,7 +218,7 @@ bool ScAccessibleSpreadsheet::CalcScRangeListDifferenceMax(ScRangeList *pSrc,ScR
             {
                 for (sal_uInt16 col = pRange->aStart.Col(); col <=  pRange->aEnd.Col();++col)
                 {
-                    vecRet.push_back(ScMyAddress(col,row,pRange->aStart.Tab()));
+                    vecRet.emplace_back(col,row,pRange->aStart.Tab());
                 }
             }
         }
@@ -253,8 +253,7 @@ ScAccessibleSpreadsheet::ScAccessibleSpreadsheet(
         SCTAB nTab,
         ScSplitPos eSplitPos)
     :
-    ScAccessibleTableBase (pAccDoc, GetDocument(pViewShell),
-        ScRange(ScAddress(0, 0, nTab),ScAddress(MAXCOL, MAXROW, nTab))),
+    ScAccessibleTableBase( pAccDoc, GetDocument(pViewShell), ScRange( 0, 0, nTab, MAXCOL, MAXROW, nTab)),
     mbIsSpreadsheet( true ),
     m_bFormulaMode( false ),
     m_bFormulaLastMode( false ),
@@ -286,12 +285,10 @@ void ScAccessibleSpreadsheet::ConstructScAccessibleSpreadsheet(
 {
     mpViewShell = pViewShell;
     mpMarkedRanges = nullptr;
-    mpSortedMarkedCells = nullptr;
     mpAccDoc = pAccDoc;
     mpAccCell.clear();
     meSplitPos = eSplitPos;
     mnTab = nTab;
-    mbHasSelection = false;
     mbDelIns = false;
     mbIsFocusSend = false;
     maVisCells = GetVisCells(GetVisArea(mpViewShell, meSplitPos));
@@ -300,10 +297,7 @@ void ScAccessibleSpreadsheet::ConstructScAccessibleSpreadsheet(
         mpViewShell->AddAccessibilityObject(*this);
 
         const ScViewData& rViewData = mpViewShell->GetViewData();
-        const ScMarkData& rMarkData = rViewData.GetMarkData();
         maActiveCell = rViewData.GetCurPos();
-        mbHasSelection = rMarkData.GetTableSelect(maActiveCell.Tab()) &&
-                    (rMarkData.IsMarked() || rMarkData.IsMultiMarked());
         mpAccCell = GetAccessibleCellAt(maActiveCell.Row(), maActiveCell.Col());
         ScDocument* pScDoc= GetDocument(mpViewShell);
         if (pScDoc)
@@ -334,14 +328,13 @@ void ScAccessibleSpreadsheet::CompleteSelectionChanged(bool bNewState)
     }
     if (mpMarkedRanges)
         DELETEZ(mpMarkedRanges);
-    mbHasSelection = bNewState;
 
     AccessibleEventObject aEvent;
     aEvent.EventId = AccessibleEventId::STATE_CHANGED;
     if (bNewState)
-        aEvent.NewValue = uno::makeAny(AccessibleStateType::SELECTED);
+        aEvent.NewValue <<= AccessibleStateType::SELECTED;
     else
-        aEvent.OldValue = uno::makeAny(AccessibleStateType::SELECTED);
+        aEvent.OldValue <<= AccessibleStateType::SELECTED;
     aEvent.Source = uno::Reference< XAccessibleContext >(this);
 
     CommitChange(aEvent);
@@ -418,10 +411,69 @@ void ScAccessibleSpreadsheet::VisAreaChanged()
 
 void ScAccessibleSpreadsheet::Notify( SfxBroadcaster& rBC, const SfxHint& rHint )
 {
-    const SfxSimpleHint* pSimpleHint = dynamic_cast<const SfxSimpleHint*>(&rHint);
-    if (pSimpleHint)
+    if ( dynamic_cast<const ScUpdateRefHint*>(&rHint) )
     {
-        if (pSimpleHint->GetId() == SC_HINT_ACC_CURSORCHANGED)
+        const ScUpdateRefHint& rRef = static_cast<const ScUpdateRefHint&>(rHint);
+        if (rRef.GetMode() == URM_INSDEL && rRef.GetDz() == 0) //test whether table is inserted or deleted
+        {
+            if (((rRef.GetRange().aStart.Col() == maRange.aStart.Col()) &&
+                (rRef.GetRange().aEnd.Col() == maRange.aEnd.Col())) ||
+                ((rRef.GetRange().aStart.Row() == maRange.aStart.Row()) &&
+                (rRef.GetRange().aEnd.Row() == maRange.aEnd.Row())))
+            {
+                // ignore next SfxHintId::ScDataChanged notification
+                mbDelIns = true;
+
+                sal_Int16 nId(0);
+                SCCOL nX(rRef.GetDx());
+                SCROW nY(rRef.GetDy());
+                ScRange aRange(rRef.GetRange());
+                if ((nX < 0) || (nY < 0))
+                {
+                    OSL_ENSURE(!((nX < 0) && (nY < 0)), "should not be possible to remove row and column at the same time");
+                    nId = AccessibleTableModelChangeType::DELETE;
+                    if (nX < 0)
+                    {
+                        nX = -nX;
+                        nY = aRange.aEnd.Row() - aRange.aStart.Row();
+                    }
+                    else
+                    {
+                        nY = -nY;
+                        nX = aRange.aEnd.Col() - aRange.aStart.Col();
+                    }
+                }
+                else if ((nX > 0) || (nY > 0))
+                {
+                    OSL_ENSURE(!((nX > 0) && (nY > 0)), "should not be possible to add row and column at the same time");
+                    nId = AccessibleTableModelChangeType::INSERT;
+                    if (nX < 0)
+                        nY = aRange.aEnd.Row() - aRange.aStart.Row();
+                    else
+                        nX = aRange.aEnd.Col() - aRange.aStart.Col();
+                }
+                else
+                {
+                    OSL_FAIL("is it a deletion or a insertion?");
+                }
+
+                CommitTableModelChange(rRef.GetRange().aStart.Row(),
+                    rRef.GetRange().aStart.Col(),
+                    rRef.GetRange().aStart.Row() + nY,
+                    rRef.GetRange().aStart.Col() + nX, nId);
+
+                AccessibleEventObject aEvent;
+                aEvent.EventId = AccessibleEventId::ACTIVE_DESCENDANT_CHANGED;
+                aEvent.Source = uno::Reference< XAccessibleContext >(this);
+                aEvent.NewValue <<= uno::Reference<XAccessible>(mpAccCell.get());
+
+                CommitChange(aEvent);
+            }
+        }
+    }
+    else
+    {
+        if (rHint.GetId() == SfxHintId::ScAccCursorChanged)
         {
             if (mpViewShell)
             {
@@ -472,14 +524,14 @@ void ScAccessibleSpreadsheet::Notify( SfxBroadcaster& rBC, const SfxHint& rHint
                 sal_uInt16 nTab = rViewData.GetTabNo();
                 ScRange aMarkRange;
                 refScMarkData.GetMarkArea(aMarkRange);
-                aEvent.OldValue <<= css::uno::Any();
+                aEvent.OldValue.clear();
                 //Mark All
                 if ( !bNewPosCellFocus &&
                     (bNewMarked || bIsMark || bIsMultMark ) &&
                     aMarkRange == ScRange( 0,0,nTab, MAXCOL,MAXROW,nTab ) )
                 {
                     aEvent.EventId = AccessibleEventId::SELECTION_CHANGED_WITHIN;
-                    aEvent.NewValue <<= css::uno::Any();
+                    aEvent.NewValue.clear();
                     CommitChange(aEvent);
                     return ;
                 }
@@ -511,7 +563,7 @@ void ScAccessibleSpreadsheet::Notify( SfxBroadcaster& rBC, const SfxHint& rHint
                         if( !bSelSmaller )
                         {
                             aEvent.EventId = AccessibleEventId::SELECTION_CHANGED_WITHIN;
-                            aEvent.NewValue <<= css::uno::Any();
+                            aEvent.NewValue.clear();
                             CommitChange(aEvent);
                         }
                         m_aLastWithInMarkRange = aMarkRange;
@@ -548,7 +600,7 @@ void ScAccessibleSpreadsheet::Notify( SfxBroadcaster& rBC, const SfxHint& rHint
                     aEvent.NewValue <<= xChild;
                     CommitChange(aEvent);
                     OSL_ASSERT(m_mapSelectionSend.count(aNewCell) == 0 );
-                    m_mapSelectionSend.insert(MAP_ADDR_XACC::value_type(aNewCell,xChild));
+                    m_mapSelectionSend.emplace(aNewCell,xChild);
 
                 }
                 else
@@ -558,7 +610,7 @@ void ScAccessibleSpreadsheet::Notify( SfxBroadcaster& rBC, const SfxHint& rHint
                     if ( (!bIsDel || aMarkRange != aDelRange) &&
                         bNewMarked &&
                         nNewMarkCount > 0 &&
-                        !IsSameMarkCell() )
+                        m_LastMarkedRanges != *mpMarkedRanges )
                     {
                         RemoveSelection(refScMarkData);
                         if(bNewPosCellFocus)
@@ -569,7 +621,7 @@ void ScAccessibleSpreadsheet::Notify( SfxBroadcaster& rBC, const SfxHint& rHint
                         if(CalcScRangeListDifferenceMax(mpMarkedRanges,&m_LastMarkedRanges,10,vecNew))
                         {
                             aEvent.EventId = AccessibleEventId::SELECTION_CHANGED_WITHIN;
-                            aEvent.NewValue <<= css::uno::Any();
+                            aEvent.NewValue.clear();
                             CommitChange(aEvent);
                         }
                         else
@@ -587,7 +639,7 @@ void ScAccessibleSpreadsheet::Notify( SfxBroadcaster& rBC, const SfxHint& rHint
                                 aEvent.EventId = AccessibleEventId::SELECTION_CHANGED_ADD;
                                 aEvent.NewValue <<= xChild;
                                 CommitChange(aEvent);
-                                m_mapSelectionSend.insert(MAP_ADDR_XACC::value_type(*viAddr,xChild));
+                                m_mapSelectionSend.emplace(*viAddr,xChild);
                             }
                         }
                     }
@@ -599,7 +651,7 @@ void ScAccessibleSpreadsheet::Notify( SfxBroadcaster& rBC, const SfxHint& rHint
                 m_LastMarkedRanges = *mpMarkedRanges;
             }
         }
-        else if (pSimpleHint->GetId() == SC_HINT_DATACHANGED)
+        else if (rHint.GetId() == SfxHintId::ScDataChanged)
         {
             if (!mbDelIns)
                 CommitTableModelChange(maRange.aStart.Row(), maRange.aStart.Col(), maRange.aEnd.Row(), maRange.aEnd.Col(), AccessibleTableModelChangeType::UPDATE);
@@ -657,75 +709,14 @@ void ScAccessibleSpreadsheet::Notify( SfxBroadcaster& rBC, const SfxHint& rHint
             }
         }*/
     }
-    else if ( dynamic_cast<const ScUpdateRefHint*>(&rHint) )
-    {
-        const ScUpdateRefHint& rRef = static_cast<const ScUpdateRefHint&>(rHint);
-        if (rRef.GetMode() == URM_INSDEL && rRef.GetDz() == 0) //test whether table is inserted or deleted
-        {
-            if (((rRef.GetRange().aStart.Col() == maRange.aStart.Col()) &&
-                (rRef.GetRange().aEnd.Col() == maRange.aEnd.Col())) ||
-                ((rRef.GetRange().aStart.Row() == maRange.aStart.Row()) &&
-                (rRef.GetRange().aEnd.Row() == maRange.aEnd.Row())))
-            {
-                // ignore next SC_HINT_DATACHANGED notification
-                mbDelIns = true;
-
-                sal_Int16 nId(0);
-                SCsCOL nX(rRef.GetDx());
-                SCsROW nY(rRef.GetDy());
-                ScRange aRange(rRef.GetRange());
-                if ((nX < 0) || (nY < 0))
-                {
-                    OSL_ENSURE(!((nX < 0) && (nY < 0)), "should not be possible to remove row and column at the same time");
-                    nId = AccessibleTableModelChangeType::DELETE;
-                    if (nX < 0)
-                    {
-                        nX = -nX;
-                        nY = aRange.aEnd.Row() - aRange.aStart.Row();
-                    }
-                    else
-                    {
-                        nY = -nY;
-                        nX = aRange.aEnd.Col() - aRange.aStart.Col();
-                    }
-                }
-                else if ((nX > 0) || (nY > 0))
-                {
-                    OSL_ENSURE(!((nX > 0) && (nY > 0)), "should not be possible to add row and column at the same time");
-                    nId = AccessibleTableModelChangeType::INSERT;
-                    if (nX < 0)
-                        nY = aRange.aEnd.Row() - aRange.aStart.Row();
-                    else
-                        nX = aRange.aEnd.Col() - aRange.aStart.Col();
-                }
-                else
-                {
-                    OSL_FAIL("is it a deletion or a insertion?");
-                }
-
-                CommitTableModelChange(rRef.GetRange().aStart.Row(),
-                    rRef.GetRange().aStart.Col(),
-                    rRef.GetRange().aStart.Row() + nY,
-                    rRef.GetRange().aStart.Col() + nX, nId);
-
-                AccessibleEventObject aEvent;
-                aEvent.EventId = AccessibleEventId::ACTIVE_DESCENDANT_CHANGED;
-                aEvent.Source = uno::Reference< XAccessibleContext >(this);
-                aEvent.NewValue <<= uno::Reference<XAccessible>(mpAccCell.get());
-
-                CommitChange(aEvent);
-            }
-        }
-    }
 
     ScAccessibleTableBase::Notify(rBC, rHint);
 }
 
-void ScAccessibleSpreadsheet::RemoveSelection(ScMarkData &refScMarkData)
+void ScAccessibleSpreadsheet::RemoveSelection(const ScMarkData &refScMarkData)
 {
     AccessibleEventObject aEvent;
     aEvent.Source = uno::Reference< XAccessible >(this);
-    aEvent.OldValue <<= css::uno::Any();
     MAP_ADDR_XACC::iterator miRemove = m_mapSelectionSend.begin();
     for(;  miRemove != m_mapSelectionSend.end() ;)
     {
@@ -767,15 +758,9 @@ void ScAccessibleSpreadsheet::CommitFocusCell(const ScAddress &aNewCell)
     CommitChange(aEvent);
 }
 
-bool ScAccessibleSpreadsheet::IsSameMarkCell()
-{
-    return m_LastMarkedRanges == *mpMarkedRanges;
-}
-
 //=====  XAccessibleTable  ================================================
 
 uno::Reference< XAccessibleTable > SAL_CALL ScAccessibleSpreadsheet::getAccessibleRowHeaders(  )
-                    throw (uno::RuntimeException, std::exception)
 {
     SolarMutexGuard aGuard;
     IsObjectValid();
@@ -794,7 +779,6 @@ uno::Reference< XAccessibleTable > SAL_CALL ScAccessibleSpreadsheet::getAccessib
 }
 
 uno::Reference< XAccessibleTable > SAL_CALL ScAccessibleSpreadsheet::getAccessibleColumnHeaders(  )
-                    throw (uno::RuntimeException, std::exception)
 {
     SolarMutexGuard aGuard;
     IsObjectValid();
@@ -813,7 +797,6 @@ uno::Reference< XAccessibleTable > SAL_CALL ScAccessibleSpreadsheet::getAccessib
 }
 
 uno::Sequence< sal_Int32 > SAL_CALL ScAccessibleSpreadsheet::getSelectedAccessibleRows(  )
-                    throw (uno::RuntimeException, std::exception)
 {
     SolarMutexGuard aGuard;
     IsObjectValid();
@@ -844,44 +827,36 @@ uno::Sequence< sal_Int32 > SAL_CALL ScAccessibleSpreadsheet::getSelectedAccessib
 }
 
 uno::Sequence< sal_Int32 > SAL_CALL ScAccessibleSpreadsheet::getSelectedAccessibleColumns(  )
-                    throw (uno::RuntimeException, std::exception)
 {
     SolarMutexGuard aGuard;
     IsObjectValid();
     uno::Sequence<sal_Int32> aSequence;
-    if (IsFormulaMode())
-    {
+    if (IsFormulaMode() || !mpViewShell)
         return aSequence;
-    }
-    if (mpViewShell)
+
+    aSequence.realloc(maRange.aEnd.Col() - maRange.aStart.Col() + 1);
+    sal_Int32* pSequence = aSequence.getArray();
+    sal_Int32 nCount(0);
+    const ScMarkData& rMarkdata = mpViewShell->GetViewData().GetMarkData();
+    for (SCCOL i = maRange.aStart.Col(); i <= maRange.aEnd.Col(); ++i)
     {
-        aSequence.realloc(maRange.aEnd.Col() - maRange.aStart.Col() + 1);
-        const ScMarkData& rMarkdata = mpViewShell->GetViewData().GetMarkData();
-        sal_Int32* pSequence = aSequence.getArray();
-        sal_Int32 nCount(0);
-        for (SCCOL i = maRange.aStart.Col(); i <= maRange.aEnd.Col(); ++i)
+        if (rMarkdata.IsColumnMarked(i))
         {
-            if (rMarkdata.IsColumnMarked(i))
-            {
-                pSequence[nCount] = i;
-                ++nCount;
-            }
+            pSequence[nCount] = i;
+            ++nCount;
         }
-        aSequence.realloc(nCount);
     }
-    else
-        aSequence.realloc(0);
+    aSequence.realloc(nCount);
     return aSequence;
 }
 
 sal_Bool SAL_CALL ScAccessibleSpreadsheet::isAccessibleRowSelected( sal_Int32 nRow )
-    throw (uno::RuntimeException, lang::IndexOutOfBoundsException, std::exception)
 {
     SolarMutexGuard aGuard;
     IsObjectValid();
     if (IsFormulaMode())
     {
-        return sal_False;
+        return false;
     }
 
     if ((nRow > (maRange.aEnd.Row() - maRange.aStart.Row())) || (nRow < 0))
@@ -897,14 +872,13 @@ sal_Bool SAL_CALL ScAccessibleSpreadsheet::isAccessibleRowSelected( sal_Int32 nR
 }
 
 sal_Bool SAL_CALL ScAccessibleSpreadsheet::isAccessibleColumnSelected( sal_Int32 nColumn )
-    throw (uno::RuntimeException, lang::IndexOutOfBoundsException, std::exception)
 {
     SolarMutexGuard aGuard;
     IsObjectValid();
 
     if (IsFormulaMode())
     {
-        return sal_False;
+        return false;
     }
     if ((nColumn > (maRange.aEnd.Col() - maRange.aStart.Col())) || (nColumn < 0))
         throw lang::IndexOutOfBoundsException();
@@ -944,7 +918,6 @@ rtl::Reference<ScAccessibleCell> ScAccessibleSpreadsheet::GetAccessibleCellAt(sa
 }
 
 uno::Reference< XAccessible > SAL_CALL ScAccessibleSpreadsheet::getAccessibleCellAt( sal_Int32 nRow, sal_Int32 nColumn )
-                    throw (uno::RuntimeException, lang::IndexOutOfBoundsException, std::exception)
 {
     SolarMutexGuard aGuard;
     IsObjectValid();
@@ -961,7 +934,6 @@ uno::Reference< XAccessible > SAL_CALL ScAccessibleSpreadsheet::getAccessibleCel
 }
 
 sal_Bool SAL_CALL ScAccessibleSpreadsheet::isAccessibleSelected( sal_Int32 nRow, sal_Int32 nColumn )
-    throw (uno::RuntimeException, lang::IndexOutOfBoundsException, std::exception)
 {
     SolarMutexGuard aGuard;
     IsObjectValid();
@@ -987,7 +959,6 @@ sal_Bool SAL_CALL ScAccessibleSpreadsheet::isAccessibleSelected( sal_Int32 nRow,
     //=====  XAccessibleComponent  ============================================
 
 uno::Reference< XAccessible > SAL_CALL ScAccessibleSpreadsheet::getAccessibleAtPoint(const awt::Point& rPoint)
-    throw (uno::RuntimeException, std::exception)
 {
     uno::Reference< XAccessible > xAccessible;
     if (containsPoint(rPoint))
@@ -996,8 +967,8 @@ uno::Reference< XAccessible > SAL_CALL ScAccessibleSpreadsheet::getAccessibleAtP
         IsObjectValid();
         if (mpViewShell)
         {
-            SCsCOL nX;
-            SCsROW nY;
+            SCCOL nX;
+            SCROW nY;
             mpViewShell->GetViewData().GetPosFromPixel( rPoint.X, rPoint.Y, meSplitPos, nX, nY);
             try {
                 xAccessible = getAccessibleCellAt(nY, nX);
@@ -1012,7 +983,6 @@ uno::Reference< XAccessible > SAL_CALL ScAccessibleSpreadsheet::getAccessibleAtP
 }
 
 void SAL_CALL ScAccessibleSpreadsheet::grabFocus(  )
-        throw (uno::RuntimeException, std::exception)
 {
     if (getAccessibleParent().is())
     {
@@ -1023,13 +993,11 @@ void SAL_CALL ScAccessibleSpreadsheet::grabFocus(  )
 }
 
 sal_Int32 SAL_CALL ScAccessibleSpreadsheet::getForeground(  )
-        throw (uno::RuntimeException, std::exception)
 {
     return COL_BLACK;
 }
 
 sal_Int32 SAL_CALL ScAccessibleSpreadsheet::getBackground(  )
-        throw (uno::RuntimeException, std::exception)
 {
     SolarMutexGuard aGuard;
     IsObjectValid();
@@ -1039,7 +1007,6 @@ sal_Int32 SAL_CALL ScAccessibleSpreadsheet::getBackground(  )
     //=====  XAccessibleContext  ==============================================
 
 uno::Reference<XAccessibleRelationSet> SAL_CALL ScAccessibleSpreadsheet::getAccessibleRelationSet()
-        throw (css::uno::RuntimeException, std::exception)
 {
     utl::AccessibleRelationSetHelper* pRelationSet = nullptr;
     if(mpAccDoc)
@@ -1051,7 +1018,6 @@ uno::Reference<XAccessibleRelationSet> SAL_CALL ScAccessibleSpreadsheet::getAcce
 
 uno::Reference<XAccessibleStateSet> SAL_CALL
     ScAccessibleSpreadsheet::getAccessibleStateSet()
-    throw (uno::RuntimeException, std::exception)
 {
     SolarMutexGuard aGuard;
     uno::Reference<XAccessibleStateSet> xParentStates;
@@ -1066,7 +1032,7 @@ uno::Reference<XAccessibleStateSet> SAL_CALL
     else
     {
         pStateSet->AddState(AccessibleStateType::MANAGES_DESCENDANTS);
-        if (IsEditable(xParentStates))
+        if (IsEditable())
             pStateSet->AddState(AccessibleStateType::EDITABLE);
         pStateSet->AddState(AccessibleStateType::ENABLED);
         pStateSet->AddState(AccessibleStateType::FOCUSABLE);
@@ -1088,7 +1054,6 @@ uno::Reference<XAccessibleStateSet> SAL_CALL
     ///=====  XAccessibleSelection  ===========================================
 
 void SAL_CALL ScAccessibleSpreadsheet::selectAccessibleChild( sal_Int32 nChildIndex )
-    throw (lang::IndexOutOfBoundsException, uno::RuntimeException, std::exception)
 {
     SolarMutexGuard aGuard;
     IsObjectValid();
@@ -1106,7 +1071,6 @@ void SAL_CALL ScAccessibleSpreadsheet::selectAccessibleChild( sal_Int32 nChildIn
 
 void SAL_CALL
         ScAccessibleSpreadsheet::clearAccessibleSelection(  )
-        throw (uno::RuntimeException, std::exception)
 {
     SolarMutexGuard aGuard;
     IsObjectValid();
@@ -1118,7 +1082,6 @@ void SAL_CALL
 }
 
 void SAL_CALL ScAccessibleSpreadsheet::selectAllAccessibleChildren(  )
-    throw (uno::RuntimeException, std::exception)
 {
     SolarMutexGuard aGuard;
     IsObjectValid();
@@ -1139,7 +1102,6 @@ void SAL_CALL ScAccessibleSpreadsheet::selectAllAccessibleChildren(  )
 
 sal_Int32 SAL_CALL
         ScAccessibleSpreadsheet::getSelectedAccessibleChildCount(  )
-        throw (uno::RuntimeException, std::exception)
 {
     SolarMutexGuard aGuard;
     IsObjectValid();
@@ -1168,7 +1130,6 @@ sal_Int32 SAL_CALL
 
 uno::Reference<XAccessible > SAL_CALL
         ScAccessibleSpreadsheet::getSelectedAccessibleChild( sal_Int32 nSelectedChildIndex )
-        throw (lang::IndexOutOfBoundsException, uno::RuntimeException, std::exception)
 {
     SolarMutexGuard aGuard;
     IsObjectValid();
@@ -1207,7 +1168,6 @@ uno::Reference<XAccessible > SAL_CALL
 }
 
 void SAL_CALL ScAccessibleSpreadsheet::deselectAccessibleChild( sal_Int32 nChildIndex )
-    throw (lang::IndexOutOfBoundsException, uno::RuntimeException, std::exception)
 {
     SolarMutexGuard aGuard;
     IsObjectValid();
@@ -1308,14 +1268,12 @@ void ScAccessibleSpreadsheet::AddMarkedRange(const ScRange& rRange)
     //=====  XServiceInfo  ====================================================
 
 OUString SAL_CALL ScAccessibleSpreadsheet::getImplementationName()
-        throw (uno::RuntimeException, std::exception)
 {
     return OUString("ScAccessibleSpreadsheet");
 }
 
 uno::Sequence< OUString> SAL_CALL
     ScAccessibleSpreadsheet::getSupportedServiceNames()
-        throw (uno::RuntimeException, std::exception)
 {
     uno::Sequence< OUString > aSequence = ScAccessibleTableBase::getSupportedServiceNames();
     sal_Int32 nOldSize(aSequence.getLength());
@@ -1330,7 +1288,6 @@ uno::Sequence< OUString> SAL_CALL
 
 uno::Sequence<sal_Int8> SAL_CALL
     ScAccessibleSpreadsheet::getImplementationId()
-    throw (uno::RuntimeException, std::exception)
 {
     return css::uno::Sequence<sal_Int8>();
 }
@@ -1338,7 +1295,6 @@ uno::Sequence<sal_Int8> SAL_CALL
 ///=====  XAccessibleEventBroadcaster  =====================================
 
 void SAL_CALL ScAccessibleSpreadsheet::addAccessibleEventListener(const uno::Reference<XAccessibleEventListener>& xListener)
-        throw (uno::RuntimeException, std::exception)
 {
     SolarMutexGuard aGuard;
     IsObjectValid();
@@ -1348,10 +1304,9 @@ void SAL_CALL ScAccessibleSpreadsheet::addAccessibleEventListener(const uno::Ref
 
 //====  internal  =========================================================
 
-Rectangle ScAccessibleSpreadsheet::GetBoundingBoxOnScreen() const
-    throw (uno::RuntimeException, std::exception)
+tools::Rectangle ScAccessibleSpreadsheet::GetBoundingBoxOnScreen() const
 {
-    Rectangle aRect;
+    tools::Rectangle aRect;
     if (mpViewShell)
     {
         vcl::Window* pWindow = mpViewShell->GetWindowByPos(meSplitPos);
@@ -1361,10 +1316,9 @@ Rectangle ScAccessibleSpreadsheet::GetBoundingBoxOnScreen() const
     return aRect;
 }
 
-Rectangle ScAccessibleSpreadsheet::GetBoundingBox() const
-    throw (uno::RuntimeException, std::exception)
+tools::Rectangle ScAccessibleSpreadsheet::GetBoundingBox() const
 {
-    Rectangle aRect;
+    tools::Rectangle aRect;
     if (mpViewShell)
     {
         vcl::Window* pWindow = mpViewShell->GetWindowByPos(meSplitPos);
@@ -1382,8 +1336,7 @@ bool ScAccessibleSpreadsheet::IsDefunc(
         (rxParentStates.is() && rxParentStates->contains(AccessibleStateType::DEFUNC));
 }
 
-bool ScAccessibleSpreadsheet::IsEditable(
-    const uno::Reference<XAccessibleStateSet>& /* rxParentStates */)
+bool ScAccessibleSpreadsheet::IsEditable()
 {
     if (IsFormulaMode())
     {
@@ -1433,9 +1386,9 @@ ScDocument* ScAccessibleSpreadsheet::GetDocument(ScTabViewShell* pViewShell)
     return pDoc;
 }
 
-Rectangle ScAccessibleSpreadsheet::GetVisArea(ScTabViewShell* pViewShell, ScSplitPos eSplitPos)
+tools::Rectangle ScAccessibleSpreadsheet::GetVisArea(ScTabViewShell* pViewShell, ScSplitPos eSplitPos)
 {
-    Rectangle aVisArea;
+    tools::Rectangle aVisArea;
     if (pViewShell)
     {
         vcl::Window* pWindow = pViewShell->GetWindowByPos(eSplitPos);
@@ -1448,30 +1401,29 @@ Rectangle ScAccessibleSpreadsheet::GetVisArea(ScTabViewShell* pViewShell, ScSpli
     return aVisArea;
 }
 
-Rectangle ScAccessibleSpreadsheet::GetVisCells(const Rectangle& rVisArea)
+tools::Rectangle ScAccessibleSpreadsheet::GetVisCells(const tools::Rectangle& rVisArea)
 {
     if (mpViewShell)
     {
-        SCsCOL nStartX, nEndX;
-        SCsROW nStartY, nEndY;
+        SCCOL nStartX, nEndX;
+        SCROW nStartY, nEndY;
 
         mpViewShell->GetViewData().GetPosFromPixel( 1, 1, meSplitPos, nStartX, nStartY);
         mpViewShell->GetViewData().GetPosFromPixel( rVisArea.GetWidth(), rVisArea.GetHeight(), meSplitPos, nEndX, nEndY);
 
-        return Rectangle(nStartX, nStartY, nEndX, nEndY);
+        return tools::Rectangle(nStartX, nStartY, nEndX, nEndY);
     }
     else
-        return Rectangle();
+        return tools::Rectangle();
 }
 
 sal_Bool SAL_CALL ScAccessibleSpreadsheet::selectRow( sal_Int32 row )
-    throw (lang::IndexOutOfBoundsException, uno::RuntimeException, std::exception)
 {
     SolarMutexGuard g;
 
     if (IsFormulaMode())
     {
-        return sal_False;
+        return false;
     }
 
     mpViewShell->SetTabNo( maRange.aStart.Tab() );
@@ -1479,17 +1431,16 @@ sal_Bool SAL_CALL ScAccessibleSpreadsheet::selectRow( sal_Int32 row )
     mpViewShell->InitBlockMode( 0, row, maRange.aStart.Tab(), false, false, true );
     mpViewShell->MarkCursor( MAXCOL, row, maRange.aStart.Tab(), false, true );
     mpViewShell->SelectionChanged();
-    return sal_True;
+    return true;
 }
 
 sal_Bool SAL_CALL ScAccessibleSpreadsheet::selectColumn( sal_Int32 column )
-        throw (lang::IndexOutOfBoundsException, uno::RuntimeException, std::exception)
 {
     SolarMutexGuard g;
 
     if (IsFormulaMode())
     {
-        return sal_False;
+        return false;
     }
 
     mpViewShell->SetTabNo( maRange.aStart.Tab() );
@@ -1497,17 +1448,16 @@ sal_Bool SAL_CALL ScAccessibleSpreadsheet::selectColumn( sal_Int32 column )
     mpViewShell->InitBlockMode( static_cast<SCCOL>(column), 0, maRange.aStart.Tab(), false, true );
     mpViewShell->MarkCursor( static_cast<SCCOL>(column), MAXROW, maRange.aStart.Tab(), true );
     mpViewShell->SelectionChanged();
-    return sal_True;
+    return true;
 }
 
 sal_Bool SAL_CALL ScAccessibleSpreadsheet::unselectRow( sal_Int32 row )
-        throw (lang::IndexOutOfBoundsException, uno::RuntimeException, std::exception)
 {
     SolarMutexGuard g;
 
     if (IsFormulaMode())
     {
-        return sal_False;
+        return false;
     }
 
     mpViewShell->SetTabNo( maRange.aStart.Tab() );
@@ -1516,17 +1466,16 @@ sal_Bool SAL_CALL ScAccessibleSpreadsheet::unselectRow( sal_Int32 row )
     mpViewShell->MarkCursor( MAXCOL, row, maRange.aStart.Tab(), false, true );
     mpViewShell->SelectionChanged();
     mpViewShell->DoneBlockMode( true );
-    return sal_True;
+    return true;
 }
 
 sal_Bool SAL_CALL ScAccessibleSpreadsheet::unselectColumn( sal_Int32 column )
-    throw (lang::IndexOutOfBoundsException, uno::RuntimeException, std::exception)
 {
     SolarMutexGuard g;
 
     if (IsFormulaMode())
     {
-        return sal_False;
+        return false;
     }
 
     mpViewShell->SetTabNo( maRange.aStart.Tab() );
@@ -1535,7 +1484,7 @@ sal_Bool SAL_CALL ScAccessibleSpreadsheet::unselectColumn( sal_Int32 column )
     mpViewShell->MarkCursor( static_cast<SCCOL>(column), MAXROW, maRange.aStart.Tab(), true );
     mpViewShell->SelectionChanged();
     mpViewShell->DoneBlockMode( true );
-    return sal_True;
+    return true;
 }
 
 void ScAccessibleSpreadsheet::FireFirstCellFocus()
@@ -1582,7 +1531,6 @@ void ScAccessibleSpreadsheet::NotifyRefMode()
         AccessibleEventObject aEvent;
         aEvent.Source = uno::Reference< XAccessible >(this);
         aEvent.EventId = AccessibleEventId::ACTIVE_DESCENDANT_CHANGED;
-        aEvent.Source = uno::Reference< XAccessible >(this);
         aEvent.OldValue <<= uno::Reference<XAccessible>(m_pAccFormulaCell.get());
         m_pAccFormulaCell = GetAccessibleCellAt(aFormulaAddr.Row(), aFormulaAddr.Col());
         uno::Reference< XAccessible > xNew = m_pAccFormulaCell.get();
@@ -1593,9 +1541,9 @@ void ScAccessibleSpreadsheet::NotifyRefMode()
             aEvent.EventId = AccessibleEventId::SELECTION_CHANGED;
             aEvent.NewValue <<= xNew;
             CommitChange(aEvent);
-            m_mapFormulaSelectionSend.insert(MAP_ADDR_XACC::value_type(aFormulaAddr,xNew));
+            m_mapFormulaSelectionSend.emplace(aFormulaAddr,xNew);
             m_vecFormulaLastMyAddr.clear();
-            m_vecFormulaLastMyAddr.push_back(aFormulaAddr);
+            m_vecFormulaLastMyAddr.emplace_back(aFormulaAddr);
         }
         else
         {
@@ -1619,7 +1567,7 @@ void ScAccessibleSpreadsheet::NotifyRefMode()
             if ( nNewSize > 10 )
             {
                 aEvent.EventId = AccessibleEventId::SELECTION_CHANGED_WITHIN;
-                aEvent.NewValue <<= css::uno::Any();
+                aEvent.NewValue.clear();
                 CommitChange(aEvent);
             }
             else
@@ -1642,7 +1590,7 @@ void ScAccessibleSpreadsheet::NotifyRefMode()
                     aEvent.EventId = AccessibleEventId::SELECTION_CHANGED_ADD;
                     aEvent.NewValue <<= xChild;
                     CommitChange(aEvent);
-                    m_mapFormulaSelectionSend.insert(MAP_ADDR_XACC::value_type(*viAddr,xChild));
+                    m_mapFormulaSelectionSend.emplace(*viAddr,xChild);
                 }
             }
             m_vecFormulaLastMyAddr.swap(vecCurSel);
@@ -1655,7 +1603,6 @@ void ScAccessibleSpreadsheet::RemoveFormulaSelection(bool bRemoveAll )
 {
     AccessibleEventObject aEvent;
     aEvent.Source = uno::Reference< XAccessible >(this);
-    aEvent.OldValue <<= css::uno::Any();
     MAP_ADDR_XACC::iterator miRemove = m_mapFormulaSelectionSend.begin();
     for(;  miRemove != m_mapFormulaSelectionSend.end() ;)
     {
@@ -1676,13 +1623,9 @@ void ScAccessibleSpreadsheet::RemoveFormulaSelection(bool bRemoveAll )
 
 bool ScAccessibleSpreadsheet::IsScAddrFormulaSel(const ScAddress &addr) const
 {
-    if( addr.Col() >= m_nMinX && addr.Col() <= m_nMaxX &&
+    return addr.Col() >= m_nMinX && addr.Col() <= m_nMaxX &&
         addr.Row() >= m_nMinY && addr.Row() <= m_nMaxY &&
-        addr.Tab() == mpViewShell->GetViewData().GetTabNo() )
-    {
-        return true;
-    }
-    return false;
+        addr.Tab() == mpViewShell->GetViewData().GetTabNo();
 }
 
 bool ScAccessibleSpreadsheet::CheckChildIndex(sal_Int32 nIndex) const
