@@ -8,44 +8,43 @@
  *
  */
 
+#include <memory>
 #include <sfx2/dispatch.hxx>
 #include <svl/zforlist.hxx>
 #include <svl/undo.hxx>
 
-#include "formulacell.hxx"
-#include "rangelst.hxx"
-#include "scitems.hxx"
-#include "docsh.hxx"
-#include "document.hxx"
-#include "uiitems.hxx"
-#include "reffact.hxx"
-#include "strload.hxx"
-#include "docfunc.hxx"
-#include "StatisticsDialogs.hrc"
-#include "TableFillingAndNavigationTools.hxx"
-
-#include "AnalysisOfVarianceDialog.hxx"
+#include <formulacell.hxx>
+#include <rangelst.hxx>
+#include <scitems.hxx>
+#include <docsh.hxx>
+#include <document.hxx>
+#include <uiitems.hxx>
+#include <reffact.hxx>
+#include <docfunc.hxx>
+#include <TableFillingAndNavigationTools.hxx>
+#include <AnalysisOfVarianceDialog.hxx>
+#include <strings.hrc>
 
 namespace
 {
 
 struct StatisticCalculation {
-    sal_Int16   aLabelId;
+    const char* aLabelId;
     const char* aFormula;
     const char* aResultRangeName;
 };
 
 static StatisticCalculation lclBasicStatistics[] =
 {
-    { STR_ANOVA_LABEL_GROUPS, NULL,                NULL          },
+    { STR_ANOVA_LABEL_GROUPS, nullptr,             nullptr       },
     { STRID_CALC_COUNT,       "=COUNT(%RANGE%)",   "COUNT_RANGE" },
     { STRID_CALC_SUM,         "=SUM(%RANGE%)",     "SUM_RANGE"   },
     { STRID_CALC_MEAN,        "=AVERAGE(%RANGE%)", "MEAN_RANGE"  },
     { STRID_CALC_VARIANCE,    "=VAR(%RANGE%)",     "VAR_RANGE"   },
-    { 0,                      NULL,                NULL          }
+    { nullptr,                nullptr,             nullptr       }
 };
 
-static sal_Int16 lclAnovaLabels[] =
+static const char* lclAnovaLabels[] =
 {
     STR_ANOVA_LABEL_SOURCE_OF_VARIATION,
     STR_ANOVA_LABEL_SS,
@@ -54,21 +53,20 @@ static sal_Int16 lclAnovaLabels[] =
     STR_ANOVA_LABEL_F,
     STR_ANOVA_LABEL_P_VALUE,
     STR_ANOVA_LABEL_F_CRITICAL,
-    0
+    nullptr
 };
 
 static const char strWildcardRange[] = "%RANGE%";
-static const char strWildcardNumber[] = "%NUMBER%";
 
 OUString lclCreateMultiParameterFormula(
             ScRangeList&        aRangeList, const OUString& aFormulaTemplate,
-            const OUString&     aWildcard,  ScDocument*     pDocument,
-            ScAddress::Details& aAddressDetails)
+            const OUString&     aWildcard,  const ScDocument*     pDocument,
+            const ScAddress::Details& aAddressDetails)
 {
     OUString aResult;
     for (size_t i = 0; i < aRangeList.size(); i++)
     {
-        OUString aRangeString(aRangeList[i]->Format(SCR_ABS, pDocument, aAddressDetails));
+        OUString aRangeString(aRangeList[i]->Format(ScRefFlags::RANGE_ABS, pDocument, aAddressDetails));
         OUString aFormulaString = aFormulaTemplate.replaceAll(aWildcard, aRangeString);
         aResult += aFormulaString;
         if(i != aRangeList.size() - 1) // Not Last
@@ -77,9 +75,9 @@ OUString lclCreateMultiParameterFormula(
     return aResult;
 }
 
-void lclMakeSubRangesList(ScRangeList& rRangeList, ScRange& rInputRange, ScStatisticsInputOutputDialog::GroupedBy aGroupedBy)
+void lclMakeSubRangesList(ScRangeList& rRangeList, const ScRange& rInputRange, ScStatisticsInputOutputDialog::GroupedBy aGroupedBy)
 {
-    boost::scoped_ptr<DataRangeIterator> pIterator;
+    std::unique_ptr<DataRangeIterator> pIterator;
     if (aGroupedBy == ScStatisticsInputOutputDialog::BY_COLUMN)
         pIterator.reset(new DataRangeByColumnIterator(rInputRange));
     else
@@ -110,10 +108,10 @@ ScAnalysisOfVarianceDialog::ScAnalysisOfVarianceDialog(
     mpSingleFactorRadio->SetToggleHdl( LINK( this, ScAnalysisOfVarianceDialog, FactorChanged ) );
     mpTwoFactorRadio->SetToggleHdl( LINK( this, ScAnalysisOfVarianceDialog, FactorChanged ) );
 
-    mpSingleFactorRadio->Check(true);
+    mpSingleFactorRadio->Check();
     mpTwoFactorRadio->Check(false);
 
-    FactorChanged(NULL);
+    FactorChanged();
 }
 
 ScAnalysisOfVarianceDialog::~ScAnalysisOfVarianceDialog()
@@ -135,17 +133,22 @@ bool ScAnalysisOfVarianceDialog::Close()
     return DoClose( ScAnalysisOfVarianceDialogWrapper::GetChildWindowId() );
 }
 
-sal_Int16 ScAnalysisOfVarianceDialog::GetUndoNameId()
+const char* ScAnalysisOfVarianceDialog::GetUndoNameId()
 {
     return STR_ANALYSIS_OF_VARIANCE_UNDO_NAME;
 }
 
-IMPL_LINK_NOARG( ScAnalysisOfVarianceDialog, FactorChanged )
+IMPL_LINK_NOARG( ScAnalysisOfVarianceDialog, FactorChanged, RadioButton&, void )
+{
+    FactorChanged();
+}
+
+void ScAnalysisOfVarianceDialog::FactorChanged()
 {
     if (mpSingleFactorRadio->IsChecked())
     {
-        mpGroupByRowsRadio->Enable(true);
-        mpGroupByColumnsRadio->Enable(true);
+        mpGroupByRowsRadio->Enable();
+        mpGroupByColumnsRadio->Enable();
         mpRowsPerSampleField->Enable(false);
         meFactor = SINGLE_FACTOR;
     }
@@ -156,14 +159,12 @@ IMPL_LINK_NOARG( ScAnalysisOfVarianceDialog, FactorChanged )
         mpRowsPerSampleField->Enable(false); // Rows per sample not yet implemented
         meFactor = TWO_FACTOR;
     }
-
-    return 0;
 }
 
 void ScAnalysisOfVarianceDialog::RowColumn(ScRangeList& rRangeList, AddressWalkerWriter& aOutput, FormulaTemplate& aTemplate,
-                                           OUString& sFormula, GroupedBy aGroupedBy, ScRange* pResultRange)
+                                           const OUString& sFormula, GroupedBy aGroupedBy, ScRange* pResultRange)
 {
-    if (pResultRange != NULL)
+    if (pResultRange != nullptr)
         pResultRange->aStart = aOutput.current();
     if (!sFormula.isEmpty())
     {
@@ -173,22 +174,22 @@ void ScAnalysisOfVarianceDialog::RowColumn(ScRangeList& rRangeList, AddressWalke
             aTemplate.setTemplate(sFormula);
             aTemplate.applyRange(strWildcardRange, *pRange);
             aOutput.writeFormula(aTemplate.getTemplate());
-            if (pResultRange != NULL)
+            if (pResultRange != nullptr)
                 pResultRange->aEnd = aOutput.current();
             aOutput.nextRow();
         }
     }
     else
     {
-        sal_Int16 aLabelId = (aGroupedBy == BY_COLUMN) ? STR_COLUMN_LABEL_TEMPLATE : STR_ROW_LABEL_TEMPLATE;
-        OUString aLabelTemplate(SC_STRLOAD(RID_STATISTICS_DLGS, aLabelId));
+        const char* pLabelId = (aGroupedBy == BY_COLUMN) ? STR_COLUMN_LABEL_TEMPLATE : STR_ROW_LABEL_TEMPLATE;
+        OUString aLabelTemplate(ScResId(pLabelId));
 
         for (size_t i = 0; i < rRangeList.size(); i++)
         {
             aTemplate.setTemplate(aLabelTemplate);
-            aTemplate.applyNumber(strWildcardNumber, i + 1);
+            aTemplate.applyNumber("%NUMBER%", i + 1);
             aOutput.writeString(aTemplate.getTemplate());
-            if (pResultRange != NULL)
+            if (pResultRange != nullptr)
                 pResultRange->aEnd = aOutput.current();
             aOutput.nextRow();
         }
@@ -197,11 +198,11 @@ void ScAnalysisOfVarianceDialog::RowColumn(ScRangeList& rRangeList, AddressWalke
 
 void ScAnalysisOfVarianceDialog::AnovaSingleFactor(AddressWalkerWriter& output, FormulaTemplate& aTemplate)
 {
-    output.writeBoldString(SC_STRLOAD(RID_STATISTICS_DLGS, STR_ANOVA_SINGLE_FACTOR_LABEL));
+    output.writeBoldString(ScResId(STR_ANOVA_SINGLE_FACTOR_LABEL));
     output.newLine();
 
     double aAlphaValue = mpAlphaField->GetValue() / 100.0;
-    output.writeString(SC_STRLOAD(RID_STATISTICS_DLGS, STR_LABEL_ALPHA));
+    output.writeString(ScResId(STR_LABEL_ALPHA));
     output.nextColumn();
     output.writeValue(aAlphaValue);
     aTemplate.autoReplaceAddress("%ALPHA%", output.current());
@@ -209,9 +210,9 @@ void ScAnalysisOfVarianceDialog::AnovaSingleFactor(AddressWalkerWriter& output,
     output.newLine();
 
     // Write labels
-    for(sal_Int32 i = 0; lclBasicStatistics[i].aLabelId != 0; i++)
+    for(sal_Int32 i = 0; lclBasicStatistics[i].aLabelId; i++)
     {
-        output.writeString(SC_STRLOAD(RID_STATISTICS_DLGS, lclBasicStatistics[i].aLabelId));
+        output.writeString(ScResId(lclBasicStatistics[i].aLabelId));
         output.nextColumn();
     }
     output.newLine();
@@ -223,14 +224,14 @@ void ScAnalysisOfVarianceDialog::AnovaSingleFactor(AddressWalkerWriter& output,
     output.push();
 
     // Write values
-    for(sal_Int32 i = 0; lclBasicStatistics[i].aLabelId != 0; i++)
+    for(sal_Int32 i = 0; lclBasicStatistics[i].aLabelId; i++)
     {
         output.resetRow();
         ScRange aResultRange;
         OUString sFormula = OUString::createFromAscii(lclBasicStatistics[i].aFormula);
         RowColumn(aRangeList, output, aTemplate, sFormula, mGroupedBy, &aResultRange);
         output.nextColumn();
-        if (lclBasicStatistics[i].aResultRangeName != NULL)
+        if (lclBasicStatistics[i].aResultRangeName != nullptr)
         {
             OUString sResultRangeName = OUString::createFromAscii(lclBasicStatistics[i].aResultRangeName);
             aTemplate.autoReplaceRange("%" + sResultRangeName + "%", aResultRange);
@@ -241,9 +242,9 @@ void ScAnalysisOfVarianceDialog::AnovaSingleFactor(AddressWalkerWriter& output,
 
     // Write ANOVA labels
     output.resetColumn();
-    for(sal_Int32 i = 0; lclAnovaLabels[i] != 0; i++)
+    for(sal_Int32 i = 0; lclAnovaLabels[i]; i++)
     {
-        output.writeString(SC_STRLOAD(RID_STATISTICS_DLGS, lclAnovaLabels[i]));
+        output.writeString(ScResId(lclAnovaLabels[i]));
         output.nextColumn();
     }
     output.nextRow();
@@ -254,7 +255,7 @@ void ScAnalysisOfVarianceDialog::AnovaSingleFactor(AddressWalkerWriter& output,
     {
         // Label
         output.resetColumn();
-        output.writeString(SC_STRLOAD(RID_STATISTICS_DLGS, STR_ANOVA_LABEL_BETWEEN_GROUPS));
+        output.writeString(ScResId(STR_ANOVA_LABEL_BETWEEN_GROUPS));
         output.nextColumn();
 
         // Sum of Squares
@@ -300,11 +301,11 @@ void ScAnalysisOfVarianceDialog::AnovaSingleFactor(AddressWalkerWriter& output,
     {
         // Label
         output.resetColumn();
-        output.writeString(SC_STRLOAD(RID_STATISTICS_DLGS, STR_ANOVA_LABEL_WITHIN_GROUPS));
+        output.writeString(ScResId(STR_ANOVA_LABEL_WITHIN_GROUPS));
         output.nextColumn();
 
         // Sum of Squares
-        OUString aSSPart = lclCreateMultiParameterFormula(aRangeList, OUString("DEVSQ(%RANGE%)"), strWildcardRange, mDocument, mAddressDetails);
+        OUString aSSPart = lclCreateMultiParameterFormula(aRangeList, "DEVSQ(%RANGE%)", strWildcardRange, mDocument, mAddressDetails);
         aTemplate.setTemplate("=SUM(%RANGE%)");
         aTemplate.applyString(strWildcardRange, aSSPart);
         aTemplate.autoReplaceAddress("%WITHIN_SS%", output.current());
@@ -327,7 +328,7 @@ void ScAnalysisOfVarianceDialog::AnovaSingleFactor(AddressWalkerWriter& output,
     {
         // Label
         output.resetColumn();
-        output.writeString(SC_STRLOAD(RID_STATISTICS_DLGS, STR_ANOVA_LABEL_TOTAL));
+        output.writeString(ScResId(STR_ANOVA_LABEL_TOTAL));
         output.nextColumn();
 
         // Sum of Squares
@@ -345,7 +346,7 @@ void ScAnalysisOfVarianceDialog::AnovaSingleFactor(AddressWalkerWriter& output,
 
 void ScAnalysisOfVarianceDialog::AnovaTwoFactor(AddressWalkerWriter& output, FormulaTemplate& aTemplate)
 {
-    output.writeBoldString(SC_STRLOAD(RID_STATISTICS_DLGS, STR_ANOVA_TWO_FACTOR_LABEL));
+    output.writeBoldString(ScResId(STR_ANOVA_TWO_FACTOR_LABEL));
     output.newLine();
 
     double aAlphaValue = mpAlphaField->GetValue() / 100.0;
@@ -357,9 +358,9 @@ void ScAnalysisOfVarianceDialog::AnovaTwoFactor(AddressWalkerWriter& output, For
     output.newLine();
 
     // Write labels
-    for(sal_Int32 i = 0; lclBasicStatistics[i].aLabelId != 0; i++)
+    for(sal_Int32 i = 0; lclBasicStatistics[i].aLabelId; i++)
     {
-        output.writeString(SC_STRLOAD(RID_STATISTICS_DLGS, lclBasicStatistics[i].aLabelId));
+        output.writeString(ScResId(lclBasicStatistics[i].aLabelId));
         output.nextColumn();
     }
     output.newLine();
@@ -372,13 +373,13 @@ void ScAnalysisOfVarianceDialog::AnovaTwoFactor(AddressWalkerWriter& output, For
 
     // Write ColumnX values
     output.push();
-    for(sal_Int32 i = 0; lclBasicStatistics[i].aLabelId != 0; i++)
+    for(sal_Int32 i = 0; lclBasicStatistics[i].aLabelId; i++)
     {
         output.resetRow();
         ScRange aResultRange;
         OUString sFormula = OUString::createFromAscii(lclBasicStatistics[i].aFormula);
         RowColumn(aColumnRangeList, output, aTemplate, sFormula, BY_COLUMN, &aResultRange);
-        if (lclBasicStatistics[i].aResultRangeName != NULL)
+        if (lclBasicStatistics[i].aResultRangeName != nullptr)
         {
             OUString sResultRangeName = OUString::createFromAscii(lclBasicStatistics[i].aResultRangeName);
             aTemplate.autoReplaceRange("%" + sResultRangeName + "_COLUMN%", aResultRange);
@@ -389,14 +390,14 @@ void ScAnalysisOfVarianceDialog::AnovaTwoFactor(AddressWalkerWriter& output, For
 
     // Write RowX values
     output.push();
-    for(sal_Int32 i = 0; lclBasicStatistics[i].aLabelId != 0; i++)
+    for(sal_Int32 i = 0; lclBasicStatistics[i].aLabelId; i++)
     {
         output.resetRow();
         ScRange aResultRange;
         OUString sFormula = OUString::createFromAscii(lclBasicStatistics[i].aFormula);
         RowColumn(aRowRangeList, output, aTemplate, sFormula, BY_ROW, &aResultRange);
 
-        if (lclBasicStatistics[i].aResultRangeName != NULL)
+        if (lclBasicStatistics[i].aResultRangeName != nullptr)
         {
             OUString sResultRangeName = OUString::createFromAscii(lclBasicStatistics[i].aResultRangeName);
             aTemplate.autoReplaceRange("%" + sResultRangeName + "_ROW%", aResultRange);
@@ -406,9 +407,9 @@ void ScAnalysisOfVarianceDialog::AnovaTwoFactor(AddressWalkerWriter& output, For
     output.newLine();
 
     // Write ANOVA labels
-    for(sal_Int32 i = 0; lclAnovaLabels[i] != 0; i++)
+    for(sal_Int32 i = 0; lclAnovaLabels[i]; i++)
     {
-        output.writeString(SC_STRLOAD(RID_STATISTICS_DLGS, lclAnovaLabels[i]));
+        output.writeString(ScResId(lclAnovaLabels[i]));
         output.nextColumn();
     }
     output.nextRow();
@@ -525,7 +526,7 @@ void ScAnalysisOfVarianceDialog::AnovaTwoFactor(AddressWalkerWriter& output, For
 
         // Degree of freedom
         aTemplate.setTemplate("=%TOTAL_DF% - %ROW_DF% - %COLUMN_DF%");
-        aTemplate.applyAddress("%TOTAL_DF%", output.current(0,1,0));
+        aTemplate.applyAddress("%TOTAL_DF%", output.current(0,1));
         aTemplate.autoReplaceAddress("%ERROR_DF%", output.current());
         output.writeFormula(aTemplate.getTemplate());
         output.nextColumn();
