@@ -21,59 +21,60 @@
 
 #include "scdlgfact.hxx"
 
-#include "sc.hrc"
-#include "scuiasciiopt.hxx"
-#include "scuiautofmt.hxx"
-#include "corodlg.hxx"
-#include "crdlg.hxx"
-#include "dapidata.hxx"
-#include "dapitype.hxx"
-#include "delcldlg.hxx"
-#include "delcodlg.hxx"
-#include "filldlg.hxx"
-#include "groupdlg.hxx"
-#include "inscldlg.hxx"
-#include "inscodlg.hxx"
-#include "instbdlg.hxx"
-#include "lbseldlg.hxx"
-#include "linkarea.hxx"
-#include "mtrindlg.hxx"
-#include "mvtabdlg.hxx"
-#include "namecrea.hxx"
-#include "namepast.hxx"
-#include "namedefdlg.hxx"
-#include "pfiltdlg.hxx"
-#include "pvfundlg.hxx"
-#include "dpgroupdlg.hxx"
-#include "scendlg.hxx"
-#include "shtabdlg.hxx"
-#include "strindlg.hxx"
-#include "tabbgcolordlg.hxx"
-#include "scuiimoptdlg.hxx"
-#include "attrdlg.hxx"
-#include "hfedtdlg.hxx"
-#include "styledlg.hxx"
-#include "subtdlg.hxx"
-#include "textdlgs.hxx"
-#include "sortdlg.hxx"
-#include "textimportoptions.hxx"
-#include "opredlin.hxx"
-#include "tpcalc.hxx"
-#include "tpprint.hxx"
-#include "tpstat.hxx"
-#include "tpusrlst.hxx"
-#include "tpview.hxx"
-#include "tpformula.hxx"
-#include "datafdlg.hxx"
-#include "tpcompatibility.hxx"
-#include "tpdefaults.hxx"
-#include "colorformat.hxx"
-#include "condformatdlg.hxx"
-#include "condformatmgr.hxx"
-#include "xmlsourcedlg.hxx"
-#include "editutil.hxx"
+#include <sc.hrc>
+#include <scuiasciiopt.hxx>
+#include <scuiautofmt.hxx>
+#include <corodlg.hxx>
+#include <crdlg.hxx>
+#include <dapidata.hxx>
+#include <dapitype.hxx>
+#include <delcldlg.hxx>
+#include <delcodlg.hxx>
+#include <filldlg.hxx>
+#include <groupdlg.hxx>
+#include <inscldlg.hxx>
+#include <inscodlg.hxx>
+#include <instbdlg.hxx>
+#include <lbseldlg.hxx>
+#include <linkarea.hxx>
+#include <mtrindlg.hxx>
+#include <mvtabdlg.hxx>
+#include <namecrea.hxx>
+#include <namepast.hxx>
+#include <namedefdlg.hxx>
+#include <pfiltdlg.hxx>
+#include <pvfundlg.hxx>
+#include <dpgroupdlg.hxx>
+#include <scendlg.hxx>
+#include <shtabdlg.hxx>
+#include <strindlg.hxx>
+#include <tabbgcolordlg.hxx>
+#include <scuiimoptdlg.hxx>
+#include <attrdlg.hxx>
+#include <hfedtdlg.hxx>
+#include <styledlg.hxx>
+#include <subtdlg.hxx>
+#include <textdlgs.hxx>
+#include <sortdlg.hxx>
+#include <textimportoptions.hxx>
+#include <opredlin.hxx>
+#include <tpcalc.hxx>
+#include <tpprint.hxx>
+#include <tpstat.hxx>
+#include <tpusrlst.hxx>
+#include <tpview.hxx>
+#include <tpformula.hxx>
+#include <datafdlg.hxx>
+#include <tpcompatibility.hxx>
+#include <tpdefaults.hxx>
+#include <colorformat.hxx>
+#include <condformatdlg.hxx>
+#include <condformatmgr.hxx>
+#include <xmlsourcedlg.hxx>
+#include <editutil.hxx>
+#include <scres.hrc>
+#include <svx/dialogs.hrc>
 
-IMPL_ABSTDLG_BASE(ScVclAbstractDialog_Impl);
 IMPL_ABSTDLG_BASE(AbstractScImportAsciiDlg_Impl);
 IMPL_ABSTDLG_BASE(AbstractScAutoFormatDlg_Impl);
 IMPL_ABSTDLG_BASE(AbstractScColRowLabelDlg_Impl);
@@ -91,7 +92,6 @@ IMPL_ABSTDLG_BASE(AbstractScInsertCellDlg_Impl);
 IMPL_ABSTDLG_BASE(AbstractScInsertContentsDlg_Impl);
 IMPL_ABSTDLG_BASE(AbstractScInsertTableDlg_Impl);
 IMPL_ABSTDLG_BASE(AbstractScSelEntryDlg_Impl);
-IMPL_ABSTDLG2_BASE(AbstractScLinkedAreaDlg_Impl);
 IMPL_ABSTDLG_BASE(AbstractScMetricInputDlg_Impl);
 IMPL_ABSTDLG_BASE(AbstractScMoveTableDlg_Impl);
 IMPL_ABSTDLG_BASE(AbstractScNameCreateDlg_Impl);
@@ -111,6 +111,14 @@ IMPL_ABSTDLG_BASE(AbstractScImportOptionsDlg_Impl);
 IMPL_ABSTDLG_BASE(AbstractScTextImportOptionsDlg_Impl);
 IMPL_ABSTDLG_BASE(ScAbstractTabDialog_Impl);
 
+AbstractScLinkedAreaDlg_Impl::~AbstractScLinkedAreaDlg_Impl()
+{
+}
+short AbstractScLinkedAreaDlg_Impl::Execute()
+{
+    return pDlg->Execute();
+}
+
 void ScAbstractTabDialog_Impl::SetCurPageId( sal_uInt16 nId )
 {
     pDlg->SetCurPageId( nId );
@@ -336,7 +344,7 @@ void    AbstractScInsertContentsDlg_Impl::SetChangeTrack( bool bSet )
     pDlg->SetChangeTrack( bSet );
 }
 
-void    AbstractScInsertContentsDlg_Impl::SetCellShiftDisabled( int nDisable )
+void    AbstractScInsertContentsDlg_Impl::SetCellShiftDisabled( CellShiftDisabledFlags nDisable )
 {
     pDlg->SetCellShiftDisabled( nDisable );
 }
@@ -381,9 +389,9 @@ const OUString* AbstractScInsertTableDlg_Impl::GetNextTable( sal_uInt16* pN )
     return pDlg->GetNextTable( pN );
 }
 
-OUString AbstractScSelEntryDlg_Impl::GetSelectEntry() const
+OUString AbstractScSelEntryDlg_Impl::GetSelectedEntry() const
 {
-    return pDlg->GetSelectEntry();
+    return pDlg->GetSelectedEntry();
 }
 
 void AbstractScLinkedAreaDlg_Impl::InitFromOldLink( const OUString& rFile, const OUString& rFilter,
@@ -423,11 +431,16 @@ ScConditionalFormatList* AbstractScCondFormatManagerDlg_Impl::GetConditionalForm
     return pDlg->GetConditionalFormatList();
 }
 
-bool AbstractScCondFormatManagerDlg_Impl::CondFormatsChanged()
+bool AbstractScCondFormatManagerDlg_Impl::CondFormatsChanged() const
 {
     return pDlg->CondFormatsChanged();
 }
 
+void AbstractScCondFormatManagerDlg_Impl::SetModified()
+{
+    return pDlg->SetModified();
+}
+
 ScConditionalFormat* AbstractScCondFormatManagerDlg_Impl::GetCondFormatSelected()
 {
     return pDlg->GetCondFormatSelected();
@@ -473,7 +486,7 @@ void    AbstractScMoveTableDlg_Impl::EnableRenameTable(bool bFlag)
     return pDlg->EnableRenameTable( bFlag);
 }
 
-sal_uInt16 AbstractScNameCreateDlg_Impl::GetFlags() const
+CreateNameFlags AbstractScNameCreateDlg_Impl::GetFlags() const
 {
     return pDlg->GetFlags();
 }
@@ -529,13 +542,13 @@ OUString AbstractScDPShowDetailDlg_Impl::GetDimensionName() const
 }
 
 void AbstractScNewScenarioDlg_Impl::SetScenarioData(
-    const OUString& rName, const OUString& rComment, const Color& rColor, sal_uInt16 nFlags )
+    const OUString& rName, const OUString& rComment, const Color& rColor, ScScenarioFlags nFlags )
 {
     pDlg->SetScenarioData(rName, rComment, rColor, nFlags);
 }
 
 void AbstractScNewScenarioDlg_Impl::GetScenarioData(
-    OUString& rName, OUString& rComment, Color& rColor, sal_uInt16& rFlags ) const
+    OUString& rName, OUString& rComment, Color& rColor, ScScenarioFlags& rFlags ) const
 {
     pDlg->GetScenarioData(rName, rComment, rColor, rFlags);
 }
@@ -545,9 +558,9 @@ void AbstractScShowTabDlg_Impl::Insert( const OUString& rString, bool bSelected
     pDlg->Insert( rString, bSelected);
 }
 
-sal_Int32 AbstractScShowTabDlg_Impl::GetSelectEntryCount() const
+sal_Int32 AbstractScShowTabDlg_Impl::GetSelectedEntryCount() const
 {
-    return pDlg->GetSelectEntryCount();
+    return pDlg->GetSelectedEntryCount();
 }
 
 void    AbstractScShowTabDlg_Impl::SetDescription(
@@ -557,14 +570,14 @@ void    AbstractScShowTabDlg_Impl::SetDescription(
     pDlg->SetDescription( rTitle, rFixedText, sDlgHelpId, sLbHelpId );
 }
 
-sal_Int32 AbstractScShowTabDlg_Impl::GetSelectEntryPos(sal_Int32 nPos) const
+sal_Int32 AbstractScShowTabDlg_Impl::GetSelectedEntryPos(sal_Int32 nPos) const
 {
-    return pDlg->GetSelectEntryPos( nPos);
+    return pDlg->GetSelectedEntryPos( nPos);
 }
 
-OUString AbstractScShowTabDlg_Impl::GetSelectEntry(sal_Int32 nPos) const
+OUString AbstractScShowTabDlg_Impl::GetSelectedEntry(sal_Int32 nPos) const
 {
-    return pDlg->GetSelectEntry(nPos);
+    return pDlg->GetSelectedEntry(nPos);
 }
 
 OUString AbstractScStringInputDlg_Impl::GetInputString() const
@@ -582,6 +595,11 @@ void AbstractScImportOptionsDlg_Impl::GetImportOptions( ScImportOptions& rOption
     pDlg->GetImportOptions(rOptions);
 }
 
+void AbstractScImportOptionsDlg_Impl::SaveImportOptions() const
+{
+    pDlg->SaveImportOptions();
+}
+
 LanguageType AbstractScTextImportOptionsDlg_Impl::GetLanguageType() const
 {
     return pDlg->getLanguageType();
@@ -593,113 +611,89 @@ bool AbstractScTextImportOptionsDlg_Impl::IsDateConversionSet() const
 }
 
 // =========================Factories  for createdialog ===================
-AbstractScImportAsciiDlg * ScAbstractDialogFactory_Impl::CreateScImportAsciiDlg ( const OUString& aDatName,
+VclPtr<AbstractScImportAsciiDlg> ScAbstractDialogFactory_Impl::CreateScImportAsciiDlg ( const OUString& aDatName,
                                                     SvStream* pInStream, ScImportAsciiCall eCall )
 {
     VclPtr<ScImportAsciiDlg> pDlg = VclPtr<ScImportAsciiDlg>::Create( nullptr, aDatName,pInStream, eCall );
-    return new AbstractScImportAsciiDlg_Impl( pDlg );
+    return VclPtr<AbstractScImportAsciiDlg_Impl>::Create( pDlg );
 }
 
-AbstractScTextImportOptionsDlg * ScAbstractDialogFactory_Impl::CreateScTextImportOptionsDlg()
+VclPtr<AbstractScTextImportOptionsDlg> ScAbstractDialogFactory_Impl::CreateScTextImportOptionsDlg()
 {
     VclPtr<ScTextImportOptionsDlg> pDlg = VclPtr<ScTextImportOptionsDlg>::Create(nullptr);
-    return new AbstractScTextImportOptionsDlg_Impl(pDlg);
+    return VclPtr<AbstractScTextImportOptionsDlg_Impl>::Create(pDlg);
 }
 
-AbstractScAutoFormatDlg * ScAbstractDialogFactory_Impl::CreateScAutoFormatDlg(vcl::Window* pParent,
+VclPtr<AbstractScAutoFormatDlg> ScAbstractDialogFactory_Impl::CreateScAutoFormatDlg(vcl::Window* pParent,
                                                                 ScAutoFormat* pAutoFormat,
                                                                 const ScAutoFormatData* pSelFormatData,
                                                                 ScViewData *pViewData)
 {
     VclPtr<ScAutoFormatDlg> pDlg = VclPtr<ScAutoFormatDlg>::Create(pParent, pAutoFormat, pSelFormatData, pViewData);
-    return new AbstractScAutoFormatDlg_Impl(pDlg);
+    return VclPtr<AbstractScAutoFormatDlg_Impl>::Create(pDlg);
 }
 
-AbstractScColRowLabelDlg *  ScAbstractDialogFactory_Impl::CreateScColRowLabelDlg(vcl::Window* pParent,
+VclPtr<AbstractScColRowLabelDlg>  ScAbstractDialogFactory_Impl::CreateScColRowLabelDlg(vcl::Window* pParent,
                                                                 bool bCol ,
                                                                 bool bRow)
 {
     VclPtr<ScColRowLabelDlg> pDlg = VclPtr<ScColRowLabelDlg>::Create( pParent, bCol,bRow );
-    return new AbstractScColRowLabelDlg_Impl( pDlg );
+    return VclPtr<AbstractScColRowLabelDlg_Impl>::Create( pDlg );
 }
 
-AbstractScSortWarningDlg* ScAbstractDialogFactory_Impl::CreateScSortWarningDlg( vcl::Window* pParent, const OUString& rExtendText, const OUString& rCurrentText )
+VclPtr<AbstractScSortWarningDlg> ScAbstractDialogFactory_Impl::CreateScSortWarningDlg( vcl::Window* pParent, const OUString& rExtendText, const OUString& rCurrentText )
 {
     VclPtr<ScSortWarningDlg> pDlg = VclPtr<ScSortWarningDlg>::Create(pParent, rExtendText, rCurrentText );
-    return new AbstractScSortWarningDlg_Impl( pDlg );
+    return VclPtr<AbstractScSortWarningDlg_Impl>::Create( pDlg );
 }
 
-AbstractScCondFormatManagerDlg* ScAbstractDialogFactory_Impl::CreateScCondFormatMgrDlg(vcl::Window* pParent, ScDocument* pDoc, const ScConditionalFormatList* pFormatList,
-                                                                int nId )
+VclPtr<AbstractScCondFormatManagerDlg> ScAbstractDialogFactory_Impl::CreateScCondFormatMgrDlg(vcl::Window* pParent, ScDocument* pDoc, const ScConditionalFormatList* pFormatList )
 {
-    VclPtr<ScCondFormatManagerDlg> pDlg;
-    switch( nId )
-    {
-        case RID_SCDLG_COND_FORMAT_MANAGER:
-            pDlg = VclPtr<ScCondFormatManagerDlg>::Create( pParent, pDoc, pFormatList );
-            break;
-        default:
-            break;
-    }
-    if(pDlg)
-        return new AbstractScCondFormatManagerDlg_Impl( pDlg );
-
-    return nullptr;
+    VclPtr<ScCondFormatManagerDlg> pDlg = VclPtr<ScCondFormatManagerDlg>::Create( pParent, pDoc, pFormatList );
+    return VclPtr<AbstractScCondFormatManagerDlg_Impl>::Create( pDlg );
 }
 
-AbstractScDataPilotDatabaseDlg *  ScAbstractDialogFactory_Impl::CreateScDataPilotDatabaseDlg(vcl::Window* pParent)
+VclPtr<AbstractScDataPilotDatabaseDlg> ScAbstractDialogFactory_Impl::CreateScDataPilotDatabaseDlg(vcl::Window* pParent)
 {
     VclPtr<ScDataPilotDatabaseDlg> pDlg = VclPtr<ScDataPilotDatabaseDlg>::Create( pParent );
-    return new AbstractScDataPilotDatabaseDlg_Impl( pDlg );
+    return VclPtr<AbstractScDataPilotDatabaseDlg_Impl>::Create( pDlg );
 }
 
-AbstractScDataPilotSourceTypeDlg* ScAbstractDialogFactory_Impl::CreateScDataPilotSourceTypeDlg(
+VclPtr<AbstractScDataPilotSourceTypeDlg> ScAbstractDialogFactory_Impl::CreateScDataPilotSourceTypeDlg(
     vcl::Window* pParent, bool bEnableExternal)
 {
     VclPtr<ScDataPilotSourceTypeDlg> pDlg = VclPtr<ScDataPilotSourceTypeDlg>::Create(pParent, bEnableExternal);
-    return new AbstractScDataPilotSourceTypeDlg_Impl(pDlg);
+    return VclPtr<AbstractScDataPilotSourceTypeDlg_Impl>::Create(pDlg);
 }
 
-AbstractScDataPilotServiceDlg* ScAbstractDialogFactory_Impl::CreateScDataPilotServiceDlg( vcl::Window* pParent,
-                                                                        const std::vector<OUString>& rServices,
-                                                            int nId )
+VclPtr<AbstractScDataPilotServiceDlg> ScAbstractDialogFactory_Impl::CreateScDataPilotServiceDlg( vcl::Window* pParent,
+                                                                        const std::vector<OUString>& rServices )
 {
-    VclPtr<ScDataPilotServiceDlg> pDlg;
-    switch ( nId )
-    {
-        case RID_SCDLG_DAPISERVICE :
-            pDlg = VclPtr<ScDataPilotServiceDlg>::Create( pParent, rServices );
-            break;
-        default:
-            break;
-    }
-
-    if ( pDlg )
-        return new AbstractScDataPilotServiceDlg_Impl( pDlg );
-    return nullptr;
+    VclPtr<ScDataPilotServiceDlg> pDlg = VclPtr<ScDataPilotServiceDlg>::Create( pParent, rServices );
+    return VclPtr<AbstractScDataPilotServiceDlg_Impl>::Create( pDlg );
 }
 
-AbstractScDeleteCellDlg* ScAbstractDialogFactory_Impl::CreateScDeleteCellDlg(vcl::Window* pParent,
+VclPtr<AbstractScDeleteCellDlg> ScAbstractDialogFactory_Impl::CreateScDeleteCellDlg(vcl::Window* pParent,
     bool bDisallowCellMove)
 {
     VclPtr<ScDeleteCellDlg> pDlg = VclPtr<ScDeleteCellDlg>::Create(pParent, bDisallowCellMove);
-    return new AbstractScDeleteCellDlg_Impl( pDlg );
+    return VclPtr<AbstractScDeleteCellDlg_Impl>::Create( pDlg );
 }
 
-AbstractScDataFormDlg* ScAbstractDialogFactory_Impl::CreateScDataFormDlg(vcl::Window* pParent,
+VclPtr<AbstractScDataFormDlg> ScAbstractDialogFactory_Impl::CreateScDataFormDlg(vcl::Window* pParent,
     ScTabViewShell* pTabViewShell)
 {
     VclPtr<ScDataFormDlg> pDlg = VclPtr<ScDataFormDlg>::Create(pParent, pTabViewShell);
-    return new AbstractScDataFormDlg_Impl(pDlg);
+    return VclPtr<AbstractScDataFormDlg_Impl>::Create(pDlg);
 }
 
-AbstractScDeleteContentsDlg* ScAbstractDialogFactory_Impl::CreateScDeleteContentsDlg(vcl::Window* pParent)
+VclPtr<AbstractScDeleteContentsDlg> ScAbstractDialogFactory_Impl::CreateScDeleteContentsDlg(vcl::Window* pParent)
 {
     VclPtr<ScDeleteContentsDlg> pDlg = VclPtr<ScDeleteContentsDlg>::Create(pParent, InsertDeleteFlags::NONE);
-    return new AbstractScDeleteContentsDlg_Impl( pDlg );
+    return VclPtr<AbstractScDeleteContentsDlg_Impl>::Create( pDlg );
 }
 
-AbstractScFillSeriesDlg* ScAbstractDialogFactory_Impl::CreateScFillSeriesDlg( vcl::Window*       pParent,
+VclPtr<AbstractScFillSeriesDlg> ScAbstractDialogFactory_Impl::CreateScFillSeriesDlg( vcl::Window*       pParent,
                                                             ScDocument&     rDocument,
                                                             FillDir         eFillDir,
                                                             FillCmd         eFillCmd,
@@ -710,201 +704,179 @@ AbstractScFillSeriesDlg* ScAbstractDialogFactory_Impl::CreateScFillSeriesDlg( vc
                                                             sal_uInt16      nPossDir)
 {
     VclPtr<ScFillSeriesDlg> pDlg = VclPtr<ScFillSeriesDlg>::Create( pParent, rDocument,eFillDir, eFillCmd,eFillDateCmd, aStartStr,fStep,fMax,nPossDir);
-    return new AbstractScFillSeriesDlg_Impl( pDlg );
+    return VclPtr<AbstractScFillSeriesDlg_Impl>::Create( pDlg );
 }
 
-AbstractScGroupDlg* ScAbstractDialogFactory_Impl::CreateAbstractScGroupDlg( vcl::Window* pParent,
+VclPtr<AbstractScGroupDlg> ScAbstractDialogFactory_Impl::CreateAbstractScGroupDlg( vcl::Window* pParent,
                                                             bool bUnGroup )
 {
     VclPtr<ScGroupDlg> pDlg = VclPtr<ScGroupDlg>::Create( pParent, bUnGroup, true/*bRows*/);
-    return new AbstractScGroupDlg_Impl( pDlg );
+    return VclPtr<AbstractScGroupDlg_Impl>::Create( pDlg );
 }
 
-AbstractScInsertCellDlg * ScAbstractDialogFactory_Impl::CreateScInsertCellDlg( vcl::Window* pParent,
-                                                                int nId,
+VclPtr<AbstractScInsertCellDlg> ScAbstractDialogFactory_Impl::CreateScInsertCellDlg( vcl::Window* pParent,
                                                                 bool bDisallowCellMove )
 {
-    VclPtr<ScInsertCellDlg> pDlg;
-    switch ( nId )
-    {
-        case RID_SCDLG_INSCELL :
-            pDlg = VclPtr<ScInsertCellDlg>::Create( pParent, bDisallowCellMove);
-            break;
-        default:
-            break;
-    }
-
-    if ( pDlg )
-        return new AbstractScInsertCellDlg_Impl( pDlg );
-    return nullptr;
+    VclPtr<ScInsertCellDlg> pDlg = VclPtr<ScInsertCellDlg>::Create( pParent, bDisallowCellMove);
+    return VclPtr<AbstractScInsertCellDlg_Impl>::Create( pDlg );
 }
 
-AbstractScInsertContentsDlg * ScAbstractDialogFactory_Impl::CreateScInsertContentsDlg( vcl::Window*      pParent,
+VclPtr<AbstractScInsertContentsDlg> ScAbstractDialogFactory_Impl::CreateScInsertContentsDlg( vcl::Window*      pParent,
                                                                                     const OUString* pStrTitle )
 {
     VclPtr<ScInsertContentsDlg> pDlg = VclPtr<ScInsertContentsDlg>::Create(pParent, InsertDeleteFlags::NONE, pStrTitle);
-    return new AbstractScInsertContentsDlg_Impl( pDlg );
+    return VclPtr<AbstractScInsertContentsDlg_Impl>::Create( pDlg );
 }
 
-AbstractScInsertTableDlg * ScAbstractDialogFactory_Impl::CreateScInsertTableDlg(vcl::Window* pParent, ScViewData& rViewData,
+VclPtr<AbstractScInsertTableDlg> ScAbstractDialogFactory_Impl::CreateScInsertTableDlg(vcl::Window* pParent, ScViewData& rViewData,
     SCTAB nTabCount, bool bFromFile)
 {
     VclPtr<ScInsertTableDlg> pDlg = VclPtr<ScInsertTableDlg>::Create( pParent, rViewData,nTabCount, bFromFile );
-    return new AbstractScInsertTableDlg_Impl( pDlg );
+    return VclPtr<AbstractScInsertTableDlg_Impl>::Create( pDlg );
 }
 
-AbstractScSelEntryDlg * ScAbstractDialogFactory_Impl::CreateScSelEntryDlg ( vcl::Window* pParent,
+VclPtr<AbstractScSelEntryDlg> ScAbstractDialogFactory_Impl::CreateScSelEntryDlg ( vcl::Window* pParent,
                                                         const std::vector<OUString> &rEntryList )
 {
     VclPtr<ScSelEntryDlg> pDlg = VclPtr<ScSelEntryDlg>::Create( pParent, rEntryList );
-    return new AbstractScSelEntryDlg_Impl( pDlg );
+    return VclPtr<AbstractScSelEntryDlg_Impl>::Create( pDlg );
 }
 
-AbstractScLinkedAreaDlg * ScAbstractDialogFactory_Impl::CreateScLinkedAreaDlg(vcl::Window* pParent)
+VclPtr<AbstractScLinkedAreaDlg> ScAbstractDialogFactory_Impl::CreateScLinkedAreaDlg(vcl::Window* pParent)
 {
     VclPtr<ScLinkedAreaDlg> pDlg = VclPtr<ScLinkedAreaDlg>::Create( pParent );
-    return new AbstractScLinkedAreaDlg_Impl( pDlg );
+    return VclPtr<AbstractScLinkedAreaDlg_Impl>::Create( pDlg );
 }
 
-AbstractScMetricInputDlg * ScAbstractDialogFactory_Impl::CreateScMetricInputDlg (  vcl::Window*      pParent,
+VclPtr<AbstractScMetricInputDlg> ScAbstractDialogFactory_Impl::CreateScMetricInputDlg (  vcl::Window*      pParent,
                                                                 const OString& sDialogName,
                                                                 long            nCurrent,
                                                                 long            nDefault,
                                                                 FieldUnit       eFUnit,
                                                                 sal_uInt16      nDecimals,
                                                                 long            nMaximum ,
-                                                                long            nMinimum,
-                                                                long            nFirst,
-                                                                long            nLast )
+                                                                long            nMinimum )
 {
     VclPtr<ScMetricInputDlg> pDlg = VclPtr<ScMetricInputDlg>::Create(pParent, sDialogName, nCurrent ,nDefault, eFUnit,
-        nDecimals, nMaximum , nMinimum , nFirst, nLast);
-    return new AbstractScMetricInputDlg_Impl( pDlg );
+        nDecimals, nMaximum , nMinimum , 1, 100);
+    return VclPtr<AbstractScMetricInputDlg_Impl>::Create( pDlg );
 }
 
-AbstractScMoveTableDlg * ScAbstractDialogFactory_Impl::CreateScMoveTableDlg(vcl::Window* pParent,
+VclPtr<AbstractScMoveTableDlg> ScAbstractDialogFactory_Impl::CreateScMoveTableDlg(vcl::Window* pParent,
     const OUString& rDefault)
 {
     VclPtr<ScMoveTableDlg> pDlg = VclPtr<ScMoveTableDlg>::Create( pParent, rDefault );
-    return new AbstractScMoveTableDlg_Impl( pDlg );
+    return VclPtr<AbstractScMoveTableDlg_Impl>::Create( pDlg );
 }
 
-AbstractScNameCreateDlg * ScAbstractDialogFactory_Impl::CreateScNameCreateDlg(vcl::Window * pParent, sal_uInt16 nFlags)
+VclPtr<AbstractScNameCreateDlg> ScAbstractDialogFactory_Impl::CreateScNameCreateDlg(vcl::Window * pParent, CreateNameFlags nFlags)
 {
     VclPtr<ScNameCreateDlg> pDlg = VclPtr<ScNameCreateDlg>::Create( pParent, nFlags );
-    return new AbstractScNameCreateDlg_Impl( pDlg );
+    return VclPtr<AbstractScNameCreateDlg_Impl>::Create( pDlg );
 }
 
-AbstractScNamePasteDlg * ScAbstractDialogFactory_Impl::CreateScNamePasteDlg ( vcl::Window * pParent, ScDocShell* pShell, bool bInsList )
+VclPtr<AbstractScNamePasteDlg> ScAbstractDialogFactory_Impl::CreateScNamePasteDlg ( vcl::Window * pParent, ScDocShell* pShell )
 {
-    VclPtr<ScNamePasteDlg> pDlg = VclPtr<ScNamePasteDlg>::Create( pParent, pShell, bInsList );
-    return new AbstractScNamePasteDlg_Impl( pDlg );
+    VclPtr<ScNamePasteDlg> pDlg = VclPtr<ScNamePasteDlg>::Create( pParent, pShell );
+    return VclPtr<AbstractScNamePasteDlg_Impl>::Create( pDlg );
 }
 
-AbstractScPivotFilterDlg * ScAbstractDialogFactory_Impl::CreateScPivotFilterDlg(vcl::Window* pParent,
+VclPtr<AbstractScPivotFilterDlg> ScAbstractDialogFactory_Impl::CreateScPivotFilterDlg(vcl::Window* pParent,
     const SfxItemSet& rArgSet, sal_uInt16 nSourceTab)
 {
     VclPtr<ScPivotFilterDlg> pDlg = VclPtr<ScPivotFilterDlg>::Create(pParent, rArgSet, nSourceTab);
-    return new AbstractScPivotFilterDlg_Impl(pDlg);
+    return VclPtr<AbstractScPivotFilterDlg_Impl>::Create(pDlg);
 }
 
-AbstractScDPFunctionDlg * ScAbstractDialogFactory_Impl::CreateScDPFunctionDlg ( vcl::Window* pParent,
+VclPtr<AbstractScDPFunctionDlg> ScAbstractDialogFactory_Impl::CreateScDPFunctionDlg ( vcl::Window* pParent,
                                                                 const ScDPLabelDataVector& rLabelVec,
                                                                 const ScDPLabelData& rLabelData,
                                                                 const ScPivotFuncData& rFuncData )
 {
     VclPtr<ScDPFunctionDlg> pDlg = VclPtr<ScDPFunctionDlg>::Create( pParent, rLabelVec, rLabelData, rFuncData );
-    return new AbstractScDPFunctionDlg_Impl( pDlg );
+    return VclPtr<AbstractScDPFunctionDlg_Impl>::Create( pDlg );
 }
 
-AbstractScDPSubtotalDlg * ScAbstractDialogFactory_Impl::CreateScDPSubtotalDlg ( vcl::Window* pParent,
+VclPtr<AbstractScDPSubtotalDlg> ScAbstractDialogFactory_Impl::CreateScDPSubtotalDlg ( vcl::Window* pParent,
                                                                 ScDPObject& rDPObj,
                                                                 const ScDPLabelData& rLabelData,
                                                                 const ScPivotFuncData& rFuncData,
                                                                 const ScDPNameVec& rDataFields )
 {
     VclPtr<ScDPSubtotalDlg> pDlg = VclPtr<ScDPSubtotalDlg>::Create( pParent, rDPObj, rLabelData, rFuncData, rDataFields, true/*bEnableLayout*/ );
-    return new AbstractScDPSubtotalDlg_Impl( pDlg );
+    return VclPtr<AbstractScDPSubtotalDlg_Impl>::Create( pDlg );
 }
 
-AbstractScDPNumGroupDlg * ScAbstractDialogFactory_Impl::CreateScDPNumGroupDlg(
-        vcl::Window* pParent, int nId, const ScDPNumGroupInfo& rInfo )
+VclPtr<AbstractScDPNumGroupDlg> ScAbstractDialogFactory_Impl::CreateScDPNumGroupDlg(
+        vcl::Window* pParent, const ScDPNumGroupInfo& rInfo )
 {
-    if( nId == RID_SCDLG_DPNUMGROUP )
-        return new AbstractScDPNumGroupDlg_Impl( VclPtr<ScDPNumGroupDlg>::Create( pParent, rInfo ) );
-    return nullptr;
+    return VclPtr<AbstractScDPNumGroupDlg_Impl>::Create( VclPtr<ScDPNumGroupDlg>::Create( pParent, rInfo ) );
 }
 
-AbstractScDPDateGroupDlg * ScAbstractDialogFactory_Impl::CreateScDPDateGroupDlg(
-        vcl::Window* pParent, int nId,
+VclPtr<AbstractScDPDateGroupDlg> ScAbstractDialogFactory_Impl::CreateScDPDateGroupDlg(
+        vcl::Window* pParent,
         const ScDPNumGroupInfo& rInfo, sal_Int32 nDatePart, const Date& rNullDate )
 {
-    if( nId == RID_SCDLG_DPDATEGROUP )
-        return new AbstractScDPDateGroupDlg_Impl( VclPtr<ScDPDateGroupDlg>::Create( pParent, rInfo, nDatePart, rNullDate ) );
-    return nullptr;
+    return VclPtr<AbstractScDPDateGroupDlg_Impl>::Create( VclPtr<ScDPDateGroupDlg>::Create( pParent, rInfo, nDatePart, rNullDate ) );
 }
 
-AbstractScDPShowDetailDlg * ScAbstractDialogFactory_Impl::CreateScDPShowDetailDlg (
-        vcl::Window* pParent, int nId, ScDPObject& rDPObj, sal_uInt16 nOrient )
+VclPtr<AbstractScDPShowDetailDlg> ScAbstractDialogFactory_Impl::CreateScDPShowDetailDlg (
+        vcl::Window* pParent, ScDPObject& rDPObj, css::sheet::DataPilotFieldOrientation nOrient )
 {
-    if( nId == RID_SCDLG_DPSHOWDETAIL )
-        return new AbstractScDPShowDetailDlg_Impl( VclPtr<ScDPShowDetailDlg>::Create( pParent, rDPObj, nOrient ) );
-    return nullptr;
+    return VclPtr<AbstractScDPShowDetailDlg_Impl>::Create( VclPtr<ScDPShowDetailDlg>::Create( pParent, rDPObj, nOrient ) );
 }
 
-AbstractScNewScenarioDlg * ScAbstractDialogFactory_Impl::CreateScNewScenarioDlg(vcl::Window* pParent, const OUString& rName,
+VclPtr<AbstractScNewScenarioDlg> ScAbstractDialogFactory_Impl::CreateScNewScenarioDlg(vcl::Window* pParent, const OUString& rName,
     bool bEdit, bool bSheetProtected)
 {
     VclPtr<ScNewScenarioDlg> pDlg = VclPtr<ScNewScenarioDlg>::Create(pParent, rName, bEdit, bSheetProtected);
-    return new AbstractScNewScenarioDlg_Impl( pDlg );
+    return VclPtr<AbstractScNewScenarioDlg_Impl>::Create( pDlg );
 }
 
-AbstractScShowTabDlg * ScAbstractDialogFactory_Impl::CreateScShowTabDlg(vcl::Window* pParent)
+VclPtr<AbstractScShowTabDlg> ScAbstractDialogFactory_Impl::CreateScShowTabDlg(vcl::Window* pParent)
 {
     VclPtr<ScShowTabDlg> pDlg = VclPtr<ScShowTabDlg>::Create( pParent);
-    return new AbstractScShowTabDlg_Impl( pDlg );
+    return VclPtr<AbstractScShowTabDlg_Impl>::Create( pDlg );
 }
 
-AbstractScStringInputDlg * ScAbstractDialogFactory_Impl::CreateScStringInputDlg (  vcl::Window* pParent,
+VclPtr<AbstractScStringInputDlg> ScAbstractDialogFactory_Impl::CreateScStringInputDlg (  vcl::Window* pParent,
                                                                 const OUString& rTitle,
                                                                 const OUString& rEditTitle,
                                                                 const OUString& rDefault,
                                                                 const OString& sHelpId, const OString& sEditHelpId )
 {
     VclPtr<ScStringInputDlg> pDlg = VclPtr<ScStringInputDlg>::Create( pParent, rTitle, rEditTitle, rDefault, sHelpId, sEditHelpId );
-    return new AbstractScStringInputDlg_Impl( pDlg );
+    return VclPtr<AbstractScStringInputDlg_Impl>::Create( pDlg );
 }
 
-AbstractScTabBgColorDlg * ScAbstractDialogFactory_Impl::CreateScTabBgColorDlg(
+VclPtr<AbstractScTabBgColorDlg> ScAbstractDialogFactory_Impl::CreateScTabBgColorDlg(
                                                             vcl::Window* pParent,
                                                             const OUString& rTitle,
                                                             const OUString& rTabBgColorNoColorText,
-                                                            const Color& rDefaultColor,
-                                                            const OString& sHelpId)
+                                                            const Color& rDefaultColor)
 {
-    VclPtr<ScTabBgColorDlg> pDlg = VclPtr<ScTabBgColorDlg>::Create( pParent, rTitle, rTabBgColorNoColorText, rDefaultColor, sHelpId );
-    return new AbstractScTabBgColorDlg_Impl( pDlg );
+    VclPtr<ScTabBgColorDlg> pDlg = VclPtr<ScTabBgColorDlg>::Create( pParent, rTitle, rTabBgColorNoColorText, rDefaultColor );
+    return VclPtr<AbstractScTabBgColorDlg_Impl>::Create( pDlg );
 }
 
-AbstractScImportOptionsDlg * ScAbstractDialogFactory_Impl::CreateScImportOptionsDlg (
+VclPtr<AbstractScImportOptionsDlg> ScAbstractDialogFactory_Impl::CreateScImportOptionsDlg (
                                                                     bool                    bAscii,
                                                                     const ScImportOptions*  pOptions,
                                                                     const OUString*         pStrTitle,
-                                                                    bool                    bMultiByte,
                                                                     bool                    bOnlyDbtoolsEncodings,
                                                                     bool                    bImport )
 {
-    VclPtr<ScImportOptionsDlg> pDlg = VclPtr<ScImportOptionsDlg>::Create( nullptr, bAscii, pOptions,pStrTitle, bMultiByte,bOnlyDbtoolsEncodings, bImport );
-    return new AbstractScImportOptionsDlg_Impl( pDlg );
+    VclPtr<ScImportOptionsDlg> pDlg = VclPtr<ScImportOptionsDlg>::Create( nullptr, bAscii, pOptions,pStrTitle, true/*bMultiByte*/,bOnlyDbtoolsEncodings, bImport );
+    return VclPtr<AbstractScImportOptionsDlg_Impl>::Create( pDlg );
 }
 
-SfxAbstractTabDialog * ScAbstractDialogFactory_Impl::CreateScAttrDlg(vcl::Window* pParent, const SfxItemSet* pCellAttrs)
+VclPtr<SfxAbstractTabDialog> ScAbstractDialogFactory_Impl::CreateScAttrDlg(vcl::Window* pParent, const SfxItemSet* pCellAttrs)
 {
     VclPtr<SfxTabDialog> pDlg = VclPtr<ScAttrDlg>::Create(pParent, pCellAttrs);
-    return new ScAbstractTabDialog_Impl(pDlg);
+    return VclPtr<ScAbstractTabDialog_Impl>::Create(pDlg);
 }
 
-SfxAbstractTabDialog * ScAbstractDialogFactory_Impl::CreateScHFEditDlg( vcl::Window*         pParent,
+VclPtr<SfxAbstractTabDialog> ScAbstractDialogFactory_Impl::CreateScHFEditDlg( vcl::Window*         pParent,
                                                                         const SfxItemSet&   rCoreSet,
                                                                         const OUString&     rPageStyle,
                                                                         sal_uInt16          nResId )
@@ -948,10 +920,10 @@ SfxAbstractTabDialog * ScAbstractDialogFactory_Impl::CreateScHFEditDlg( vcl::Win
             break;
     }
 
-    return pDlg ? new ScAbstractTabDialog_Impl( pDlg ) : nullptr;
+    return pDlg ? VclPtr<ScAbstractTabDialog_Impl>::Create( pDlg ) : nullptr;
 }
 
-SfxAbstractTabDialog * ScAbstractDialogFactory_Impl::CreateScStyleDlg( vcl::Window*              pParent,
+VclPtr<SfxAbstractTabDialog> ScAbstractDialogFactory_Impl::CreateScStyleDlg( vcl::Window*              pParent,
                                                                         SfxStyleSheetBase&  rStyleBase,
                                                                         sal_uInt16              nRscId,
                                                                         int nId)
@@ -968,60 +940,60 @@ SfxAbstractTabDialog * ScAbstractDialogFactory_Impl::CreateScStyleDlg( vcl::Wind
     }
 
     if ( pDlg )
-        return new ScAbstractTabDialog_Impl( pDlg );
+        return VclPtr<ScAbstractTabDialog_Impl>::Create( pDlg );
     return nullptr;
 }
 
-SfxAbstractTabDialog * ScAbstractDialogFactory_Impl::CreateScSubTotalDlg(vcl::Window* pParent, const SfxItemSet* pArgSet)
+VclPtr<SfxAbstractTabDialog> ScAbstractDialogFactory_Impl::CreateScSubTotalDlg(vcl::Window* pParent, const SfxItemSet* pArgSet)
 {
     VclPtr<SfxTabDialog> pDlg = VclPtr<ScSubTotalDlg>::Create( pParent, pArgSet );
-    return new ScAbstractTabDialog_Impl( pDlg );
+    return VclPtr<ScAbstractTabDialog_Impl>::Create( pDlg );
 }
 
-SfxAbstractTabDialog * ScAbstractDialogFactory_Impl::CreateScCharDlg(
+VclPtr<SfxAbstractTabDialog> ScAbstractDialogFactory_Impl::CreateScCharDlg(
     vcl::Window* pParent, const SfxItemSet* pAttr, const SfxObjectShell* pDocShell)
 {
     VclPtr<SfxTabDialog> pDlg = VclPtr<ScCharDlg>::Create(pParent, pAttr, pDocShell);
-    return new ScAbstractTabDialog_Impl(pDlg);
+    return VclPtr<ScAbstractTabDialog_Impl>::Create(pDlg);
 }
 
-SfxAbstractTabDialog * ScAbstractDialogFactory_Impl::CreateScParagraphDlg(
+VclPtr<SfxAbstractTabDialog> ScAbstractDialogFactory_Impl::CreateScParagraphDlg(
     vcl::Window* pParent, const SfxItemSet* pAttr)
 {
     VclPtr<SfxTabDialog> pDlg = VclPtr<ScParagraphDlg>::Create(pParent, pAttr);
-    return new ScAbstractTabDialog_Impl(pDlg);
+    return VclPtr<ScAbstractTabDialog_Impl>::Create(pDlg);
 }
 
-SfxAbstractTabDialog * ScAbstractDialogFactory_Impl::CreateScSortDlg(vcl::Window* pParent, const SfxItemSet* pArgSet)
+VclPtr<SfxAbstractTabDialog> ScAbstractDialogFactory_Impl::CreateScSortDlg(vcl::Window* pParent, const SfxItemSet* pArgSet)
 {
     VclPtr<SfxTabDialog> pDlg = VclPtr<ScSortDlg>::Create( pParent, pArgSet );
-    return new ScAbstractTabDialog_Impl( pDlg );
+    return VclPtr<ScAbstractTabDialog_Impl>::Create( pDlg );
 }
 
 //------------------ Factories for TabPages--------------------
 CreateTabPage ScAbstractDialogFactory_Impl::GetTabPageCreatorFunc( sal_uInt16 nId )
 {
-    switch ( nId )
+    switch (nId)
     {
-        case RID_SCPAGE_OPREDLINE :
+        case SID_SC_TP_CHANGES:
             return ScRedlineOptionsTabPage::Create;
-        case RID_SCPAGE_CALC :
+        case SID_SC_TP_CALC:
             return ScTpCalcOptions::Create;
-        case RID_SCPAGE_FORMULA:
+        case SID_SC_TP_FORMULA:
             return ScTpFormulaOptions::Create;
-        case RID_SCPAGE_COMPATIBILITY:
+        case SID_SC_TP_COMPATIBILITY:
             return ScTpCompatOptions::Create;
-        case RID_SCPAGE_DEFAULTS:
+        case RID_SC_TP_DEFAULTS:
             return ScTpDefaultsOptions::Create;
-        case RID_SCPAGE_PRINT :
+        case RID_SC_TP_PRINT:
             return ScTpPrintOptions::Create;
-        case RID_SCPAGE_STAT :
+        case SID_SC_TP_STAT:
             return ScDocStatPage::Create;
-        case RID_SCPAGE_USERLISTS :
+        case SID_SC_TP_USERLISTS:
              return ScTpUserLists::Create;
-        case RID_SCPAGE_CONTENT :
+        case SID_SC_TP_CONTENT:
             return ScTpContentOptions::Create;
-        case RID_SCPAGE_LAYOUT :
+        case SID_SC_TP_LAYOUT:
             return ScTpLayoutOptions::Create;
         default:
             break;
