@@ -25,33 +25,33 @@
 #include <svl/stritem.hxx>
 #include <vcl/msgbox.hxx>
 
-#include "arealink.hxx"
+#include <arealink.hxx>
 
-#include "tablink.hxx"
-#include "document.hxx"
-#include "docsh.hxx"
-#include "rangenam.hxx"
-#include "dbdata.hxx"
-#include "undoblk.hxx"
-#include "globstr.hrc"
-#include "markdata.hxx"
-#include "hints.hxx"
-#include "filter.hxx"
+#include <tablink.hxx>
+#include <document.hxx>
+#include <docsh.hxx>
+#include <rangenam.hxx>
+#include <dbdata.hxx>
+#include <undoblk.hxx>
+#include <globstr.hrc>
+#include <markdata.hxx>
+#include <hints.hxx>
+#include <filter.hxx>
 
-#include "attrib.hxx"
-#include "patattr.hxx"
-#include "docpool.hxx"
+#include <attrib.hxx>
+#include <patattr.hxx>
+#include <docpool.hxx>
 
-#include "sc.hrc"
-#include "scabstdlg.hxx"
-#include "clipparam.hxx"
+#include <sc.hrc>
+#include <scabstdlg.hxx>
+#include <clipparam.hxx>
 
 struct AreaLink_Impl
 {
     ScDocShell* m_pDocSh;
-    AbstractScLinkedAreaDlg* m_pDialog;
+    VclPtr<AbstractScLinkedAreaDlg> m_pDialog;
 
-    AreaLink_Impl() : m_pDocSh( nullptr ), m_pDialog( nullptr ) {}
+    AreaLink_Impl() : m_pDocSh( nullptr ), m_pDialog() {}
 };
 
 
@@ -71,7 +71,7 @@ ScAreaLink::ScAreaLink( SfxObjectShell* pShell, const OUString& rFile,
     bInCreate       (false),
     bDoInsert       (true)
 {
-    OSL_ENSURE(dynamic_cast< const ScDocShell *>( pShell ) !=  nullptr, "ScAreaLink mit falscher ObjectShell");
+    OSL_ENSURE(dynamic_cast< const ScDocShell *>( pShell ) !=  nullptr, "ScAreaLink with wrong ObjectShell");
     pImpl->m_pDocSh = static_cast< ScDocShell* >( pShell );
     SetRefreshHandler( LINK( this, ScAreaLink, RefreshHdl ) );
     SetRefreshControl( &pImpl->m_pDocSh->GetDocument().GetRefreshTimerControlAddress() );
@@ -88,18 +88,29 @@ void ScAreaLink::Edit(vcl::Window* pParent, const Link<SvBaseLink&,void>& /* rEn
     ScAbstractDialogFactory* pFact = ScAbstractDialogFactory::Create();
     OSL_ENSURE(pFact, "ScAbstractFactory create fail!");
 
-    AbstractScLinkedAreaDlg* pDlg = pFact->CreateScLinkedAreaDlg(pParent);
+    ScopedVclPtr<AbstractScLinkedAreaDlg> pDlg(pFact->CreateScLinkedAreaDlg(pParent));
     OSL_ENSURE(pDlg, "Dialog create fail!");
     pDlg->InitFromOldLink( aFileName, aFilterName, aOptions, aSourceArea, GetRefreshDelay() );
     pImpl->m_pDialog = pDlg;
-    pDlg->StartExecuteModal( LINK( this, ScAreaLink, AreaEndEditHdl ) );
+    if ( pDlg->Execute() == RET_OK )
+    {
+        aOptions = pImpl->m_pDialog->GetOptions();
+        Refresh( pImpl->m_pDialog->GetURL(), pImpl->m_pDialog->GetFilter(),
+                 pImpl->m_pDialog->GetSource(), pImpl->m_pDialog->GetRefresh() );
+
+        //  copy source data from members (set in Refresh) into link name for dialog
+        OUString aNewLinkName;
+        sfx2::MakeLnkName( aNewLinkName, nullptr, aFileName, aSourceArea, &aFilterName );
+        SetName( aNewLinkName );
+    }
+    pImpl->m_pDialog.clear();    // dialog is deleted with parent
 }
 
 ::sfx2::SvBaseLink::UpdateResult ScAreaLink::DataChanged(
     const OUString&, const css::uno::Any& )
 {
-    //  bei bInCreate nichts tun, damit Update gerufen werden kann, um den Status im
-    //  LinkManager zu setzen, ohne die Daten im Dokument zu aendern
+    //  Do not do anything at bInCreate so that update can be called to set
+    //  the status in the LinkManager without changing the data in the document
 
     if (bInCreate)
         return SUCCESS;
@@ -136,7 +147,7 @@ void ScAreaLink::Edit(vcl::Window* pParent, const Link<SvBaseLink&,void>& /* rEn
 
 void ScAreaLink::Closed()
 {
-    // Verknuepfung loeschen: Undo
+    // delete link: Undo
 
     ScDocument& rDoc = pImpl->m_pDocSh->GetDocument();
     bool bUndo (rDoc.IsUndoEnabled());
@@ -146,19 +157,18 @@ void ScAreaLink::Closed()
                                                         aFileName, aFilterName, aOptions,
                                                         aSourceArea, aDestArea, GetRefreshDelay() ) );
 
-        bAddUndo = false;   // nur einmal
+        bAddUndo = false;   // only once
     }
 
     SCTAB nDestTab = aDestArea.aStart.Tab();
-    if (rDoc.IsStreamValid(nDestTab))
-        rDoc.SetStreamValid(nDestTab, false);
+    rDoc.SetStreamValid(nDestTab, false);
 
     SvBaseLink::Closed();
 }
 
 void ScAreaLink::SetDestArea(const ScRange& rNew)
 {
-    aDestArea = rNew;           // fuer Undo
+    aDestArea = rNew;           // for Undo
 }
 
 void ScAreaLink::SetSource(const OUString& rDoc, const OUString& rFlt, const OUString& rOpt,
@@ -183,18 +193,18 @@ bool ScAreaLink::IsEqual( const OUString& rFile, const OUString& rFilter, const
 }
 
 // find a range with name >rAreaName< in >pSrcDoc<, return it in >rRange<
-bool ScAreaLink::FindExtRange( ScRange& rRange, ScDocument* pSrcDoc, const OUString& rAreaName )
+bool ScAreaLink::FindExtRange( ScRange& rRange, const ScDocument* pSrcDoc, const OUString& rAreaName )
 {
     bool bFound = false;
     OUString aUpperName = ScGlobal::pCharClass->uppercase(rAreaName);
     ScRangeName* pNames = pSrcDoc->GetRangeName();
-    if (pNames)         // benannte Bereiche
+    if (pNames)         // named ranges
     {
         const ScRangeData* p = pNames->findByUpperName(aUpperName);
         if (p && p->IsValidReference(rRange))
             bFound = true;
     }
-    if (!bFound)        // Datenbankbereiche
+    if (!bFound)        // database ranges
     {
         ScDBCollection* pDBColl = pSrcDoc->GetDBCollection();
         if (pDBColl)
@@ -220,12 +230,12 @@ bool ScAreaLink::FindExtRange( ScRange& rRange, ScDocument* pSrcDoc, const OUStr
     return bFound;
 }
 
-//  ausfuehren:
+//  execute:
 
 bool ScAreaLink::Refresh( const OUString& rNewFile, const OUString& rNewFilter,
                             const OUString& rNewArea, sal_uLong nNewRefresh )
 {
-    //  Dokument laden - wie TabLink
+    //  load document - like TabLink
 
     if (rNewFile.isEmpty() || rNewFilter.isEmpty())
         return false;
@@ -242,7 +252,7 @@ bool ScAreaLink::Refresh( const OUString& rNewFile, const OUString& rNewFilter,
     bool bUndo (rDoc.IsUndoEnabled());
     rDoc.SetInLinkUpdate( true );
 
-    //  wenn neuer Filter ausgewaehlt wurde, Optionen vergessen
+    //  if new filter was selected, forget options
     if ( rNewFilter != aFilterName )
         aOptions.clear();
 
@@ -255,7 +265,7 @@ bool ScAreaLink::Refresh( const OUString& rNewFile, const OUString& rNewFilter,
 
     ScDocument& rSrcDoc = pSrcShell->GetDocument();
 
-    // Optionen koennten gesetzt worden sein
+    // options could have been set
     OUString aNewOpt = ScDocumentLoader::GetOptions(*pMed);
     if (aNewOpt.isEmpty())
         aNewOpt = aOptions;
@@ -291,12 +301,12 @@ bool ScAreaLink::Refresh( const OUString& rNewFile, const OUString& rNewFilter,
     if( nHeight > 0 )
         nHeight--;
 
-    //  alte Daten loeschen / neue kopieren
+    //  delete old data / copy new
 
     ScAddress aDestPos = aDestArea.aStart;
     SCTAB nDestTab = aDestPos.Tab();
     ScRange aOldRange = aDestArea;
-    ScRange aNewRange = aDestArea;          // alter Bereich, wenn Datei nicht gefunden o.ae.
+    ScRange aNewRange = aDestArea;          // old range, if file not found or similar
     if (nWidth > 0 && nHeight > 0)
     {
         aNewRange.aEnd.SetCol( aNewRange.aStart.Col() + nWidth - 1 );
@@ -317,7 +327,7 @@ bool ScAreaLink::Refresh( const OUString& rNewFile, const OUString& rNewFilter,
         ScRange aMaxRange( aDestPos,
                     ScAddress(std::max(nOldEndX,nNewEndX), std::max(nOldEndY,nNewEndY), nDestTab) );
 
-        //  Undo initialisieren
+        //  initialise Undo
 
         ScDocument* pUndoDoc = nullptr;
         if ( bAddUndo && bUndo )
@@ -325,32 +335,32 @@ bool ScAreaLink::Refresh( const OUString& rNewFile, const OUString& rNewFilter,
             pUndoDoc = new ScDocument( SCDOCMODE_UNDO );
             if ( bDoInsert )
             {
-                if ( nNewEndX != nOldEndX || nNewEndY != nOldEndY )             // Bereich veraendert?
+                if ( nNewEndX != nOldEndX || nNewEndY != nOldEndY )             // range changed?
                 {
                     pUndoDoc->InitUndo( &rDoc, 0, rDoc.GetTableCount()-1 );
-                    rDoc.CopyToDocument( 0,0,0,MAXCOL,MAXROW,MAXTAB,
-                                            InsertDeleteFlags::FORMULA, false, pUndoDoc );     // alle Formeln
+                    rDoc.CopyToDocument(0, 0, 0, MAXCOL, MAXROW, MAXTAB,
+                                        InsertDeleteFlags::FORMULA, false, *pUndoDoc);     // all formulas
                 }
                 else
-                    pUndoDoc->InitUndo( &rDoc, nDestTab, nDestTab );             // nur Zieltabelle
-                rDoc.CopyToDocument( aOldRange, InsertDeleteFlags::ALL & ~InsertDeleteFlags::NOTE, false, pUndoDoc );
+                    pUndoDoc->InitUndo( &rDoc, nDestTab, nDestTab );             // only destination table
+                rDoc.CopyToDocument(aOldRange, InsertDeleteFlags::ALL & ~InsertDeleteFlags::NOTE, false, *pUndoDoc);
             }
-            else        // ohne Einfuegen
+            else        // without insertion
             {
-                pUndoDoc->InitUndo( &rDoc, nDestTab, nDestTab );             // nur Zieltabelle
-                rDoc.CopyToDocument( aMaxRange, InsertDeleteFlags::ALL & ~InsertDeleteFlags::NOTE, false, pUndoDoc );
+                pUndoDoc->InitUndo( &rDoc, nDestTab, nDestTab );             // only destination table
+                rDoc.CopyToDocument(aMaxRange, InsertDeleteFlags::ALL & ~InsertDeleteFlags::NOTE, false, *pUndoDoc);
             }
         }
 
-        //  Zellen einfuegen / loeschen
-        //  DeleteAreaTab loescht auch MERGE_FLAG Attribute
+        //  insert / delete cells
+        //  DeleteAreaTab also deletes MERGE_FLAG attributes
 
         if (bDoInsert)
-            rDoc.FitBlock( aOldRange, aNewRange );         // incl. loeschen
+            rDoc.FitBlock( aOldRange, aNewRange );         // incl. deletion
         else
             rDoc.DeleteAreaTab( aMaxRange, InsertDeleteFlags::ALL & ~InsertDeleteFlags::NOTE );
 
-        //  Daten kopieren
+        //  copy data
 
         if (nWidth > 0 && nHeight > 0)
         {
@@ -365,16 +375,16 @@ bool ScAreaLink::Refresh( const OUString& rNewFile, const OUString& rNewFilter,
                 {
                     SCTAB nSrcTab = aTokenRange.aStart.Tab();
                     ScMarkData aSourceMark;
-                    aSourceMark.SelectOneTable( nSrcTab );      // selektieren fuer CopyToClip
+                    aSourceMark.SelectOneTable( nSrcTab );      // selecting for CopyToClip
                     aSourceMark.SetMarkArea( aTokenRange );
 
                     ScClipParam aClipParam(aTokenRange, false);
                     rSrcDoc.CopyToClip(aClipParam, &aClipDoc, &aSourceMark, false, false);
 
                     if ( aClipDoc.HasAttrib( 0,0,nSrcTab, MAXCOL,MAXROW,nSrcTab,
-                                            HASATTR_MERGED | HASATTR_OVERLAPPED ) )
+                                            HasAttrFlags::Merged | HasAttrFlags::Overlapped ) )
                     {
-                        //! ResetAttrib am Dokument !!!
+                        //! ResetAttrib at document !!!
 
                         ScPatternAttr aPattern( rSrcDoc.GetPool() );
                         aPattern.GetItemSet().Put( ScMergeAttr() );             // Defaults
@@ -398,13 +408,13 @@ bool ScAreaLink::Refresh( const OUString& rNewFile, const OUString& rNewFilter,
             rDoc.SetString( aDestPos.Col(), aDestPos.Row(), aDestPos.Tab(), aErr );
         }
 
-        //  Undo eintragen
+        //  enter Undo
 
         if ( bAddUndo && bUndo)
         {
             ScDocument* pRedoDoc = new ScDocument( SCDOCMODE_UNDO );
             pRedoDoc->InitUndo( &rDoc, nDestTab, nDestTab );
-            rDoc.CopyToDocument( aNewRange, InsertDeleteFlags::ALL & ~InsertDeleteFlags::NOTE, false, pRedoDoc );
+            rDoc.CopyToDocument(aNewRange, InsertDeleteFlags::ALL & ~InsertDeleteFlags::NOTE, false, *pRedoDoc);
 
             pImpl->m_pDocSh->GetUndoManager()->AddUndoAction(
                 new ScUndoUpdateAreaLink( pImpl->m_pDocSh,
@@ -415,7 +425,7 @@ bool ScAreaLink::Refresh( const OUString& rNewFile, const OUString& rNewFilter,
                                             pUndoDoc, pRedoDoc, bDoInsert ) );
         }
 
-        //  neue Einstellungen merken
+        //  remember new settings
 
         if ( bNewUrlName )
             aFileName = aNewUrl;
@@ -443,23 +453,22 @@ bool ScAreaLink::Refresh( const OUString& rNewFile, const OUString& rNewFilter,
         if ( !pImpl->m_pDocSh->AdjustRowHeight( aDestPos.Row(), nPaintEndY, nDestTab ) )
             pImpl->m_pDocSh->PostPaint(
                 ScRange(aDestPos.Col(), aDestPos.Row(), nDestTab, nPaintEndX, nPaintEndY, nDestTab),
-                PAINT_GRID);
+                PaintPartFlags::Grid);
         aModificator.SetDocumentModified();
     }
     else
     {
-        //  CanFitBlock sal_False -> Probleme mit zusammengefassten Zellen
-        //                       oder Tabellengrenze erreicht!
-        //! Zellschutz ???
+        //  CanFitBlock sal_False -> Problems with summarized cells or table boundary reached!
+        //! cell protection ???
 
-        //! Link-Dialog muss Default-Parent setzen
-        //  "kann keine Zeilen einfuegen"
+        //! Link dialog must set default parent
+        //  "cannot insert rows"
         ScopedVclPtrInstance<InfoBox> aBox( Application::GetDefDialogParent(),
                                             ScGlobal::GetRscString( STR_MSSG_DOSUBTOTALS_2 ) );
         aBox->Execute();
     }
 
-    //  aufraeumen
+    //  clean up
 
     aRef->DoClose();
 
@@ -477,28 +486,9 @@ bool ScAreaLink::Refresh( const OUString& rNewFile, const OUString& rNewFilter,
     return bCanDo;
 }
 
-IMPL_LINK_NOARG_TYPED(ScAreaLink, RefreshHdl, Timer *, void)
+IMPL_LINK_NOARG(ScAreaLink, RefreshHdl, Timer *, void)
 {
     Refresh( aFileName, aFilterName, aSourceArea, GetRefreshDelay() );
 }
 
-IMPL_LINK_NOARG_TYPED(ScAreaLink, AreaEndEditHdl, Dialog&, void)
-{
-    //  #i76514# can't use link argument to access the dialog,
-    //  because it's the ScLinkedAreaDlg, not AbstractScLinkedAreaDlg
-
-    if ( pImpl->m_pDialog && pImpl->m_pDialog->GetResult() == RET_OK )
-    {
-        aOptions = pImpl->m_pDialog->GetOptions();
-        Refresh( pImpl->m_pDialog->GetURL(), pImpl->m_pDialog->GetFilter(),
-                 pImpl->m_pDialog->GetSource(), pImpl->m_pDialog->GetRefresh() );
-
-        //  copy source data from members (set in Refresh) into link name for dialog
-        OUString aNewLinkName;
-        sfx2::MakeLnkName( aNewLinkName, nullptr, aFileName, aSourceArea, &aFilterName );
-        SetName( aNewLinkName );
-    }
-    pImpl->m_pDialog = nullptr;    // dialog is deleted with parent
-}
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
