@@ -17,6 +17,7 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
+#include <vcl/errinf.hxx>
 #include <comphelper/processfactory.hxx>
 #include <comphelper/types.hxx>
 #include <vcl/msgbox.hxx>
@@ -25,6 +26,7 @@
 
 #include <com/sun/star/sdb/CommandType.hpp>
 #include <com/sun/star/sdb/XCompletedExecution.hpp>
+#include <com/sun/star/sdbc/SQLException.hpp>
 #include <com/sun/star/sdbc/XRow.hpp>
 #include <com/sun/star/sdbc/XRowSet.hpp>
 #include <com/sun/star/sdbc/XResultSetMetaDataSupplier.hpp>
@@ -32,27 +34,25 @@
 #include <com/sun/star/task/InteractionHandler.hpp>
 #include <com/sun/star/lang/XMultiServiceFactory.hpp>
 #include <com/sun/star/beans/XPropertySet.hpp>
-#include <com/sun/star/frame/XDispatchProvider.hpp>
 #include <com/sun/star/frame/FrameSearchFlag.hpp>
 #include <com/sun/star/view/XSelectionSupplier.hpp>
 
-
-#include "dbdocfun.hxx"
-#include "docsh.hxx"
-#include "globstr.hrc"
-#include "scerrors.hxx"
-#include "dbdata.hxx"
-#include "markdata.hxx"
-#include "undodat.hxx"
-#include "progress.hxx"
-#include "patattr.hxx"
-#include "docpool.hxx"
-#include "attrib.hxx"
-#include "dbdocutl.hxx"
-#include "editable.hxx"
-#include "hints.hxx"
-#include "miscuno.hxx"
-#include "chgtrack.hxx"
+#include <dbdocfun.hxx>
+#include <docsh.hxx>
+#include <globstr.hrc>
+#include <scerrors.hxx>
+#include <dbdata.hxx>
+#include <markdata.hxx>
+#include <undodat.hxx>
+#include <progress.hxx>
+#include <patattr.hxx>
+#include <docpool.hxx>
+#include <attrib.hxx>
+#include <dbdocutl.hxx>
+#include <editable.hxx>
+#include <hints.hxx>
+#include <miscuno.hxx>
+#include <chgtrack.hxx>
 #include <refupdatecontext.hxx>
 
 using namespace com::sun::star;
@@ -64,7 +64,7 @@ using namespace com::sun::star;
 #define SC_DBPROP_COMMAND           "Command"
 #define SC_DBPROP_COMMANDTYPE       "CommandType"
 
-void ScDBDocFunc::ShowInBeamer( const ScImportParam& rParam, SfxViewFrame* pFrame )
+void ScDBDocFunc::ShowInBeamer( const ScImportParam& rParam, const SfxViewFrame* pFrame )
 {
     //  called after opening the database beamer
 
@@ -72,10 +72,9 @@ void ScDBDocFunc::ShowInBeamer( const ScImportParam& rParam, SfxViewFrame* pFram
         return;
 
     uno::Reference<frame::XFrame> xFrame = pFrame->GetFrame().GetFrameInterface();
-    uno::Reference<frame::XDispatchProvider> xDP(xFrame, uno::UNO_QUERY);
 
     uno::Reference<frame::XFrame> xBeamerFrame = xFrame->findFrame(
-                                        OUString("_beamer"),
+                                        "_beamer",
                                         frame::FrameSearchFlag::CHILDREN);
     if (xBeamerFrame.is())
     {
@@ -87,10 +86,10 @@ void ScDBDocFunc::ShowInBeamer( const ScImportParam& rParam, SfxViewFrame* pFram
                         ( (rParam.nType == ScDbQuery) ? sdb::CommandType::QUERY :
                                                         sdb::CommandType::TABLE );
 
-            ::svx::ODataAccessDescriptor aSelection;
+            svx::ODataAccessDescriptor aSelection;
             aSelection.setDataSource(rParam.aDBName);
-            aSelection[svx::daCommand]      <<= rParam.aStatement;
-            aSelection[svx::daCommandType]  <<= nType;
+            aSelection[svx::DataAccessDescriptorProperty::Command]      <<= rParam.aStatement;
+            aSelection[svx::DataAccessDescriptorProperty::CommandType]  <<= nType;
 
             xControllerSelection->select(uno::makeAny(aSelection.createPropertyValueSequence()));
         }
@@ -101,15 +100,13 @@ void ScDBDocFunc::ShowInBeamer( const ScImportParam& rParam, SfxViewFrame* pFram
     }
 }
 
-// -----------------------------------------------------------------
-
 bool ScDBDocFunc::DoImportUno( const ScAddress& rPos,
                                 const uno::Sequence<beans::PropertyValue>& aArgs )
 {
     svx::ODataAccessDescriptor aDesc( aArgs );      // includes selection and result set
 
     //  create database range
-    ScDBData* pDBData = rDocShell.GetDBData( ScRange(rPos), SC_DB_IMPORT, SC_DBSEL_KEEP );
+    ScDBData* pDBData = rDocShell.GetDBData( ScRange(rPos), SC_DB_IMPORT, ScGetDBSelection::Keep );
     DBG_ASSERT(pDBData, "can't create DB data");
     OUString sTarget = pDBData->GetName();
 
@@ -118,64 +115,58 @@ bool ScDBDocFunc::DoImportUno( const ScAddress& rPos,
     return true;
 }
 
-// -----------------------------------------------------------------
-
 bool ScDBDocFunc::DoImport( SCTAB nTab, const ScImportParam& rParam,
-        const svx::ODataAccessDescriptor* pDescriptor, bool bRecord, bool bAddrInsert )
+        const svx::ODataAccessDescriptor* pDescriptor )
 {
-    ScDocument* pDoc = rDocShell.GetDocument();
-    ScChangeTrack *pChangeTrack = NULL;
+    ScDocument& rDoc = rDocShell.GetDocument();
+    ScChangeTrack *pChangeTrack = nullptr;
     ScRange aChangedRange;
 
-    if (bRecord && !pDoc->IsUndoEnabled())
+    bool bRecord = true;
+    if (!rDoc.IsUndoEnabled())
         bRecord = false;
 
-    ScDBData* pDBData = NULL;
-    if ( !bAddrInsert )
+    ScDBData* pDBData = rDoc.GetDBAtArea( nTab, rParam.nCol1, rParam.nRow1,
+                                          rParam.nCol2, rParam.nRow2 );
+    if (!pDBData)
     {
-        pDBData = pDoc->GetDBAtArea( nTab, rParam.nCol1, rParam.nRow1,
-                                            rParam.nCol2, rParam.nRow2 );
-        if (!pDBData)
-        {
-            OSL_FAIL( "DoImport: no DBData" );
-            return false;
-        }
+         OSL_FAIL( "DoImport: no DBData" );
+        return false;
     }
 
-    Window* pWaitWin = rDocShell.GetActiveDialogParent();
+    vcl::Window* pWaitWin = ScDocShell::GetActiveDialogParent();
     if (pWaitWin)
         pWaitWin->EnterWait();
     ScDocShellModificator aModificator( rDocShell );
 
-    sal_Bool bSuccess = false;
-    sal_Bool bApi = false;                      //! pass as argument
-    sal_Bool bTruncated = false;                // for warning
-    sal_uInt16 nErrStringId = 0;
+    bool bSuccess = false;
+    bool bApi = false;                      //! pass as argument
+    bool bTruncated = false;                // for warning
+    const char* pErrStringId = nullptr;
     OUString aErrorMessage;
 
     SCCOL nCol = rParam.nCol1;
     SCROW nRow = rParam.nRow1;
     SCCOL nEndCol = nCol;                   // end of resulting database area
     SCROW nEndRow = nRow;
-    long i;
 
-    sal_Bool bDoSelection = false;
-    sal_Bool bRealSelection = false;            // sal_True if not everything is selected
-    sal_Bool bBookmarkSelection = sal_False;
+    bool bDoSelection = false;
+    bool bRealSelection = false;            // sal_True if not everything is selected
+    bool bBookmarkSelection = false;
     sal_Int32 nListPos = 0;
     sal_Int32 nRowsRead = 0;
     sal_Int32 nListCount = 0;
 
     uno::Sequence<uno::Any> aSelection;
-    if ( pDescriptor && pDescriptor->has(svx::daSelection) )
+    if ( pDescriptor && pDescriptor->has(svx::DataAccessDescriptorProperty::Selection) )
     {
-        (*pDescriptor)[svx::daSelection] >>= aSelection;
+        (*pDescriptor)[svx::DataAccessDescriptorProperty::Selection] >>= aSelection;
         nListCount = aSelection.getLength();
         if ( nListCount > 0 )
         {
             bDoSelection = true;
-            if ( pDescriptor->has(svx::daBookmarkSelection) )
-                bBookmarkSelection = ScUnoHelpFunctions::GetBoolFromAny( (*pDescriptor)[svx::daBookmarkSelection] );
+            if ( pDescriptor->has(svx::DataAccessDescriptorProperty::BookmarkSelection) )
+                bBookmarkSelection = ScUnoHelpFunctions::GetBoolFromAny( (*pDescriptor)[svx::DataAccessDescriptorProperty::BookmarkSelection] );
             if ( bBookmarkSelection )
             {
                 // From bookmarks, there's no way to detect if all records are selected.
@@ -186,63 +177,51 @@ bool ScDBDocFunc::DoImport( SCTAB nTab, const ScImportParam& rParam,
     }
 
     uno::Reference<sdbc::XResultSet> xResultSet;
-    if ( pDescriptor && pDescriptor->has(svx::daCursor) )
-        xResultSet.set((*pDescriptor)[svx::daCursor], uno::UNO_QUERY);
+    if ( pDescriptor && pDescriptor->has(svx::DataAccessDescriptorProperty::Cursor) )
+        xResultSet.set((*pDescriptor)[svx::DataAccessDescriptorProperty::Cursor], uno::UNO_QUERY);
 
     // ImportDoc - also used for Redo
     ScDocument* pImportDoc = new ScDocument( SCDOCMODE_UNDO );
-    pImportDoc->InitUndo( pDoc, nTab, nTab );
+    pImportDoc->InitUndo( &rDoc, nTab, nTab );
 
-    //
     //  get data from database into import document
-    //
 
     try
     {
         //  progress bar
         //  only text (title is still needed, for the cancel button)
-        ScProgress aProgress( &rDocShell, ScGlobal::GetRscString(STR_UNDO_IMPORTDATA), 0 );
+        ScProgress aProgress( &rDocShell, ScGlobal::GetRscString(STR_UNDO_IMPORTDATA), 0, true );
 
-        uno::Reference<sdbc::XRowSet> xRowSet = uno::Reference<sdbc::XRowSet>(
-                xResultSet, uno::UNO_QUERY );
-        sal_Bool bDispose = false;
+        uno::Reference<sdbc::XRowSet> xRowSet( xResultSet, uno::UNO_QUERY );
+        bool bDispose = false;
         if ( !xRowSet.is() )
         {
-            bDispose = sal_True;
-            xRowSet = uno::Reference<sdbc::XRowSet>(
-                    comphelper::getProcessServiceFactory()->createInstance(
-                        OUString( SC_SERVICE_ROWSET ) ),
-                    uno::UNO_QUERY);
+            bDispose = true;
+            xRowSet.set(comphelper::getProcessServiceFactory()->createInstance(
+                            SC_SERVICE_ROWSET ),
+                        uno::UNO_QUERY);
             uno::Reference<beans::XPropertySet> xRowProp( xRowSet, uno::UNO_QUERY );
             OSL_ENSURE( xRowProp.is(), "can't get RowSet" );
             if ( xRowProp.is() )
             {
-                //
+
                 //  set source parameters
-                //
 
                 sal_Int32 nType = rParam.bSql ? sdb::CommandType::COMMAND :
                             ( (rParam.nType == ScDbQuery) ? sdb::CommandType::QUERY :
                                                             sdb::CommandType::TABLE );
-                uno::Any aAny;
 
-                aAny <<= rParam.aDBName;
-                xRowProp->setPropertyValue(
-                            OUString(SC_DBPROP_DATASOURCENAME), aAny );
+                xRowProp->setPropertyValue( SC_DBPROP_DATASOURCENAME, uno::Any(rParam.aDBName) );
 
-                aAny <<= rParam.aStatement;
-                xRowProp->setPropertyValue(
-                            OUString(SC_DBPROP_COMMAND), aAny );
+                xRowProp->setPropertyValue( SC_DBPROP_COMMAND, uno::Any(rParam.aStatement) );
 
-                aAny <<= nType;
-                xRowProp->setPropertyValue(
-                            OUString(SC_DBPROP_COMMANDTYPE), aAny );
+                xRowProp->setPropertyValue( SC_DBPROP_COMMANDTYPE, uno::Any(nType) );
 
                 uno::Reference<sdb::XCompletedExecution> xExecute( xRowSet, uno::UNO_QUERY );
                 if ( xExecute.is() )
                 {
                     uno::Reference<task::XInteractionHandler> xHandler(
-                        task::InteractionHandler::createWithParent(comphelper::getProcessComponentContext(), 0),
+                        task::InteractionHandler::createWithParent(comphelper::getProcessComponentContext(), nullptr),
                         uno::UNO_QUERY_THROW);
                     xExecute->executeWithCompletion( xHandler );
                 }
@@ -252,9 +231,8 @@ bool ScDBDocFunc::DoImport( SCTAB nTab, const ScImportParam& rParam,
         }
         if ( xRowSet.is() )
         {
-            //
+
             //  get column descriptions
-            //
 
             long nColCount = 0;
             uno::Reference<sdbc::XResultSetMetaData> xMeta;
@@ -277,7 +255,7 @@ bool ScDBDocFunc::DoImport( SCTAB nTab, const ScImportParam& rParam,
                 if ( !xLocate.is() )
                 {
                     SAL_WARN( "sc.ui","can't get XRowLocate");
-                    bDoSelection = bRealSelection = bBookmarkSelection = sal_False;
+                    bDoSelection = bRealSelection = bBookmarkSelection = false;
                 }
             }
 
@@ -290,25 +268,23 @@ bool ScDBDocFunc::DoImport( SCTAB nTab, const ScImportParam& rParam,
                 uno::Sequence<sal_Bool> aColCurr( nColCount );      // currency flag is not in types
                 sal_Int32* pTypeArr = aColTypes.getArray();
                 sal_Bool* pCurrArr = aColCurr.getArray();
-                for (i=0; i<nColCount; i++)
+                for (long i=0; i<nColCount; i++)
                 {
                     pTypeArr[i] = xMeta->getColumnType( i+1 );
                     pCurrArr[i] = xMeta->isCurrency( i+1 );
                 }
 
-                if ( !bAddrInsert )                 // read column names
+                // read column names
+                nCol = rParam.nCol1;
+                for (long i=0; i<nColCount; i++)
                 {
-                    nCol = rParam.nCol1;
-                    for (i=0; i<nColCount; i++)
-                    {
-                        pImportDoc->SetString( nCol, nRow, nTab,
-                                                xMeta->getColumnLabel( i+1 ) );
-                        ++nCol;
-                    }
-                    ++nRow;
+                    pImportDoc->SetString( nCol, nRow, nTab,
+                                            xMeta->getColumnLabel( i+1 ) );
+                    ++nCol;
                 }
+                ++nRow;
 
-                sal_Bool bEnd = false;
+                bool bEnd = false;
                 if ( !bDoSelection )
                     xRowSet->beforeFirst();
                 sal_uInt16 nInserted = 0;
@@ -317,7 +293,8 @@ bool ScDBDocFunc::DoImport( SCTAB nTab, const ScImportParam& rParam,
                     //  skip rows that are not selected
                     if ( !bDoSelection )
                     {
-                        if ( (bEnd = !xRowSet->next()) == false )
+                        bEnd = !xRowSet->next();
+                        if ( !bEnd )
                             ++nRowsRead;
                     }
                     else
@@ -351,7 +328,7 @@ bool ScDBDocFunc::DoImport( SCTAB nTab, const ScImportParam& rParam,
                         if ( ValidRow(nRow) )
                         {
                             nCol = rParam.nCol1;
-                            for (i=0; i<nColCount; i++)
+                            for (long i=0; i<nColCount; i++)
                             {
                                 ScDatabaseDocUtil::PutData( pImportDoc, nCol, nRow, nTab,
                                                 xRow, i+1, pTypeArr[i], pCurrArr[i] );
@@ -370,23 +347,18 @@ bool ScDBDocFunc::DoImport( SCTAB nTab, const ScImportParam& rParam,
                                 aText += OUString::number( nInserted );
                                 aText += aPict.getToken(1,'#');
 
-                                if (!aProgress.SetStateText( 0, aText ))    // stopped by user?
-                                {
-                                    bEnd = sal_True;
-                                    bSuccess = false;
-                                    nErrStringId = STR_DATABASE_ABORTED;
-                                }
+                                aProgress.SetStateText( 0, aText );
                             }
                         }
                         else        // past the end of the spreadsheet
                         {
-                            bEnd = sal_True;            // don't continue
-                            bTruncated = sal_True;      // warning flag
+                            bEnd = true;            // don't continue
+                            bTruncated = true;      // warning flag
                         }
                     }
                 }
 
-                bSuccess = sal_True;
+                bSuccess = true;
             }
 
             if ( bDispose )
@@ -402,12 +374,10 @@ bool ScDBDocFunc::DoImport( SCTAB nTab, const ScImportParam& rParam,
         OSL_FAIL("Unexpected exception in database");
     }
 
-    //
     //  test for cell protection
-    //
 
-    sal_Bool bKeepFormat = !bAddrInsert && pDBData->IsKeepFmt();
-    sal_Bool bMoveCells = !bAddrInsert && pDBData->IsDoSize();
+    bool bKeepFormat = pDBData->IsKeepFmt();
+    bool bMoveCells = pDBData->IsDoSize();
     SCCOL nFormulaCols = 0; // columns to be filled with formulas
     if (bMoveCells && nEndCol == rParam.nCol2)
     {
@@ -417,22 +387,25 @@ bool ScDBDocFunc::DoImport( SCTAB nTab, const ScImportParam& rParam,
         SCCOL nTestCol = rParam.nCol2 + 1;      // right of the data
         SCROW nTestRow = rParam.nRow1 + 1;      // below the title row
         while ( nTestCol <= MAXCOL &&
-                pDoc->GetCellType(ScAddress( nTestCol, nTestRow, nTab )) == CELLTYPE_FORMULA )
-            ++nTestCol, ++nFormulaCols;
+                rDoc.GetCellType(ScAddress( nTestCol, nTestRow, nTab )) == CELLTYPE_FORMULA )
+        {
+            ++nTestCol;
+            ++nFormulaCols;
+        }
     }
 
     if (bSuccess)
     {
         //  old and new range editable?
         ScEditableTester aTester;
-        aTester.TestBlock( pDoc, nTab, rParam.nCol1,rParam.nRow1,rParam.nCol2,rParam.nRow2 );
-        aTester.TestBlock( pDoc, nTab, rParam.nCol1,rParam.nRow1,nEndCol,nEndRow );
+        aTester.TestBlock( &rDoc, nTab, rParam.nCol1,rParam.nRow1,rParam.nCol2,rParam.nRow2 );
+        aTester.TestBlock( &rDoc, nTab, rParam.nCol1,rParam.nRow1,nEndCol,nEndRow );
         if ( !aTester.IsEditable() )
         {
-            nErrStringId = aTester.GetMessageId();
+            pErrStringId = aTester.GetMessageId();
             bSuccess = false;
         }
-        else if ( (pChangeTrack = pDoc->GetChangeTrack()) != NULL )
+        else if ( (pChangeTrack = rDoc.GetChangeTrack()) != nullptr )
             aChangedRange = ScRange(rParam.nCol1, rParam.nRow1, nTab,
                         nEndCol+nFormulaCols, nEndRow, nTab );
     }
@@ -443,16 +416,14 @@ bool ScDBDocFunc::DoImport( SCTAB nTab, const ScImportParam& rParam,
                         rParam.nCol2+nFormulaCols, rParam.nRow2, nTab );
         ScRange aNew( rParam.nCol1, rParam.nRow1, nTab,
                         nEndCol+nFormulaCols, nEndRow, nTab );
-        if (!pDoc->CanFitBlock( aOld, aNew ))
+        if (!rDoc.CanFitBlock( aOld, aNew ))
         {
-            nErrStringId = STR_MSSG_DOSUBTOTALS_2;      // can't insert cells
+            pErrStringId = STR_MSSG_DOSUBTOTALS_2;      // can't insert cells
             bSuccess = false;
         }
     }
 
-    //
     //  copy data from import doc into real document
-    //
 
     if ( bSuccess )
     {
@@ -463,15 +434,15 @@ bool ScDBDocFunc::DoImport( SCTAB nTab, const ScImportParam& rParam,
 
             SCCOL nMinEndCol = std::min( rParam.nCol2, nEndCol );    // not too much
             nMinEndCol = sal::static_int_cast<SCCOL>( nMinEndCol + nFormulaCols );  // only if column count unchanged
-            pImportDoc->DeleteAreaTab( 0,0, MAXCOL,MAXROW, nTab, IDF_ATTRIB );
-            pDoc->CopyToDocument( rParam.nCol1, rParam.nRow1, nTab,
-                                    nMinEndCol, rParam.nRow1, nTab,
-                                    IDF_ATTRIB, false, pImportDoc );
+            pImportDoc->DeleteAreaTab( 0,0, MAXCOL,MAXROW, nTab, InsertDeleteFlags::ATTRIB );
+            rDoc.CopyToDocument(rParam.nCol1, rParam.nRow1, nTab,
+                                nMinEndCol, rParam.nRow1, nTab,
+                                InsertDeleteFlags::ATTRIB, false, *pImportDoc);
 
             SCROW nDataStartRow = rParam.nRow1+1;
             for (SCCOL nCopyCol=rParam.nCol1; nCopyCol<=nMinEndCol; nCopyCol++)
             {
-                const ScPatternAttr* pSrcPattern = pDoc->GetPattern(
+                const ScPatternAttr* pSrcPattern = rDoc.GetPattern(
                                                     nCopyCol, nDataStartRow, nTab );
                 pImportDoc->ApplyPatternAreaTab( nCopyCol, nDataStartRow, nCopyCol, nEndRow,
                                                     nTab, *pSrcPattern );
@@ -483,29 +454,26 @@ bool ScDBDocFunc::DoImport( SCTAB nTab, const ScImportParam& rParam,
         }
 
         //  don't set cell protection attribute if table is protected
-        if (pDoc->IsTabProtected(nTab))
+        if (rDoc.IsTabProtected(nTab))
         {
             ScPatternAttr aPattern(pImportDoc->GetPool());
             aPattern.GetItemSet().Put( ScProtectionAttr( false,false,false,false ) );
             pImportDoc->ApplyPatternAreaTab( 0,0,MAXCOL,MAXROW, nTab, aPattern );
         }
 
-        //
         //  copy old data for undo
-        //
 
         SCCOL nUndoEndCol = std::max( nEndCol, rParam.nCol2 );       // rParam = old end
         SCROW nUndoEndRow = std::max( nEndRow, rParam.nRow2 );
 
-        ScDocument* pUndoDoc = NULL;
-        ScDBData* pUndoDBData = NULL;
+        ScDocument* pUndoDoc = nullptr;
+        ScDBData* pUndoDBData = nullptr;
         if ( bRecord )
         {
             pUndoDoc = new ScDocument( SCDOCMODE_UNDO );
-            pUndoDoc->InitUndo( pDoc, nTab, nTab );
+            pUndoDoc->InitUndo( &rDoc, nTab, nTab );
 
-            if ( !bAddrInsert )
-                pUndoDBData = new ScDBData( *pDBData );
+            pUndoDBData = new ScDBData( *pDBData );
         }
 
         ScMarkData aNewMark;
@@ -514,25 +482,23 @@ bool ScDBDocFunc::DoImport( SCTAB nTab, const ScImportParam& rParam,
         if (bRecord)
         {
             // do not touch notes (ScUndoImportData does not support drawing undo)
-            sal_uInt16 nCopyFlags = IDF_ALL & ~IDF_NOTE;
+            InsertDeleteFlags nCopyFlags = InsertDeleteFlags::ALL & ~InsertDeleteFlags::NOTE;
 
             //  nFormulaCols is set only if column count is unchanged
-            pDoc->CopyToDocument( rParam.nCol1, rParam.nRow1, nTab,
-                                    nEndCol+nFormulaCols, nEndRow, nTab,
-                                    nCopyFlags, false, pUndoDoc );
+            rDoc.CopyToDocument(rParam.nCol1, rParam.nRow1, nTab,
+                                nEndCol+nFormulaCols, nEndRow, nTab,
+                                nCopyFlags, false, *pUndoDoc);
             if ( rParam.nCol2 > nEndCol )
-                pDoc->CopyToDocument( nEndCol+1, rParam.nRow1, nTab,
-                                        nUndoEndCol, nUndoEndRow, nTab,
-                                        nCopyFlags, false, pUndoDoc );
+                rDoc.CopyToDocument(nEndCol+1, rParam.nRow1, nTab,
+                                    nUndoEndCol, nUndoEndRow, nTab,
+                                    nCopyFlags, false, *pUndoDoc);
             if ( rParam.nRow2 > nEndRow )
-                pDoc->CopyToDocument( rParam.nCol1, nEndRow+1, nTab,
-                                        nUndoEndCol+nFormulaCols, nUndoEndRow, nTab,
-                                        nCopyFlags, false, pUndoDoc );
+                rDoc.CopyToDocument(rParam.nCol1, nEndRow+1, nTab,
+                                    nUndoEndCol+nFormulaCols, nUndoEndRow, nTab,
+                                    nCopyFlags, false, *pUndoDoc);
         }
 
-        //
         //  move new data
-        //
 
         if (bMoveCells)
         {
@@ -541,48 +507,48 @@ bool ScDBDocFunc::DoImport( SCTAB nTab, const ScImportParam& rParam,
 
             ScRange aDelRange( rParam.nCol1, rParam.nRow1, nTab,
                                 rParam.nCol2, rParam.nRow2, nTab );
-            pDoc->DeleteAreaTab( aDelRange, IDF_ALL & ~IDF_NOTE );  // ohne die Formeln
+            rDoc.DeleteAreaTab( aDelRange, InsertDeleteFlags::ALL & ~InsertDeleteFlags::NOTE );  // without the formulas
 
             ScRange aOld( rParam.nCol1, rParam.nRow1, nTab,
                             rParam.nCol2+nFormulaCols, rParam.nRow2, nTab );
             ScRange aNew( rParam.nCol1, rParam.nRow1, nTab,
                             nEndCol+nFormulaCols, nEndRow, nTab );
-            pDoc->FitBlock( aOld, aNew, false );        // Formeln nicht loeschen
+            rDoc.FitBlock( aOld, aNew, false );        // Do not delete formulas
         }
         else if ( nEndCol < rParam.nCol2 )      // DeleteArea calls PutInOrder
-            pDoc->DeleteArea( nEndCol+1, rParam.nRow1, rParam.nCol2, rParam.nRow2,
-                                aNewMark, IDF_CONTENTS & ~IDF_NOTE );
+            rDoc.DeleteArea( nEndCol+1, rParam.nRow1, rParam.nCol2, rParam.nRow2,
+                                aNewMark, InsertDeleteFlags::CONTENTS & ~InsertDeleteFlags::NOTE );
 
         //  CopyToDocument doesn't remove contents
-        pDoc->DeleteAreaTab( rParam.nCol1, rParam.nRow1, nEndCol, nEndRow, nTab, IDF_CONTENTS & ~IDF_NOTE );
+        rDoc.DeleteAreaTab( rParam.nCol1, rParam.nRow1, nEndCol, nEndRow, nTab, InsertDeleteFlags::CONTENTS & ~InsertDeleteFlags::NOTE );
 
         //  remove each column from ImportDoc after copying to reduce memory usage
-        sal_Bool bOldAutoCalc = pDoc->GetAutoCalc();
-        pDoc->SetAutoCalc( false );             // outside of the loop
+        bool bOldAutoCalc = rDoc.GetAutoCalc();
+        rDoc.SetAutoCalc( false );             // outside of the loop
         for (SCCOL nCopyCol = rParam.nCol1; nCopyCol <= nEndCol; nCopyCol++)
         {
-            pImportDoc->CopyToDocument( nCopyCol, rParam.nRow1, nTab, nCopyCol, nEndRow, nTab,
-                                        IDF_ALL, false, pDoc );
-            pImportDoc->DeleteAreaTab( nCopyCol, rParam.nRow1, nCopyCol, nEndRow, nTab, IDF_CONTENTS );
+            pImportDoc->CopyToDocument(nCopyCol, rParam.nRow1, nTab, nCopyCol, nEndRow, nTab,
+                                       InsertDeleteFlags::ALL, false, rDoc);
+            pImportDoc->DeleteAreaTab( nCopyCol, rParam.nRow1, nCopyCol, nEndRow, nTab, InsertDeleteFlags::CONTENTS );
         }
-        pDoc->SetAutoCalc( bOldAutoCalc );
+        rDoc.SetAutoCalc( bOldAutoCalc );
 
         if (nFormulaCols > 0)               // copy formulas
         {
             if (bKeepFormat)            // formats for formulas
-                pImportDoc->CopyToDocument( nEndCol+1, rParam.nRow1, nTab,
-                                            nEndCol+nFormulaCols, nEndRow, nTab,
-                                            IDF_ATTRIB, false, pDoc );
+                pImportDoc->CopyToDocument(nEndCol+1, rParam.nRow1, nTab,
+                                           nEndCol+nFormulaCols, nEndRow, nTab,
+                                           InsertDeleteFlags::ATTRIB, false, rDoc);
             // fill formulas
             ScMarkData aMark;
             aMark.SelectOneTable(nTab);
 
             sal_uLong nProgCount = nFormulaCols;
             nProgCount *= nEndRow-rParam.nRow1-1;
-            ScProgress aProgress( pDoc->GetDocumentShell(),
-                    ScGlobal::GetRscString(STR_FILL_SERIES_PROGRESS), nProgCount );
+            ScProgress aProgress( rDoc.GetDocumentShell(),
+                    ScGlobal::GetRscString(STR_FILL_SERIES_PROGRESS), nProgCount, true );
 
-            pDoc->Fill( nEndCol+1, rParam.nRow1+1, nEndCol+nFormulaCols, rParam.nRow1+1,
+            rDoc.Fill( nEndCol+1, rParam.nRow1+1, nEndCol+nFormulaCols, rParam.nRow1+1,
                             &aProgress, aMark, nEndRow-rParam.nRow1-1, FILL_TO_BOTTOM, FILL_SIMPLE );
         }
 
@@ -591,34 +557,32 @@ bool ScDBDocFunc::DoImport( SCTAB nTab, const ScImportParam& rParam,
         if (!bMoveCells)        // move has happened above
         {
             if ( rParam.nCol2 > nEndCol )
-                pDoc->DeleteArea( nEndCol+1, rParam.nRow1, rParam.nCol2, rParam.nRow2,
-                                    aNewMark, IDF_CONTENTS );
+                rDoc.DeleteArea( nEndCol+1, rParam.nRow1, rParam.nCol2, rParam.nRow2,
+                                    aNewMark, InsertDeleteFlags::CONTENTS );
             if ( rParam.nRow2 > nEndRow )
-                pDoc->DeleteArea( rParam.nCol1, nEndRow+1, rParam.nCol2, rParam.nRow2,
-                                    aNewMark, IDF_CONTENTS );
+                rDoc.DeleteArea( rParam.nCol1, nEndRow+1, rParam.nCol2, rParam.nRow2,
+                                    aNewMark, InsertDeleteFlags::CONTENTS );
         }
 
-        if( !bAddrInsert )      // update database range
-        {
-            pDBData->SetImportParam( rParam );
-            pDBData->SetHeader( sal_True );
-            pDBData->SetByRow( sal_True );
-            pDBData->SetArea( nTab, rParam.nCol1,rParam.nRow1, nEndCol,nEndRow );
-            pDBData->SetImportSelection( bRealSelection );
-            pDoc->CompileDBFormula();
-        }
+        // update database range
+        pDBData->SetImportParam( rParam );
+        pDBData->SetHeader( true );
+        pDBData->SetByRow( true );
+        pDBData->SetArea( nTab, rParam.nCol1,rParam.nRow1, nEndCol,nEndRow );
+        pDBData->SetImportSelection( bRealSelection );
+        rDoc.CompileDBFormula();
 
         if (bRecord)
         {
             ScDocument* pRedoDoc = pImportDoc;
-            pImportDoc = NULL;
+            pImportDoc = nullptr;
 
             if (nFormulaCols > 0)                   // include filled formulas for redo
-                pDoc->CopyToDocument( rParam.nCol1, rParam.nRow1, nTab,
-                                        nEndCol+nFormulaCols, nEndRow, nTab,
-                                        IDF_ALL & ~IDF_NOTE, false, pRedoDoc );
+                rDoc.CopyToDocument(rParam.nCol1, rParam.nRow1, nTab,
+                                    nEndCol+nFormulaCols, nEndRow, nTab,
+                                    InsertDeleteFlags::ALL & ~InsertDeleteFlags::NOTE, false, *pRedoDoc);
 
-            ScDBData* pRedoDBData = pDBData ? new ScDBData( *pDBData ) : NULL;
+            ScDBData* pRedoDBData = pDBData ? new ScDBData( *pDBData ) : nullptr;
 
             rDocShell.GetUndoManager()->AddUndoAction(
                 new ScUndoImportData( &rDocShell, nTab,
@@ -628,12 +592,12 @@ bool ScDBDocFunc::DoImport( SCTAB nTab, const ScImportParam& rParam,
         }
 
         sc::SetFormulaDirtyContext aCxt;
-        pDoc->SetAllFormulasDirty(aCxt);
-        rDocShell.PostPaint(ScRange(0, 0, nTab, MAXCOL, MAXROW, nTab), PAINT_GRID);
+        rDoc.SetAllFormulasDirty(aCxt);
+        rDocShell.PostPaint(ScRange(0, 0, nTab, MAXCOL, MAXROW, nTab), PaintPartFlags::Grid);
         aModificator.SetDocumentModified();
 
         ScDBRangeRefreshedHint aHint( rParam );
-        pDoc->BroadcastUno( aHint );
+        rDoc.BroadcastUno( aHint );
 
         if (pWaitWin)
             pWaitWin->LeaveWait();
@@ -648,12 +612,12 @@ bool ScDBDocFunc::DoImport( SCTAB nTab, const ScImportParam& rParam,
 
         if (aErrorMessage.isEmpty())
         {
-            if (!nErrStringId)
-                nErrStringId = STR_MSSG_IMPORTDATA_0;
-            aErrorMessage = ScGlobal::GetRscString( nErrStringId );
+            if (!pErrStringId)
+                pErrStringId = STR_MSSG_IMPORTDATA_0;
+            aErrorMessage = ScGlobal::GetRscString(pErrStringId);
         }
-        InfoBox aInfoBox( rDocShell.GetActiveDialogParent(), aErrorMessage );
-        aInfoBox.Execute();
+        ScopedVclPtrInstance< InfoBox > aInfoBox( ScDocShell::GetActiveDialogParent(), aErrorMessage );
+        aInfoBox->Execute();
     }
 
     delete pImportDoc;
@@ -664,7 +628,4 @@ bool ScDBDocFunc::DoImport( SCTAB nTab, const ScImportParam& rParam,
     return bSuccess;
 }
 
-
-
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
