@@ -20,9 +20,10 @@
 #include <documentlinkmgr.hxx>
 #include <datastream.hxx>
 #include <ddelink.hxx>
-#include <sc.hrc>
+#include <webservicelink.hxx>
+#include <strings.hrc>
 #include <scresid.hxx>
-
+#include <o3tl/deleter.hxx>
 #include <svx/svdoole2.hxx>
 #include <vcl/layout.hxx>
 
@@ -33,7 +34,7 @@ namespace sc {
 struct DocumentLinkManagerImpl
 {
     SfxObjectShell* mpShell;
-    std::unique_ptr<DataStream> mpDataStream;
+    std::unique_ptr<DataStream, o3tl::default_delete<DataStream>> mpDataStream;
     std::unique_ptr<sfx2::LinkManager> mpLinkManager;
 
     DocumentLinkManagerImpl(const DocumentLinkManagerImpl&) = delete;
@@ -115,15 +116,15 @@ bool DocumentLinkManager::idleCheckLinks()
 
 bool DocumentLinkManager::hasDdeLinks() const
 {
-    return hasDdeOrOleLinks(true, false);
+    return hasDdeOrOleOrWebServiceLinks(true, false, false);
 }
 
-bool DocumentLinkManager::hasDdeOrOleLinks() const
+bool DocumentLinkManager::hasDdeOrOleOrWebServiceLinks() const
 {
-    return hasDdeOrOleLinks(true, true);
+    return hasDdeOrOleOrWebServiceLinks(true, true, true);
 }
 
-bool DocumentLinkManager::hasDdeOrOleLinks(bool bDde, bool bOle) const
+bool DocumentLinkManager::hasDdeOrOleOrWebServiceLinks(bool bDde, bool bOle, bool bWebService) const
 {
     if (!mpImpl->mpLinkManager)
         return false;
@@ -136,12 +137,14 @@ bool DocumentLinkManager::hasDdeOrOleLinks(bool bDde, bool bOle) const
             return true;
         if (bOle && dynamic_cast<SdrEmbedObjectLink*>(pBase))
             return true;
+        if (bWebService && dynamic_cast<ScWebServiceLink*>(pBase))
+            return true;
     }
 
     return false;
 }
 
-bool DocumentLinkManager::updateDdeOrOleLinks( vcl::Window* pWin )
+bool DocumentLinkManager::updateDdeOrOleOrWebServiceLinks(vcl::Window* pWin)
 {
     if (!mpImpl->mpLinkManager)
         return false;
@@ -163,6 +166,13 @@ bool DocumentLinkManager::updateDdeOrOleLinks( vcl::Window* pWin )
             continue;
         }
 
+        ScWebServiceLink* pWebserviceLink = dynamic_cast<ScWebServiceLink*>(pBase);
+        if (pWebserviceLink)
+        {
+            pWebserviceLink->Update();
+            continue;
+        }
+
         ScDdeLink* pDdeLink = dynamic_cast<ScDdeLink*>(pBase);
         if (!pDdeLink)
             continue;
@@ -177,7 +187,7 @@ bool DocumentLinkManager::updateDdeOrOleLinks( vcl::Window* pWin )
             OUString aType = pDdeLink->GetAppl();
 
             OUStringBuffer aBuf;
-            aBuf.append(OUString(ScResId(SCSTR_DDEDOC_NOT_LOADED)));
+            aBuf.append(ScResId(SCSTR_DDEDOC_NOT_LOADED));
             aBuf.append("\n\n");
             aBuf.append("Source : ");
             aBuf.append(aFile);
@@ -210,9 +220,9 @@ void DocumentLinkManager::updateDdeLink( const OUString& rAppl, const OUString&
         if (!pDdeLink)
             continue;
 
-        if ( OUString(pDdeLink->GetAppl()) == rAppl &&
-             OUString(pDdeLink->GetTopic()) == rTopic &&
-             OUString(pDdeLink->GetItem()) == rItem )
+        if ( pDdeLink->GetAppl() == rAppl &&
+             pDdeLink->GetTopic() == rTopic &&
+             pDdeLink->GetItem() == rItem )
         {
             pDdeLink->TryUpdate();
             // Could be multiple (Mode), so continue searching
