@@ -19,7 +19,7 @@
 
 #include <com/sun/star/embed/EmbedMisc.hpp>
 
-#include "scitems.hxx"
+#include <scitems.hxx>
 #include <editeng/eeitem.hxx>
 #include <editeng/sizeitem.hxx>
 #include <svx/svdpagv.hxx>
@@ -37,30 +37,28 @@
 #include <svx/sidebar/SelectionAnalyzer.hxx>
 #include <svx/sidebar/ContextChangeEventMultiplexer.hxx>
 
-#include "drawsh.hxx"
-#include "drawview.hxx"
-#include "viewdata.hxx"
-#include "sc.hrc"
-#include "tabvwsh.hxx"
-#include "document.hxx"
-#include "drwlayer.hxx"
-#include "userdat.hxx"
-#include "drtxtob.hxx"
+#include <drawsh.hxx>
+#include <drawview.hxx>
+#include <viewdata.hxx>
+#include <sc.hrc>
+#include <tabvwsh.hxx>
+#include <document.hxx>
+#include <drwlayer.hxx>
+#include <userdat.hxx>
+#include <drtxtob.hxx>
 #include <gridwin.hxx>
 #include <svx/svdoole2.hxx>
 #include <svx/svdocapt.hxx>
 
-#include <boost/bind.hpp>
-
 using namespace com::sun::star;
 
 ScDrawShell::ScDrawShell( ScViewData* pData ) :
     SfxShell(pData->GetViewShell()),
     pViewData( pData ),
     mpSelectionChangeHandler(new svx::sidebar::SelectionChangeHandler(
-            ::boost::bind(&ScDrawShell::GetSidebarContextName, this),
+            [this] () { return this->GetSidebarContextName(); },
             GetFrame()->GetFrame().GetController(),
-            sfx2::sidebar::EnumContext::Context_Cell))
+            vcl::EnumContext::Context::Cell))
 {
     SetPool( &pViewData->GetScDrawView()->GetModel()->GetItemPool() );
     ::svl::IUndoManager* pMgr = pViewData->GetSfxDocShell()->GetUndoManager();
@@ -69,8 +67,7 @@ ScDrawShell::ScDrawShell( ScViewData* pData ) :
     {
         pMgr->SetMaxUndoActionCount( 0 );
     }
-    SetHelpId( HID_SCSHELL_DRAWSH );
-    SetName(OUString("Drawing"));
+    SetName("Drawing");
 
     mpSelectionChangeHandler->Connect();
 }
@@ -80,13 +77,13 @@ ScDrawShell::~ScDrawShell()
     mpSelectionChangeHandler->Disconnect();
 }
 
-void ScDrawShell::GetState( SfxItemSet& rSet )          // Zustaende / Toggles
+void ScDrawShell::GetState( SfxItemSet& rSet )          // Conditions / Toggles
 {
     ScDrawView* pView    = pViewData->GetScDrawView();
     SdrDragMode eMode    = pView->GetDragMode();
 
-    rSet.Put( SfxBoolItem( SID_OBJECT_ROTATE, eMode == SDRDRAG_ROTATE ) );
-    rSet.Put( SfxBoolItem( SID_OBJECT_MIRROR, eMode == SDRDRAG_MIRROR ) );
+    rSet.Put( SfxBoolItem( SID_OBJECT_ROTATE, eMode == SdrDragMode::Rotate ) );
+    rSet.Put( SfxBoolItem( SID_OBJECT_MIRROR, eMode == SdrDragMode::Mirror ) );
     rSet.Put( SfxBoolItem( SID_BEZIER_EDIT, !pView->IsFrameDragSingles() ) );
 
     sal_uInt16 nFWId = ScGetFontWorkId();
@@ -129,7 +126,7 @@ void ScDrawShell::GetState( SfxItemSet& rSet )          // Zustaende / Toggles
     }
 }
 
-void ScDrawShell::GetDrawFuncState( SfxItemSet& rSet )      // Funktionen disablen
+void ScDrawShell::GetDrawFuncState( SfxItemSet& rSet )      // disable functions
 {
     ScDrawView* pView = pViewData->GetScDrawView();
 
@@ -155,15 +152,16 @@ void ScDrawShell::GetDrawFuncState( SfxItemSet& rSet )      // Funktionen disabl
     if ( !pView->IsGroupEntered() )
         rSet.DisableItem( SID_LEAVE_GROUP );
 
-    if ( nMarkCount <= 1 )                      // nichts oder nur ein Objekt selektiert
+    if ( nMarkCount <= 1 )                      // Nothing or only one object selected
     {
-            //  Ausrichtung
-        rSet.DisableItem( SID_OBJECT_ALIGN_LEFT );      // keine Ausrichtung an der Seite
+            //  alignment
+        rSet.DisableItem( SID_OBJECT_ALIGN_LEFT );      // no alignment on the side
         rSet.DisableItem( SID_OBJECT_ALIGN_CENTER );
         rSet.DisableItem( SID_OBJECT_ALIGN_RIGHT );
         rSet.DisableItem( SID_OBJECT_ALIGN_UP );
         rSet.DisableItem( SID_OBJECT_ALIGN_MIDDLE );
         rSet.DisableItem( SID_OBJECT_ALIGN_DOWN );
+        rSet.DisableItem( SID_OBJECT_ALIGN );
 
         // pseudo slots for Format menu
         rSet.DisableItem( SID_ALIGN_ANY_LEFT );
@@ -220,7 +218,7 @@ void ScDrawShell::GetDrawFuncState( SfxItemSet& rSet )      // Funktionen disabl
         {
             SdrOle2Obj* pOleObj = static_cast<SdrOle2Obj*>(rMarkList.GetMark( 0 )->GetMarkedSdrObj());
             if (pOleObj->GetObjRef().is() &&
-                ((pOleObj->GetObjRef()->getStatus( pOleObj->GetAspect() ) & embed::EmbedMisc::MS_EMBED_RECOMPOSEONRESIZE) ) )
+                (pOleObj->GetObjRef()->getStatus( pOleObj->GetAspect() ) & embed::EmbedMisc::MS_EMBED_RECOMPOSEONRESIZE) )
                 //TODO/LATER: why different slots in Draw and Calc?
                 rSet.DisableItem(SID_ORIGINALSIZE);
         }
@@ -244,19 +242,19 @@ void ScDrawShell::GetDrawFuncState( SfxItemSet& rSet )      // Funktionen disabl
         rSet.DisableItem( SID_TITLE_DESCRIPTION_OBJECT );
     }
 
-    if ( !nMarkCount )                          // nichts selektiert
+    if ( !nMarkCount )                          // nothing selected
     {
-            //  Anordnung
+            //  Arrangement
         rSet.DisableItem( SID_FRAME_UP );
         rSet.DisableItem( SID_FRAME_DOWN );
         rSet.DisableItem( SID_FRAME_TO_TOP );
         rSet.DisableItem( SID_FRAME_TO_BOTTOM );
-            //  Clipboard / loeschen
+            //  Clipboard / delete
         rSet.DisableItem( SID_DELETE );
         rSet.DisableItem( SID_DELETE_CONTENTS );
         rSet.DisableItem( SID_CUT );
         rSet.DisableItem( SID_COPY );
-            //  sonstiges
+            //  other
         rSet.DisableItem( SID_ANCHOR_TOGGLE );
         rSet.DisableItem( SID_ORIGINALSIZE );
         rSet.DisableItem( SID_ATTR_TRANSFORM );
@@ -268,7 +266,7 @@ void ScDrawShell::GetDrawFuncState( SfxItemSet& rSet )      // Funktionen disabl
         pView->GetAttributes( aAttrs );
         if( aAttrs.GetItemState( EE_PARA_HYPHENATE ) >= SfxItemState::DEFAULT )
         {
-            bool bValue = static_cast<const SfxBoolItem&>( aAttrs.Get( EE_PARA_HYPHENATE ) ).GetValue();
+            bool bValue = aAttrs.Get( EE_PARA_HYPHENATE ).GetValue();
             rSet.Put( SfxBoolItem( SID_ENABLE_HYPHENATION, bValue ) );
         }
     }
@@ -277,7 +275,7 @@ void ScDrawShell::GetDrawFuncState( SfxItemSet& rSet )      // Funktionen disabl
     svx::FontworkBar::getState( pView, rSet );
 }
 
-//          Attribute fuer Drawing-Objekte
+//          Attributes for Drawing-Objects
 
 void ScDrawShell::GetDrawAttrState( SfxItemSet& rSet )
 {
@@ -310,7 +308,7 @@ void ScDrawShell::GetDrawAttrState( SfxItemSet& rSet )
         bool bActionItem = false;
         if ( pDrView->IsAction() )              // action rectangle
         {
-            Rectangle aRect;
+            tools::Rectangle aRect;
             pDrView->TakeActionRect( aRect );
             if ( !aRect.IsEmpty() )
             {
@@ -325,7 +323,7 @@ void ScDrawShell::GetDrawAttrState( SfxItemSet& rSet )
         {
             if ( pDrView->AreObjectsMarked() )      // selected objects
             {
-                Rectangle aRect = pDrView->GetAllMarkedRect();
+                tools::Rectangle aRect = pDrView->GetAllMarkedRect();
                 pPV->LogicToPagePos(aRect);
                 rSet.Put( SfxPointItem( SID_ATTR_POSITION, aRect.TopLeft() ) );
                 Size aSize( aRect.Right() - aRect.Left(), aRect.Bottom() - aRect.Top() );
@@ -344,10 +342,26 @@ void ScDrawShell::GetDrawAttrState( SfxItemSet& rSet )
 
 void ScDrawShell::GetAttrFuncState(SfxItemSet &rSet)
 {
-    //  Dialoge fuer Draw-Attribute disablen, wenn noetig
+    //  Disable dialogs for Draw-attributes if necessary
 
     ScDrawView* pDrView = pViewData->GetScDrawView();
     SfxItemSet aViewSet = pDrView->GetAttrFromMarked(false);
+    const SdrMarkList& rMarkList = pDrView->GetMarkedObjectList();
+
+    if ( rMarkList.GetMarkCount() == 1 )
+    {
+        SdrObject* pObj = rMarkList.GetMark( 0 )->GetMarkedSdrObj();
+        sal_uInt16 nObjType = pObj->GetObjIdentifier();
+
+        // If marked object is 2D, disable format area command.
+        if ( nObjType == OBJ_PLIN     ||
+             nObjType == OBJ_LINE     ||
+             nObjType == OBJ_PATHLINE ||
+             nObjType == OBJ_FREELINE ||
+             nObjType == OBJ_EDGE     ||
+             nObjType == OBJ_CARC )
+            rSet.DisableItem( SID_ATTRIBUTES_AREA );
+    }
 
     if ( aViewSet.GetItemState( XATTR_LINESTYLE ) == SfxItemState::DEFAULT )
     {
@@ -359,14 +373,14 @@ void ScDrawShell::GetAttrFuncState(SfxItemSet &rSet)
         rSet.DisableItem( SID_ATTRIBUTES_AREA );
 }
 
-bool ScDrawShell::AreAllObjectsOnLayer(sal_uInt16 nLayerNo,const SdrMarkList& rMark)
+bool ScDrawShell::AreAllObjectsOnLayer(SdrLayerID nLayerNo,const SdrMarkList& rMark)
 {
     bool bResult=true;
     const size_t nCount = rMark.GetMarkCount();
     for (size_t i=0; i<nCount; ++i)
     {
         SdrObject* pObj = rMark.GetMark(i)->GetMarkedSdrObj();
-        if ( !pObj->ISA(SdrUnoObj) )
+        if ( dynamic_cast<const SdrUnoObj*>( pObj) ==  nullptr )
         {
             if(nLayerNo!=pObj->GetLayer())
             {
@@ -383,27 +397,25 @@ void ScDrawShell::GetDrawAttrStateForIFBX( SfxItemSet& rSet )
     ScDrawView* pView = pViewData->GetScDrawView();
     const SdrMarkList& rMarkList = pView->GetMarkedObjectList();
 
-    if( rMarkList.GetMark(0) != 0 )
+    if( rMarkList.GetMark(0) != nullptr )
     {
         SfxItemSet aNewAttr(pView->GetGeoAttrFromMarked());
         rSet.Put(aNewAttr, false);
     }
 }
 
-void ScDrawShell::Activate (const bool bMDI)
+void ScDrawShell::Activate (const bool)
 {
-    (void)bMDI;
-
     ContextChangeEventMultiplexer::NotifyContextChange(
         GetFrame()->GetFrame().GetController(),
-        ::sfx2::sidebar::EnumContext::GetContextEnum(
+        vcl::EnumContext::GetContextEnum(
             GetSidebarContextName()));
 }
 
-::rtl::OUString ScDrawShell::GetSidebarContextName (void)
+::rtl::OUString ScDrawShell::GetSidebarContextName()
 {
-    return sfx2::sidebar::EnumContext::GetContextName(
-        ::svx::sidebar::SelectionAnalyzer::GetContextForSelection_SC(
+    return vcl::EnumContext::GetContextName(
+        svx::sidebar::SelectionAnalyzer::GetContextForSelection_SC(
             GetDrawView()->GetMarkedObjectList()));
 }
 
