@@ -23,11 +23,11 @@
 #include <vcl/layout.hxx>
 #include <limits.h>
 
-#include "scresid.hxx"
-#include "document.hxx"
-#include "globstr.hrc"
-#include "miscdlgs.hrc"
-#include "filldlg.hxx"
+#include <scresid.hxx>
+#include <document.hxx>
+#include <globstr.hrc>
+#include <strings.hrc>
+#include <filldlg.hxx>
 
 // class ScFillSeriesDlg
 
@@ -42,7 +42,7 @@ ScFillSeriesDlg::ScFillSeriesDlg( vcl::Window*       pParent,
                                   sal_uInt16        nPossDir )
     : ModalDialog(pParent, "FillSeriesDialog", "modules/scalc/ui/filldlg.ui"),
         aStartStrVal    ( aStartStr),
-        aErrMsgInvalidVal( SC_RESSTR(SCSTR_VALERR) ),
+        aErrMsgInvalidVal( ScResId(SCSTR_VALERR) ),
         rDoc            ( rDocument ),
         theFillDir      ( eFillDir ),
         theFillCmd      ( eFillCmd ),
@@ -106,7 +106,6 @@ void ScFillSeriesDlg::dispose()
 
 void ScFillSeriesDlg::SetEdStartValEnabled(bool bFlag)
 {
-    bStartValFlag=bFlag;
     if(bFlag)
     {
        m_pFtStartVal->Enable();
@@ -201,8 +200,6 @@ void ScFillSeriesDlg::Init( sal_uInt16 nPossDir )
     if ( fEndVal != MAXDOUBLE )
         rDoc.GetFormatTable()->GetInputLineString( fEndVal, 0, aEndTxt );
     m_pEdEndVal->SetText( aEndTxt );
-
-    bStartValFlag = false;
 }
 
 bool ScFillSeriesDlg::CheckStartVal()
@@ -251,7 +248,7 @@ bool ScFillSeriesDlg::CheckEndVal()
 
 // Handler:
 
-IMPL_LINK( ScFillSeriesDlg, DisableHdl, Button *, pBtn )
+IMPL_LINK( ScFillSeriesDlg, DisableHdl, Button *, pBtn, void )
 {
     if ( pBtn == m_pBtnDate )
     {
@@ -284,10 +281,9 @@ IMPL_LINK( ScFillSeriesDlg, DisableHdl, Button *, pBtn )
         m_pFtEndVal->Disable();
         m_pEdEndVal->Disable();
     }
-    return 0;
 }
 
-IMPL_LINK_NOARG(ScFillSeriesDlg, OKHdl)
+IMPL_LINK_NOARG(ScFillSeriesDlg, OKHdl, Button*, void)
 {
     if ( m_pBtnLeft->IsChecked() )             theFillDir = FILL_TO_LEFT;
     else if ( m_pBtnRight->IsChecked() )       theFillDir = FILL_TO_RIGHT;
@@ -305,7 +301,7 @@ IMPL_LINK_NOARG(ScFillSeriesDlg, OKHdl)
     else if ( m_pBtnYear->IsChecked() )        theFillDateCmd = FILL_YEAR;
 
     bool  bAllOk = true;
-    Edit* pEdWrong = NULL;
+    Edit* pEdWrong = nullptr;
     if ( !CheckStartVal() )
     {
         bAllOk = false;
@@ -325,11 +321,9 @@ IMPL_LINK_NOARG(ScFillSeriesDlg, OKHdl)
         EndDialog( RET_OK );
     else
     {
-        ScopedVclPtr<MessageDialog>::Create(this, aErrMsgInvalidVal)->Execute();
+        ScopedVclPtrInstance<MessageDialog>(this, aErrMsgInvalidVal)->Execute();
         pEdWrong->GrabFocus();
     }
-
-    return 0;
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
