@@ -7,31 +7,25 @@
  * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  */
 
-#include "namedefdlg.hxx"
+#include <namedefdlg.hxx>
 
 #include <vcl/msgbox.hxx>
+#include <vcl/settings.hxx>
+#include <formula/errorcodes.hxx>
 #include <sfx2/app.hxx>
 
-#include "document.hxx"
-#include "globstr.hrc"
-#include "globalnames.hxx"
-#include "rangenam.hxx"
-#include "reffact.hxx"
-#include "undorangename.hxx"
-#include "tabvwsh.hxx"
-#include "tokenarray.hxx"
-#include "sc.hrc"
+#include <document.hxx>
+#include <globstr.hrc>
+#include <globalnames.hxx>
+#include <rangenam.hxx>
+#include <reffact.hxx>
+#include <undorangename.hxx>
+#include <tabvwsh.hxx>
+#include <tokenarray.hxx>
+#include <sc.hrc>
 
-// defines -------------------------------------------------------------------
-
-#define ABS_SREF          SCA_VALID \
-    | SCA_COL_ABSOLUTE | SCA_ROW_ABSOLUTE | SCA_TAB_ABSOLUTE
-#define ABS_DREF          ABS_SREF \
-    | SCA_COL2_ABSOLUTE | SCA_ROW2_ABSOLUTE | SCA_TAB2_ABSOLUTE
-#define ABS_DREF3D      ABS_DREF | SCA_TAB_3D
-
-ScNameDefDlg::ScNameDefDlg( SfxBindings* pB, SfxChildWindow* pCW, Window* pParent,
-        ScViewData* pViewData, std::map<OUString, ScRangeName*> aRangeMap,
+ScNameDefDlg::ScNameDefDlg( SfxBindings* pB, SfxChildWindow* pCW, vcl::Window* pParent,
+        const ScViewData* pViewData, const std::map<OUString, ScRangeName*>& aRangeMap,
         const ScAddress& aCursorPos, const bool bUndo )
     : ScAnyRefDlg( pB, pCW, pParent, "DefineNameDialog", "modules/scalc/ui/definename.ui" )
     ,
@@ -42,6 +36,7 @@ ScNameDefDlg::ScNameDefDlg( SfxBindings* pB, SfxChildWindow* pCW, Window* pParen
 
     maGlobalNameStr  ( ScGlobal::GetRscString(STR_GLOBAL_SCOPE) ),
     maErrInvalidNameStr( ScGlobal::GetRscString(STR_ERR_NAME_INVALID)),
+    maErrInvalidNameCellRefStr( ScGlobal::GetRscString(STR_ERR_NAME_INVALID_CELL_REF)),
     maErrNameInUse   ( ScGlobal::GetRscString(STR_ERR_NAME_EXISTS)),
     maRangeMap( aRangeMap )
 {
@@ -81,7 +76,7 @@ ScNameDefDlg::ScNameDefDlg( SfxBindings* pB, SfxChildWindow* pCW, Window* pParen
     ScRange aRange;
 
     pViewData->GetSimpleArea( aRange );
-    OUString aAreaStr(aRange.Format(ABS_DREF3D, mpDoc,
+    OUString aAreaStr(aRange.Format(ScRefFlags::RANGE_ABS_3D, mpDoc,
             ScAddress::Details(mpDoc->GetAddressConvention(), 0, 0)));
 
     m_pEdRange->SetText( aAreaStr );
@@ -91,6 +86,27 @@ ScNameDefDlg::ScNameDefDlg( SfxBindings* pB, SfxChildWindow* pCW, Window* pParen
     m_pEdName->SetSelection( aCurSel );
 }
 
+ScNameDefDlg::~ScNameDefDlg()
+{
+    disposeOnce();
+}
+
+void ScNameDefDlg::dispose()
+{
+    m_pEdName.clear();
+    m_pEdRange.clear();
+    m_pRbRange.clear();
+    m_pLbScope.clear();
+    m_pBtnRowHeader.clear();
+    m_pBtnColHeader.clear();
+    m_pBtnPrintArea.clear();
+    m_pBtnCriteria.clear();
+    m_pBtnAdd.clear();
+    m_pBtnCancel.clear();
+    m_pFtInfo.clear();
+    ScAnyRefDlg::dispose();
+}
+
 void ScNameDefDlg::CancelPushed()
 {
     if (mbUndo)
@@ -104,10 +120,9 @@ void ScNameDefDlg::CancelPushed()
 
 bool ScNameDefDlg::IsFormulaValid()
 {
-    ScCompiler aComp( mpDoc, maCursorPos);
-    aComp.SetGrammar( mpDoc->GetGrammar() );
+    ScCompiler aComp( mpDoc, maCursorPos, mpDoc->GetGrammar());
     ScTokenArray* pCode = aComp.CompileString(m_pEdRange->GetText());
-    if (pCode->GetCodeError())
+    if (pCode->GetCodeError() != FormulaError::NONE)
     {
         //TODO: info message
         delete pCode;
@@ -122,10 +137,10 @@ bool ScNameDefDlg::IsFormulaValid()
 
 bool ScNameDefDlg::IsNameValid()
 {
-    OUString aScope = m_pLbScope->GetSelectEntry();
+    OUString aScope = m_pLbScope->GetSelectedEntry();
     OUString aName = m_pEdName->GetText();
 
-    ScRangeName* pRangeName = NULL;
+    ScRangeName* pRangeName = nullptr;
     if(aScope == maGlobalNameStr)
     {
         pRangeName = maRangeMap.find(OUString(STR_GLOBAL_RANGE_NAME))->second;
@@ -135,6 +150,7 @@ bool ScNameDefDlg::IsNameValid()
         pRangeName = maRangeMap.find(aScope)->second;
     }
 
+    ScRangeData::IsNameValidType eType;
     m_pFtInfo->SetControlBackground(GetSettings().GetStyleSettings().GetDialogColor());
     if ( aName.isEmpty() )
     {
@@ -142,10 +158,17 @@ bool ScNameDefDlg::IsNameValid()
         m_pFtInfo->SetText(maStrInfoDefault);
         return false;
     }
-    else if (!ScRangeData::IsNameValid( aName, mpDoc ))
+    else if ((eType = ScRangeData::IsNameValid( aName, mpDoc )) != ScRangeData::NAME_VALID)
     {
         m_pFtInfo->SetControlBackground(GetSettings().GetStyleSettings().GetHighlightColor());
-        m_pFtInfo->SetText(maErrInvalidNameStr);
+        if (eType == ScRangeData::NAME_INVALID_BAD_STRING)
+        {
+            m_pFtInfo->SetText(maErrInvalidNameStr);
+        }
+        else if (eType == ScRangeData::NAME_INVALID_CELL_REF)
+        {
+            m_pFtInfo->SetText(maErrInvalidNameCellRefStr);
+        }
         m_pBtnAdd->Disable();
         return false;
     }
@@ -171,7 +194,7 @@ bool ScNameDefDlg::IsNameValid()
 
 void ScNameDefDlg::AddPushed()
 {
-    OUString aScope = m_pLbScope->GetSelectEntry();
+    OUString aScope = m_pLbScope->GetSelectedEntry();
     OUString aName = m_pEdName->GetText();
     OUString aExpression = m_pEdRange->GetText();
 
@@ -184,7 +207,7 @@ void ScNameDefDlg::AddPushed()
         return;
     }
 
-    ScRangeName* pRangeName = NULL;
+    ScRangeName* pRangeName = nullptr;
     if(aScope == maGlobalNameStr)
     {
         pRangeName = maRangeMap.find(OUString(STR_GLOBAL_RANGE_NAME))->second;
@@ -202,29 +225,26 @@ void ScNameDefDlg::AddPushed()
     {
         if ( mpDoc )
         {
-            ScRangeData*    pNewEntry   = NULL;
-            RangeType       nType       = RT_NAME;
+            ScRangeData::Type nType = ScRangeData::Type::Name;
 
-            pNewEntry = new ScRangeData( mpDoc,
+            ScRangeData* pNewEntry = new ScRangeData( mpDoc,
                     aName,
                     aExpression,
                     maCursorPos,
                     nType );
-            if (pNewEntry)
-            {
-                nType = nType
-                    | (m_pBtnRowHeader->IsChecked() ? RT_ROWHEADER  : RangeType(0))
-                    | (m_pBtnColHeader->IsChecked() ? RT_COLHEADER  : RangeType(0))
-                    | (m_pBtnPrintArea->IsChecked() ? RT_PRINTAREA  : RangeType(0))
-                    | (m_pBtnCriteria->IsChecked() ? RT_CRITERIA   : RangeType(0));
-                pNewEntry->AddType(nType);
-            }
+
+            if ( m_pBtnRowHeader->IsChecked() ) nType |= ScRangeData::Type::RowHeader;
+            if ( m_pBtnColHeader->IsChecked() ) nType |= ScRangeData::Type::ColHeader;
+            if ( m_pBtnPrintArea->IsChecked() ) nType |= ScRangeData::Type::PrintArea;
+            if ( m_pBtnCriteria->IsChecked()  ) nType |= ScRangeData::Type::Criteria;
+
+            pNewEntry->AddType(nType);
 
             // aExpression valid?
-            if ( 0 == pNewEntry->GetErrCode() )
+            if ( FormulaError::NONE == pNewEntry->GetErrCode() )
             {
-                if ( !pRangeName->insert( pNewEntry ) )
-                    pNewEntry = NULL;
+                if ( !pRangeName->insert( pNewEntry, false /*bReuseFreeIndex*/ ) )
+                    pNewEntry = nullptr;
 
                 if (mbUndo)
                 {
@@ -235,14 +255,16 @@ void ScNameDefDlg::AddPushed()
                     if (!mpDoc->GetTable(aScope, nTab))
                         nTab = -1;
 
-                    mpDocShell->GetUndoManager()->AddUndoAction(
-                            new ScUndoAddRangeData( mpDocShell, pNewEntry, nTab) );
+                    assert( pNewEntry);     // undo of no insertion smells fishy
+                    if (pNewEntry)
+                        mpDocShell->GetUndoManager()->AddUndoAction(
+                                new ScUndoAddRangeData( mpDocShell, pNewEntry, nTab) );
 
                     // set table stream invalid, otherwise RangeName won't be saved if no other
                     // call invalidates the stream
                     if (nTab != -1)
                         mpDoc->SetStreamValid(nTab, false);
-                    SFX_APP()->Broadcast( SfxSimpleHint( SC_HINT_AREAS_CHANGED ) );
+                    SfxGetpApp()->Broadcast( SfxHint( SfxHintId::ScAreasChanged ) );
                     mpDocShell->SetDocumentModified();
                     Close();
                 }
@@ -271,12 +293,12 @@ void ScNameDefDlg::GetNewData(OUString& rName, OUString& rScope)
     rScope = maScope;
 }
 
-sal_Bool ScNameDefDlg::IsRefInputMode() const
+bool ScNameDefDlg::IsRefInputMode() const
 {
     return m_pEdRange->IsEnabled();
 }
 
-void ScNameDefDlg::RefInputDone( sal_Bool bForced)
+void ScNameDefDlg::RefInputDone( bool bForced)
 {
     ScAnyRefDlg::RefInputDone(bForced);
     IsNameValid();
@@ -288,13 +310,13 @@ void ScNameDefDlg::SetReference( const ScRange& rRef, ScDocument* pDocP )
     {
         if ( rRef.aStart != rRef.aEnd )
             RefInputStart(m_pEdRange);
-        OUString aRefStr(rRef.Format(ABS_DREF3D, pDocP,
+        OUString aRefStr(rRef.Format(ScRefFlags::RANGE_ABS_3D, pDocP,
                 ScAddress::Details(pDocP->GetAddressConvention(), 0, 0)));
         m_pEdRange->SetRefString( aRefStr );
     }
 }
 
-sal_Bool ScNameDefDlg::Close()
+bool ScNameDefDlg::Close()
 {
     return DoClose( ScNameDefDlgWrapper::GetChildWindowId() );
 }
@@ -305,28 +327,24 @@ void ScNameDefDlg::SetActive()
     RefInputDone();
 }
 
-IMPL_LINK_NOARG(ScNameDefDlg, CancelBtnHdl)
+IMPL_LINK_NOARG(ScNameDefDlg, CancelBtnHdl, Button*, void)
 {
     CancelPushed();
-    return 0;
 }
 
-IMPL_LINK_NOARG(ScNameDefDlg, AddBtnHdl)
+IMPL_LINK_NOARG(ScNameDefDlg, AddBtnHdl, Button*, void)
 {
     AddPushed();
-    return 0;
 };
 
-IMPL_LINK_NOARG(ScNameDefDlg, NameModifyHdl)
+IMPL_LINK_NOARG(ScNameDefDlg, NameModifyHdl, Edit&, void)
 {
     IsNameValid();
-    return 0;
 }
 
-IMPL_LINK_NOARG(ScNameDefDlg, AssignGetFocusHdl)
+IMPL_LINK_NOARG(ScNameDefDlg, AssignGetFocusHdl, Control&, void)
 {
     IsNameValid();
-    return 0;
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
