@@ -9,15 +9,15 @@
 
 //ScRangeManagerTable
 #include <memory>
-#include "global.hxx"
-#include "reffact.hxx"
-#include "document.hxx"
-#include "docfunc.hxx"
-#include "scresid.hxx"
-#include "globstr.hrc"
-#include "namedlg.hxx"
-#include "viewdata.hxx"
-#include "globalnames.hxx"
+#include <global.hxx>
+#include <reffact.hxx>
+#include <document.hxx>
+#include <docfunc.hxx>
+#include <scresid.hxx>
+#include <globstr.hrc>
+#include <namedlg.hxx>
+#include <viewdata.hxx>
+#include <globalnames.hxx>
 
 #include <sfx2/app.hxx>
 
@@ -36,7 +36,7 @@ static OUString createEntryString(const ScRangeNameLine& rLine)
 ScRangeManagerTable::InitListener::~InitListener() {}
 
 ScRangeManagerTable::ScRangeManagerTable(SvSimpleTableContainer& rParent,
-        std::map<OUString, std::unique_ptr<ScRangeName>>& rRangeMap,
+        const std::map<OUString, std::unique_ptr<ScRangeName>>& rRangeMap,
         const ScAddress& rPos)
     : SvSimpleTable( rParent, WB_SORT | WB_HSCROLL | WB_CLIPCHILDREN | WB_TABSTOP )
     , maGlobalString( ScGlobal::GetRscString(STR_GLOBAL_SCOPE))
