@@ -20,12 +20,10 @@
 #include <svl/intitem.hxx>
 #include <svl/stritem.hxx>
 
-#include "navcitem.hxx"
-#include "global.hxx"
-#include "navipi.hxx"
-#include "sc.hrc"
-
-// STATIC DATA -----------------------------------------------------------
+#include <navcitem.hxx>
+#include <global.hxx>
+#include <navipi.hxx>
+#include <sc.hrc>
 
 ScNavigatorControllerItem::ScNavigatorControllerItem( sal_uInt16          nIdP,
                                                       ScNavigatorDlg& rDlg,
@@ -69,7 +67,7 @@ void ScNavigatorControllerItem::StateChanged( sal_uInt16 /* nSID */, SfxItemStat
 
                 OSL_ENSURE( pTabItem, "SfxUInt16Item expected!" );
 
-                //  Tabelle fuer Basic ist 1-basiert
+                //  table for Basic is 1-based
                 if ( pTabItem && pTabItem->GetValue() )
                 {
                     SCTAB nTab = pTabItem->GetValue() - 1;
@@ -83,7 +81,7 @@ void ScNavigatorControllerItem::StateChanged( sal_uInt16 /* nSID */, SfxItemStat
 
         case SID_CURRENTDOC:
 
-            //  gar nix mehr, wird ueber SFX_HINT_DOCCHANGED erledigt
+            //  nothing is done via SfxHintId::DocChanged
 
             break;
 
