@@ -7,17 +7,17 @@
  * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  */
 
-#include "undorangename.hxx"
-#include "globstr.hrc"
-#include "global.hxx"
-#include "docfunc.hxx"
-#include "sc.hrc"
+#include <undorangename.hxx>
+#include <globstr.hrc>
+#include <global.hxx>
+#include <docfunc.hxx>
+#include <sc.hrc>
 
 #include <sfx2/app.hxx>
 
 #include <memory>
 #include <utility>
-
+#include <o3tl/make_unique.hxx>
 using ::std::unique_ptr;
 
 ScUndoAllRangeNames::ScUndoAllRangeNames(
@@ -29,14 +29,12 @@ ScUndoAllRangeNames::ScUndoAllRangeNames(
     std::map<OUString, ScRangeName*>::const_iterator itr, itrEnd;
     for (itr = rOldNames.begin(), itrEnd = rOldNames.end(); itr != itrEnd; ++itr)
     {
-        unique_ptr<ScRangeName> p(new ScRangeName(*itr->second));
-        m_OldNames.insert(std::make_pair(itr->first, std::move(p)));
+        m_OldNames.insert(std::make_pair(itr->first,o3tl::make_unique<ScRangeName>(*itr->second)));
     }
 
     for (auto const& it : rNewNames)
     {
-        unique_ptr<ScRangeName> p(new ScRangeName(*it.second));
-        m_NewNames.insert(std::make_pair(it.first, std::move(p)));
+        m_NewNames.insert(std::make_pair(it.first, o3tl::make_unique<ScRangeName>(*it.second)));
     }
 }
 
@@ -72,14 +70,14 @@ void ScUndoAllRangeNames::DoChange(const std::map<OUString, std::unique_ptr<ScRa
 {
     ScDocument& rDoc = pDocShell->GetDocument();
 
-    rDoc.PreprocessRangeNameUpdate();
+    rDoc.PreprocessAllRangeNamesUpdate(rNames);
     rDoc.SetAllRangeNames(rNames);
     rDoc.CompileHybridFormula();
 
-    SfxGetpApp()->Broadcast(SfxSimpleHint(SC_HINT_AREAS_CHANGED));
+    SfxGetpApp()->Broadcast(SfxHint(SfxHintId::ScAreasChanged));
 }
 
-ScUndoAddRangeData::ScUndoAddRangeData(ScDocShell* pDocSh, ScRangeData* pRangeData, SCTAB nTab) :
+ScUndoAddRangeData::ScUndoAddRangeData(ScDocShell* pDocSh, const ScRangeData* pRangeData, SCTAB nTab) :
     ScSimpleUndo(pDocSh),
     mpRangeData(new ScRangeData(*pRangeData)),
     mnTab(nTab)
@@ -89,7 +87,6 @@ ScUndoAddRangeData::ScUndoAddRangeData(ScDocShell* pDocSh, ScRangeData* pRangeDa
 
 ScUndoAddRangeData::~ScUndoAddRangeData()
 {
-    delete mpRangeData;
 }
 
 void ScUndoAddRangeData::Undo()
@@ -105,7 +102,7 @@ void ScUndoAddRangeData::Undo()
         pRangeName = rDoc.GetRangeName( mnTab );
     }
     pRangeName->erase(*mpRangeData);
-    SfxGetpApp()->Broadcast( SfxSimpleHint( SC_HINT_AREAS_CHANGED ) );
+    SfxGetpApp()->Broadcast( SfxHint( SfxHintId::ScAreasChanged ) );
 
 }
 
@@ -122,7 +119,7 @@ void ScUndoAddRangeData::Redo()
         pRangeName = rDoc.GetRangeName( mnTab );
     }
     pRangeName->insert(new ScRangeData(*mpRangeData));
-    SfxGetpApp()->Broadcast( SfxSimpleHint( SC_HINT_AREAS_CHANGED ) );
+    SfxGetpApp()->Broadcast( SfxHint( SfxHintId::ScAreasChanged ) );
 }
 
 void ScUndoAddRangeData::Repeat(SfxRepeatTarget& /*rTarget*/)
