@@ -42,7 +42,7 @@ void UndoSort::Execute( bool bUndo )
     sc::ReorderParam aParam = maParam;
     if (bUndo)
         aParam.reverse();
-    rDoc.Reorder(aParam, nullptr);
+    rDoc.Reorder(aParam);
 
     if (maParam.mbHasHeaders)
     {
@@ -66,9 +66,9 @@ void UndoSort::Execute( bool bUndo )
 
     rDoc.SetDirty(maParam.maSortRange, true);
     if (!aParam.mbUpdateRefs)
-        rDoc.BroadcastCells(aParam.maSortRange, SC_HINT_DATACHANGED);
+        rDoc.BroadcastCells(aParam.maSortRange, SfxHintId::ScDataChanged);
 
-    pDocShell->PostPaint(maParam.maSortRange, PAINT_GRID);
+    pDocShell->PostPaint(maParam.maSortRange, PaintPartFlags::Grid);
     pDocShell->PostDataChanged();
 }
 
