@@ -22,30 +22,31 @@
 #include <sfx2/dispatch.hxx>
 #include <svl/hint.hxx>
 
-#include "undotab.hxx"
-#include "document.hxx"
-#include "docsh.hxx"
-#include "tabvwsh.hxx"
-#include "globstr.hrc"
-#include "global.hxx"
-#include "scres.hrc"
-#include "undoolk.hxx"
-#include "target.hxx"
-#include "uiitems.hxx"
-#include "prnsave.hxx"
-#include "printfun.hxx"
-#include "chgtrack.hxx"
-#include "tabprotection.hxx"
-#include "viewdata.hxx"
-#include "progress.hxx"
-#include "markdata.hxx"
+#include <undotab.hxx>
+#include <document.hxx>
+#include <docsh.hxx>
+#include <tabvwsh.hxx>
+#include <globstr.hrc>
+#include <global.hxx>
+#include <sc.hrc>
+#include <strings.hrc>
+#include <undoolk.hxx>
+#include <target.hxx>
+#include <uiitems.hxx>
+#include <prnsave.hxx>
+#include <printfun.hxx>
+#include <chgtrack.hxx>
+#include <tabprotection.hxx>
+#include <viewdata.hxx>
+#include <progress.hxx>
+#include <markdata.hxx>
 
 // for ScUndoRenameObject - might me moved to another file later
 #include <svx/svditer.hxx>
 #include <svx/svdoole2.hxx>
 #include <svx/svdpage.hxx>
-#include "drwlayer.hxx"
-#include "scresid.hxx"
+#include <drwlayer.hxx>
+#include <scresid.hxx>
 
 #include <memory>
 #include <utility>
@@ -152,7 +153,7 @@ bool ScUndoInsertTab::CanRepeat(SfxRepeatTarget& rTarget) const
 
 ScUndoInsertTables::ScUndoInsertTables( ScDocShell* pNewDocShell,
                                         SCTAB nTabNum,
-                                        std::vector<OUString>& newNameList) :
+                                        const std::vector<OUString>& newNameList) :
     ScSimpleUndo( pNewDocShell ),
     pDrawUndo( nullptr ),
     aNameList( newNameList ),
@@ -283,7 +284,7 @@ void ScUndoDeleteTab::SetChangeTrack()
         nStartChangeAction = nEndChangeAction = 0;
 }
 
-static SCTAB lcl_GetVisibleTabBefore( ScDocument& rDoc, SCTAB nTab )
+static SCTAB lcl_GetVisibleTabBefore( const ScDocument& rDoc, SCTAB nTab )
 {
     while ( nTab > 0 && !rDoc.IsVisible( nTab ) )
         --nTab;
@@ -1017,9 +1018,9 @@ ScUndoRemoveLink::ScUndoRemoveLink( ScDocShell* pShell, const OUString& rDocName
 {
     ScDocument& rDoc = pDocShell->GetDocument();
     SCTAB nTabCount = rDoc.GetTableCount();
-    pTabs     = new SCTAB[nTabCount];
-    pModes    = new ScLinkMode[nTabCount];
-    pTabNames = new OUString[nTabCount];
+    pTabs.reset( new SCTAB[nTabCount] );
+    pModes.reset( new ScLinkMode[nTabCount] );
+    pTabNames.reset( new OUString[nTabCount] );
 
     for (SCTAB i=0; i<nTabCount; i++)
     {
@@ -1049,9 +1050,6 @@ ScUndoRemoveLink::ScUndoRemoveLink( ScDocShell* pShell, const OUString& rDocName
 
 ScUndoRemoveLink::~ScUndoRemoveLink()
 {
-    delete pTabs;
-    delete pModes;
-    delete[] pTabNames;
 }
 
 OUString ScUndoRemoveLink::GetComment() const
@@ -1145,17 +1143,17 @@ bool ScUndoShowHideTab::CanRepeat(SfxRepeatTarget& rTarget) const
 
 OUString ScUndoShowHideTab::GetComment() const
 {
-    sal_uInt16 nId;
+    const char* pId;
     if (undoTabs.size() > 1)
     {
-        nId = bShow ? STR_UNDO_SHOWTABS : STR_UNDO_HIDETABS;
+        pId = bShow ? STR_UNDO_SHOWTABS : STR_UNDO_HIDETABS;
     }
     else
     {
-        nId = bShow ? STR_UNDO_SHOWTAB : STR_UNDO_HIDETAB;
+        pId = bShow ? STR_UNDO_SHOWTAB : STR_UNDO_HIDETAB;
     }
 
-    return ScGlobal::GetRscString( nId );
+    return ScGlobal::GetRscString(pId);
 }
 
 ScUndoDocProtect::ScUndoDocProtect(ScDocShell* pShell, unique_ptr<ScDocProtection> && pProtectSettings) :
@@ -1221,8 +1219,8 @@ bool ScUndoDocProtect::CanRepeat(SfxRepeatTarget& /* rTarget */) const
 
 OUString ScUndoDocProtect::GetComment() const
 {
-    sal_uInt16 nId = mpProtectSettings->isProtected() ? STR_UNDO_PROTECT_DOC : STR_UNDO_UNPROTECT_DOC;
-    return ScGlobal::GetRscString( nId );
+    const char* pId = mpProtectSettings->isProtected() ? STR_UNDO_PROTECT_DOC : STR_UNDO_UNPROTECT_DOC;
+    return ScGlobal::GetRscString(pId);
 }
 
 ScUndoTabProtect::ScUndoTabProtect(ScDocShell* pShell, SCTAB nTab, unique_ptr<ScTableProtection> && pProtectSettings) :
@@ -1289,8 +1287,8 @@ bool ScUndoTabProtect::CanRepeat(SfxRepeatTarget& /* rTarget */) const
 
 OUString ScUndoTabProtect::GetComment() const
 {
-    sal_uInt16 nId = mpProtectSettings->isProtected() ? STR_UNDO_PROTECT_TAB : STR_UNDO_UNPROTECT_TAB;
-    return ScGlobal::GetRscString( nId );
+    const char* pId = mpProtectSettings->isProtected() ? STR_UNDO_PROTECT_TAB : STR_UNDO_UNPROTECT_TAB;
+    return ScGlobal::GetRscString(pId);
 }
 
 ScUndoPrintRange::ScUndoPrintRange( ScDocShell* pShell, SCTAB nNewTab,
@@ -1440,7 +1438,7 @@ ScUndoRenameObject::~ScUndoRenameObject()
 OUString ScUndoRenameObject::GetComment() const
 {
     //  string resource shared with title for dialog
-    return OUString( ScResId(SCSTR_RENAMEOBJECT) );
+    return ScResId(SCSTR_RENAMEOBJECT);
 }
 
 SdrObject* ScUndoRenameObject::GetObject()
