@@ -26,20 +26,21 @@
 #include <vcl/settings.hxx>
 #include <com/sun/star/awt/XBitmap.hpp>
 
-#include "targuno.hxx"
-#include "miscuno.hxx"
-#include "docuno.hxx"
-#include "datauno.hxx"
-#include "nameuno.hxx"
-#include "docsh.hxx"
-#include "content.hxx"
-#include "scresid.hxx"
-#include "sc.hrc"
-#include "unonames.hxx"
+#include <targuno.hxx>
+#include <miscuno.hxx>
+#include <docuno.hxx>
+#include <datauno.hxx>
+#include <nameuno.hxx>
+#include <docsh.hxx>
+#include <content.hxx>
+#include <scresid.hxx>
+#include <strings.hrc>
+#include <bitmaps.hlst>
+#include <unonames.hxx>
 
 using  namespace ::com::sun::star;
 
-sal_uInt16 nTypeResIds[SC_LINKTARGETTYPE_COUNT] =
+static const char* aTypeResIds[SC_LINKTARGETTYPE_COUNT] =
 {
     SCSTR_CONTENT_TABLE,        // SC_LINKTARGETTYPE_SHEET
     SCSTR_CONTENT_RANGENAME,    // SC_LINKTARGETTYPE_RANGENAME
@@ -70,7 +71,7 @@ ScLinkTargetTypesObj::ScLinkTargetTypesObj(ScDocShell* pDocSh) :
     pDocShell->GetDocument().AddUnoObject(*this);
 
     for (sal_uInt16 i=0; i<SC_LINKTARGETTYPE_COUNT; i++)
-        aNames[i] = ScResId( nTypeResIds[i] );
+        aNames[i] = ScResId(aTypeResIds[i]);
 }
 
 ScLinkTargetTypesObj::~ScLinkTargetTypesObj()
@@ -83,14 +84,13 @@ ScLinkTargetTypesObj::~ScLinkTargetTypesObj()
 
 void ScLinkTargetTypesObj::Notify( SfxBroadcaster&, const SfxHint& rHint )
 {
-    if ( rHint.GetId() == SFX_HINT_DYING )
+    if ( rHint.GetId() == SfxHintId::Dying )
         pDocShell = nullptr;       // document gone
 }
 
 // container::XNameAccess
 
 uno::Any SAL_CALL ScLinkTargetTypesObj::getByName(const OUString& aName)
-        throw( container::NoSuchElementException, lang::WrappedTargetException, uno::RuntimeException, std::exception )
 {
     if (pDocShell)
     {
@@ -102,7 +102,7 @@ uno::Any SAL_CALL ScLinkTargetTypesObj::getByName(const OUString& aName)
     throw container::NoSuchElementException();
 }
 
-uno::Sequence<OUString> SAL_CALL ScLinkTargetTypesObj::getElementNames() throw( uno::RuntimeException, std::exception )
+uno::Sequence<OUString> SAL_CALL ScLinkTargetTypesObj::getElementNames()
 {
     uno::Sequence<OUString> aRet(SC_LINKTARGETTYPE_COUNT);
     OUString* pArray = aRet.getArray();
@@ -111,7 +111,7 @@ uno::Sequence<OUString> SAL_CALL ScLinkTargetTypesObj::getElementNames() throw(
     return aRet;
 }
 
-sal_Bool SAL_CALL ScLinkTargetTypesObj::hasByName(const OUString& aName) throw( uno::RuntimeException, std::exception )
+sal_Bool SAL_CALL ScLinkTargetTypesObj::hasByName(const OUString& aName)
 {
     for (const auto & i : aNames)
         if ( i == aName )
@@ -121,12 +121,12 @@ sal_Bool SAL_CALL ScLinkTargetTypesObj::hasByName(const OUString& aName) throw(
 
 // container::XElementAccess
 
-uno::Type SAL_CALL ScLinkTargetTypesObj::getElementType() throw( uno::RuntimeException, std::exception )
+uno::Type SAL_CALL ScLinkTargetTypesObj::getElementType()
 {
     return cppu::UnoType<beans::XPropertySet>::get();
 }
 
-sal_Bool SAL_CALL ScLinkTargetTypesObj::hasElements() throw( uno::RuntimeException, std::exception )
+sal_Bool SAL_CALL ScLinkTargetTypesObj::hasElements()
 {
     return true;
 }
@@ -136,7 +136,7 @@ ScLinkTargetTypeObj::ScLinkTargetTypeObj(ScDocShell* pDocSh, sal_uInt16 nT) :
     nType( nT )
 {
     pDocShell->GetDocument().AddUnoObject(*this);
-    aName = ScResId( nTypeResIds[nType] );    //! on demand?
+    aName = ScResId(aTypeResIds[nType]);    //! on demand?
 }
 
 ScLinkTargetTypeObj::~ScLinkTargetTypeObj()
@@ -149,13 +149,13 @@ ScLinkTargetTypeObj::~ScLinkTargetTypeObj()
 
 void ScLinkTargetTypeObj::Notify( SfxBroadcaster&, const SfxHint& rHint )
 {
-    if ( rHint.GetId() == SFX_HINT_DYING )
+    if ( rHint.GetId() == SfxHintId::Dying )
         pDocShell = nullptr;       // document gone
 }
 
 // document::XLinkTargetSupplier
 
-uno::Reference< container::XNameAccess > SAL_CALL  ScLinkTargetTypeObj::getLinks() throw( uno::RuntimeException, std::exception )
+uno::Reference< container::XNameAccess > SAL_CALL  ScLinkTargetTypeObj::getLinks()
 {
     uno::Reference< container::XNameAccess >  xCollection;
 
@@ -186,7 +186,7 @@ uno::Reference< container::XNameAccess > SAL_CALL  ScLinkTargetTypeObj::getLinks
 
 // beans::XPropertySet
 
-uno::Reference< beans::XPropertySetInfo > SAL_CALL  ScLinkTargetTypeObj::getPropertySetInfo() throw( uno::RuntimeException, std::exception )
+uno::Reference< beans::XPropertySetInfo > SAL_CALL  ScLinkTargetTypeObj::getPropertySetInfo()
 {
     SolarMutexGuard aGuard;
     static uno::Reference< beans::XPropertySetInfo >  aRef(new SfxItemPropertySetInfo( lcl_GetLinkTargetMap() ));
@@ -195,16 +195,23 @@ uno::Reference< beans::XPropertySetInfo > SAL_CALL  ScLinkTargetTypeObj::getProp
 
 void SAL_CALL ScLinkTargetTypeObj::setPropertyValue(const OUString& /* aPropertyName */,
             const uno::Any& /* aValue */)
-        throw(  beans::UnknownPropertyException,
-                beans::PropertyVetoException,
-                lang::IllegalArgumentException,
-                lang::WrappedTargetException,
-                 uno::RuntimeException, std::exception )
 {
     //  everything is read-only
     //! exception?
 }
 
+static const OUStringLiteral aContentBmps[]=
+{
+    RID_BMP_CONTENT_TABLE,
+    RID_BMP_CONTENT_RANGENAME,
+    RID_BMP_CONTENT_DBAREA,
+    RID_BMP_CONTENT_GRAPHIC,
+    RID_BMP_CONTENT_OLEOBJECT,
+    RID_BMP_CONTENT_NOTE,
+    RID_BMP_CONTENT_AREALINK,
+    RID_BMP_CONTENT_DRAWING
+};
+
 void ScLinkTargetTypeObj::SetLinkTargetBitmap( uno::Any& rRet, sal_uInt16 nType )
 {
     ScContentId nImgId = ScContentId::ROOT;
@@ -222,20 +229,18 @@ void ScLinkTargetTypeObj::SetLinkTargetBitmap( uno::Any& rRet, sal_uInt16 nType
     }
     if (nImgId != ScContentId::ROOT)
     {
-        ImageList aEntryImages( ScResId( RID_IMAGELIST_NAVCONT ) );
-        const Image& rImage = aEntryImages.GetImage( (sal_uInt16)nImgId );
-        rRet <<= uno::Reference< awt::XBitmap > (VCLUnoHelper::CreateBitmap( rImage.GetBitmapEx() ));
+        BitmapEx aBitmapEx(aContentBmps[(int)nImgId -1 ]);
+        rRet <<= uno::Reference< awt::XBitmap > (VCLUnoHelper::CreateBitmap(aBitmapEx));
     }
 }
 
 uno::Any SAL_CALL ScLinkTargetTypeObj::getPropertyValue(const OUString& PropertyName)
-        throw( beans::UnknownPropertyException, lang::WrappedTargetException, uno::RuntimeException, std::exception )
 {
     uno::Any aRet;
     if ( PropertyName == SC_UNO_LINKDISPBIT )
         SetLinkTargetBitmap( aRet, nType );
     else if ( PropertyName == SC_UNO_LINKDISPNAME )
-        aRet <<= OUString( aName );
+        aRet <<= aName;
 
     return aRet;
 }
@@ -255,7 +260,6 @@ ScLinkTargetsObj::~ScLinkTargetsObj()
 // container::XNameAccess
 
 uno::Any SAL_CALL ScLinkTargetsObj::getByName(const OUString& aName)
-        throw( container::NoSuchElementException, lang::WrappedTargetException, uno::RuntimeException, std::exception )
 {
     uno::Reference< beans::XPropertySet >  xProp( ScUnoHelpFunctions::AnyToInterface( xCollection->getByName(aName) ), uno::UNO_QUERY );
     if (xProp.is())
@@ -265,24 +269,24 @@ uno::Any SAL_CALL ScLinkTargetsObj::getByName(const OUString& aName)
 //    return uno::Any();
 }
 
-uno::Sequence<OUString> SAL_CALL ScLinkTargetsObj::getElementNames() throw( uno::RuntimeException, std::exception )
+uno::Sequence<OUString> SAL_CALL ScLinkTargetsObj::getElementNames()
 {
     return xCollection->getElementNames();
 }
 
-sal_Bool SAL_CALL ScLinkTargetsObj::hasByName(const OUString& aName) throw( uno::RuntimeException, std::exception )
+sal_Bool SAL_CALL ScLinkTargetsObj::hasByName(const OUString& aName)
 {
     return xCollection->hasByName(aName);
 }
 
 // container::XElementAccess
 
-uno::Type SAL_CALL ScLinkTargetsObj::getElementType() throw( uno::RuntimeException, std::exception )
+uno::Type SAL_CALL ScLinkTargetsObj::getElementType()
 {
     return cppu::UnoType<beans::XPropertySet>::get();
 }
 
-sal_Bool SAL_CALL ScLinkTargetsObj::hasElements() throw( uno::RuntimeException, std::exception )
+sal_Bool SAL_CALL ScLinkTargetsObj::hasElements()
 {
     return xCollection->hasElements();
 }
