@@ -17,13 +17,17 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "scitems.hxx"
+#include <memory>
+#include <sal/config.h>
+
+#include <scitems.hxx>
 #include <editeng/eeitem.hxx>
 #include <svx/svdpool.hxx>
 #include <svx/svdobj.hxx>
 #include <editeng/editeng.hxx>
 #include <editeng/editobj.hxx>
 #include <editeng/flditem.hxx>
+#include <editeng/fhgtitem.hxx>
 #include <svx/unomid.hxx>
 #include <editeng/unoprnms.hxx>
 #include <editeng/unofored.hxx>
@@ -33,24 +37,24 @@
 
 #include <com/sun/star/beans/PropertyAttribute.hpp>
 #include <editeng/unoipset.hxx>
-#include "textuno.hxx"
-#include "fielduno.hxx"
-#include "servuno.hxx"
-#include "editsrc.hxx"
-#include "docsh.hxx"
-#include "editutil.hxx"
-#include "miscuno.hxx"
-#include "cellsuno.hxx"
-#include "hints.hxx"
-#include "patattr.hxx"
-#include "formulacell.hxx"
-#include "docfunc.hxx"
-#include "scmod.hxx"
+#include <textuno.hxx>
+#include <fielduno.hxx>
+#include <servuno.hxx>
+#include <editsrc.hxx>
+#include <docsh.hxx>
+#include <editutil.hxx>
+#include <miscuno.hxx>
+#include <cellsuno.hxx>
+#include <hints.hxx>
+#include <cellvalue.hxx>
+#include <cellform.hxx>
+#include <patattr.hxx>
+#include <formulacell.hxx>
+#include <docfunc.hxx>
+#include <scmod.hxx>
 
 using namespace com::sun::star;
 
-//------------------------------------------------------------------------
-
 static const SvxItemPropertySet * lcl_GetHdFtPropertySet()
 {
     static SfxItemPropertyMapEntry aHdFtPropertyMap_Impl[] =
@@ -59,9 +63,9 @@ static const SvxItemPropertySet * lcl_GetHdFtPropertySet()
         SVX_UNOEDIT_FONT_PROPERTIES,
         SVX_UNOEDIT_PARA_PROPERTIES,
         SVX_UNOEDIT_NUMBERING_PROPERTIE,    // for completeness of service ParagraphProperties
-        {0,0,0,0,0,0}
+        { OUString(), 0, css::uno::Type(), 0, 0 }
     };
-    static sal_Bool bTwipsSet = false;
+    static bool bTwipsSet = false;
 
     if (!bTwipsSet)
     {
@@ -69,7 +73,7 @@ static const SvxItemPropertySet * lcl_GetHdFtPropertySet()
         //  (headers/footers are in twips)
 
         SfxItemPropertyMapEntry* pEntry = aHdFtPropertyMap_Impl;
-        while (pEntry->pName)
+        while (!pEntry->aName.isEmpty())
         {
             if ( ( pEntry->nWID == EE_CHAR_FONTHEIGHT ||
                    pEntry->nWID == EE_CHAR_FONTHEIGHT_CJK ||
@@ -81,26 +85,20 @@ static const SvxItemPropertySet * lcl_GetHdFtPropertySet()
 
             ++pEntry;
         }
-        bTwipsSet = sal_True;
+        bTwipsSet = true;
     }
     static SvxItemPropertySet aHdFtPropertySet_Impl( aHdFtPropertyMap_Impl, SdrObject::GetGlobalDrawObjectItemPool() );
     return &aHdFtPropertySet_Impl;
 }
 
-//------------------------------------------------------------------------
-
 SC_SIMPLE_SERVICE_INFO( ScHeaderFooterContentObj, "ScHeaderFooterContentObj", "com.sun.star.sheet.HeaderFooterContent" )
 SC_SIMPLE_SERVICE_INFO( ScHeaderFooterTextObj, "ScHeaderFooterTextObj", "stardiv.one.Text.Text" )
 
-//------------------------------------------------------------------------
-
-ScHeaderFooterContentObj::ScHeaderFooterContentObj( const EditTextObject* pLeft,
-                                                    const EditTextObject* pCenter,
-                                                    const EditTextObject* pRight ) :
-    mxLeftText(new ScHeaderFooterTextObj(*this, SC_HDFT_LEFT, pLeft)),
-    mxCenterText(new ScHeaderFooterTextObj(*this, SC_HDFT_CENTER, pCenter)),
-    mxRightText(new ScHeaderFooterTextObj(*this, SC_HDFT_RIGHT, pRight))
+ScHeaderFooterContentObj::ScHeaderFooterContentObj()
 {
+#if defined __clang__ && defined _MSC_VER // workaround clang-cl ABI bug PR25641
+    css::uno::Sequence<css::beans::PropertyState> dummy; (void) dummy;
+#endif
 }
 
 ScHeaderFooterContentObj::~ScHeaderFooterContentObj() {}
@@ -123,7 +121,6 @@ const EditTextObject* ScHeaderFooterContentObj::GetRightEditObject() const
 // XHeaderFooterContent
 
 uno::Reference<text::XText> SAL_CALL ScHeaderFooterContentObj::getLeftText()
-                                                throw(uno::RuntimeException)
 {
     SolarMutexGuard aGuard;
     uno::Reference<text::XText> xInt(*mxLeftText, uno::UNO_QUERY);
@@ -131,7 +128,6 @@ uno::Reference<text::XText> SAL_CALL ScHeaderFooterContentObj::getLeftText()
 }
 
 uno::Reference<text::XText> SAL_CALL ScHeaderFooterContentObj::getCenterText()
-                                                throw(uno::RuntimeException)
 {
     SolarMutexGuard aGuard;
     uno::Reference<text::XText> xInt(*mxCenterText, uno::UNO_QUERY);
@@ -139,7 +135,6 @@ uno::Reference<text::XText> SAL_CALL ScHeaderFooterContentObj::getCenterText()
 }
 
 uno::Reference<text::XText> SAL_CALL ScHeaderFooterContentObj::getRightText()
-                                                throw(uno::RuntimeException)
 {
     SolarMutexGuard aGuard;
     uno::Reference<text::XText> xInt(*mxRightText, uno::UNO_QUERY);
@@ -149,7 +144,7 @@ uno::Reference<text::XText> SAL_CALL ScHeaderFooterContentObj::getRightText()
 // XUnoTunnel
 
 sal_Int64 SAL_CALL ScHeaderFooterContentObj::getSomething(
-                const uno::Sequence<sal_Int8 >& rId ) throw(uno::RuntimeException)
+                const uno::Sequence<sal_Int8 >& rId )
 {
     if ( rId.getLength() == 16 &&
           0 == memcmp( getUnoTunnelId().getConstArray(),
@@ -170,26 +165,33 @@ const uno::Sequence<sal_Int8>& ScHeaderFooterContentObj::getUnoTunnelId()
     return theScHeaderFooterContentObjUnoTunnelId::get().getSeq();
 }
 
-ScHeaderFooterContentObj* ScHeaderFooterContentObj::getImplementation(
-                                const uno::Reference<sheet::XHeaderFooterContent> xObj )
+rtl::Reference<ScHeaderFooterContentObj> ScHeaderFooterContentObj::getImplementation(
+                                const uno::Reference<sheet::XHeaderFooterContent>& rObj)
 {
-    ScHeaderFooterContentObj* pRet = NULL;
-    uno::Reference<lang::XUnoTunnel> xUT( xObj, uno::UNO_QUERY );
+    rtl::Reference<ScHeaderFooterContentObj> pRet;
+    uno::Reference<lang::XUnoTunnel> xUT(rObj, uno::UNO_QUERY);
     if (xUT.is())
         pRet = reinterpret_cast<ScHeaderFooterContentObj*>(sal::static_int_cast<sal_IntPtr>(xUT->getSomething(getUnoTunnelId())));
     return pRet;
 }
 
-
-//------------------------------------------------------------------------
+void ScHeaderFooterContentObj::Init( const EditTextObject* pLeft,
+                                                    const EditTextObject* pCenter,
+                                                    const EditTextObject* pRight )
+{
+    uno::Reference<css::sheet::XHeaderFooterContent> xThis(this);
+    mxLeftText = rtl::Reference<ScHeaderFooterTextObj>(new ScHeaderFooterTextObj(xThis, ScHeaderFooterPart::LEFT, pLeft));
+    mxCenterText = rtl::Reference<ScHeaderFooterTextObj>(new ScHeaderFooterTextObj(xThis, ScHeaderFooterPart::CENTER, pCenter));
+    mxRightText = rtl::Reference<ScHeaderFooterTextObj>(new ScHeaderFooterTextObj(xThis, ScHeaderFooterPart::RIGHT, pRight));
+}
 
 ScHeaderFooterTextData::ScHeaderFooterTextData(
-    ScHeaderFooterContentObj& rContent, sal_uInt16 nP, const EditTextObject* pTextObj) :
-    mpTextObj(pTextObj ? pTextObj->Clone() : NULL),
-    rContentObj( rContent ),
+    uno::WeakReference<sheet::XHeaderFooterContent> const & xContent, ScHeaderFooterPart nP, const EditTextObject* pTextObj) :
+    mpTextObj(pTextObj ? pTextObj->Clone() : nullptr),
+    xContentObj( xContent ),
     nPart( nP ),
-    pEditEngine( NULL ),
-    pForwarder( NULL ),
+    pEditEngine( nullptr ),
+    pForwarder( nullptr ),
     bDataValid(false)
 {
 }
@@ -200,7 +202,6 @@ ScHeaderFooterTextData::~ScHeaderFooterTextData()
 
     delete pForwarder;
     delete pEditEngine;
-    delete mpTextObj;
 }
 
 SvxTextForwarder* ScHeaderFooterTextData::GetTextForwarder()
@@ -209,22 +210,25 @@ SvxTextForwarder* ScHeaderFooterTextData::GetTextForwarder()
     {
         SfxItemPool* pEnginePool = EditEngine::CreatePool();
         pEnginePool->FreezeIdRanges();
-        ScHeaderEditEngine* pHdrEngine = new ScHeaderEditEngine( pEnginePool, sal_True );
+        ScHeaderEditEngine* pHdrEngine = new ScHeaderEditEngine( pEnginePool );
 
         pHdrEngine->EnableUndo( false );
-        pHdrEngine->SetRefMapMode( MAP_TWIP );
+        pHdrEngine->SetRefMapMode(MapMode(MapUnit::MapTwip));
 
         //  default font must be set, independently of document
         //  -> use global pool from module
 
         SfxItemSet aDefaults( pHdrEngine->GetEmptyItemSet() );
-        const ScPatternAttr& rPattern = (const ScPatternAttr&)SC_MOD()->GetPool().GetDefaultItem(ATTR_PATTERN);
+        const ScPatternAttr& rPattern = SC_MOD()->GetPool().GetDefaultItem(ATTR_PATTERN);
         rPattern.FillEditItemSet( &aDefaults );
         //  FillEditItemSet adjusts font height to 1/100th mm,
         //  but for header/footer twips is needed, as in the PatternAttr:
-        aDefaults.Put( rPattern.GetItem(ATTR_FONT_HEIGHT), EE_CHAR_FONTHEIGHT );
-        aDefaults.Put( rPattern.GetItem(ATTR_CJK_FONT_HEIGHT), EE_CHAR_FONTHEIGHT_CJK );
-        aDefaults.Put( rPattern.GetItem(ATTR_CTL_FONT_HEIGHT), EE_CHAR_FONTHEIGHT_CTL );
+        std::unique_ptr<SfxPoolItem> pNewItem( rPattern.GetItem(ATTR_FONT_HEIGHT).CloneSetWhich(EE_CHAR_FONTHEIGHT) );
+        aDefaults.Put( *pNewItem );
+        pNewItem.reset( rPattern.GetItem(ATTR_CJK_FONT_HEIGHT).CloneSetWhich(EE_CHAR_FONTHEIGHT_CJK) );
+        aDefaults.Put( *pNewItem );
+        pNewItem.reset( rPattern.GetItem(ATTR_CTL_FONT_HEIGHT).CloneSetWhich(EE_CHAR_FONTHEIGHT_CTL) );
+        aDefaults.Put( *pNewItem );
         pHdrEngine->SetDefaults( aDefaults );
 
         ScHeaderFieldData aData;
@@ -249,28 +253,19 @@ void ScHeaderFooterTextData::UpdateData()
 {
     if (pEditEngine)
     {
-        delete mpTextObj;
-        mpTextObj = pEditEngine->CreateTextObject();
+        mpTextObj.reset(pEditEngine->CreateTextObject());
     }
 }
 
 void ScHeaderFooterTextData::UpdateData(EditEngine& rEditEngine)
 {
-    delete mpTextObj;
-    mpTextObj = rEditEngine.CreateTextObject();
+    mpTextObj.reset(rEditEngine.CreateTextObject());
     bDataValid = false;
 }
 
-const EditTextObject* ScHeaderFooterTextData::GetTextObject() const
-{
-    return mpTextObj;
-}
-
-//------------------------------------------------------------------------
-
 ScHeaderFooterTextObj::ScHeaderFooterTextObj(
-    ScHeaderFooterContentObj& rContent, sal_uInt16 nP, const EditTextObject* pTextObj) :
-    aTextData(rContent, nP, pTextObj)
+    const uno::WeakReference<sheet::XHeaderFooterContent>& xContent, ScHeaderFooterPart nP, const EditTextObject* pTextObj) :
+    aTextData(xContent, nP, pTextObj)
 {
     //  ScHeaderFooterTextData acquires rContent
     //  pUnoText is created on demand (getString/setString work without it)
@@ -303,21 +298,19 @@ const SvxUnoText& ScHeaderFooterTextObj::GetUnoText()
 // XText
 
 uno::Reference<text::XTextCursor> SAL_CALL ScHeaderFooterTextObj::createTextCursor()
-                                                    throw(uno::RuntimeException)
 {
     SolarMutexGuard aGuard;
-    return new ScHeaderFooterTextCursor( *this );
+    return new ScHeaderFooterTextCursor( this );
 }
 
 uno::Reference<text::XTextCursor> SAL_CALL ScHeaderFooterTextObj::createTextCursorByRange(
                                     const uno::Reference<text::XTextRange>& aTextPosition )
-                                                    throw(uno::RuntimeException)
 {
     SolarMutexGuard aGuard;
     if (!mxUnoText.is())
         CreateUnoText_Impl();
     return mxUnoText->createTextCursorByRange(aTextPosition);
-    //! wie ScCellObj::createTextCursorByRange, wenn SvxUnoTextRange_getReflection verfuegbar
+    //! like ScCellObj::createTextCursorByRange, if SvxUnoTextRange_getReflection available
 }
 
 void ScHeaderFooterTextObj::FillDummyFieldData( ScHeaderFieldData& rData )
@@ -331,25 +324,39 @@ void ScHeaderFooterTextObj::FillDummyFieldData( ScHeaderFieldData& rData )
     rData.nTotalPages   = 99;
 }
 
-OUString SAL_CALL ScHeaderFooterTextObj::getString() throw(uno::RuntimeException)
+OUString SAL_CALL ScHeaderFooterTextObj::getString()
 {
     SolarMutexGuard aGuard;
     OUString aRet;
     const EditTextObject* pData;
 
-    sal_uInt16 nPart = aTextData.GetPart();
-    ScHeaderFooterContentObj& rContentObj = aTextData.GetContentObj();
+    uno::Reference<css::sheet::XHeaderFooterContent> xContentObj = aTextData.GetContentObj();
+    if (!xContentObj.is())
+        throw css::uno::RuntimeException(
+            "ScHeaderFooterTextObj::getString: no ContentObj");
+
+    rtl::Reference<ScHeaderFooterContentObj> pObj = ScHeaderFooterContentObj::getImplementation(xContentObj);
+
+    switch ( aTextData.GetPart() )
+    {
+        case ScHeaderFooterPart::LEFT:
+            pData = pObj->GetLeftEditObject();
+        break;
+        case ScHeaderFooterPart::CENTER:
+            pData = pObj->GetCenterEditObject();
+        break;
+        case ScHeaderFooterPart::RIGHT:
+            pData = pObj->GetRightEditObject();
+        break;
+        default:
+            SAL_WARN("sc.ui","unexpected enum value of ScHeaderFooterPart");
+            pData = nullptr;
+    }
 
-    if (nPart == SC_HDFT_LEFT)
-        pData = rContentObj.GetLeftEditObject();
-    else if (nPart == SC_HDFT_CENTER)
-        pData = rContentObj.GetCenterEditObject();
-    else
-        pData = rContentObj.GetRightEditObject();
     if (pData)
     {
         // for pure text, no font info is needed in pool defaults
-        ScHeaderEditEngine aEditEngine( EditEngine::CreatePool(), sal_True );
+        ScHeaderEditEngine aEditEngine( EditEngine::CreatePool() );
 
         ScHeaderFieldData aData;
         FillDummyFieldData( aData );
@@ -361,20 +368,18 @@ OUString SAL_CALL ScHeaderFooterTextObj::getString() throw(uno::RuntimeException
     return aRet;
 }
 
-void SAL_CALL ScHeaderFooterTextObj::setString( const OUString& aText ) throw(uno::RuntimeException)
+void SAL_CALL ScHeaderFooterTextObj::setString( const OUString& aText )
 {
     SolarMutexGuard aGuard;
-    OUString aString(aText);
 
     // for pure text, no font info is needed in pool defaults
-    ScHeaderEditEngine aEditEngine(EditEngine::CreatePool(), true);
-    aEditEngine.SetText( aString );
+    ScHeaderEditEngine aEditEngine(EditEngine::CreatePool());
+    aEditEngine.SetText( aText );
     aTextData.UpdateData(aEditEngine);
 }
 
 void SAL_CALL ScHeaderFooterTextObj::insertString( const uno::Reference<text::XTextRange>& xRange,
                                             const OUString& aString, sal_Bool bAbsorb )
-                                throw(uno::RuntimeException)
 {
     SolarMutexGuard aGuard;
     if (!mxUnoText.is())
@@ -385,7 +390,6 @@ void SAL_CALL ScHeaderFooterTextObj::insertString( const uno::Reference<text::XT
 void SAL_CALL ScHeaderFooterTextObj::insertControlCharacter(
                                             const uno::Reference<text::XTextRange>& xRange,
                                             sal_Int16 nControlCharacter, sal_Bool bAbsorb )
-                                throw(lang::IllegalArgumentException, uno::RuntimeException)
 {
     SolarMutexGuard aGuard;
     if (!mxUnoText.is())
@@ -397,7 +401,6 @@ void SAL_CALL ScHeaderFooterTextObj::insertTextContent(
                                             const uno::Reference<text::XTextRange >& xRange,
                                             const uno::Reference<text::XTextContent >& xContent,
                                             sal_Bool bAbsorb )
-                                throw(lang::IllegalArgumentException, uno::RuntimeException)
 {
     SolarMutexGuard aGuard;
     if ( xContent.is() && xRange.is() )
@@ -426,34 +429,25 @@ void SAL_CALL ScHeaderFooterTextObj::insertTextContent(
             pForwarder->QuickInsertField( aItem, aSelection );
             pEditSource->UpdateData();
 
-            //  neue Selektion: ein Zeichen
+            //  new selection: a digit
             aSelection.Adjust();
             aSelection.nEndPara = aSelection.nStartPara;
             aSelection.nEndPos = aSelection.nStartPos + 1;
 
             uno::Reference<text::XTextRange> xTextRange;
-            switch (aTextData.GetPart())
+            switch ( aTextData.GetPart() )
             {
-                case SC_HDFT_LEFT:
-                {
-                    uno::Reference<text::XTextRange> xTemp(
-                        aTextData.GetContentObj().getLeftText(), uno::UNO_QUERY);
-                    xTextRange = xTemp;
-                }
+                case ScHeaderFooterPart::LEFT:
+                    xTextRange = uno::Reference<text::XTextRange>(
+                                  aTextData.GetContentObj()->getLeftText(), uno::UNO_QUERY);
                 break;
-                case SC_HDFT_CENTER:
-                {
-                    uno::Reference<text::XTextRange> xTemp(
-                        aTextData.GetContentObj().getCenterText(), uno::UNO_QUERY);
-                    xTextRange = xTemp;
-                }
+                case ScHeaderFooterPart::CENTER:
+                    xTextRange = uno::Reference<text::XTextRange>(
+                                  aTextData.GetContentObj()->getCenterText(), uno::UNO_QUERY);
                 break;
-                case SC_HDFT_RIGHT:
-                {
-                    uno::Reference<text::XTextRange> xTemp(
-                        aTextData.GetContentObj().getRightText(), uno::UNO_QUERY);
-                    xTextRange = xTemp;
-                }
+                case ScHeaderFooterPart::RIGHT:
+                    xTextRange = uno::Reference<text::XTextRange>(
+                                  aTextData.GetContentObj()->getRightText(), uno::UNO_QUERY);
                 break;
             }
 
@@ -477,7 +471,6 @@ void SAL_CALL ScHeaderFooterTextObj::insertTextContent(
 
 void SAL_CALL ScHeaderFooterTextObj::removeTextContent(
                                             const uno::Reference<text::XTextContent>& xContent )
-                                throw(container::NoSuchElementException, uno::RuntimeException)
 {
     SolarMutexGuard aGuard;
     if ( xContent.is() )
@@ -485,7 +478,7 @@ void SAL_CALL ScHeaderFooterTextObj::removeTextContent(
         ScEditFieldObj* pHeaderField = ScEditFieldObj::getImplementation(xContent);
         if ( pHeaderField && pHeaderField->IsInserted() )
         {
-            //! Testen, ob das Feld in dieser Zelle ist
+            //! check if the field is in this cell
             pHeaderField->DeleteField();
             return;
         }
@@ -495,7 +488,7 @@ void SAL_CALL ScHeaderFooterTextObj::removeTextContent(
     mxUnoText->removeTextContent( xContent );
 }
 
-uno::Reference<text::XText> SAL_CALL ScHeaderFooterTextObj::getText() throw(uno::RuntimeException)
+uno::Reference<text::XText> SAL_CALL ScHeaderFooterTextObj::getText()
 {
     SolarMutexGuard aGuard;
     if (!mxUnoText.is())
@@ -503,7 +496,7 @@ uno::Reference<text::XText> SAL_CALL ScHeaderFooterTextObj::getText() throw(uno:
     return mxUnoText->getText();
 }
 
-uno::Reference<text::XTextRange> SAL_CALL ScHeaderFooterTextObj::getStart() throw(uno::RuntimeException)
+uno::Reference<text::XTextRange> SAL_CALL ScHeaderFooterTextObj::getStart()
 {
     SolarMutexGuard aGuard;
     if (!mxUnoText.is())
@@ -511,7 +504,7 @@ uno::Reference<text::XTextRange> SAL_CALL ScHeaderFooterTextObj::getStart() thro
     return mxUnoText->getStart();
 }
 
-uno::Reference<text::XTextRange> SAL_CALL ScHeaderFooterTextObj::getEnd() throw(uno::RuntimeException)
+uno::Reference<text::XTextRange> SAL_CALL ScHeaderFooterTextObj::getEnd()
 {
     SolarMutexGuard aGuard;
     if (!mxUnoText.is())
@@ -522,7 +515,6 @@ uno::Reference<text::XTextRange> SAL_CALL ScHeaderFooterTextObj::getEnd() throw(
 // XTextFieldsSupplier
 
 uno::Reference<container::XEnumerationAccess> SAL_CALL ScHeaderFooterTextObj::getTextFields()
-                                                throw(uno::RuntimeException)
 {
     SolarMutexGuard aGuard;
     // all fields
@@ -530,10 +522,9 @@ uno::Reference<container::XEnumerationAccess> SAL_CALL ScHeaderFooterTextObj::ge
 }
 
 uno::Reference<container::XNameAccess> SAL_CALL ScHeaderFooterTextObj::getTextFieldMasters()
-                                                throw(uno::RuntimeException)
 {
-    //  sowas gibts nicht im Calc (?)
-    return NULL;
+    //  this does not exists in Calc (?)
+    return nullptr;
 }
 
 // XTextRangeMover
@@ -541,7 +532,6 @@ uno::Reference<container::XNameAccess> SAL_CALL ScHeaderFooterTextObj::getTextFi
 void SAL_CALL ScHeaderFooterTextObj::moveTextRange(
                                         const uno::Reference<text::XTextRange>& xRange,
                                         sal_Int16 nParagraphs )
-                                        throw(uno::RuntimeException)
 {
     SolarMutexGuard aGuard;
     if (!mxUnoText.is())
@@ -552,7 +542,6 @@ void SAL_CALL ScHeaderFooterTextObj::moveTextRange(
 // XEnumerationAccess
 
 uno::Reference<container::XEnumeration> SAL_CALL ScHeaderFooterTextObj::createEnumeration()
-                                                throw(uno::RuntimeException)
 {
     SolarMutexGuard aGuard;
     if (!mxUnoText.is())
@@ -562,7 +551,7 @@ uno::Reference<container::XEnumeration> SAL_CALL ScHeaderFooterTextObj::createEn
 
 // XElementAccess
 
-uno::Type SAL_CALL ScHeaderFooterTextObj::getElementType() throw(uno::RuntimeException)
+uno::Type SAL_CALL ScHeaderFooterTextObj::getElementType()
 {
     SolarMutexGuard aGuard;
     if (!mxUnoText.is())
@@ -570,7 +559,7 @@ uno::Type SAL_CALL ScHeaderFooterTextObj::getElementType() throw(uno::RuntimeExc
     return mxUnoText->getElementType();
 }
 
-sal_Bool SAL_CALL ScHeaderFooterTextObj::hasElements() throw(uno::RuntimeException)
+sal_Bool SAL_CALL ScHeaderFooterTextObj::hasElements()
 {
     SolarMutexGuard aGuard;
     if (!mxUnoText.is())
@@ -578,36 +567,30 @@ sal_Bool SAL_CALL ScHeaderFooterTextObj::hasElements() throw(uno::RuntimeExcepti
     return mxUnoText->hasElements();
 }
 
-//------------------------------------------------------------------------
-
 ScCellTextCursor::ScCellTextCursor(const ScCellTextCursor& rOther) :
     SvxUnoTextCursor( rOther ),
-    rTextObj( rOther.rTextObj )
+    mxTextObj( rOther.mxTextObj )
 {
-    rTextObj.acquire();
 }
 
 ScCellTextCursor::ScCellTextCursor(ScCellObj& rText) :
     SvxUnoTextCursor( rText.GetUnoText() ),
-    rTextObj( rText )
+    mxTextObj( &rText )
 {
-    rTextObj.acquire();
 }
 
 ScCellTextCursor::~ScCellTextCursor() throw()
 {
-    rTextObj.release();
 }
 
 // SvxUnoTextCursor methods reimplemented here to return the right objects:
 
-uno::Reference<text::XText> SAL_CALL ScCellTextCursor::getText() throw(uno::RuntimeException)
+uno::Reference<text::XText> SAL_CALL ScCellTextCursor::getText()
 {
-    SolarMutexGuard aGuard;
-    return &rTextObj;
+    return mxTextObj.get();
 }
 
-uno::Reference<text::XTextRange> SAL_CALL ScCellTextCursor::getStart() throw(uno::RuntimeException)
+uno::Reference<text::XTextRange> SAL_CALL ScCellTextCursor::getStart()
 {
     SolarMutexGuard aGuard;
 
@@ -624,7 +607,7 @@ uno::Reference<text::XTextRange> SAL_CALL ScCellTextCursor::getStart() throw(uno
     return xRange;
 }
 
-uno::Reference<text::XTextRange> SAL_CALL ScCellTextCursor::getEnd() throw(uno::RuntimeException)
+uno::Reference<text::XTextRange> SAL_CALL ScCellTextCursor::getEnd()
 {
     SolarMutexGuard aGuard;
 
@@ -644,7 +627,7 @@ uno::Reference<text::XTextRange> SAL_CALL ScCellTextCursor::getEnd() throw(uno::
 // XUnoTunnel
 
 sal_Int64 SAL_CALL ScCellTextCursor::getSomething(
-                const uno::Sequence<sal_Int8 >& rId ) throw(uno::RuntimeException)
+                const uno::Sequence<sal_Int8 >& rId )
 {
     if ( rId.getLength() == 16 &&
           0 == memcmp( getUnoTunnelId().getConstArray(),
@@ -665,45 +648,31 @@ const uno::Sequence<sal_Int8>& ScCellTextCursor::getUnoTunnelId()
     return theScCellTextCursorUnoTunnelId::get().getSeq();
 }
 
-ScCellTextCursor* ScCellTextCursor::getImplementation( const uno::Reference<uno::XInterface> xObj )
+ScCellTextCursor* ScCellTextCursor::getImplementation(const uno::Reference<uno::XInterface>& rObj)
 {
-    ScCellTextCursor* pRet = NULL;
-    uno::Reference<lang::XUnoTunnel> xUT( xObj, uno::UNO_QUERY );
+    ScCellTextCursor* pRet = nullptr;
+    uno::Reference<lang::XUnoTunnel> xUT(rObj, uno::UNO_QUERY);
     if (xUT.is())
         pRet = reinterpret_cast<ScCellTextCursor*>(sal::static_int_cast<sal_IntPtr>(xUT->getSomething(getUnoTunnelId())));
     return pRet;
 }
 
-//------------------------------------------------------------------------
-
-ScHeaderFooterTextCursor::ScHeaderFooterTextCursor(const ScHeaderFooterTextCursor& rOther) :
-    SvxUnoTextCursor( rOther ),
-    rTextObj( rOther.rTextObj )
-{
-    rTextObj.acquire();
-}
-
-ScHeaderFooterTextCursor::ScHeaderFooterTextCursor(ScHeaderFooterTextObj& rText) :
-    SvxUnoTextCursor( rText.GetUnoText() ),
+ScHeaderFooterTextCursor::ScHeaderFooterTextCursor(rtl::Reference<ScHeaderFooterTextObj> const & rText) :
+    SvxUnoTextCursor( rText->GetUnoText() ),
     rTextObj( rText )
-{
-    rTextObj.acquire();
-}
+{}
 
-ScHeaderFooterTextCursor::~ScHeaderFooterTextCursor() throw()
-{
-    rTextObj.release();
-}
+ScHeaderFooterTextCursor::~ScHeaderFooterTextCursor() throw() {};
 
 // SvxUnoTextCursor methods reimplemented here to return the right objects:
 
-uno::Reference<text::XText> SAL_CALL ScHeaderFooterTextCursor::getText() throw(uno::RuntimeException)
+uno::Reference<text::XText> SAL_CALL ScHeaderFooterTextCursor::getText()
 {
     SolarMutexGuard aGuard;
-    return &rTextObj;
+    return rTextObj.get();
 }
 
-uno::Reference<text::XTextRange> SAL_CALL ScHeaderFooterTextCursor::getStart() throw(uno::RuntimeException)
+uno::Reference<text::XTextRange> SAL_CALL ScHeaderFooterTextCursor::getStart()
 {
     SolarMutexGuard aGuard;
 
@@ -720,7 +689,7 @@ uno::Reference<text::XTextRange> SAL_CALL ScHeaderFooterTextCursor::getStart() t
     return xRange;
 }
 
-uno::Reference<text::XTextRange> SAL_CALL ScHeaderFooterTextCursor::getEnd() throw(uno::RuntimeException)
+uno::Reference<text::XTextRange> SAL_CALL ScHeaderFooterTextCursor::getEnd()
 {
     SolarMutexGuard aGuard;
 
@@ -740,7 +709,7 @@ uno::Reference<text::XTextRange> SAL_CALL ScHeaderFooterTextCursor::getEnd() thr
 // XUnoTunnel
 
 sal_Int64 SAL_CALL ScHeaderFooterTextCursor::getSomething(
-                const uno::Sequence<sal_Int8 >& rId ) throw(uno::RuntimeException)
+                const uno::Sequence<sal_Int8 >& rId )
 {
     if ( rId.getLength() == 16 &&
           0 == memcmp( getUnoTunnelId().getConstArray(),
@@ -762,17 +731,15 @@ const uno::Sequence<sal_Int8>& ScHeaderFooterTextCursor::getUnoTunnelId()
 }
 
 ScHeaderFooterTextCursor* ScHeaderFooterTextCursor::getImplementation(
-                                const uno::Reference<uno::XInterface> xObj )
+                                const uno::Reference<uno::XInterface>& rObj)
 {
-    ScHeaderFooterTextCursor* pRet = NULL;
-    uno::Reference<lang::XUnoTunnel> xUT( xObj, uno::UNO_QUERY );
+    ScHeaderFooterTextCursor* pRet = nullptr;
+    uno::Reference<lang::XUnoTunnel> xUT(rObj, uno::UNO_QUERY);
     if (xUT.is())
         pRet = reinterpret_cast<ScHeaderFooterTextCursor*>(sal::static_int_cast<sal_IntPtr>(xUT->getSomething(getUnoTunnelId())));
     return pRet;
 }
 
-//------------------------------------------------------------------------
-
 ScDrawTextCursor::ScDrawTextCursor(const ScDrawTextCursor& rOther) :
     SvxUnoTextCursor( rOther ),
     xParentText( rOther.xParentText )
@@ -793,13 +760,13 @@ ScDrawTextCursor::~ScDrawTextCursor() throw()
 
 // SvxUnoTextCursor methods reimplemented here to return the right objects:
 
-uno::Reference<text::XText> SAL_CALL ScDrawTextCursor::getText() throw(uno::RuntimeException)
+uno::Reference<text::XText> SAL_CALL ScDrawTextCursor::getText()
 {
     SolarMutexGuard aGuard;
     return xParentText;
 }
 
-uno::Reference<text::XTextRange> SAL_CALL ScDrawTextCursor::getStart() throw(uno::RuntimeException)
+uno::Reference<text::XTextRange> SAL_CALL ScDrawTextCursor::getStart()
 {
     SolarMutexGuard aGuard;
 
@@ -816,7 +783,7 @@ uno::Reference<text::XTextRange> SAL_CALL ScDrawTextCursor::getStart() throw(uno
     return xRange;
 }
 
-uno::Reference<text::XTextRange> SAL_CALL ScDrawTextCursor::getEnd() throw(uno::RuntimeException)
+uno::Reference<text::XTextRange> SAL_CALL ScDrawTextCursor::getEnd()
 {
     SolarMutexGuard aGuard;
 
@@ -836,7 +803,7 @@ uno::Reference<text::XTextRange> SAL_CALL ScDrawTextCursor::getEnd() throw(uno::
 // XUnoTunnel
 
 sal_Int64 SAL_CALL ScDrawTextCursor::getSomething(
-                const uno::Sequence<sal_Int8 >& rId ) throw(uno::RuntimeException)
+                const uno::Sequence<sal_Int8 >& rId )
 {
     if ( rId.getLength() == 16 &&
           0 == memcmp( getUnoTunnelId().getConstArray(),
@@ -857,24 +824,22 @@ const uno::Sequence<sal_Int8>& ScDrawTextCursor::getUnoTunnelId()
     return theScDrawTextCursorUnoTunnelId::get().getSeq();
 }
 
-ScDrawTextCursor* ScDrawTextCursor::getImplementation( const uno::Reference<uno::XInterface> xObj )
+ScDrawTextCursor* ScDrawTextCursor::getImplementation(const uno::Reference<uno::XInterface>& rObj)
 {
-    ScDrawTextCursor* pRet = NULL;
-    uno::Reference<lang::XUnoTunnel> xUT( xObj, uno::UNO_QUERY );
+    ScDrawTextCursor* pRet = nullptr;
+    uno::Reference<lang::XUnoTunnel> xUT(rObj, uno::UNO_QUERY);
     if (xUT.is())
         pRet = reinterpret_cast<ScDrawTextCursor*>(sal::static_int_cast<sal_IntPtr>(xUT->getSomething(getUnoTunnelId())));
     return pRet;
 }
 
-//------------------------------------------------------------------------
-
 ScSimpleEditSourceHelper::ScSimpleEditSourceHelper()
 {
     SfxItemPool* pEnginePool = EditEngine::CreatePool();
-    pEnginePool->SetDefaultMetric( SFX_MAPUNIT_100TH_MM );
+    pEnginePool->SetDefaultMetric( MapUnit::Map100thMM );
     pEnginePool->FreezeIdRanges();
 
-    pEditEngine = new ScFieldEditEngine(NULL, pEnginePool, NULL, true);     // TRUE: become owner of pool
+    pEditEngine = new ScFieldEditEngine(nullptr, pEnginePool, nullptr, true);     // TRUE: become owner of pool
     pForwarder = new SvxEditEngineForwarder( *pEditEngine );
     pOriginalSource = new ScSimpleEditSource( pForwarder );
 }
@@ -911,21 +876,19 @@ EditTextObject* ScEditEngineTextObj::CreateTextObject()
     return GetEditEngine()->CreateTextObject();
 }
 
-//------------------------------------------------------------------------
-
 ScCellTextData::ScCellTextData(ScDocShell* pDocSh, const ScAddress& rP) :
     pDocShell( pDocSh ),
     aCellPos( rP ),
-    pEditEngine( NULL ),
-    pForwarder( NULL ),
-    pOriginalSource( NULL ),
+    pEditEngine( nullptr ),
+    pForwarder( nullptr ),
+    pOriginalSource( nullptr ),
     bDataValid( false ),
     bInUpdate( false ),
     bDirty( false ),
-    bDoUpdate( sal_True )
+    bDoUpdate( true )
 {
     if (pDocShell)
-        pDocShell->GetDocument()->AddUnoObject(*this);
+        pDocShell->GetDocument().AddUnoObject(*this);
 }
 
 ScCellTextData::~ScCellTextData()
@@ -934,8 +897,8 @@ ScCellTextData::~ScCellTextData()
 
     if (pDocShell)
     {
-        pDocShell->GetDocument()->RemoveUnoObject(*this);
-        pDocShell->GetDocument()->DisposeFieldEditEngine(pEditEngine);
+        pDocShell->GetDocument().RemoveUnoObject(*this);
+        pDocShell->GetDocument().DisposeFieldEditEngine(pEditEngine);
     }
     else
         delete pEditEngine;
@@ -952,29 +915,20 @@ ScCellEditSource* ScCellTextData::GetOriginalSource()
     return pOriginalSource;
 }
 
-void ScCellTextData::GetCellText(const ScAddress& rCellPos, OUString& rText)
-{
-    if (pDocShell)
-    {
-        ScDocument* pDoc = pDocShell->GetDocument();
-        pDoc->GetInputString( rCellPos.Col(), rCellPos.Row(), rCellPos.Tab(), rText );
-    }
-}
-
 SvxTextForwarder* ScCellTextData::GetTextForwarder()
 {
     if (!pEditEngine)
     {
         if ( pDocShell )
         {
-            ScDocument* pDoc = pDocShell->GetDocument();
-            pEditEngine = pDoc->CreateFieldEditEngine();
+            ScDocument& rDoc = pDocShell->GetDocument();
+            pEditEngine = rDoc.CreateFieldEditEngine();
         }
         else
         {
             SfxItemPool* pEnginePool = EditEngine::CreatePool();
             pEnginePool->FreezeIdRanges();
-            pEditEngine = new ScFieldEditEngine(NULL, pEnginePool, NULL, true);
+            pEditEngine = new ScFieldEditEngine(nullptr, pEnginePool, nullptr, true);
         }
         //  currently, GetPortions doesn't work if UpdateMode is sal_False,
         //  this will be fixed (in EditEngine) by src600
@@ -983,7 +937,7 @@ SvxTextForwarder* ScCellTextData::GetTextForwarder()
         if (pDocShell)
             pEditEngine->SetRefDevice(pDocShell->GetRefDevice());
         else
-            pEditEngine->SetRefMapMode( MAP_100TH_MM );
+            pEditEngine->SetRefMapMode(MapMode(MapUnit::Map100thMM));
         pForwarder = new SvxEditEngineForwarder(*pEditEngine);
     }
 
@@ -994,25 +948,26 @@ SvxTextForwarder* ScCellTextData::GetTextForwarder()
 
     if (pDocShell)
     {
-        ScDocument* pDoc = pDocShell->GetDocument();
+        ScDocument& rDoc = pDocShell->GetDocument();
 
         SfxItemSet aDefaults( pEditEngine->GetEmptyItemSet() );
         if( const ScPatternAttr* pPattern =
-                pDoc->GetPattern( aCellPos.Col(), aCellPos.Row(), aCellPos.Tab() ) )
+                rDoc.GetPattern( aCellPos.Col(), aCellPos.Row(), aCellPos.Tab() ) )
         {
             pPattern->FillEditItemSet( &aDefaults );
             pPattern->FillEditParaItems( &aDefaults );  // including alignment etc. (for reading)
         }
 
-        if (pDoc->GetCellType(aCellPos) == CELLTYPE_EDIT)
+        ScRefCellValue aCell(rDoc, aCellPos);
+        if (aCell.meType == CELLTYPE_EDIT)
         {
-            const EditTextObject* pObj = pDoc->GetEditText(aCellPos);
-            if (pObj)
-                pEditEngine->SetTextNewDefaults(*pObj, aDefaults);
+            const EditTextObject* pObj = aCell.mpEditText;
+            pEditEngine->SetTextNewDefaults(*pObj, aDefaults);
         }
         else
         {
-            GetCellText(aCellPos, aText);
+            sal_uInt32 nFormat = rDoc.GetNumberFormat(aCellPos);
+            ScCellFormat::GetInputString(aCell, nFormat, aText, *rDoc.GetFormatTable(), &rDoc);
             if (!aText.isEmpty())
                 pEditEngine->SetTextNewDefaults(aText, aDefaults);
             else
@@ -1028,13 +983,13 @@ void ScCellTextData::UpdateData()
 {
     if ( bDoUpdate )
     {
-        OSL_ENSURE(pEditEngine != NULL, "no EditEngine for UpdateData()");
+        OSL_ENSURE(pEditEngine != nullptr, "no EditEngine for UpdateData()");
         if ( pDocShell && pEditEngine )
         {
             //  during the own UpdateData call, bDataValid must not be reset,
             //  or things like attributes after the text would be lost
             //  (are not stored in the cell)
-            bInUpdate = sal_True;   // prevents bDataValid from being reset
+            bInUpdate = true;   // prevents bDataValid from being reset
             pDocShell->GetDocFunc().PutData(aCellPos, *pEditEngine, true); // always as text
 
             bInUpdate = false;
@@ -1042,28 +997,28 @@ void ScCellTextData::UpdateData()
         }
     }
     else
-        bDirty = sal_True;
+        bDirty = true;
 }
 
 void ScCellTextData::Notify( SfxBroadcaster&, const SfxHint& rHint )
 {
-    if ( rHint.ISA( ScUpdateRefHint ) )
+    if ( dynamic_cast<const ScUpdateRefHint*>(&rHint) )
     {
 //        const ScUpdateRefHint& rRef = (const ScUpdateRefHint&)rHint;
 
         //! Ref-Update
     }
-    else if ( rHint.ISA( SfxSimpleHint ) )
+    else
     {
-        sal_uLong nId = ((const SfxSimpleHint&)rHint).GetId();
-        if ( nId == SFX_HINT_DYING )
+        const SfxHintId nId = rHint.GetId();
+        if ( nId == SfxHintId::Dying )
         {
-            pDocShell = NULL;                       // invalid now
+            pDocShell = nullptr;                       // invalid now
 
             DELETEZ( pForwarder );
             DELETEZ( pEditEngine );     // EditEngine uses document's pool
         }
-        else if ( nId == SFX_HINT_DATACHANGED )
+        else if ( nId == SfxHintId::DataChanged )
         {
             if (!bInUpdate)                         // not for own UpdateData calls
                 bDataValid = false;                 // text has to be read from the cell again
