@@ -27,9 +27,10 @@
 #include "vbachartobjects.hxx"
 #include "vbachartobject.hxx"
 #include "vbaglobals.hxx"
-#include "cellsuno.hxx"
+#include <cellsuno.hxx>
 #include <vector>
 #include <basic/sberrors.hxx>
+#include <comphelper/sequence.hxx>
 
 using namespace ::com::sun::star;
 using namespace ::ooo::vba;
@@ -39,9 +40,9 @@ class ChartObjectEnumerationImpl : public EnumerationHelperImpl
     uno::Reference< drawing::XDrawPageSupplier > xDrawPageSupplier;
 
 public:
-
-    ChartObjectEnumerationImpl( const uno::Reference< uno::XComponentContext >& xContext, const uno::Reference< container::XEnumeration >& xEnumeration, const uno::Reference< drawing::XDrawPageSupplier >& _xDrawPageSupplier, const uno::Reference< XHelperInterface >& _xParent ) throw ( uno::RuntimeException ) : EnumerationHelperImpl( _xParent, xContext, xEnumeration ), xDrawPageSupplier( _xDrawPageSupplier ) {}
-    virtual uno::Any SAL_CALL nextElement(  ) throw (container::NoSuchElementException, lang::WrappedTargetException, uno::RuntimeException, std::exception) override
+    /// @throws uno::RuntimeException
+    ChartObjectEnumerationImpl( const uno::Reference< uno::XComponentContext >& xContext, const uno::Reference< container::XEnumeration >& xEnumeration, const uno::Reference< drawing::XDrawPageSupplier >& _xDrawPageSupplier, const uno::Reference< XHelperInterface >& _xParent ) : EnumerationHelperImpl( _xParent, xContext, xEnumeration ), xDrawPageSupplier( _xDrawPageSupplier ) {}
+    virtual uno::Any SAL_CALL nextElement(  ) override
     {
         uno::Any ret;
 
@@ -49,7 +50,7 @@ public:
         {
             uno::Reference< table::XTableChart > xTableChart( m_xEnumeration->nextElement(), uno::UNO_QUERY_THROW );
             // parent Object is sheet
-            ret = uno::makeAny(  uno::Reference< excel::XChartObject > ( new ScVbaChartObject(  m_xParent, m_xContext, xTableChart, xDrawPageSupplier ) ) );
+            ret <<= uno::Reference< excel::XChartObject > ( new ScVbaChartObject(  m_xParent, m_xContext, xTableChart, xDrawPageSupplier ) );
         }
         catch (const lang::WrappedTargetException&)
         {
@@ -86,7 +87,7 @@ ScVbaChartObjects::removeByName(const OUString& _sChartName)
 }
 
 uno::Sequence< OUString >
-ScVbaChartObjects::getChartObjectNames() throw( css::script::BasicErrorException )
+ScVbaChartObjects::getChartObjectNames()
 {
     uno::Sequence< OUString > sChartNames;
     try
@@ -115,22 +116,18 @@ ScVbaChartObjects::getChartObjectNames() throw( css::script::BasicErrorException
             for (sal_Int32 n = 0; n < nChartNames; n++ )
                 aChartNamesVector.push_back(scurchartnames[n]);
         }
-        sChartNames.realloc( aChartNamesVector.size() );
-        std::vector< OUString > ::const_iterator it = aChartNamesVector.begin();
-        std::vector< OUString > ::const_iterator it_end = aChartNamesVector.end();
-        for ( sal_Int32 index = 0 ; it != it_end; ++it, ++index )
-            sChartNames[index] = *it;
+        sChartNames = comphelper::containerToSequence( aChartNamesVector );
     }
     catch (uno::Exception& )
     {
-        throw script::BasicErrorException( OUString(), uno::Reference< uno::XInterface >(), ERRCODE_BASIC_METHOD_FAILED, OUString() );
+        throw script::BasicErrorException( OUString(), uno::Reference< uno::XInterface >(), sal_uInt32(ERRCODE_BASIC_METHOD_FAILED), OUString() );
     }
     return sChartNames;
 }
 
 // XChartObjects
 uno::Any SAL_CALL
-ScVbaChartObjects::Add( double _nX, double _nY, double _nWidth, double _nHeight ) throw (script::BasicErrorException, std::exception)
+ScVbaChartObjects::Add( double _nX, double _nY, double _nWidth, double _nHeight )
 {
     try
     {
@@ -149,11 +146,11 @@ ScVbaChartObjects::Add( double _nX, double _nY, double _nWidth, double _nHeight
     }
     catch (const uno::Exception& ex)
     {
-        OSL_TRACE("AddItem caught exception ->%s", OUStringToOString( ex.Message, RTL_TEXTENCODING_UTF8 ).getStr() );
+        SAL_WARN("sc", "AddItem caught " << ex );
     }
     return aNULL();
 }
-void SAL_CALL ScVbaChartObjects::Delete(  ) throw (script::BasicErrorException, std::exception)
+void SAL_CALL ScVbaChartObjects::Delete(  )
 {
     uno::Sequence< OUString > sChartNames = xTableCharts->getElementNames();
     sal_Int32 ncount = sChartNames.getLength();
@@ -164,7 +161,7 @@ void SAL_CALL ScVbaChartObjects::Delete(  ) throw (script::BasicErrorException,
 // XEnumerationAccess
 
 uno::Reference< container::XEnumeration >
-ScVbaChartObjects::createEnumeration() throw (uno::RuntimeException)
+ScVbaChartObjects::createEnumeration()
 {
     css::uno::Reference< container::XEnumerationAccess > xEnumAccess( xTableCharts, uno::UNO_QUERY_THROW );
     return new ChartObjectEnumerationImpl( mxContext, xEnumAccess->createEnumeration(), xDrawPageSupplier, getParent() /* sheet */);
@@ -173,7 +170,7 @@ ScVbaChartObjects::createEnumeration() throw (uno::RuntimeException)
 // XElementAccess
 
 uno::Type
-ScVbaChartObjects::getElementType() throw (uno::RuntimeException)
+ScVbaChartObjects::getElementType()
 {
     return cppu::UnoType<excel::XChartObject>::get();
 }
