@@ -19,7 +19,8 @@
 
 #include <config_features.h>
 
-#include "scitems.hxx"
+#include <basic/sberrors.hxx>
+#include <scitems.hxx>
 #include <comphelper/lok.hxx>
 #include <sfx2/viewfrm.hxx>
 #include <sfx2/app.hxx>
@@ -37,33 +38,35 @@
 #include <com/sun/star/frame/FrameSearchFlag.hpp>
 #include <com/sun/star/sdbc/XResultSet.hpp>
 
-#include "cellsh.hxx"
-#include "tabvwsh.hxx"
-#include "sc.hrc"
-#include "globstr.hrc"
-#include "global.hxx"
-#include "globalnames.hxx"
-#include "scmod.hxx"
-#include "docsh.hxx"
-#include "document.hxx"
-#include "uiitems.hxx"
-#include "dbfunc.hxx"
-#include "dbdocfun.hxx"
-#include "filtdlg.hxx"
-#include "dbnamdlg.hxx"
-#include "reffact.hxx"
-#include "validat.hxx"
-#include "validate.hxx"
-#include "scresid.hxx"
+#include <cellsh.hxx>
+#include <tabvwsh.hxx>
+#include <sc.hrc>
+#include <globstr.hrc>
+#include <global.hxx>
+#include <globalnames.hxx>
+#include <scmod.hxx>
+#include <docsh.hxx>
+#include <document.hxx>
+#include <uiitems.hxx>
+#include <dbfunc.hxx>
+#include <dbdocfun.hxx>
+#include <filtdlg.hxx>
+#include <dbnamdlg.hxx>
+#include <reffact.hxx>
+#include <validat.hxx>
+#include <validate.hxx>
+#include <scresid.hxx>
+#include <datamapper.hxx>
 
-#include "scui_def.hxx"
-#include "scabstdlg.hxx"
-#include "impex.hxx"
-#include "asciiopt.hxx"
-#include "datastream.hxx"
-#include "datastreamdlg.hxx"
-#include "queryentry.hxx"
-#include "markdata.hxx"
+#include <scui_def.hxx>
+#include <scabstdlg.hxx>
+#include <impex.hxx>
+#include <asciiopt.hxx>
+#include <datastream.hxx>
+#include <datastreamdlg.hxx>
+#include <dataproviderdlg.hxx>
+#include <queryentry.hxx>
+#include <markdata.hxx>
 #include <documentlinkmgr.hxx>
 
 #include <memory>
@@ -360,7 +363,6 @@ void ScCellShell::ExecuteDB( SfxRequest& rReq )
 
                 if( lcl_GetSortParam( pData, aSortParam ) )
                 {
-                    SfxItemSet  aArgSet( GetPool(), SCITEM_SORTDATA, SCITEM_SORTDATA );
                     SCCOL nCol  = GetViewData()->GetCurX();
                     SCCOL nTab  = GetViewData()->GetTabNo();
                     ScDocument* pDoc    = GetViewData()->GetDocument();
@@ -387,8 +389,6 @@ void ScCellShell::ExecuteDB( SfxRequest& rReq )
                     for ( sal_uInt16 i=1; i<aSortParam.GetSortKeyCount(); i++ )
                         aSortParam.maKeyState[i].bDoSort = false;
 
-                    aArgSet.Put( ScSortItem( SCITEM_SORTDATA, GetViewData(), &aSortParam ) );
-
                     pTabViewShell->UISort( aSortParam );        // subtotal when needed new
 
                     rReq.Done();
@@ -481,7 +481,7 @@ void ScCellShell::ExecuteDB( SfxRequest& rReq )
                     if( lcl_GetSortParam( pData, aSortParam ) )
                     {
                         ScDocument* pDoc = GetViewData()->GetDocument();
-                        SfxItemSet  aArgSet( GetPool(), SCITEM_SORTDATA, SCITEM_SORTDATA );
+                        SfxItemSet  aArgSet( GetPool(), svl::Items<SCITEM_SORTDATA, SCITEM_SORTDATA>{} );
 
                         pDBData->GetSortParam( aSortParam );
                         bool bHasHeader = pDoc->HasColHeader( aSortParam.nCol1, aSortParam.nRow1, aSortParam.nCol2, aSortParam.nRow2, pData->GetTabNo() );
@@ -683,7 +683,7 @@ void ScCellShell::ExecuteDB( SfxRequest& rReq )
                 }
 #if HAVE_FEATURE_SCRIPTING
                 else if (rReq.IsAPI())
-                    SbxBase::SetError(ERRCODE_SBX_BAD_PARAMETER);
+                    SbxBase::SetError(ERRCODE_BASIC_BAD_PARAMETER);
 #endif
             }
             break;
@@ -741,7 +741,7 @@ void ScCellShell::ExecuteDB( SfxRequest& rReq )
                         OSL_ENSURE(pDlg, "Dialog create fail!");
                         if ( pDlg->Execute() == RET_OK )
                         {
-                            OUString aName = pDlg->GetSelectEntry();
+                            OUString aName = pDlg->GetSelectedEntry();
                             pTabViewShell->GotoDBArea( aName );
                             rReq.AppendItem( SfxStringItem( SID_SELECT_DB, aName ) );
                             rReq.Done();
@@ -781,6 +781,27 @@ void ScCellShell::ExecuteDB( SfxRequest& rReq )
                 pStrm->StopImport();
         }
         break;
+        case SID_DATA_PROVIDER:
+        {
+            std::shared_ptr<ScDocument> xDoc(new ScDocument, o3tl::default_delete<ScDocument>());
+            xDoc->InsertTab(0, "test");
+            ScopedVclPtrInstance< ScDataProviderDlg > aDialog( pTabViewShell->GetDialogParent(), xDoc);
+            if (aDialog->Execute() == RET_OK)
+            {
+                // handle the import here
+            }
+        }
+        break;
+        case SID_DATA_PROVIDER_REFRESH:
+        {
+            ScDocument* pDoc = GetViewData()->GetDocument();
+            auto& rDataMapper = pDoc->GetExternalDataMapper();
+            for (auto& rDataSource : rDataMapper.getDataSources())
+            {
+                rDataSource.refresh(pDoc, false);
+            }
+        }
+        break;
         case SID_MANAGE_XML_SOURCE:
             ExecuteXMLSourceDialog();
         break;
@@ -796,7 +817,7 @@ void ScCellShell::ExecuteDB( SfxRequest& rReq )
                 {
                     SfxItemSet aArgSet( GetPool(), ScTPValidationValue::GetRanges() );
                     ScValidationMode eMode = SC_VALID_ANY;
-                    ScConditionMode eOper = SC_COND_EQUAL;
+                    ScConditionMode eOper = ScConditionMode::Equal;
                     OUString aExpr1, aExpr2;
                     bool bBlank = true;
                     sal_Int16 nListType = css::sheet::TableValidationVisibility::UNSORTED;
@@ -820,7 +841,7 @@ void ScCellShell::ExecuteDB( SfxRequest& rReq )
                         {
                             eMode = pOldData->GetDataMode();
                             eOper = pOldData->GetOperation();
-                            sal_uLong nNumFmt = 0;
+                            sal_uInt32 nNumFmt = 0;
                             if ( eMode == SC_VALID_DATE || eMode == SC_VALID_TIME )
                             {
                                 short nType = ( eMode == SC_VALID_DATE ) ? css::util::NumberFormat::DATE
@@ -897,14 +918,14 @@ void ScCellShell::ExecuteDB( SfxRequest& rReq )
                                 if ( eMode == SC_VALID_TIME ) {
                                     sal_Int32 wraparound = aExpr1.compareTo(aExpr2);
                                     if (wraparound > 0) {
-                                        if (eOper == SC_COND_BETWEEN) {
-                                            eOper = SC_COND_NOTBETWEEN;
+                                        if (eOper == ScConditionMode::Between) {
+                                            eOper = ScConditionMode::NotBetween;
                                             OUString tmp = aExpr1;
                                             aExpr1 = aExpr2;
                                             aExpr2 = tmp;
                                         }
-                                        else if (eOper == SC_COND_NOTBETWEEN) {
-                                            eOper = SC_COND_BETWEEN;
+                                        else if (eOper == ScConditionMode::NotBetween) {
+                                            eOper = ScConditionMode::Between;
                                             OUString tmp = aExpr1;
                                             aExpr1 = aExpr2;
                                             aExpr2 = tmp;
@@ -1106,8 +1127,7 @@ void ScCellShell::GetDBState( SfxItemSet& rSet )
                 {
                     //  SBA wants a sal_Bool-item, enabled
 
-                    bool bEnable = true;
-                    rSet.Put(SfxBoolItem(nWhich, bEnable));
+                    rSet.Put(SfxBoolItem(nWhich, true));
                 }
                 break;
 
@@ -1188,6 +1208,16 @@ void ScCellShell::GetDBState( SfxItemSet& rSet )
                     }
                 }
                 break;
+            case SID_DATA_PROVIDER:
+            break;
+            case SID_DATA_PROVIDER_REFRESH:
+            {
+                ScDocument* pDoc = GetViewData()->GetDocument();
+                auto& rDataMapper = pDoc->GetExternalDataMapper();
+                if (rDataMapper.getDataSources().empty())
+                    rSet.DisableItem(nWhich);
+            }
+            break;
             case SID_DATA_STREAMS:
             case SID_DATA_STREAMS_PLAY:
             case SID_DATA_STREAMS_STOP:
@@ -1207,7 +1237,11 @@ void ScCellShell::GetDBState( SfxItemSet& rSet )
                 }
                 break;
             case SID_MANAGE_XML_SOURCE:
-                rSet.DisableItem(nWhich);
+                {
+                    SvtMiscOptions aMiscOptions;
+                    if ( !aMiscOptions.IsExperimentalMode() )
+                        rSet.DisableItem( nWhich );
+                }
             break;
         }
         nWhich = aIter.NextWhich();
