@@ -27,18 +27,18 @@
 #include <tools/urlobj.hxx>
 #include <toolkit/helper/vclunohelper.hxx>
 
-#include "drawview.hxx"
-#include "global.hxx"
-#include "drwlayer.hxx"
-#include "viewdata.hxx"
-#include "document.hxx"
-#include "docsh.hxx"
-#include "drwtrans.hxx"
-#include "transobj.hxx"
-#include "drawutil.hxx"
-#include "scmod.hxx"
-#include "globstr.hrc"
-#include "chartarr.hxx"
+#include <drawview.hxx>
+#include <global.hxx>
+#include <drwlayer.hxx>
+#include <viewdata.hxx>
+#include <document.hxx>
+#include <docsh.hxx>
+#include <drwtrans.hxx>
+#include <transobj.hxx>
+#include <drawutil.hxx>
+#include <scmod.hxx>
+#include <globstr.hrc>
+#include <chartarr.hxx>
 #include <gridwin.hxx>
 
 #include <com/sun/star/embed/NoVisualAreaSizeException.hpp>
@@ -199,7 +199,7 @@ void getRangeFromOle2Object(const SdrOle2Obj& rObj, std::vector<OUString>& rRang
 }
 
 // Get all cell ranges that are referenced by the selected chart objects.
-void getOleSourceRanges(const SdrMarkList& rMarkList, bool& rAnyOle, bool& rOneOle, std::vector<ScRange>* pRanges = nullptr, ScDocument* pDoc = nullptr )
+void getOleSourceRanges(const SdrMarkList& rMarkList, bool& rAnyOle, bool& rOneOle, std::vector<ScRange>* pRanges = nullptr, const ScDocument* pDoc = nullptr )
 {
     bool bCalcSourceRanges = pRanges && pDoc;
     std::vector<OUString> aRangeReps;
@@ -266,7 +266,7 @@ void getOleSourceRanges(const SdrMarkList& rMarkList, bool& rAnyOle, bool& rOneO
     return;
 }
 
-class InsertTabIndex : public std::unary_function<ScRange, void>
+class InsertTabIndex
 {
     std::vector<SCTAB>& mrTabs;
 public:
@@ -277,7 +277,7 @@ public:
     }
 };
 
-class CopyRangeData : public std::unary_function<ScRange, void>
+class CopyRangeData
 {
     ScDocument* mpSrc;
     ScDocument* mpDest;
@@ -473,7 +473,8 @@ void ScDrawView::SetMarkedOriginalSize()
                         aSz = xObj->getVisualAreaSize( static_cast<SdrOle2Obj*>(pObj)->GetAspect() );
                         aOriginalSize = OutputDevice::LogicToLogic(
                                             Size( aSz.Width, aSz.Height ),
-                                            aUnit, MapUnit::Map100thMM );
+                                            MapMode(aUnit),
+                                            MapMode(MapUnit::Map100thMM));
                         bDo = true;
                     } catch( embed::NoVisualAreaSizeException& )
                     {
