@@ -19,7 +19,7 @@
 
 #include <com/sun/star/linguistic2/XThesaurus.hpp>
 #include <comphelper/string.hxx>
-#include "scitems.hxx"
+#include <scitems.hxx>
 #include <editeng/eeitem.hxx>
 #include <i18nutil/unicode.hxx>
 
@@ -58,26 +58,26 @@
 #include <svtools/transfer.hxx>
 #include <svl/stritem.hxx>
 
-#include "editsh.hxx"
-#include "scresid.hxx"
-#include "global.hxx"
-#include "sc.hrc"
-#include "scmod.hxx"
-#include "inputhdl.hxx"
-#include "viewutil.hxx"
-#include "viewdata.hxx"
-#include "document.hxx"
-#include "reffind.hxx"
-#include "tabvwsh.hxx"
-#include "editutil.hxx"
-#include "globstr.hrc"
+#include <editsh.hxx>
+#include <scresid.hxx>
+#include <global.hxx>
+#include <sc.hrc>
+#include <scmod.hxx>
+#include <inputhdl.hxx>
+#include <viewutil.hxx>
+#include <viewdata.hxx>
+#include <document.hxx>
+#include <reffind.hxx>
+#include <tabvwsh.hxx>
+#include <editutil.hxx>
+#include <globstr.hrc>
 #include <gridwin.hxx>
 
 #define ScEditShell
-#include "scslots.hxx"
+#include <scslots.hxx>
 
-#include "scui_def.hxx"
-#include "scabstdlg.hxx"
+#include <scui_def.hxx>
+#include <scabstdlg.hxx>
 #include <memory>
 
 using namespace ::com::sun::star;
@@ -99,7 +99,7 @@ ScEditShell::ScEditShell(EditView* pView, ScViewData* pData) :
     SetPool( pEditView->GetEditEngine()->GetEmptyItemSet().GetPool() );
     SetUndoManager( &pEditView->GetEditEngine()->GetUndoManager() );
     SetName("EditCell");
-    SfxShell::SetContextName(vcl::EnumContext::GetContextName(vcl::EnumContext::Context_EditCell));
+    SfxShell::SetContextName(vcl::EnumContext::GetContextName(vcl::EnumContext::Context::EditCell));
 }
 
 ScEditShell::~ScEditShell()
@@ -135,7 +135,7 @@ static void lcl_RemoveAttribs( EditView& rEditView )
     pEngine->SetUpdateMode(false);
 
     OUString aName = ScGlobal::GetRscString( STR_UNDO_DELETECONTENTS );
-    int nViewShellId = -1;
+    ViewShellId nViewShellId(-1);
     if (ScTabViewShell* pViewSh = ScTabViewShell::GetActiveViewShell())
         nViewShellId = pViewSh->GetViewShellId();
     pEngine->GetUndoManager().EnterListAction( aName, aName, 0, nViewShellId );
@@ -280,6 +280,8 @@ void ScEditShell::Execute( SfxRequest& rReq )
                     pDlg->Insert( SotClipboardFormatId::STRING, EMPTY_OUSTRING );
                     pDlg->Insert( SotClipboardFormatId::RTF,    EMPTY_OUSTRING );
                     pDlg->Insert( SotClipboardFormatId::RICHTEXT,    EMPTY_OUSTRING );
+                    // Do not offer SotClipboardFormatId::STRING_TSVC for
+                    // in-cell paste.
 
                     TransferableDataHelper aDataHelper(
                         TransferableDataHelper::CreateFromSystemClipboard( pViewData->GetActiveWin() ) );
@@ -308,6 +310,18 @@ void ScEditShell::Execute( SfxRequest& rReq )
             }
             break;
 
+        case SID_PASTE_UNFORMATTED:
+            {
+                pTableView->Paste();
+
+                if (pTopView)
+                {
+                    pTopView->Paste();
+                    pTopView->GetWindow()->GrabFocus();
+                }
+            }
+            break;
+
         case SID_SELECTALL:
             {
                 sal_Int32 nPar = pEngine->GetParagraphCount();
@@ -454,7 +468,7 @@ void ScEditShell::Execute( SfxRequest& rReq )
                 ScAbstractDialogFactory* pFact = ScAbstractDialogFactory::Create();
                 OSL_ENSURE(pFact, "ScAbstractFactory create fail!");
 
-                ScopedVclPtr<AbstractScNamePasteDlg> pDlg(pFact->CreateScNamePasteDlg( pViewData->GetDialogParent(), pViewData->GetDocShell(), false ));
+                ScopedVclPtr<AbstractScNamePasteDlg> pDlg(pFact->CreateScNamePasteDlg( pViewData->GetDialogParent(), pViewData->GetDocShell() ));
                 OSL_ENSURE(pDlg, "Dialog create fail!");
                 short nRet = pDlg->Execute();
                 // pDlg is needed below
@@ -575,7 +589,7 @@ void ScEditShell::Execute( SfxRequest& rReq )
 
                             // insert new field
 
-                            SvxURLField aURLField( rURL, rName, SVXURLFORMAT_REPR );
+                            SvxURLField aURLField( rURL, rName, SvxURLFormat::Repr );
                             aURLField.SetTargetFrame( rTarget );
                             SvxFieldItem aURLItem( aURLField, EE_FEATURE_FIELD );
                             pTableView->InsertField( aURLItem );
@@ -751,8 +765,6 @@ void ScEditShell::GetState( SfxItemSet& rSet )
             case SID_TRANSLITERATE_KATAGANA:
             case SID_INSERT_RLM:
             case SID_INSERT_LRM:
-            case SID_INSERT_ZWNBSP:
-            case SID_INSERT_ZWSP:
                 ScViewUtil::HideDisabledSlot( rSet, pViewData->GetBindings(), nWhich );
             break;
 
@@ -800,17 +812,21 @@ const SvxURLField* ScEditShell::GetURLField()
 
 IMPL_LINK( ScEditShell, ClipboardChanged, TransferableDataHelper*, pDataHelper, void )
 {
-    bPastePossible = ( pDataHelper->HasFormat( SotClipboardFormatId::STRING ) || pDataHelper->HasFormat( SotClipboardFormatId::RTF )
-        || pDataHelper->HasFormat( SotClipboardFormatId::RICHTEXT )    );
+    bPastePossible = ( pDataHelper->HasFormat( SotClipboardFormatId::STRING )
+            || pDataHelper->HasFormat( SotClipboardFormatId::RTF )
+            || pDataHelper->HasFormat( SotClipboardFormatId::RICHTEXT ));
 
     SfxBindings& rBindings = pViewData->GetBindings();
     rBindings.Invalidate( SID_PASTE );
     rBindings.Invalidate( SID_PASTE_SPECIAL );
+    rBindings.Invalidate( SID_PASTE_UNFORMATTED );
     rBindings.Invalidate( SID_CLIPBOARD_FORMAT_ITEMS );
 }
 
 void ScEditShell::GetClipState( SfxItemSet& rSet )
 {
+    // Do not offer SotClipboardFormatId::STRING_TSVC for in-cell paste.
+
     if ( !mxClipEvtLstnr.is() )
     {
         // create listener
@@ -820,8 +836,9 @@ void ScEditShell::GetClipState( SfxItemSet& rSet )
 
         // get initial state
         TransferableDataHelper aDataHelper( TransferableDataHelper::CreateFromSystemClipboard( pViewData->GetActiveWin() ) );
-        bPastePossible = ( aDataHelper.HasFormat( SotClipboardFormatId::STRING ) || aDataHelper.HasFormat( SotClipboardFormatId::RTF )
-            || aDataHelper.HasFormat( SotClipboardFormatId::RICHTEXT ) );
+        bPastePossible = ( aDataHelper.HasFormat( SotClipboardFormatId::STRING )
+                || aDataHelper.HasFormat( SotClipboardFormatId::RTF )
+                || aDataHelper.HasFormat( SotClipboardFormatId::RICHTEXT ) );
     }
 
     SfxWhichIter aIter( rSet );
@@ -832,6 +849,7 @@ void ScEditShell::GetClipState( SfxItemSet& rSet )
         {
             case SID_PASTE:
             case SID_PASTE_SPECIAL:
+            case SID_PASTE_UNFORMATTED:
                 if( !bPastePossible )
                     rSet.DisableItem( nWhich );
                 break;
@@ -966,8 +984,7 @@ void ScEditShell::ExecuteAttr(SfxRequest& rReq)
         case SID_ULINE_VAL_DOUBLE:
         case SID_ULINE_VAL_DOTTED:
             {
-                FontLineStyle eOld = static_cast<const SvxUnderlineItem&>( pEditView->
-                                    GetAttribs().Get(EE_CHAR_UNDERLINE)).GetLineStyle();
+                FontLineStyle eOld = pEditView->GetAttribs().Get(EE_CHAR_UNDERLINE).GetLineStyle();
                 FontLineStyle eNew = eOld;
                 switch (nSlot)
                 {
@@ -999,8 +1016,7 @@ void ScEditShell::ExecuteAttr(SfxRequest& rReq)
 
         case SID_ATTR_CHAR_OVERLINE:
             {
-                FontLineStyle eOld = static_cast<const SvxOverlineItem&>( pEditView->
-                                    GetAttribs().Get(EE_CHAR_OVERLINE)).GetLineStyle();
+                FontLineStyle eOld = pEditView->GetAttribs().Get(EE_CHAR_OVERLINE).GetLineStyle();
                 FontLineStyle eNew = ( eOld != LINESTYLE_NONE ) ? LINESTYLE_NONE : LINESTYLE_SINGLE;
                 aSet.Put( SvxOverlineItem( eNew, EE_CHAR_OVERLINE ) );
                 rBindings.Invalidate( nSlot );
@@ -1009,8 +1025,7 @@ void ScEditShell::ExecuteAttr(SfxRequest& rReq)
 
         case SID_ATTR_CHAR_STRIKEOUT:
             {
-                bool bOld = static_cast<const SvxCrossedOutItem&>( pEditView->GetAttribs().
-                                Get(EE_CHAR_STRIKEOUT)).GetValue() != STRIKEOUT_NONE;
+                bool bOld = pEditView->GetAttribs().Get(EE_CHAR_STRIKEOUT).GetValue() != STRIKEOUT_NONE;
                 aSet.Put( SvxCrossedOutItem( bOld ? STRIKEOUT_NONE : STRIKEOUT_SINGLE, EE_CHAR_STRIKEOUT ) );
                 rBindings.Invalidate( nSlot );
             }
@@ -1018,8 +1033,7 @@ void ScEditShell::ExecuteAttr(SfxRequest& rReq)
 
         case SID_ATTR_CHAR_SHADOWED:
             {
-                bool bOld = static_cast<const SvxShadowedItem&>(pEditView->GetAttribs().
-                                Get(EE_CHAR_SHADOW)).GetValue();
+                bool bOld = pEditView->GetAttribs().Get(EE_CHAR_SHADOW).GetValue();
                 aSet.Put( SvxShadowedItem( !bOld, EE_CHAR_SHADOW ) );
                 rBindings.Invalidate( nSlot );
             }
@@ -1027,8 +1041,7 @@ void ScEditShell::ExecuteAttr(SfxRequest& rReq)
 
         case SID_ATTR_CHAR_CONTOUR:
             {
-                bool bOld = static_cast<const SvxContourItem&>(pEditView->GetAttribs().
-                                Get(EE_CHAR_OUTLINE)).GetValue();
+                bool bOld = pEditView->GetAttribs().Get(EE_CHAR_OUTLINE).GetValue();
                 aSet.Put( SvxContourItem( !bOld, EE_CHAR_OUTLINE ) );
                 rBindings.Invalidate( nSlot );
             }
@@ -1036,8 +1049,8 @@ void ScEditShell::ExecuteAttr(SfxRequest& rReq)
 
         case SID_SET_SUPER_SCRIPT:
             {
-                SvxEscapement eOld = (SvxEscapement) static_cast<const SvxEscapementItem&>(
-                        pEditView->GetAttribs().Get(EE_CHAR_ESCAPEMENT)).GetEnumValue();
+                SvxEscapement eOld = (SvxEscapement)
+                        pEditView->GetAttribs().Get(EE_CHAR_ESCAPEMENT).GetEnumValue();
                 SvxEscapement eNew = (eOld == SvxEscapement::Superscript) ?
                                         SvxEscapement::Off : SvxEscapement::Superscript;
                 aSet.Put( SvxEscapementItem( eNew, EE_CHAR_ESCAPEMENT ) );
@@ -1046,8 +1059,8 @@ void ScEditShell::ExecuteAttr(SfxRequest& rReq)
             break;
         case SID_SET_SUB_SCRIPT:
             {
-                SvxEscapement eOld = (SvxEscapement) static_cast<const SvxEscapementItem&>(
-                        pEditView->GetAttribs().Get(EE_CHAR_ESCAPEMENT)).GetEnumValue();
+                SvxEscapement eOld = (SvxEscapement)
+                        pEditView->GetAttribs().Get(EE_CHAR_ESCAPEMENT).GetEnumValue();
                 SvxEscapement eNew = (eOld == SvxEscapement::Subscript) ?
                                         SvxEscapement::Off : SvxEscapement::Subscript;
                 aSet.Put( SvxEscapementItem( eNew, EE_CHAR_ESCAPEMENT ) );
@@ -1140,8 +1153,7 @@ void ScEditShell::GetAttrState(SfxItemSet &rSet)
     }
     else
     {
-        FontLineStyle eUnderline = static_cast<const SvxUnderlineItem&>(
-                    aAttribs.Get(EE_CHAR_UNDERLINE)).GetLineStyle();
+        FontLineStyle eUnderline = aAttribs.Get(EE_CHAR_UNDERLINE).GetLineStyle();
         sal_uInt16 nId = SID_ULINE_VAL_NONE;
         switch (eUnderline)
         {
@@ -1159,8 +1171,7 @@ void ScEditShell::GetAttrState(SfxItemSet &rSet)
     if ( pHdl && pHdl->IsFormulaMode() )
         rSet.ClearItem( EE_CHAR_WEIGHT );   // Highlighted brace not here
 
-    SvxEscapement eEsc = (SvxEscapement) static_cast<const SvxEscapementItem&>(
-                    aAttribs.Get( EE_CHAR_ESCAPEMENT ) ).GetEnumValue();
+    SvxEscapement eEsc = (SvxEscapement) aAttribs.Get( EE_CHAR_ESCAPEMENT ).GetEnumValue();
     if( eEsc == SvxEscapement::Superscript )
     {
         rSet.Put( SfxBoolItem( SID_SET_SUPER_SCRIPT, true ) );
@@ -1205,7 +1216,7 @@ OUString ScEditShell::GetSelectionText( bool bWholeWord )
     return aStrSelection;
 }
 
-void ScEditShell::ExecuteUndo(SfxRequest& rReq)
+void ScEditShell::ExecuteUndo(const SfxRequest& rReq)
 {
     //  Undo must be handled here because it's called for both EditViews
 
@@ -1285,10 +1296,10 @@ void ScEditShell::GetUndoState(SfxItemSet &rSet)
     }
 }
 
-void ScEditShell::ExecuteTrans( SfxRequest& rReq )
+void ScEditShell::ExecuteTrans( const SfxRequest& rReq )
 {
-    sal_Int32 nType = ScViewUtil::GetTransliterationType( rReq.GetSlot() );
-    if ( nType )
+    TransliterationFlags nType = ScViewUtil::GetTransliterationType( rReq.GetSlot() );
+    if ( nType != TransliterationFlags::NONE )
     {
         ScInputHandler* pHdl = GetMyInputHdl();
         assert(pHdl && "no ScInputHandler");
