@@ -23,15 +23,17 @@
 #include <tools/poly.hxx>
 #include <svtools/colorcfg.hxx>
 
-#include "scresid.hxx"
-#include "sc.hrc"
-#include "tabvwsh.hxx"
-#include "hdrcont.hxx"
-#include "scmod.hxx"
-#include "inputopt.hxx"
-#include "gridmerg.hxx"
-#include "document.hxx"
-#include "markdata.hxx"
+#include <scresid.hxx>
+#include <sc.hrc>
+#include <tabvwsh.hxx>
+#include <hdrcont.hxx>
+#include <scmod.hxx>
+#include <inputopt.hxx>
+#include <gridmerg.hxx>
+#include <document.hxx>
+#include <markdata.hxx>
+#include <tabview.hxx>
+#include <viewdata.hxx>
 
 #define SC_DRAG_MIN     2
 
@@ -45,7 +47,7 @@
 #define SC_HDRPAINT_COUNT       7
 
 ScHeaderControl::ScHeaderControl( vcl::Window* pParent, SelectionEngine* pSelectionEngine,
-                                  SCCOLROW nNewSize, bool bNewVertical ) :
+                                  SCCOLROW nNewSize, bool bNewVertical, ScTabView* pTab ) :
             Window      ( pParent ),
             pSelEngine  ( pSelectionEngine ),
             bVertical   ( bNewVertical ),
@@ -58,9 +60,11 @@ ScHeaderControl::ScHeaderControl( vcl::Window* pParent, SelectionEngine* pSelect
             nDragStart  ( 0 ),
             nDragPos    ( 0 ),
             bDragMoved  ( false ),
-            bIgnoreMove ( false )
+            bIgnoreMove ( false ),
+            bInRefMode  ( false ),
+            pTabView    ( pTab )
 {
-    // --- RTL --- no default mirroring for this window, the spreadsheet itself
+    // RTL: no default mirroring for this window, the spreadsheet itself
     // is also not mirrored
     // mirror the vertical window for correct border drawing
     // table layout depends on sheet format, not UI setting, so the
@@ -111,7 +115,7 @@ void ScHeaderControl::DoPaint( SCCOLROW nStart, SCCOLROW nEnd )
     bool bLayoutRTL = IsLayoutRTL();
     long nLayoutSign = bLayoutRTL ? -1 : 1;
 
-    Rectangle aRect( Point(0,0), GetOutputSizePixel() );
+    tools::Rectangle aRect( Point(0,0), GetOutputSizePixel() );
     if ( bVertical )
     {
         aRect.Top() = GetScrPos( nStart )-nLayoutSign;      // extra pixel for line at top of selection
@@ -220,22 +224,22 @@ void ScHeaderControl::DrawShadedRect( long nStart, long nEnd, const Color& rBase
     SetLineColor();
     SetFillColor( aOuter );
     if (bVertical)
-        DrawRect( Rectangle( 0, nStart, nCenterPos-1, nEnd ) );
+        DrawRect( tools::Rectangle( 0, nStart, nCenterPos-1, nEnd ) );
     else
-        DrawRect( Rectangle( nStart, 0, nEnd, nCenterPos-1 ) );
+        DrawRect( tools::Rectangle( nStart, 0, nEnd, nCenterPos-1 ) );
     SetFillColor( aCenter );
     if (bVertical)
-        DrawRect( Rectangle( nCenterPos, nStart, nCenterPos, nEnd ) );
+        DrawRect( tools::Rectangle( nCenterPos, nStart, nCenterPos, nEnd ) );
     else
-        DrawRect( Rectangle( nStart, nCenterPos, nEnd, nCenterPos ) );
+        DrawRect( tools::Rectangle( nStart, nCenterPos, nEnd, nCenterPos ) );
     SetFillColor( aInner );
     if (bVertical)
-        DrawRect( Rectangle( nCenterPos+1, nStart, nBarSize-1, nEnd ) );
+        DrawRect( tools::Rectangle( nCenterPos+1, nStart, nBarSize-1, nEnd ) );
     else
-        DrawRect( Rectangle( nStart, nCenterPos+1, nEnd, nBarSize-1 ) );
+        DrawRect( tools::Rectangle( nStart, nCenterPos+1, nEnd, nBarSize-1 ) );
 }
 
-void ScHeaderControl::Paint( vcl::RenderContext& /*rRenderContext*/, const Rectangle& rRect )
+void ScHeaderControl::Paint( vcl::RenderContext& /*rRenderContext*/, const tools::Rectangle& rRect )
 {
     // It is important for VCL to have few calls, that is why the outer lines are
     // grouped together
@@ -332,7 +336,7 @@ void ScHeaderControl::Paint( vcl::RenderContext& /*rRenderContext*/, const Recta
 
     //  background is different for entry area and behind the entries
 
-    Rectangle aFillRect;
+    tools::Rectangle aFillRect;
     SetLineColor();
 
     if ( nLineEnd * nLayoutSign >= nInitScrPos * nLayoutSign )
@@ -342,9 +346,9 @@ void ScHeaderControl::Paint( vcl::RenderContext& /*rRenderContext*/, const Recta
             // high contrast: single-color background
             SetFillColor( rStyleSettings.GetFaceColor() );
             if ( bVertical )
-                aFillRect = Rectangle( 0, nInitScrPos, nBarSize-1, nLineEnd );
+                aFillRect = tools::Rectangle( 0, nInitScrPos, nBarSize-1, nLineEnd );
             else
-                aFillRect = Rectangle( nInitScrPos, 0, nLineEnd, nBarSize-1 );
+                aFillRect = tools::Rectangle( nInitScrPos, 0, nLineEnd, nBarSize-1 );
             DrawRect( aFillRect );
         }
         else
@@ -358,9 +362,9 @@ void ScHeaderControl::Paint( vcl::RenderContext& /*rRenderContext*/, const Recta
     {
         SetFillColor( SC_MOD()->GetColorConfig().GetColorValue(svtools::APPBACKGROUND).nColor );
         if ( bVertical )
-            aFillRect = Rectangle( 0, nLineEnd+nLayoutSign, nBarSize-1, nPEnd );
+            aFillRect = tools::Rectangle( 0, nLineEnd+nLayoutSign, nBarSize-1, nPEnd );
         else
-            aFillRect = Rectangle( nLineEnd+nLayoutSign, 0, nPEnd, nBarSize-1 );
+            aFillRect = tools::Rectangle( nLineEnd+nLayoutSign, 0, nPEnd, nBarSize-1 );
         DrawRect( aFillRect );
     }
 
@@ -377,9 +381,9 @@ void ScHeaderControl::Paint( vcl::RenderContext& /*rRenderContext*/, const Recta
                     SetLineColor();
                     SetFillColor( COL_LIGHTGRAY );
                     if (bVertical)
-                        DrawRect( Rectangle( 0, nTransStart, nBarSize-1, nTransEnd ) );
+                        DrawRect( tools::Rectangle( 0, nTransStart, nBarSize-1, nTransEnd ) );
                     else
-                        DrawRect( Rectangle( nTransStart, 0, nTransEnd, nBarSize-1 ) );
+                        DrawRect( tools::Rectangle( nTransStart, 0, nTransEnd, nBarSize-1 ) );
                 }
             }
             else
@@ -446,13 +450,13 @@ void ScHeaderControl::Paint( vcl::RenderContext& /*rRenderContext*/, const Recta
                     //  The window's background color (SetBackground) has to be the background
                     //  of the cell area, for the contrast comparison in DrawSelectionBackground.
 
-                    Rectangle aTransRect;
+                    tools::Rectangle aTransRect;
                     if (bVertical)
-                        aTransRect = Rectangle( 0, nTransStart, nBarSize-1, nTransEnd );
+                        aTransRect = tools::Rectangle( 0, nTransStart, nBarSize-1, nTransEnd );
                     else
-                        aTransRect = Rectangle( nTransStart, 0, nTransEnd, nBarSize-1 );
+                        aTransRect = tools::Rectangle( nTransStart, 0, nTransEnd, nBarSize-1 );
                     SetBackground( Color( rStyleSettings.GetFaceColor() ) );
-                    DrawSelectionBackground( aTransRect, 0, true, false, false );
+                    DrawSelectionBackground( aTransRect, 0, true, false );
                     SetBackground();
                 }
                 break;
@@ -622,13 +626,13 @@ bool ScHeaderControl::IsSelectionAllowed(SCCOLROW nPos) const
         {
             // row header
             SCROW nRPos = static_cast<SCROW>(nPos);
-            bCellsProtected = pDoc->HasAttrib(0, nRPos, nTab, MAXCOL, nRPos, nTab, HASATTR_PROTECTED);
+            bCellsProtected = pDoc->HasAttrib(0, nRPos, nTab, MAXCOL, nRPos, nTab, HasAttrFlags::Protected);
         }
         else
         {
             // column header
             SCCOL nCPos = static_cast<SCCOL>(nPos);
-            bCellsProtected = pDoc->HasAttrib(nCPos, 0, nTab, nCPos, MAXROW, nTab, HASATTR_PROTECTED);
+            bCellsProtected = pDoc->HasAttrib(nCPos, 0, nTab, nCPos, MAXROW, nTab, HasAttrFlags::Protected);
         }
 
         bool bSelProtected   = pProtect->isOptionEnabled(ScTableProtection::SELECT_LOCKED_CELLS);
@@ -656,6 +660,26 @@ void ScHeaderControl::MouseButtonDown( const MouseEvent& rMEvt )
         return;
     if ( ! rMEvt.IsLeft() )
         return;
+    if ( SC_MOD()->IsFormulaMode() )
+    {
+        if( !pTabView )
+            return;
+        SCTAB nTab = pTabView->GetViewData().GetTabNo();
+        if( !rMEvt.IsShift() )
+            pTabView->DoneRefMode( rMEvt.IsMod1() );
+        if( !bVertical )
+        {
+            pTabView->InitRefMode( nHitNo, 0, nTab, SC_REFTYPE_REF );
+            pTabView->UpdateRef( nHitNo, MAXROW, nTab );
+        }
+        else
+        {
+            pTabView->InitRefMode( 0, nHitNo, nTab, SC_REFTYPE_REF );
+            pTabView->UpdateRef( MAXCOL, nHitNo, nTab );
+        }
+        bInRefMode = true;
+        return;
+    }
     if ( bIsBorder && ResizeAllowed() )
     {
         nDragNo = nHitNo;
@@ -684,11 +708,17 @@ void ScHeaderControl::MouseButtonDown( const MouseEvent& rMEvt )
     {
         pSelEngine->SetWindow( this );
         Point aPoint;
-        Rectangle aVis( aPoint,GetOutputSizePixel() );
+        tools::Rectangle aVis( aPoint,GetOutputSizePixel() );
         if (bVertical)
-            aVis.Left() = LONG_MIN, aVis.Right() = LONG_MAX;
+        {
+            aVis.Left() = LONG_MIN;
+            aVis.Right() = LONG_MAX;
+        }
         else
-            aVis.Top() = LONG_MIN, aVis.Bottom() = LONG_MAX;
+        {
+            aVis.Top() = LONG_MIN;
+            aVis.Bottom() = LONG_MAX;
+        }
         pSelEngine->SetVisibleArea( aVis );
 
         SetMarking( true );     //  must precede SelMouseButtonDown
@@ -714,6 +744,13 @@ void ScHeaderControl::MouseButtonUp( const MouseEvent& rMEvt )
     if ( IsDisabled() )
         return;
 
+    if ( SC_MOD()->IsFormulaMode() )
+    {
+        SC_MOD()->EndReference();
+        bInRefMode = false;
+        return;
+    }
+
     SetMarking( false );
     bIgnoreMove = false;
 
@@ -767,6 +804,21 @@ void ScHeaderControl::MouseMove( const MouseEvent& rMEvt )
         return;
     }
 
+    if ( bInRefMode && rMEvt.IsLeft() && SC_MOD()->IsFormulaMode() )
+    {
+        if( !pTabView )
+            return;
+        bool bTmp;
+        SCCOLROW nHitNo = GetMousePos( rMEvt, bTmp );
+        SCTAB nTab = pTabView->GetViewData().GetTabNo();
+        if( !bVertical )
+            pTabView->UpdateRef( nHitNo, MAXROW, nTab );
+        else
+            pTabView->UpdateRef( MAXCOL, nHitNo, nTab );
+
+        return;
+    }
+
     if ( bDragging )
     {
         long nNewPos = bVertical ? rMEvt.GetPosPixel().Y() : rMEvt.GetPosPixel().X();
@@ -856,8 +908,7 @@ void ScHeaderControl::Command( const CommandEvent& rCEvt )
                     pViewSh->MarkRange( aNewRange );
             }
 
-            ScResId aResId( bVertical ? RID_POPUP_ROWHEADER : RID_POPUP_COLHEADER );
-            pViewSh->GetDispatcher()->ExecutePopup( aResId );
+            pViewSh->GetDispatcher()->ExecutePopup( bVertical ? OUString( "rowheader" ) : OUString( "colheader" ) );
         }
     }
     else if ( nCmd == CommandEventId::StartDrag )
@@ -879,8 +930,8 @@ void ScHeaderControl::StopMarking()
 
     //  don't call pSelEngine->Reset, so selection across the parts of
     //  a split/frozen view is possible
-
-    ReleaseMouse();
+    if (IsMouseCaptured())
+        ReleaseMouse();
 }
 
 void ScHeaderControl::ShowDragHelp()
@@ -898,7 +949,7 @@ void ScHeaderControl::ShowDragHelp()
 
         Point aMousePos = OutputToScreenPixel(GetPointerPosPixel());
 
-        Rectangle aRect;
+        tools::Rectangle aRect;
         QuickHelpFlags nAlign;
         if (!bVertical)
         {
