@@ -17,7 +17,7 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "scitems.hxx"
+#include <scitems.hxx>
 #include <svl/srchitem.hxx>
 #include <sfx2/app.hxx>
 #include <sfx2/objface.hxx>
@@ -25,21 +25,21 @@
 #include <sfx2/request.hxx>
 #include <svl/whiter.hxx>
 
-#include "pgbrksh.hxx"
-#include "tabvwsh.hxx"
-#include "scresid.hxx"
-#include "document.hxx"
-#include "sc.hrc"
+#include <pgbrksh.hxx>
+#include <tabvwsh.hxx>
+#include <scresid.hxx>
+#include <document.hxx>
+#include <sc.hrc>
 
 #define ScPageBreakShell
-#include "scslots.hxx"
+#include <scslots.hxx>
 
 
 SFX_IMPL_INTERFACE(ScPageBreakShell, SfxShell)
 
 void ScPageBreakShell::InitInterface_Impl()
 {
-    GetStaticInterface()->RegisterPopupMenu(ScResId(RID_POPUP_PAGEBREAK));
+    GetStaticInterface()->RegisterPopupMenu("pagebreak");
 }
 
 ScPageBreakShell::ScPageBreakShell( ScTabViewShell* pViewSh ) :
@@ -53,7 +53,6 @@ ScPageBreakShell::ScPageBreakShell( ScTabViewShell* pViewSh ) :
     {
         pMgr->SetMaxUndoActionCount( 0 );
     }
-    SetHelpId( HID_SCSHELL_PAGEBREAK );
     SetName("PageBreak");
 }
 
