@@ -19,14 +19,16 @@
 
 #include <com/sun/star/embed/NoVisualAreaSizeException.hpp>
 #include <com/sun/star/chart2/data/XDataReceiver.hpp>
+#include <com/sun/star/awt/XRequestCallback.hpp>
+#include <com/sun/star/awt/Rectangle.hpp>
 
 #include <com/sun/star/embed/EmbedMisc.hpp>
 #include <com/sun/star/embed/EmbedStates.hpp>
+#include <vcl/errinf.hxx>
 #include <sfx2/app.hxx>
 #include <toolkit/helper/vclunohelper.hxx>
 #include <svx/svxdlg.hxx>
 #include <svx/dataaccessdescriptor.hxx>
-#include <svx/pfiledlg.hxx>
 #include <svx/svditer.hxx>
 #include <svx/svdmark.hxx>
 #include <svx/svdograf.hxx>
@@ -39,6 +41,7 @@
 #include <sfx2/bindings.hxx>
 #include <sfx2/dispatch.hxx>
 #include <sfx2/viewfrm.hxx>
+#include <sfx2/filedlghelper.hxx>
 #include <svtools/soerr.hxx>
 #include <svl/rectitem.hxx>
 #include <svl/slstitm.hxx>
@@ -47,27 +50,26 @@
 #include <sot/exchange.hxx>
 #include <tools/diagnose_ex.h>
 
-#include "tabvwsh.hxx"
-#include "globstr.hrc"
-#include "scmod.hxx"
-#include "document.hxx"
-#include "sc.hrc"
-#include "client.hxx"
-#include "fuinsert.hxx"
-#include "docsh.hxx"
-#include "chartarr.hxx"
-#include "drawview.hxx"
-#include "ChartRangeSelectionListener.hxx"
+#include <tabvwsh.hxx>
+#include <globstr.hrc>
+#include <scmod.hxx>
+#include <document.hxx>
+#include <sc.hrc>
+#include <client.hxx>
+#include <fuinsert.hxx>
+#include <docsh.hxx>
+#include <chartarr.hxx>
+#include <drawview.hxx>
+#include <ChartRangeSelectionListener.hxx>
 #include <gridwin.hxx>
 
 #include <tools/urlobj.hxx>
 #include <com/sun/star/ui/dialogs/TemplateDescription.hpp>
+#include <comphelper/lok.hxx>
 
 using namespace com::sun::star;
 
-// STATIC DATA -----------------------------------------------------------
-
-void ScTabViewShell::ConnectObject( SdrOle2Obj* pObj )
+void ScTabViewShell::ConnectObject( const SdrOle2Obj* pObj )
 {
     // is called from paint
 
@@ -80,7 +82,7 @@ void ScTabViewShell::ConnectObject( SdrOle2Obj* pObj )
     if ( !pClient )
     {
         pClient = new ScClient( this, pWin, GetSdrView()->GetModel(), pObj );
-        Rectangle aRect = pObj->GetLogicRect();
+        tools::Rectangle aRect = pObj->GetLogicRect();
         Size aDrawSize = aRect.GetSize();
 
         Size aOleSize = pObj->GetOrigObjSize();
@@ -95,12 +97,51 @@ void ScTabViewShell::ConnectObject( SdrOle2Obj* pObj )
         // the object area must be set after the scaling since it triggers the resizing
         aRect.SetSize( aOleSize );
         pClient->SetObjArea( aRect );
-
-        static_cast<ScClient*>(pClient)->SetGrafEdit( nullptr );
     }
 }
 
-bool ScTabViewShell::ActivateObject( SdrOle2Obj* pObj, long nVerb )
+class PopupCallback : public cppu::WeakImplHelper<css::awt::XCallback>
+{
+    ScTabViewShell* m_pViewShell;
+    SdrOle2Obj* m_pObject;
+
+public:
+    explicit PopupCallback(ScTabViewShell* pViewShell, SdrOle2Obj* pObject)
+        : m_pViewShell(pViewShell)
+        , m_pObject(pObject)
+    {}
+
+    // XCallback
+    virtual void SAL_CALL notify(const css::uno::Any& aData) override
+    {
+        uno::Sequence<beans::PropertyValue> aProperties;
+        if (aData >>= aProperties)
+        {
+            awt::Rectangle xRectangle;
+            sal_Int32 dimensionIndex = 0;
+            OUString sPivotTableName("DataPilot1");
+
+            for (beans::PropertyValue const & rProperty : aProperties)
+            {
+                if (rProperty.Name == "Rectangle")
+                    rProperty.Value >>= xRectangle;
+                if (rProperty.Name == "DimensionIndex")
+                    rProperty.Value >>= dimensionIndex;
+                if (rProperty.Name == "PivotTableName")
+                    rProperty.Value >>= sPivotTableName;
+            }
+
+            tools::Rectangle aChartRect = m_pObject->GetLogicRect();
+
+            Point aPoint(xRectangle.X  + aChartRect.Left(), xRectangle.Y + aChartRect.Top());
+            Size aSize(xRectangle.Width, xRectangle.Height);
+
+            m_pViewShell->DoDPFieldPopup(sPivotTableName, dimensionIndex, aPoint, aSize);
+        }
+    }
+};
+
+void ScTabViewShell::ActivateObject( SdrOle2Obj* pObj, long nVerb )
 {
     // Do not leave the hint message box on top of the object
     RemoveHintWindow();
@@ -115,21 +156,21 @@ bool ScTabViewShell::ActivateObject( SdrOle2Obj* pObj, long nVerb )
         if ( !pClient )
             pClient = new ScClient( this, pWin, GetSdrView()->GetModel(), pObj );
 
-        if ( !(nErr & ERRCODE_ERROR_MASK) && xObj.is() )
+        if ( (sal_uInt32(nErr) & ERRCODE_ERROR_MASK) == 0 && xObj.is() )
         {
-            Rectangle aRect = pObj->GetLogicRect();
+            tools::Rectangle aRect = pObj->GetLogicRect();
 
             {
                 // #i118485# center on BoundRect for activation,
                 // OLE may be sheared/rotated now
-                const Rectangle& rBoundRect = pObj->GetCurrentBoundRect();
+                const tools::Rectangle& rBoundRect = pObj->GetCurrentBoundRect();
                 const Point aDelta(rBoundRect.Center() - aRect.Center());
                 aRect.Move(aDelta.X(), aDelta.Y());
             }
 
             Size aDrawSize = aRect.GetSize();
 
-            MapMode aMapMode( MAP_100TH_MM );
+            MapMode aMapMode( MapUnit::Map100thMM );
             Size aOleSize = pObj->GetOrigObjSize( &aMapMode );
 
             if ( pClient->GetAspect() != embed::Aspects::MSOLE_ICON
@@ -141,7 +182,7 @@ bool ScTabViewShell::ActivateObject( SdrOle2Obj* pObj, long nVerb )
                 {
                     MapUnit aUnit = VCLUnoHelper::UnoEmbed2VCLMapUnit( xObj->getMapUnit( pClient->GetAspect() ) );
                     aOleSize = OutputDevice::LogicToLogic( aDrawSize,
-                                            MAP_100TH_MM, aUnit );
+                                MapMode(MapUnit::Map100thMM), MapMode(aUnit));
                     awt::Size aSz( aOleSize.Width(), aOleSize.Height() );
                     xObj->setVisualAreaSize( pClient->GetAspect(), aSz );
                 }
@@ -164,8 +205,6 @@ bool ScTabViewShell::ActivateObject( SdrOle2Obj* pObj, long nVerb )
             aRect.SetSize( aOleSize );
             pClient->SetObjArea( aRect );
 
-            static_cast<ScClient*>(pClient)->SetGrafEdit( nullptr );
-
             nErr = pClient->DoVerb( nVerb );
             bErrorShown = true;
             // SfxViewShell::DoVerb shows its error messages
@@ -185,12 +224,19 @@ bool ScTabViewShell::ActivateObject( SdrOle2Obj* pObj, long nVerb )
                             xSup->getComponent(), uno::UNO_QUERY_THROW );
                         uno::Reference< chart2::data::XRangeHighlighter > xRangeHightlighter(
                             xDataReceiver->getRangeHighlighter());
-                        if( xRangeHightlighter.is())
+                        if (xRangeHightlighter.is())
                         {
                             uno::Reference< view::XSelectionChangeListener > xListener(
                                 new ScChartRangeSelectionListener( this ));
                             xRangeHightlighter->addSelectionChangeListener( xListener );
                         }
+                        uno::Reference<awt::XRequestCallback> xPopupRequest(xDataReceiver->getPopupRequest());
+                        if (xPopupRequest.is())
+                        {
+                            uno::Reference<awt::XCallback> xCallback(new PopupCallback(this, pObj));
+                            uno::Any aAny;
+                            xPopupRequest->addCallback(xCallback, aAny);
+                        }
                     }
                     catch( const uno::Exception & )
                     {
@@ -211,8 +257,6 @@ bool ScTabViewShell::ActivateObject( SdrOle2Obj* pObj, long nVerb )
     //! SetDocumentName should already happen in Sfx ???
     //TODO/LATER: how "SetDocumentName"?
     //xIPObj->SetDocumentName( GetViewData().GetDocShell()->GetTitle() );
-
-    return ( !(nErr & ERRCODE_ERROR_MASK) );
 }
 
 ErrCode ScTabViewShell::DoVerb(long nVerb)
@@ -222,7 +266,6 @@ ErrCode ScTabViewShell::DoVerb(long nVerb)
         return ERRCODE_SO_NOTIMPL;          // should not be
 
     SdrOle2Obj* pOle2Obj = nullptr;
-    ErrCode nErr = ERRCODE_NONE;
 
     const SdrMarkList& rMarkList = pView->GetMarkedObjectList();
     if (rMarkList.GetMarkCount() == 1)
@@ -241,7 +284,7 @@ ErrCode ScTabViewShell::DoVerb(long nVerb)
         OSL_FAIL("no object for Verb found");
     }
 
-    return nErr;
+    return ERRCODE_NONE;
 }
 
 void ScTabViewShell::DeactivateOle()
@@ -297,9 +340,6 @@ void ScTabViewShell::ExecDrawIns(SfxRequest& rReq)
             break;
 
         case SID_INSERT_OBJECT:
-        case SID_INSERT_PLUGIN:
-        case SID_INSERT_SOUND:
-        case SID_INSERT_VIDEO:
         case SID_INSERT_SMATH:
         case SID_INSERT_FLOATINGFRAME:
             FuInsertOLE(this, pWin, pView, pDrModel, rReq);
@@ -309,7 +349,8 @@ void ScTabViewShell::ExecDrawIns(SfxRequest& rReq)
             try
             {
                 sfx2::FileDialogHelper aDlg(ui::dialogs::TemplateDescription::FILEOPEN_SIMPLE,
-                        0, OUString("com.sun.star.chart2.ChartDocument"));
+                        FileDialogFlags::NONE, "com.sun.star.chart2.ChartDocument",
+                        SfxFilterFlags::NONE, SfxFilterFlags::NONE, pWin);
                 if(aDlg.Execute() == ERRCODE_NONE )
                 {
                     INetURLObject aURLObj( aDlg.GetPath() );
@@ -319,7 +360,7 @@ void ScTabViewShell::ExecDrawIns(SfxRequest& rReq)
             }
             catch (const uno::Exception& e)
             {
-                SAL_WARN( "sc", "Cannot Insert Chart: " << e.Message);
+                SAL_WARN( "sc", "Cannot Insert Chart: " << e);
             }
             break;
 
@@ -333,7 +374,7 @@ void ScTabViewShell::ExecDrawIns(SfxRequest& rReq)
                 {
                     const SfxRectangleItem& rRect =
                         static_cast<const SfxRectangleItem&>(rReq.GetArgs()->Get(SID_OBJECTRESIZE));
-                    Rectangle aRect( pWin->PixelToLogic( rRect.GetValue() ) );
+                    tools::Rectangle aRect( pWin->PixelToLogic( rRect.GetValue() ) );
 
                     if ( pView->AreObjectsMarked() )
                     {
@@ -362,12 +403,12 @@ void ScTabViewShell::ExecDrawIns(SfxRequest& rReq)
         case SID_LINKS:
             {
                 SvxAbstractDialogFactory* pFact = SvxAbstractDialogFactory::Create();
-                SfxAbstractLinksDialog* pDlg = pFact->CreateLinksDialog( pWin, rDoc.GetLinkManager() );
+                ScopedVclPtr<SfxAbstractLinksDialog> pDlg(pFact->CreateLinksDialog( pWin, rDoc.GetLinkManager() ));
                 if ( pDlg )
                 {
                     pDlg->Execute();
                     rBindings.Invalidate( nSlot );
-                    SfxGetpApp()->Broadcast( SfxSimpleHint( SC_HINT_AREALINKS_CHANGED ) );     // Navigator
+                    SfxGetpApp()->Broadcast( SfxHint( SfxHintId::ScAreaLinksChanged ) );     // Navigator
                     rReq.Done();
                 }
             }
@@ -391,12 +432,12 @@ void ScTabViewShell::ExecDrawIns(SfxRequest& rReq)
 
                         if(pNewDBField)
                         {
-                            Rectangle aVisArea = pWin->PixelToLogic(Rectangle(Point(0,0), pWin->GetOutputSizePixel()));
+                            tools::Rectangle aVisArea = pWin->PixelToLogic(tools::Rectangle(Point(0,0), pWin->GetOutputSizePixel()));
                             Point aObjPos(aVisArea.Center());
                             Size aObjSize(pNewDBField->GetLogicRect().GetSize());
                             aObjPos.X() -= aObjSize.Width() / 2;
                             aObjPos.Y() -= aObjSize.Height() / 2;
-                            Rectangle aNewObjectRectangle(aObjPos, aObjSize);
+                            tools::Rectangle aNewObjectRectangle(aObjPos, aObjSize);
 
                             pNewDBField->SetLogicRect(aNewObjectRectangle);
 
@@ -407,7 +448,7 @@ void ScTabViewShell::ExecDrawIns(SfxRequest& rReq)
                                 pNewDBField->NbcSetLayer(SC_LAYER_FRONT);
                             if (dynamic_cast<const SdrObjGroup*>( pNewDBField) !=  nullptr)
                             {
-                                SdrObjListIter aIter( *pNewDBField, IM_DEEPWITHGROUPS );
+                                SdrObjListIter aIter( *pNewDBField, SdrIterMode::DeepWithGroups );
                                 SdrObject* pSubObj = aIter.Next();
                                 while (pSubObj)
                                 {
@@ -458,28 +499,40 @@ void ScTabViewShell::GetDrawInsState(SfxItemSet &rSet)
                 break;
 
             case SID_INSERT_OBJECT:
-            case SID_INSERT_PLUGIN:
             case SID_INSERT_FLOATINGFRAME:
                 if ( bOle || bTabProt || bShared )
                     rSet.DisableItem( nWhich );
                 break;
 
-            case SID_INSERT_SOUND:
-            case SID_INSERT_VIDEO:
-                 /* #i102735# discussed with NN: removed for performance reasons
-                 || !SvxPluginFileDlg::IsAvailable(nWhich)
-                 */
-                if ( bOle || bTabProt || bShared )
-                    rSet.DisableItem( nWhich );
-                break;
-
-            case SID_INSERT_GRAPHIC:
             case SID_INSERT_AVMEDIA:
             case SID_FONTWORK_GALLERY_FLOATER:
                 if ( bTabProt || bShared )
                     rSet.DisableItem( nWhich );
                 break;
 
+            case SID_INSERT_GRAPHIC:
+                if (bTabProt || bShared)
+                {
+                    // do not disable 'insert graphic' item if the currently marked area is editable (not protected)
+                    // if there is no marked area, check the current cell
+                    bool bDisableInsertImage = true;
+                    ScMarkData& rMark = GetViewData().GetMarkData();
+                    if (!rMark.GetMarkedRanges().empty() && GetViewData().GetDocument()->IsSelectionEditable(rMark))
+                        bDisableInsertImage = false;
+                    else
+                    {
+                        if (GetViewData().GetDocument()->IsBlockEditable
+                            (GetViewData().GetTabNo(), GetViewData().GetCurX(), GetViewData().GetCurY(), GetViewData().GetCurX(), GetViewData().GetCurY()))
+                        {
+                            bDisableInsertImage = false;
+                        }
+                    }
+
+                    if (bDisableInsertImage)
+                        rSet.DisableItem(nWhich);
+                }
+                break;
+
             case SID_LINKS:
                 {
                     if (GetViewData().GetDocument()->GetLinkManager()->GetLinks().empty())
@@ -513,6 +566,36 @@ void ScTabViewShell::ExecuteUndo(SfxRequest& rReq)
                 if ( pReqArgs && pReqArgs->GetItemState( nSlot, true, &pItem ) == SfxItemState::SET )
                     nCount = static_cast<const SfxUInt16Item*>(pItem)->GetValue();
 
+                // Repair mode: allow undo/redo of all undo actions, even if access would
+                // be limited based on the view shell ID.
+                bool bRepair = false;
+                if (pReqArgs && pReqArgs->GetItemState(SID_REPAIRPACKAGE, false, &pItem) == SfxItemState::SET)
+                    bRepair = static_cast<const SfxBoolItem*>(pItem)->GetValue();
+
+                if (comphelper::LibreOfficeKit::isActive() && !bRepair)
+                {
+                    SfxUndoAction* pAction = nullptr;
+                    if (bIsUndo)
+                    {
+                        if (pUndoManager->GetUndoActionCount() != 0)
+                            pAction = pUndoManager->GetUndoAction();
+                    }
+                    else
+                    {
+                        if (pUndoManager->GetRedoActionCount() != 0)
+                            pAction = pUndoManager->GetRedoAction();
+                    }
+                    if (pAction)
+                    {
+                        ViewShellId nViewShellId = GetViewShellId();
+                        if (pAction->GetViewShellId() != nViewShellId)
+                        {
+                            rReq.SetReturnValue(SfxUInt32Item(SID_UNDO, static_cast<sal_uInt32>(SID_REPAIRPACKAGE)));
+                            return;
+                        }
+                    }
+                }
+
                 // lock paint for more than one cell undo action (not for editing within a cell)
                 bool bLockPaint = ( nCount > 1 && pUndoManager == GetUndoManager() );
                 if ( bLockPaint )
