@@ -21,8 +21,9 @@
 
 #include "dlgprov.hxx"
 
-#include <sfx2/sfx.hrc>
+#include <sfx2/strings.hrc>
 #include <sfx2/app.hxx>
+#include <sfx2/sfxresid.hxx>
 #include <vcl/layout.hxx>
 #include <tools/diagnose_ex.h>
 
@@ -38,6 +39,7 @@
 #include <com/sun/star/script/provider/XScriptProviderSupplier.hpp>
 #include <com/sun/star/script/vba/XVBACompatibility.hpp>
 #include <com/sun/star/lang/NoSuchMethodException.hpp>
+#include <com/sun/star/lang/ServiceNotRegisteredException.hpp>
 #include <com/sun/star/reflection/XIdlMethod.hpp>
 #include <com/sun/star/beans/MethodConcept.hpp>
 #include <com/sun/star/beans/XMaterialHolder.hpp>
@@ -53,7 +55,6 @@ using namespace ::com::sun::star::uno;
 using namespace ::com::sun::star::reflection;
 
 
-
 namespace dlgprov
 {
 
@@ -148,8 +149,6 @@ namespace dlgprov
     }
 
 
-
-
     // DialogEventsAttacherImpl
 
 
@@ -159,12 +158,12 @@ namespace dlgprov
         // key listeners by protocol when ScriptType = 'Script'
         // otherwise key is the ScriptType e.g. StarBasic
         if ( rxRTLListener.is() ) // set up handler for RTL_BASIC
-            listernersForTypes[ OUString("StarBasic") ] = rxRTLListener;
+            listenersForTypes[ OUString("StarBasic") ] = rxRTLListener;
         else
-            listernersForTypes[ OUString("StarBasic") ] = new DialogLegacyScriptListenerImpl( rxContext, rxModel );
+            listenersForTypes[ OUString("StarBasic") ] = new DialogLegacyScriptListenerImpl( rxContext, rxModel );
         // handler for Script & OUString("vnd.sun.star.UNO:")
-        listernersForTypes[ OUString("vnd.sun.star.UNO") ] = new DialogUnoScriptListenerImpl( rxContext, rxModel, rxControl, rxHandler, rxIntrospect, bProviderMode );
-        listernersForTypes[ OUString("vnd.sun.star.script") ] = new DialogSFScriptListenerImpl( rxContext, rxModel );
+        listenersForTypes[ OUString("vnd.sun.star.UNO") ] = new DialogUnoScriptListenerImpl( rxContext, rxModel, rxControl, rxHandler, rxIntrospect, bProviderMode );
+        listenersForTypes[ OUString("vnd.sun.star.script") ] = new DialogSFScriptListenerImpl( rxContext, rxModel );
 
         // determine the VBA compatibility mode from the Basic library container
         try
@@ -178,25 +177,24 @@ namespace dlgprov
         {
         }
         if ( mbUseFakeVBAEvents )
-            listernersForTypes[ OUString("VBAInterop") ] = new DialogVBAScriptListenerImpl( rxContext, rxControl, rxModel, sDialogLibName );
+            listenersForTypes[ OUString("VBAInterop") ] = new DialogVBAScriptListenerImpl( rxContext, rxControl, rxModel, sDialogLibName );
     }
 
 
-
     DialogEventsAttacherImpl::~DialogEventsAttacherImpl()
     {
     }
 
 
     Reference< script::XScriptListener >
-    DialogEventsAttacherImpl::getScriptListenerForKey( const OUString& sKey ) throw ( RuntimeException )
+    DialogEventsAttacherImpl::getScriptListenerForKey( const OUString& sKey )
     {
-        ListenerHash::iterator it = listernersForTypes.find( sKey );
-        if ( it == listernersForTypes.end() )
+        ListenerHash::iterator it = listenersForTypes.find( sKey );
+        if ( it == listenersForTypes.end() )
             throw RuntimeException(); // more text info here please
         return it->second;
     }
-    Reference< XScriptEventsSupplier > DialogEventsAttacherImpl::getFakeVbaEventsSupplier( const Reference< XControl >& xControl, OUString& sControlName )
+    Reference< XScriptEventsSupplier > DialogEventsAttacherImpl::getFakeVbaEventsSupplier( const Reference< XControl >& xControl, OUString const & sControlName )
     {
         Reference< XScriptEventsSupplier > xEventsSupplier;
         Reference< XMultiComponentFactory > xSMgr( m_xContext->getServiceManager() );
@@ -263,7 +261,7 @@ namespace dlgprov
                         // if we had no success, try to attach to the control
                         if ( !bSuccess )
                         {
-                            Reference< XEventListener > xListener_ = m_xEventAttacher->attachSingleEventListener(
+                            m_xEventAttacher->attachSingleEventListener(
                                 xControl, xAllListener, Helper, aDesc.ListenerType,
                                 aDesc.AddListenerParam, aDesc.EventMethod );
                         }
@@ -329,8 +327,6 @@ namespace dlgprov
     void SAL_CALL DialogEventsAttacherImpl::attachEvents( const Sequence< Reference< XInterface > >& Objects,
         const css::uno::Reference<css::script::XScriptListener>&,
         const Any& Helper )
-        throw (IllegalArgumentException, IntrospectionException, CannotCreateAdapterException,
-               ServiceNotRegisteredException, RuntimeException, std::exception)
     {
         // get EventAttacher
         {
@@ -339,19 +335,14 @@ namespace dlgprov
             if ( !m_xEventAttacher.is() )
             {
                 Reference< XMultiComponentFactory > xSMgr( m_xContext->getServiceManager() );
-                if ( xSMgr.is() )
-                {
-                    m_xEventAttacher.set( xSMgr->createInstanceWithContext(
-                        "com.sun.star.script.EventAttacher", m_xContext ), UNO_QUERY );
-
-                    if ( !m_xEventAttacher.is() )
-                        throw ServiceNotRegisteredException();
-                }
-                else
-                {
+                if ( !xSMgr.is() )
                     throw RuntimeException();
-                }
 
+                m_xEventAttacher.set( xSMgr->createInstanceWithContext(
+                    "com.sun.star.script.EventAttacher", m_xContext ), UNO_QUERY );
+
+                if ( !m_xEventAttacher.is() )
+                    throw ServiceNotRegisteredException();
             }
         }
         OUString sDialogCodeName;
@@ -371,7 +362,6 @@ namespace dlgprov
     }
 
 
-
     // DialogAllListenerImpl
 
 
@@ -384,13 +374,11 @@ namespace dlgprov
     }
 
 
-
     DialogAllListenerImpl::~DialogAllListenerImpl()
     {
     }
 
 
-
     void DialogAllListenerImpl::firing_impl( const AllEventObject& Event, Any* pRet )
     {
         ScriptEvent aScriptEvent;
@@ -415,7 +403,7 @@ namespace dlgprov
     // XEventListener
 
 
-    void DialogAllListenerImpl::disposing(const EventObject& ) throw ( RuntimeException, std::exception )
+    void DialogAllListenerImpl::disposing(const EventObject& )
     {
     }
 
@@ -423,7 +411,7 @@ namespace dlgprov
     // XAllListener
 
 
-    void DialogAllListenerImpl::firing( const AllEventObject& Event ) throw ( RuntimeException, std::exception )
+    void DialogAllListenerImpl::firing( const AllEventObject& Event )
     {
         //::osl::MutexGuard aGuard( getMutex() );
 
@@ -431,9 +419,7 @@ namespace dlgprov
     }
 
 
-
     Any DialogAllListenerImpl::approveFiring( const AllEventObject& Event )
-        throw ( reflection::InvocationTargetException, RuntimeException, std::exception )
     {
         //::osl::MutexGuard aGuard( getMutex() );
 
@@ -443,7 +429,6 @@ namespace dlgprov
     }
 
 
-
     // DialogScriptListenerImpl
 
 
@@ -462,7 +447,6 @@ namespace dlgprov
     }
 
 
-
     DialogScriptListenerImpl::~DialogScriptListenerImpl()
     {
     }
@@ -546,9 +530,7 @@ namespace dlgprov
 
     void DialogUnoScriptListenerImpl::firing_impl( const ScriptEvent& aScriptEvent, Any* pRet )
     {
-        static const char sUnoURLScheme[] = "vnd.sun.star.UNO:";
-
-        OUString aMethodName = aScriptEvent.ScriptCode.copy( strlen(sUnoURLScheme) );
+        OUString aMethodName = aScriptEvent.ScriptCode.copy( strlen("vnd.sun.star.UNO:") );
 
         const Any* pArguments = aScriptEvent.Arguments.getConstArray();
         Any aEventObject = pArguments[0];
@@ -581,7 +563,7 @@ namespace dlgprov
         {
             try
             {
-                // Methode ansprechen
+                // call method
                 const Reference< XIdlMethod >& rxMethod = m_xIntrospectionAccess->
                     getMethod( aMethodName, MethodConcept::ALL - MethodConcept::DANGEROUS );
 
@@ -630,24 +612,19 @@ namespace dlgprov
         }
         else
         {
-            ResMgr* pResMgr = SfxApplication::GetSfxResManager();
-            if( pResMgr )
-            {
-                OUString aRes( ResId(STR_ERRUNOEVENTBINDUNG, *pResMgr) );
-                OUString aQuoteChar( "\""  );
+            OUString aRes(SfxResId(STR_ERRUNOEVENTBINDUNG));
+            OUString aQuoteChar( "\"" );
 
-                OUString aOURes = aRes;
-                sal_Int32 nIndex = aOURes.indexOf( '%' );
+            sal_Int32 nIndex = aRes.indexOf( '%' );
 
-                OUString aOUFinal;
-                aOUFinal += aOURes.copy( 0, nIndex );
-                aOUFinal += aQuoteChar;
-                aOUFinal += aMethodName;
-                aOUFinal += aQuoteChar;
-                aOUFinal += aOURes.copy( nIndex + 2 );
+            OUString aOUFinal;
+            aOUFinal += aRes.copy( 0, nIndex );
+            aOUFinal += aQuoteChar;
+            aOUFinal += aMethodName;
+            aOUFinal += aQuoteChar;
+            aOUFinal += aRes.copy( nIndex + 2 );
 
-                ScopedVclPtrInstance<MessageDialog>::Create(nullptr, aOUFinal)->Execute();
-            }
+            ScopedVclPtrInstance<MessageDialog>(nullptr, aOUFinal)->Execute();
         }
     }
 
@@ -655,7 +632,7 @@ namespace dlgprov
     // XEventListener
 
 
-    void DialogScriptListenerImpl::disposing(const EventObject& ) throw ( RuntimeException, std::exception )
+    void DialogScriptListenerImpl::disposing(const EventObject& )
     {
     }
 
@@ -663,7 +640,7 @@ namespace dlgprov
     // XScriptListener
 
 
-    void DialogScriptListenerImpl::firing( const ScriptEvent& aScriptEvent ) throw ( RuntimeException, std::exception )
+    void DialogScriptListenerImpl::firing( const ScriptEvent& aScriptEvent )
     {
         //::osl::MutexGuard aGuard( getMutex() );
 
@@ -671,9 +648,7 @@ namespace dlgprov
     }
 
 
-
     Any DialogScriptListenerImpl::approveFiring( const ScriptEvent& aScriptEvent )
-        throw ( reflection::InvocationTargetException, RuntimeException, std::exception )
     {
         //::osl::MutexGuard aGuard( getMutex() );
 
@@ -683,8 +658,6 @@ namespace dlgprov
     }
 
 
-
-
 }   // namespace dlgprov
 
 
