@@ -21,9 +21,6 @@
 #include <com/sun/star/presentation/ShapeAnimationSubType.hpp>
 #include <com/sun/star/presentation/TextAnimationType.hpp>
 #include <com/sun/star/presentation/ParagraphTarget.hpp>
-#include <com/sun/star/animations/Event.hpp>
-#include <com/sun/star/animations/EventTrigger.hpp>
-#include <com/sun/star/animations/Timing.hpp>
 #include <comphelper/processfactory.hxx>
 #include <com/sun/star/animations/AnimationFill.hpp>
 #include <com/sun/star/animations/XAnimate.hpp>
@@ -33,8 +30,8 @@
 #include <svx/svdopath.hxx>
 #include <svx/svdogrp.hxx>
 #include <svx/svditer.hxx>
-#include "drawdoc.hxx"
-#include "sdpage.hxx"
+#include <drawdoc.hxx>
+#include <sdpage.hxx>
 #include <CustomAnimationPreset.hxx>
 #include <TransitionPreset.hxx>
 #include <EffectMigration.hxx>
@@ -55,7 +52,7 @@ struct deprecated_FadeEffect_conversion_table_entry
     const sal_Char* mpPresetId;
 }
 
-deprecated_FadeEffect_conversion_table[] =
+const deprecated_FadeEffect_conversion_table[] =
 {
 // OOo 1.x transitions
     { FadeEffect_FADE_FROM_LEFT,            "wipe-right" },
@@ -163,7 +160,7 @@ wedge                           wedge
 
 void EffectMigration::SetFadeEffect( SdPage* pPage, css::presentation::FadeEffect eNewEffect)
 {
-    deprecated_FadeEffect_conversion_table_entry* pEntry = deprecated_FadeEffect_conversion_table;
+    deprecated_FadeEffect_conversion_table_entry const * pEntry = deprecated_FadeEffect_conversion_table;
     while( (pEntry->meFadeEffect != FadeEffect_NONE) && (pEntry->meFadeEffect != eNewEffect) )
         pEntry++;
 
@@ -210,7 +207,7 @@ FadeEffect EffectMigration::GetFadeEffect( const SdPage* pPage )
         {
             const OUString& aPresetId = (*aIt)->getPresetId();
 
-            deprecated_FadeEffect_conversion_table_entry* pEntry = deprecated_FadeEffect_conversion_table;
+            deprecated_FadeEffect_conversion_table_entry const * pEntry = deprecated_FadeEffect_conversion_table;
             while( (pEntry->meFadeEffect != FadeEffect_NONE) && (!aPresetId.equalsAscii( pEntry->mpPresetId ) ) )
                 pEntry++;
 
@@ -226,7 +223,7 @@ struct deprecated_AnimationEffect_conversion_table_entry
     const sal_Char* mpPresetId;
     const sal_Char* mpPresetSubType;
 }
-deprecated_AnimationEffect_conversion_table[] =
+const deprecated_AnimationEffect_conversion_table[] =
 {
 // OOo 1.x entrance effects
     { AnimationEffect_APPEAR, "ooo-entrance-appear",nullptr },
@@ -393,7 +390,7 @@ deprecated_AnimationEffect_conversion_table[] =
     { AnimationEffect_NONE, nullptr, nullptr }
 };
 
-EffectSequence::iterator ImplFindEffect( MainSequencePtr& pMainSequence, const Reference< XShape >& rShape, sal_Int16 nSubItem )
+EffectSequence::iterator ImplFindEffect( MainSequencePtr const & pMainSequence, const Reference< XShape >& rShape, sal_Int16 nSubItem )
 {
     EffectSequence::iterator aIter;
 
@@ -407,7 +404,7 @@ EffectSequence::iterator ImplFindEffect( MainSequencePtr& pMainSequence, const R
     return aIter;
 }
 
-static bool implIsInsideGroup( SdrObject* pObj )
+static bool implIsInsideGroup( SdrObject const * pObj )
 {
     return pObj && pObj->GetObjList() && pObj->GetObjList()->GetUpList();
 }
@@ -497,7 +494,7 @@ void EffectMigration::SetAnimationEffect( SvxShape* pShape, AnimationEffect eEff
 
                     pMainSequence->append( pEffect );
 
-                    if( ( pObj->GetObjInventor() == SdrInventor ) && ( pObj->GetObjIdentifier() == OBJ_OUTLINETEXT ) )
+                    if( ( pObj->GetObjInventor() == SdrInventor::Default ) && ( pObj->GetObjIdentifier() == OBJ_OUTLINETEXT ) )
                     {
                         // special case for outline text, effects are always mapped to text group effect
                         pMainSequence->
@@ -525,7 +522,7 @@ void EffectMigration::SetAnimationEffect( SvxShape* pShape, AnimationEffect eEff
                 if( (pEffect->getPresetId() != aPresetId) ||
                     (pEffect->getPresetSubType() != aPresetSubType) )
                 {
-                    pMainSequence->replace( pEffect, pPreset, aPresetSubType );
+                    pMainSequence->replace( pEffect, pPreset, aPresetSubType, -1.0 );
                 }
             }
         }
@@ -749,7 +746,7 @@ bool EffectMigration::ConvertPreset( const OUString& rPresetId, const OUString*
     if( !rPresetId.isEmpty() )
     {
         // first try a match for preset id and subtype
-        deprecated_AnimationEffect_conversion_table_entry* p = deprecated_AnimationEffect_conversion_table;
+        deprecated_AnimationEffect_conversion_table_entry const * p = deprecated_AnimationEffect_conversion_table;
         while( p->mpPresetId )
         {
             if( rPresetId.equalsAscii( p->mpPresetId ) &&
@@ -773,7 +770,7 @@ bool EffectMigration::ConvertPreset( const OUString& rPresetId, const OUString*
 
 bool EffectMigration::ConvertAnimationEffect( const AnimationEffect& rEffect, OUString& rPresetId, OUString& rPresetSubType )
 {
-    deprecated_AnimationEffect_conversion_table_entry* p = deprecated_AnimationEffect_conversion_table;
+    deprecated_AnimationEffect_conversion_table_entry const * p = deprecated_AnimationEffect_conversion_table;
     while( p->mpPresetId )
     {
         if( p->meEffect == rEffect )
@@ -1139,7 +1136,7 @@ void EffectMigration::SetPresentationOrder( SvxShape* pShape, sal_Int32 nNewPos
         std::vector< EffectSequence::iterator >::iterator aEnd( aEffectVector[nCurrentPos].end() );
         while( aIter != aEnd )
         {
-            aEffects.push_back( (*(*aIter)) );
+            aEffects.push_back( *(*aIter) );
             rSequence.erase( (*aIter++) );
         }
 
@@ -1153,7 +1150,7 @@ void EffectMigration::SetPresentationOrder( SvxShape* pShape, sal_Int32 nNewPos
         {
             while( aTempIter != aTempEnd )
             {
-                rSequence.push_back( (*aTempIter++) );
+                rSequence.push_back( *aTempIter++ );
             }
         }
         else
@@ -1169,7 +1166,7 @@ void EffectMigration::SetPresentationOrder( SvxShape* pShape, sal_Int32 nNewPos
 
 /** Returns the position of the given SdrObject in the Presentation order.
  *  This function returns -1 if the SdrObject is not in the Presentation order
- *  or if its the path-object.
+ *  or if it's the path-object.
  */
 sal_Int32 EffectMigration::GetPresentationOrder( SvxShape* pShape )
 {
@@ -1206,7 +1203,7 @@ sal_Int32 EffectMigration::GetPresentationOrder( SvxShape* pShape )
     return nFound;
 }
 
-void EffectMigration::UpdateSoundEffect( SvxShape* pShape, SdAnimationInfo* pInfo )
+void EffectMigration::UpdateSoundEffect( SvxShape* pShape, SdAnimationInfo const * pInfo )
 {
     if( pInfo )
     {
@@ -1280,7 +1277,7 @@ bool EffectMigration::GetSoundOn( SvxShape* pShape )
     return !GetSoundFile( pShape ).isEmpty();
 }
 
-void EffectMigration::SetAnimationPath( SvxShape* pShape, SdrPathObj* pPathObj )
+void EffectMigration::SetAnimationPath( SvxShape* pShape, SdrPathObj const * pPathObj )
 {
     if( pShape && pPathObj )
     {
@@ -1301,17 +1298,15 @@ void EffectMigration::SetAnimationPath( SvxShape* pShape, SdrPathObj* pPathObj )
 }
 
 // #i42894# helper which creates the needed XAnimate for changing visibility and all the (currently) needed embeddings
-void createVisibilityOnOffNode(Reference< XTimeContainer >& rxParentContainer, SdrObject& rCandidate, bool bVisible, bool bOnClick, double fDuration)
+void createVisibilityOnOffNode(Reference< XTimeContainer > const & rxParentContainer, SdrObject& rCandidate, bool bVisible, bool bOnClick, double fDuration)
 {
     Reference< XMultiServiceFactory > xMsf(::comphelper::getProcessServiceFactory());
-    Any aAny;
 
     // create par container node
     Reference< XAnimationNode > xOuterSeqTimeContainer(xMsf->createInstance("com.sun.star.animations.ParallelTimeContainer"), UNO_QUERY_THROW);
 
     // set begin
-    aAny <<= (double)(0.0);
-    xOuterSeqTimeContainer->setBegin(aAny);
+    xOuterSeqTimeContainer->setBegin(Any(0.0));
 
     // set fill
     xOuterSeqTimeContainer->setFill(AnimationFill::HOLD);
@@ -1329,12 +1324,10 @@ void createVisibilityOnOffNode(Reference< XTimeContainer >& rxParentContainer, S
     Reference< XAnimationNode > xAnimateSetForLast(xMsf->createInstance("com.sun.star.animations.AnimateSet"), UNO_QUERY_THROW);
 
     // set begin
-    aAny <<= (double)(0.0);
-    xAnimateSetForLast->setBegin(aAny);
+    xAnimateSetForLast->setBegin(Any(0.0));
 
     // set duration
-    aAny <<= fDuration;
-    xAnimateSetForLast->setDuration(aAny);
+    xAnimateSetForLast->setDuration(Any(fDuration));
 
     // set fill
     xAnimateSetForLast->setFill(AnimationFill::HOLD);
@@ -1342,15 +1335,13 @@ void createVisibilityOnOffNode(Reference< XTimeContainer >& rxParentContainer, S
     // set target
     Reference< XAnimate > xAnimate(xAnimateSetForLast, UNO_QUERY);
     Reference< XShape > xTargetShape(rCandidate.getUnoShape(), UNO_QUERY);
-    aAny <<= xTargetShape;
-    xAnimate->setTarget(aAny);
+    xAnimate->setTarget(Any(xTargetShape));
 
     // set AttributeName
     xAnimate->setAttributeName("Visibility");
 
     // set attribute value
-    aAny <<= bVisible;
-    xAnimate->setTo(aAny);
+    xAnimate->setTo(Any(bVisible));
 
     // ad set node to par node
     Reference< XTimeContainer > xParentContainer(xOuterSeqTimeContainer, UNO_QUERY_THROW);
@@ -1365,9 +1356,9 @@ void createVisibilityOnOffNode(Reference< XTimeContainer >& rxParentContainer, S
 // fallback will create the needed SMIL animation stuff. Unfortunately the members of the group
 // have to be moved directly to the page, else the (explained to be generic, thus I expected this to
 // work) animations will not work in slideshow
-void EffectMigration::CreateAnimatedGroup(SdrObjGroup& rGroupObj, SdPage& rPage)
+void EffectMigration::CreateAnimatedGroup(SdrObjGroup const & rGroupObj, SdPage& rPage)
 {
-    // aw080 will give a vector immeditately
+    // aw080 will give a vector immediately
     SdrObjListIter aIter(rGroupObj);
 
     if(aIter.Count())
@@ -1391,11 +1382,9 @@ void EffectMigration::CreateAnimatedGroup(SdrObjGroup& rGroupObj, SdPage& rPage)
             // create main node
             Reference< XMultiServiceFactory > xMsf(::comphelper::getProcessServiceFactory());
             Reference< XAnimationNode > xOuterSeqTimeContainer(xMsf->createInstance("com.sun.star.animations.ParallelTimeContainer"), UNO_QUERY_THROW);
-            Any aAny;
 
             // set begin
-            aAny <<= (double)(0.0);
-            xOuterSeqTimeContainer->setBegin(aAny);
+            xOuterSeqTimeContainer->setBegin(Any(0.0));
 
             // prepare parent container
             Reference< XTimeContainer > xParentContainer(xOuterSeqTimeContainer, UNO_QUERY_THROW);
@@ -1435,4 +1424,29 @@ void EffectMigration::CreateAnimatedGroup(SdrObjGroup& rGroupObj, SdPage& rPage)
     }
 }
 
+void EffectMigration::DocumentLoaded(SdDrawDocument & rDoc)
+{
+    if (DocumentType::Draw == rDoc.GetDocumentType())
+        return; // no animations in Draw
+    for (sal_uInt16 n = 0; n < rDoc.GetSdPageCount(PageKind::Standard); ++n)
+    {
+        SdPage *const pPage = rDoc.GetSdPage(n, PageKind::Standard);
+        if (pPage->hasAnimationNode())
+        {
+            // this will force the equivalent of the MainSequence::onTimerHdl
+            // so that the animations are present in export-able representation
+            // *before* the import is finished
+            pPage->getMainSequence()->getRootNode();
+        }
+    }
+    for (sal_uInt16 n = 0; n < rDoc.GetMasterSdPageCount(PageKind::Standard); ++n)
+    {
+        SdPage *const pPage = rDoc.GetMasterSdPage(n, PageKind::Standard);
+        if (pPage->hasAnimationNode())
+        {
+            pPage->getMainSequence()->getRootNode();
+        }
+    }
+}
+
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
