@@ -20,9 +20,11 @@
 #include <libxml/xmlwriter.h>
 
 #include "PageListWatcher.hxx"
-#include <com/sun/star/text/WritingMode.hpp>
 #include <com/sun/star/document/PrinterIndependentLayout.hpp>
 #include <com/sun/star/i18n/ScriptType.hpp>
+#include <com/sun/star/beans/XPropertyContainer.hpp>
+#include <com/sun/star/beans/PropertyAttribute.hpp>
+#include <com/sun/star/document/XDocumentProperties.hpp>
 #include <editeng/forbiddencharacterstable.hxx>
 
 #include <svx/svxids.hrc>
@@ -38,8 +40,8 @@
 #include <sfx2/app.hxx>
 #include <sfx2/linkmgr.hxx>
 #include <svx/dialogs.hrc>
-#include "Outliner.hxx"
-#include "sdmod.hxx"
+#include <Outliner.hxx>
+#include <sdmod.hxx>
 #include <editeng/editstat.hxx>
 #include <editeng/fontitem.hxx>
 #include <svl/flagitem.hxx>
@@ -71,34 +73,33 @@
 #include <com/sun/star/xml/dom/XDocument.hpp>
 #include <com/sun/star/xml/dom/XNode.hpp>
 #include <com/sun/star/xml/dom/XNodeList.hpp>
-#include <com/sun/star/xml/dom/XNamedNodeMap.hpp>
 #include <com/sun/star/xml/dom/DocumentBuilder.hpp>
 #include <com/sun/star/uno/XComponentContext.hpp>
 #include <rtl/ustring.hxx>
 #include <rtl/uri.hxx>
 
 #include <editeng/outliner.hxx>
-#include "drawdoc.hxx"
-#include "sdpage.hxx"
-#include "pglink.hxx"
-#include "sdattr.hxx"
-#include "glob.hrc"
-#include "glob.hxx"
-#include "stlpool.hxx"
-#include "sdiocmpt.hxx"
-#include "sdresid.hxx"
-#include "cusshow.hxx"
-#include "customshowlist.hxx"
-#include "../ui/inc/DrawDocShell.hxx"
-#include "../ui/inc/GraphicDocShell.hxx"
-#include "../ui/inc/sdxfer.hxx"
-#include "../ui/inc/ViewShell.hxx"
-#include "../ui/inc/optsitem.hxx"
-#include "../ui/inc/FrameView.hxx"
+#include <drawdoc.hxx>
+#include <sdpage.hxx>
+#include <pglink.hxx>
+#include <sdattr.hxx>
+#include <strings.hrc>
+#include <glob.hxx>
+#include <stlpool.hxx>
+#include <sdiocmpt.hxx>
+#include <sdresid.hxx>
+#include <cusshow.hxx>
+#include <customshowlist.hxx>
+#include <DrawDocShell.hxx>
+#include <GraphicDocShell.hxx>
+#include <sdxfer.hxx>
+#include <ViewShell.hxx>
+#include <optsitem.hxx>
+#include <FrameView.hxx>
+#include <undo/undomanager.hxx>
 
 #include <tools/tenccvt.hxx>
 #include <vcl/settings.hxx>
-#include <comphelper/lok.hxx>
 
 using namespace ::sd;
 using namespace ::com::sun::star;
@@ -109,7 +110,6 @@ using namespace ::com::sun::star::linguistic2;
 using namespace com::sun::star::xml::dom;
 using ::com::sun::star::uno::Reference;
 using ::com::sun::star::lang::XMultiServiceFactory;
-using ::com::sun::star::beans::PropertyValue;
 
 
 SdDrawDocument* SdDrawDocument::s_pDocLockedInsertingLinks = nullptr;
@@ -126,8 +126,7 @@ PresentationSettings::PresentationSettings()
     mbFullScreen( true ),
     mbAnimationAllowed( true ),
     mnPauseTimeout( 10 ),
-    mbShowPauseLogo( false ),
-    mbStartWithNavigator(false)
+    mbShowPauseLogo( false )
 {
 }
 
@@ -144,14 +143,12 @@ PresentationSettings::PresentationSettings( const PresentationSettings& r )
     mbFullScreen( r.mbFullScreen ),
     mbAnimationAllowed( r.mbAnimationAllowed ),
     mnPauseTimeout( r.mnPauseTimeout ),
-    mbShowPauseLogo( r.mbShowPauseLogo ),
-    mbStartWithNavigator( r.mbStartWithNavigator )
+    mbShowPauseLogo( r.mbShowPauseLogo )
 {
 }
 
 SdDrawDocument::SdDrawDocument(DocumentType eType, SfxObjectShell* pDrDocSh)
-: FmFormModel( !utl::ConfigManager::IsAvoidConfig() ? SvtPathOptions().GetPalettePath() : OUString(), nullptr, pDrDocSh )
-, bReadOnly(false)
+: FmFormModel( !utl::ConfigManager::IsFuzzing() ? SvtPathOptions().GetPalettePath() : OUString(), nullptr, pDrDocSh )
 , mpOutliner(nullptr)
 , mpInternalOutliner(nullptr)
 , mpWorkStartupTimer(nullptr)
@@ -170,11 +167,10 @@ SdDrawDocument::SdDrawDocument(DocumentType eType, SfxObjectShell* pDrDocSh)
 , meLanguage( LANGUAGE_SYSTEM )
 , meLanguageCJK( LANGUAGE_SYSTEM )
 , meLanguageCTL( LANGUAGE_SYSTEM )
-, mePageNumType(SVX_ARABIC)
+, mePageNumType(SVX_NUM_ARABIC)
 , mbAllocDocSh(false)
 , meDocType(eType)
 , mpCharClass(nullptr)
-, mpLocale(nullptr)
 , mbUseEmbedFonts(false)
 {
     mpDrawPageListWatcher.reset(new ImpDrawPageListWatcher(*this));
@@ -195,16 +191,16 @@ SdDrawDocument::SdDrawDocument(DocumentType eType, SfxObjectShell* pDrDocSh)
     pOptions->GetScale( nX, nY );
 
     // Allow UI scale only for draw documents.
-    if( eType == DOCUMENT_TYPE_DRAW )
+    if( eType == DocumentType::Draw )
         SetUIUnit( (FieldUnit)pOptions->GetMetric(), Fraction( nX, nY ) );  // user-defined
     else
         SetUIUnit( (FieldUnit)pOptions->GetMetric(), Fraction( 1, 1 ) );    // default
 
-    SetScaleUnit(MAP_100TH_MM);
+    SetScaleUnit(MapUnit::Map100thMM);
     SetScaleFraction(Fraction(1, 1));
     SetDefaultFontHeight(847);     // 24p
 
-    pItemPool->SetDefaultMetric(SFX_MAPUNIT_100TH_MM);
+    pItemPool->SetDefaultMetric(MapUnit::Map100thMM);
     pItemPool->FreezeIdRanges();
     SetTextDefaults();
 
@@ -219,7 +215,7 @@ SdDrawDocument::SdDrawDocument(DocumentType eType, SfxObjectShell* pDrDocSh)
     SetCalcFieldValueHdl( &rOutliner );
 
     // set linguistic options
-    if (!utl::ConfigManager::IsAvoidConfig())
+    if (!utl::ConfigManager::IsFuzzing())
     {
         const SvtLinguConfig    aLinguConfig;
         SvtLinguOptions         aOptions;
@@ -232,22 +228,15 @@ SdDrawDocument::SdDrawDocument(DocumentType eType, SfxObjectShell* pDrDocSh)
         SetLanguage( MsLangId::resolveSystemLanguageByScriptType(aOptions.nDefaultLanguage_CTL,
             css::i18n::ScriptType::COMPLEX), EE_CHAR_LANGUAGE_CTL );
 
-        if (!comphelper::LibreOfficeKit::isActive())
-            mbOnlineSpell = aOptions.bIsSpellAuto;
+        mbOnlineSpell = aOptions.bIsSpellAuto;
     }
 
     LanguageType eRealLanguage = MsLangId::getRealLanguage( meLanguage );
     LanguageTag aLanguageTag( eRealLanguage);
-    mpLocale = new css::lang::Locale( aLanguageTag.getLocale());
-    mpCharClass = new CharClass( aLanguageTag );
+    mpCharClass.reset(new CharClass( aLanguageTag ));
 
     // If the current application language is a language that uses right-to-left text...
     LanguageType eRealCTLLanguage = Application::GetSettings().GetLanguageTag().getLanguageType();
-    if( MsLangId::isRightToLeft( eRealCTLLanguage ) )
-    {
-        // ... then we have to set this as a default
-        SetDefaultWritingMode( css::text::WritingMode_RL_TB );
-    }
 
     // for korean and japanese languages we have a different default for apply spacing between asian, latin and ctl text
     if (MsLangId::isKorean(eRealCTLLanguage) || (LANGUAGE_JAPANESE == eRealCTLLanguage))
@@ -269,7 +258,7 @@ SdDrawDocument::SdDrawDocument(DocumentType eType, SfxObjectShell* pDrDocSh)
         if( xHyphenator.is() )
             rOutliner.SetHyphenator( xHyphenator );
 
-        SetForbiddenCharsTable( new SvxForbiddenCharactersTable( ::comphelper::getProcessComponentContext() ) );
+        SetForbiddenCharsTable(SvxForbiddenCharactersTable::makeForbiddenCharactersTable(::comphelper::getProcessComponentContext()));
     }
     catch(...)
     {
@@ -292,7 +281,7 @@ SdDrawDocument::SdDrawDocument(DocumentType eType, SfxObjectShell* pDrDocSh)
         nCntrl &= ~EEControlBits::ONLINESPELLING;
 
     nCntrl &= ~ EEControlBits::ULSPACESUMMATION;
-    if ( meDocType != DOCUMENT_TYPE_IMPRESS )
+    if ( meDocType != DocumentType::Impress )
         SetSummationOfParagraphs( false );
     else
     {
@@ -308,7 +297,6 @@ SdDrawDocument::SdDrawDocument(DocumentType eType, SfxObjectShell* pDrDocSh)
     // Set the StyleSheetPool for HitTestOutliner.
     // The link to the StyleRequest handler of the document is set later, in
     // NewOrLoadCompleted, because only then do all the templates exist.
-    SfxItemSet aSet2( pHitTestOutliner->GetEmptyItemSet() );
     pHitTestOutliner->SetStyleSheetPool( static_cast<SfxStyleSheetPool*>(GetStyleSheetPool()) );
 
     SetCalcFieldValueHdl( pHitTestOutliner );
@@ -356,14 +344,14 @@ SdDrawDocument::SdDrawDocument(DocumentType eType, SfxObjectShell* pDrDocSh)
       */
 
     {
-        OUString aControlLayerName( SD_RESSTR(STR_LAYER_CONTROLS) );
+        OUString aControlLayerName( SdResId(STR_LAYER_CONTROLS) );
 
         SdrLayerAdmin& rLayerAdmin = GetLayerAdmin();
-        rLayerAdmin.NewLayer( SD_RESSTR(STR_LAYER_LAYOUT) );
-        rLayerAdmin.NewLayer( SD_RESSTR(STR_LAYER_BCKGRND) );
-        rLayerAdmin.NewLayer( SD_RESSTR(STR_LAYER_BCKGRNDOBJ) );
+        rLayerAdmin.NewLayer( SdResId(STR_LAYER_LAYOUT) );
+        rLayerAdmin.NewLayer( SdResId(STR_LAYER_BCKGRND) );
+        rLayerAdmin.NewLayer( SdResId(STR_LAYER_BCKGRNDOBJ) );
         rLayerAdmin.NewLayer( aControlLayerName );
-        rLayerAdmin.NewLayer( SD_RESSTR(STR_LAYER_MEASURELINES) );
+        rLayerAdmin.NewLayer( SdResId(STR_LAYER_MEASURELINES) );
 
         rLayerAdmin.SetControlLayerName(aControlLayerName);
     }
@@ -373,7 +361,7 @@ SdDrawDocument::SdDrawDocument(DocumentType eType, SfxObjectShell* pDrDocSh)
 // Destructor
 SdDrawDocument::~SdDrawDocument()
 {
-    Broadcast(SdrHint(HINT_MODELCLEARED));
+    Broadcast(SdrHint(SdrHintKind::ModelCleared));
 
     if (mpWorkStartupTimer)
     {
@@ -385,8 +373,7 @@ SdDrawDocument::~SdDrawDocument()
     }
 
     StopOnlineSpelling();
-    delete mpOnlineSearchItem;
-    mpOnlineSearchItem = nullptr;
+    mpOnlineSearchItem.reset();
 
     CloseBookmarkDoc();
     SetAllocDocSh(false);
@@ -405,9 +392,7 @@ SdDrawDocument::~SdDrawDocument()
         pLinkManager = nullptr;
     }
 
-    std::vector<sd::FrameView*>::iterator pIter;
-    for ( pIter = maFrameViewList.begin(); pIter != maFrameViewList.end(); ++pIter )
-        delete *pIter;
+    maFrameViewList.clear();
 
     if (mpCustomShowList)
     {
@@ -422,17 +407,9 @@ SdDrawDocument::~SdDrawDocument()
         mpCustomShowList = nullptr;
     }
 
-    delete mpOutliner;
-    mpOutliner = nullptr;
-
-    delete mpInternalOutliner;
-    mpInternalOutliner = nullptr;
-
-    delete mpLocale;
-    mpLocale = nullptr;
-
-    delete mpCharClass;
-    mpCharClass = nullptr;
+    mpOutliner.reset();
+    mpInternalOutliner.reset();
+    mpCharClass.reset();
 }
 
 SdrModel* SdDrawDocument::AllocModel() const
@@ -440,6 +417,33 @@ SdrModel* SdDrawDocument::AllocModel() const
     return AllocSdDrawDocument();
 }
 
+namespace
+{
+
+/// Copies all user-defined properties from pSource to pDestination.
+void lcl_copyUserDefinedProperties(SfxObjectShell* pSource, SfxObjectShell* pDestination)
+{
+    if (!pSource || !pDestination)
+        return;
+
+    uno::Reference<document::XDocumentProperties> xSource = pSource->getDocProperties();
+    uno::Reference<document::XDocumentProperties> xDestination = pDestination->getDocProperties();
+    uno::Reference<beans::XPropertyContainer> xSourcePropertyContainer = xSource->getUserDefinedProperties();
+    uno::Reference<beans::XPropertyContainer> xDestinationPropertyContainer = xDestination->getUserDefinedProperties();
+    uno::Reference<beans::XPropertySet> xSourcePropertySet(xSourcePropertyContainer, uno::UNO_QUERY);
+    uno::Sequence<beans::Property> aProperties = xSourcePropertySet->getPropertySetInfo()->getProperties();
+
+    for (const beans::Property& rProperty : aProperties)
+    {
+        const OUString& rKey = rProperty.Name;
+        uno::Any aValue = xSourcePropertySet->getPropertyValue(rKey);
+        // We know that pDestination was just created, so has no properties: addProperty() will never throw.
+        xDestinationPropertyContainer->addProperty(rKey, beans::PropertyAttribute::REMOVABLE, aValue);
+    }
+}
+
+}
+
 // This method creates a new document (SdDrawDocument) and returns a pointer to
 // said document. The drawing engine uses this method to put the document (or
 // parts of it) into the clipboard/DragServer.
@@ -454,14 +458,14 @@ SdDrawDocument* SdDrawDocument::AllocSdDrawDocument() const
         SfxObjectShell*   pObj = nullptr;
         ::sd::DrawDocShell*     pNewDocSh = nullptr;
 
-        if( meDocType == DOCUMENT_TYPE_IMPRESS )
+        if( meDocType == DocumentType::Impress )
             mpCreatingTransferable->SetDocShell( new ::sd::DrawDocShell(
                 SfxObjectCreateMode::EMBEDDED, true, meDocType ) );
         else
             mpCreatingTransferable->SetDocShell( new ::sd::GraphicDocShell(
                 SfxObjectCreateMode::EMBEDDED, true, meDocType ) );
 
-        pNewDocSh = static_cast< ::sd::DrawDocShell*>( pObj = mpCreatingTransferable->GetDocShell() );
+        pNewDocSh = static_cast< ::sd::DrawDocShell*>( pObj = mpCreatingTransferable->GetDocShell().get() );
         pNewDocSh->DoInitNew();
         pNewModel = pNewDocSh->GetDoc();
 
@@ -474,15 +478,17 @@ SdDrawDocument* SdDrawDocument::AllocSdDrawDocument() const
         pNewStylePool->CopyCellSheets(*pOldStylePool);
         pNewStylePool->CopyTableStyles(*pOldStylePool);
 
-        for (sal_uInt16 i = 0; i < GetMasterSdPageCount(PK_STANDARD); i++)
+        for (sal_uInt16 i = 0; i < GetMasterSdPageCount(PageKind::Standard); i++)
         {
             // Move with all of the master page's layouts
-            OUString aOldLayoutName(const_cast<SdDrawDocument*>(this)->GetMasterSdPage(i, PK_STANDARD)->GetLayoutName());
+            OUString aOldLayoutName(const_cast<SdDrawDocument*>(this)->GetMasterSdPage(i, PageKind::Standard)->GetLayoutName());
             aOldLayoutName = aOldLayoutName.copy( 0, aOldLayoutName.indexOf( SD_LT_SEPARATOR ) );
             SdStyleSheetVector aCreatedSheets;
             pNewStylePool->CopyLayoutSheets(aOldLayoutName, *pOldStylePool, aCreatedSheets );
         }
 
+        lcl_copyUserDefinedProperties(GetDocSh(), pNewDocSh);
+
         pNewModel->NewOrLoadCompleted( DOC_LOADED );  // loaded from source document
     }
     else if( mbAllocDocSh )
@@ -564,7 +570,7 @@ void SdDrawDocument::NewOrLoadCompleted(DocCreationMode eMode)
 
         CheckMasterPages();
 
-        if ( GetMasterSdPageCount(PK_STANDARD) > 1 )
+        if ( GetMasterSdPageCount(PageKind::Standard) > 1 )
             RemoveUnnecessaryMasterPages( nullptr, true, false );
 
         for ( sal_uInt16 i = 0; i < GetPageCount(); i++ )
@@ -606,11 +612,11 @@ void SdDrawDocument::NewOrLoadCompleted(DocCreationMode eMode)
     }
 
     // Set default style of Drawing Engine
-    OUString aName( SD_RESSTR(STR_STANDARD_STYLESHEET_NAME));
+    OUString aName( SdResId(STR_STANDARD_STYLESHEET_NAME));
     SetDefaultStyleSheet(static_cast<SfxStyleSheet*>(mxStyleSheetPool->Find(aName, SD_STYLE_FAMILY_GRAPHICS)));
 
     // #i119287# Set default StyleSheet for SdrGrafObj and SdrOle2Obj
-    SetDefaultStyleSheetForSdrGrafObjAndSdrOle2Obj(static_cast<SfxStyleSheet*>(mxStyleSheetPool->Find(SD_RESSTR(STR_POOLSHEET_OBJNOLINENOFILL), SD_STYLE_FAMILY_GRAPHICS)));
+    SetDefaultStyleSheetForSdrGrafObjAndSdrOle2Obj(static_cast<SfxStyleSheet*>(mxStyleSheetPool->Find(SdResId(STR_POOLSHEET_OBJNOLINENOFILL), SD_STYLE_FAMILY_GRAPHICS)));
 
     // Initialize DrawOutliner and DocumentOutliner, but don't initialize the
     // global outliner, as it is not document specific like StyleSheetPool and
@@ -646,10 +652,10 @@ void SdDrawDocument::NewOrLoadCompleted(DocCreationMode eMode)
 
         // create missing layout style sheets for broken documents
         //         that where created with the 5.2
-        nPageCount = GetMasterSdPageCount( PK_STANDARD );
+        nPageCount = GetMasterSdPageCount( PageKind::Standard );
         for (nPage = 0; nPage < nPageCount; nPage++)
         {
-            SdPage* pPage = GetMasterSdPage(nPage, PK_STANDARD);
+            SdPage* pPage = GetMasterSdPage(nPage, PageKind::Standard);
             pSPool->CreateLayoutStyleSheets( pPage->GetName(), true );
         }
 
@@ -672,11 +678,11 @@ void SdDrawDocument::NewOrLoadCompleted(DocCreationMode eMode)
     mbNewOrLoadCompleted = true;
 
     // Update all linked pages
-    sal_uInt16 nMaxSdPages = GetSdPageCount(PK_STANDARD);
+    sal_uInt16 nMaxSdPages = GetSdPageCount(PageKind::Standard);
 
     for (sal_uInt16 nSdPage=0; nSdPage < nMaxSdPages; nSdPage++)
     {
-        SdPage* pPage = GetSdPage(nSdPage, PK_STANDARD);
+        SdPage* pPage = GetSdPage(nSdPage, PageKind::Standard);
 
         if (pPage && !pPage->GetFileName().isEmpty() && pPage->GetBookmarkName().getLength())
         {
@@ -696,7 +702,13 @@ void SdDrawDocument::UpdateAllLinks()
     {
         s_pDocLockedInsertingLinks = this; // lock inserting links. only links in this document should by resolved
 
-        pLinkManager->UpdateAllLinks();  // query box: update all links?
+        if (mpDocSh)
+        {
+            comphelper::EmbeddedObjectContainer& rEmbeddedObjectContainer = mpDocSh->getEmbeddedObjectContainer();
+            rEmbeddedObjectContainer.setUserAllowsLinkUpdate(true);
+        }
+
+        pLinkManager->UpdateAllLinks(true, false, nullptr);  // query box: update all links?
 
         if (s_pDocLockedInsertingLinks == this)
             s_pDocLockedInsertingLinks = nullptr;  // unlock inserting links
@@ -727,15 +739,15 @@ void SdDrawDocument::NewOrLoadCompleted( SdPage* pPage, SdStyleSheetPool* pSPool
         // listeners.
         while( (pObj = rPresentationShapes.getNextShape()) )
         {
-            if (pObj->GetObjInventor() == SdrInventor)
+            if (pObj->GetObjInventor() == SdrInventor::Default)
             {
                 OutlinerParaObject* pOPO = pObj->GetOutlinerParaObject();
                 sal_uInt16 nId = pObj->GetObjIdentifier();
 
                 if (nId == OBJ_TITLETEXT)
                 {
-                    if( pOPO && pOPO->GetOutlinerMode() == OUTLINERMODE_DONTKNOW )
-                        pOPO->SetOutlinerMode( OUTLINERMODE_TITLEOBJECT );
+                    if( pOPO && pOPO->GetOutlinerMode() == OutlinerMode::DontKnow )
+                        pOPO->SetOutlinerMode( OutlinerMode::TitleObject );
 
                     // sal_True: don't delete "hard" attributes when doing this.
                     if (pTitleSheet)
@@ -743,8 +755,8 @@ void SdDrawDocument::NewOrLoadCompleted( SdPage* pPage, SdStyleSheetPool* pSPool
                 }
                 else if (nId == OBJ_OUTLINETEXT)
                 {
-                    if( pOPO && pOPO->GetOutlinerMode() == OUTLINERMODE_DONTKNOW )
-                        pOPO->SetOutlinerMode( OUTLINERMODE_OUTLINEOBJECT );
+                    if( pOPO && pOPO->GetOutlinerMode() == OutlinerMode::DontKnow )
+                        pOPO->SetOutlinerMode( OutlinerMode::OutlineObject );
 
                     std::vector<SfxStyleSheetBase*>::iterator iter;
                     for (iter = aOutlineList.begin(); iter != aOutlineList.end(); ++iter)
@@ -769,7 +781,7 @@ void SdDrawDocument::NewOrLoadCompleted( SdPage* pPage, SdStyleSheetPool* pSPool
 
                     if (!aString.isEmpty())
                     {
-                        sd::Outliner* pInternalOutl = GetInternalOutliner();
+                        SdOutliner* pInternalOutl = GetInternalOutliner();
                         pPage->SetObjText( static_cast<SdrTextObj*>(pObj), pInternalOutl, ePresObjKind, aString );
                         pObj->NbcSetStyleSheet( pPage->GetStyleSheetForPresObj( ePresObjKind ), true );
                         pInternalOutl->Clear();
@@ -782,29 +794,29 @@ void SdDrawDocument::NewOrLoadCompleted( SdPage* pPage, SdStyleSheetPool* pSPool
 
 // Local outliner that is used for outline mode. In this outliner, OutlinerViews
 // may be inserted.
-::sd::Outliner* SdDrawDocument::GetOutliner(bool bCreateOutliner)
+SdOutliner* SdDrawDocument::GetOutliner(bool bCreateOutliner)
 {
     if (!mpOutliner && bCreateOutliner)
     {
-        mpOutliner = new ::sd::Outliner( this, OUTLINERMODE_TEXTOBJECT );
+        mpOutliner.reset(new SdOutliner( this, OutlinerMode::TextObject ));
 
         if (mpDocSh)
-            mpOutliner->SetRefDevice( SD_MOD()->GetRefDevice( *mpDocSh ) );
+            mpOutliner->SetRefDevice( SD_MOD()->GetVirtualRefDevice() );
 
         mpOutliner->SetDefTab( nDefaultTabulator );
         mpOutliner->SetStyleSheetPool(static_cast<SfxStyleSheetPool*>(GetStyleSheetPool()));
     }
 
-    return mpOutliner;
+    return mpOutliner.get();
 }
 
 // Internal outliner that is used to create text objects. We don't insert any
 // OutlinerViews into this outliner!
-::sd::Outliner* SdDrawDocument::GetInternalOutliner(bool bCreateOutliner)
+SdOutliner* SdDrawDocument::GetInternalOutliner(bool bCreateOutliner)
 {
     if ( !mpInternalOutliner && bCreateOutliner )
     {
-        mpInternalOutliner = new ::sd::Outliner( this, OUTLINERMODE_TEXTOBJECT );
+        mpInternalOutliner.reset( new SdOutliner( this, OutlinerMode::TextObject ) );
 
         // This outliner is only used to create special text objects. As no
         // information about portions is saved in this outliner, the update mode
@@ -813,7 +825,7 @@ void SdDrawDocument::NewOrLoadCompleted( SdPage* pPage, SdStyleSheetPool* pSPool
         mpInternalOutliner->EnableUndo( false );
 
         if (mpDocSh)
-            mpInternalOutliner->SetRefDevice( SD_MOD()->GetRefDevice( *mpDocSh ) );
+            mpInternalOutliner->SetRefDevice( SD_MOD()->GetVirtualRefDevice() );
 
         mpInternalOutliner->SetDefTab( nDefaultTabulator );
         mpInternalOutliner->SetStyleSheetPool(static_cast<SfxStyleSheetPool*>(GetStyleSheetPool()));
@@ -828,7 +840,7 @@ void SdDrawDocument::NewOrLoadCompleted( SdPage* pPage, SdStyleSheetPool* pSPool
     // b) no wasted memory
     DBG_ASSERT( !mpInternalOutliner || ( ( mpInternalOutliner->GetParagraphCount() == 1 ) && ( mpInternalOutliner->GetText( mpInternalOutliner->GetParagraph( 0 ) ).isEmpty() ) ), "InternalOutliner: not empty!" );
 
-    return mpInternalOutliner;
+    return mpInternalOutliner.get();
 }
 
 // OnlineSpelling on/off
@@ -984,7 +996,7 @@ sal_uInt16 SdDrawDocument::GetAnnotationAuthorIndex( const OUString& rAuthor )
 
 void SdDrawDocument::InitLayoutVector()
 {
-    if (utl::ConfigManager::IsAvoidConfig())
+    if (utl::ConfigManager::IsFuzzing())
         return;
 
     const Reference<css::uno::XComponentContext> xContext(
@@ -1023,7 +1035,7 @@ void SdDrawDocument::InitLayoutVector()
 
 void SdDrawDocument::InitObjectVector()
 {
-    if (utl::ConfigManager::IsAvoidConfig())
+    if (utl::ConfigManager::IsFuzzing())
         return;
 
     const Reference<css::uno::XComponentContext> xContext(
@@ -1066,10 +1078,21 @@ void SdDrawDocument::dumpAsXml(xmlTextWriterPtr pWriter) const
     if (!pWriter)
     {
         pWriter = xmlNewTextWriterFilename("model.xml", 0);
+        xmlTextWriterSetIndent(pWriter,1);
+        xmlTextWriterSetIndentString(pWriter, BAD_CAST("  "));
         xmlTextWriterStartDocument(pWriter, nullptr, nullptr, nullptr);
         bOwns = true;
     }
+    xmlTextWriterStartElement(pWriter, BAD_CAST("SdDrawDocument"));
+    xmlTextWriterWriteFormatAttribute(pWriter, BAD_CAST("ptr"), "%p", this);
+
+    if (mpOutliner)
+        mpOutliner->dumpAsXml(pWriter);
     FmFormModel::dumpAsXml(pWriter);
+    if (GetUndoManager())
+        GetUndoManager()->dumpAsXml(pWriter);
+
+    xmlTextWriterEndElement(pWriter);
     if (bOwns)
     {
         xmlTextWriterEndDocument(pWriter);
