@@ -19,7 +19,7 @@
 
 #include <tools/debug.hxx>
 
-#include "sdiocmpt.hxx"
+#include <sdiocmpt.hxx>
 
 old_SdrDownCompat::old_SdrDownCompat(SvStream& rNewStream, StreamMode nNewMode)
 :   rStream(rNewStream),
@@ -37,11 +37,6 @@ old_SdrDownCompat::~old_SdrDownCompat()
         CloseSubRecord();
 }
 
-void old_SdrDownCompat::Read()
-{
-    rStream.ReadUInt32( nSubRecSiz );
-}
-
 void old_SdrDownCompat::Write()
 {
     rStream.WriteUInt32( nSubRecSiz );
@@ -56,7 +51,7 @@ void old_SdrDownCompat::OpenSubRecord()
 
     if(nMode == StreamMode::READ)
     {
-        Read();
+        rStream.ReadUInt32( nSubRecSiz );
     }
     else if(nMode == StreamMode::WRITE)
     {
@@ -75,8 +70,8 @@ void old_SdrDownCompat::CloseSubRecord()
 
     if(nMode == StreamMode::READ)
     {
-        sal_uInt32 nReadAnz(nAktPos - nSubRecPos);
-        if(nReadAnz != nSubRecSiz)
+        sal_uInt32 nReadCnt(nAktPos - nSubRecPos);
+        if(nReadCnt != nSubRecSiz)
         {
             rStream.Seek(nSubRecPos + nSubRecSiz);
         }
