@@ -26,7 +26,7 @@
 #include <editeng/eeitem.hxx>
 #include <editeng/editeng.hxx>
 #include <editeng/outlobj.hxx>
-#include "Outliner.hxx"
+#include <Outliner.hxx>
 #include <svx/svdpool.hxx>
 
 using namespace ::com::sun::star::uno;
@@ -57,6 +57,9 @@ UndoTextAPIChanged::UndoTextAPIChanged(SdrModel& rModel, TextApiObject* pTextObj
 , mpNewText( nullptr )
 , mxTextObj( pTextObj )
 {
+#if defined __clang__ && defined _MSC_VER // workaround clang-cl ABI bug PR25641
+    css::uno::Sequence<css::beans::PropertyState> dummy; (void) dummy;
+#endif
 }
 
 UndoTextAPIChanged::~UndoTextAPIChanged()
@@ -102,7 +105,7 @@ public:
     explicit            TextAPIEditSource(SdDrawDocument* pDoc);
 
     void                Dispose();
-    void                SetText( OutlinerParaObject& rText );
+    void                SetText( OutlinerParaObject const & rText );
     OutlinerParaObject* CreateText();
     OUString            GetText();
     SdDrawDocument*     GetDoc() { return m_xImpl->mpDoc; }
@@ -160,7 +163,7 @@ OutlinerParaObject* TextApiObject::CreateText()
     return mpSource->CreateText();
 }
 
-void TextApiObject::SetText( OutlinerParaObject& rText )
+void TextApiObject::SetText( OutlinerParaObject const & rText )
 {
     SdrModel* pModel = mpSource->GetDoc();
     if( pModel && pModel->IsUndoEnabled() )
@@ -237,7 +240,7 @@ SvxTextForwarder* TextAPIEditSource::GetTextForwarder()
     return m_xImpl->mpTextForwarder;
 }
 
-void TextAPIEditSource::SetText( OutlinerParaObject& rText )
+void TextAPIEditSource::SetText( OutlinerParaObject const & rText )
 {
     if (m_xImpl->mpDoc)
     {
