@@ -17,40 +17,38 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-
+#include <memory>
 #include <osl/module.hxx>
 #include <tools/urlobj.hxx>
+#include <unotools/ucbstreamhelper.hxx>
 #include <svl/itemset.hxx>
 #include <sfx2/docfile.hxx>
 #include <sfx2/docfilt.hxx>
 #include <svx/xflclit.hxx>
 #include <svx/xfillit0.hxx>
 
-#include "sdpage.hxx"
-#include "drawdoc.hxx"
-#include "sdcgmfilter.hxx"
+#include <sddll.hxx>
+#include <sdpage.hxx>
+#include <drawdoc.hxx>
+#include <sdcgmfilter.hxx>
 
-#define CGM_IMPORT_CGM      0x00000001
-
-#define CGM_EXPORT_IMPRESS  0x00000100
-
-#define CGM_BIG_ENDIAN      0x00020000
+#include <DrawDocShell.hxx>
 
+using namespace ::com::sun::star;
 using namespace ::com::sun::star::uno;
 using namespace ::com::sun::star::task;
 using namespace ::com::sun::star::frame;
 
-typedef sal_uInt32 ( SAL_CALL *ImportCGMPointer )( OUString&, Reference< XModel >&, sal_uInt32, Reference< XStatusIndicator >& );
-typedef sal_Bool ( SAL_CALL *ExportCGMPointer )( OUString&, Reference< XModel >&, Reference< XStatusIndicator >&, void* );
+typedef sal_uInt32 ( SAL_CALL *ImportCGMPointer )(SvStream&, Reference< XModel > const &, Reference< XStatusIndicator > const &);
 
 #ifdef DISABLE_DYNLOADING
 
-extern "C" sal_uInt32 ImportCGM( OUString&, Reference< XModel >&, sal_uInt32, Reference< XStatusIndicator >& );
+extern "C" sal_uInt32 ImportCGM(SvStream&, Reference< XModel > const &, Reference< XStatusIndicator > const &);
 
 #endif
 
-SdCGMFilter::SdCGMFilter( SfxMedium& rMedium, ::sd::DrawDocShell& rDocShell, sal_Bool bShowProgress ) :
-    SdFilter( rMedium, rDocShell, bShowProgress )
+SdCGMFilter::SdCGMFilter( SfxMedium& rMedium, ::sd::DrawDocShell& rDocShell ) :
+    SdFilter( rMedium, rDocShell )
 {
 }
 
@@ -58,83 +56,87 @@ SdCGMFilter::~SdCGMFilter()
 {
 }
 
-sal_Bool SdCGMFilter::Import()
+namespace
 {
-#ifndef DISABLE_DYNLOADING
-    ::osl::Module* pLibrary = OpenLibrary( mrMedium.GetFilter()->GetUserData() );
-#endif
-    sal_Bool        bRet = sal_False;
-
-    if(
-#ifndef DISABLE_DYNLOADING
-       pLibrary &&
-#endif
-       mxModel.is() )
+    class CGMPointer
     {
+        ImportCGMPointer m_pPointer;
 #ifndef DISABLE_DYNLOADING
-        ImportCGMPointer FncImportCGM = reinterpret_cast< ImportCGMPointer >( pLibrary->getFunctionSymbol(  "ImportCGM" ) );
-#else
-        ImportCGMPointer FncImportCGM = ImportCGM;
+        std::unique_ptr<osl::Module> m_xLibrary;
 #endif
-        OUString aFileURL( mrMedium.GetURLObject().GetMainURL( INetURLObject::NO_DECODE ) );
+    public:
+        CGMPointer()
+        {
+#ifdef DISABLE_DYNLOADING
+            m_pPointer = ImportCGM;
+#else
+            m_xLibrary.reset(SdFilter::OpenLibrary("icg"));
+            m_pPointer = m_xLibrary ? reinterpret_cast<ImportCGMPointer>(m_xLibrary->getFunctionSymbol("ImportCGM")) : nullptr;
+#endif
+        }
+        ImportCGMPointer get() { return m_pPointer; }
+    };
+}
+
+bool SdCGMFilter::Import()
+{
+    bool        bRet = false;
+
+    CGMPointer aPointer;
+    ImportCGMPointer FncImportCGM = aPointer.get();
+    if (FncImportCGM && mxModel.is())
+    {
+        OUString aFileURL( mrMedium.GetURLObject().GetMainURL( INetURLObject::DecodeMechanism::NONE ) );
         sal_uInt32          nRetValue;
 
-        if( mrDocument.GetPageCount() == 0L )
+        if( mrDocument.GetPageCount() == 0 )
             mrDocument.CreateFirstPages();
 
         CreateStatusIndicator();
-        nRetValue = FncImportCGM( aFileURL, mxModel, CGM_IMPORT_CGM | CGM_BIG_ENDIAN | CGM_EXPORT_IMPRESS, mxStatusIndicator );
+        std::unique_ptr<SvStream> xIn(::utl::UcbStreamHelper::CreateStream(aFileURL, StreamMode::READ));
+        nRetValue = xIn ? FncImportCGM(*xIn, mxModel, mxStatusIndicator) : 0;
 
         if( nRetValue )
         {
-            bRet = sal_True;
+            bRet = true;
 
             if( ( nRetValue &~0xff000000 ) != 0xffffff )    // maybe the backgroundcolor is already white
             {                                               // so we must not set a master page
                 mrDocument.StopWorkStartupDelay();
-                SdPage* pSdPage = mrDocument.GetMasterSdPage(0, PK_STANDARD);
+                SdPage* pSdPage = mrDocument.GetMasterSdPage(0, PageKind::Standard);
 
                 if(pSdPage)
                 {
                     // set PageFill to given color
                     const Color aColor((sal_uInt8)(nRetValue >> 16), (sal_uInt8)(nRetValue >> 8), (sal_uInt8)(nRetValue >> 16));
                     pSdPage->getSdrPageProperties().PutItem(XFillColorItem(OUString(), aColor));
-                    pSdPage->getSdrPageProperties().PutItem(XFillStyleItem(XFILL_SOLID));
+                    pSdPage->getSdrPageProperties().PutItem(XFillStyleItem(drawing::FillStyle_SOLID));
                 }
             }
         }
     }
-#ifndef DISABLE_DYNLOADING
-    delete pLibrary;
-#endif
     return bRet;
 }
 
-sal_Bool SdCGMFilter::Export()
+bool SdCGMFilter::Export()
 {
-#ifdef DISABLE_DYNLOADING
     // No ExportCGM function exists(!)
-    return sal_False;
-#else
-    ::osl::Module* pLibrary = OpenLibrary( mrMedium.GetFilter()->GetUserData() );
-    sal_Bool        bRet = sal_False;
+    return false;
+}
 
-    if( pLibrary && mxModel.is() )
-    {
-        ExportCGMPointer FncCGMExport = reinterpret_cast< ExportCGMPointer >( pLibrary->getFunctionSymbol( "ExportCGM" ) );
+extern "C" SAL_DLLPUBLIC_EXPORT bool SAL_CALL TestImportCGM(SvStream &rStream)
+{
+    SdDLL::Init();
 
-        if( FncCGMExport )
-        {
-            OUString aPhysicalName( mrMedium.GetPhysicalName() );
+    ::sd::DrawDocShellRef xDocShRef = new ::sd::DrawDocShell(SfxObjectCreateMode::EMBEDDED, false);
 
-            CreateStatusIndicator();
-            bRet = FncCGMExport( aPhysicalName, mxModel, mxStatusIndicator, NULL );
-        }
-    }
+    CGMPointer aPointer;
+
+    bool bRet = aPointer.get()(rStream, xDocShRef->GetModel(), css::uno::Reference<css::task::XStatusIndicator>()) == 0;
+
+    xDocShRef->DoClose();
 
-    delete pLibrary;
     return bRet;
-#endif
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
