@@ -29,7 +29,6 @@
 #include <com/sun/star/animations/AnimationNodeType.hpp>
 #include <com/sun/star/animations/AnimationTransformType.hpp>
 #include <com/sun/star/animations/AnimationCalcMode.hpp>
-#include <com/sun/star/animations/AnimationValueType.hpp>
 #include <com/sun/star/util/XCloneable.hpp>
 #include <com/sun/star/animations/AnimationAdditiveMode.hpp>
 #include <com/sun/star/animations/XAnimateSet.hpp>
@@ -38,8 +37,6 @@
 #include <com/sun/star/animations/XAnimateColor.hpp>
 #include <com/sun/star/animations/XAnimateMotion.hpp>
 #include <com/sun/star/animations/XAnimateTransform.hpp>
-#include <com/sun/star/animations/TransitionType.hpp>
-#include <com/sun/star/animations/TransitionSubType.hpp>
 #include <com/sun/star/animations/ValuePair.hpp>
 #include <com/sun/star/animations/AnimationColorSpace.hpp>
 #include <com/sun/star/drawing/FillStyle.hpp>
@@ -52,7 +49,6 @@
 #include <com/sun/star/text/XSimpleText.hpp>
 #include <com/sun/star/animations/XIterateContainer.hpp>
 #include <com/sun/star/presentation/TextAnimationType.hpp>
-#include <com/sun/star/container/XChild.hpp>
 #include <comphelper/processfactory.hxx>
 #include <rtl/ustrbuf.hxx>
 
@@ -61,26 +57,21 @@
 #include <svx/svdotext.hxx>
 #include <editeng/outlobj.hxx>
 #include <editeng/editobj.hxx>
-#include <pptexanimations.hxx>
+#include "pptexanimations.hxx"
 #include <osl/endian.h>
 
 #include <algorithm>
 
-using ::std::map;
 using ::com::sun::star::uno::Any;
-using ::com::sun::star::container::XChild;
 using ::com::sun::star::util::XCloneable;
 using ::com::sun::star::uno::Reference;
 using ::com::sun::star::uno::UNO_QUERY;
 using ::com::sun::star::uno::UNO_QUERY_THROW;
 using ::com::sun::star::uno::Sequence;
-using ::com::sun::star::uno::makeAny;
 using ::com::sun::star::uno::Exception;
-using ::com::sun::star::uno::XInterface;
 using ::com::sun::star::beans::NamedValue;
 using ::com::sun::star::container::XEnumerationAccess;
 using ::com::sun::star::container::XEnumeration;
-using ::com::sun::star::lang::XMultiServiceFactory;
 
 using namespace ::com::sun::star::text;
 using namespace ::com::sun::star::drawing;
@@ -253,7 +244,7 @@ const sal_Char* AnimationExporter::FindTransitionName( const sal_Int16 nType, co
     return pRet;
 }
 
-SvStream& WriteAnimationNode(SvStream& rOut, AnimationNode& rNode )
+SvStream& WriteAnimationNode(SvStream& rOut, AnimationNode const & rNode )
 {
     rOut.WriteInt32( rNode.mnU1 );
     rOut.WriteInt32( rNode.mnRestart );
@@ -287,8 +278,7 @@ sal_Int16 AnimationExporter::GetFillMode( const Reference< XAnimationNode >& xNo
             return nFill;
     }
 
-    if ( ( nFill == AnimationFill::DEFAULT ) ||
-        ( nFill == AnimationFill::INHERIT ) )
+    if ( nFill == AnimationFill::DEFAULT )
     {
         if ( nFill != AnimationFill::AUTO )
             nFill = nFillDefault;
@@ -342,7 +332,7 @@ void AnimationExporter::doexport( const Reference< XDrawPage >& xPage, SvStream&
         if( xRootNode.is() )
         {
             processAfterEffectNodes( xRootNode );
-            exportNode( rStrm, xRootNode, nullptr, DFF_msofbtAnimGroup, 1, 0, false, AnimationFill::AUTO );
+            exportNode( rStrm, xRootNode, DFF_msofbtAnimGroup, 1, 0, false, AnimationFill::AUTO );
         }
     }
 }
@@ -418,8 +408,8 @@ void AnimationExporter::processAfterEffectNodes( const Reference< XAnimationNode
 
 bool AnimationExporter::isAfterEffectNode( const Reference< XAnimationNode >& xNode ) const
 {
-    const std::list< AfterEffectNodePtr >::const_iterator aEnd( maAfterEffectNodes.end() );
-    for (std::list< AfterEffectNodePtr >::const_iterator aIter( maAfterEffectNodes.begin() );
+    const std::vector< AfterEffectNodePtr >::const_iterator aEnd( maAfterEffectNodes.end() );
+    for (std::vector< AfterEffectNodePtr >::const_iterator aIter( maAfterEffectNodes.begin() );
          aIter != aEnd ; ++aIter)
     {
         if( (*aIter)->mxNode == xNode )
@@ -430,8 +420,8 @@ bool AnimationExporter::isAfterEffectNode( const Reference< XAnimationNode >& xN
 
 bool AnimationExporter::hasAfterEffectNode( const Reference< XAnimationNode >& xNode, Reference< XAnimationNode >& xAfterEffectNode ) const
 {
-    const std::list< AfterEffectNodePtr >::const_iterator aEnd( maAfterEffectNodes.end() );
-    for (std::list< AfterEffectNodePtr >::const_iterator aIter( maAfterEffectNodes.begin() );
+    const std::vector< AfterEffectNodePtr >::const_iterator aEnd( maAfterEffectNodes.end() );
+    for (std::vector< AfterEffectNodePtr >::const_iterator aIter( maAfterEffectNodes.begin() );
         aIter != aEnd ; ++aIter)
     {
         if( (*aIter)->mxMaster == xNode )
@@ -481,9 +471,11 @@ bool AnimationExporter::isEmptyNode( const Reference< XAnimationNode >& xNode )
     return true;
 }
 
-void AnimationExporter::exportNode( SvStream& rStrm, Reference< XAnimationNode > xNode, const Reference< XAnimationNode >* pParent, const sal_uInt16 nContainerRecType,
+void AnimationExporter::exportNode( SvStream& rStrm, Reference< XAnimationNode > const & xNode_in, const sal_uInt16 nContainerRecType,
                                     const sal_uInt16 nInstance, const sal_Int32 nGroupLevel, const bool bTakeBackInteractiveSequenceTiming, const sal_Int16 nFDef )
 {
+    auto xNode = xNode_in;
+
     if( (nGroupLevel == 4) && isEmptyNode( xNode ) )
         return;
 
@@ -496,18 +488,17 @@ void AnimationExporter::exportNode( SvStream& rStrm, Reference< XAnimationNode >
     bool bTakeBackInteractiveSequenceTimingForChild = false;
     sal_Int16 nFillDefault = GetFillMode( xNode, nFDef );
 
-    bool bSkipChildren = false;
-
     Reference< XAnimationNode > xAudioNode;
     static sal_uInt32 nAudioGroup;
 
     {
+        bool bSkipChildren = false;
         EscherExContainer aContainer( rStrm, nContainerRecType, nInstance );
         switch( xNode->getType() )
         {
             case AnimationNodeType::CUSTOM :
             {
-                exportAnimNode( rStrm, xNode, pParent, nGroupLevel, nFillDefault );
+                exportAnimNode( rStrm, xNode, nFillDefault );
                 exportAnimPropertySet( rStrm, xNode );
                 exportAnimEvent( rStrm, xNode );
                 exportAnimValue( rStrm, xNode, false );
@@ -516,7 +507,7 @@ void AnimationExporter::exportNode( SvStream& rStrm, Reference< XAnimationNode >
 
             case AnimationNodeType::PAR :
             {
-                exportAnimNode( rStrm, xNode, pParent, nGroupLevel, nFillDefault );
+                exportAnimNode( rStrm, xNode, nFillDefault );
                 exportAnimPropertySet( rStrm, xNode );
                 sal_Int32 nFlags = nGroupLevel == 2 ? 0x10 : 0;
                 if ( bTakeBackInteractiveSequenceTiming )
@@ -528,7 +519,7 @@ void AnimationExporter::exportNode( SvStream& rStrm, Reference< XAnimationNode >
 
             case AnimationNodeType::SEQ :
             {
-                exportAnimNode( rStrm, xNode, pParent, nGroupLevel, nFillDefault );
+                exportAnimNode( rStrm, xNode, nFillDefault );
                 sal_Int16 nNodeType = exportAnimPropertySet( rStrm, xNode );
                 sal_Int32 nFlags = 12;
                 if ( ( nGroupLevel == 1 ) && ( nNodeType == css::presentation::EffectNodeType::INTERACTIVE_SEQUENCE ) )
@@ -580,7 +571,7 @@ void AnimationExporter::exportNode( SvStream& rStrm, Reference< XAnimationNode >
 
             case AnimationNodeType::ANIMATE :
             {
-                exportAnimNode( rStrm, xNode, pParent, nGroupLevel, nFillDefault );
+                exportAnimNode( rStrm, xNode, nFillDefault );
                 exportAnimPropertySet( rStrm, xNode );
                 exportAnimEvent( rStrm, xNode );
                 exportAnimValue( rStrm, xNode, false );
@@ -593,7 +584,7 @@ void AnimationExporter::exportNode( SvStream& rStrm, Reference< XAnimationNode >
                 bool bIsAfterEffectNode( isAfterEffectNode( xNode ) );
                 if( (nGroupLevel != 4) || !bIsAfterEffectNode )
                 {
-                    exportAnimNode( rStrm, xNode, pParent, nGroupLevel, nFillDefault );
+                    exportAnimNode( rStrm, xNode, nFillDefault );
                     exportAnimPropertySet( rStrm, xNode );
                     exportAnimateSet( rStrm, xNode, bIsAfterEffectNode ? AFTEREFFECT_SET : AFTEREFFECT_NONE );
                     exportAnimEvent( rStrm, xNode );
@@ -608,7 +599,7 @@ void AnimationExporter::exportNode( SvStream& rStrm, Reference< XAnimationNode >
 
             case AnimationNodeType::ANIMATEMOTION :
             {
-                exportAnimNode( rStrm, xNode, pParent, nGroupLevel, nFillDefault );
+                exportAnimNode( rStrm, xNode, nFillDefault );
                 exportAnimPropertySet( rStrm, xNode );
                 exportAnimateMotion( rStrm, xNode );
                 exportAnimEvent( rStrm, xNode );
@@ -624,7 +615,7 @@ void AnimationExporter::exportNode( SvStream& rStrm, Reference< XAnimationNode >
                     if( bIsAfterEffectNode )
                         xNode = createAfterEffectNodeClone( xNode );
 
-                    exportAnimNode( rStrm, xNode, pParent, nGroupLevel, nFillDefault );
+                    exportAnimNode( rStrm, xNode, nFillDefault );
                     exportAnimPropertySet( rStrm, xNode );
                     exportAnimateColor( rStrm, xNode, bIsAfterEffectNode ? AFTEREFFECT_COLOR : AFTEREFFECT_NONE );
                     exportAnimEvent( rStrm, xNode );
@@ -639,7 +630,7 @@ void AnimationExporter::exportNode( SvStream& rStrm, Reference< XAnimationNode >
 
             case AnimationNodeType::ANIMATETRANSFORM :
             {
-                exportAnimNode( rStrm, xNode, pParent, nGroupLevel, nFillDefault );
+                exportAnimNode( rStrm, xNode, nFillDefault );
                 exportAnimPropertySet( rStrm, xNode );
                 exportAnimateTransform( rStrm, xNode );
                 exportAnimEvent( rStrm, xNode );
@@ -649,7 +640,7 @@ void AnimationExporter::exportNode( SvStream& rStrm, Reference< XAnimationNode >
 
             case AnimationNodeType::TRANSITIONFILTER :
             {
-                exportAnimNode( rStrm, xNode, pParent, nGroupLevel, nFillDefault );
+                exportAnimNode( rStrm, xNode, nFillDefault );
                 exportAnimPropertySet( rStrm, xNode );
                 exportAnimEvent( rStrm, xNode );
                 exportAnimValue( rStrm, xNode, false );
@@ -659,7 +650,7 @@ void AnimationExporter::exportNode( SvStream& rStrm, Reference< XAnimationNode >
 
             case AnimationNodeType::AUDIO :     // #i58428#
             {
-                exportAnimNode( rStrm, xNode, pParent, nGroupLevel, nFillDefault );
+                exportAnimNode( rStrm, xNode, nFillDefault );
                 exportAnimPropertySet( rStrm, xNode );
 
                 Reference< XAudio > xAudio( xNode, UNO_QUERY );
@@ -693,11 +684,11 @@ void AnimationExporter::exportNode( SvStream& rStrm, Reference< XAnimationNode >
                         }
                         EscherExContainer aAnimateTargetElement( rStrm, DFF_msofbtAnimateTargetElement );
                         {
-                            sal_uInt32 nRefMode = 3;
-                            sal_uInt32 nRefType = 2;
+                            sal_uInt32 const nRefMode = 3;
+                            sal_uInt32 const nRefType = 2;
                             sal_uInt32 nRefId = mrExSoundCollection.GetId( aURL );
-                            sal_Int32 begin = -1;
-                            sal_Int32 end = -1;
+                            sal_Int32 const begin = -1;
+                            sal_Int32 const end = -1;
 
                             EscherExAtom aAnimReference( rStrm, DFF_msofbtAnimReference );
                             rStrm.WriteUInt32( nRefMode ).WriteUInt32( nRefType ).WriteUInt32( nRefId ).WriteInt32( begin ).WriteInt32( end );
@@ -714,7 +705,7 @@ void AnimationExporter::exportNode( SvStream& rStrm, Reference< XAnimationNode >
             Reference< XAnimationNode > xAfterEffectNode;
             if( hasAfterEffectNode( xNode, xAfterEffectNode ) )
             {
-                exportNode( rStrm, xAfterEffectNode, &xNode, DFF_msofbtAnimSubGoup, 1, nGroupLevel + 1, bTakeBackInteractiveSequenceTimingForChild, nFillDefault );
+                exportNode( rStrm, xAfterEffectNode, DFF_msofbtAnimSubGoup, 1, nGroupLevel + 1, bTakeBackInteractiveSequenceTimingForChild, nFillDefault );
             }
 
             Reference< XEnumerationAccess > xEnumerationAccess( xNode, UNO_QUERY );
@@ -734,7 +725,7 @@ void AnimationExporter::exportNode( SvStream& rStrm, Reference< XAnimationNode >
                                 nAudioGroup = mnCurrentGroup;
                             }
                             else
-                                exportNode( rStrm, xChildNode, &xNode, DFF_msofbtAnimGroup, 1, nGroupLevel + 1, bTakeBackInteractiveSequenceTimingForChild, nFillDefault );
+                                exportNode( rStrm, xChildNode, DFF_msofbtAnimGroup, 1, nGroupLevel + 1, bTakeBackInteractiveSequenceTimingForChild, nFillDefault );
                         }
                     }
                 }
@@ -742,7 +733,7 @@ void AnimationExporter::exportNode( SvStream& rStrm, Reference< XAnimationNode >
         }
     }
     if ( xAudioNode.is() )
-        exportNode( rStrm, xAudioNode, &xNode, DFF_msofbtAnimGroup, 1, nGroupLevel, bTakeBackInteractiveSequenceTimingForChild, nFillDefault );
+        exportNode( rStrm, xAudioNode, DFF_msofbtAnimGroup, 1, nGroupLevel, bTakeBackInteractiveSequenceTimingForChild, nFillDefault );
 
     if( xNode->getType() == AnimationNodeType::ITERATE )
         aTarget = Any();
@@ -789,7 +780,7 @@ bool AnimationExporter::GetNodeType( const Reference< XAnimationNode >& xNode, s
 }
 
 void AnimationExporter::exportAnimNode( SvStream& rStrm, const Reference< XAnimationNode >& xNode,
-        const css::uno::Reference< css::animations::XAnimationNode >*, const sal_Int32, const sal_Int16 nFillDefault )
+        const sal_Int16 nFillDefault )
 {
     EscherExAtom    aAnimNodeExAtom( rStrm, DFF_msofbtAnimNode );
     AnimationNode   aAnim;
@@ -836,7 +827,7 @@ void AnimationExporter::exportAnimNode( SvStream& rStrm, const Reference< XAnima
     {
         case AnimationNodeType::PAR :
             aAnim.mnGroupType = mso_Anim_GroupType_PAR;
-            // PASSTROUGH!!! (as it was intended)
+            SAL_FALLTHROUGH;
         case AnimationNodeType::SEQ :
         {
             sal_Int16 nType = 0;
@@ -881,7 +872,7 @@ void AnimationExporter::exportAnimNode( SvStream& rStrm, const Reference< XAnima
     WriteAnimationNode( rStrm, aAnim );
 }
 
-void AnimationExporter::GetUserData( const Sequence< NamedValue >& rUserData, const Any ** pAny, sal_Size nLen )
+void AnimationExporter::GetUserData( const Sequence< NamedValue >& rUserData, const Any ** pAny, std::size_t nLen )
 {
     // storing user data into pAny, to allow direct access later
     memset( pAny, 0, nLen );
@@ -909,7 +900,7 @@ void AnimationExporter::GetUserData( const Sequence< NamedValue >& rUserData, co
         }
         else if ( p->Name == "master-element" )
         {
-        pAny[ DFF_ANIM_AFTEREFFECT ] = &(p->Value);;
+        pAny[ DFF_ANIM_AFTEREFFECT ] = &(p->Value);
         }
         p++;
     }
@@ -998,7 +989,7 @@ sal_Int16 AnimationExporter::exportAnimPropertySet( SvStream& rStrm, const Refer
                 case css::presentation::EffectNodeType::TIMING_ROOT : nPPTNodeType = DFF_ANIM_NODE_TYPE_TIMING_ROOT; break;
                 case css::presentation::EffectNodeType::INTERACTIVE_SEQUENCE: nPPTNodeType = DFF_ANIM_NODE_TYPE_INTERACTIVE_SEQ; break;
             }
-            exportAnimPropertyuInt32( rStrm, DFF_ANIM_NODE_TYPE, nPPTNodeType, TRANSLATE_NONE );
+            exportAnimPropertyuInt32( rStrm, DFF_ANIM_NODE_TYPE, nPPTNodeType );
         }
     }
     sal_uInt32 nPresetId = 0;
@@ -1045,11 +1036,11 @@ sal_Int16 AnimationExporter::exportAnimPropertySet( SvStream& rStrm, const Refer
         }
     }
     if ( bPresetId )
-        exportAnimPropertyuInt32( rStrm, DFF_ANIM_PRESET_ID, nPresetId, TRANSLATE_NONE );
+        exportAnimPropertyuInt32( rStrm, DFF_ANIM_PRESET_ID, nPresetId );
     if ( bPresetSubType )
-        exportAnimPropertyuInt32( rStrm, DFF_ANIM_PRESET_SUB_TYPE, nPresetSubType, TRANSLATE_NONE );
+        exportAnimPropertyuInt32( rStrm, DFF_ANIM_PRESET_SUB_TYPE, nPresetSubType );
     if ( bPresetClass )
-        exportAnimPropertyuInt32( rStrm, DFF_ANIM_PRESET_CLASS, nPresetClass, TRANSLATE_NONE );
+        exportAnimPropertyuInt32( rStrm, DFF_ANIM_PRESET_CLASS, nPresetClass );
 
     if ( pAny[ DFF_ANIM_ID ] )
     {
@@ -1060,14 +1051,14 @@ sal_Int16 AnimationExporter::exportAnimPropertySet( SvStream& rStrm, const Refer
     {
         bool bAfterEffect = false;
         if ( *pAny[ DFF_ANIM_AFTEREFFECT ] >>= bAfterEffect )
-            exportAnimPropertyByte( rStrm, DFF_ANIM_AFTEREFFECT, int(bAfterEffect), TRANSLATE_NONE );
+            exportAnimPropertyByte( rStrm, DFF_ANIM_AFTEREFFECT, int(bAfterEffect) );
     }
 
     if ( pAny[ DFF_ANIM_RUNTIMECONTEXT ] )
     {
         sal_Int32 nRunTimeContext = 0;
         if ( *pAny[ DFF_ANIM_RUNTIMECONTEXT ] >>= nRunTimeContext )
-            exportAnimPropertyuInt32( rStrm, DFF_ANIM_RUNTIMECONTEXT, nRunTimeContext, TRANSLATE_NONE );
+            exportAnimPropertyuInt32( rStrm, DFF_ANIM_RUNTIMECONTEXT, nRunTimeContext );
     }
     if ( pAny[ DFF_ANIM_PATH_EDIT_MODE ] )
     {
@@ -1081,7 +1072,7 @@ sal_Int16 AnimationExporter::exportAnimPropertySet( SvStream& rStrm, const Refer
         {
 
             bool bDirection = !xColor->getDirection();
-            exportAnimPropertyuInt32( rStrm, DFF_ANIM_DIRECTION, bDirection ? 1 : 0, TRANSLATE_NONE );
+            exportAnimPropertyuInt32( rStrm, DFF_ANIM_DIRECTION, bDirection ? 1 : 0 );
         }
     }
 
@@ -1089,14 +1080,14 @@ sal_Int16 AnimationExporter::exportAnimPropertySet( SvStream& rStrm, const Refer
     {
         sal_Int32 nOverride = 0;
         if ( *pAny[ DFF_ANIM_OVERRIDE ] >>= nOverride )
-            exportAnimPropertyuInt32( rStrm, DFF_ANIM_OVERRIDE, nOverride, TRANSLATE_NONE );
+            exportAnimPropertyuInt32( rStrm, DFF_ANIM_OVERRIDE, nOverride );
     }
 
     if ( pAny[ DFF_ANIM_MASTERREL ] )
     {
         sal_Int32 nMasterRel = 0;
         if ( *pAny[ DFF_ANIM_MASTERREL ] >>= nMasterRel )
-            exportAnimPropertyuInt32( rStrm, DFF_ANIM_MASTERREL, nMasterRel, TRANSLATE_NONE );
+            exportAnimPropertyuInt32( rStrm, DFF_ANIM_MASTERREL, nMasterRel );
     }
 
 /* todo
@@ -1139,7 +1130,7 @@ bool AnimationExporter::exportAnimProperty( SvStream& rStrm, const sal_uInt16 nP
                 sal_Int32 nVal = 0;
                 if ( rAny >>= nVal )
                 {
-                    exportAnimPropertyuInt32( rStrm, nPropertyId, nVal, eTranslateMode );
+                    exportAnimPropertyuInt32( rStrm, nPropertyId, nVal );
                     bRet = true;
                 }
             }
@@ -1150,7 +1141,7 @@ bool AnimationExporter::exportAnimProperty( SvStream& rStrm, const sal_uInt16 nP
                 double fVal = 0.0;
                 if ( rAny >>= fVal )
                 {
-                    exportAnimPropertyFloat( rStrm, nPropertyId, fVal, eTranslateMode );
+                    exportAnimPropertyFloat( rStrm, nPropertyId, fVal );
                     bRet = true;
                 }
             }
@@ -1162,14 +1153,12 @@ bool AnimationExporter::exportAnimProperty( SvStream& rStrm, const sal_uInt16 nP
                 {
                     if ( eTranslateMode & TRANSLATE_NUMBER_TO_STRING )
                     {
-                        Any aAny;
                         OUString aNumber( OUString::number( fVal ) );
-                        aAny <<= aNumber;
                         exportAnimPropertyString( rStrm, nPropertyId, aNumber, eTranslateMode );
                     }
                     else
                     {
-                        exportAnimPropertyFloat( rStrm, nPropertyId, fVal, eTranslateMode );
+                        exportAnimPropertyFloat( rStrm, nPropertyId, fVal );
                         bRet = true;
                     }
                 }
@@ -1194,36 +1183,32 @@ bool AnimationExporter::exportAnimProperty( SvStream& rStrm, const sal_uInt16 nP
 void AnimationExporter::exportAnimPropertyString( SvStream& rStrm, const sal_uInt16 nPropertyId, const OUString& rVal, const TranslateMode eTranslateMode )
 {
     EscherExAtom aExAtom( rStrm, DFF_msofbtAnimAttributeValue, nPropertyId );
-    sal_uInt8 nType = DFF_ANIM_PROP_TYPE_UNISTRING;
-    rStrm.WriteUChar( nType );
+    rStrm.WriteUChar( DFF_ANIM_PROP_TYPE_UNISTRING );
     OUString aStr( rVal );
     if ( eTranslateMode != TRANSLATE_NONE )
         ImplTranslateAttribute( aStr, eTranslateMode );
     writeZString( rStrm, aStr );
 }
 
-void AnimationExporter::exportAnimPropertyFloat( SvStream& rStrm, const sal_uInt16 nPropertyId, const double& rVal, const TranslateMode )
+void AnimationExporter::exportAnimPropertyFloat( SvStream& rStrm, const sal_uInt16 nPropertyId, const double& rVal )
 {
     EscherExAtom aExAtom( rStrm, DFF_msofbtAnimAttributeValue, nPropertyId );
-    sal_uInt8 nType = DFF_ANIM_PROP_TYPE_FLOAT;
     float fFloat = (float)rVal;
-    rStrm.WriteUChar( nType )
+    rStrm.WriteUChar( DFF_ANIM_PROP_TYPE_FLOAT )
          .WriteFloat( fFloat );
 }
 
-void AnimationExporter::exportAnimPropertyuInt32( SvStream& rStrm, const sal_uInt16 nPropertyId, const sal_uInt32 nVal, const TranslateMode )
+void AnimationExporter::exportAnimPropertyuInt32( SvStream& rStrm, const sal_uInt16 nPropertyId, const sal_uInt32 nVal )
 {
     EscherExAtom aExAtom( rStrm, DFF_msofbtAnimAttributeValue, nPropertyId );
-    sal_uInt8 nType = DFF_ANIM_PROP_TYPE_INT32 ;
-    rStrm.WriteUChar( nType )
+    rStrm.WriteUChar( DFF_ANIM_PROP_TYPE_INT32 )
          .WriteUInt32( nVal );
 }
 
-void AnimationExporter::exportAnimPropertyByte( SvStream& rStrm, const sal_uInt16 nPropertyId, const sal_uInt8 nVal, const TranslateMode )
+void AnimationExporter::exportAnimPropertyByte( SvStream& rStrm, const sal_uInt16 nPropertyId, const sal_uInt8 nVal )
 {
     EscherExAtom aExAtom( rStrm, DFF_msofbtAnimAttributeValue, nPropertyId );
-    sal_uInt8 nType = DFF_ANIM_PROP_TYPE_BYTE;
-    rStrm.WriteUChar( nType )
+    rStrm.WriteUChar( DFF_ANIM_PROP_TYPE_BYTE )
          .WriteUChar( nVal );
 }
 
@@ -1239,11 +1224,11 @@ void AnimationExporter::exportAnimAction( SvStream& rStrm, const Reference< XAni
 {
     EscherExAtom aExAtom( rStrm, DFF_msofbtAnimAction );
 
-    sal_Int32 nConcurrent = 1;
-    sal_Int32 nNextAction = 1;
+    sal_Int32 const nConcurrent = 1;
+    sal_Int32 const nNextAction = 1;
     sal_Int32 nEndSync = 0;
-    sal_Int32 nU4 = 0;
-    sal_Int32 nU5 = 3;
+    sal_Int32 const nU4 = 0;
+    sal_Int32 const nU5 = 3;
 
     sal_Int16 nAnimationEndSync = 0;
     if ( xNode->getEndSync() >>= nAnimationEndSync )
@@ -1292,10 +1277,8 @@ void AnimationExporter::exportAnimEvent( SvStream& rStrm, const Reference< XAnim
                         Reference< XEnumeration > xE( xEA->createEnumeration(), UNO_QUERY_THROW );
                         if ( xE.is() && xE->hasMoreElements() )
                         {
-                            {
-                                Reference< XAnimationNode > xClickNode( xE->nextElement(), UNO_QUERY );
-                                aAny = xClickNode->getBegin();
-                            }
+                            Reference< XAnimationNode > xClickNode( xE->nextElement(), UNO_QUERY );
+                            aAny = xClickNode->getBegin();
                         }
                     }
                     else if ( nFlags & 0x40 )
@@ -1305,7 +1288,7 @@ void AnimationExporter::exportAnimEvent( SvStream& rStrm, const Reference< XAnim
                     else
                     {
                         aAny = xNode->getBegin();
-                        if ( nFlags & 0x10 )    // replace ON_NEXT with IDEFINITE
+                        if ( nFlags & 0x10 )    // replace ON_NEXT with INDEFINITE
                         {
                             if ( ( aAny >>= aEvent ) && ( aEvent.Trigger == EventTrigger::ON_NEXT ) )
                             {
@@ -1416,7 +1399,6 @@ Any AnimationExporter::convertAnimateValue( const Any& rSourceValue, const OUStr
         }
     }
     else if ( rAttributeName == "Rotate"         // "r" or "style.rotation" ?
-            || rAttributeName == "SkewX"
             || rAttributeName == "Opacity"
             || rAttributeName == "CharHeight"
         )
@@ -1436,23 +1418,23 @@ Any AnimationExporter::convertAnimateValue( const Any& rSourceValue, const OUStr
         OUString aP( "," );
         if ( rSourceValue >>= aHSL )
         {
-            aDest += "hsl(";
-            aDest += OUString::number( (sal_Int32)( aHSL[ 0 ] / ( 360.0 / 255 ) ) );
-            aDest += aP;
-            aDest += OUString::number( (sal_Int32)( aHSL[ 1 ] * 255.0 ) );
-            aDest += aP;
-            aDest += OUString::number( (sal_Int32)( aHSL[ 2 ] * 255.0 ) );
-            aDest += ")";
+            aDest += "hsl("
+                  +  OUString::number( (sal_Int32)( aHSL[ 0 ] / ( 360.0 / 255 ) ) )
+                  +  aP
+                  +  OUString::number( (sal_Int32)( aHSL[ 1 ] * 255.0 ) )
+                  +  aP
+                  +  OUString::number( (sal_Int32)( aHSL[ 2 ] * 255.0 ) )
+                  +  ")";
         }
         else if ( rSourceValue >>= nColor )
         {
-            aDest += "rgb(";
-            aDest += OUString::number( ( (sal_Int8)nColor ) );
-            aDest += aP;
-            aDest += OUString::number( ( (sal_Int8)( nColor >> 8 ) ) );
-            aDest += aP;
-            aDest += OUString::number( ( (sal_Int8)( nColor >> 16 ) ) );
-            aDest += ")";
+            aDest += "rgb("
+                  +  OUString::number( ( (sal_Int8)nColor ) )
+                  +  aP
+                  +  OUString::number( ( (sal_Int8)( nColor >> 8 ) ) )
+                  +  aP
+                  +  OUString::number( ( (sal_Int8)( nColor >> 16 ) ) )
+                  +  ")";
         }
     }
     else if ( rAttributeName == "FillStyle" )
@@ -1466,6 +1448,17 @@ Any AnimationExporter::convertAnimateValue( const Any& rSourceValue, const OUStr
                 aDest += "solid";
         }
     }
+    else if (rAttributeName == "FillOn")
+    {
+        bool bFillOn;
+        if ( rSourceValue >>= bFillOn )
+        {
+            if ( bFillOn )
+                aDest += "true";
+            else
+                aDest += "false";
+        }
+    }
     else if ( rAttributeName == "LineStyle" )
     {
         css::drawing::LineStyle eLineStyle;
@@ -1537,8 +1530,8 @@ void AnimationExporter::exportAnimateSet( SvStream& rStrm, const Reference< XAni
         EscherExContainer aAnimateSet( rStrm, DFF_msofbtAnimateSet, 0 );
         {
             EscherExAtom aAnimateSetData( rStrm, DFF_msofbtAnimateSetData );
-            sal_uInt32 nId1 = 1;            // ??
-            sal_uInt32 nId2 = 1;            // ??
+            sal_uInt32 const nId1 = 1;            // ??
+            sal_uInt32 const nId2 = 1;            // ??
             rStrm.WriteUInt32( nId1 ).WriteUInt32( nId2 );
         }
         Any aConvertedValue( convertAnimateValue( xSet->getTo(), xSet->getAttributeName() ) );
@@ -1614,7 +1607,6 @@ void AnimationExporter::exportAnimate( SvStream& rStrm, const Reference< XAnimat
             sal_uInt32 nBits = 0x38;
             sal_Int16 nTmp = xAnimate->getCalcMode();
             sal_uInt32 nCalcMode = /* (nTmp == AnimationCalcMode::FORMULA) ? 2 : */ (nTmp == AnimationCalcMode::LINEAR) ? 1 : 0;
-            nTmp = xAnimate->getValueType();
             sal_uInt32 nValueType = GetValueTypeForAttributeName( xAnimate->getAttributeName() );
 
             if ( aBy.hasValue() )
@@ -1655,7 +1647,7 @@ void AnimationExporter::exportAnimateTarget( SvStream& rStrm, const Reference< X
             sal_uInt32 nBits = 0;
             sal_uInt32 nAdditive = 0;
             sal_uInt32 nAccumulate = 0;
-            sal_uInt32 nTransformType = 0;
+            sal_uInt32 const nTransformType = 0;
             if ( xAnimate.is() )
             {
                 if ( !xAnimate->getAttributeName().isEmpty() )
@@ -1706,11 +1698,11 @@ void AnimationExporter::exportAnimateTarget( SvStream& rStrm, const Reference< X
         if( nAfterEffectType != AFTEREFFECT_NONE )
         {
             EscherExContainer aAnimPropertySet( rStrm, DFF_msofbtAnimPropertySet );
-            exportAnimPropertyuInt32( rStrm, 6, 1, TRANSLATE_NONE );
+            exportAnimPropertyuInt32( rStrm, 6, 1 );
             if( nAfterEffectType == AFTEREFFECT_COLOR )
             {
-                exportAnimPropertyuInt32( rStrm, 4, 0, TRANSLATE_NONE );
-                exportAnimPropertyuInt32( rStrm, 5, 0, TRANSLATE_NONE );
+                exportAnimPropertyuInt32( rStrm, 4, 0 );
+                exportAnimPropertyuInt32( rStrm, 5, 0 );
             }
         }
         exportAnimateTargetElement( rStrm, aTarget.hasValue() ? aTarget : xAnimate->getTarget(), false );
@@ -1787,8 +1779,8 @@ void AnimationExporter::exportAnimateTargetElement( SvStream& rStrm, const Any&
         {
             EscherExAtom aAnimReference( rStrm, DFF_msofbtAnimReference );
 
-            sal_uInt32 nRefType = 1;    // TODO: nRefType == 2 -> Sound;
-            sal_uInt32 nRefId = ((EscherSolverContainer&)mrSolverContainer).GetShapeId( xShape );
+            sal_uInt32 const nRefType = 1;    // TODO: nRefType == 2 -> Sound;
+            sal_uInt32 nRefId = mrSolverContainer.GetShapeId( xShape );
 
             rStrm.WriteUInt32( nRefMode )
                  .WriteUInt32( nRefType )
@@ -1863,7 +1855,7 @@ void AnimationExporter::exportAnimValue( SvStream& rStrm, const Reference< XAnim
     if ( fRepeatCount != 0.0 )
     {
         EscherExAtom aExAtom( rStrm, DFF_msofbtAnimValue );
-        sal_uInt32 nType = 0;
+        sal_uInt32 const nType = 0;
         rStrm.WriteUInt32( nType )
              .WriteFloat( fRepeatCount );
     }
@@ -1872,7 +1864,7 @@ void AnimationExporter::exportAnimValue( SvStream& rStrm, const Reference< XAnim
     if ( bExportAlways || ( fAccelerate != 0.0 ) )
     {
         EscherExAtom aExAtom( rStrm, DFF_msofbtAnimValue );
-        sal_uInt32 nType = 3;
+        sal_uInt32 const nType = 3;
         rStrm.WriteUInt32( nType )
              .WriteFloat( fAccelerate );
     }
@@ -1882,7 +1874,7 @@ void AnimationExporter::exportAnimValue( SvStream& rStrm, const Reference< XAnim
     if ( bExportAlways || ( fDecelerate != 0.0 ) )
     {
         EscherExAtom aExAtom( rStrm, DFF_msofbtAnimValue );
-        sal_uInt32 nType = 4;
+        sal_uInt32 const nType = 4;
         rStrm.WriteUInt32( nType )
              .WriteFloat( fDecelerate );
     }
@@ -1892,7 +1884,7 @@ void AnimationExporter::exportAnimValue( SvStream& rStrm, const Reference< XAnim
     if ( bExportAlways || bAutoReverse )
     {
         EscherExAtom aExAtom( rStrm, DFF_msofbtAnimValue );
-        sal_uInt32 nType = 5;
+        sal_uInt32 const nType = 5;
         sal_uInt32 nVal  = bAutoReverse ? 1 : 0;
         rStrm.WriteUInt32( nType )
              .WriteUInt32( nVal );
@@ -1907,8 +1899,8 @@ void AnimationExporter::exportTransitionFilter( SvStream& rStrm, const Reference
         EscherExContainer aAnimateFilter( rStrm, DFF_msofbtAnimateFilter );
         {
             EscherExAtom aAnimateFilterData( rStrm, DFF_msofbtAnimateFilterData );
-            sal_uInt32 nBits = 3;       // bit 0 -> use AnimAttributeValue
-                                        // bit 1 -> use nTransition
+            sal_uInt32 const nBits = 3;       // bit 0 -> use AnimAttributeValue
+                                              // bit 1 -> use nTransition
 
             sal_uInt32 nTransition = xFilter->getMode() ? 0 : 1;
             rStrm.WriteUInt32( nBits )
@@ -1933,14 +1925,14 @@ void AnimationExporter::exportAnimateMotion( SvStream& rStrm, const Reference< X
         {
             {   //SJ: Ignored from import filter
                 EscherExAtom aAnimateMotionData( rStrm, DFF_msofbtAnimateMotionData );
-                sal_uInt32 nBits = 0x98;
-                sal_uInt32 nOrigin = 0x2;
-                float fByX = 100.0; // nBits&1
-                float fByY = 100.0; // nBits&1
-                float fFromX = 0.0; // nBits&2
-                float fFromY = 0.0; // nBits&2
-                float fToX = 100.0; // nBits&4
-                float fToY = 100.0; // nBits&4
+                sal_uInt32 const nBits = 0x98;
+                sal_uInt32 const nOrigin = 0x2;
+                float const fByX = 100.0; // nBits&1
+                float const fByY = 100.0; // nBits&1
+                float const fFromX = 0.0; // nBits&2
+                float const fFromY = 0.0; // nBits&2
+                float const fToX = 100.0; // nBits&4
+                float const fToY = 100.0; // nBits&4
                 rStrm.WriteUInt32( nBits ).WriteFloat( fByX ).WriteFloat( fByY ).WriteFloat( fFromX ).WriteFloat( fFromY ).WriteFloat( fToX ).WriteFloat( fToY ).WriteUInt32( nOrigin );
             }
 
@@ -1966,7 +1958,7 @@ void AnimationExporter::exportAnimateTransform( SvStream& rStrm, const Reference
             {
                 EscherExAtom aAnimateScaleData( rStrm, DFF_msofbtAnimateScaleData );
                 sal_uInt32 nBits = 0;
-                sal_uInt32 nZoomContents = 1;
+                sal_uInt32 const nZoomContents = 1;
                 float fByX = 100.0;
                 float fByY = 100.0;
                 float fFromX = 0.0;
@@ -2018,7 +2010,7 @@ void AnimationExporter::exportAnimateTransform( SvStream& rStrm, const Reference
             {
                 EscherExAtom aAnimateRotationData( rStrm, DFF_msofbtAnimateRotationData );
                 sal_uInt32 nBits = 0;
-                sal_uInt32 nU1 = 0;
+                sal_uInt32 const nU1 = 0;
                 float fBy = 360.0;
                 float fFrom = 0.0;
                 float fTo = 360.0;
@@ -2060,7 +2052,7 @@ bool AnimationExporter::getColorAny( const Any& rAny, const sal_Int16 nColorSpac
     {
         rA = (sal_uInt8)( nColor >> 16 );
         rB = (sal_uInt8)( nColor >> 8 );
-        rC = (sal_uInt8)( nColor );
+        rC = (sal_uInt8) nColor;
     }
     else if ( rAny >>= aHSL )   // HSL
     {
@@ -2130,9 +2122,9 @@ void AnimationExporter::exportIterate( SvStream& rStrm, const Reference< XAnimat
 
         float       fInterval = 10.0;
         sal_Int32   nTextUnitEffect = 0;
-        sal_Int32   nU1 = 1;
-        sal_Int32   nU2 = 1;
-        sal_Int32   nU3 = 0xe;
+        sal_Int32 const nU1 = 1;
+        sal_Int32 const nU2 = 1;
+        sal_Int32 const nU3 = 0xe;
 
         sal_Int16 nIterateType = xIterate->getIterateType();
         switch( nIterateType )
