@@ -17,13 +17,12 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "AccessibleDocumentViewBase.hxx"
+#include <AccessibleDocumentViewBase.hxx>
 #include <com/sun/star/drawing/XDrawPage.hpp>
 #include <com/sun/star/drawing/XDrawView.hpp>
 #include <com/sun/star/drawing/XShapes.hpp>
 #include <com/sun/star/container/XChild.hpp>
 #include <com/sun/star/frame/XController.hpp>
-#include <com/sun/star/frame/XFrame.hpp>
 #include <com/sun/star/document/XEventBroadcaster.hpp>
 #include <com/sun/star/beans/XPropertySet.hpp>
 #include <com/sun/star/accessibility/AccessibleEventId.hpp>
@@ -39,16 +38,16 @@
 #include <svx/svdmodel.hxx>
 #include <svx/unoapi.hxx>
 #include <toolkit/helper/vclunohelper.hxx>
-#include "Window.hxx"
+#include <Window.hxx>
 #include <vcl/svapp.hxx>
-#include "OutlineViewShell.hxx"
+#include <OutlineViewShell.hxx>
 
 #include <svx/svdlayer.hxx>
 #include <editeng/editobj.hxx>
-#include "LayerTabBar.hxx"
+#include <LayerTabBar.hxx>
 #include <svtools/colorcfg.hxx>
-#include "ViewShell.hxx"
-#include "View.hxx"
+#include <ViewShell.hxx>
+#include <View.hxx>
 
 using namespace ::com::sun::star;
 using namespace ::com::sun::star::accessibility;
@@ -63,15 +62,15 @@ AccessibleDocumentViewBase::AccessibleDocumentViewBase (
     const uno::Reference<frame::XController>& rxController,
     const uno::Reference<XAccessible>& rxParent)
     : AccessibleContextBase (rxParent,
-                             pViewShell->GetDoc()->GetDocumentType() == DOCUMENT_TYPE_IMPRESS ?
+                             pViewShell->GetDoc()->GetDocumentType() == DocumentType::Impress ?
                                      AccessibleRole::DOCUMENT_PRESENTATION :
                                      AccessibleRole::DOCUMENT),
       mpWindow (pSdWindow),
       mxController (rxController),
-      mxModel (NULL),
+      mxModel (nullptr),
       maViewForwarder (
         static_cast<SdrPaintView*>(pViewShell->GetView()),
-        *static_cast<OutputDevice*>(pSdWindow))
+        *pSdWindow)
 {
     if (mxController.is())
         mxModel = mxController->getModel();
@@ -89,19 +88,16 @@ AccessibleDocumentViewBase::AccessibleDocumentViewBase (
     mpViewShell = pViewShell;
 }
 
-
-
-
-AccessibleDocumentViewBase::~AccessibleDocumentViewBase (void)
+AccessibleDocumentViewBase::~AccessibleDocumentViewBase()
 {
     // At this place we should be disposed.  You may want to add a
     // corresponding assertion into the destructor of a derived class.
+
+    SolarMutexGuard g;
+    mpWindow.reset();
 }
 
-
-
-
-void AccessibleDocumentViewBase::Init (void)
+void AccessibleDocumentViewBase::Init()
 {
     // Finish the initialization of the shape tree info container.
     maShapeTreeInfo.SetDocumentWindow (this);
@@ -116,8 +112,7 @@ void AccessibleDocumentViewBase::Init (void)
     uno::Reference<drawing::XShapes> xShapeList;
     uno::Reference<drawing::XDrawView> xView (mxController, uno::UNO_QUERY);
     if (xView.is())
-        xShapeList = uno::Reference<drawing::XShapes> (
-            xView->getCurrentPage(), uno::UNO_QUERY);
+        xShapeList.set( xView->getCurrentPage(), uno::UNO_QUERY);
 
     // Register this object as dispose event listener at the model.
     if (mxModel.is())
@@ -138,8 +133,8 @@ void AccessibleDocumentViewBase::Init (void)
 
     // Register at VCL Window to be informed of activated and deactivated
     // OLE objects.
-    Window* pWindow = maShapeTreeInfo.GetWindow();
-    if (pWindow != NULL)
+    vcl::Window* pWindow = maShapeTreeInfo.GetWindow();
+    if (pWindow != nullptr)
     {
         maWindowLink = LINK(
             this, AccessibleDocumentViewBase, WindowChildEventListener);
@@ -149,7 +144,7 @@ void AccessibleDocumentViewBase::Init (void)
         sal_uInt16 nCount = pWindow->GetChildCount();
         for (sal_uInt16 i=0; i<nCount; i++)
         {
-            Window* pChildWindow = pWindow->GetChild (i);
+            vcl::Window* pChildWindow = pWindow->GetChild (i);
             if (pChildWindow &&
                 (AccessibleRole::EMBEDDED_OBJECT
                     ==pChildWindow->GetAccessibleRole()))
@@ -163,40 +158,32 @@ void AccessibleDocumentViewBase::Init (void)
         SetState(AccessibleStateType::EDITABLE);
 }
 
-
-
-
 IMPL_LINK(AccessibleDocumentViewBase, WindowChildEventListener,
-    VclSimpleEvent*, pEvent)
+    VclWindowEvent&, rEvent, void)
 {
-    OSL_ASSERT(pEvent!=NULL && pEvent->ISA(VclWindowEvent));
-    if (pEvent!=NULL && pEvent->ISA(VclWindowEvent))
-    {
-        VclWindowEvent* pWindowEvent = static_cast<VclWindowEvent*>(pEvent);
         //      DBG_ASSERT( pVclEvent->GetWindow(), "Window???" );
-        switch (pWindowEvent->GetId())
+        switch (rEvent.GetId())
         {
-            case VCLEVENT_OBJECT_DYING:
+            case VclEventId::ObjectDying:
             {
                 // Window is dying.  Unregister from VCL Window.
                 // This is also attempted in the disposing() method.
-                Window* pWindow = maShapeTreeInfo.GetWindow();
-                Window* pDyingWindow = static_cast<Window*>(
-                    pWindowEvent->GetWindow());
-                if (pWindow==pDyingWindow && pWindow!=NULL && maWindowLink.IsSet())
+                vcl::Window* pWindow = maShapeTreeInfo.GetWindow();
+                vcl::Window* pDyingWindow = rEvent.GetWindow();
+                if (pWindow==pDyingWindow && pWindow!=nullptr && maWindowLink.IsSet())
                 {
                     pWindow->RemoveChildEventListener (maWindowLink);
-                    maWindowLink = Link();
+                    maWindowLink = Link<VclWindowEvent&,void>();
                 }
             }
             break;
 
-            case VCLEVENT_WINDOW_SHOW:
+            case VclEventId::WindowShow:
             {
                 // A new window has been created.  Is it an OLE object?
-                Window* pChildWindow = static_cast<Window*>(
-                    pWindowEvent->GetData());
-                if (pChildWindow!=NULL
+                vcl::Window* pChildWindow = static_cast<vcl::Window*>(
+                    rEvent.GetData());
+                if (pChildWindow!=nullptr
                     && (pChildWindow->GetAccessibleRole()
                         == AccessibleRole::EMBEDDED_OBJECT))
                 {
@@ -205,55 +192,44 @@ IMPL_LINK(AccessibleDocumentViewBase, WindowChildEventListener,
             }
             break;
 
-            case VCLEVENT_WINDOW_HIDE:
+            case VclEventId::WindowHide:
             {
                 // A window has been destroyed.  Has that been an OLE
                 // object?
-                Window* pChildWindow = static_cast<Window*>(
-                    pWindowEvent->GetData());
-                if (pChildWindow!=NULL
+                vcl::Window* pChildWindow = static_cast<vcl::Window*>(
+                    rEvent.GetData());
+                if (pChildWindow!=nullptr
                     && (pChildWindow->GetAccessibleRole()
                         == AccessibleRole::EMBEDDED_OBJECT))
                 {
-                    SetAccessibleOLEObject (NULL);
+                    SetAccessibleOLEObject (nullptr);
                 }
             }
             break;
+
+            default: break;
         }
-    }
-
-    return 0;
 }
 
-
-
-
 //=====  IAccessibleViewForwarderListener  ====================================
 
-void AccessibleDocumentViewBase::ViewForwarderChanged(ChangeType, const IAccessibleViewForwarder* )
+void AccessibleDocumentViewBase::ViewForwarderChanged()
 {
     // Empty
 }
 
-
-
-
 //=====  XAccessibleContext  ==================================================
 
 Reference<XAccessible> SAL_CALL
-       AccessibleDocumentViewBase::getAccessibleParent (void)
-    throw (uno::RuntimeException, std::exception)
+       AccessibleDocumentViewBase::getAccessibleParent()
 {
     ThrowIfDisposed ();
 
     return AccessibleContextBase::getAccessibleParent();
 }
 
-
-
 sal_Int32 SAL_CALL
-    AccessibleDocumentViewBase::getAccessibleChildCount (void)
-    throw (uno::RuntimeException, std::exception)
+    AccessibleDocumentViewBase::getAccessibleChildCount()
 {
     ThrowIfDisposed ();
 
@@ -263,12 +239,8 @@ sal_Int32 SAL_CALL
         return 0;
 }
 
-
-
-
 Reference<XAccessible> SAL_CALL
     AccessibleDocumentViewBase::getAccessibleChild (sal_Int32 nIndex)
-    throw (uno::RuntimeException, lang::IndexOutOfBoundsException, std::exception)
 {
     ThrowIfDisposed ();
 
@@ -277,12 +249,9 @@ Reference<XAccessible> SAL_CALL
         if (nIndex == 0)
             return mxAccessibleOLEObject;
 
-    throw lang::IndexOutOfBoundsException ( "no child with index " + OUString::number(nIndex), NULL);
+    throw lang::IndexOutOfBoundsException ( "no child with index " + OUString::number(nIndex) );
 }
 
-
-
-
 //=====  XAccessibleComponent  ================================================
 
 /** Iterate over all children and test whether the specified point lies
@@ -292,7 +261,6 @@ Reference<XAccessible> SAL_CALL
 uno::Reference<XAccessible > SAL_CALL
     AccessibleDocumentViewBase::getAccessibleAtPoint (
         const awt::Point& aPoint)
-    throw (uno::RuntimeException, std::exception)
 {
     ThrowIfDisposed ();
 
@@ -327,17 +295,13 @@ uno::Reference<XAccessible > SAL_CALL
     return xChildAtPosition;
 }
 
-
-
-
 awt::Rectangle SAL_CALL
-    AccessibleDocumentViewBase::getBounds (void)
-    throw (::com::sun::star::uno::RuntimeException, std::exception)
+    AccessibleDocumentViewBase::getBounds()
 {
     ThrowIfDisposed ();
 
     // Transform visible area into screen coordinates.
-    ::Rectangle aVisibleArea (
+    ::tools::Rectangle aVisibleArea (
         maShapeTreeInfo.GetViewForwarder()->GetVisibleArea());
     ::Point aPixelTopLeft (
         maShapeTreeInfo.GetViewForwarder()->LogicToPixel (
@@ -366,24 +330,16 @@ awt::Rectangle SAL_CALL
         aPixelSize.Y());
 }
 
-
-
-
 awt::Point SAL_CALL
-    AccessibleDocumentViewBase::getLocation (void)
-    throw (uno::RuntimeException, std::exception)
+    AccessibleDocumentViewBase::getLocation()
 {
     ThrowIfDisposed ();
     awt::Rectangle aBoundingBox (getBounds());
     return awt::Point (aBoundingBox.X, aBoundingBox.Y);
 }
 
-
-
-
 awt::Point SAL_CALL
-    AccessibleDocumentViewBase::getLocationOnScreen (void)
-    throw (uno::RuntimeException, std::exception)
+    AccessibleDocumentViewBase::getLocationOnScreen()
 {
     ThrowIfDisposed ();
     ::Point aLogicalPoint (maShapeTreeInfo.GetViewForwarder()->GetVisibleArea().TopLeft());
@@ -391,17 +347,13 @@ awt::Point SAL_CALL
     return awt::Point (aPixelPoint.X(), aPixelPoint.Y());
 }
 
-
-
-
 awt::Size SAL_CALL
-    AccessibleDocumentViewBase::getSize (void)
-    throw (uno::RuntimeException, std::exception)
+    AccessibleDocumentViewBase::getSize()
 {
     ThrowIfDisposed ();
 
     // Transform visible area into screen coordinates.
-    ::Rectangle aVisibleArea (
+    ::tools::Rectangle aVisibleArea (
         maShapeTreeInfo.GetViewForwarder()->GetVisibleArea());
     ::Point aPixelTopLeft (
         maShapeTreeInfo.GetViewForwarder()->LogicToPixel (
@@ -414,14 +366,10 @@ awt::Size SAL_CALL
     return awt::Size (aPixelSize.X(), aPixelSize.Y());
 }
 
-
-
-
 //=====  XInterface  ==========================================================
 
 uno::Any SAL_CALL
     AccessibleDocumentViewBase::queryInterface (const uno::Type & rType)
-    throw (uno::RuntimeException, std::exception)
 {
     uno::Any aReturn = AccessibleContextBase::queryInterface (rType);
     if ( ! aReturn.hasValue())
@@ -439,58 +387,39 @@ uno::Any SAL_CALL
     return aReturn;
 }
 
-
-
-
 void SAL_CALL
-    AccessibleDocumentViewBase::acquire (void)
+    AccessibleDocumentViewBase::acquire()
     throw ()
 {
     AccessibleContextBase::acquire ();
 }
 
-
-
-
 void SAL_CALL
-    AccessibleDocumentViewBase::release (void)
+    AccessibleDocumentViewBase::release()
     throw ()
 {
     AccessibleContextBase::release ();
 }
 
-
-
-
-//=====  XServiceInfo  ========================================================
+// XServiceInfo
 
 OUString SAL_CALL
-    AccessibleDocumentViewBase::getImplementationName (void)
-    throw (::com::sun::star::uno::RuntimeException, std::exception)
+    AccessibleDocumentViewBase::getImplementationName()
 {
     return OUString("AccessibleDocumentViewBase");
 }
 
-
-
-
-::com::sun::star::uno::Sequence< OUString> SAL_CALL
-    AccessibleDocumentViewBase::getSupportedServiceNames (void)
-    throw (::com::sun::star::uno::RuntimeException, std::exception)
+css::uno::Sequence< OUString> SAL_CALL
+    AccessibleDocumentViewBase::getSupportedServiceNames()
 {
     ThrowIfDisposed ();
     return AccessibleContextBase::getSupportedServiceNames ();
 }
 
-
-
-
-
 //=====  XTypeProvider  =======================================================
 
-::com::sun::star::uno::Sequence< ::com::sun::star::uno::Type> SAL_CALL
-    AccessibleDocumentViewBase::getTypes (void)
-    throw (::com::sun::star::uno::RuntimeException, std::exception)
+css::uno::Sequence< css::uno::Type> SAL_CALL
+    AccessibleDocumentViewBase::getTypes()
 {
     ThrowIfDisposed ();
 
@@ -499,7 +428,6 @@ OUString SAL_CALL
     // ... get list of types from component base implementation, ...
     uno::Sequence<uno::Type> aComponentTypeList (AccessibleComponentBase::getTypes());
 
-
     // ...and add the additional type for the component, ...
     const uno::Type aLangEventListenerType =
          cppu::UnoType<lang::XEventListener>::get();
@@ -531,18 +459,15 @@ OUString SAL_CALL
     return aTypeList;
 }
 
-
-
-
 void AccessibleDocumentViewBase::impl_dispose()
 {
     // Unregister from VCL Window.
-    Window* pWindow = maShapeTreeInfo.GetWindow();
+    vcl::Window* pWindow = maShapeTreeInfo.GetWindow();
     if (maWindowLink.IsSet())
     {
         if (pWindow)
             pWindow->RemoveChildEventListener (maWindowLink);
-        maWindowLink = Link();
+        maWindowLink = Link<VclWindowEvent&,void>();
     }
     else
     {
@@ -554,7 +479,7 @@ void AccessibleDocumentViewBase::impl_dispose()
     {
         mxWindow->removeWindowListener (this);
         mxWindow->removeFocusListener (this);
-        mxWindow = NULL;
+        mxWindow = nullptr;
     }
 
     // Unregister form the model.
@@ -574,24 +499,20 @@ void AccessibleDocumentViewBase::impl_dispose()
     }
 
     // Propagate change of controller down the shape tree.
-    maShapeTreeInfo.SetControllerBroadcaster (NULL);
+    maShapeTreeInfo.SetModelBroadcaster (nullptr);
 
     // Reset the model reference.
-    mxModel = NULL;
+    mxModel = nullptr;
     // Reset the model reference.
-    mxController = NULL;
+    mxController = nullptr;
 
-    maShapeTreeInfo.SetDocumentWindow (NULL);
+    maShapeTreeInfo.SetDocumentWindow (nullptr);
 }
 
-
-
-
 //=====  XEventListener  ======================================================
 
 void SAL_CALL
     AccessibleDocumentViewBase::disposing (const lang::EventObject& rEventObject)
-    throw (::com::sun::star::uno::RuntimeException, std::exception)
 {
     ThrowIfDisposed ();
 
@@ -611,127 +532,86 @@ void SAL_CALL
 //=====  XPropertyChangeListener  =============================================
 
 void SAL_CALL AccessibleDocumentViewBase::propertyChange (const beans::PropertyChangeEvent& )
-    throw (::com::sun::star::uno::RuntimeException, std::exception)
 {
     // Empty
 }
 
-
-
-
 //=====  XWindowListener  =====================================================
 
 void SAL_CALL
-    AccessibleDocumentViewBase::windowResized (const ::com::sun::star::awt::WindowEvent& )
-    throw (::com::sun::star::uno::RuntimeException, std::exception)
+    AccessibleDocumentViewBase::windowResized (const css::awt::WindowEvent& )
 {
     if( IsDisposed() )
         return;
 
-    ViewForwarderChanged (
-        IAccessibleViewForwarderListener::VISIBLE_AREA,
-        &maViewForwarder);
+    ViewForwarderChanged();
 }
 
-
-
-
 void SAL_CALL
-    AccessibleDocumentViewBase::windowMoved (const ::com::sun::star::awt::WindowEvent& )
-    throw (::com::sun::star::uno::RuntimeException, std::exception)
+    AccessibleDocumentViewBase::windowMoved (const css::awt::WindowEvent& )
 {
     if( IsDisposed() )
         return;
 
-    ViewForwarderChanged (
-        IAccessibleViewForwarderListener::VISIBLE_AREA,
-        &maViewForwarder);
+    ViewForwarderChanged();
 }
 
-
-
-
 void SAL_CALL
-    AccessibleDocumentViewBase::windowShown (const ::com::sun::star::lang::EventObject& )
-    throw (::com::sun::star::uno::RuntimeException, std::exception)
+    AccessibleDocumentViewBase::windowShown (const css::lang::EventObject& )
 {
     if( IsDisposed() )
         return;
 
-    ViewForwarderChanged (
-        IAccessibleViewForwarderListener::VISIBLE_AREA,
-        &maViewForwarder);
+    ViewForwarderChanged();
 }
 
-
-
-
 void SAL_CALL
-    AccessibleDocumentViewBase::windowHidden (const ::com::sun::star::lang::EventObject& )
-    throw (::com::sun::star::uno::RuntimeException, std::exception)
+    AccessibleDocumentViewBase::windowHidden (const css::lang::EventObject& )
 {
     if( IsDisposed() )
         return;
 
-    ViewForwarderChanged (
-        IAccessibleViewForwarderListener::VISIBLE_AREA,
-        &maViewForwarder);
+    ViewForwarderChanged();
 }
 
-
-
-
 //=====  XFocusListener  ==================================================
 
-void AccessibleDocumentViewBase::focusGained (const ::com::sun::star::awt::FocusEvent& e)
-    throw (::com::sun::star::uno::RuntimeException, std::exception)
+void AccessibleDocumentViewBase::focusGained (const css::awt::FocusEvent& e)
 {
     ThrowIfDisposed ();
     if (e.Source == mxWindow)
         Activated ();
 }
 
-void AccessibleDocumentViewBase::focusLost (const ::com::sun::star::awt::FocusEvent& e)
-    throw (::com::sun::star::uno::RuntimeException, std::exception)
+void AccessibleDocumentViewBase::focusLost (const css::awt::FocusEvent& e)
 {
     ThrowIfDisposed ();
     if (e.Source == mxWindow)
         Deactivated ();
 }
 
-
-
-
 //=====  protected internal  ==================================================
 
 // This method is called from the component helper base class while disposing.
-void SAL_CALL AccessibleDocumentViewBase::disposing (void)
+void SAL_CALL AccessibleDocumentViewBase::disposing()
 {
     impl_dispose();
 
     AccessibleContextBase::disposing ();
 }
 
-
-
-
 /// Create a name for this view.
 OUString
-    AccessibleDocumentViewBase::CreateAccessibleName (void)
-    throw (::com::sun::star::uno::RuntimeException)
+    AccessibleDocumentViewBase::CreateAccessibleName()
 {
     return OUString ("AccessibleDocumentViewBase");
 }
 
-
-
-
 /** Create a description for this view.  Use the model's description or URL
     if a description is not available.
 */
 OUString
-    AccessibleDocumentViewBase::CreateAccessibleDescription (void)
-    throw (::com::sun::star::uno::RuntimeException)
+    AccessibleDocumentViewBase::CreateAccessibleDescription()
 {
     OUString sDescription;
 
@@ -751,25 +631,16 @@ OUString
     return sDescription;
 }
 
-
-
-
-void AccessibleDocumentViewBase::Activated (void)
+void AccessibleDocumentViewBase::Activated()
 {
     // Empty.  Overwrite to do something useful.
 }
 
-
-
-
-void AccessibleDocumentViewBase::Deactivated (void)
+void AccessibleDocumentViewBase::Deactivated()
 {
     // Empty.  Overwrite to do something useful.
 }
 
-
-
-
 void AccessibleDocumentViewBase::SetAccessibleOLEObject (
     const Reference <XAccessible>& xOLEObject)
 {
@@ -796,53 +667,44 @@ void AccessibleDocumentViewBase::SetAccessibleOLEObject (
             uno::Any());
 }
 
-
-
-
 //=====  methods from AccessibleSelectionBase ==================================================
 
 // return the member maMutex;
 ::osl::Mutex&
     AccessibleDocumentViewBase::implGetMutex()
 {
-    return( maMutex );
+    return maMutex;
 }
 
 // return ourself as context in default case
 uno::Reference< XAccessibleContext >
     AccessibleDocumentViewBase::implGetAccessibleContext()
-    throw (uno::RuntimeException)
 {
-    return( this );
+    return this;
 }
 
 // return sal_False in default case
 bool
     AccessibleDocumentViewBase::implIsSelected( sal_Int32 )
-    throw (uno::RuntimeException)
 {
-    return( false );
+    return false;
 }
 
 // return nothing in default case
 void
-    AccessibleDocumentViewBase::implSelect( sal_Int32, sal_Bool )
-    throw (lang::IndexOutOfBoundsException, uno::RuntimeException)
+    AccessibleDocumentViewBase::implSelect( sal_Int32, bool )
 {
 }
 
 uno::Any SAL_CALL AccessibleDocumentViewBase::getExtendedAttributes()
-    throw (::com::sun::star::lang::IndexOutOfBoundsException,
-           ::com::sun::star::uno::RuntimeException,
-           std::exception)
 {
     ::osl::MutexGuard aGuard (maMutex);
 
     uno::Any anyAtrribute;
     OUString sValue;
-    if (mpViewShell && mpViewShell->ISA(::sd::DrawViewShell))
+    if (nullptr != dynamic_cast<const ::sd::DrawViewShell* > (mpViewShell))
     {
-        ::sd::DrawViewShell* pDrViewSh = (::sd::DrawViewShell*) mpViewShell;
+        ::sd::DrawViewShell* pDrViewSh = static_cast< ::sd::DrawViewShell*>(mpViewShell);
         OUString sDisplay;
         OUString sName = "page-name:";
         // MT IA2: Not used...
@@ -860,7 +722,7 @@ uno::Any SAL_CALL AccessibleDocumentViewBase::getExtendedAttributes()
         sValue += OUString::number((sal_Int16)((sal_uInt16)((pDrViewSh->getCurrentPage()->GetPageNum()-1)>>1) + 1)) ;
         sName = ";total-pages:";
         sValue += sName;
-        sValue += OUString::number(pDrViewSh->GetPageTabControl()->GetPageCount()) ;
+        sValue += OUString::number(pDrViewSh->GetPageTabControl().GetPageCount()) ;
         sValue += ";";
         if(pDrViewSh->IsLayerModeActive() && pDrViewSh->GetLayerTabControl()) // #i87182#
         {
@@ -870,7 +732,7 @@ uno::Any SAL_CALL AccessibleDocumentViewBase::getExtendedAttributes()
             if( pDoc )
             {
                 SdrLayerAdmin& rLayerAdmin = pDoc->GetLayerAdmin();
-                SdrLayer* aSdrLayer = rLayerAdmin.GetLayer(sDisplay, false);
+                SdrLayer* aSdrLayer = rLayerAdmin.GetLayer(sDisplay);
                 if( aSdrLayer )
                 {
                     OUString layerAltText = aSdrLayer->GetTitle();
@@ -897,12 +759,12 @@ uno::Any SAL_CALL AccessibleDocumentViewBase::getExtendedAttributes()
             sValue += ";";
         }
     }
-    if (mpViewShell && mpViewShell->ISA(::sd::PresentationViewShell))
+    if (dynamic_cast<const ::sd::PresentationViewShell* >(mpViewShell) !=  nullptr )
     {
-        ::sd::PresentationViewShell* pPresViewSh = (::sd::PresentationViewShell*) mpViewShell;
+        ::sd::PresentationViewShell* pPresViewSh = static_cast< ::sd::PresentationViewShell*>(mpViewShell);
         SdPage* pCurrPge = pPresViewSh->getCurrentPage();
         SdDrawDocument* pDoc = pPresViewSh->GetDoc();
-        SdPage* pNotesPge = (SdPage*)pDoc->GetSdPage((pCurrPge->GetPageNum()-1)>>1, PK_NOTES);
+        SdPage* pNotesPge = pDoc->GetSdPage((pCurrPge->GetPageNum()-1)>>1, PageKind::Notes);
         if (pNotesPge)
         {
             SdrObject* pNotesObj = pNotesPge->GetPresObj(PRESOBJ_NOTES);
@@ -913,7 +775,7 @@ uno::Any SAL_CALL AccessibleDocumentViewBase::getExtendedAttributes()
                 {
                     sValue += "note:";
                     const EditTextObject& rEdit = pPara->GetTextObject();
-                    for (sal_uInt16 i=0;i<rEdit.GetParagraphCount();i++)
+                    for (sal_Int32 i=0;i<rEdit.GetParagraphCount();i++)
                     {
                         OUString strNote = rEdit.GetText(i);
                         strNote = strNote.replaceFirst( "\\", "\\\\" );
@@ -928,7 +790,7 @@ uno::Any SAL_CALL AccessibleDocumentViewBase::getExtendedAttributes()
             }
         }
     }
-    if (mpViewShell && mpViewShell->ISA(::sd::OutlineViewShell) )
+    if (dynamic_cast<const ::sd::OutlineViewShell* >(mpViewShell ) !=  nullptr )
     {
         OUString sName;
         OUString sDisplay;
@@ -948,7 +810,7 @@ uno::Any SAL_CALL AccessibleDocumentViewBase::getExtendedAttributes()
             sValue += OUString::number((sal_Int16)((sal_uInt16)((pCurrPge->GetPageNum()-1)>>1) + 1)) ;
             sName = ";total-pages:";
             sValue += sName;
-            sValue += OUString::number(pDoc->GetSdPageCount(PK_STANDARD)) ;
+            sValue += OUString::number(pDoc->GetSdPageCount(PageKind::Standard)) ;
             sValue += ";";
         }
     }
@@ -957,23 +819,20 @@ uno::Any SAL_CALL AccessibleDocumentViewBase::getExtendedAttributes()
     return anyAtrribute;
 }
 
-::com::sun::star::uno::Sequence< ::com::sun::star::uno::Any >
-        SAL_CALL AccessibleDocumentViewBase::getAccFlowTo(const ::com::sun::star::uno::Any&, sal_Int32 )
-        throw ( ::com::sun::star::uno::RuntimeException, std::exception )
+css::uno::Sequence< css::uno::Any >
+        SAL_CALL AccessibleDocumentViewBase::getAccFlowTo(const css::uno::Any&, sal_Int32 )
 {
-    ::com::sun::star::uno::Sequence< uno::Any> aRet;
+    css::uno::Sequence< uno::Any> aRet;
 
     return aRet;
 }
 
 sal_Int32 SAL_CALL AccessibleDocumentViewBase::getForeground(  )
-        throw (uno::RuntimeException, std::exception)
 {
     return COL_BLACK;
 }
 
 sal_Int32 SAL_CALL AccessibleDocumentViewBase::getBackground(  )
-        throw (uno::RuntimeException, std::exception)
 {
      ThrowIfDisposed ();
     ::osl::MutexGuard aGuard (maMutex);
