@@ -17,13 +17,11 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "sddll.hxx"
+#include <sddll.hxx>
 
 #include <boost/property_tree/json_parser.hpp>
 
 #include <com/sun/star/beans/XMultiPropertyStates.hpp>
-#include <com/sun/star/frame/XController.hpp>
-#include <com/sun/star/frame/XModel.hpp>
 #include <com/sun/star/view/XSelectionSupplier.hpp>
 #include <com/sun/star/geometry/RealPoint2D.hpp>
 #include <com/sun/star/text/XText.hpp>
@@ -64,30 +62,27 @@
 #include <editeng/udlnitem.hxx>
 #include <editeng/crossedoutitem.hxx>
 
-#include <LibreOfficeKit/LibreOfficeKitEnums.h>
-
 #include <svx/postattr.hxx>
 #include <svx/svdetc.hxx>
 
-#include "annotationmanager.hxx"
+#include <annotationmanager.hxx>
 #include "annotationmanagerimpl.hxx"
 #include "annotationwindow.hxx"
-#include "annotations.hrc"
+#include <strings.hrc>
 
-#include "Annotation.hxx"
-#include "ToolBarManager.hxx"
-#include "DrawDocShell.hxx"
-#include "DrawViewShell.hxx"
-#include "DrawController.hxx"
-#include "glob.hrc"
-#include "sdresid.hxx"
-#include "EventMultiplexer.hxx"
-#include "ViewShellManager.hxx"
-#include "helpids.h"
-#include "sdpage.hxx"
-#include "drawdoc.hxx"
-#include "textapi.hxx"
-#include "optsitem.hxx"
+#include <Annotation.hxx>
+#include <ToolBarManager.hxx>
+#include <DrawDocShell.hxx>
+#include <DrawViewShell.hxx>
+#include <DrawController.hxx>
+#include <sdresid.hxx>
+#include <EventMultiplexer.hxx>
+#include <ViewShellManager.hxx>
+#include <helpids.h>
+#include <sdpage.hxx>
+#include <drawdoc.hxx>
+#include <textapi.hxx>
+#include <optsitem.hxx>
 
 #include <memory>
 
@@ -107,43 +102,6 @@ using namespace ::com::sun::star::ui;
 using namespace ::com::sun::star::task;
 using namespace ::com::sun::star::office;
 
-namespace {
-
-    enum class CommentNotificationType { Add, Modify, Remove };
-
-    void lcl_CommentNotification(CommentNotificationType nType, const SfxViewShell* pViewShell, Reference<XAnnotation>& rxAnnotation)
-    {
-        // callbacks only if tiled annotations are explicitly turned off by LOK client
-        if (!comphelper::LibreOfficeKit::isActive() || comphelper::LibreOfficeKit::isTiledAnnotations())
-            return;
-
-        boost::property_tree::ptree aAnnotation;
-        aAnnotation.put("action", (nType == CommentNotificationType::Add ? "Add" :
-                                   (nType == CommentNotificationType::Remove ? "Remove" :
-                                    (nType == CommentNotificationType::Modify ? "Modify" : "???"))));
-        aAnnotation.put("id", sd::getAnnotationId(rxAnnotation));
-        if (nType != CommentNotificationType::Remove && rxAnnotation.is())
-        {
-            aAnnotation.put("id", sd::getAnnotationId(rxAnnotation));
-            aAnnotation.put("author", rxAnnotation->getAuthor());
-            aAnnotation.put("dateTime", utl::toISO8601(rxAnnotation->getDateTime()));
-            uno::Reference<text::XText> xText(rxAnnotation->getTextRange());
-            aAnnotation.put("text", xText->getString());
-            const SdPage* pPage = sd::getAnnotationPage(rxAnnotation);
-            aAnnotation.put("parthash", pPage ? OString::number(pPage->GetHashCode()) : OString());
-        }
-
-        boost::property_tree::ptree aTree;
-        aTree.add_child("comment", aAnnotation);
-        std::stringstream aStream;
-        boost::property_tree::write_json(aStream, aTree);
-        std::string aPayload = aStream.str();
-
-        pViewShell->libreOfficeKitViewCallback(LOK_CALLBACK_COMMENT, aPayload.c_str());
-    }
-
-} // anonymous ns
-
 namespace sd {
 
 SfxItemPool* GetAnnotationPool()
@@ -151,7 +109,7 @@ SfxItemPool* GetAnnotationPool()
     static SfxItemPool* s_pAnnotationPool = nullptr;
     if( s_pAnnotationPool == nullptr )
     {
-        s_pAnnotationPool = EditEngine::CreatePool( false );
+        s_pAnnotationPool = EditEngine::CreatePool();
         s_pAnnotationPool->SetPoolDefaultItem(SvxFontHeightItem(423,100,EE_CHAR_FONTHEIGHT));
 
         vcl::Font aAppFont( Application::GetSettings().GetStyleSettings().GetAppFont() );
@@ -161,7 +119,7 @@ SfxItemPool* GetAnnotationPool()
     return s_pAnnotationPool;
 }
 
-static SfxBindings* getBindings( ViewShellBase& rBase )
+static SfxBindings* getBindings( ViewShellBase const & rBase )
 {
     if( rBase.GetMainViewShell().get() && rBase.GetMainViewShell()->GetViewFrame() )
         return &rBase.GetMainViewShell()->GetViewFrame()->GetBindings();
@@ -169,7 +127,7 @@ static SfxBindings* getBindings( ViewShellBase& rBase )
     return nullptr;
 }
 
-static SfxDispatcher* getDispatcher( ViewShellBase& rBase )
+static SfxDispatcher* getDispatcher( ViewShellBase const & rBase )
 {
     if( rBase.GetMainViewShell().get() && rBase.GetMainViewShell()->GetViewFrame() )
         return rBase.GetMainViewShell()->GetViewFrame()->GetDispatcher();
@@ -200,7 +158,7 @@ OUString getAnnotationDateTimeString( const Reference< XAnnotation >& xAnnotatio
         Date aDate( aDateTime.Day, aDateTime.Month, aDateTime.Year );
         if (aDate==aSysDate)
             sRet = SdResId(STR_ANNOTATION_TODAY);
-        else if (aDate == Date(aSysDate-1))
+        else if (aDate == (aSysDate-1))
             sRet = SdResId(STR_ANNOTATION_YESTERDAY);
         else if (aDate.IsValidAndGregorian() )
             sRet = rLocalData.getDate(aDate);
@@ -291,7 +249,7 @@ void SAL_CALL AnnotationManagerImpl::notifyEvent( const css::document::EventObje
             Reference< XAnnotation > xAnnotation( aEvent.Source, uno::UNO_QUERY );
             if ( xAnnotation.is() )
             {
-                lcl_CommentNotification(CommentNotificationType::Remove, &mrBase, xAnnotation);
+                LOKCommentNotify(CommentNotificationType::Remove, &mrBase, xAnnotation);
             }
         }
 
@@ -342,7 +300,7 @@ void AnnotationManagerImpl::ShowAnnotations( bool bShow )
     }
 }
 
-void AnnotationManagerImpl::ExecuteAnnotation(SfxRequest& rReq )
+void AnnotationManagerImpl::ExecuteAnnotation(SfxRequest const & rReq )
 {
     switch( rReq.GetSlot() )
     {
@@ -370,7 +328,7 @@ void AnnotationManagerImpl::ExecuteAnnotation(SfxRequest& rReq )
     }
 }
 
-void AnnotationManagerImpl::ExecuteInsertAnnotation(SfxRequest& rReq)
+void AnnotationManagerImpl::ExecuteInsertAnnotation(SfxRequest const & rReq)
 {
     if (!comphelper::LibreOfficeKit::isActive() || comphelper::LibreOfficeKit::isTiledAnnotations())
         ShowAnnotations(true);
@@ -389,7 +347,7 @@ void AnnotationManagerImpl::ExecuteInsertAnnotation(SfxRequest& rReq)
     InsertAnnotation(sText);
 }
 
-void AnnotationManagerImpl::ExecuteDeleteAnnotation(SfxRequest& rReq)
+void AnnotationManagerImpl::ExecuteDeleteAnnotation(SfxRequest const & rReq)
 {
     ShowAnnotations( true );
 
@@ -437,7 +395,7 @@ void AnnotationManagerImpl::ExecuteDeleteAnnotation(SfxRequest& rReq)
     UpdateTags();
 }
 
-void AnnotationManagerImpl::ExecuteEditAnnotation(SfxRequest& rReq)
+void AnnotationManagerImpl::ExecuteEditAnnotation(SfxRequest const & rReq)
 {
     const SfxItemSet* pArgs = rReq.GetArgs();
     Reference< XAnnotation > xAnnotation;
@@ -445,6 +403,9 @@ void AnnotationManagerImpl::ExecuteEditAnnotation(SfxRequest& rReq)
     OUString sText;
     if (pArgs)
     {
+        if (mpDoc->IsUndoEnabled())
+            mpDoc->BegUndo(SdResId(STR_ANNOTATION_UNDO_EDIT));
+
         const SfxPoolItem* pPoolItem = nullptr;
         if (SfxItemState::SET == pArgs->GetItemState(SID_ATTR_POSTIT_ID, true, &pPoolItem))
         {
@@ -456,20 +417,20 @@ void AnnotationManagerImpl::ExecuteEditAnnotation(SfxRequest& rReq)
 
         if (xAnnotation.is() && !sText.isEmpty())
         {
+            CreateChangeUndo(xAnnotation);
+
             // TODO: Not allow other authors to change others' comments ?
             Reference<XText> xText(xAnnotation->getTextRange());
             xText->setString(sText);
 
-            const SfxViewShell* pViewShell = SfxViewShell::GetFirst();
-            while (pViewShell)
-            {
-                lcl_CommentNotification(CommentNotificationType::Modify, pViewShell, xAnnotation);
-                pViewShell = SfxViewShell::GetNext(*pViewShell);
-            }
+            LOKCommentNotifyAll(CommentNotificationType::Modify, xAnnotation);
         }
-    }
 
-    UpdateTags(true);
+        if (mpDoc->IsUndoEnabled())
+            mpDoc->EndUndo();
+
+        UpdateTags(true);
+    }
 }
 
 void AnnotationManagerImpl::InsertAnnotation(const OUString& rText)
@@ -559,19 +520,14 @@ void AnnotationManagerImpl::InsertAnnotation(const OUString& rText)
             mpDoc->EndUndo();
 
         // Tell our LOK clients about new comment added
-        const SfxViewShell* pViewShell = SfxViewShell::GetFirst();
-        while (pViewShell)
-        {
-            lcl_CommentNotification(CommentNotificationType::Add, pViewShell, xAnnotation);
-            pViewShell = SfxViewShell::GetNext(*pViewShell);
-        }
+        LOKCommentNotifyAll(CommentNotificationType::Add, xAnnotation);
 
         UpdateTags(true);
         SelectAnnotation( xAnnotation, true );
     }
 }
 
-void AnnotationManagerImpl::ExecuteReplyToAnnotation( SfxRequest& rReq )
+void AnnotationManagerImpl::ExecuteReplyToAnnotation( SfxRequest const & rReq )
 {
     Reference< XAnnotation > xAnnotation;
     const SfxItemSet* pArgs = rReq.GetArgs();
@@ -652,12 +608,7 @@ void AnnotationManagerImpl::ExecuteReplyToAnnotation( SfxRequest& rReq )
         xAnnotation->setDateTime( getCurrentDateTime() );
 
         // Tell our LOK clients about this (comment modification)
-        const SfxViewShell* pViewShell = SfxViewShell::GetFirst();
-        while (pViewShell)
-        {
-            lcl_CommentNotification(CommentNotificationType::Modify, pViewShell, xAnnotation);
-            pViewShell = SfxViewShell::GetNext(*pViewShell);
-        }
+        LOKCommentNotifyAll(CommentNotificationType::Modify, xAnnotation);
 
         UpdateTags(true);
         SelectAnnotation( xAnnotation, true );
@@ -728,7 +679,7 @@ void AnnotationManagerImpl::DeleteAllAnnotations()
             AnnotationVector aAnnotations( pPage->getAnnotations() );
             for( AnnotationVector::iterator iter = aAnnotations.begin(); iter != aAnnotations.end(); ++iter )
             {
-                pPage->removeAnnotation( (*iter) );
+                pPage->removeAnnotation( *iter );
             }
         }
     }
@@ -879,15 +830,15 @@ void AnnotationManagerImpl::SelectNextAnnotation(bool bForeward)
 
         // The question text depends on the search direction.
         bool bImpress = mpDoc->GetDocumentType() == DocumentType::Impress;
-        sal_uInt16 nStringId;
+        const char* pStringId;
         if(bForeward)
-            nStringId = bImpress ? STR_ANNOTATION_WRAP_FORWARD : STR_ANNOTATION_WRAP_FORWARD_DRAW;
+            pStringId = bImpress ? STR_ANNOTATION_WRAP_FORWARD : STR_ANNOTATION_WRAP_FORWARD_DRAW;
         else
-            nStringId = bImpress ? STR_ANNOTATION_WRAP_BACKWARD : STR_ANNOTATION_WRAP_BACKWARD_DRAW;
+            pStringId = bImpress ? STR_ANNOTATION_WRAP_BACKWARD : STR_ANNOTATION_WRAP_BACKWARD_DRAW;
 
         // Pop up question box that asks the user whether to wrap around.
         // The dialog is made modal with respect to the whole application.
-        ScopedVclPtrInstance< QueryBox > aQuestionBox( nullptr, (WB_YES_NO | WB_DEF_YES), SdResId(nStringId));
+        ScopedVclPtrInstance< QueryBox > aQuestionBox( nullptr, (MessBoxStyle::YesNo | MessBoxStyle::DefaultYes), SdResId(pStringId));
         aQuestionBox->SetImage( QueryBox::GetStandardImage() );
         if (aQuestionBox->Execute() != RET_YES)
             break;
@@ -895,13 +846,13 @@ void AnnotationManagerImpl::SelectNextAnnotation(bool bForeward)
     while( true );
 }
 
-void AnnotationManagerImpl::onTagSelected( AnnotationTag& rTag )
+void AnnotationManagerImpl::onTagSelected( AnnotationTag const & rTag )
 {
     mxSelectedAnnotation = rTag.GetAnnotation();
     invalidateSlots();
 }
 
-void AnnotationManagerImpl::onTagDeselected( AnnotationTag& rTag )
+void AnnotationManagerImpl::onTagDeselected( AnnotationTag const & rTag )
 {
     if( rTag.GetAnnotation() == mxSelectedAnnotation )
     {
@@ -1169,25 +1120,25 @@ void AnnotationManagerImpl::ExecuteAnnotationContextMenu( const Reference< XAnno
 
             if ( aSet.GetItemState( EE_CHAR_WEIGHT ) == SfxItemState::SET )
             {
-                if( static_cast<const SvxWeightItem&>(aSet.Get( EE_CHAR_WEIGHT )).GetWeight() == WEIGHT_BOLD )
+                if( aSet.Get( EE_CHAR_WEIGHT ).GetWeight() == WEIGHT_BOLD )
                     pMenu->CheckItem(pMenu->GetItemId("bold"));
             }
 
             if ( aSet.GetItemState( EE_CHAR_ITALIC ) == SfxItemState::SET )
             {
-                if( static_cast<const SvxPostureItem&>(aSet.Get( EE_CHAR_ITALIC )).GetPosture() != ITALIC_NONE )
+                if( aSet.Get( EE_CHAR_ITALIC ).GetPosture() != ITALIC_NONE )
                     pMenu->CheckItem(pMenu->GetItemId("italic"));
 
             }
             if ( aSet.GetItemState( EE_CHAR_UNDERLINE ) == SfxItemState::SET )
             {
-                if( static_cast<const SvxUnderlineItem&>(aSet.Get( EE_CHAR_UNDERLINE )).GetLineStyle() != LINESTYLE_NONE )
+                if( aSet.Get( EE_CHAR_UNDERLINE ).GetLineStyle() != LINESTYLE_NONE )
                     pMenu->CheckItem(pMenu->GetItemId("underline"));
             }
 
             if ( aSet.GetItemState( EE_CHAR_STRIKEOUT ) == SfxItemState::SET )
             {
-                if( static_cast<const SvxCrossedOutItem&>(aSet.Get( EE_CHAR_STRIKEOUT )).GetStrikeout() != STRIKEOUT_NONE )
+                if( aSet.Get( EE_CHAR_STRIKEOUT ).GetStrikeout() != STRIKEOUT_NONE )
                     pMenu->CheckItem(pMenu->GetItemId("strike"));
             }
             TransferableDataHelper aDataHelper( TransferableDataHelper::CreateFromSystemClipboard( pAnnotationWindow ) );
@@ -1307,7 +1258,7 @@ Color AnnotationManagerImpl::GetColorDark(sal_uInt16 aAuthorIndex)
     return Color(COL_WHITE);
 }
 
-SdPage* AnnotationManagerImpl::GetNextPage( SdPage* pPage, bool bForward )
+SdPage* AnnotationManagerImpl::GetNextPage( SdPage const * pPage, bool bForward )
 {
     if( pPage == nullptr )
     {
@@ -1382,7 +1333,7 @@ AnnotationManager::~AnnotationManager()
     mxImpl->dispose();
 }
 
-void AnnotationManager::ExecuteAnnotation(SfxRequest& rRequest)
+void AnnotationManager::ExecuteAnnotation(SfxRequest const & rRequest)
 {
     mxImpl->ExecuteAnnotation( rRequest );
 }
