@@ -29,15 +29,15 @@
 #include <svx/unoshape.hxx>
 #include <svx/xfltrit.hxx>
 #include <svx/xfillit.hxx>
+#include <xmloff/autolayout.hxx>
+
 #include "PhotoAlbumDialog.hxx"
-#include "strings.hrc"
-#include "sdresid.hxx"
+#include <strings.hrc>
+#include <sdresid.hxx>
 
 namespace sd
 {
 
-OUString SdPhotoAlbumDialog::sDirUrl;
-
 SdPhotoAlbumDialog::SdPhotoAlbumDialog(vcl::Window* pWindow, SdDrawDocument* pActDoc)
 : ModalDialog(pWindow, "PhotoAlbumCreatorDialog", "modules/simpress/ui/photoalbum.ui"),
   pDoc(pActDoc)
@@ -55,7 +55,10 @@ SdPhotoAlbumDialog::SdPhotoAlbumDialog(vcl::Window* pWindow, SdDrawDocument* pAc
 
     get(pInsTypeCombo, "opt_combo");
     get(pASRCheck, "asr_check");
+    get(pASRCheckCrop, "asr_check_crop");
     get(pCapCheck, "cap_check");
+    get(pInsertAsLinkCheck, "insert_as_link_check");
+
     pCancelBtn->SetClickHdl(LINK(this, SdPhotoAlbumDialog, CancelHdl));
     pCreateBtn->SetClickHdl(LINK(this, SdPhotoAlbumDialog, CreateHdl));
 
@@ -67,9 +70,9 @@ SdPhotoAlbumDialog::SdPhotoAlbumDialog(vcl::Window* pWindow, SdDrawDocument* pAc
     pRemoveBtn->SetClickHdl(LINK(this, SdPhotoAlbumDialog, RemoveHdl));
     pRemoveBtn->Disable();
     pImagesLst->SetSelectHdl(LINK(this, SdPhotoAlbumDialog, SelectHdl));
+    pInsTypeCombo->SetSelectHdl(LINK(this, SdPhotoAlbumDialog, TypeSelectHdl));
 
     mpGraphicFilter = new GraphicFilter;
-    sDirUrl.clear();
     pAddBtn->GrabFocus();
     pImagesLst->Clear();
 }
@@ -91,20 +94,22 @@ void SdPhotoAlbumDialog::dispose()
     pImg.clear();
     pInsTypeCombo.clear();
     pASRCheck.clear();
+    pASRCheckCrop.clear();
     pCapCheck.clear();
+    pInsertAsLinkCheck.clear();
     ModalDialog::dispose();
 }
 
-IMPL_LINK_NOARG_TYPED(SdPhotoAlbumDialog, CancelHdl, Button*, void)
+IMPL_LINK_NOARG(SdPhotoAlbumDialog, CancelHdl, Button*, void)
 {
     Close();
 }
 
-IMPL_LINK_NOARG_TYPED(SdPhotoAlbumDialog, CreateHdl, Button*, void)
+IMPL_LINK_NOARG(SdPhotoAlbumDialog, CreateHdl, Button*, void)
 {
     if (pImagesLst->GetEntryCount() == 0)
     {
-        ScopedVclPtrInstance< WarningBox > aWarning(this, WB_OK, SD_RESSTR(STR_PHOTO_ALBUM_EMPTY_WARNING));
+        ScopedVclPtrInstance< WarningBox > aWarning(this, MessBoxStyle::Ok, SdResId(STR_PHOTO_ALBUM_EMPTY_WARNING));
         aWarning->Execute();
     }
     else
@@ -116,8 +121,14 @@ IMPL_LINK_NOARG_TYPED(SdPhotoAlbumDialog, CreateHdl, Button*, void)
         Reference< XComponentContext > xContext(::comphelper::getProcessComponentContext());
         Reference< graphic::XGraphicProvider> xProvider(graphic::GraphicProvider::create(xContext));
 
+        // determine if to use Captions (use TitleObject) and choose the correct AutoLayout
+        // from the beginning
+        const bool bCreateCaptions(pCapCheck->IsChecked());
+        const bool bInsertAsLink(pInsertAsLinkCheck->IsChecked());
+        const AutoLayout aAutoLayout(bCreateCaptions ? AUTOLAYOUT_TITLE_ONLY : AUTOLAYOUT_NONE);
+
         // get the option
-        const sal_Int32 nOpt = pInsTypeCombo->GetSelectEntryPos();
+        const sal_Int32 nOpt = pInsTypeCombo->GetSelectedEntryPos();
         if ( nOpt == ONE_IMAGE )
         {
             OUString sUrl;
@@ -126,12 +137,12 @@ IMPL_LINK_NOARG_TYPED(SdPhotoAlbumDialog, CreateHdl, Button*, void)
                 OUString const * pData = static_cast<OUString const *>(pImagesLst->GetEntryData(i));
                 sUrl = *pData;
 
-                Reference< drawing::XDrawPage > xSlide = appendNewSlide(AUTOLAYOUT_NONE, xDrawPages);
+                Reference< drawing::XDrawPage > xSlide = appendNewSlide(aAutoLayout, xDrawPages);
                 Reference< beans::XPropertySet > xSlideProps( xSlide, uno::UNO_QUERY );
 
                 Reference< graphic::XGraphic > xGraphic = createXGraphicFromUrl(sUrl, xProvider);
 
-                Image aImg(xGraphic);
+                Graphic aImg(xGraphic);
                 // Save the original size, multiplied with 100
                 ::awt::Size aPicSize(aImg.GetSizePixel().Width()*100, aImg.GetSizePixel().Height()*100);
 
@@ -140,7 +151,10 @@ IMPL_LINK_NOARG_TYPED(SdPhotoAlbumDialog, CreateHdl, Button*, void)
                     uno::UNO_QUERY);
 
                 Reference< beans::XPropertySet > xProps( xShape, uno::UNO_QUERY );
-                xProps->setPropertyValue("Graphic", ::uno::Any(xGraphic));
+                if (bInsertAsLink)
+                    xProps->setPropertyValue("GraphicURL", ::uno::Any(sUrl));
+                else
+                    xProps->setPropertyValue("Graphic", ::uno::Any(xGraphic));
 
                 ::awt::Size aPageSize;
 
@@ -151,15 +165,14 @@ IMPL_LINK_NOARG_TYPED(SdPhotoAlbumDialog, CreateHdl, Button*, void)
 
                 ::awt::Point aPicPos;
 
-                if(pASRCheck->IsChecked())
+                if(pASRCheck->IsChecked() && !pASRCheckCrop->IsChecked())
                 {
                     // Resize the image, with keeping ASR
                     aPicSize = createASRSize(aPicSize, aPageSize);
                 }
-                else
+                else if(pASRCheckCrop->IsChecked())
                 {
-                    aPicSize.Width = aPageSize.Width;
-                    aPicSize.Height = aPageSize.Height;
+                    aPicSize = createASRSizeCrop(aPicSize, aPageSize);
                 }
 
                 xShape->setSize(aPicSize);
@@ -168,7 +181,7 @@ IMPL_LINK_NOARG_TYPED(SdPhotoAlbumDialog, CreateHdl, Button*, void)
 
                 xShape->setPosition(aPicPos);
                 xSlide->add(xShape);
-                if(pCapCheck->IsChecked())
+                if(bCreateCaptions)
                     createCaption( aPageSize );
             }
         }
@@ -182,7 +195,7 @@ IMPL_LINK_NOARG_TYPED(SdPhotoAlbumDialog, CreateHdl, Button*, void)
                 OUString const * pData = nullptr;
 
                 // create the slide
-                Reference< drawing::XDrawPage > xSlide = appendNewSlide(AUTOLAYOUT_NONE, xDrawPages);
+                Reference< drawing::XDrawPage > xSlide = appendNewSlide(aAutoLayout, xDrawPages);
                 Reference< beans::XPropertySet > xSlideProps( xSlide, uno::UNO_QUERY );
                 //Slide dimensions
                 ::awt::Size aPageSize;
@@ -195,18 +208,17 @@ IMPL_LINK_NOARG_TYPED(SdPhotoAlbumDialog, CreateHdl, Button*, void)
                 // grab the left one
                 void* pD1 = pImagesLst->GetEntryData(i);
                 pData = static_cast<OUString const *>(pD1);
-                sUrl1 = pData ? OUString(*pData) : "";
+                sUrl1 = pData ? *pData : "";
                 // grab the right one
                 void* pD2 = pImagesLst->GetEntryData(i+1);
                 pData = static_cast<OUString const *>(pD2);
-                sUrl2 = pData ? OUString(*pData) : "";
+                sUrl2 = pData ? *pData : "";
 
                 if( !sUrl1.isEmpty() )
                 {
-
                     Reference< graphic::XGraphic > xGraphic = createXGraphicFromUrl(sUrl1, xProvider);
 
-                    Image aImg(xGraphic);
+                    Graphic aImg(xGraphic);
                     // Save the original size, multiplied with 100
                     ::awt::Size aPicSize(aImg.GetSizePixel().Width()*100, aImg.GetSizePixel().Height()*100);
 
@@ -215,7 +227,10 @@ IMPL_LINK_NOARG_TYPED(SdPhotoAlbumDialog, CreateHdl, Button*, void)
                         uno::UNO_QUERY);
 
                     Reference< beans::XPropertySet > xProps( xShape, uno::UNO_QUERY );
-                    xProps->setPropertyValue("Graphic", ::uno::Any(xGraphic));
+                    if (bInsertAsLink)
+                        xProps->setPropertyValue("GraphicURL", ::uno::Any(sUrl1));
+                    else
+                        xProps->setPropertyValue("Graphic", ::uno::Any(xGraphic));
 
                     ::awt::Point aPicPos;
 
@@ -241,7 +256,7 @@ IMPL_LINK_NOARG_TYPED(SdPhotoAlbumDialog, CreateHdl, Button*, void)
                 {
                     Reference< graphic::XGraphic > xGraphic = createXGraphicFromUrl(sUrl2, xProvider);
 
-                    Image aImg(xGraphic);
+                    Graphic aImg(xGraphic);
                     // Save the original size, multiplied with 100
                     ::awt::Size aPicSize(aImg.GetSizePixel().Width()*100, aImg.GetSizePixel().Height()*100);
 
@@ -250,7 +265,10 @@ IMPL_LINK_NOARG_TYPED(SdPhotoAlbumDialog, CreateHdl, Button*, void)
                         uno::UNO_QUERY);
 
                     Reference< beans::XPropertySet > xProps( xShape, uno::UNO_QUERY );
-                    xProps->setPropertyValue("Graphic", ::uno::Any(xGraphic));
+                    if (bInsertAsLink)
+                        xProps->setPropertyValue("GraphicURL", ::uno::Any(sUrl2));
+                    else
+                        xProps->setPropertyValue("Graphic", ::uno::Any(xGraphic));
 
                     ::awt::Point aPicPos;
 
@@ -270,7 +288,7 @@ IMPL_LINK_NOARG_TYPED(SdPhotoAlbumDialog, CreateHdl, Button*, void)
 
                     xShape->setPosition(aPicPos);
                     xSlide->add(xShape);
-                    if(pCapCheck->IsChecked())
+                    if(bCreateCaptions)
                         createCaption( aPageSize );
 
                 }
@@ -287,7 +305,7 @@ IMPL_LINK_NOARG_TYPED(SdPhotoAlbumDialog, CreateHdl, Button*, void)
             {
                 OUString* pData = nullptr;
                 // create the slide
-                Reference< drawing::XDrawPage > xSlide = appendNewSlide(AUTOLAYOUT_NONE, xDrawPages);
+                Reference< drawing::XDrawPage > xSlide = appendNewSlide(aAutoLayout, xDrawPages);
                 Reference< beans::XPropertySet > xSlideProps( xSlide, uno::UNO_QUERY );
                 //Slide dimensions
                 ::awt::Size aPageSize;
@@ -300,28 +318,28 @@ IMPL_LINK_NOARG_TYPED(SdPhotoAlbumDialog, CreateHdl, Button*, void)
                 // grab the upper left one
                 void* pD1 = pImagesLst->GetEntryData(i);
                 pData = static_cast<OUString*>(pD1);
-                sUrl1 = pData ? OUString(*pData) : "";
+                sUrl1 = pData ? *pData : "";
 
                 // grab the upper right one
                 void* pD2 = pImagesLst->GetEntryData(i+1);
                 pData = static_cast<OUString *>(pD2);
-                sUrl2 = pData ? OUString(*pData) : "";
+                sUrl2 = pData ? *pData : "";
 
                 // grab the lower left one
                 void* pD3 = pImagesLst->GetEntryData(i+2);
                 pData = static_cast<OUString*>(pD3);
-                sUrl3 = pData ? OUString(*pData) : "";
+                sUrl3 = pData ? *pData : "";
 
                 // grab the lower right one
                 void* pD4 = pImagesLst->GetEntryData(i+3);
                 pData = static_cast<OUString*>(pD4);
-                sUrl4 = pData ? OUString(*pData) : "";
+                sUrl4 = pData ? *pData : "";
 
                 if( !sUrl1.isEmpty() )
                 {
                     Reference< graphic::XGraphic > xGraphic = createXGraphicFromUrl(sUrl1, xProvider);
 
-                    Image aImg(xGraphic);
+                    Graphic aImg(xGraphic);
                     // Save the original size, multiplied with 100
                     ::awt::Size aPicSize(aImg.GetSizePixel().Width()*100, aImg.GetSizePixel().Height()*100);
 
@@ -330,7 +348,10 @@ IMPL_LINK_NOARG_TYPED(SdPhotoAlbumDialog, CreateHdl, Button*, void)
                         uno::UNO_QUERY);
 
                     Reference< beans::XPropertySet > xProps( xShape, uno::UNO_QUERY );
-                    xProps->setPropertyValue("Graphic", ::uno::Any(xGraphic));
+                    if (bInsertAsLink)
+                        xProps->setPropertyValue("GraphicURL", ::uno::Any(sUrl1));
+                    else
+                        xProps->setPropertyValue("Graphic", ::uno::Any(xGraphic));
 
                     ::awt::Point aPicPos;
 
@@ -355,7 +376,7 @@ IMPL_LINK_NOARG_TYPED(SdPhotoAlbumDialog, CreateHdl, Button*, void)
                 {
                     Reference< graphic::XGraphic > xGraphic = createXGraphicFromUrl(sUrl2, xProvider);
 
-                    Image aImg(xGraphic);
+                    Graphic aImg(xGraphic);
                     // Save the original size, multiplied with 100
                     ::awt::Size aPicSize(aImg.GetSizePixel().Width()*100, aImg.GetSizePixel().Height()*100);
 
@@ -364,7 +385,10 @@ IMPL_LINK_NOARG_TYPED(SdPhotoAlbumDialog, CreateHdl, Button*, void)
                         uno::UNO_QUERY);
 
                     Reference< beans::XPropertySet > xProps( xShape, uno::UNO_QUERY );
-                    xProps->setPropertyValue("Graphic", ::uno::Any(xGraphic));
+                    if (bInsertAsLink)
+                        xProps->setPropertyValue("GraphicURL", ::uno::Any(sUrl2));
+                    else
+                        xProps->setPropertyValue("Graphic", ::uno::Any(xGraphic));
 
                     ::awt::Point aPicPos;
 
@@ -387,10 +411,9 @@ IMPL_LINK_NOARG_TYPED(SdPhotoAlbumDialog, CreateHdl, Button*, void)
                 }
                 if( !sUrl3.isEmpty() )
                 {
-
                     Reference< graphic::XGraphic > xGraphic = createXGraphicFromUrl(sUrl3, xProvider);
 
-                    Image aImg(xGraphic);
+                    Graphic aImg(xGraphic);
                     // Save the original size, multiplied with 100
                     ::awt::Size aPicSize(aImg.GetSizePixel().Width()*100, aImg.GetSizePixel().Height()*100);
 
@@ -399,7 +422,10 @@ IMPL_LINK_NOARG_TYPED(SdPhotoAlbumDialog, CreateHdl, Button*, void)
                         uno::UNO_QUERY);
 
                     Reference< beans::XPropertySet > xProps( xShape, uno::UNO_QUERY );
-                    xProps->setPropertyValue("Graphic", ::uno::Any(xGraphic));
+                    if (bInsertAsLink)
+                        xProps->setPropertyValue("GraphicURL", ::uno::Any(sUrl3));
+                    else
+                        xProps->setPropertyValue("Graphic", ::uno::Any(xGraphic));
 
                     ::awt::Point aPicPos;
 
@@ -424,7 +450,7 @@ IMPL_LINK_NOARG_TYPED(SdPhotoAlbumDialog, CreateHdl, Button*, void)
                 {
                     Reference< graphic::XGraphic > xGraphic = createXGraphicFromUrl(sUrl4, xProvider);
 
-                    Image aImg(xGraphic);
+                    Graphic aImg(xGraphic);
                     // Save the original size, multiplied with 100
                     ::awt::Size aPicSize(aImg.GetSizePixel().Width()*100, aImg.GetSizePixel().Height()*100);
 
@@ -433,7 +459,10 @@ IMPL_LINK_NOARG_TYPED(SdPhotoAlbumDialog, CreateHdl, Button*, void)
                         uno::UNO_QUERY);
 
                     Reference< beans::XPropertySet > xProps( xShape, uno::UNO_QUERY );
-                    xProps->setPropertyValue("Graphic", ::uno::Any(xGraphic));
+                    if (bInsertAsLink)
+                        xProps->setPropertyValue("GraphicURL", ::uno::Any(sUrl4));
+                    else
+                        xProps->setPropertyValue("Graphic", ::uno::Any(xGraphic));
 
                     ::awt::Point aPicPos;
 
@@ -453,7 +482,7 @@ IMPL_LINK_NOARG_TYPED(SdPhotoAlbumDialog, CreateHdl, Button*, void)
 
                     xShape->setPosition(aPicPos);
                     xSlide->add(xShape);
-                    if(pCapCheck->IsChecked())
+                    if(bCreateCaptions)
                         createCaption( aPageSize );
 
                 }
@@ -468,11 +497,11 @@ IMPL_LINK_NOARG_TYPED(SdPhotoAlbumDialog, CreateHdl, Button*, void)
     }
 }
 
-IMPL_LINK_NOARG_TYPED(SdPhotoAlbumDialog, FileHdl, Button*, void)
+IMPL_LINK_NOARG(SdPhotoAlbumDialog, FileHdl, Button*, void)
 {
     ::sfx2::FileDialogHelper aDlg(
-        css::ui::dialogs::TemplateDescription::FILEOPEN_LINK_PREVIEW,
-        SFXWB_GRAPHIC | SFXWB_MULTISELECTION
+        css::ui::dialogs::TemplateDescription::FILEOPEN_PREVIEW,
+        FileDialogFlags::Graphic | FileDialogFlags::MultiSelection, this
     );
     // Read configuration
     OUString sUrl(officecfg::Office::Impress::Pictures::Path::get());
@@ -481,7 +510,7 @@ IMPL_LINK_NOARG_TYPED(SdPhotoAlbumDialog, FileHdl, Button*, void)
     if (!sUrl.isEmpty())
         aDlg.SetDisplayDirectory(sUrl);
     else
-        aDlg.SetDisplayDirectory( aFile.GetMainURL( INetURLObject::NO_DECODE ) );
+        aDlg.SetDisplayDirectory( aFile.GetMainURL( INetURLObject::DecodeMechanism::NONE ) );
 
     if ( aDlg.Execute() == ERRCODE_NONE )
     {
@@ -501,20 +530,20 @@ IMPL_LINK_NOARG_TYPED(SdPhotoAlbumDialog, FileHdl, Button*, void)
             {
                 // Store full path, show filename only. Use INetURLObject to display spaces in filename correctly
                 INetURLObject aUrl = INetURLObject(aFilesArr[i]);
-                sal_Int16 nPos = pImagesLst->InsertEntry( aUrl.GetLastName(INetURLObject::DECODE_WITH_CHARSET) );
-                pImagesLst->SetEntryData(nPos, new OUString(aUrl.GetMainURL(INetURLObject::DECODE_WITH_CHARSET)));
+                sal_Int16 nPos = pImagesLst->InsertEntry( aUrl.GetLastName(INetURLObject::DecodeMechanism::WithCharset) );
+                pImagesLst->SetEntryData(nPos, new OUString(aUrl.GetMainURL(INetURLObject::DecodeMechanism::NONE)));
             }
         }
     }
     EnableDisableButtons();
 }
 
-IMPL_LINK_NOARG_TYPED(SdPhotoAlbumDialog, UpHdl, Button*, void)
+IMPL_LINK_NOARG(SdPhotoAlbumDialog, UpHdl, Button*, void)
 {
-    if (pImagesLst->GetSelectEntryPos() != LISTBOX_ENTRY_NOTFOUND
-        && pImagesLst->GetSelectEntryPos() != 0)
+    if (pImagesLst->GetSelectedEntryPos() != LISTBOX_ENTRY_NOTFOUND
+        && pImagesLst->GetSelectedEntryPos() != 0)
     {
-        const sal_Int32 nActPos = pImagesLst->GetSelectEntryPos();
+        const sal_Int32 nActPos = pImagesLst->GetSelectedEntryPos();
         OUString sActEntry( pImagesLst->GetEntry(nActPos) );
         // actual data
         OUString* pActData = static_cast<OUString*>(pImagesLst->GetEntryData(nActPos));
@@ -540,13 +569,13 @@ IMPL_LINK_NOARG_TYPED(SdPhotoAlbumDialog, UpHdl, Button*, void)
     EnableDisableButtons();
 }
 
-IMPL_LINK_NOARG_TYPED(SdPhotoAlbumDialog, DownHdl, Button*, void)
+IMPL_LINK_NOARG(SdPhotoAlbumDialog, DownHdl, Button*, void)
 {
-    const sal_Int32 nActPos = pImagesLst->GetSelectEntryPos();
+    const sal_Int32 nActPos = pImagesLst->GetSelectedEntryPos();
     if (!pImagesLst->GetEntry(nActPos + 1).isEmpty())
     {
-        OUString sActEntry( pImagesLst->GetSelectEntry() );
-        OUString* pActData = static_cast<OUString*>(pImagesLst->GetSelectEntryData());
+        OUString sActEntry( pImagesLst->GetSelectedEntry() );
+        OUString* pActData = static_cast<OUString*>(pImagesLst->GetSelectedEntryData());
         OUString sAct(*pActData);
 
         OUString sDownEntry( pImagesLst->GetEntry(nActPos + 1) );
@@ -568,20 +597,20 @@ IMPL_LINK_NOARG_TYPED(SdPhotoAlbumDialog, DownHdl, Button*, void)
     EnableDisableButtons();
 }
 
-IMPL_LINK_NOARG_TYPED(SdPhotoAlbumDialog, RemoveHdl, Button*, void)
+IMPL_LINK_NOARG(SdPhotoAlbumDialog, RemoveHdl, Button*, void)
 {
-    pImagesLst->RemoveEntry( pImagesLst->GetSelectEntryPos() );
+    pImagesLst->RemoveEntry( pImagesLst->GetSelectedEntryPos() );
     pImg->SetImage(Image());
 
     EnableDisableButtons();
 }
 
-IMPL_LINK_NOARG_TYPED(SdPhotoAlbumDialog, SelectHdl, ListBox&, void)
+IMPL_LINK_NOARG(SdPhotoAlbumDialog, SelectHdl, ListBox&, void)
 {
-    OUString* pData = static_cast<OUString*>(pImagesLst->GetSelectEntryData());
-    OUString sImgUrl = pData ? OUString(*pData) : "";
+    OUString* pData = static_cast<OUString*>(pImagesLst->GetSelectedEntryData());
+    OUString sImgUrl = pData ? *pData : "";
 
-    if (sImgUrl != SD_RESSTR(STR_PHOTO_ALBUM_TEXTBOX))
+    if (sImgUrl != SdResId(STR_PHOTO_ALBUM_TEXTBOX))
     {
         GraphicFilter aCurFilter;
         Graphic aGraphic;
@@ -615,17 +644,15 @@ IMPL_LINK_NOARG_TYPED(SdPhotoAlbumDialog, SelectHdl, ListBox&, void)
         Bitmap aBmp = aGraphic.GetBitmap();
         sal_Int32 nBmpWidth  = aBmp.GetSizePixel().Width();
         sal_Int32 nBmpHeight = aBmp.GetSizePixel().Height();
-        sal_Int32 nPrevWidth = 200;
-        sal_Int32 nPrewHeight = 150;
 
-        double nXRatio = (double) nPrevWidth / nBmpWidth;
-        double nYRatio = (double) nPrewHeight / nBmpHeight;
+        double nXRatio = (double) 200 / nBmpWidth;
+        double nYRatio = (double) 150 / nBmpHeight;
         if ( nXRatio < nYRatio )
             aBmp.Scale( nXRatio, nXRatio );
         else
             aBmp.Scale( nYRatio, nYRatio );
 
-        aBmp.Convert( BMP_CONVERSION_24BIT );
+        aBmp.Convert( BmpConversion::N24Bit );
         pImg->SetImage(Image(aBmp));
     }
     else
@@ -635,14 +662,24 @@ IMPL_LINK_NOARG_TYPED(SdPhotoAlbumDialog, SelectHdl, ListBox&, void)
     EnableDisableButtons();
 }
 
+IMPL_LINK_NOARG(SdPhotoAlbumDialog, TypeSelectHdl, ListBox&, void)
+{
+    // Enable "Fill Slide" only for one image
+    // If we want to have it for other images too, we need to implement the actual cropping.
+    bool const bEnable = pInsTypeCombo->GetSelectedEntryPos() == ONE_IMAGE;
+    pASRCheckCrop->Enable(bEnable);
+    if (!bEnable)
+        pASRCheckCrop->Check(false);
+}
+
 Reference< drawing::XDrawPage > SdPhotoAlbumDialog::appendNewSlide(AutoLayout aLayout,
-    Reference< drawing::XDrawPages > xDrawPages
+    const Reference< drawing::XDrawPages >& xDrawPages
 )
 {
     Reference< drawing::XDrawPage > xSlide; // Create the slide
     Reference< container::XIndexAccess > xIndexAccess( xDrawPages, uno::UNO_QUERY );
     xSlide = xDrawPages->insertNewByIndex( xIndexAccess->getCount() );
-    SdPage* pSlide = pDoc->GetSdPage( pDoc->GetSdPageCount(PK_STANDARD)-1, PK_STANDARD);
+    SdPage* pSlide = pDoc->GetSdPage( pDoc->GetSdPageCount(PageKind::Standard)-1, PageKind::Standard);
     pSlide->SetAutoLayout(aLayout, true); // Set the layout here
     return xSlide;
 }
@@ -668,6 +705,46 @@ awt::Size SdPhotoAlbumDialog::createASRSize(const awt::Size& aPicSize, const awt
     return awt::Size(resizeWidth, resizeHeight);
 }
 
+awt::Size SdPhotoAlbumDialog::createASRSizeCrop(const awt::Size& aPicSize, const awt::Size& aMaxSize)
+{
+    double resizeWidth = aPicSize.Width;
+    double resizeHeight = aPicSize.Height;
+    double imgAspect = resizeWidth / resizeHeight;
+    double windowAspectRatio = static_cast<double>(aMaxSize.Width) / aMaxSize.Height ;
+
+
+    //When both sides of an image are bigger than canvas size, image would be downscaled.
+    if( resizeWidth > aMaxSize.Width && resizeHeight > aMaxSize.Height )
+    {
+        if( imgAspect > windowAspectRatio )
+        {
+            resizeHeight = aMaxSize.Height;
+            resizeWidth = aMaxSize.Height * imgAspect;
+        }
+        else
+        {
+            resizeHeight = aMaxSize.Width / imgAspect;
+            resizeWidth = aMaxSize.Width;
+        }
+
+    }
+    //In all other cases image is upscaled
+    else
+    {
+        if( imgAspect > windowAspectRatio )
+        {
+            resizeHeight = aMaxSize.Height;
+            resizeWidth = aMaxSize.Height * imgAspect;
+        }
+        else
+        {
+            resizeWidth = aMaxSize.Width;
+            resizeHeight = aMaxSize.Width / imgAspect;
+        }
+    }
+    return awt::Size(resizeWidth, resizeHeight);
+}
+
 void SdPhotoAlbumDialog::createCaption(const awt::Size& aPageSize )
 {
     Point CapPos;
@@ -677,41 +754,61 @@ void SdPhotoAlbumDialog::createCaption(const awt::Size& aPageSize )
     CapSize.Height() = aPageSize.Height/6;
     CapPos.X() = 0;
     CapPos.Y() = aPageSize.Height - CapSize.Height();
-    SdPage* pSlide = pDoc->GetSdPage( pDoc->GetSdPageCount(PK_STANDARD)-1, PK_STANDARD );
-    Rectangle rRect(CapPos,CapSize);
-    SdrObject* pSdrObj = pSlide->CreatePresObj(PRESOBJ_TITLE,false,rRect);
-    SdrModel* pSdrModel = pDoc->AllocModel();
-    SfxItemSet aSet(pSdrModel->GetItemPool() );
-    aSet.Put( XFillStyleItem(drawing::FillStyle_SOLID) );
-    aSet.Put( XFillColorItem( "", Color(COL_BLACK) ) );
-    aSet.Put( XFillTransparenceItem( 20 ) );
-    pSdrObj->SetMergedItemSetAndBroadcast(aSet);
+    SdPage* pSlide = pDoc->GetSdPage( pDoc->GetSdPageCount(PageKind::Standard)-1, PageKind::Standard );
+
+    // try to get existing PresObj
+    const ::tools::Rectangle rRect(CapPos,CapSize);
+    SdrObject* pSdrObj = pSlide->GetPresObj(PRESOBJ_TITLE);
+
+    if(!pSdrObj)
+    {
+        // if not exists, create. Beware: It is already inserted to the SdPage
+        pSdrObj = pSlide->CreatePresObj(PRESOBJ_TITLE,false,rRect);
+    }
+    else
+    {
+        // if exists, bring to front and position it
+        const size_t nObjNum(pSlide->GetObjCount());
+
+        if(nObjNum)
+        {
+            pSlide->SetObjectOrdNum(pSdrObj->GetOrdNum(), nObjNum - 1);
+        }
+
+        pSdrObj->SetSnapRect(rRect);
+    }
+
+    if(pSdrObj)
+    {
+        // set color, style and some transparency
+        SfxItemSet aSet(pDoc->GetItemPool() );
+
+        aSet.Put( XFillStyleItem(drawing::FillStyle_SOLID) );
+        aSet.Put( XFillColorItem( "", Color(COL_BLACK) ) );
+        aSet.Put( XFillTransparenceItem( 20 ) );
+        pSdrObj->SetMergedItemSetAndBroadcast(aSet);
+    }
 }
 
 Reference< graphic::XGraphic> SdPhotoAlbumDialog::createXGraphicFromUrl(const OUString& sUrl,
-    Reference< graphic::XGraphicProvider> xProvider
+    const Reference< graphic::XGraphicProvider>& xProvider
 )
 {
     // The same as above, except this returns an XGraphic from the image URL
     ::comphelper::NamedValueCollection aMediaProperties;
-    aMediaProperties.put( "URL", OUString( sUrl ) );
+    aMediaProperties.put( "URL", sUrl );
     Reference< graphic::XGraphic> xGraphic =
         xProvider->queryGraphic( aMediaProperties.getPropertyValues() );
     return xGraphic;
 }
 
-short SdPhotoAlbumDialog::Execute()
-{
-    return ModalDialog::Execute();
-}
-
 void SdPhotoAlbumDialog::EnableDisableButtons()
 {
-    pRemoveBtn->Enable(pImagesLst->GetSelectEntryCount() > 0);
-    pUpBtn->Enable(pImagesLst->GetSelectEntryCount() > 0 &&
-                   pImagesLst->GetSelectEntryPos() != 0);
-    pDownBtn->Enable(pImagesLst->GetSelectEntryCount() > 0 &&
-                     pImagesLst->GetSelectEntryPos() < pImagesLst->GetEntryCount()-1);
+    pRemoveBtn->Enable(pImagesLst->GetSelectedEntryCount() > 0);
+    pUpBtn->Enable(pImagesLst->GetSelectedEntryCount() > 0 &&
+                   pImagesLst->GetSelectedEntryPos() != 0);
+    pDownBtn->Enable(pImagesLst->GetSelectedEntryCount() > 0 &&
+                     pImagesLst->GetSelectedEntryPos() < pImagesLst->GetEntryCount()-1);
 }
 
 } // end of namespace sd
