@@ -38,22 +38,23 @@
 #include <sfx2/dockwin.hxx>
 #include <sfx2/sfxresid.hxx>
 
-#include "pres.hxx"
-#include "navigatr.hxx"
-#include "pgjump.hxx"
-#include "app.hrc"
-#include "strings.hrc"
-#include "res_bmp.hrc"
-#include "bitmaps.hlst"
-#include "drawdoc.hxx"
-#include "DrawDocShell.hxx"
-#include "sdresid.hxx"
-#include "ViewShell.hxx"
-#include "ViewShellBase.hxx"
-#include "DrawViewShell.hxx"
-#include "slideshow.hxx"
-#include "FrameView.hxx"
-#include "helpids.h"
+#include <pres.hxx>
+#include <navigatr.hxx>
+#include <pgjump.hxx>
+#include <app.hrc>
+#include <strings.hrc>
+
+#include <bitmaps.hlst>
+#include <drawdoc.hxx>
+#include <DrawDocShell.hxx>
+#include <sdresid.hxx>
+#include <ViewShell.hxx>
+#include <ViewShellBase.hxx>
+#include <DrawViewShell.hxx>
+#include <slideshow.hxx>
+#include <FrameView.hxx>
+#include <helpids.h>
+#include <Window.hxx>
 
 namespace {
 static const sal_uInt16 nShowNamedShapesFilter=1;
@@ -74,7 +75,7 @@ SdNavigatorWin::SdNavigatorWin(vcl::Window* pParent, SfxBindings* pInBindings)
 {
     get(maToolbox, "toolbox");
     get(maTlbObjects, "tree");
-    Size aSize(maTlbObjects->LogicToPixel(Size(97, 67), MapUnit::MapAppFont));
+    Size aSize(maTlbObjects->LogicToPixel(Size(97, 67), MapMode(MapUnit::MapAppFont)));
     maTlbObjects->set_height_request(aSize.Width());
     maTlbObjects->set_width_request(aSize.Height());
     get(maLbDocs, "documents");
@@ -146,7 +147,7 @@ void SdNavigatorWin::FreshTree( const SdDrawDocument* pDoc )
 
 void SdNavigatorWin::FreshEntry( )
 {
-    maTlbObjects->FreshCurEntry();
+    maTlbObjects->Invalidate();
 }
 
 void SdNavigatorWin::InitTreeLB( const SdDrawDocument* pDoc )
@@ -188,7 +189,7 @@ void SdNavigatorWin::InitTreeLB( const SdDrawDocument* pDoc )
         maLbDocs->SelectEntry( aDocShName );
 
 // commented in order to fix 30246
-//        if( maLbDocs->GetSelectEntryCount() == 0 )
+//        if( maLbDocs->GetSelectedEntryCount() == 0 )
         {
             RefreshDocumentLB();
             maLbDocs->SelectEntry( aDocShName );
@@ -215,13 +216,9 @@ NavigatorDragType SdNavigatorWin::GetNavigatorDragType()
     return eDT;
 }
 
-//Get SdDrawDocShell
-sd::DrawDocShell* SdNavigatorWin::GetDrawDocShell( const SdDrawDocument* pDoc )
+VclPtr<SdPageObjsTLB> SdNavigatorWin::GetObjects()
 {
-    if( !pDoc )
-        return nullptr; // const as const can...
-    sd::DrawDocShell* pDocShell = pDoc->GetDocSh();
-    return pDocShell;
+    return maTlbObjects;
 }
 
 IMPL_LINK_NOARG(SdNavigatorWin, SelectToolboxHdl, ToolBox *, void)
@@ -267,11 +264,11 @@ IMPL_LINK( SdNavigatorWin, DropdownClickToolBoxHdl, ToolBox*, pBox, void )
 
         for (sal_uInt16 nID = NAVIGATOR_DRAGTYPE_URL; nID < NAVIGATOR_DRAGTYPE_COUNT; ++nID)
         {
-            sal_uInt16 nRId = GetDragTypeSdStrId((NavigatorDragType)nID);
-            if( nRId > 0 )
+            const char* pRId = GetDragTypeSdStrId((NavigatorDragType)nID);
+            if (pRId)
             {
                 DBG_ASSERT(aHIDs[nID-NAVIGATOR_DRAGTYPE_URL],"HelpId not added!");
-                pMenu->InsertItem(nID, SdResId(nRId), MenuItemBits::RADIOCHECK);
+                pMenu->InsertItem(nID, SdResId(pRId), MenuItemBits::RADIOCHECK);
                 pMenu->SetHelpId(nID, aHIDs[nID - NAVIGATOR_DRAGTYPE_URL]);
             }
 
@@ -317,14 +314,14 @@ IMPL_LINK( SdNavigatorWin, DropdownClickToolBoxHdl, ToolBox*, pBox, void )
 
 IMPL_LINK_NOARG(SdNavigatorWin, ClickObjectHdl, SvTreeListBox*, bool)
 {
-    if( !mbDocImported || maLbDocs->GetSelectEntryPos() != 0 )
+    if( !mbDocImported || maLbDocs->GetSelectedEntryPos() != 0 )
     {
         NavDocInfo* pInfo = GetDocInfo();
 
         // if it is the active window, we jump to the page
         if( pInfo && pInfo->IsActive() )
         {
-            OUString aStr( maTlbObjects->GetSelectEntry() );
+            OUString aStr( maTlbObjects->GetSelectedEntry() );
 
             if( !aStr.isEmpty() )
             {
@@ -333,7 +330,7 @@ IMPL_LINK_NOARG(SdNavigatorWin, ClickObjectHdl, SvTreeListBox*, bool)
                     SID_NAVIGATOR_OBJECT,
                     SfxCallMode::SLOT | SfxCallMode::RECORD, { &aItem });
                 //set sign variable
-                maTlbObjects->MarkCurEntry(aStr);
+                maTlbObjects->Invalidate();
 
                 // moved here from SetGetFocusHdl. Reset the
                 // focus only if something has been selected in the
@@ -346,6 +343,27 @@ IMPL_LINK_NOARG(SdNavigatorWin, ClickObjectHdl, SvTreeListBox*, bool)
                     if ( pShellWnd )
                         pShellWnd->GrabFocus();
                 }
+
+                // We navigated to an object, but the current shell may be
+                // still the slide sorter. Explicitly try to grab the draw
+                // shell focus, so follow-up operations work with the object
+                // and not with the whole slide.
+                sd::DrawDocShell* pDocShell = pInfo->mpDocShell;
+                if (pDocShell)
+                {
+                    sd::ViewShell* pViewShell = pDocShell->GetViewShell();
+                    if (pViewShell)
+                    {
+                        vcl::Window* pWindow = pViewShell->GetActiveWindow();
+                        if (pWindow)
+                            pWindow->GrabFocus();
+                    }
+                }
+
+                if (!maTlbObjects->IsNavigationGrabsFocus())
+                    // This is the case when keyboard navigation inside the
+                    // navigator should continue to work.
+                    maTlbObjects->GrabFocus();
             }
         }
     }
@@ -354,8 +372,8 @@ IMPL_LINK_NOARG(SdNavigatorWin, ClickObjectHdl, SvTreeListBox*, bool)
 
 IMPL_LINK_NOARG(SdNavigatorWin, SelectDocumentHdl, ListBox&, void)
 {
-    OUString aStrLb = maLbDocs->GetSelectEntry();
-    long   nPos = maLbDocs->GetSelectEntryPos();
+    OUString aStrLb = maLbDocs->GetSelectedEntry();
+    long   nPos = maLbDocs->GetSelectedEntryPos();
     bool   bFound = false;
     ::sd::DrawDocShell* pDocShell = nullptr;
     NavDocInfo* pInfo = GetDocInfo();
@@ -499,7 +517,7 @@ bool SdNavigatorWin::InsertFile(const OUString& rFileName)
     {
         // show dragged-in document
         std::shared_ptr<const SfxFilter> pFilter;
-        ErrCode nErr = 0;
+        ErrCode nErr = ERRCODE_NONE;
 
         if (aFileName != maDropFileName)
         {
@@ -564,7 +582,7 @@ void SdNavigatorWin::RefreshDocumentLB( const OUString* pDocName )
     }
     else
     {
-        nPos = maLbDocs->GetSelectEntryPos();
+        nPos = maLbDocs->GetSelectedEntryPos();
         if( nPos == LISTBOX_ENTRY_NOTFOUND )
             nPos = 0;
 
@@ -617,12 +635,12 @@ void SdNavigatorWin::RefreshDocumentLB( const OUString* pDocName )
     maLbDocs->SelectEntryPos( nPos );
 }
 
-sal_uInt16 SdNavigatorWin::GetDragTypeSdStrId(NavigatorDragType eDT)
+const char* SdNavigatorWin::GetDragTypeSdStrId(NavigatorDragType eDT)
 {
     switch( eDT )
     {
         case NAVIGATOR_DRAGTYPE_NONE:
-                return STR_NONE;
+                return STR_SD_NONE;
         case NAVIGATOR_DRAGTYPE_URL:
                 return STR_DRAGTYPE_URL;
         case NAVIGATOR_DRAGTYPE_EMBEDDED:
@@ -631,7 +649,7 @@ sal_uInt16 SdNavigatorWin::GetDragTypeSdStrId(NavigatorDragType eDT)
                 return STR_DRAGTYPE_LINK;
         default: OSL_FAIL( "No resource for DragType available!" );
     }
-    return 0;
+    return nullptr;
 }
 
 OUString SdNavigatorWin::GetDragTypeSdBmpId(NavigatorDragType eDT)
@@ -653,7 +671,7 @@ OUString SdNavigatorWin::GetDragTypeSdBmpId(NavigatorDragType eDT)
 
 NavDocInfo* SdNavigatorWin::GetDocInfo()
 {
-    sal_uInt32 nPos = maLbDocs->GetSelectEntryPos();
+    sal_uInt32 nPos = maLbDocs->GetSelectedEntryPos();
 
     if( mbDocImported )
     {
