@@ -27,34 +27,39 @@
 #include <svx/svdoole2.hxx>
 #include <vcl/svapp.hxx>
 #include <vcl/builderfactory.hxx>
-#include "cusshow.hxx"
+#include <cusshow.hxx>
 #include <sfx2/childwin.hxx>
 
 #include <sfx2/viewfrm.hxx>
 
-#include "strmname.h"
-#include "sdtreelb.hxx"
-#include "DrawDocShell.hxx"
-#include "drawdoc.hxx"
-#include "sdpage.hxx"
-#include "sdresid.hxx"
-#include "navigatr.hxx"
-#include "strings.hrc"
-#include "res_bmp.hrc"
-#include "customshowlist.hxx"
-#include "ViewShell.hxx"
-#include "DrawController.hxx"
-#include "ViewShellBase.hxx"
+#include <strmname.h>
+#include <sdtreelb.hxx>
+#include <DrawDocShell.hxx>
+#include <drawdoc.hxx>
+#include <sdpage.hxx>
+#include <sdresid.hxx>
+#include <navigatr.hxx>
+#include <strings.hrc>
+
+#include <bitmaps.hlst>
+#include <customshowlist.hxx>
+#include <ViewShell.hxx>
+#include <DrawController.hxx>
+#include <ViewShellBase.hxx>
 
 #include <com/sun/star/embed/XEmbedPersist.hpp>
 #include <com/sun/star/frame/Desktop.hpp>
 #include <com/sun/star/frame/XFramesSupplier.hpp>
+#include <svtools/acceleratorexecute.hxx>
 #include <svtools/embedtransfer.hxx>
 #include <svtools/svlbitm.hxx>
 #include <svtools/treelistentry.hxx>
 #include <comphelper/servicehelper.hxx>
 #include <comphelper/processfactory.hxx>
 #include <tools/diagnose_ex.h>
+#include <o3tl/make_unique.hxx>
+#include <comphelper/scopeguard.hxx>
+
 
 using namespace com::sun::star;
 
@@ -81,7 +86,6 @@ bool SdPageObjsTLB::IsInDrag()
 
 SotClipboardFormatId SdPageObjsTLB::SdPageObjsTransferable::mnListBoxDropFormatId = static_cast<SotClipboardFormatId>(SAL_MAX_UINT32);
 
-// - SdPageObjsTLB::SdPageObjsTransferable -
 
 SdPageObjsTLB::SdPageObjsTransferable::SdPageObjsTransferable(
     SdPageObjsTLB& rParent,
@@ -97,14 +101,7 @@ SdPageObjsTLB::SdPageObjsTransferable::SdPageObjsTransferable(
     rParent.SetupDragOrigin();
 }
 
-VCL_BUILDER_DECL_FACTORY(SdPageObjsTLB)
-{
-    WinBits nWinStyle = WB_TABSTOP;
-    OString sBorder = VclBuilder::extractCustomProperty(rMap);
-    if (!sBorder.isEmpty())
-        nWinStyle |= WB_BORDER;
-    rRet = VclPtr<SdPageObjsTLB>::Create(pParent, nWinStyle);
-}
+VCL_BUILDER_FACTORY_CONSTRUCTOR(SdPageObjsTLB, WB_TABSTOP)
 
 SdPageObjsTLB::SdPageObjsTransferable::~SdPageObjsTransferable()
 {
@@ -129,7 +126,7 @@ bool SdPageObjsTLB::SdPageObjsTransferable::GetData( const css::datatransfer::Da
         case SotClipboardFormatId::TREELISTBOX:
         {
             css::uno::Any aTreeListBoxData; // empty for now
-            SetAny(aTreeListBoxData, rFlavor);
+            SetAny(aTreeListBoxData);
             return true;
         }
 
@@ -140,11 +137,11 @@ bool SdPageObjsTLB::SdPageObjsTransferable::GetData( const css::datatransfer::Da
 
 void SdPageObjsTLB::SdPageObjsTransferable::DragFinished( sal_Int8 nDropAction )
 {
-    mrParent.OnDragFinished( nDropAction );
+    mrParent.OnDragFinished();
     SdTransferable::DragFinished(nDropAction);
 }
 
-sal_Int64 SAL_CALL SdPageObjsTLB::SdPageObjsTransferable::getSomething( const css::uno::Sequence< sal_Int8 >& rId ) throw( css::uno::RuntimeException, std::exception )
+sal_Int64 SAL_CALL SdPageObjsTLB::SdPageObjsTransferable::getSomething( const css::uno::Sequence< sal_Int8 >& rId )
 {
     sal_Int64 nRet;
 
@@ -193,37 +190,6 @@ SotClipboardFormatId SdPageObjsTLB::SdPageObjsTransferable::GetListBoxDropFormat
     return mnListBoxDropFormatId;
 }
 
-SdPageObjsTLB::SdPageObjsTLB( vcl::Window* pParentWin, const SdResId& rSdResId )
-:   SvTreeListBox       ( pParentWin, rSdResId )
-,   bisInSdNavigatorWin  ( false )
-,   mpParent            ( pParentWin )
-,   mpDoc               ( nullptr )
-,   mpBookmarkDoc       ( nullptr )
-,   mpMedium            ( nullptr )
-,   mpOwnMedium         ( nullptr )
-,   maImgOle             ( BitmapEx( SdResId( BMP_OLE ) ) )
-,   maImgGraphic         ( BitmapEx( SdResId( BMP_GRAPHIC ) ) )
-,   mbLinkableSelected  ( false )
-,   mpDropNavWin        ( nullptr )
-,   mpFrame             ( nullptr )
-,   mbSaveTreeItemState ( false )
-,   mbShowAllShapes     ( false )
-,   mbShowAllPages      ( false )
-{
-    // add lines to Tree-ListBox
-    SetStyle( GetStyle() | WB_TABSTOP | WB_BORDER | WB_HASLINES |
-                           WB_HASBUTTONS | // WB_HASLINESATROOT |
-                           WB_HSCROLL |
-                           WB_HASBUTTONSATROOT |
-                           WB_QUICK_SEARCH /* i31275 */ );
-    SetNodeBitmaps( Image(Bitmap( SdResId(BMP_EXPAND) )),
-                    Image(Bitmap( SdResId(BMP_COLLAPSE) )));
-
-    SetDragDropMode(
-         DragDropMode::CTRL_MOVE | DragDropMode::CTRL_COPY |
-            DragDropMode::APP_MOVE  | DragDropMode::APP_COPY  | DragDropMode::APP_DROP );
-}
-
 SdPageObjsTLB::SdPageObjsTLB( vcl::Window* pParentWin, WinBits nStyle )
 :   SvTreeListBox       ( pParentWin, nStyle )
 ,   bisInSdNavigatorWin ( false )
@@ -232,29 +198,41 @@ SdPageObjsTLB::SdPageObjsTLB( vcl::Window* pParentWin, WinBits nStyle )
 ,   mpBookmarkDoc       ( nullptr )
 ,   mpMedium            ( nullptr )
 ,   mpOwnMedium         ( nullptr )
-,   maImgOle             ( BitmapEx( SdResId( BMP_OLE ) ) )
-,   maImgGraphic         ( BitmapEx( SdResId( BMP_GRAPHIC ) ) )
+,   maImgOle            ( BitmapEx(BMP_OLE) )
+,   maImgGraphic        ( BitmapEx(BMP_GRAPHIC) )
 ,   mbLinkableSelected  ( false )
 ,   mpDropNavWin        ( nullptr )
 ,   mpFrame             ( nullptr )
 ,   mbSaveTreeItemState ( false )
 ,   mbShowAllShapes     ( false )
 ,   mbShowAllPages      ( false )
+,   mbSelectionHandlerNavigates(false)
+,   mbNavigationGrabsFocus(true)
 {
     // add lines to Tree-ListBox
     SetStyle( GetStyle() | WB_TABSTOP | WB_BORDER | WB_HASLINES |
                            WB_HASBUTTONS | // WB_HASLINESATROOT |
                            WB_HSCROLL |
-                           WB_HASBUTTONSATROOT |
-                           WB_QUICK_SEARCH /* i31275 */ );
-    SetNodeBitmaps( Image(Bitmap( SdResId(BMP_EXPAND) )),
-                    Image(Bitmap( SdResId(BMP_COLLAPSE) )));
+                           WB_HASBUTTONSATROOT );
+    SetQuickSearch(true); /* i31275 */;
+    SetNodeBitmaps(Image(BitmapEx(BMP_EXPAND)), Image(BitmapEx(BMP_COLLAPSE)));
 
     SetDragDropMode(
          DragDropMode::CTRL_MOVE | DragDropMode::CTRL_COPY |
             DragDropMode::APP_MOVE  | DragDropMode::APP_COPY  | DragDropMode::APP_DROP );
+
+    m_pAccel = ::svt::AcceleratorExecute::createAcceleratorHelper();
 }
 
+void SdPageObjsTLB::SetViewFrame( SfxViewFrame* pViewFrame )
+{
+    mpFrame = pViewFrame;
+    sd::ViewShellBase* pBase = sd::ViewShellBase::GetViewShellBase(pViewFrame);
+    const css::uno::Reference< css::frame::XFrame > xFrame = pBase->GetMainViewShell()->GetViewFrame()->GetFrame().GetFrameInterface();
+    m_pAccel->init(::comphelper::getProcessComponentContext(), xFrame);
+}
+
+
 SdPageObjsTLB::~SdPageObjsTLB()
 {
     disposeOnce();
@@ -269,6 +247,7 @@ void SdPageObjsTLB::dispose()
         delete mpMedium;
     mpParent.clear();
     mpDropNavWin.clear();
+    m_pAccel.reset();
     SvTreeListBox::dispose();
 }
 
@@ -284,9 +263,9 @@ OUString SdPageObjsTLB::getAltLongDescText(SvTreeListEntry* pEntry , bool isAltT
     for( pageNo = 0;  pageNo < maxPages; pageNo++ )
     {
         const SdPage* pPage = static_cast<const SdPage*>( mpDoc->GetPage( pageNo ) );
-        if( pPage->GetPageKind() != PK_STANDARD ) continue;
+        if( pPage->GetPageKind() != PageKind::Standard ) continue;
         if( pPage->GetName() !=  ParentName ) continue;
-        SdrObjListIter aIter( *pPage, IM_FLAT );
+        SdrObjListIter aIter( *pPage, SdrIterMode::Flat );
         while( aIter.IsMore() )
         {
             pObj = aIter.Next();
@@ -313,68 +292,13 @@ OUString SdPageObjsTLB::GetEntryLongDescription( SvTreeListEntry* pEntry ) const
     return getAltLongDescText( pEntry, false);
 }
 
-void  SdPageObjsTLB::MarkCurEntry( const OUString& rName )
-{
-
-    if (!rName.isEmpty())
-    {
-        SvTreeListEntry* pCurEntry =GetCurEntry();
-        SvTreeListEntry* pEntry =nullptr;
-        OUString aTmp1;
-        OUString aTmp2;
-
-        if( GetParent(pCurEntry)==nullptr )
-        {
-            aTmp1 = GetEntryText( pCurEntry );
-            for( pEntry = First(); pEntry ; pEntry = Next( pEntry ) )
-            {
-               if(GetParent( pEntry )==nullptr)
-                   continue;
-                aTmp2 = GetEntryText( GetParent( pEntry ));
-                if( aTmp1 != aTmp2)
-                {
-                    // IA2 CWS. MT: Removed in SvTreeListEntry for now - only used in Sw/Sd/ScContentLBoxString, they should decide if they need this
-                    pEntry->SetMarked(false);
-                }
-            }
-        }
-        else
-        {
-            for( pEntry = First(); pEntry ; pEntry = Next( pEntry ) )
-            {
-                aTmp2 = GetEntryText( pEntry );
-                if( aTmp2 == rName)
-                {
-                    pEntry->SetMarked(true);
-                }
-                else
-                {
-                    pEntry->SetMarked(false);
-                }
-            }
-        }
-    }
-    Invalidate();
-}
-
-void  SdPageObjsTLB:: FreshCurEntry()
-{
-    SvTreeListEntry* pEntry =nullptr;
-    for( pEntry = First(); pEntry ; pEntry = Next( pEntry ) )
-    {
-                pEntry->SetMarked(false);
-    }
-    Invalidate();
-}
-
 void SdPageObjsTLB::InitEntry(SvTreeListEntry* pEntry,
     const OUString& rStr, const Image& rImg1, const Image& rImg2, SvLBoxButtonKind eButtonKind)
 {
     sal_uInt16 nColToHilite = 1; //0==Bitmap;1=="Spalte1";2=="Spalte2"
     SvTreeListBox::InitEntry( pEntry, rStr, rImg1, rImg2, eButtonKind );
     SvLBoxString& rCol = static_cast<SvLBoxString&>(pEntry->GetItem( nColToHilite ));
-    std::unique_ptr<SvLBoxString> pStr(new SvLBoxString(pEntry, 0, rCol.GetText()));
-    pEntry->ReplaceItem(std::move(pStr), nColToHilite );
+    pEntry->ReplaceItem(o3tl::make_unique<SvLBoxString>(rCol.GetText()), nColToHilite );
 }
 
 void SdPageObjsTLB::SaveExpandedTreeItemState(SvTreeListEntry* pEntry, std::vector<OUString>& vectTreeItem)
@@ -403,7 +327,7 @@ void SdPageObjsTLB::Clear()
         maSelectionEntryText.clear();
         maTreeItem.clear();
         if (GetCurEntry())
-            maSelectionEntryText = GetSelectEntry();
+            maSelectionEntryText = GetSelectedEntry();
         SvTreeListEntry* pEntry = FirstChild(nullptr);
         SaveExpandedTreeItemState(pEntry, maTreeItem);
     }
@@ -429,7 +353,7 @@ OUString SdPageObjsTLB::GetObjectName(
         && aRet.isEmpty()
         && pObject!=nullptr)
     {
-        aRet = SD_RESSTR(STR_NAVIGATOR_SHAPE_BASE_NAME);
+        aRet = SdResId(STR_NAVIGATOR_SHAPE_BASE_NAME);
         aRet = aRet.replaceFirst("%1", OUString::number(pObject->GetOrdNum() + 1));
     }
 
@@ -499,7 +423,7 @@ void SdPageObjsTLB::Fill( const SdDrawDocument* pInDoc, bool bAllPages,
     OUString aSelection;
     if( GetSelectionCount() > 0 )
     {
-        aSelection = GetSelectEntry();
+        aSelection = GetSelectedEntry();
         Clear();
     }
 
@@ -517,8 +441,8 @@ void SdPageObjsTLB::Fill( const SdDrawDocument* pInDoc, bool bAllPages,
     while( nPage < nMaxPages )
     {
         const SdPage* pPage = static_cast<const SdPage*>( mpDoc->GetPage( nPage ) );
-        if(  (mbShowAllPages || pPage->GetPageKind() == PK_STANDARD)
-             && !(pPage->GetPageKind()==PK_HANDOUT)   ) //#94954# never list the normal handout page ( handout-masterpage is used instead )
+        if(  (mbShowAllPages || pPage->GetPageKind() == PageKind::Standard)
+             && (pPage->GetPageKind() != PageKind::Handout)   ) //#94954# never list the normal handout page ( handout-masterpage is used instead )
         {
             bool bPageExluded = pPage->IsExcluded();
 
@@ -563,8 +487,8 @@ void SdPageObjsTLB::Fill( const SdDrawDocument* pInDoc, SfxMedium* pInMedium,
     mpMedium = pInMedium;
     maDocName = rDocName;
 
-    Image aImgDocOpen=Image( BitmapEx( SdResId( BMP_DOC_OPEN ) ) );
-    Image aImgDocClosed=Image( BitmapEx( SdResId( BMP_DOC_CLOSED ) ) );
+    Image aImgDocOpen=Image(BitmapEx(BMP_DOC_OPEN));
+    Image aImgDocClosed=Image(BitmapEx(BMP_DOC_CLOSED));
 
     // insert document name
     InsertEntry( maDocName, aImgDocOpen, aImgDocClosed, nullptr, true, TREELIST_APPEND,
@@ -602,31 +526,8 @@ void SdPageObjsTLB::AddShapeList (
     SdrObjListIter aIter(
         rList,
         !rList.HasObjectNavigationOrder() /* use navigation order, if available */,
-        IM_FLAT,
-        false /*not reverse*/);
+        SdrIterMode::Flat);
 
-    bool  bMarked=false;
-    if(bisInSdNavigatorWin)
-    {
-        vcl::Window* pWindow=nullptr;
-        SdNavigatorWin* pSdNavigatorWin=nullptr;
-        sd::DrawDocShell* pSdDrawDocShell = nullptr;
-        if(pEntry)
-            pWindow=reinterpret_cast<vcl::Window*>(GetParent(pEntry));
-        if(pWindow)
-            pSdNavigatorWin = static_cast<SdNavigatorWin*>(pWindow);
-        if( pSdNavigatorWin )
-            pSdDrawDocShell = SdNavigatorWin::GetDrawDocShell(mpDoc);
-        if(pSdDrawDocShell)
-            bMarked = pSdDrawDocShell->IsMarked(pShape);
-        if(pEntry)
-        {
-            if(bMarked)
-                pEntry->SetMarked(true);
-            else
-                pEntry->SetMarked(false);
-        }
-    }
     while( aIter.IsMore() )
     {
         SdrObject* pObj = aIter.Next();
@@ -637,9 +538,9 @@ void SdPageObjsTLB::AddShapeList (
 
         if( !aStr.isEmpty() )
         {
-            if( pObj->GetObjInventor() == SdrInventor && pObj->GetObjIdentifier() == OBJ_OLE2 )
+            if( pObj->GetObjInventor() == SdrInventor::Default && pObj->GetObjIdentifier() == OBJ_OLE2 )
             {
-                SvTreeListEntry *pNewEntry = InsertEntry(
+                InsertEntry(
                     aStr,
                     maImgOle,
                     maImgOle,
@@ -648,32 +549,10 @@ void SdPageObjsTLB::AddShapeList (
                     TREELIST_APPEND,
                     pObj
                 );
-
-                if(bisInSdNavigatorWin)
-                {
-                    vcl::Window* pWindow=nullptr;
-                    SdNavigatorWin* pSdNavigatorWin=nullptr;
-                    sd::DrawDocShell* pSdDrawDocShell = nullptr;
-                    if(pNewEntry)
-                        pWindow=reinterpret_cast<vcl::Window*>(GetParent(pNewEntry));
-                    if(pWindow)
-                        pSdNavigatorWin = static_cast<SdNavigatorWin*>(pWindow);
-                    if( pSdNavigatorWin )
-                        pSdDrawDocShell = SdNavigatorWin::GetDrawDocShell(mpDoc);
-                    if(pSdDrawDocShell)
-                        bMarked = pSdDrawDocShell->IsMarked(pObj);
-                    if(pNewEntry)
-                    {
-                        if(bMarked)
-                            pNewEntry->SetMarked(true);
-                        else
-                            pNewEntry->SetMarked(false);
-                    }
-                }
             }
-            else if( pObj->GetObjInventor() == SdrInventor && pObj->GetObjIdentifier() == OBJ_GRAF )
+            else if( pObj->GetObjInventor() == SdrInventor::Default && pObj->GetObjIdentifier() == OBJ_GRAF )
             {
-                SvTreeListEntry *pNewEntry = InsertEntry(
+                InsertEntry(
                     aStr,
                     maImgGraphic,
                     maImgGraphic,
@@ -682,32 +561,6 @@ void SdPageObjsTLB::AddShapeList (
                     TREELIST_APPEND,
                     pObj
                 );
-
-                if(bisInSdNavigatorWin)
-                {
-                    vcl::Window* pWindow=nullptr;
-                    SdNavigatorWin* pSdNavigatorWin=nullptr;
-                    sd::DrawDocShell* pSdDrawDocShell = nullptr;
-                    if(pNewEntry)
-                        pWindow=reinterpret_cast<vcl::Window*>(GetParent(pNewEntry));
-                    if(pWindow)
-                        pSdNavigatorWin = static_cast<SdNavigatorWin*>(pWindow);
-                    if( pSdNavigatorWin )
-                        pSdDrawDocShell = SdNavigatorWin::GetDrawDocShell(mpDoc);
-                    if(pSdDrawDocShell)
-                        bMarked = pSdDrawDocShell->IsMarked(pObj);
-                    if(pNewEntry)
-                    {
-                        if(bMarked)
-                        {
-                            pNewEntry->SetMarked(true);
-                        }
-                        else
-                        {
-                            pNewEntry->SetMarked(false);
-                        }
-                    }
-                }
             }
             else if (pObj->IsGroupObject())
             {
@@ -722,7 +575,7 @@ void SdPageObjsTLB::AddShapeList (
             }
             else
             {
-                SvTreeListEntry *pNewEntry = InsertEntry(
+                InsertEntry(
                     aStr,
                     rIconProvider.maImgObjects,
                     rIconProvider.maImgObjects,
@@ -731,32 +584,6 @@ void SdPageObjsTLB::AddShapeList (
                     TREELIST_APPEND,
                     pObj
                 );
-
-                if(bisInSdNavigatorWin)
-                {
-                    vcl::Window* pWindow=nullptr;
-                    SdNavigatorWin* pSdNavigatorWin=nullptr;
-                    sd::DrawDocShell* pSdDrawDocShell = nullptr;
-                    if(pNewEntry)
-                        pWindow=reinterpret_cast<vcl::Window*>(GetParent(pNewEntry));
-                    if(pWindow)
-                        pSdNavigatorWin = static_cast<SdNavigatorWin*>(pWindow);
-                    if( pSdNavigatorWin )
-                        pSdDrawDocShell = SdNavigatorWin::GetDrawDocShell(mpDoc);
-                    if(pSdDrawDocShell)
-                        bMarked = pSdDrawDocShell->IsMarked(pObj);
-                    if(pNewEntry)
-                    {
-                        if(bMarked)
-                        {
-                            pNewEntry->SetMarked(true);
-                        }
-                        else
-                        {
-                            pNewEntry->SetMarked(false);
-                        }
-                    }
-                }
             }
         }
     }
@@ -802,8 +629,54 @@ void SdPageObjsTLB::SetShowAllShapes (
     }
 }
 
+bool SdPageObjsTLB::IsEqualToShapeList(SvTreeListEntry*& pEntry, const SdrObjList& rList,
+                                       const OUString& rListName)
+{
+    if (!pEntry)
+        return false;
+    OUString aName = GetEntryText(pEntry);
+
+    if (rListName != aName)
+        return false;
+
+    pEntry = Next(pEntry);
+
+    SdrObjListIter aIter(rList,
+                         !rList.HasObjectNavigationOrder() /* use navigation order, if available */,
+                         SdrIterMode::Flat);
+
+    while (aIter.IsMore())
+    {
+        SdrObject* pObj = aIter.Next();
+
+        const OUString aObjectName(GetObjectName(pObj));
+
+        if (!aObjectName.isEmpty())
+        {
+            if (!pEntry)
+                return false;
+
+            aName = GetEntryText(pEntry);
+
+            if (aObjectName != aName)
+                return false;
+
+            if (pObj->IsGroupObject())
+            {
+                bool bRet = IsEqualToShapeList(pEntry, *pObj->GetSubList(), aObjectName);
+                if (!bRet)
+                    return false;
+            }
+            else
+                pEntry = Next(pEntry);
+        }
+    }
+
+    return true;
+}
+
 /**
- * Checks if the pages (PK_STANDARD) of a doc and the objects on the pages
+ * Checks if the pages (PageKind::Standard) of a doc and the objects on the pages
  * are identical to the TreeLB.
  * If a doc is provided, this will be the used doc (important by more than
  * one document).
@@ -816,9 +689,7 @@ bool SdPageObjsTLB::IsEqualToDoc( const SdDrawDocument* pInDoc )
     if( !mpDoc )
         return false;
 
-    SdrObject*   pObj = nullptr;
     SvTreeListEntry* pEntry = First();
-    OUString     aName;
 
     // compare all pages including the objects
     sal_uInt16 nPage = 0;
@@ -827,41 +698,11 @@ bool SdPageObjsTLB::IsEqualToDoc( const SdDrawDocument* pInDoc )
     while( nPage < nMaxPages )
     {
         const SdPage* pPage = static_cast<const SdPage*>( mpDoc->GetPage( nPage ) );
-        if( pPage->GetPageKind() == PK_STANDARD )
+        if( pPage->GetPageKind() == PageKind::Standard )
         {
-            if( !pEntry )
+            bool bRet = IsEqualToShapeList(pEntry, *pPage, pPage->GetName());
+            if (!bRet)
                 return false;
-            aName = GetEntryText( pEntry );
-
-            if( pPage->GetName() != aName )
-                return false;
-
-            pEntry = Next( pEntry );
-
-            SdrObjListIter aIter(
-                *pPage,
-                !pPage->HasObjectNavigationOrder() /* use navigation order, if available */,
-                IM_DEEPWITHGROUPS );
-
-            while( aIter.IsMore() )
-            {
-                pObj = aIter.Next();
-
-                const OUString aObjectName( GetObjectName( pObj ) );
-
-                if( !aObjectName.isEmpty() )
-                {
-                    if( !pEntry )
-                        return false;
-
-                    aName = GetEntryText( pEntry );
-
-                    if( aObjectName != aName )
-                        return false;
-
-                    pEntry = Next( pEntry );
-                }
-            }
         }
         nPage++;
     }
@@ -873,7 +714,7 @@ bool SdPageObjsTLB::IsEqualToDoc( const SdDrawDocument* pInDoc )
 /**
  * @return selected string
  */
-OUString SdPageObjsTLB::GetSelectEntry()
+OUString SdPageObjsTLB::GetSelectedEntry()
 {
     return GetEntryText( GetCurEntry() );
 }
@@ -908,9 +749,9 @@ void SdPageObjsTLB::RequestingChildren( SvTreeListEntry* pFileEntry )
             SdrObject*   pObj = nullptr;
             SvTreeListEntry* pPageEntry = nullptr;
 
-            Image aImgPage     = Image( BitmapEx( SdResId( BMP_PAGE     ) ) );
-            Image aImgPageObjs = Image( BitmapEx( SdResId( BMP_PAGEOBJS ) ) );
-            Image aImgObjects  = Image( BitmapEx( SdResId( BMP_OBJECTS  ) ) );
+            Image aImgPage     = Image(BitmapEx(BMP_PAGE));
+            Image aImgPageObjs = Image(BitmapEx(BMP_PAGEOBJS));
+            Image aImgObjects  = Image(BitmapEx(BMP_OBJECTS));
 
             // document name already inserted
 
@@ -921,7 +762,7 @@ void SdPageObjsTLB::RequestingChildren( SvTreeListEntry* pFileEntry )
             while( nPage < nMaxPages )
             {
                 SdPage* pPage = static_cast<SdPage*>( mpBookmarkDoc->GetPage( nPage ) );
-                if( pPage->GetPageKind() == PK_STANDARD )
+                if( pPage->GetPageKind() == PageKind::Standard )
                 {
                     pPageEntry = InsertEntry( pPage->GetName(),
                                               aImgPage,
@@ -931,7 +772,7 @@ void SdPageObjsTLB::RequestingChildren( SvTreeListEntry* pFileEntry )
                                               TREELIST_APPEND,
                                               reinterpret_cast< void* >( 1 ) );
 
-                    SdrObjListIter aIter( *pPage, IM_DEEPWITHGROUPS );
+                    SdrObjListIter aIter( *pPage, SdrIterMode::DeepWithGroups );
 
                     while( aIter.IsMore() )
                     {
@@ -939,11 +780,11 @@ void SdPageObjsTLB::RequestingChildren( SvTreeListEntry* pFileEntry )
                         OUString aStr( GetObjectName( pObj ) );
                         if( !aStr.isEmpty() )
                         {
-                            if( pObj->GetObjInventor() == SdrInventor && pObj->GetObjIdentifier() == OBJ_OLE2 )
+                            if( pObj->GetObjInventor() == SdrInventor::Default && pObj->GetObjIdentifier() == OBJ_OLE2 )
                             {
                                 InsertEntry(aStr, maImgOle, maImgOle, pPageEntry);
                             }
-                            else if( pObj->GetObjInventor() == SdrInventor && pObj->GetObjIdentifier() == OBJ_GRAF )
+                            else if( pObj->GetObjInventor() == SdrInventor::Default && pObj->GetObjIdentifier() == OBJ_GRAF )
                             {
                                 InsertEntry(aStr, maImgGraphic, maImgGraphic, pPageEntry);
                             }
@@ -1010,11 +851,11 @@ SdDrawDocument* SdPageObjsTLB::GetBookmarkDoc(SfxMedium* pMed)
             // in this mode the document is owned and controlled by the SdDrawDocument
             // it can be released by calling the corresponding CloseBookmarkDoc method
             // successful creation of a document makes this the owner of the medium
-            mpBookmarkDoc = const_cast<SdDrawDocument*>(mpDoc)->OpenBookmarkDoc(*mpMedium);
+            mpBookmarkDoc = const_cast<SdDrawDocument*>(mpDoc)->OpenBookmarkDoc(mpMedium);
 
         if ( !mpBookmarkDoc )
         {
-            ScopedVclPtrInstance< MessageDialog > aErrorBox(this, SD_RESSTR(STR_READ_DATA_ERROR));
+            ScopedVclPtrInstance< MessageDialog > aErrorBox(this, SdResId(STR_READ_DATA_ERROR));
             aErrorBox->Execute();
             mpMedium = nullptr; //On failure the SfxMedium is invalid
         }
@@ -1028,10 +869,10 @@ SdDrawDocument* SdPageObjsTLB::GetBookmarkDoc(SfxMedium* pMed)
  */
 void SdPageObjsTLB::CloseBookmarkDoc()
 {
-    if (mxBookmarkDocShRef.Is())
+    if (mxBookmarkDocShRef.is())
     {
         mxBookmarkDocShRef->DoClose();
-        mxBookmarkDocShRef.Clear();
+        mxBookmarkDocShRef.clear();
 
         // Medium is owned by document, so it's destroyed already
         mpOwnMedium = nullptr;
@@ -1071,6 +912,9 @@ void SdPageObjsTLB::SelectHdl()
     }
 
     SvTreeListBox::SelectHdl();
+
+    if (mbSelectionHandlerNavigates)
+        DoubleClickHdl();
 }
 
 /**
@@ -1078,6 +922,10 @@ void SdPageObjsTLB::SelectHdl()
  */
 void SdPageObjsTLB::KeyInput( const KeyEvent& rKEvt )
 {
+    const vcl::KeyCode& aKeyCode = rKEvt.GetKeyCode();
+    if ( m_pAccel->execute( aKeyCode ) )
+        // the accelerator consumed the event
+        return;
     if( rKEvt.GetKeyCode().GetCode() == KEY_RETURN )
     {
         // commented code from svtools/source/contnr/svimpbox.cxx
@@ -1098,21 +946,12 @@ void SdPageObjsTLB::KeyInput( const KeyEvent& rKEvt )
     {
         if(bisInSdNavigatorWin)
         {
-            bool bMarked=false;
             SvTreeListEntry* pNewEntry = GetCurEntry();
             if (!pNewEntry)
                 return;
             SvTreeListEntry* pParentEntry = GetParent(pNewEntry);
             if (!pParentEntry)
                 return;
-            OUString  aStr(GetSelectEntry());
-            sd::DrawDocShell* pSdDrawDocShell = SdNavigatorWin::GetDrawDocShell(mpDoc);
-            if (pSdDrawDocShell)
-            {
-                pSdDrawDocShell->GotoTreeBookmark(aStr);
-                bMarked = pSdDrawDocShell->GetObjectIsmarked(aStr);
-            }
-            pNewEntry->SetMarked(bMarked);
             Invalidate();
         }
     }
@@ -1120,14 +959,21 @@ void SdPageObjsTLB::KeyInput( const KeyEvent& rKEvt )
         SvTreeListBox::KeyInput( rKEvt );
 }
 
+void SdPageObjsTLB::MouseButtonDown(const MouseEvent& rMEvt)
+{
+    mbSelectionHandlerNavigates = rMEvt.GetClicks() == 1;
+    comphelper::ScopeGuard aNavigationGuard([this]() { this->mbSelectionHandlerNavigates = false; });
+    mbNavigationGrabsFocus = rMEvt.GetClicks() != 1;
+    comphelper::ScopeGuard aGrabGuard([this]() { this->mbNavigationGrabsFocus = true; });
+
+    SvTreeListBox::MouseButtonDown(rMEvt);
+}
+
 /**
  * StartDrag-Request
  */
-void SdPageObjsTLB::StartDrag( sal_Int8 nAction, const Point& rPosPixel)
+void SdPageObjsTLB::StartDrag( sal_Int8, const Point& rPosPixel)
 {
-    (void)nAction;
-    (void)rPosPixel;
-
     SdNavigatorWin* pNavWin = nullptr;
     SvTreeListEntry* pEntry = GetEntry(rPosPixel);
 
@@ -1146,7 +992,7 @@ void SdPageObjsTLB::StartDrag( sal_Int8 nAction, const Point& rPosPixel)
         // targets.  This prevents moving shapes from one page to another.
 
         // Select all entries and disable them as drop targets.
-        SetSelectionMode(MULTIPLE_SELECTION);
+        SetSelectionMode(SelectionMode::Multiple);
         SetCursor(static_cast<SvTreeListEntry*>(nullptr));
         SelectAll(true, false);
         EnableSelectionAsDropTarget(false);
@@ -1165,7 +1011,7 @@ void SdPageObjsTLB::StartDrag( sal_Int8 nAction, const Point& rPosPixel)
 
         // Set selection back to the entry under the mouse.
         SelectAll(false, false);
-        SetSelectionMode(SINGLE_SELECTION);
+        SetSelectionMode(SelectionMode::Single);
         Select(pEntry);
 
         // We can delete the Navigator from ExecuteDrag (when switching to
@@ -1187,17 +1033,17 @@ void SdPageObjsTLB::DoDrag()
     if( mpDropNavWin )
     {
         ::sd::DrawDocShell* pDocShell = mpDoc->GetDocSh();
-        OUString aURL = INetURLObject( pDocShell->GetMedium()->GetPhysicalName(), INetProtocol::File ).GetMainURL( INetURLObject::NO_DECODE );
+        OUString aURL = INetURLObject( pDocShell->GetMedium()->GetPhysicalName(), INetProtocol::File ).GetMainURL( INetURLObject::DecodeMechanism::NONE );
         NavigatorDragType   eDragType = mpDropNavWin->GetNavigatorDragType();
 
-        aURL += "#" + GetSelectEntry();
+        aURL += "#" + GetSelectedEntry();
 
-        INetBookmark    aBookmark( aURL, GetSelectEntry() );
+        INetBookmark    aBookmark( aURL, GetSelectedEntry() );
         sal_Int8        nDNDActions = DND_ACTION_COPYMOVE;
 
         if( eDragType == NAVIGATOR_DRAGTYPE_LINK )
             nDNDActions = DND_ACTION_LINK;  // Either COPY *or* LINK, never both!
-        else if (mpDoc->GetSdPageCount(PK_STANDARD) == 1)
+        else if (mpDoc->GetSdPageCount(PageKind::Standard) == 1)
         {
             // Can not move away the last slide in a document.
             nDNDActions = DND_ACTION_COPY;
@@ -1260,7 +1106,7 @@ void SdPageObjsTLB::DoDrag()
     }
 }
 
-void SdPageObjsTLB::OnDragFinished( sal_uInt8 )
+void SdPageObjsTLB::OnDragFinished()
 {
     if( mpFrame->HasChildWindow( SID_NAVIGATOR ) )
     {
@@ -1367,7 +1213,7 @@ sal_Int8 SdPageObjsTLB::ExecuteDrop( const ExecuteDropEvent& rEvt )
 /**
  * Handler for Dragging
  */
-IMPL_LINK_NOARG_TYPED(SdPageObjsTLB, ExecDragHdl, void*, void)
+IMPL_LINK_NOARG(SdPageObjsTLB, ExecDragHdl, void*, void)
 {
     // as link, then it is allowed to asynchronous, without ImpMouseMoveMsg on
     // the stack, delete the Navigator
@@ -1474,7 +1320,7 @@ SvTreeListEntry* SdPageObjsTLB::GetDropTarget (const Point& rLocation)
         sal_uInt16 nDepth (0);
         do
         {
-            pNext = dynamic_cast<SvTreeListEntry*>(NextVisible(pEntry, &nDepth));
+            pNext = NextVisible(pEntry, &nDepth);
             if (pNext != nullptr && nDepth > 0 && nDepth!=0xffff)
                 pEntry = pNext;
             else
@@ -1486,7 +1332,7 @@ SvTreeListEntry* SdPageObjsTLB::GetDropTarget (const Point& rLocation)
     return pEntry;
 }
 
-bool SdPageObjsTLB::IsDropAllowed (SvTreeListEntry* pEntry)
+bool SdPageObjsTLB::IsDropAllowed (SvTreeListEntry const * pEntry)
 {
     if (pEntry == nullptr)
         return false;
@@ -1543,7 +1389,6 @@ void SdPageObjsTLB::AddShapeToTransferable (
         aObjectDescriptor.maDisplayName = pDocShell->GetMedium()->GetURLObject().GetURLNoPass();
     else
         aObjectDescriptor.maDisplayName.clear();
-    aObjectDescriptor.mbCanLink = false;
 
     rTransferable.SetStartPos(aDragPos);
     rTransferable.SetObjectDescriptor( aObjectDescriptor );
@@ -1603,12 +1448,12 @@ void SdPageObjsTLB::AddShapeToTransferable (
 //===== IconProvider ==========================================================
 
 SdPageObjsTLB::IconProvider::IconProvider()
-    : maImgPage( BitmapEx( SdResId( BMP_PAGE ) ) ),
-      maImgPageExcl( BitmapEx( SdResId( BMP_PAGE_EXCLUDED ) ) ),
-      maImgPageObjsExcl( BitmapEx( SdResId( BMP_PAGEOBJS_EXCLUDED ) ) ),
-      maImgPageObjs( BitmapEx( SdResId( BMP_PAGEOBJS ) ) ),
-      maImgObjects( BitmapEx( SdResId( BMP_OBJECTS ) ) ),
-      maImgGroup( BitmapEx( SdResId( BMP_GROUP ) ) )
+    : maImgPage(BitmapEx(BMP_PAGE)),
+      maImgPageExcl(BitmapEx(BMP_PAGE_EXCLUDED)),
+      maImgPageObjsExcl(BitmapEx(BMP_PAGEOBJS_EXCLUDED)),
+      maImgPageObjs(BitmapEx(BMP_PAGEOBJS)),
+      maImgObjects(BitmapEx(BMP_OBJECTS)),
+      maImgGroup(BitmapEx(BMP_GROUP))
 {
 }
 
