@@ -33,12 +33,12 @@
 #include <svx/dlgutil.hxx>
 #include <vcl/msgbox.hxx>
 
-#include "sdattr.hxx"
-#include "sdresid.hxx"
-#include "optsitem.hxx"
-#include "tpoption.hxx"
-#include "strings.hrc"
-#include "app.hrc"
+#include <sdattr.hxx>
+#include <sdresid.hxx>
+#include <optsitem.hxx>
+#include <tpoption.hxx>
+#include <strings.hrc>
+#include <app.hrc>
 #include <svl/intitem.hxx>
 #include <sfx2/request.hxx>
 
@@ -158,9 +158,6 @@ bool SdTpOptionsContents::FillItemSet( SfxItemSet* rAttrs )
 
 void SdTpOptionsContents::Reset( const SfxItemSet* rAttrs )
 {
-    SdOptionsContentsItem aOptsItem( static_cast<const SdOptionsContentsItem&>( rAttrs->
-                        Get( ATTR_OPTIONS_CONTENTS ) ) );
-
     SdOptionsLayoutItem aLayoutItem( static_cast<const SdOptionsLayoutItem&>( rAttrs->
                         Get( ATTR_OPTIONS_LAYOUT ) ) );
 
@@ -242,13 +239,10 @@ SdTpOptionsMisc::SdTpOptionsMisc(vcl::Window* pParent, const SfxItemSet& rInAttr
     m_pScaleFrame->Hide();
 
     // fill ListBox with metrics
-    SvxStringArray aMetricArr( RID_SVXSTR_FIELDUNIT_TABLE );
-    sal_uInt16 i;
-
-    for ( i = 0; i < aMetricArr.Count(); ++i )
+    for (sal_uInt32 i = 0; i < SvxFieldUnitTable::Count(); ++i)
     {
-        OUString sMetric = aMetricArr.GetStringByPos( i );
-        sal_IntPtr nFieldUnit = aMetricArr.GetValue( i );
+        OUString sMetric = SvxFieldUnitTable::GetString(i);
+        sal_IntPtr nFieldUnit = SvxFieldUnitTable::GetValue(i);
         sal_Int32 nPos = m_pLbMetric->InsertEntry( sMetric );
         m_pLbMetric->SetEntryData( nPos, reinterpret_cast<void*>(nFieldUnit) );
     }
@@ -274,13 +268,13 @@ SdTpOptionsMisc::SdTpOptionsMisc(vcl::Window* pParent, const SfxItemSet& rInAttr
     DBG_ASSERT( pPool, "Where is the Pool?" );
     ePoolUnit = pPool->GetMetric( SID_ATTR_FILL_HATCH );
 
-    // Fuellen der CB
+    // Fill the CB
     sal_uInt16 aTable[ TABLE_COUNT ] =
         { 1, 2, 4, 5, 8, 10, 16, 20, 30, 40, 50, 100 };
 
-    for( i = 0; i < TABLE_COUNT; i++ )
+    for( sal_uInt16 i = 0; i < TABLE_COUNT; i++ )
         m_pCbScale->InsertEntry( GetScale( 1, aTable[i] ) );
-    for( i = 1; i < TABLE_COUNT; i++ )
+    for( sal_uInt16 i = 1; i < TABLE_COUNT; i++ )
         m_pCbScale->InsertEntry( GetScale(  aTable[i], 1 ) );
 }
 
@@ -373,7 +367,7 @@ DeactivateRC SdTpOptionsMisc::DeactivatePage( SfxItemSet* pActiveSet )
             FillItemSet( pActiveSet );
         return DeactivateRC::LeavePage;
     }
-    ScopedVclPtrInstance< WarningBox > aWarnBox( GetParent(), WB_YES_NO, SD_RESSTR( STR_WARN_SCALE_FAIL ) );
+    ScopedVclPtrInstance< WarningBox > aWarnBox( GetParent(), MessBoxStyle::YesNo, SdResId( STR_WARN_SCALE_FAIL ) );
 
     if( aWarnBox->Execute() == RET_YES )
         return DeactivateRC::KeepPage;
@@ -420,12 +414,11 @@ bool SdTpOptionsMisc::FillItemSet( SfxItemSet* rAttrs )
     }
 
     // metric
-    const sal_Int32 nMPos = m_pLbMetric->GetSelectEntryPos();
+    const sal_Int32 nMPos = m_pLbMetric->GetSelectedEntryPos();
     if ( m_pLbMetric->IsValueChangedFromSaved() )
     {
         sal_uInt16 nFieldUnit = (sal_uInt16)reinterpret_cast<sal_IntPtr>(m_pLbMetric->GetEntryData( nMPos ));
-        rAttrs->Put( SfxUInt16Item( GetWhich( SID_ATTR_METRIC ),
-                                     (sal_uInt16)nFieldUnit ) );
+        rAttrs->Put( SfxUInt16Item( GetWhich( SID_ATTR_METRIC ), nFieldUnit ) );
         bModified = true;
     }
 
@@ -537,7 +530,7 @@ VclPtr<SfxTabPage> SdTpOptionsMisc::Create( vcl::Window* pWindow,
 
 IMPL_LINK_NOARG(SdTpOptionsMisc, SelectMetricHdl_Impl, ListBox&, void)
 {
-    sal_Int32 nPos = m_pLbMetric->GetSelectEntryPos();
+    sal_Int32 nPos = m_pLbMetric->GetSelectedEntryPos();
 
     if( nPos != LISTBOX_ENTRY_NOTFOUND )
     {
@@ -606,10 +599,7 @@ bool SdTpOptionsMisc::SetScale( const OUString& aScale, sal_Int32& rX, sal_Int32
         return false;
 
     rY = (long) aTmp.toInt32();
-    if( rY == 0 )
-        return false;
-
-    return true;
+    return rY != 0;
 }
 
 void SdTpOptionsMisc::UpdateCompatibilityControls()
