@@ -20,12 +20,12 @@
 #include <vcl/vclenum.hxx>
 #include <vcl/wrkwin.hxx>
 
-#include "strings.hrc"
-#include "sdresid.hxx"
-#include "DrawDocShell.hxx"
-#include "sdmod.hxx"
-#include "sdiocmpt.hxx"
-#include "vectdlg.hxx"
+#include <strings.hrc>
+#include <sdresid.hxx>
+#include <DrawDocShell.hxx>
+#include <sdmod.hxx>
+#include <sdiocmpt.hxx>
+#include <vectdlg.hxx>
 #include <vcl/bitmapaccess.hxx>
 #include <vcl/msgbox.hxx>
 #include <vcl/metaact.hxx>
@@ -45,7 +45,7 @@ SdVectorizeDlg::SdVectorizeDlg(vcl::Window* pParent, const Bitmap& rBmp, ::sd::D
     get(m_pBmpWin, "source");
     get(m_pMtfWin, "vectorized");
 
-    Size aSize(LogicToPixel(Size(92, 100), MapUnit::MapAppFont));
+    Size aSize(LogicToPixel(Size(92, 100), MapMode(MapUnit::MapAppFont)));
     m_pBmpWin->set_width_request(aSize.Width());
     m_pMtfWin->set_width_request(aSize.Width());
     m_pBmpWin->set_height_request(aSize.Height());
@@ -129,7 +129,7 @@ void SdVectorizeDlg::InitPreviewBmp()
     m_pBmpWin->SetGraphic( aPreviewBmp );
 }
 
-Bitmap SdVectorizeDlg::GetPreparedBitmap( Bitmap& rBmp, Fraction& rScale )
+Bitmap SdVectorizeDlg::GetPreparedBitmap( Bitmap const & rBmp, Fraction& rScale )
 {
     Bitmap      aNew( rBmp );
     const Size  aSizePix( aNew.GetSizePixel() );
@@ -148,7 +148,7 @@ Bitmap SdVectorizeDlg::GetPreparedBitmap( Bitmap& rBmp, Fraction& rScale )
     return aNew;
 }
 
-void SdVectorizeDlg::Calculate( Bitmap& rBmp, GDIMetaFile& rMtf )
+void SdVectorizeDlg::Calculate( Bitmap const & rBmp, GDIMetaFile& rMtf )
 {
     mpDocSh->SetWaitCursor( true );
     m_pPrgs->SetValue( 0 );
@@ -220,12 +220,12 @@ void SdVectorizeDlg::Calculate( Bitmap& rBmp, GDIMetaFile& rMtf )
     mpDocSh->SetWaitCursor( false );
 }
 
-void SdVectorizeDlg::AddTile( BitmapReadAccess* pRAcc, GDIMetaFile& rMtf,
+void SdVectorizeDlg::AddTile( BitmapReadAccess const * pRAcc, GDIMetaFile& rMtf,
                               long nPosX, long nPosY, long nWidth, long nHeight )
 {
-    sal_uLong           nSumR = 0UL, nSumG = 0UL, nSumB = 0UL;
-    const long      nRight = nPosX + nWidth - 1L;
-    const long      nBottom = nPosY + nHeight - 1L;
+    sal_uLong           nSumR = 0, nSumG = 0, nSumB = 0;
+    const long      nRight = nPosX + nWidth - 1;
+    const long      nBottom = nPosY + nHeight - 1;
     const double    fMult = 1.0 / ( nWidth * nHeight );
 
     for( long nY = nPosY; nY <= nBottom; nY++ )
@@ -249,11 +249,11 @@ void SdVectorizeDlg::AddTile( BitmapReadAccess* pRAcc, GDIMetaFile& rMtf,
 
     aRect = PixelToLogic( aRect, rMtf.GetPrefMapMode() );
 
-    if( aRect.Right() > ( rMaxSize.Width() - 1L ) )
-        aRect.Right() = rMaxSize.Width() - 1L;
+    if( aRect.Right() > ( rMaxSize.Width() - 1 ) )
+        aRect.Right() = rMaxSize.Width() - 1;
 
-    if( aRect.Bottom() > ( rMaxSize.Height() - 1L ) )
-        aRect.Bottom() = rMaxSize.Height() - 1L;
+    if( aRect.Bottom() > ( rMaxSize.Height() - 1 ) )
+        aRect.Bottom() = rMaxSize.Height() - 1;
 
     rMtf.AddAction( new MetaLineColorAction( aColor, true ) );
     rMtf.AddAction( new MetaFillColorAction( aColor, true ) );
