@@ -17,11 +17,9 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-
 #include "ConfigurationControllerBroadcaster.hxx"
 #include <com/sun/star/lang/IllegalArgumentException.hpp>
 #include <com/sun/star/lang/DisposedException.hpp>
-#include <tools/debug.hxx>
 #include <tools/diagnose_ex.h>
 
 using namespace ::com::sun::star;
@@ -37,9 +35,6 @@ ConfigurationControllerBroadcaster::ConfigurationControllerBroadcaster (
 {
 }
 
-
-
-
 void ConfigurationControllerBroadcaster::AddListener(
     const Reference<XConfigurationChangeListener>& rxListener,
     const OUString& rsEventType,
@@ -58,9 +53,6 @@ void ConfigurationControllerBroadcaster::AddListener(
     maListenerMap[rsEventType].push_back(aDescriptor);
 }
 
-
-
-
 void ConfigurationControllerBroadcaster::RemoveListener(
     const Reference<XConfigurationChangeListener>& rxListener)
 {
@@ -84,9 +76,6 @@ void ConfigurationControllerBroadcaster::RemoveListener(
     }
 }
 
-
-
-
 void ConfigurationControllerBroadcaster::NotifyListeners (
     const ListenerList& rList,
     const ConfigurationChangeEvent& rEvent)
@@ -117,9 +106,6 @@ void ConfigurationControllerBroadcaster::NotifyListeners (
     }
 }
 
-
-
-
 void ConfigurationControllerBroadcaster::NotifyListeners (const ConfigurationChangeEvent& rEvent)
 {
     // Notify the specialized listeners.
@@ -143,9 +129,6 @@ void ConfigurationControllerBroadcaster::NotifyListeners (const ConfigurationCha
     }
 }
 
-
-
-
 void ConfigurationControllerBroadcaster::NotifyListeners (
     const OUString& rsEventType,
     const Reference<XResourceId>& rxResourceId,
@@ -164,11 +147,7 @@ void ConfigurationControllerBroadcaster::NotifyListeners (
     }
 }
 
-
-
-
-
-void ConfigurationControllerBroadcaster::DisposeAndClear (void)
+void ConfigurationControllerBroadcaster::DisposeAndClear()
 {
     lang::EventObject aEvent;
     aEvent.Source = mxConfigurationController;
@@ -186,8 +165,8 @@ void ConfigurationControllerBroadcaster::DisposeAndClear (void)
         }
         else
         {
-            Reference<lang::XEventListener> xListener (
-                iMap->second.front().mxListener, UNO_QUERY);
+            Reference<XConfigurationChangeListener> xListener (
+                iMap->second.front().mxListener );
             if (xListener.is())
             {
                 // Tell the listener that the configuration controller is
@@ -195,7 +174,7 @@ void ConfigurationControllerBroadcaster::DisposeAndClear (void)
                 // types).
                 try
                 {
-                    RemoveListener(iMap->second.front().mxListener);
+                    RemoveListener(xListener);
                     xListener->disposing(aEvent);
                 }
                 catch (const RuntimeException&)
@@ -212,9 +191,6 @@ void ConfigurationControllerBroadcaster::DisposeAndClear (void)
     }
 }
 
-
-
-
 } } // end of namespace sd::framework
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
