@@ -17,7 +17,6 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-
 #include <svx/svxids.hrc>
 
 //-> Fonts & Items
@@ -40,8 +39,7 @@
 #include <editeng/numitem.hxx>
 #include <editeng/eeitem.hxx>
 
-#include "bulmaper.hxx"
-
+#include <bulmaper.hxx>
 
 #define GetWhich(nSlot) rSet.GetPool()->GetWhich( nSlot )
 
@@ -53,56 +51,52 @@ void SdBulletMapper::MapFontsInNumRule( SvxNumRule& aNumRule, const SfxItemSet&
         const SvxNumberFormat& rSrcLevel = aNumRule.GetLevel(nLevel);
         SvxNumberFormat aNewLevel( rSrcLevel );
 
-        if(rSrcLevel.GetNumberingType() != com::sun::star::style::NumberingType::CHAR_SPECIAL &&
-           rSrcLevel.GetNumberingType() != com::sun::star::style::NumberingType::NUMBER_NONE )
+        if(rSrcLevel.GetNumberingType() != css::style::NumberingType::CHAR_SPECIAL &&
+           rSrcLevel.GetNumberingType() != css::style::NumberingType::NUMBER_NONE )
         {
             // if enumeration instead bullet is chosen, adjust bullet font to template font
 
             // to be implemented if module supports CJK
-            long nFontID = SID_ATTR_CHAR_FONT;
-            long nFontHeightID = SID_ATTR_CHAR_FONTHEIGHT;
-            long nWeightID = SID_ATTR_CHAR_WEIGHT;
-            long nPostureID = SID_ATTR_CHAR_POSTURE;
 
-            Font aMyFont;
+            vcl::Font aMyFont;
             const SvxFontItem& rFItem =
-                (SvxFontItem&)rSet.Get(GetWhich( (sal_uInt16)nFontID ));
+                static_cast<const SvxFontItem&>(rSet.Get(GetWhich( (sal_uInt16)SID_ATTR_CHAR_FONT )));
             aMyFont.SetFamily(rFItem.GetFamily());
-            aMyFont.SetName(rFItem.GetFamilyName());
+            aMyFont.SetFamilyName(rFItem.GetFamilyName());
             aMyFont.SetCharSet(rFItem.GetCharSet());
             aMyFont.SetPitch(rFItem.GetPitch());
 
             const SvxFontHeightItem& rFHItem =
-                (SvxFontHeightItem&)rSet.Get(GetWhich( (sal_uInt16)nFontHeightID ));
-            aMyFont.SetSize(Size(0, rFHItem.GetHeight()));
+                static_cast<const SvxFontHeightItem&>(rSet.Get(GetWhich( (sal_uInt16)SID_ATTR_CHAR_FONTHEIGHT )));
+            aMyFont.SetFontSize(Size(0, rFHItem.GetHeight()));
 
             const SvxWeightItem& rWItem =
-                (SvxWeightItem&)rSet.Get(GetWhich( (sal_uInt16)nWeightID ));
+                static_cast<const SvxWeightItem&>(rSet.Get(GetWhich( (sal_uInt16)SID_ATTR_CHAR_WEIGHT )));
             aMyFont.SetWeight(rWItem.GetWeight());
 
             const SvxPostureItem& rPItem =
-                (SvxPostureItem&)rSet.Get(GetWhich( (sal_uInt16)nPostureID ));
+                static_cast<const SvxPostureItem&>(rSet.Get(GetWhich( (sal_uInt16)SID_ATTR_CHAR_POSTURE )));
             aMyFont.SetItalic(rPItem.GetPosture());
 
-            const SvxUnderlineItem& rUItem = (SvxUnderlineItem&)rSet.Get(GetWhich(SID_ATTR_CHAR_UNDERLINE));
+            const SvxUnderlineItem& rUItem = static_cast<const SvxUnderlineItem&>(rSet.Get(GetWhich(SID_ATTR_CHAR_UNDERLINE)));
             aMyFont.SetUnderline(rUItem.GetLineStyle());
 
-            const SvxOverlineItem& rOItem = (SvxOverlineItem&)rSet.Get(GetWhich(SID_ATTR_CHAR_OVERLINE));
+            const SvxOverlineItem& rOItem = static_cast<const SvxOverlineItem&>(rSet.Get(GetWhich(SID_ATTR_CHAR_OVERLINE)));
             aMyFont.SetOverline(rOItem.GetLineStyle());
 
-            const SvxCrossedOutItem& rCOItem = (SvxCrossedOutItem&)rSet.Get(GetWhich(SID_ATTR_CHAR_STRIKEOUT));
+            const SvxCrossedOutItem& rCOItem = static_cast<const SvxCrossedOutItem&>(rSet.Get(GetWhich(SID_ATTR_CHAR_STRIKEOUT)));
             aMyFont.SetStrikeout(rCOItem.GetStrikeout());
 
-            const SvxContourItem& rCItem = (SvxContourItem&)rSet.Get(GetWhich(SID_ATTR_CHAR_CONTOUR));
+            const SvxContourItem& rCItem = static_cast<const SvxContourItem&>(rSet.Get(GetWhich(SID_ATTR_CHAR_CONTOUR)));
             aMyFont.SetOutline(rCItem.GetValue());
 
-            const SvxShadowedItem& rSItem = (SvxShadowedItem&)rSet.Get(GetWhich(SID_ATTR_CHAR_SHADOWED));
+            const SvxShadowedItem& rSItem = static_cast<const SvxShadowedItem&>(rSet.Get(GetWhich(SID_ATTR_CHAR_SHADOWED)));
             aMyFont.SetShadow(rSItem.GetValue());
 
             aNewLevel.SetBulletFont(&aMyFont);
             aNumRule.SetLevel(nLevel, aNewLevel );
         }
-        else if( rSrcLevel.GetNumberingType() == com::sun::star::style::NumberingType::CHAR_SPECIAL )
+        else if( rSrcLevel.GetNumberingType() == css::style::NumberingType::CHAR_SPECIAL )
         {
             aNewLevel.SetPrefix("");
             aNewLevel.SetSuffix("");
