@@ -17,7 +17,7 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "fuchar.hxx"
+#include <fuchar.hxx>
 #include <svx/dialogs.hrc>
 #include <sfx2/viewfrm.hxx>
 
@@ -29,13 +29,14 @@
 #include <vcl/msgbox.hxx>
 #include <sfx2/bindings.hxx>
 #include <sfx2/request.hxx>
-#include "View.hxx"
-#include "drawview.hxx"
-#include "drawdoc.hxx"
-#include "DrawViewShell.hxx"
-#include "ViewShell.hxx"
-#include "DrawDocShell.hxx"
-#include "sdabstdlg.hxx"
+#include <View.hxx>
+#include <Window.hxx>
+#include <drawview.hxx>
+#include <drawdoc.hxx>
+#include <DrawViewShell.hxx>
+#include <ViewShell.hxx>
+#include <DrawDocShell.hxx>
+#include <sdabstdlg.hxx>
 #include <memory>
 
 namespace sd {
@@ -67,35 +68,11 @@ void FuChar::DoExecute( SfxRequest& rReq )
         SfxItemSet aEditAttr( mpDoc->GetPool() );
         mpView->GetAttributes( aEditAttr );
 
-        static const sal_uInt16 aRanges[] =
-        {
-            EE_ITEMS_START, EE_ITEMS_END,
-            SID_ATTR_BRUSH_CHAR, SID_ATTR_BRUSH_CHAR,
-            0
-        };
-
-        SfxItemSet aNewAttr( mpViewShell->GetPool(),
-                                aRanges );
+        SfxItemSet aNewAttr(mpViewShell->GetPool(), svl::Items<EE_ITEMS_START, EE_ITEMS_END>{});
         aNewAttr.Put( aEditAttr, false );
 
-        // EE_CHAR_BKGCOLOR is SvxBackgroundColorItem, but char background tabpage
-        // can only work with SvxBrushItems (it requires major undertaking to have
-        // it support anything else). Do the following then:
-        const SfxPoolItem* pItem;
-        if ( aNewAttr.GetItemState( EE_CHAR_BKGCOLOR, true, &pItem ) == SfxItemState::SET )
-        {
-            // extract Color outta SvxBackColorItem
-            Color aBackColor = static_cast<const SvxBackgroundColorItem*>(pItem)->GetValue();
-            // make new SvxBrushItem with this Color
-            SvxBrushItem aBrushItem( aBackColor, SID_ATTR_BRUSH_CHAR );
-
-            aNewAttr.ClearItem( EE_CHAR_BKGCOLOR );
-            // and stick it into the set
-            aNewAttr.Put( aBrushItem );
-        }
-
         SdAbstractDialogFactory* pFact = SdAbstractDialogFactory::Create();
-        std::unique_ptr<SfxAbstractTabDialog> pDlg(pFact ? pFact->CreateSdTabCharDialog( nullptr, &aNewAttr, mpDoc->GetDocSh() ) : nullptr);
+        ScopedVclPtr<SfxAbstractTabDialog> pDlg(pFact ? pFact->CreateSdTabCharDialog(mpViewShell->GetActiveWindow(), &aNewAttr, mpDoc->GetDocSh() ) : nullptr);
         sal_uInt16 nResult = RET_CANCEL;
         if( pDlg )
         {
@@ -109,19 +86,19 @@ void FuChar::DoExecute( SfxRequest& rReq )
             if( nResult == RET_OK )
             {
                 const SfxItemSet* pOutputSet = pDlg->GetOutputItemSet();
-                SfxItemSet pOtherSet( *pOutputSet );
+                SfxItemSet aOtherSet( *pOutputSet );
 
                 // and now the reverse process
-                const SvxBrushItem* pBrushItem= static_cast<const SvxBrushItem*>(pOtherSet.GetItem( SID_ATTR_BRUSH_CHAR ));
+                const SvxBrushItem* pBrushItem = aOtherSet.GetItem<SvxBrushItem>( SID_ATTR_BRUSH_CHAR );
 
                 if ( pBrushItem )
                 {
                     SvxBackgroundColorItem aBackColorItem( pBrushItem->GetColor(), EE_CHAR_BKGCOLOR );
-                    pOtherSet.ClearItem( SID_ATTR_BRUSH_CHAR );
-                    pOtherSet.Put( aBackColorItem );
+                    aOtherSet.ClearItem( SID_ATTR_BRUSH_CHAR );
+                    aOtherSet.Put( aBackColorItem );
                 }
 
-                rReq.Done( pOtherSet );
+                rReq.Done( aOtherSet );
                 pArgs = rReq.GetArgs();
             }
         }
@@ -133,7 +110,7 @@ void FuChar::DoExecute( SfxRequest& rReq )
     mpView->SetAttributes(*pArgs);
 
     // invalidate the Slots which are in DrTxtObjBar
-    static sal_uInt16 SidArray[] = {
+    static const sal_uInt16 SidArray[] = {
                     SID_ATTR_CHAR_FONT,
                     SID_ATTR_CHAR_POSTURE,
                     SID_ATTR_CHAR_WEIGHT,
@@ -142,11 +119,11 @@ void FuChar::DoExecute( SfxRequest& rReq )
                     SID_ATTR_CHAR_UNDERLINE,
                     SID_ATTR_CHAR_FONTHEIGHT,
                     SID_ATTR_CHAR_COLOR,
-                    SID_ATTR_CHAR_BACK_COLOR,
                     SID_ATTR_CHAR_KERNING,
                     SID_ATTR_CHAR_CASEMAP,
                     SID_SET_SUPER_SCRIPT,
                     SID_SET_SUB_SCRIPT,
+                    SID_ATTR_CHAR_BACK_COLOR,
                     0 };
 
     mpViewShell->GetViewFrame()->GetBindings().Invalidate( SidArray );
