@@ -17,31 +17,35 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
+#include <config_features.h>
 
-#include "fuinsert.hxx"
+#include <fuinsert.hxx>
 
 #include <comphelper/storagehelper.hxx>
 #include <comphelper/processfactory.hxx>
 #include <toolkit/helper/vclunohelper.hxx>
 #include <svx/svxdlg.hxx>
+#include <com/sun/star/embed/EmbedVerbs.hpp>
 #include <com/sun/star/embed/NoVisualAreaSizeException.hpp>
 #include <com/sun/star/embed/XComponentSupplier.hpp>
 #include <com/sun/star/embed/Aspects.hpp>
 #include <com/sun/star/beans/XPropertySet.hpp>
 #include <com/sun/star/chart2/XChartDocument.hpp>
 #include <com/sun/star/drawing/FillStyle.hpp>
+#include <com/sun/star/ui/dialogs/TemplateDescription.hpp>
 
 #include <tools/urlobj.hxx>
 #include <svl/urihelper.hxx>
 #include <sfx2/docfile.hxx>
 #include <sfx2/msgpool.hxx>
-#include <svtools/sores.hxx>
+#include <sfx2/filedlghelper.hxx>
+#include <svtools/strings.hrc>
 #include <svtools/insdlg.hxx>
 #include <sfx2/request.hxx>
 #include <svl/globalnameitem.hxx>
 #include <unotools/pathoptions.hxx>
 #include <svtools/miscopt.hxx>
-#include <svx/pfiledlg.hxx>
+#include <svtools/embedhlp.hxx>
 #include <svx/dialogs.hrc>
 #include <sfx2/linkmgr.hxx>
 #include <svx/linkwarn.hxx>
@@ -65,103 +69,153 @@
 #include <sfx2/opengrf.hxx>
 #include <sfx2/viewfrm.hxx>
 #include <svx/charthelper.hxx>
+#include <comphelper/lok.hxx>
 
-#include "app.hrc"
-#include "sdresid.hxx"
-#include "View.hxx"
-#include "sdmod.hxx"
-#include "Window.hxx"
-#include "drawview.hxx"
-#include "DrawViewShell.hxx"
-#include "DrawDocShell.hxx"
-#include "GraphicDocShell.hxx"
-#include "strings.hrc"
-#include "drawdoc.hxx"
-#include "sdgrffilter.hxx"
-#include "sdxfer.hxx"
+#include <app.hrc>
+#include <sdresid.hxx>
+#include <View.hxx>
+#include <sdmod.hxx>
+#include <Window.hxx>
+#include <drawview.hxx>
+#include <DrawViewShell.hxx>
+#include <DrawDocShell.hxx>
+#include <GraphicDocShell.hxx>
+#include <strings.hrc>
+#include <drawdoc.hxx>
+#include <sdgrffilter.hxx>
+#include <sdxfer.hxx>
 #include <vcl/svapp.hxx>
-#include "undo/undoobjects.hxx"
-#include "glob.hrc"
+#include <undo/undoobjects.hxx>
+#include <memory>
 
 using namespace com::sun::star;
 
 namespace sd {
 
-TYPEINIT1( FuInsertGraphic, FuPoor );
-TYPEINIT1( FuInsertClipboard, FuPoor );
-TYPEINIT1( FuInsertOLE, FuPoor );
-TYPEINIT1( FuInsertAVMedia, FuPoor );
 
 FuInsertGraphic::FuInsertGraphic (
     ViewShell* pViewSh,
     ::sd::Window* pWin,
     ::sd::View* pView,
     SdDrawDocument* pDoc,
-    SfxRequest& rReq)
-    : FuPoor(pViewSh, pWin, pView, pDoc, rReq)
+    SfxRequest& rReq,
+    bool replaceExistingImage)
+    : FuPoor(pViewSh, pWin, pView, pDoc, rReq),
+      mbReplaceExistingImage(replaceExistingImage)
 {
 }
 
-rtl::Reference<FuPoor> FuInsertGraphic::Create( ViewShell* pViewSh, ::sd::Window* pWin, ::sd::View* pView, SdDrawDocument* pDoc, SfxRequest& rReq )
+rtl::Reference<FuPoor> FuInsertGraphic::Create( ViewShell* pViewSh, ::sd::Window* pWin, ::sd::View* pView,
+                                                SdDrawDocument* pDoc, SfxRequest& rReq, bool replaceExistingImage )
 {
-    rtl::Reference<FuPoor> xFunc( new FuInsertGraphic( pViewSh, pWin, pView, pDoc, rReq ) );
+    rtl::Reference<FuPoor> xFunc( new FuInsertGraphic( pViewSh, pWin, pView, pDoc, rReq, replaceExistingImage ) );
     xFunc->DoExecute(rReq);
     return xFunc;
 }
 
-void FuInsertGraphic::DoExecute( SfxRequest&  )
+void FuInsertGraphic::DoExecute( SfxRequest& rReq )
 {
-    SvxOpenGraphicDialog    aDlg(SdResId(STR_INSERTGRAPHIC));
+    OUString aFileName;
+    OUString aFilterName;
+    Graphic aGraphic;
 
-    if( aDlg.Execute() == GRFILTER_OK )
+    bool bAsLink = false;
+    ErrCode nError = ERRCODE_GRFILTER_OPENERROR;
+
+    const SfxItemSet* pArgs = rReq.GetArgs();
+    const SfxPoolItem* pItem;
+
+    if ( pArgs &&
+         pArgs->GetItemState( SID_INSERT_GRAPHIC, true, &pItem ) == SfxItemState::SET )
     {
-        Graphic     aGraphic;
-        int nError = aDlg.GetGraphic(aGraphic);
-        if( nError == GRFILTER_OK )
+        aFileName = static_cast<const SfxStringItem*>(pItem)->GetValue();
+
+        if ( pArgs->GetItemState( FN_PARAM_FILTER, true, &pItem ) == SfxItemState::SET )
+            aFilterName = static_cast<const SfxStringItem*>(pItem)->GetValue();
+
+        if ( pArgs->GetItemState( FN_PARAM_1, true, &pItem ) == SfxItemState::SET )
+            bAsLink = static_cast<const SfxBoolItem*>(pItem)->GetValue();
+
+        nError = GraphicFilter::LoadGraphic( aFileName, aFilterName, aGraphic, &GraphicFilter::GetGraphicFilter() );
+    }
+    else
+    {
+        SvxOpenGraphicDialog aDlg(SdResId(STR_INSERTGRAPHIC), mpWindow);
+
+        if( aDlg.Execute() != ERRCODE_NONE )
+            return; // cancel dialog
+
+        nError = aDlg.GetGraphic(aGraphic);
+        bAsLink = aDlg.IsAsLink();
+        aFileName = aDlg.GetPath();
+        aFilterName = aDlg.GetDetectedFilter();
+    }
+
+    if( nError == ERRCODE_NONE )
+    {
+        if( mpViewShell && dynamic_cast< DrawViewShell *>( mpViewShell ) !=  nullptr)
         {
-            if( mpViewShell && mpViewShell->ISA(DrawViewShell))
+            sal_Int8    nAction = DND_ACTION_COPY;
+            SdrObject* pPickObj = mpView->GetEmptyPresentationObject( PRESOBJ_GRAPHIC );
+            bool bSelectionReplaced(false);
+
+            if( pPickObj )
             {
-                sal_Int8    nAction = DND_ACTION_COPY;
-                SdrObject* pPickObj;
+                nAction = DND_ACTION_LINK;
+            }
+            else if(mbReplaceExistingImage && mpView->GetMarkedObjectCount() == 1)
+            {
+                pPickObj = mpView->GetMarkedObjectByIndex(0);
+                nAction = DND_ACTION_MOVE;
+                bSelectionReplaced = true;
+            }
 
-                if( ( pPickObj = mpView->GetSelectedSingleObject( mpView->GetPage() ) ) || ( pPickObj = mpView->GetEmptyPresentationObject( PRESOBJ_GRAPHIC ) ) )
-                    nAction = DND_ACTION_LINK;
-
-                Point aPos;
-                Rectangle aRect(aPos, mpWindow->GetOutputSizePixel() );
+            Point aPos;
+            // For LOK, set position to center of the page
+            if (comphelper::LibreOfficeKit::isActive())
+                aPos = ::tools::Rectangle(aPos, mpView->GetSdrPageView()->GetPage()->GetSize()).Center();
+            else
+            {
+                ::tools::Rectangle aRect(aPos, mpWindow->GetOutputSizePixel() );
                 aPos = aRect.Center();
+                bool bMapModeWasEnabled(mpWindow->IsMapModeEnabled());
+                mpWindow->EnableMapMode(/*true*/);
                 aPos = mpWindow->PixelToLogic(aPos);
-                SdrGrafObj* pGrafObj = mpView->InsertGraphic(aGraphic, nAction, aPos, pPickObj, NULL);
+                mpWindow->EnableMapMode(bMapModeWasEnabled);
+            }
 
-                if(pGrafObj && aDlg.IsAsLink())
+            SdrGrafObj* pGrafObj = mpView->InsertGraphic(aGraphic, nAction, aPos, pPickObj, nullptr);
+
+            if(pGrafObj && bAsLink )
+            {
+                // really store as link only?
+                if( SvtMiscOptions().ShowLinkWarningDialog() )
                 {
-                    // really store as link only?
-                    if( SvtMiscOptions().ShowLinkWarningDialog() )
-                    {
-                        SvxLinkWarningDialog aWarnDlg(mpWindow,aDlg.GetPath());
-                        if( aWarnDlg.Execute() != RET_OK )
-                            return; // don't store as link
-                    }
-
-                    // store as link
-                    OUString aFltName(aDlg.GetCurrentFilter());
-                    OUString aPath(aDlg.GetPath());
-                    OUString aReferer;
-                    if (mpDocSh->HasName()) {
-                        aReferer = mpDocSh->GetMedium()->GetName();
-                    }
-                    pGrafObj->SetGraphicLink(aPath, aReferer, aFltName);
+                    ScopedVclPtrInstance< SvxLinkWarningDialog > aWarnDlg(mpWindow, aFileName);
+                    if( aWarnDlg->Execute() != RET_OK )
+                        return; // don't store as link
                 }
+
+                // store as link
+                OUString aReferer;
+                if (mpDocSh->HasName()) {
+                    aReferer = mpDocSh->GetMedium()->GetName();
+                }
+                pGrafObj->SetGraphicLink(aFileName, aReferer, aFilterName);
+            }
+
+            if(bSelectionReplaced && pGrafObj)
+            {
+                mpView->MarkObj(pGrafObj, mpView->GetSdrPageView());
             }
         }
-        else
-        {
-            SdGRFFilter::HandleGraphicFilterError( (sal_uInt16)nError, GraphicFilter::GetGraphicFilter().GetLastError().nStreamError );
-        }
+    }
+    else
+    {
+        SdGRFFilter::HandleGraphicFilterError( nError, GraphicFilter::GetGraphicFilter().GetLastError().nStreamError );
     }
 }
 
-
 FuInsertClipboard::FuInsertClipboard (
     ViewShell* pViewSh,
     ::sd::Window* pWin,
@@ -182,58 +236,57 @@ rtl::Reference<FuPoor> FuInsertClipboard::Create( ViewShell* pViewSh, ::sd::Wind
 void FuInsertClipboard::DoExecute( SfxRequest&  )
 {
     TransferableDataHelper                      aDataHelper( TransferableDataHelper::CreateFromSystemClipboard( mpWindow ) );
-    sal_uLong                                       nFormatId;
+    SotClipboardFormatId                        nFormatId;
 
     SvxAbstractDialogFactory* pFact = SvxAbstractDialogFactory::Create();
-    SfxAbstractPasteDialog* pDlg = pFact->CreatePasteDialog( mpViewShell->GetActiveWindow() );
+    ScopedVclPtr<SfxAbstractPasteDialog> pDlg(pFact->CreatePasteDialog( mpViewShell->GetActiveWindow() ));
     if ( pDlg )
     {
-        ::com::sun::star::datatransfer::DataFlavor  aFlavor;
-
-        pDlg->Insert( SOT_FORMATSTR_ID_EMBED_SOURCE, OUString() );
-        pDlg->Insert( SOT_FORMATSTR_ID_LINK_SOURCE, OUString() );
-        pDlg->Insert( SOT_FORMATSTR_ID_DRAWING, OUString() );
-        pDlg->Insert( SOT_FORMATSTR_ID_SVXB, OUString() );
-        pDlg->Insert( FORMAT_GDIMETAFILE, OUString() );
-        pDlg->Insert( FORMAT_BITMAP, OUString() );
-        pDlg->Insert( SOT_FORMATSTR_ID_NETSCAPE_BOOKMARK, OUString() );
-        pDlg->Insert( FORMAT_STRING, OUString() );
-        pDlg->Insert( SOT_FORMATSTR_ID_HTML, OUString() );
-        pDlg->Insert( FORMAT_RTF, OUString() );
-        pDlg->Insert( SOT_FORMATSTR_ID_EDITENGINE, OUString() );
+        pDlg->Insert( SotClipboardFormatId::EMBED_SOURCE, OUString() );
+        pDlg->Insert( SotClipboardFormatId::LINK_SOURCE, OUString() );
+        pDlg->Insert( SotClipboardFormatId::DRAWING, OUString() );
+        pDlg->Insert( SotClipboardFormatId::SVXB, OUString() );
+        pDlg->Insert( SotClipboardFormatId::GDIMETAFILE, OUString() );
+        pDlg->Insert( SotClipboardFormatId::BITMAP, OUString() );
+        pDlg->Insert( SotClipboardFormatId::NETSCAPE_BOOKMARK, OUString() );
+        pDlg->Insert( SotClipboardFormatId::STRING, OUString() );
+        pDlg->Insert( SotClipboardFormatId::HTML, OUString() );
+        pDlg->Insert( SotClipboardFormatId::RTF, OUString() );
+        pDlg->Insert( SotClipboardFormatId::RICHTEXT, OUString() );
+        pDlg->Insert( SotClipboardFormatId::EDITENGINE_ODF_TEXT_FLAT, OUString() );
 
         //TODO/MBA: testing
         nFormatId = pDlg->GetFormat( aDataHelper );
-        if( nFormatId && aDataHelper.GetTransferable().is() )
+        if( nFormatId != SotClipboardFormatId::NONE && aDataHelper.GetTransferable().is() )
         {
             sal_Int8 nAction = DND_ACTION_COPY;
+            DrawViewShell* pDrViewSh = nullptr;
 
-            if( !mpView->InsertData( aDataHelper,
-                                    mpWindow->PixelToLogic( Rectangle( Point(), mpWindow->GetOutputSizePixel() ).Center() ),
-                                    nAction, sal_False, nFormatId ) &&
-                ( mpViewShell && mpViewShell->ISA( DrawViewShell ) ) )
+            if (!mpView->InsertData( aDataHelper,
+                                    mpWindow->PixelToLogic( ::tools::Rectangle( Point(), mpWindow->GetOutputSizePixel() ).Center() ),
+                                    nAction, false, nFormatId ))
             {
-                DrawViewShell* pDrViewSh = static_cast<DrawViewShell*>(mpViewShell);
-                INetBookmark        aINetBookmark( aEmptyStr, aEmptyStr );
+                pDrViewSh = dynamic_cast<DrawViewShell*>(mpViewShell);
+            }
 
-                if( ( aDataHelper.HasFormat( SOT_FORMATSTR_ID_NETSCAPE_BOOKMARK ) &&
-                    aDataHelper.GetINetBookmark( SOT_FORMATSTR_ID_NETSCAPE_BOOKMARK, aINetBookmark ) ) ||
-                    ( aDataHelper.HasFormat( SOT_FORMATSTR_ID_FILEGRPDESCRIPTOR ) &&
-                    aDataHelper.GetINetBookmark( SOT_FORMATSTR_ID_FILEGRPDESCRIPTOR, aINetBookmark ) ) ||
-                    ( aDataHelper.HasFormat( SOT_FORMATSTR_ID_UNIFORMRESOURCELOCATOR ) &&
-                    aDataHelper.GetINetBookmark( SOT_FORMATSTR_ID_UNIFORMRESOURCELOCATOR, aINetBookmark ) ) )
+            if (pDrViewSh)
+            {
+                INetBookmark        aINetBookmark( "", "" );
+
+                if( ( aDataHelper.HasFormat( SotClipboardFormatId::NETSCAPE_BOOKMARK ) &&
+                    aDataHelper.GetINetBookmark( SotClipboardFormatId::NETSCAPE_BOOKMARK, aINetBookmark ) ) ||
+                    ( aDataHelper.HasFormat( SotClipboardFormatId::FILEGRPDESCRIPTOR ) &&
+                    aDataHelper.GetINetBookmark( SotClipboardFormatId::FILEGRPDESCRIPTOR, aINetBookmark ) ) ||
+                    ( aDataHelper.HasFormat( SotClipboardFormatId::UNIFORMRESOURCELOCATOR ) &&
+                    aDataHelper.GetINetBookmark( SotClipboardFormatId::UNIFORMRESOURCELOCATOR, aINetBookmark ) ) )
                 {
-                    pDrViewSh->InsertURLField( aINetBookmark.GetURL(), aINetBookmark.GetDescription(), aEmptyStr, NULL );
+                    pDrViewSh->InsertURLField( aINetBookmark.GetURL(), aINetBookmark.GetDescription(), "" );
                 }
             }
         }
-
-        delete pDlg;
     }
 }
 
-
-
 FuInsertOLE::FuInsertOLE (
     ViewShell* pViewSh,
     ::sd::Window* pWin,
@@ -288,7 +341,7 @@ void FuInsertOLE::DoExecute( SfxRequest& rReq )
 
             MapUnit aUnit = VCLUnoHelper::UnoEmbed2VCLMapUnit( xObj->getMapUnit( nAspect ) );
 
-            Rectangle aRect;
+            ::tools::Rectangle aRect;
             if( pPickObj )
             {
                 aRect = pPickObj->GetLogicRect();
@@ -317,23 +370,23 @@ void FuInsertOLE::DoExecute( SfxRequest& rReq )
                     // rectangle with balanced edge ratio
                     aSize.Width()  = 14100;
                     aSize.Height() = 10000;
-                    Size aTmp = OutputDevice::LogicToLogic( aSize, MAP_100TH_MM, aUnit );
+                    Size aTmp = OutputDevice::LogicToLogic(aSize, MapMode(MapUnit::Map100thMM), MapMode(aUnit));
                     aSz.Width = aTmp.Width();
                     aSz.Height = aTmp.Height();
                     xObj->setVisualAreaSize( nAspect, aSz );
                 }
                 else
                 {
-                    aSize = OutputDevice::LogicToLogic(aSize, aUnit, MAP_100TH_MM);
+                    aSize = OutputDevice::LogicToLogic(aSize, MapMode(aUnit), MapMode(MapUnit::Map100thMM));
                 }
 
                 Point aPos;
-                Rectangle aWinRect(aPos, mpWindow->GetOutputSizePixel() );
+                ::tools::Rectangle aWinRect(aPos, mpWindow->GetOutputSizePixel() );
                 aPos = aWinRect.Center();
                 aPos = mpWindow->PixelToLogic(aPos);
                 aPos.X() -= aSize.Width() / 2;
                 aPos.Y() -= aSize.Height() / 2;
-                aRect = Rectangle(aPos, aSize);
+                aRect = ::tools::Rectangle(aPos, aSize);
             }
 
             SdrOle2Obj* pOleObj = new SdrOle2Obj( svt::EmbeddedObjectRef( xObj, nAspect ), aObjName, aRect );
@@ -360,32 +413,32 @@ void FuInsertOLE::DoExecute( SfxRequest& rReq )
 
             bool bRet = true;
             if( pPickObj )
-                mpView->ReplaceObjectAtView(pPickObj, *pPV, pOleObj, sal_True );
+                mpView->ReplaceObjectAtView(pPickObj, *pPV, pOleObj );
             else
-                bRet = mpView->InsertObjectAtView(pOleObj, *pPV, SDRINSERT_SETDEFLAYER);
+                bRet = mpView->InsertObjectAtView(pOleObj, *pPV, SdrInsertFlags::SETDEFLAYER);
 
             if( bRet )
             {
                 if (nSlotId == SID_INSERT_DIAGRAM)
                 {
-                    pOleObj->SetProgName( OUString( "StarChart" ));
+                    pOleObj->SetProgName( "StarChart");
                 }
                 else if (nSlotId == SID_ATTR_TABLE)
                 {
-                    pOleObj->SetProgName( OUString( "StarCalc" ) );
+                    pOleObj->SetProgName( "StarCalc" );
                 }
                 else if (nSlotId == SID_INSERT_MATH)
                 {
-                    pOleObj->SetProgName( OUString( "StarMath" ) );
+                    pOleObj->SetProgName( "StarMath" );
                 }
 
                 pOleObj->SetLogicRect(aRect);
-                Size aTmp( OutputDevice::LogicToLogic( aRect.GetSize(), MAP_100TH_MM, aUnit ) );
+                Size aTmp( OutputDevice::LogicToLogic(aRect.GetSize(), MapMode(MapUnit::Map100thMM), MapMode(aUnit)) );
                 awt::Size aVisualSize;
                 aVisualSize.Width = aTmp.Width();
                 aVisualSize.Height = aTmp.Height();
                 xObj->setVisualAreaSize( nAspect, aVisualSize );
-                mpViewShell->ActivateObject(pOleObj, SVVERB_SHOW);
+                mpViewShell->ActivateObject(pOleObj, embed::EmbedVerbs::MS_OLEVERB_SHOW);
 
                 if (nSlotId == SID_INSERT_DIAGRAM)
                 {
@@ -399,14 +452,14 @@ void FuInsertOLE::DoExecute( SfxRequest& rReq )
         else
         {
             ErrorHandler::HandleError(* new StringErrorInfo(ERRCODE_SFX_OLEGENERAL,
-                                        aEmptyStr ) );
+                                        "" ) );
         }
     }
     else
     {
         // insert object
         sal_Int64 nAspect = embed::Aspects::MSOLE_CONTENT;
-        sal_Bool bCreateNew = sal_False;
+        bool bCreateNew = false;
         uno::Reference < embed::XEmbeddedObject > xObj;
         uno::Reference < embed::XStorage > xStorage = comphelper::OStorageHelper::GetTemporaryStorage();
         SvObjectServerList aServerLst;
@@ -415,7 +468,7 @@ void FuInsertOLE::DoExecute( SfxRequest& rReq )
         OUString aIconMediaType;
         uno::Reference< io::XInputStream > xIconMetaFile;
 
-        SFX_REQUEST_ARG( rReq, pNameItem, SfxGlobalNameItem, SID_INSERT_OBJECT, sal_False );
+        const SfxGlobalNameItem* pNameItem = rReq.GetArg<SfxGlobalNameItem>(SID_INSERT_OBJECT);
         if ( nSlotId == SID_INSERT_OBJECT && pNameItem )
         {
             SvGlobalName aClassName = pNameItem->GetValue();
@@ -429,7 +482,7 @@ void FuInsertOLE::DoExecute( SfxRequest& rReq )
                 case SID_INSERT_OBJECT :
                 {
                     aServerLst.FillInsertObjects();
-                    if (mpDoc->GetDocumentType() == DOCUMENT_TYPE_DRAW)
+                    if (mpDoc->GetDocumentType() == DocumentType::Draw)
                     {
                         aServerLst.Remove( GraphicDocShell::Factory().GetClassId() );
                     }
@@ -438,15 +491,14 @@ void FuInsertOLE::DoExecute( SfxRequest& rReq )
                         aServerLst.Remove( DrawDocShell::Factory().GetClassId() );
                     }
 
-                    // intentionally no break!
+                    SAL_FALLTHROUGH;
                 }
-                case SID_INSERT_PLUGIN :
                 case SID_INSERT_FLOATINGFRAME :
                 {
                     SvxAbstractDialogFactory* pFact = SvxAbstractDialogFactory::Create();
-                    SfxAbstractInsertObjectDialog* pDlg =
+                    ScopedVclPtr<SfxAbstractInsertObjectDialog> pDlg(
                             pFact->CreateInsertObjectDialog( mpViewShell->GetActiveWindow(), SD_MOD()->GetSlotPool()->GetSlot(nSlotId)->GetCommandString(),
-                            xStorage, &aServerLst );
+                            xStorage, &aServerLst ));
                     if ( pDlg )
                     {
                         pDlg->Execute();
@@ -459,50 +511,10 @@ void FuInsertOLE::DoExecute( SfxRequest& rReq )
 
                         if ( xObj.is() )
                             mpViewShell->GetObjectShell()->GetEmbeddedObjectContainer().InsertEmbeddedObject( xObj, aName );
-                        DELETEZ( pDlg );
                     }
 
                     break;
                 }
-                case SID_INSERT_SOUND :
-                case SID_INSERT_VIDEO :
-                {
-                    // create special filedialog for plugins
-                    SvxPluginFileDlg aPluginFileDialog (mpWindow, nSlotId);
-                    if( ERRCODE_NONE == aPluginFileDialog.Execute () )
-                    {
-                        // get URL
-                        OUString aStrURL(aPluginFileDialog.GetPath());
-                        INetURLObject aURL( aStrURL, INET_PROT_FILE );
-                        if( aURL.GetProtocol() != INET_PROT_NOT_VALID )
-                        {
-                            // create a plugin object
-                            xObj = mpViewShell->GetObjectShell()->GetEmbeddedObjectContainer().CreateEmbeddedObject( SvGlobalName( SO3_PLUGIN_CLASSID ).GetByteSequence(), aName );
-                        }
-
-                        if ( xObj.is() && svt::EmbeddedObjectRef::TryRunningState( xObj ) )
-                        {
-                            // set properties from dialog
-                            uno::Reference < embed::XComponentSupplier > xSup( xObj, uno::UNO_QUERY );
-                            if ( xSup.is() )
-                            {
-                                uno::Reference < beans::XPropertySet > xSet( xSup->getComponent(), uno::UNO_QUERY );
-                                if ( xSet.is() )
-                                {
-                                    xSet->setPropertyValue("PluginURL",
-                                            uno::makeAny( OUString( aURL.GetMainURL( INetURLObject::NO_DECODE ) ) ) );
-                                }
-                            }
-                        }
-                        else
-                        {
-                            // unable to create PlugIn
-                            OUString aStrErr( SdResId( STR_ERROR_OBJNOCREATE_PLUGIN ) );
-                            aStrErr = aStrErr.replaceFirst( "%", aStrURL );
-                            ErrorBox( mpWindow, WB_3DLOOK | WB_OK, aStrErr ).Execute();
-                        }
-                    }
-                }
             }
         }
 
@@ -510,14 +522,10 @@ void FuInsertOLE::DoExecute( SfxRequest& rReq )
         {
             if (xObj.is())
             {
-                //TODO/LATER: needs status for RESIZEONPRINTERCHANGE
-                //if( SVOBJ_MISCSTATUS_RESIZEONPRINTERCHANGE & xObj->getStatus( nAspect ) )
-                //    aIPObj->OnDocumentPrinterChanged( mpDocSh->GetPrinter(sal_False) );
-
-                sal_Bool bInsertNewObject = sal_True;
+                bool bInsertNewObject = true;
 
                 Size aSize;
-                MapUnit aMapUnit = MAP_100TH_MM;
+                MapUnit aMapUnit = MapUnit::Map100thMM;
                 if ( nAspect != embed::Aspects::MSOLE_ICON )
                 {
                     awt::Size aSz;
@@ -538,14 +546,14 @@ void FuInsertOLE::DoExecute( SfxRequest& rReq )
                         // rectangle with balanced edge ratio
                         aSize.Width()  = 14100;
                         aSize.Height() = 10000;
-                        Size aTmp = OutputDevice::LogicToLogic( aSize, MAP_100TH_MM, aMapUnit );
+                        Size aTmp = OutputDevice::LogicToLogic(aSize, MapMode(MapUnit::Map100thMM), MapMode(aMapUnit));
                         aSz.Width = aTmp.Width();
                         aSz.Height = aTmp.Height();
                         xObj->setVisualAreaSize( nAspect, aSz );
                     }
                     else
                     {
-                        aSize = OutputDevice::LogicToLogic(aSize, aMapUnit, MAP_100TH_MM);
+                        aSize = OutputDevice::LogicToLogic(aSize, MapMode(aMapUnit), MapMode(MapUnit::Map100thMM));
                     }
                 }
 
@@ -559,29 +567,29 @@ void FuInsertOLE::DoExecute( SfxRequest& rReq )
                         SdrMark* pMark = rMarkList.GetMark(0);
                         SdrObject* pObj = pMark->GetMarkedSdrObj();
 
-                        if (pObj->GetObjInventor() == SdrInventor &&
+                        if (pObj->GetObjInventor() == SdrInventor::Default &&
                         pObj->GetObjIdentifier() == OBJ_OLE2)
                         {
-                            if ( !( (SdrOle2Obj*) pObj)->GetObjRef().is() )
+                            if ( !static_cast<SdrOle2Obj*>(pObj)->GetObjRef().is() )
                             {
                                 // the empty OLE object gets a new IPObj
-                                bInsertNewObject = sal_False;
-                                pObj->SetEmptyPresObj(sal_False);
-                                ( (SdrOle2Obj*) pObj)->SetOutlinerParaObject(NULL);
-                                ( (SdrOle2Obj*) pObj)->SetObjRef(xObj);
-                                ( (SdrOle2Obj*) pObj)->SetPersistName(aName);
-                                ( (SdrOle2Obj*) pObj)->SetName(aName);
-                                ( (SdrOle2Obj*) pObj)->SetAspect(nAspect);
-                                Rectangle aRect = ( (SdrOle2Obj*) pObj)->GetLogicRect();
+                                bInsertNewObject = false;
+                                pObj->SetEmptyPresObj(false);
+                                static_cast<SdrOle2Obj*>(pObj)->SetOutlinerParaObject(nullptr);
+                                static_cast<SdrOle2Obj*>(pObj)->SetObjRef(xObj);
+                                static_cast<SdrOle2Obj*>(pObj)->SetPersistName(aName);
+                                static_cast<SdrOle2Obj*>(pObj)->SetName(aName);
+                                static_cast<SdrOle2Obj*>(pObj)->SetAspect(nAspect);
+                                ::tools::Rectangle aRect = static_cast<SdrOle2Obj*>(pObj)->GetLogicRect();
 
                                 if ( nAspect == embed::Aspects::MSOLE_ICON )
                                 {
                                     if( xIconMetaFile.is() )
-                                        ( (SdrOle2Obj*) pObj)->SetGraphicToObj( xIconMetaFile, aIconMediaType );
+                                        static_cast<SdrOle2Obj*>(pObj)->SetGraphicToObj( xIconMetaFile, aIconMediaType );
                                 }
                                 else
                                 {
-                                    Size aTmp = OutputDevice::LogicToLogic( aRect.GetSize(), MAP_100TH_MM, aMapUnit );
+                                    Size aTmp = OutputDevice::LogicToLogic(aRect.GetSize(), MapMode(MapUnit::Map100thMM), MapMode(aMapUnit));
                                     awt::Size aSz( aTmp.Width(), aTmp.Height() );
                                     xObj->setVisualAreaSize( nAspect, aSz );
                                 }
@@ -601,17 +609,17 @@ void FuInsertOLE::DoExecute( SfxRequest& rReq )
                     if ( nAspect == embed::Aspects::MSOLE_ICON )
                     {
                         aObjRef.SetGraphicStream( xIconMetaFile, aIconMediaType );
-                        MapMode aMapMode( MAP_100TH_MM );
+                        MapMode aMapMode( MapUnit::Map100thMM );
                         aSize = aObjRef.GetSize( &aMapMode );
                     }
 
                     Point aPnt ((aPageSize.Width()  - aSize.Width())  / 2,
                         (aPageSize.Height() - aSize.Height()) / 2);
-                    Rectangle aRect (aPnt, aSize);
+                    ::tools::Rectangle aRect (aPnt, aSize);
 
                     SdrOle2Obj* pObj = new SdrOle2Obj( aObjRef, aName, aRect);
 
-                    if( mpView->InsertObjectAtView(pObj, *pPV, SDRINSERT_SETDEFLAYER) )
+                    if( mpView->InsertObjectAtView(pObj, *pPV, SdrInsertFlags::SETDEFLAYER) )
                     {
                         //  Math objects change their object size during InsertObject.
                         //  New size must be set in SdrObject, or a wrong scale will be set at
@@ -624,7 +632,7 @@ void FuInsertOLE::DoExecute( SfxRequest& rReq )
                                 awt::Size aSz = xObj->getVisualAreaSize( nAspect );
 
                                 Size aNewSize = Window::LogicToLogic( Size( aSz.Width, aSz.Height ),
-                                    MapMode( aMapUnit ), MapMode( MAP_100TH_MM ) );
+                                    MapMode( aMapUnit ), MapMode( MapUnit::Map100thMM ) );
                                 if ( aNewSize != aSize )
                                 {
                                     aRect.SetSize( aNewSize );
@@ -641,16 +649,16 @@ void FuInsertOLE::DoExecute( SfxRequest& rReq )
 
                             if ( nAspect != embed::Aspects::MSOLE_ICON )
                             {
-                                Size aTmp = OutputDevice::LogicToLogic( aRect.GetSize(), MAP_100TH_MM, aMapUnit );
+                                Size aTmp = OutputDevice::LogicToLogic(aRect.GetSize(), MapMode(MapUnit::Map100thMM), MapMode(aMapUnit));
                                 awt::Size aSz( aTmp.Width(), aTmp.Height() );
                                 xObj->setVisualAreaSize( nAspect, aSz );
                             }
 
-                            mpViewShell->ActivateObject(pObj, SVVERB_SHOW);
+                            mpViewShell->ActivateObject(pObj, embed::EmbedVerbs::MS_OLEVERB_SHOW);
                         }
 
                         Size aVisSizePixel = mpWindow->GetOutputSizePixel();
-                        Rectangle aVisAreaWin = mpWindow->PixelToLogic( Rectangle( Point(0,0), aVisSizePixel) );
+                        ::tools::Rectangle aVisAreaWin = mpWindow->PixelToLogic( ::tools::Rectangle( Point(0,0), aVisSizePixel) );
                         mpViewShell->VisAreaChanged(aVisAreaWin);
                         mpDocSh->SetVisArea(aVisAreaWin);
                     }
@@ -665,8 +673,6 @@ void FuInsertOLE::DoExecute( SfxRequest& rReq )
     }
 }
 
-
-
 FuInsertAVMedia::FuInsertAVMedia(
     ViewShell* pViewSh,
     ::sd::Window* pWin,
@@ -692,7 +698,7 @@ void FuInsertAVMedia::DoExecute( SfxRequest& rReq )
 
     if( pReqArgs )
     {
-        const SfxStringItem* pStringItem = PTR_CAST( SfxStringItem, &pReqArgs->Get( rReq.GetSlot() ) );
+        const SfxStringItem* pStringItem = dynamic_cast<const SfxStringItem*>( &pReqArgs->Get( rReq.GetSlot() )  );
 
         if( pStringItem )
         {
@@ -702,14 +708,18 @@ void FuInsertAVMedia::DoExecute( SfxRequest& rReq )
     }
 
     bool bLink(true);
-    if (bAPI ||
-        ::avmedia::MediaWindow::executeMediaURLDialog(mpWindow, aURL, & bLink))
+    if (bAPI
+#if HAVE_FEATURE_AVMEDIA
+        || ::avmedia::MediaWindow::executeMediaURLDialog(mpWindow, aURL, & bLink)
+#endif
+       )
     {
         Size aPrefSize;
 
         if( mpWindow )
             mpWindow->EnterWait();
 
+#if HAVE_FEATURE_AVMEDIA
         if( !::avmedia::MediaWindow::isMediaURL( aURL, "", true, &aPrefSize ) )
         {
             if( mpWindow )
@@ -727,16 +737,16 @@ void FuInsertAVMedia::DoExecute( SfxRequest& rReq )
             if( aPrefSize.Width() && aPrefSize.Height() )
             {
                 if( mpWindow )
-                    aSize = mpWindow->PixelToLogic( aPrefSize, MAP_100TH_MM );
+                    aSize = mpWindow->PixelToLogic(aPrefSize, MapMode(MapUnit::Map100thMM));
                 else
-                    aSize = Application::GetDefaultDevice()->PixelToLogic( aPrefSize, MAP_100TH_MM );
+                    aSize = Application::GetDefaultDevice()->PixelToLogic(aPrefSize, MapMode(MapUnit::Map100thMM));
             }
             else
                 aSize = Size( 5000, 5000 );
 
             if( mpWindow )
             {
-                aPos = mpWindow->PixelToLogic( Rectangle( aPos, mpWindow->GetOutputSizePixel() ).Center() );
+                aPos = mpWindow->PixelToLogic( ::tools::Rectangle( aPos, mpWindow->GetOutputSizePixel() ).Center() );
                 aPos.X() -= aSize.Width() >> 1;
                 aPos.Y() -= aSize.Height() >> 1;
             }
@@ -746,6 +756,12 @@ void FuInsertAVMedia::DoExecute( SfxRequest& rReq )
             if( mpWindow )
                 mpWindow->LeaveWait();
         }
+#else
+        if( mpWindow )
+            mpWindow->LeaveWait();
+        (void) aPrefSize;
+        (void) bLink;
+#endif
     }
 }
 
