@@ -1,4 +1,4 @@
-/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4; fill-column: 100 -*- */
 /*
  * This file is part of the LibreOffice project.
  *
@@ -6,8 +6,12 @@
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  */
+
+#include <config_dbus.h>
+
 #include <time.h>
 #include <iostream>
+#include <limits>
 #include <new>
 #include <stdlib.h>
 #include <assert.h>
@@ -20,8 +24,11 @@
 #include <avahi-common/error.h>
 #include <avahi-common/timeval.h>
 #include <avahi-common/thread-watch.h>
+#include <comphelper/random.hxx>
 
+#if ENABLE_DBUS
 #include <dbus/dbus.h>
+#endif
 
 #include <sal/log.hxx>
 
@@ -30,15 +37,15 @@
 
 using namespace sd;
 
-static AvahiClient *client = NULL;
-static AvahiThreadedPoll *threaded_poll = NULL;
-static AvahiEntryGroup *group = NULL;
-static AvahiNetworkService *avahiService = NULL;
+static AvahiClient *client = nullptr;
+static AvahiThreadedPoll *threaded_poll = nullptr;
+static AvahiEntryGroup *group = nullptr;
+static AvahiNetworkService *avahiService = nullptr;
 
 static bool create_services(AvahiClient *c);
 
 static void entry_group_callback(AvahiEntryGroup *g, AvahiEntryGroupState state, AVAHI_GCC_UNUSED void *userdata) {
-    assert(g == group || group == NULL);
+    assert(g == group || group == nullptr);
     group = g;
 
     /* Called whenever the entry group state changes */
@@ -46,7 +53,7 @@ static void entry_group_callback(AvahiEntryGroup *g, AvahiEntryGroupState state,
     switch (state) {
         case AVAHI_ENTRY_GROUP_ESTABLISHED :
             /* The entry group has been established successfully */
-            SAL_INFO( "sdremote.wifi", "Service " << avahiService->getName() << " successfully established." );
+            SAL_INFO( "sdremote.wifi", "Service '" << avahiService->getName() << "' successfully established." );
             break;
 
         case AVAHI_ENTRY_GROUP_COLLISION : {
@@ -57,7 +64,7 @@ static void entry_group_callback(AvahiEntryGroup *g, AvahiEntryGroupState state,
             n = avahi_alternative_service_name(avahiService->getName().c_str());
             avahiService->setName(n);
 
-            SAL_INFO( "sdremote.wifi", "Service name collision, renaming service to " << avahiService->getName() );
+            SAL_INFO( "sdremote.wifi", "Service name collision, renaming service to '" << avahiService->getName() << "'");
 
             /* And recreate the services */
             create_services(avahi_entry_group_get_client(g));
@@ -66,7 +73,7 @@ static void entry_group_callback(AvahiEntryGroup *g, AvahiEntryGroupState state,
 
         case AVAHI_ENTRY_GROUP_FAILURE :
 
-            fprintf(stderr, "Entry group failure: %s\n", avahi_strerror(avahi_client_errno(avahi_entry_group_get_client(g))));
+            SAL_WARN("sdremote.wifi", "Entry group failure: " << avahi_strerror(avahi_client_errno(avahi_entry_group_get_client(g))));
 
             /* Some kind of failure happened while we were registering our services */
             avahi_threaded_poll_quit(threaded_poll);
@@ -87,8 +94,8 @@ static bool create_services(AvahiClient *c) {
         return false;
 
     if (!group)
-        if (!(group = avahi_entry_group_new(c, entry_group_callback, NULL))) {
-            fprintf(stderr, "avahi_entry_group_new() failed: %s\n", avahi_strerror(avahi_client_errno(c)));
+        if (!(group = avahi_entry_group_new(c, entry_group_callback, nullptr))) {
+            SAL_WARN("sdremote.wifi", "avahi_entry_group_new() failed: " << avahi_strerror(avahi_client_errno(c)));
             avahiService->clear();
             return false;
         }
@@ -97,12 +104,13 @@ static bool create_services(AvahiClient *c) {
      * because it was reset previously, add our entries.  */
 
     if (avahi_entry_group_is_empty(group)) {
-        fprintf(stderr, "Adding service '%s'\n", avahiService->getName().c_str());
+        SAL_INFO("sdremote.wifi", "Adding service '" << avahiService->getName() << "'");
         char r[128];
-        snprintf(r, sizeof(r), "random=%i", rand());
+        int nRandom = comphelper::rng::uniform_int_distribution(0, std::numeric_limits<int>::max());
+        snprintf(r, sizeof(r), "random=%i", nRandom);
         int ret = avahi_entry_group_add_service(
             group, AVAHI_IF_UNSPEC, AVAHI_PROTO_UNSPEC, static_cast<AvahiPublishFlags>(0),
-            avahiService->getName().c_str(), kREG_TYPE, NULL, NULL, 1599, "local", r, NULL
+            avahiService->getName().c_str(), kREG_TYPE, nullptr, nullptr, 1599, "local", r, nullptr
         );
         if (ret < 0) {
 
@@ -112,21 +120,21 @@ static bool create_services(AvahiClient *c) {
                 char *n = avahi_alternative_service_name(avahiService->getName().c_str());
                 avahiService->setName(n);
 
-                fprintf(stderr, "Service name collision, renaming service to '%s'\n", avahiService->getName().c_str());
+                SAL_WARN("sdremote.wifi", "Service name collision, renaming service to '" << avahiService->getName() << "'");
 
                 avahi_entry_group_reset(group);
 
                 return create_services(c);
             }
 
-            fprintf(stderr, "Failed to add _impressremote._tcp service: %s\n", avahi_strerror(ret));
+            SAL_WARN("sdremote.wifi", "Failed to add _impressremote._tcp service: " << avahi_strerror(ret));
             avahiService->clear();
             return false;
         }
 
         /* Tell the server to register the service */
         if ((ret = avahi_entry_group_commit(group)) < 0) {
-            fprintf(stderr, "Failed to commit entry group: %s\n", avahi_strerror(ret));
+            SAL_WARN("sdremote.wifi", "Failed to commit entry group: " << avahi_strerror(ret));
             avahiService->clear();
             return false;
         }
@@ -145,7 +153,7 @@ static void client_callback(AvahiClient *c, AvahiClientState state, AVAHI_GCC_UN
             create_services(c);
             break;
         case AVAHI_CLIENT_FAILURE:
-            fprintf(stderr, "Client failure: %s\n", avahi_strerror(avahi_client_errno(c)));
+            SAL_WARN("sdremote.wifi", "Client failure: " << avahi_strerror(avahi_client_errno(c)));
             avahiService->clear();
             break;
         case AVAHI_CLIENT_S_COLLISION:
@@ -159,23 +167,29 @@ static void client_callback(AvahiClient *c, AvahiClientState state, AVAHI_GCC_UN
 }
 
 void AvahiNetworkService::setup() {
+#if ENABLE_DBUS
+    // Sure, without ENABLE_DBUS it probably makes no sense to try to use this Avahi stuff either,
+    // but this is just a stop-gap measure to get this to even compile for now with the probably
+    // pointless combination of configurable options --enable-avahi --enable-dbus --disable-gui.
+
     // Avahi internally uses D-Bus, which requires the following in order to be
     // thread-safe (and we potentially access D-Bus from different threads in
     // different places of the code base):
     if (!dbus_threads_init_default()) {
         throw std::bad_alloc();
     }
+#endif
 
    int error = 0;
    avahiService = this;
    if (!(threaded_poll = avahi_threaded_poll_new())) {
-     fprintf(stderr, "avahi_threaded_poll_new '%s' failed.\n", avahi_strdup( avahiService->getName().c_str() ));
-     return;
+       SAL_WARN("sdremote.wifi", "avahi_threaded_poll_new '" << avahiService->getName() << "' failed");
+       return;
    }
 
-   if (!(client = avahi_client_new(avahi_threaded_poll_get(threaded_poll), static_cast<AvahiClientFlags>(0), client_callback, NULL, &error))) {
-     fprintf(stderr, "avahi_client_new failed.\n");
-     return;
+   if (!(client = avahi_client_new(avahi_threaded_poll_get(threaded_poll), static_cast<AvahiClientFlags>(0), client_callback, nullptr, &error))) {
+       SAL_WARN("sdremote.wifi", "avahi_client_new failed");
+       return;
    }
 
    if(!create_services(client))
@@ -183,8 +197,8 @@ void AvahiNetworkService::setup() {
 
    /* Finally, start the event loop thread */
    if (avahi_threaded_poll_start(threaded_poll) < 0) {
-     fprintf(stderr, "avahi_threaded_poll_start failed.\n");
-     return;
+       SAL_WARN("sdremote.wifi", "avahi_threaded_poll_start failed");
+       return;
    }
 }
 
