@@ -17,52 +17,53 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
+#include <memory>
 #include <sal/config.h>
 
 #include <cstdlib>
 
-#include "controller/SlsSelectionFunction.hxx"
+#include <controller/SlsSelectionFunction.hxx>
 
-#include "SlideSorter.hxx"
-#include "SlideSorterViewShell.hxx"
+#include <SlideSorter.hxx>
+#include <SlideSorterViewShell.hxx>
 #include "SlsDragAndDropContext.hxx"
-#include "controller/SlsTransferableData.hxx"
-#include "controller/SlideSorterController.hxx"
-#include "controller/SlsPageSelector.hxx"
-#include "controller/SlsFocusManager.hxx"
-#include "controller/SlsScrollBarManager.hxx"
-#include "controller/SlsClipboard.hxx"
-#include "controller/SlsCurrentSlideManager.hxx"
-#include "controller/SlsInsertionIndicatorHandler.hxx"
-#include "controller/SlsSelectionManager.hxx"
-#include "controller/SlsProperties.hxx"
-#include "controller/SlsSlotManager.hxx"
-#include "controller/SlsVisibleAreaManager.hxx"
-#include "model/SlideSorterModel.hxx"
-#include "model/SlsPageDescriptor.hxx"
-#include "model/SlsPageEnumerationProvider.hxx"
-#include "view/SlideSorterView.hxx"
-#include "view/SlsLayouter.hxx"
-#include "view/SlsPageObjectLayouter.hxx"
-#include "framework/FrameworkHelper.hxx"
-#include "ViewShellBase.hxx"
-#include "DrawController.hxx"
-#include "Window.hxx"
-#include "sdpage.hxx"
-#include "drawdoc.hxx"
-#include "DrawDocShell.hxx"
-#include "sdxfer.hxx"
-#include "ViewShell.hxx"
-#include "FrameView.hxx"
-#include "app.hrc"
-#include "sdresid.hxx"
-#include "strings.hrc"
+#include <controller/SlsTransferableData.hxx>
+#include <controller/SlideSorterController.hxx>
+#include <controller/SlsPageSelector.hxx>
+#include <controller/SlsFocusManager.hxx>
+#include <controller/SlsScrollBarManager.hxx>
+#include <controller/SlsClipboard.hxx>
+#include <controller/SlsCurrentSlideManager.hxx>
+#include <controller/SlsInsertionIndicatorHandler.hxx>
+#include <controller/SlsSelectionManager.hxx>
+#include <controller/SlsProperties.hxx>
+#include <controller/SlsSlotManager.hxx>
+#include <controller/SlsVisibleAreaManager.hxx>
+#include <model/SlideSorterModel.hxx>
+#include <model/SlsPageDescriptor.hxx>
+#include <model/SlsPageEnumerationProvider.hxx>
+#include <view/SlideSorterView.hxx>
+#include <view/SlsLayouter.hxx>
+#include <view/SlsPageObjectLayouter.hxx>
+#include <framework/FrameworkHelper.hxx>
+#include <ViewShellBase.hxx>
+#include <DrawController.hxx>
+#include <Window.hxx>
+#include <sdpage.hxx>
+#include <drawdoc.hxx>
+#include <DrawDocShell.hxx>
+#include <sdxfer.hxx>
+#include <ViewShell.hxx>
+#include <FrameView.hxx>
+#include <app.hrc>
+#include <sdresid.hxx>
+#include <strings.hrc>
+#include <o3tl/deleter.hxx>
 #include <sfx2/viewfrm.hxx>
 #include <sfx2/dispatch.hxx>
 #include <svx/svdpagv.hxx>
 #include <vcl/msgbox.hxx>
 #include <svx/svxids.hrc>
-#include <boost/bind.hpp>
 #include <boost/optional.hpp>
 
 namespace {
@@ -110,18 +111,17 @@ public:
     SdrPage* mpHitPage;
     sal_uInt32 mnEventCode;
     InsertionIndicatorHandler::Mode meDragMode;
-    bool mbMakeSelectionVisible;
     bool mbIsLeaving;
 
     EventDescriptor (
         sal_uInt32 nEventType,
         const MouseEvent& rEvent,
-        SlideSorter& rSlideSorter);
+        SlideSorter const & rSlideSorter);
     EventDescriptor (
         sal_uInt32 nEventType,
         const AcceptDropEvent& rEvent,
         const sal_Int8 nDragAction,
-        SlideSorter& rSlideSorter);
+        SlideSorter const & rSlideSorter);
 
 private:
     /** Compute a numerical code that describes a mouse event and that can
@@ -145,7 +145,7 @@ public:
         SlideSorter& rSlideSorter,
         SelectionFunction& rSelectionFunction,
         const bool bIsMouseOverIndicatorAllowed);
-    virtual ~ModeHandler();
+    virtual ~ModeHandler() COVERITY_NOEXCEPT_FALSE;
 
     virtual Mode GetMode() const = 0;
     virtual void Abort() = 0;
@@ -166,8 +166,7 @@ public:
     void SwitchView (const model::SharedPageDescriptor& rpDescriptor);
 
     void StartDrag (
-        const Point& rMousePosition,
-        const InsertionIndicatorHandler::Mode eMode);
+        const Point& rMousePosition);
 
     bool IsMouseOverIndicatorAllowed() const { return mbIsMouseOverIndicatorAllowed;}
 
@@ -196,7 +195,6 @@ public:
     NormalModeHandler (
         SlideSorter& rSlideSorter,
         SelectionFunction& rSelectionFunction);
-    virtual ~NormalModeHandler();
 
     virtual SelectionFunction::Mode GetMode() const override;
     virtual void Abort() override;
@@ -235,7 +233,7 @@ public:
         const Point& rMouseModelPosition,
         const sal_uInt32 nEventCode);
 #endif
-    virtual ~MultiSelectionModeHandler();
+    virtual ~MultiSelectionModeHandler() override;
 
 #ifndef MACOSX
     void Initialize(const sal_uInt32 nEventCode);
@@ -292,7 +290,7 @@ public:
         const Point& rMousePosition,
         vcl::Window* pWindow);
 #endif
-    virtual ~DragAndDropModeHandler();
+    virtual ~DragAndDropModeHandler() override;
 
 #ifndef MACOSX
     void Initialize(const Point& rMousePosition, vcl::Window* pWindow);
@@ -306,7 +304,7 @@ protected:
     virtual bool ProcessDragEvent (SelectionFunction::EventDescriptor& rDescriptor) override;
 
 private:
-    std::unique_ptr<DragAndDropContext> mpDragAndDropContext;
+    std::unique_ptr<DragAndDropContext, o3tl::default_delete<DragAndDropContext>> mpDragAndDropContext;
 };
 
 //===== SelectionFunction =====================================================
@@ -323,7 +321,6 @@ SelectionFunction::SelectionFunction (
         rRequest),
       mrSlideSorter(rSlideSorter),
       mrController(mrSlideSorter.GetController()),
-      mbProcessingMouseButtonDown(false),
       mnShiftKeySelectionAnchor(-1),
       mpModeHandler(new NormalModeHandler(rSlideSorter, *this))
 {
@@ -347,7 +344,6 @@ bool SelectionFunction::MouseButtonDown (const MouseEvent& rEvent)
     // remember button state for creation of own MouseEvents
     SetMouseButtonCode (rEvent.GetButtons());
     aMDPos = rEvent.GetPosPixel();
-    mbProcessingMouseButtonDown = true;
 
     //  mpWindow->CaptureMouse();
 
@@ -368,8 +364,6 @@ bool SelectionFunction::MouseButtonUp (const MouseEvent& rEvent)
 
     ProcessMouseEvent(BUTTON_UP, rEvent);
 
-    mbProcessingMouseButtonDown = false;
-
     return true;
 }
 
@@ -447,25 +441,25 @@ bool SelectionFunction::KeyInput (const KeyEvent& rEvent)
 
         // Move the focus indicator left.
         case KEY_LEFT:
-            MoveFocus(FocusManager::FMD_LEFT, rCode.IsShift(), rCode.IsMod1());
+            MoveFocus(FocusManager::FocusMoveDirection::Left, rCode.IsShift(), rCode.IsMod1());
             bResult = true;
             break;
 
         // Move the focus indicator right.
         case KEY_RIGHT:
-            MoveFocus(FocusManager::FMD_RIGHT, rCode.IsShift(), rCode.IsMod1());
+            MoveFocus(FocusManager::FocusMoveDirection::Right, rCode.IsShift(), rCode.IsMod1());
             bResult = true;
             break;
 
         // Move the focus indicator up.
         case KEY_UP:
-            MoveFocus(FocusManager::FMD_UP, rCode.IsShift(), rCode.IsMod1());
+            MoveFocus(FocusManager::FocusMoveDirection::Up, rCode.IsShift(), rCode.IsMod1());
             bResult = true;
             break;
 
         // Move the focus indicator down.
         case KEY_DOWN:
-            MoveFocus(FocusManager::FMD_DOWN, rCode.IsShift(), rCode.IsMod1());
+            MoveFocus(FocusManager::FocusMoveDirection::Down, rCode.IsShift(), rCode.IsMod1());
             bResult = true;
             break;
 
@@ -586,16 +580,6 @@ void SelectionFunction::MoveFocus (
     }
 }
 
-void SelectionFunction::Activate()
-{
-    FuPoor::Activate();
-}
-
-void SelectionFunction::Deactivate()
-{
-    FuPoor::Deactivate();
-}
-
 void SelectionFunction::DoCut()
 {
     if ( ! mrSlideSorter.GetProperties()->IsUIReadOnly())
@@ -774,14 +758,13 @@ void SelectionFunction::ResetMouseAnchor()
 SelectionFunction::EventDescriptor::EventDescriptor (
     const sal_uInt32 nEventType,
     const MouseEvent& rEvent,
-    SlideSorter& rSlideSorter)
+    SlideSorter const & rSlideSorter)
     : maMousePosition(rEvent.GetPosPixel()),
       maMouseModelPosition(),
       mpHitDescriptor(),
       mpHitPage(),
       mnEventCode(nEventType),
       meDragMode(InsertionIndicatorHandler::MoveMode),
-      mbMakeSelectionVisible(true),
       mbIsLeaving(false)
 {
     maMouseModelPosition = rSlideSorter.GetContentWindow()->PixelToLogic(maMousePosition);
@@ -798,7 +781,7 @@ SelectionFunction::EventDescriptor::EventDescriptor (
     // we can call IsLeaveWindow at the event.  Otherwise we have to make an
     // explicit test.
     mbIsLeaving = rEvent.IsLeaveWindow()
-        || ! Rectangle(Point(0,0),
+        || ! ::tools::Rectangle(Point(0,0),
              rSlideSorter.GetContentWindow()->GetOutputSizePixel()).IsInside(maMousePosition);
 }
 
@@ -806,14 +789,13 @@ SelectionFunction::EventDescriptor::EventDescriptor (
     const sal_uInt32 nEventType,
     const AcceptDropEvent& rEvent,
     const sal_Int8 nDragAction,
-    SlideSorter& rSlideSorter)
+    SlideSorter const & rSlideSorter)
     : maMousePosition(rEvent.maPosPixel),
       maMouseModelPosition(),
       mpHitDescriptor(),
       mpHitPage(),
       mnEventCode(nEventType),
       meDragMode(InsertionIndicatorHandler::GetModeFromDndAction(nDragAction)),
-      mbMakeSelectionVisible(true),
       mbIsLeaving(false)
 {
     maMouseModelPosition = rSlideSorter.GetContentWindow()->PixelToLogic(maMousePosition);
@@ -829,7 +811,7 @@ SelectionFunction::EventDescriptor::EventDescriptor (
     // we can call IsLeaveWindow at the event.  Otherwise we have to make an
     // explicit test.
     mbIsLeaving = rEvent.mbLeaving
-        || ! Rectangle(Point(0,0),
+        || ! ::tools::Rectangle(Point(0,0),
              rSlideSorter.GetContentWindow()->GetOutputSizePixel()).IsInside(maMousePosition);
 }
 
@@ -891,7 +873,7 @@ SelectionFunction::ModeHandler::ModeHandler (
 {
 }
 
-SelectionFunction::ModeHandler::~ModeHandler()
+SelectionFunction::ModeHandler::~ModeHandler() COVERITY_NOEXCEPT_FALSE
 {
 }
 
@@ -1008,10 +990,8 @@ void SelectionFunction::ModeHandler::SwitchView (const model::SharedPageDescript
 }
 
 void SelectionFunction::ModeHandler::StartDrag (
-    const Point& rMousePosition,
-    const InsertionIndicatorHandler::Mode eMode)
+    const Point& rMousePosition)
 {
-    (void)eMode;
     // Do not start a drag-and-drop operation when one is already active.
     // (when dragging pages from one document into another, pressing a
     // modifier key can trigger a MouseMotion event in the originating
@@ -1036,10 +1016,6 @@ NormalModeHandler::NormalModeHandler (
 {
 }
 
-NormalModeHandler::~NormalModeHandler()
-{
-}
-
 SelectionFunction::Mode NormalModeHandler::GetMode() const
 {
     return SelectionFunction::NormalMode;
@@ -1090,12 +1066,10 @@ bool NormalModeHandler::ProcessButtonDownEvent (
             // selection is set to this single page.  Otherwise the
             // selection is not modified.
             SetCurrentPage(rDescriptor.mpHitDescriptor);
-            rDescriptor.mbMakeSelectionVisible = false;
             break;
 
         case BUTTON_DOWN | RIGHT_BUTTON | SINGLE_CLICK | OVER_SELECTED_PAGE:
             // Do not change the selection.  Just adjust the insertion indicator.
-            rDescriptor.mbMakeSelectionVisible = false;
             break;
 
         case BUTTON_DOWN | RIGHT_BUTTON | SINGLE_CLICK | NOT_OVER_PAGE:
@@ -1180,11 +1154,8 @@ bool NormalModeHandler::ProcessMotionEvent (
     bool bIsProcessed (true);
     switch (rDescriptor.mnEventCode)
     {
-        case ANY_MODIFIER(MOUSE_MOTION | LEFT_BUTTON | SINGLE_CLICK | OVER_UNSELECTED_PAGE):
-            //            SetCurrentPage(rDescriptor.mpHitDescriptor);
-            // Fallthrough
-
         // A mouse motion without visible substitution starts that.
+        case ANY_MODIFIER(MOUSE_MOTION | LEFT_BUTTON | SINGLE_CLICK | OVER_UNSELECTED_PAGE):
         case ANY_MODIFIER(MOUSE_MOTION | LEFT_BUTTON | SINGLE_CLICK | OVER_SELECTED_PAGE):
         {
             if (maButtonDownLocation)
@@ -1195,16 +1166,12 @@ bool NormalModeHandler::ProcessMotionEvent (
                         std::abs(maButtonDownLocation->Y() - rDescriptor.maMousePosition.Y()))
                     : 0);
                 if (nDistance > 3)
-                    StartDrag(
-                        rDescriptor.maMousePosition,
-                        (rDescriptor.mnEventCode & CONTROL_MODIFIER) != 0
-                            ? InsertionIndicatorHandler::CopyMode
-                            : InsertionIndicatorHandler::MoveMode);
+                    StartDrag(rDescriptor.maMousePosition);
             }
+            break;
         }
-        break;
 
-            // A mouse motion not over a page starts a rectangle selection.
+        // A mouse motion not over a page starts a rectangle selection.
         case ANY_MODIFIER(MOUSE_MOTION | LEFT_BUTTON | SINGLE_CLICK | NOT_OVER_PAGE):
             mrSelectionFunction.SwitchToMultiSelectionMode(
                 rDescriptor.maMouseModelPosition,
@@ -1353,7 +1320,6 @@ bool MultiSelectionModeHandler::ProcessMotionEvent (
     {
         SetSelectionModeFromModifier(rDescriptor.mnEventCode);
         UpdatePosition(rDescriptor.maMousePosition, true);
-        rDescriptor.mbMakeSelectionVisible = false;
         return true;
     }
     else
@@ -1381,16 +1347,12 @@ void MultiSelectionModeHandler::UpdatePosition (
     // Convert window coordinates into model coordinates (we need the
     // window coordinates for auto-scrolling because that remains
     // constant while scrolling.)
-    sd::Window *pWindow (mrSlideSorter.GetContentWindow());
+    sd::Window *pWindow (mrSlideSorter.GetContentWindow().get());
     const Point aMouseModelPosition (pWindow->PixelToLogic(rMousePosition));
 
     bool bDoAutoScroll = bAllowAutoScroll && mrSlideSorter.GetController().GetScrollBarManager().AutoScroll(
         rMousePosition,
-        ::boost::bind(
-            &MultiSelectionModeHandler::UpdatePosition,
-            this,
-            rMousePosition,
-            false));
+        [this, &rMousePosition] () { return this->UpdatePosition(rMousePosition, false); });
 
     if (!bDoAutoScroll)
         UpdateModelPosition(aMouseModelPosition);
@@ -1535,7 +1497,7 @@ DragAndDropModeHandler::~DragAndDropModeHandler()
     if (mpDragAndDropContext)
     {
         // Disconnect the substitution handler from this selection function.
-        mpDragAndDropContext->SetTargetSlideSorter();
+        mpDragAndDropContext->SetTargetSlideSorter(Point(0,0));
         mpDragAndDropContext.reset();
     }
     mrSlideSorter.GetController().GetInsertionIndicatorHandler()->End(Animator::AM_Animated);
@@ -1581,7 +1543,7 @@ bool DragAndDropModeHandler::ProcessDragEvent (SelectionFunction::EventDescripto
     {
         mpDragAndDropContext->UpdatePosition(
             rDescriptor.maMousePosition,
-            rDescriptor.meDragMode);
+            rDescriptor.meDragMode, true);
     }
 
     return true;
