@@ -17,16 +17,15 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-
 #include "SlsLayeredDevice.hxx"
 
 #include <vcl/window.hxx>
 #include <vcl/virdev.hxx>
 
-#include <boost/bind.hpp>
-#include <boost/function.hpp>
-
 #include <tools/gen.hxx>
+#include <tools/fract.hxx>
+
+#include <functional>
 
 namespace sd { namespace slidesorter { namespace view {
 
@@ -37,35 +36,31 @@ class LayerInvalidator : public ILayerInvalidator
 {
 public:
     LayerInvalidator (
-        const ::boost::shared_ptr<LayeredDevice>& rpLayeredDevice,
-        const SharedSdWindow& rpTargetWindow,
+        const std::shared_ptr<LayeredDevice>& rpLayeredDevice,
+        sd::Window *pTargetWindow,
         const int nLayer)
         : mpLayeredDevice(rpLayeredDevice),
-          mpTargetWindow(rpTargetWindow),
+          mpTargetWindow(pTargetWindow),
           mnLayer(nLayer)
     {
     }
 
-    virtual ~LayerInvalidator ( )
-    {
-    }
-
-    virtual void Invalidate (const Rectangle& rInvalidationBox)
+    virtual void Invalidate (const ::tools::Rectangle& rInvalidationBox) override
     {
         mpLayeredDevice->Invalidate(rInvalidationBox, mnLayer);
         mpTargetWindow->Invalidate(rInvalidationBox);
     }
 
 private:
-    const ::boost::shared_ptr<LayeredDevice> mpLayeredDevice;
-    SharedSdWindow mpTargetWindow;
+    const std::shared_ptr<LayeredDevice> mpLayeredDevice;
+    VclPtr<sd::Window> mpTargetWindow;
     const int mnLayer;
 };
 
 void DeviceCopy (
-    OutputDevice& rTargetDevice,
-    OutputDevice& rSourceDevice,
-    const Rectangle& rBox)
+    vcl::RenderContext& rTargetDevice,
+    vcl::RenderContext const & rSourceDevice,
+    const ::tools::Rectangle& rBox)
 {
     rTargetDevice.DrawOutDev(
         rBox.TopLeft(),
@@ -75,8 +70,7 @@ void DeviceCopy (
         rSourceDevice);
 }
 
-
-void ForAllRectangles (const Region& rRegion, ::boost::function<void(const Rectangle&)> aFunction)
+void ForAllRectangles (const vcl::Region& rRegion, const std::function<void (const ::tools::Rectangle&)>& aFunction)
 {
     OSL_ASSERT(aFunction);
     RectangleVector aRectangles;
@@ -84,7 +78,7 @@ void ForAllRectangles (const Region& rRegion, ::boost::function<void(const Recta
 
     if(0 == aRectangles.size())
     {
-        aFunction(Rectangle());
+        aFunction(::tools::Rectangle());
     }
     else
     {
@@ -102,71 +96,80 @@ void ForAllRectangles (const Region& rRegion, ::boost::function<void(const Recta
     }
 }
 
-class Layer : private ::boost::noncopyable
+class Layer
 {
 public:
-    Layer (void);
-    ~Layer (void);
+    Layer();
+    Layer(const Layer&) = delete;
+    Layer& operator=(const Layer&) = delete;
 
-    void Initialize (const SharedSdWindow& rpTargetWindow);
-    void InvalidateRectangle (const Rectangle& rInvalidationBox);
-    void InvalidateRegion (const Region& rInvalidationRegion);
+    void Initialize (sd::Window *pTargetWindow);
+    void InvalidateRectangle (const ::tools::Rectangle& rInvalidationBox);
+    void InvalidateRegion (const vcl::Region& rInvalidationRegion);
     void Validate (const MapMode& rMapMode);
     void Repaint (
         OutputDevice& rTargetDevice,
-        const Rectangle& rRepaintRectangle);
+        const ::tools::Rectangle& rRepaintRectangle);
     void Resize (const Size& rSize);
     void AddPainter (const SharedILayerPainter& rpPainter);
     void RemovePainter (const SharedILayerPainter& rpPainter);
-    bool HasPainter (void) const;
-    void Dispose (void);
+    bool HasPainter() const;
+    void Dispose();
 
 private:
-    ::boost::shared_ptr<VirtualDevice> mpLayerDevice;
+    ScopedVclPtr<VirtualDevice> mpLayerDevice;
     ::std::vector<SharedILayerPainter> maPainters;
-    Region maInvalidationRegion;
+    vcl::Region maInvalidationRegion;
 
-    void ValidateRectangle (const Rectangle& rBox);
+    void ValidateRectangle (const ::tools::Rectangle& rBox);
 };
-typedef ::boost::shared_ptr<Layer> SharedLayer;
-
+typedef std::shared_ptr<Layer> SharedLayer;
 
 } // end of anonymous namespace
 
-
-class LayeredDevice::LayerContainer : public ::std::vector<SharedLayer>
+class LayeredDevice::LayerContainer
 {
 public:
-    LayerContainer (void) {}
-    ~LayerContainer (void) {}
+    LayerContainer() : mvLayers() {}
+
+    bool empty() const { return mvLayers.empty(); }
+
+    size_t size() const { return mvLayers.size(); }
+
+    const SharedLayer& back() const { return mvLayers.back(); }
+
+    const ::std::vector<SharedLayer>::const_iterator begin() const { return mvLayers.begin(); }
+    const ::std::vector<SharedLayer>::const_iterator end() const { return mvLayers.end(); }
+
+    void clear() { mvLayers.clear(); }
+
+    void pop_back() { mvLayers.pop_back(); }
+
+    void resize(size_t n) { mvLayers.resize(n); }
+
+    SharedLayer& operator[](size_t i) { return mvLayers[i]; }
+
+private:
+    ::std::vector<SharedLayer> mvLayers;
 };
 
-
-
-
 //===== LayeredDevice =========================================================
 
-LayeredDevice::LayeredDevice (const SharedSdWindow& rpTargetWindow)
-    : mpTargetWindow(rpTargetWindow),
+LayeredDevice::LayeredDevice (const VclPtr<sd::Window>& pTargetWindow)
+    : mpTargetWindow(pTargetWindow),
       mpLayers(new LayerContainer()),
-      mpBackBuffer(new VirtualDevice(*mpTargetWindow)),
-      maSavedMapMode(rpTargetWindow->GetMapMode())
+      mpBackBuffer(VclPtr<VirtualDevice>::Create(*mpTargetWindow)),
+      maSavedMapMode(pTargetWindow->GetMapMode())
 {
     mpBackBuffer->SetOutputSizePixel(mpTargetWindow->GetSizePixel());
 }
 
-
-
-
-LayeredDevice::~LayeredDevice (void)
+LayeredDevice::~LayeredDevice()
 {
 }
 
-
-
-
 void LayeredDevice::Invalidate (
-    const Rectangle& rInvalidationArea,
+    const ::tools::Rectangle& rInvalidationArea,
     const sal_Int32 nLayer)
 {
     if (nLayer<0 || size_t(nLayer)>=mpLayers->size())
@@ -178,27 +181,18 @@ void LayeredDevice::Invalidate (
     (*mpLayers)[nLayer]->InvalidateRectangle(rInvalidationArea);
 }
 
-
-
-
-void LayeredDevice::InvalidateAllLayers (const Rectangle& rInvalidationArea)
+void LayeredDevice::InvalidateAllLayers (const ::tools::Rectangle& rInvalidationArea)
 {
-    for (sal_uInt32 nLayer=0; nLayer<mpLayers->size(); ++nLayer)
+    for (size_t nLayer=0; nLayer<mpLayers->size(); ++nLayer)
         (*mpLayers)[nLayer]->InvalidateRectangle(rInvalidationArea);
 }
 
-
-
-
-void LayeredDevice::InvalidateAllLayers (const Region& rInvalidationRegion)
+void LayeredDevice::InvalidateAllLayers (const vcl::Region& rInvalidationRegion)
 {
-    for (sal_uInt32 nLayer=0; nLayer<mpLayers->size(); ++nLayer)
+    for (size_t nLayer=0; nLayer<mpLayers->size(); ++nLayer)
         (*mpLayers)[nLayer]->InvalidateRegion(rInvalidationRegion);
 }
 
-
-
-
 void LayeredDevice::RegisterPainter (
     const SharedILayerPainter& rpPainter,
     const sal_Int32 nLayer)
@@ -233,9 +227,6 @@ void LayeredDevice::RegisterPainter (
         SharedILayerInvalidator(new LayerInvalidator(shared_from_this(),mpTargetWindow,nLayer)));
 }
 
-
-
-
 void LayeredDevice::RemovePainter (
     const SharedILayerPainter& rpPainter,
     const sal_Int32 nLayer)
@@ -257,27 +248,22 @@ void LayeredDevice::RemovePainter (
 
     // Remove top most layers that do not contain any painters.
     while ( ! mpLayers->empty() && ! mpLayers->back()->HasPainter())
-        mpLayers->erase(mpLayers->end()-1);
+        mpLayers->pop_back();
 }
 
-
-
-
-void LayeredDevice::Repaint (const Region& rRepaintRegion)
+void LayeredDevice::Repaint (const vcl::Region& rRepaintRegion)
 {
     // Validate the contents of all layers (that have their own devices.)
-    ::std::for_each(
-        mpLayers->begin(),
-        mpLayers->end(),
-        ::boost::bind(&Layer::Validate, _1, mpTargetWindow->GetMapMode()));
+    for (auto const& it : *mpLayers)
+    {
+        it->Validate(mpTargetWindow->GetMapMode());
+    }
 
-    ForAllRectangles(rRepaintRegion, ::boost::bind(&LayeredDevice::RepaintRectangle, this, _1));
+    ForAllRectangles(rRepaintRegion,
+            [this] (::tools::Rectangle const& r) { this->RepaintRectangle(r); });
 }
 
-
-
-
-void LayeredDevice::RepaintRectangle (const Rectangle& rRepaintRectangle)
+void LayeredDevice::RepaintRectangle (const ::tools::Rectangle& rRepaintRectangle)
 {
     if (mpLayers->empty())
         return;
@@ -292,45 +278,41 @@ void LayeredDevice::RepaintRectangle (const Rectangle& rRepaintRectangle)
         // due to synchronous paints) and then copy that into the target
         // device.
         mpBackBuffer->SetMapMode(mpTargetWindow->GetMapMode());
-        ::std::for_each(
-            mpLayers->begin(),
-            mpLayers->end(),
-            ::boost::bind(&Layer::Repaint, _1, ::boost::ref(*mpBackBuffer), rRepaintRectangle));
-
+        for (auto const& it : *mpLayers)
+        {
+            it->Repaint(*mpBackBuffer, rRepaintRectangle);
+        }
         DeviceCopy(*mpTargetWindow, *mpBackBuffer, rRepaintRectangle);
     }
 }
 
-
-
-
-void LayeredDevice::Resize (void)
+void LayeredDevice::Resize()
 {
     const Size aSize (mpTargetWindow->GetSizePixel());
     mpBackBuffer->SetOutputSizePixel(aSize);
-    ::std::for_each(mpLayers->begin(), mpLayers->end(), ::boost::bind(&Layer::Resize, _1, aSize));
+    for (auto const& it : *mpLayers)
+    {
+        it->Resize(aSize);
+    }
 }
 
-
-
-
-void LayeredDevice::Dispose (void)
+void LayeredDevice::Dispose()
 {
-    ::std::for_each(mpLayers->begin(), mpLayers->end(), ::boost::bind(&Layer::Dispose, _1));
+    for (auto const& it : *mpLayers)
+    {
+        it->Dispose();
+    }
     mpLayers->clear();
 }
 
-
-
-
-bool LayeredDevice::HandleMapModeChange (void)
+bool LayeredDevice::HandleMapModeChange()
 {
     const MapMode& rMapMode (mpTargetWindow->GetMapMode());
     if (maSavedMapMode == rMapMode)
         return false;
 
-    const Rectangle aLogicWindowBox (
-        mpTargetWindow->PixelToLogic(Rectangle(Point(0,0), mpTargetWindow->GetSizePixel())));
+    const ::tools::Rectangle aLogicWindowBox (
+        mpTargetWindow->PixelToLogic(::tools::Rectangle(Point(0,0), mpTargetWindow->GetSizePixel())));
     if (maSavedMapMode.GetScaleX() != rMapMode.GetScaleX()
         || maSavedMapMode.GetScaleY() != rMapMode.GetScaleY()
         || maSavedMapMode.GetMapUnit() != rMapMode.GetMapUnit())
@@ -349,27 +331,27 @@ bool LayeredDevice::HandleMapModeChange (void)
             aLogicWindowBox.GetSize());
 
         // Invalidate the area(s) that have been exposed.
-        const Rectangle aWindowBox (Point(0,0), mpTargetWindow->GetSizePixel());
+        const ::tools::Rectangle aWindowBox (Point(0,0), mpTargetWindow->GetSizePixel());
         if (aDelta.Y() < 0)
-            InvalidateAllLayers(mpTargetWindow->PixelToLogic(Rectangle(
+            InvalidateAllLayers(mpTargetWindow->PixelToLogic(::tools::Rectangle(
                 aWindowBox.Left(),
                 aWindowBox.Bottom()+aDelta.Y(),
                 aWindowBox.Right(),
                 aWindowBox.Bottom())));
         else if (aDelta.Y() > 0)
-            InvalidateAllLayers(mpTargetWindow->PixelToLogic(Rectangle(
+            InvalidateAllLayers(mpTargetWindow->PixelToLogic(::tools::Rectangle(
                 aWindowBox.Left(),
                 aWindowBox.Top(),
                 aWindowBox.Right(),
                 aWindowBox.Top()+aDelta.Y())));
         if (aDelta.X() < 0)
-            InvalidateAllLayers(mpTargetWindow->PixelToLogic(Rectangle(
+            InvalidateAllLayers(mpTargetWindow->PixelToLogic(::tools::Rectangle(
                 aWindowBox.Right()+aDelta.X(),
                 aWindowBox.Top(),
                 aWindowBox.Right(),
                 aWindowBox.Bottom())));
         else if (aDelta.X() > 0)
-            InvalidateAllLayers(mpTargetWindow->PixelToLogic(Rectangle(
+            InvalidateAllLayers(mpTargetWindow->PixelToLogic(::tools::Rectangle(
                 aWindowBox.Left(),
                 aWindowBox.Top(),
                 aWindowBox.Left()+aDelta.X(),
@@ -386,82 +368,57 @@ bool LayeredDevice::HandleMapModeChange (void)
     return true;
 }
 
-
-
-
 //===== Layer =================================================================
 
-Layer::Layer (void)
+Layer::Layer()
     : mpLayerDevice(),
       maPainters(),
       maInvalidationRegion()
 {
 }
 
-
-
-
-Layer::~Layer (void)
-{
-}
-
-
-
-
-void Layer::Initialize (const SharedSdWindow& rpTargetWindow)
+void Layer::Initialize (sd::Window *pTargetWindow)
 {
 #if 0
-    (void)rpTargetWindow;
+    (void)pTargetWindow;
 #else
     if ( ! mpLayerDevice)
     {
-        mpLayerDevice.reset(new VirtualDevice(*rpTargetWindow));
-        mpLayerDevice->SetOutputSizePixel(rpTargetWindow->GetSizePixel());
+        mpLayerDevice.disposeAndReset(VclPtr<VirtualDevice>::Create(*pTargetWindow));
+        mpLayerDevice->SetOutputSizePixel(pTargetWindow->GetSizePixel());
     }
 #endif
 }
 
-
-
-
-void Layer::InvalidateRectangle (const Rectangle& rInvalidationBox)
+void Layer::InvalidateRectangle (const ::tools::Rectangle& rInvalidationBox)
 {
     maInvalidationRegion.Union(rInvalidationBox);
 }
 
-
-
-
-void Layer::InvalidateRegion (const Region& rInvalidationRegion)
+void Layer::InvalidateRegion (const vcl::Region& rInvalidationRegion)
 {
     maInvalidationRegion.Union(rInvalidationRegion);
 }
 
-
-
-
 void Layer::Validate (const MapMode& rMapMode)
 {
     if (mpLayerDevice && ! maInvalidationRegion.IsEmpty())
     {
-        Region aRegion (maInvalidationRegion);
+        vcl::Region aRegion (maInvalidationRegion);
         maInvalidationRegion.SetEmpty();
 
         mpLayerDevice->SetMapMode(rMapMode);
         ForAllRectangles(
             aRegion,
-            ::boost::bind(&Layer::ValidateRectangle, this, _1));
+            [this] (::tools::Rectangle const& r) { return this->ValidateRectangle(r); });
     }
 }
 
-
-
-
-void Layer::ValidateRectangle (const Rectangle& rBox)
+void Layer::ValidateRectangle (const ::tools::Rectangle& rBox)
 {
     if ( ! mpLayerDevice)
         return;
-    const Region aSavedClipRegion (mpLayerDevice->GetClipRegion());
+    const vcl::Region aSavedClipRegion (mpLayerDevice->GetClipRegion());
     mpLayerDevice->IntersectClipRegion(rBox);
 
     for (::std::vector<SharedILayerPainter>::const_iterator
@@ -476,12 +433,9 @@ void Layer::ValidateRectangle (const Rectangle& rBox)
     mpLayerDevice->SetClipRegion(aSavedClipRegion);
 }
 
-
-
-
 void Layer::Repaint (
     OutputDevice& rTargetDevice,
-    const Rectangle& rRepaintRectangle)
+    const ::tools::Rectangle& rRepaintRectangle)
 {
     if (mpLayerDevice)
     {
@@ -489,31 +443,22 @@ void Layer::Repaint (
     }
     else
     {
-        ::std::for_each(
-            maPainters.begin(),
-            maPainters.end(),
-            ::boost::bind(&ILayerPainter::Paint,
-                _1,
-                ::boost::ref(rTargetDevice),
-                rRepaintRectangle));
+        for (auto const& it : maPainters)
+        {
+            it->Paint(rTargetDevice, rRepaintRectangle);
+        }
     }
 }
 
-
-
-
 void Layer::Resize (const Size& rSize)
 {
     if (mpLayerDevice)
     {
         mpLayerDevice->SetOutputSizePixel(rSize);
-        maInvalidationRegion = Rectangle(Point(0,0), rSize);
+        maInvalidationRegion = ::tools::Rectangle(Point(0,0), rSize);
     }
 }
 
-
-
-
 void Layer::AddPainter (const SharedILayerPainter& rpPainter)
 {
     OSL_ASSERT(::std::find(maPainters.begin(), maPainters.end(), rpPainter) == maPainters.end());
@@ -521,9 +466,6 @@ void Layer::AddPainter (const SharedILayerPainter& rpPainter)
     maPainters.push_back(rpPainter);
 }
 
-
-
-
 void Layer::RemovePainter (const SharedILayerPainter& rpPainter)
 {
     const ::std::vector<SharedILayerPainter>::iterator iPainter (
@@ -534,27 +476,20 @@ void Layer::RemovePainter (const SharedILayerPainter& rpPainter)
     }
     else
     {
-        DBG_ASSERT(false,"LayeredDevice::RemovePainter called for painter that is not registered");
+        SAL_WARN("sd", "LayeredDevice::RemovePainter called for painter that is not registered");
     }
 }
 
-
-
-
-bool Layer::HasPainter (void) const
+bool Layer::HasPainter() const
 {
     return !maPainters.empty();
 }
 
-
-
-
-void Layer::Dispose (void)
+void Layer::Dispose()
 {
     maPainters.clear();
 }
 
-
 } } } // end of namespace ::sd::slidesorter::view
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
