@@ -17,10 +17,11 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "view/SlsTheme.hxx"
-#include "SlsResource.hxx"
-#include "controller/SlsProperties.hxx"
-#include "sdresid.hxx"
+#include <strings.hrc>
+#include <bitmaps.hlst>
+#include <view/SlsTheme.hxx>
+#include <controller/SlsProperties.hxx>
+#include <sdresid.hxx>
 #include <tools/color.hxx>
 #include <vcl/outdev.hxx>
 #include <vcl/image.hxx>
@@ -61,23 +62,18 @@ ColorData HGBAdapt (
 
 Theme::Theme (const std::shared_ptr<controller::Properties>& rpProperties)
     : maBackgroundColor(rpProperties->GetBackgroundColor().GetColor()),
-      maPageBackgroundColor(COL_WHITE),
       maGradients(),
       maIcons(),
       maColor()
 {
-    {
-        LocalResource aResource (RID_SLIDESORTER_ICONS);
-
-        maColor.resize(ColorType_Size_);
-        maColor[Color_Background] = maBackgroundColor;
-        maColor[Color_PageNumberDefault] = 0x0808080;
-        maColor[Color_PageNumberHover] = 0x4c4c4c;
-        maColor[Color_PageNumberHighContrast] = White;
-        maColor[Color_PageNumberBrightBackground] = 0x333333;
-        maColor[Color_PageNumberDarkBackground] = 0xcccccc;
-        maColor[Color_PreviewBorder] = 0x949599;
-    }
+    maColor.resize(ColorType_Size_);
+    maColor[Color_Background] = maBackgroundColor;
+    maColor[Color_PageNumberDefault] = 0x0808080;
+    maColor[Color_PageNumberHover] = 0x4c4c4c;
+    maColor[Color_PageNumberHighContrast] = White;
+    maColor[Color_PageNumberBrightBackground] = 0x333333;
+    maColor[Color_PageNumberDarkBackground] = 0xcccccc;
+    maColor[Color_PreviewBorder] = 0x949599;
 
     Update(rpProperties);
 }
@@ -86,7 +82,6 @@ void Theme::Update (const std::shared_ptr<controller::Properties>& rpProperties)
 {
     // Set up colors.
     maBackgroundColor = rpProperties->GetBackgroundColor().GetColor();
-    maPageBackgroundColor = svtools::ColorConfig().GetColorValue(svtools::DOCCOLOR).nColor;
 
     maColor[Color_Background] = maBackgroundColor;
 
@@ -118,7 +113,6 @@ void Theme::Update (const std::shared_ptr<controller::Properties>& rpProperties)
     // Set up icons.
     if (maIcons.empty())
     {
-        LocalResource aResource (RID_SLIDESORTER_ICONS);
         maIcons.resize(IconType_Size_);
 
         InitializeIcon(Icon_RawShadow, IMAGE_SHADOW);
@@ -168,7 +162,7 @@ std::shared_ptr<vcl::Font> Theme::GetFont (
 
 ColorData Theme::GetColor (const ColorType eType)
 {
-    if (eType>=0 && sal_uInt32(eType)<maColor.size())
+    if (sal_uInt32(eType)<maColor.size())
         return maColor[eType];
     else
         return 0;
@@ -182,13 +176,12 @@ ColorData Theme::GetGradientColor (
 
     switch (eClass)
     {
-        case Border1: return rDescriptor.maBorderColor1;
-        case Border2: return rDescriptor.maBorderColor2;
-        case Fill1: return rDescriptor.maFillColor1;
-        case Fill2: return rDescriptor.maFillColor2;
-        default: OSL_ASSERT(false); SAL_FALLTHROUGH;
-        case Base: return rDescriptor.maBaseColor;
+        case GradientColorClass::Border1: return rDescriptor.maBorderColor1;
+        case GradientColorClass::Border2: return rDescriptor.maBorderColor2;
+        case GradientColorClass::Fill1: return rDescriptor.maFillColor1;
+        case GradientColorClass::Fill2: return rDescriptor.maFillColor2;
     }
+    return 0;
 }
 
 void Theme::SetGradient (
@@ -203,10 +196,6 @@ void Theme::SetGradient (
 {
     GradientDescriptor& rGradient (GetGradient(eType));
 
-    rGradient.maBaseColor = aBaseColor;
-
-    rGradient.mnSaturationOverride = nSaturationOverride;
-    rGradient.mnBrightnessOverride = nBrightnessOverride;
     const ColorData aColor (nSaturationOverride>=0 || nBrightnessOverride>=0
         ? HGBAdapt(aBaseColor, nSaturationOverride, nBrightnessOverride)
         : aBaseColor);
@@ -215,16 +204,11 @@ void Theme::SetGradient (
     rGradient.maFillColor2 = ChangeLuminance(aColor, nFillEndOffset);
     rGradient.maBorderColor1 = ChangeLuminance(aColor, nBorderStartOffset);
     rGradient.maBorderColor2 = ChangeLuminance(aColor, nBorderEndOffset);
-
-    rGradient.mnFillOffset1 = nFillStartOffset;
-    rGradient.mnFillOffset2 = nFillEndOffset;
-    rGradient.mnBorderOffset1 = nBorderStartOffset;
-    rGradient.mnBorderOffset2 = nBorderEndOffset;
 }
 
 const BitmapEx& Theme::GetIcon (const IconType eType)
 {
-    if (eType>=0 && size_t(eType)<maIcons.size())
+    if (size_t(eType)<maIcons.size())
         return maIcons[eType];
     else
     {
@@ -235,7 +219,7 @@ const BitmapEx& Theme::GetIcon (const IconType eType)
 
 Theme::GradientDescriptor& Theme::GetGradient (const GradientColorType eType)
 {
-    if (eType>=0 && size_t(eType)<maGradients.size())
+    if (size_t(eType)<maGradients.size())
         return maGradients[eType];
     else
     {
@@ -244,11 +228,11 @@ Theme::GradientDescriptor& Theme::GetGradient (const GradientColorType eType)
     }
 }
 
-void Theme::InitializeIcon (const IconType eType, sal_uInt16 nResourceId)
+void Theme::InitializeIcon(const IconType eType, const OUString& rResourceId)
 {
-    if (eType>=0 && size_t(eType)<maIcons.size())
+    if (size_t(eType)<maIcons.size())
     {
-        const BitmapEx aIcon (Image(SdResId(nResourceId)).GetBitmapEx());
+        const BitmapEx aIcon(rResourceId);
         maIcons[eType] = aIcon;
     }
     else
