@@ -17,15 +17,15 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "DrawController.hxx"
-#include "DrawDocShell.hxx"
+#include <DrawController.hxx>
+#include <DrawDocShell.hxx>
 
-#include "DrawSubController.hxx"
-#include "sdpage.hxx"
-#include "ViewShellBase.hxx"
-#include "ViewShellManager.hxx"
-#include "FormShellManager.hxx"
-#include "Window.hxx"
+#include <DrawSubController.hxx>
+#include <sdpage.hxx>
+#include <ViewShellBase.hxx>
+#include <ViewShellManager.hxx>
+#include <FormShellManager.hxx>
+#include <Window.hxx>
 
 #include <comphelper/anytostring.hxx>
 #include <comphelper/processfactory.hxx>
@@ -40,37 +40,33 @@
 #include <com/sun/star/drawing/framework/ModuleController.hpp>
 #include <com/sun/star/lang/XInitialization.hpp>
 
-#include "slideshow.hxx"
+#include <slideshow.hxx>
 
 #include <svx/fmshell.hxx>
-#include <osl/mutex.hxx>
 #include <vcl/svapp.hxx>
-#include <sfx2/sidebar/EnumContext.hxx>
+#include <vcl/EnumContext.hxx>
 #include <svx/sidebar/ContextChangeEventMultiplexer.hxx>
 
-#include <boost/shared_ptr.hpp>
+#include <memory>
 
 using namespace ::std;
 using namespace ::cppu;
 using namespace ::com::sun::star;
 using namespace ::com::sun::star::uno;
 using namespace ::com::sun::star::drawing::framework;
-using ::sfx2::sidebar::EnumContext;
+using vcl::EnumContext;
 
 namespace sd {
 
 DrawController::DrawController (ViewShellBase& rBase) throw()
     : DrawControllerInterfaceBase(&rBase),
       BroadcastHelperOwner(SfxBaseController::m_aMutex),
-      OPropertySetHelper( static_cast<OBroadcastHelperVar<
-          OMultiTypeInterfaceContainerHelper,
-          OMultiTypeInterfaceContainerHelper::keyType>& >(
-              BroadcastHelperOwner::maBroadcastHelper)),
+      OPropertySetHelper(BroadcastHelperOwner::maBroadcastHelper),
       m_aSelectionTypeIdentifier(
         cppu::UnoType<view::XSelectionChangeListener>::get()),
       mpBase(&rBase),
       maLastVisArea(),
-      mpCurrentPage(NULL),
+      mpCurrentPage(nullptr),
       mbMasterPageMode(false),
       mbLayerMode(false),
       mbDisposing(false),
@@ -91,7 +87,7 @@ void DrawController::SetSubController (
     // Update the internal state.
     mxSubController = rxSubController;
     mpPropertyArrayHelper.reset();
-    maLastVisArea = Rectangle();
+    maLastVisArea = ::tools::Rectangle();
 
     // Inform listeners about the changed state.
     FireSelectionChangeListener();
@@ -107,7 +103,6 @@ IMPLEMENT_FORWARD_XINTERFACE2(
 // XTypeProvider
 
 Sequence<Type> SAL_CALL DrawController::getTypes()
-    throw (::com::sun::star::uno::RuntimeException, std::exception)
 {
     ThrowIfDisposed();
     // OPropertySetHelper does not provide getTypes, so we have to
@@ -128,7 +123,6 @@ IMPLEMENT_GET_IMPLEMENTATION_ID(DrawController);
 // XComponent
 
 void SAL_CALL DrawController::dispose()
-    throw( RuntimeException, std::exception )
 {
     if( !mbDisposing )
     {
@@ -138,22 +132,22 @@ void SAL_CALL DrawController::dispose()
         {
             mbDisposing = true;
 
-            boost::shared_ptr<ViewShell> pViewShell;
+            std::shared_ptr<ViewShell> pViewShell;
             if (mpBase)
                 pViewShell = mpBase->GetMainViewShell();
             if ( pViewShell )
             {
                 pViewShell->DeactivateCurrentFunction();
                 DrawDocShell* pDocShell = pViewShell->GetDocSh();
-                if ( pDocShell != NULL )
-                    pDocShell->SetDocShellFunction(0);
+                if ( pDocShell != nullptr )
+                    pDocShell->SetDocShellFunction(nullptr);
             }
             pViewShell.reset();
 
             // When the controller has not been detached from its view
             // shell, i.e. mpViewShell is not NULL, then tell PaneManager
             // and ViewShellManager to clear the shell stack.
-            if (mxSubController.is() && mpBase!=NULL)
+            if (mxSubController.is() && mpBase!=nullptr)
             {
                 mpBase->DisconnectAllClients();
                 mpBase->GetViewShellManager()->Shutdown();
@@ -170,7 +164,6 @@ void SAL_CALL DrawController::dispose()
 
 void SAL_CALL DrawController::addEventListener(
     const Reference<lang::XEventListener >& xListener)
-    throw (RuntimeException, std::exception)
 {
     ThrowIfDisposed();
     SfxBaseController::addEventListener( xListener );
@@ -178,14 +171,13 @@ void SAL_CALL DrawController::addEventListener(
 
 void SAL_CALL DrawController::removeEventListener (
     const Reference<lang::XEventListener >& aListener)
-    throw (RuntimeException, std::exception)
 {
     if(!rBHelper.bDisposed && !rBHelper.bInDispose && !mbDisposing)
         SfxBaseController::removeEventListener( aListener );
 }
 
 // XController
-sal_Bool SAL_CALL DrawController::suspend( sal_Bool Suspend ) throw (::com::sun::star::uno::RuntimeException, std::exception)
+sal_Bool SAL_CALL DrawController::suspend( sal_Bool Suspend )
 {
     if( Suspend )
     {
@@ -195,7 +187,7 @@ sal_Bool SAL_CALL DrawController::suspend( sal_Bool Suspend ) throw (::com::sun:
             // do not allow suspend if a slideshow needs this controller!
             rtl::Reference< SlideShow > xSlideShow( SlideShow::GetSlideShow( *pViewShellBase ) );
             if( xSlideShow.is() && xSlideShow->dependsOn(pViewShellBase) )
-                return sal_False;
+                return false;
         }
     }
 
@@ -203,10 +195,10 @@ sal_Bool SAL_CALL DrawController::suspend( sal_Bool Suspend ) throw (::com::sun:
 }
 
 // XServiceInfo
-OUString SAL_CALL DrawController::getImplementationName(  ) throw(RuntimeException, std::exception)
+OUString SAL_CALL DrawController::getImplementationName(  )
 {
-    // Do not throw an excepetion at the moment.  This leads to a crash
-    // under Solaris on relead.  See issue i70929 for details.
+    // Do not throw an exception at the moment.  This leads to a crash
+    // under Solaris on reload.  See issue i70929 for details.
     //    ThrowIfDisposed();
     return OUString("DrawController") ;
 }
@@ -214,24 +206,19 @@ OUString SAL_CALL DrawController::getImplementationName(  ) throw(RuntimeExcepti
 static const char ssServiceName[] = "com.sun.star.drawing.DrawingDocumentDrawView";
 
 sal_Bool SAL_CALL DrawController::supportsService (const OUString& rsServiceName)
-    throw(RuntimeException, std::exception)
 {
     return cppu::supportsService(this, rsServiceName);
 }
 
 Sequence<OUString> SAL_CALL DrawController::getSupportedServiceNames()
-    throw(RuntimeException, std::exception)
 {
     ThrowIfDisposed();
-    Sequence<OUString> aSupportedServices (1);
-    OUString* pServices = aSupportedServices.getArray();
-    pServices[0] = ssServiceName;
+    Sequence<OUString> aSupportedServices { ssServiceName };
     return aSupportedServices;
 }
 
 //------ XSelectionSupplier --------------------------------------------
 sal_Bool SAL_CALL DrawController::select (const Any& aSelection)
-    throw(lang::IllegalArgumentException, RuntimeException, std::exception)
 {
     ThrowIfDisposed();
     SolarMutexGuard aGuard;
@@ -243,7 +230,6 @@ sal_Bool SAL_CALL DrawController::select (const Any& aSelection)
 }
 
 Any SAL_CALL DrawController::getSelection()
-    throw(RuntimeException, std::exception)
 {
     ThrowIfDisposed();
     SolarMutexGuard aGuard;
@@ -256,7 +242,6 @@ Any SAL_CALL DrawController::getSelection()
 
 void SAL_CALL DrawController::addSelectionChangeListener(
     const Reference< view::XSelectionChangeListener >& xListener)
-    throw(RuntimeException, std::exception)
 {
     if( mbDisposing )
         throw lang::DisposedException();
@@ -266,7 +251,6 @@ void SAL_CALL DrawController::addSelectionChangeListener(
 
 void SAL_CALL DrawController::removeSelectionChangeListener(
     const Reference< view::XSelectionChangeListener >& xListener )
-    throw(RuntimeException, std::exception)
 {
     if (rBHelper.bDisposed)
         throw lang::DisposedException();
@@ -278,7 +262,6 @@ void SAL_CALL DrawController::removeSelectionChangeListener(
 
 void SAL_CALL
     DrawController::disposing (const lang::EventObject& )
-    throw (uno::RuntimeException, std::exception)
 {
 }
 
@@ -286,7 +269,6 @@ void SAL_CALL
 
 void  SAL_CALL
     DrawController::selectionChanged (const lang::EventObject& rEvent)
-        throw (uno::RuntimeException, std::exception)
 {
     ThrowIfDisposed();
     // Have to forward the event to our selection change listeners.
@@ -303,7 +285,7 @@ void  SAL_CALL
                 view::XSelectionChangeListener* pListener =
                     static_cast<view::XSelectionChangeListener*>(
                         aIterator.next());
-                if (pListener != NULL)
+                if (pListener != nullptr)
                     pListener->selectionChanged (rEvent);
             }
             catch (const RuntimeException&)
@@ -316,7 +298,6 @@ void  SAL_CALL
 // XDrawView
 
 void SAL_CALL DrawController::setCurrentPage( const Reference< drawing::XDrawPage >& xPage )
-    throw(RuntimeException, std::exception)
 {
     ThrowIfDisposed();
     SolarMutexGuard aGuard;
@@ -326,7 +307,6 @@ void SAL_CALL DrawController::setCurrentPage( const Reference< drawing::XDrawPag
 }
 
 Reference< drawing::XDrawPage > SAL_CALL DrawController::getCurrentPage()
-    throw(RuntimeException, std::exception)
 {
     ThrowIfDisposed();
     SolarMutexGuard aGuard;
@@ -339,12 +319,12 @@ Reference< drawing::XDrawPage > SAL_CALL DrawController::getCurrentPage()
     // When there is not yet a sub controller (during initialization) then fall back
     // to the current page in mpCurrentPage.
     if ( ! xPage.is() && mpCurrentPage.is())
-        xPage = Reference<drawing::XDrawPage>(mpCurrentPage->getUnoPage(), UNO_QUERY);
+        xPage.set(mpCurrentPage->getUnoPage(), UNO_QUERY);
 
     return xPage;
 }
 
-void DrawController::FireVisAreaChanged (const Rectangle& rVisArea) throw()
+void DrawController::FireVisAreaChanged (const ::tools::Rectangle& rVisArea) throw()
 {
     if( maLastVisArea != rVisArea )
     {
@@ -374,7 +354,7 @@ void DrawController::FireSelectionChangeListener() throw()
         m_aSelectionTypeIdentifier);
     if( pLC )
     {
-        Reference< XInterface > xSource( (XWeak*)this );
+        Reference< XInterface > xSource( static_cast<XWeak*>(this) );
         const lang::EventObject aEvent( xSource );
 
         // iterate over all listeners and send events
@@ -385,7 +365,7 @@ void DrawController::FireSelectionChangeListener() throw()
             {
                 view::XSelectionChangeListener * pL =
                     static_cast<view::XSelectionChangeListener*>(aIt.next());
-                if (pL != NULL)
+                if (pL != nullptr)
                     pL->selectionChanged( aEvent );
             }
             catch (const RuntimeException&)
@@ -432,7 +412,7 @@ void DrawController::FireSwitchCurrentPage (SdPage* pNewCurrentPage) throw()
                 makeAny(Reference<drawing::XDrawPage>(pNewCurrentPage->getUnoPage(), UNO_QUERY)));
 
             Any aOldValue;
-            if (pCurrentPage != NULL)
+            if (pCurrentPage != nullptr)
             {
                 Reference<drawing::XDrawPage> xOldPage (pCurrentPage->getUnoPage(), UNO_QUERY);
                 aOldValue <<= xOldPage;
@@ -442,13 +422,9 @@ void DrawController::FireSwitchCurrentPage (SdPage* pNewCurrentPage) throw()
 
             mpCurrentPage.reset(pNewCurrentPage);
         }
-        catch (const uno::Exception&)
+        catch (const uno::Exception& e)
         {
-            OSL_FAIL(
-                OString("sd::SdUnoDrawView::FireSwitchCurrentPage(), exception caught: " +
-                    OUStringToOString(
-                        comphelper::anyToString( cppu::getCaughtException() ),
-                        RTL_TEXTENCODING_UTF8 )).getStr() );
+            SAL_WARN("sd", "sd::SdUnoDrawView::FireSwitchCurrentPage(), exception caught:  " << e);
         }
     }
 }
@@ -457,10 +433,10 @@ void DrawController::NotifyAccUpdate()
 {
     sal_Int32 nHandle = PROPERTY_UPDATEACC;
     Any aNewValue, aOldValue;
-    fire (&nHandle, &aNewValue, &aOldValue, 1, sal_False);
+    fire (&nHandle, &aNewValue, &aOldValue, 1, false);
 }
 
-void DrawController::fireChangeLayer( ::com::sun::star::uno::Reference< ::com::sun::star::drawing::XLayer>* pCurrentLayer ) throw()
+void DrawController::fireChangeLayer( css::uno::Reference< css::drawing::XLayer>* pCurrentLayer ) throw()
 {
     if( pCurrentLayer != mpCurrentLayer )
     {
@@ -470,7 +446,7 @@ void DrawController::fireChangeLayer( ::com::sun::star::uno::Reference< ::com::s
 
         Any aOldValue ;
 
-        fire (&nHandle, &aNewValue, &aOldValue, 1, sal_False);
+        fire (&nHandle, &aNewValue, &aOldValue, 1, false);
 
         mpCurrentLayer = pCurrentLayer;
     }
@@ -488,7 +464,7 @@ void DrawController::fireSwitchCurrentPage(sal_Int32 pageIndex ) throw()
 
         // Use new property to handle page change event
         sal_Int32 nHandles = PROPERTY_PAGE_CHANGE;
-        fire( &nHandles, &aNewValue, &aOldValue, 1, sal_False );
+        fire( &nHandles, &aNewValue, &aOldValue, 1, false );
 }
 
 void DrawController::FirePropertyChange (
@@ -498,7 +474,7 @@ void DrawController::FirePropertyChange (
 {
     try
     {
-        fire (&nHandle, &rNewValue, &rOldValue, 1, sal_False);
+        fire (&nHandle, &rNewValue, &rOldValue, 1, false);
     }
     catch (const RuntimeException&)
     {
@@ -512,41 +488,41 @@ void DrawController::FirePropertyChange (
 
 void DrawController::BroadcastContextChange() const
 {
-    ::boost::shared_ptr<ViewShell> pViewShell (mpBase->GetMainViewShell());
+    std::shared_ptr<ViewShell> pViewShell (mpBase->GetMainViewShell());
     if ( ! pViewShell)
         return;
 
-    EnumContext::Context eContext (EnumContext::Context_Unknown);
+    EnumContext::Context eContext (EnumContext::Context::Unknown);
     switch (pViewShell->GetShellType())
     {
         case ViewShell::ST_IMPRESS:
         case ViewShell::ST_DRAW:
             if (mbMasterPageMode)
-                eContext = EnumContext::Context_MasterPage;
+                eContext = EnumContext::Context::MasterPage;
             else
-                eContext = EnumContext::Context_DrawPage;
+                eContext = EnumContext::Context::DrawPage;
             break;
 
         case ViewShell::ST_NOTES:
-            eContext = EnumContext::Context_NotesPage;
+            eContext = EnumContext::Context::NotesPage;
             break;
 
         case ViewShell::ST_HANDOUT:
-            eContext = EnumContext::Context_HandoutPage;
+            eContext = EnumContext::Context::HandoutPage;
             break;
 
         case ViewShell::ST_OUTLINE:
-            eContext = EnumContext::Context_OutlineText;
+            eContext = EnumContext::Context::OutlineText;
             break;
 
         case ViewShell::ST_SLIDE_SORTER:
-            eContext = EnumContext::Context_SlidesorterPage;
+            eContext = EnumContext::Context::SlidesorterPage;
             break;
 
         case ViewShell::ST_PRESENTATION:
         case ViewShell::ST_NONE:
         default:
-            eContext = EnumContext::Context_Empty;
+            eContext = EnumContext::Context::Empty;
             break;
     }
 
@@ -556,14 +532,13 @@ void DrawController::BroadcastContextChange() const
 void DrawController::ReleaseViewShellBase()
 {
     DisposeFrameworkControllers();
-    mpBase = NULL;
+    mpBase = nullptr;
 }
 
 //===== XControllerManager ==============================================================
 
 Reference<XConfigurationController> SAL_CALL
     DrawController::getConfigurationController()
-    throw (RuntimeException, std::exception)
 {
     ThrowIfDisposed();
 
@@ -572,7 +547,6 @@ Reference<XConfigurationController> SAL_CALL
 
 Reference<XModuleController> SAL_CALL
     DrawController::getModuleController()
-    throw (RuntimeException, std::exception)
 {
     ThrowIfDisposed();
 
@@ -592,7 +566,6 @@ const Sequence<sal_Int8>& DrawController::getUnoTunnelId()
 }
 
 sal_Int64 SAL_CALL DrawController::getSomething (const Sequence<sal_Int8>& rId)
-    throw (RuntimeException, std::exception)
 {
     sal_Int64 nResult = 0;
 
@@ -610,90 +583,74 @@ sal_Int64 SAL_CALL DrawController::getSomething (const Sequence<sal_Int8>& rId)
 void DrawController::FillPropertyTable (
     ::std::vector<beans::Property>& rProperties)
 {
-    rProperties.push_back(
-        beans::Property("VisibleArea",
+    rProperties.emplace_back("VisibleArea",
             PROPERTY_WORKAREA,
-            ::cppu::UnoType< ::com::sun::star::awt::Rectangle>::get(),
-            beans::PropertyAttribute::BOUND | beans::PropertyAttribute::READONLY));
-    rProperties.push_back(
-        beans::Property(
+            ::cppu::UnoType< css::awt::Rectangle>::get(),
+            beans::PropertyAttribute::BOUND | beans::PropertyAttribute::READONLY);
+    rProperties.emplace_back(
             "SubController",
             PROPERTY_SUB_CONTROLLER,
             cppu::UnoType<drawing::XDrawSubController>::get(),
-            beans::PropertyAttribute::BOUND));
-    rProperties.push_back(
-        beans::Property(
+            beans::PropertyAttribute::BOUND);
+    rProperties.emplace_back(
             "CurrentPage",
             PROPERTY_CURRENTPAGE,
             cppu::UnoType<drawing::XDrawPage>::get(),
-            beans::PropertyAttribute::BOUND ));
-    rProperties.push_back(
-        beans::Property("IsLayerMode",
+            beans::PropertyAttribute::BOUND );
+    rProperties.emplace_back("IsLayerMode",
             PROPERTY_LAYERMODE,
             cppu::UnoType<bool>::get(),
-            beans::PropertyAttribute::BOUND ));
-    rProperties.push_back(
-        beans::Property("IsMasterPageMode",
+            beans::PropertyAttribute::BOUND );
+    rProperties.emplace_back("IsMasterPageMode",
             PROPERTY_MASTERPAGEMODE,
             cppu::UnoType<bool>::get(),
-            beans::PropertyAttribute::BOUND ));
-    rProperties.push_back(
-        beans::Property("ActiveLayer",
+            beans::PropertyAttribute::BOUND );
+    rProperties.emplace_back("ActiveLayer",
             PROPERTY_ACTIVE_LAYER,
             cppu::UnoType<drawing::XLayer>::get(),
-            beans::PropertyAttribute::BOUND ));
-    rProperties.push_back(
-        beans::Property("ZoomValue",
+            beans::PropertyAttribute::BOUND );
+    rProperties.emplace_back("ZoomValue",
             PROPERTY_ZOOMVALUE,
             ::cppu::UnoType<sal_Int16>::get(),
-            beans::PropertyAttribute::BOUND ));
-    rProperties.push_back(
-        beans::Property("ZoomType",
+            beans::PropertyAttribute::BOUND );
+    rProperties.emplace_back("ZoomType",
             PROPERTY_ZOOMTYPE,
             ::cppu::UnoType<sal_Int16>::get(),
-            beans::PropertyAttribute::BOUND ));
-    rProperties.push_back(
-        beans::Property("ViewOffset",
+            beans::PropertyAttribute::BOUND );
+    rProperties.emplace_back("ViewOffset",
             PROPERTY_VIEWOFFSET,
-            ::cppu::UnoType< ::com::sun::star::awt::Point>::get(),
-            beans::PropertyAttribute::BOUND ));
-    rProperties.push_back(
-        beans::Property("DrawViewMode",
+            ::cppu::UnoType< css::awt::Point>::get(),
+            beans::PropertyAttribute::BOUND );
+    rProperties.emplace_back("DrawViewMode",
             PROPERTY_DRAWVIEWMODE,
-            ::cppu::UnoType< ::com::sun::star::awt::Point>::get(),
-            beans::PropertyAttribute::BOUND|beans::PropertyAttribute::READONLY|beans::PropertyAttribute::MAYBEVOID ));
+            ::cppu::UnoType< css::awt::Point>::get(),
+            beans::PropertyAttribute::BOUND|beans::PropertyAttribute::READONLY|beans::PropertyAttribute::MAYBEVOID );
     // add new property to update current page's acc information
-    rProperties.push_back(
-        beans::Property( OUString( RTL_CONSTASCII_USTRINGPARAM("UpdateAcc") ),
+    rProperties.emplace_back( "UpdateAcc",
             PROPERTY_UPDATEACC,
             ::cppu::UnoType<sal_Int16>::get(),
-            beans::PropertyAttribute::BOUND ));
-    rProperties.push_back(
-        beans::Property( OUString( RTL_CONSTASCII_USTRINGPARAM("PageChange") ),
+            beans::PropertyAttribute::BOUND );
+    rProperties.emplace_back( "PageChange",
             PROPERTY_PAGE_CHANGE,
             ::cppu::UnoType<sal_Int16>::get(),
-            beans::PropertyAttribute::BOUND ));
+            beans::PropertyAttribute::BOUND );
 }
 
 IPropertyArrayHelper & DrawController::getInfoHelper()
 {
     SolarMutexGuard aGuard;
 
-    if (mpPropertyArrayHelper.get() == NULL)
+    if (mpPropertyArrayHelper.get() == nullptr)
     {
         ::std::vector<beans::Property> aProperties;
-        FillPropertyTable (aProperties);
-        Sequence<beans::Property> aPropertySequence (aProperties.size());
-        for (unsigned int i=0; i<aProperties.size(); i++)
-            aPropertySequence[i] = aProperties[i];
-        mpPropertyArrayHelper.reset(new OPropertyArrayHelper(aPropertySequence, sal_False));
+        FillPropertyTable(aProperties);
+        mpPropertyArrayHelper.reset(new OPropertyArrayHelper(comphelper::containerToSequence(aProperties), false));
     }
 
     return *mpPropertyArrayHelper.get();
 }
 
 Reference < beans::XPropertySetInfo >  DrawController::getPropertySetInfo()
-        throw ( ::com::sun::star::uno::RuntimeException, std::exception)
 {
     SolarMutexGuard aGuard;
 
@@ -701,22 +658,22 @@ Reference < beans::XPropertySetInfo >  DrawController::getPropertySetInfo()
     return xInfo;
 }
 
-uno::Reference< form::runtime::XFormController > SAL_CALL DrawController::getFormController( const uno::Reference< form::XForm >& Form ) throw (uno::RuntimeException, std::exception)
+uno::Reference< form::runtime::XFormController > SAL_CALL DrawController::getFormController( const uno::Reference< form::XForm >& Form )
 {
     SolarMutexGuard aGuard;
 
     FmFormShell* pFormShell = mpBase->GetFormShellManager()->GetFormShell();
     SdrView* pSdrView = mpBase->GetDrawView();
-    ::boost::shared_ptr<ViewShell> pViewShell = mpBase->GetMainViewShell();
-    ::sd::Window* pWindow = pViewShell ? pViewShell->GetActiveWindow() : NULL;
+    std::shared_ptr<ViewShell> pViewShell = mpBase->GetMainViewShell();
+    ::sd::Window* pWindow = pViewShell ? pViewShell->GetActiveWindow() : nullptr;
 
-    uno::Reference< form::runtime::XFormController > xController( NULL );
+    uno::Reference< form::runtime::XFormController > xController( nullptr );
     if ( pFormShell && pSdrView && pWindow )
         xController = FmFormShell::GetFormController( Form, *pSdrView, *pWindow );
     return xController;
 }
 
-sal_Bool SAL_CALL DrawController::isFormDesignMode(  ) throw (uno::RuntimeException, std::exception)
+sal_Bool SAL_CALL DrawController::isFormDesignMode(  )
 {
     SolarMutexGuard aGuard;
 
@@ -729,25 +686,25 @@ sal_Bool SAL_CALL DrawController::isFormDesignMode(  ) throw (uno::RuntimeExcept
     return bIsDesignMode;
 }
 
-void SAL_CALL DrawController::setFormDesignMode( sal_Bool _DesignMode ) throw (uno::RuntimeException, std::exception)
+void SAL_CALL DrawController::setFormDesignMode( sal_Bool DesignMode )
 {
     SolarMutexGuard aGuard;
 
     FmFormShell* pFormShell = mpBase->GetFormShellManager()->GetFormShell();
     if ( pFormShell )
-        pFormShell->SetDesignMode( _DesignMode );
+        pFormShell->SetDesignMode( DesignMode );
 }
 
-uno::Reference< awt::XControl > SAL_CALL DrawController::getControl( const uno::Reference< awt::XControlModel >& xModel ) throw (container::NoSuchElementException, uno::RuntimeException, std::exception)
+uno::Reference< awt::XControl > SAL_CALL DrawController::getControl( const uno::Reference< awt::XControlModel >& xModel )
 {
     SolarMutexGuard aGuard;
 
     FmFormShell* pFormShell = mpBase->GetFormShellManager()->GetFormShell();
     SdrView* pSdrView = mpBase->GetDrawView();
-    ::boost::shared_ptr<ViewShell> pViewShell = mpBase->GetMainViewShell();
-    ::sd::Window* pWindow = pViewShell ? pViewShell->GetActiveWindow() : NULL;
+    std::shared_ptr<ViewShell> pViewShell = mpBase->GetMainViewShell();
+    ::sd::Window* pWindow = pViewShell ? pViewShell->GetActiveWindow() : nullptr;
 
-    uno::Reference< awt::XControl > xControl( NULL );
+    uno::Reference< awt::XControl > xControl( nullptr );
     if ( pFormShell && pSdrView && pWindow )
         pFormShell->GetFormControl( xModel, *pSdrView, *pWindow, xControl );
     return xControl;
@@ -758,7 +715,6 @@ sal_Bool DrawController::convertFastPropertyValue (
     Any & rOldValue,
     sal_Int32 nHandle,
     const Any& rValue)
-    throw ( com::sun::star::lang::IllegalArgumentException)
 {
     bool bResult = false;
 
@@ -779,7 +735,7 @@ sal_Bool DrawController::convertFastPropertyValue (
         catch (const beans::UnknownPropertyException&)
         {
             // The property is unknown and thus an illegal argument to this method.
-            throw com::sun::star::lang::IllegalArgumentException();
+            throw css::lang::IllegalArgumentException();
         }
     }
 
@@ -789,7 +745,6 @@ sal_Bool DrawController::convertFastPropertyValue (
 void DrawController::setFastPropertyValue_NoBroadcast (
     sal_Int32 nHandle,
     const Any& rValue)
-    throw ( com::sun::star::uno::Exception, std::exception)
 {
     SolarMutexGuard aGuard;
     if (nHandle == PROPERTY_SUB_CONTROLLER)
@@ -842,8 +797,8 @@ void DrawController::ProvideFrameworkControllers()
     }
     catch (const RuntimeException&)
     {
-        mxConfigurationController = NULL;
-        mxModuleController = NULL;
+        mxConfigurationController = nullptr;
+        mxModuleController = nullptr;
     }
 }
 
@@ -853,17 +808,16 @@ void DrawController::DisposeFrameworkControllers()
     if (xComponent.is())
         xComponent->dispose();
 
-    xComponent = Reference<XComponent>(mxConfigurationController, UNO_QUERY);
+    xComponent.set(mxConfigurationController, UNO_QUERY);
     if (xComponent.is())
         xComponent->dispose();
 }
 
 void DrawController::ThrowIfDisposed() const
-    throw (::com::sun::star::lang::DisposedException)
 {
     if (rBHelper.bDisposed || rBHelper.bInDispose || mbDisposing)
     {
-        OSL_TRACE ("Calling disposed DrawController object. Throwing exception:");
+        SAL_WARN("sd", "Calling disposed DrawController object. Throwing exception:");
         throw lang::DisposedException (
             "DrawController object has already been disposed",
             const_cast<uno::XWeak*>(static_cast<const uno::XWeak*>(this)));
