@@ -17,32 +17,30 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-
-#include "OutlinerIterator.hxx"
-#include "OutlinerIteratorImpl.hxx"
+#include <OutlinerIterator.hxx>
+#include <OutlinerIteratorImpl.hxx>
 #include <svx/svditer.hxx>
 #include <sfx2/dispatch.hxx>
 #include <sfx2/viewfrm.hxx>
-#include "Outliner.hxx"
+#include <Outliner.hxx>
 
-#include "drawdoc.hxx"
-#include "DrawViewShell.hxx"
-#include "drawview.hxx"
-#include "sdpage.hxx"
-#include "FrameView.hxx"
-#include "DrawDocShell.hxx"
-#include "Window.hxx"
+#include <drawdoc.hxx>
+#include <DrawViewShell.hxx>
+#include <drawview.hxx>
+#include <sdpage.hxx>
+#include <FrameView.hxx>
+#include <DrawDocShell.hxx>
+#include <Window.hxx>
 
 namespace sd { namespace outliner {
 
-
 //===== IteratorPosition ======================================================
 
-IteratorPosition::IteratorPosition (void)
+IteratorPosition::IteratorPosition()
 : mnText(0)
 , mnPageIndex(-1)
-, mePageKind(PK_STANDARD)
-, meEditMode(EM_PAGE)
+, mePageKind(PageKind::Standard)
+, meEditMode(EditMode::Page)
 {
 }
 
@@ -55,20 +53,6 @@ IteratorPosition::IteratorPosition (const IteratorPosition& aPosition)
 {
 }
 
-IteratorPosition::~IteratorPosition (void)
-{
-}
-
-IteratorPosition& IteratorPosition::operator= (const IteratorPosition& aPosition)
-{
-    mxObject = aPosition.mxObject;
-    mnText = aPosition.mnText;
-    mnPageIndex = aPosition.mnPageIndex;
-    mePageKind = aPosition.mePageKind;
-    meEditMode = aPosition.meEditMode;
-    return *this;
-}
-
 bool IteratorPosition::operator== (const IteratorPosition& aPosition) const
 {
     return mxObject.get() == aPosition.mxObject.get()
@@ -78,71 +62,68 @@ bool IteratorPosition::operator== (const IteratorPosition& aPosition) const
         && meEditMode == aPosition.meEditMode;
 }
 
-
-
-
 //===== Iterator ==============================================================
 
-Iterator::Iterator (void)
+Iterator::Iterator()
 {
-    mpIterator = NULL;
 }
 
 Iterator::Iterator (const Iterator& rIterator)
+    : mxIterator(rIterator.mxIterator ? rIterator.mxIterator->Clone() : nullptr)
+{
+}
+
+Iterator::Iterator (Iterator&& rIterator)
+    : mxIterator(std::move(rIterator.mxIterator))
 {
-    mpIterator = rIterator.mpIterator->Clone();
 }
 
 Iterator::Iterator (IteratorImplBase* pObject)
+    : mxIterator(pObject)
 {
-    mpIterator = pObject;
 }
 
-Iterator::~Iterator (void)
+Iterator::~Iterator()
 {
-    delete mpIterator;
 }
 
 Iterator& Iterator::operator= (const Iterator& rIterator)
 {
     if (this != &rIterator)
     {
-        delete mpIterator;
-        if (rIterator.mpIterator != NULL)
-            mpIterator = rIterator.mpIterator->Clone();
+        if (rIterator.mxIterator)
+            mxIterator.reset(rIterator.mxIterator->Clone());
         else
-            mpIterator = NULL;
+            mxIterator.reset();
     }
     return *this;
 }
 
+Iterator& Iterator::operator= (Iterator&& rIterator)
+{
+    mxIterator = std::move(rIterator.mxIterator);
+    return *this;
+}
+
 const IteratorPosition& Iterator::operator* () const
 {
-    DBG_ASSERT (mpIterator!=NULL, "::sd::outliner::Iterator::operator* : missing implementation object");
-    return mpIterator->GetPosition();
+    DBG_ASSERT (mxIterator, "::sd::outliner::Iterator::operator* : missing implementation object");
+    return mxIterator->GetPosition();
 }
 
 Iterator& Iterator::operator++ ()
 {
-    if (mpIterator!=NULL)
-        mpIterator->GotoNextText();
+    if (mxIterator)
+        mxIterator->GotoNextText();
     return *this;
 }
 
-Iterator Iterator::operator++ (int)
-{
-    Iterator aTmp (*this);
-    if (mpIterator!=NULL)
-        mpIterator->GotoNextText();
-    return aTmp;
-}
-
 bool Iterator::operator== (const Iterator& rIterator)
 {
-    if (mpIterator == NULL || rIterator.mpIterator==NULL)
-        return mpIterator == rIterator.mpIterator;
+    if (!mxIterator || !rIterator.mxIterator)
+        return mxIterator.get() == rIterator.mxIterator.get();
     else
-        return *mpIterator == *rIterator.mpIterator;
+        return *mxIterator == *rIterator.mxIterator;
 }
 
 bool Iterator::operator!= (const Iterator& rIterator)
@@ -150,35 +131,34 @@ bool Iterator::operator!= (const Iterator& rIterator)
     return ! operator==(rIterator);
 }
 
-void Iterator::Reverse (void)
+void Iterator::Reverse()
 {
-    if (mpIterator != NULL)
-        mpIterator->Reverse();
+    if (mxIterator)
+        mxIterator->Reverse();
 }
 
 //===== IteratorFactory =======================================================
 
-OutlinerContainer::OutlinerContainer (Outliner* pOutliner)
+OutlinerContainer::OutlinerContainer (SdOutliner* pOutliner)
 : mpOutliner(pOutliner)
 {
 }
 
-Iterator OutlinerContainer::begin (void)
+Iterator OutlinerContainer::begin()
 {
     return CreateIterator (BEGIN);
 }
 
-Iterator OutlinerContainer::end (void)
+Iterator OutlinerContainer::end()
 {
     return CreateIterator (END);
 }
 
-Iterator OutlinerContainer::current (void)
+Iterator OutlinerContainer::current()
 {
     return CreateIterator (CURRENT);
 }
 
-
 Iterator OutlinerContainer::CreateIterator (IteratorLocation aLocation)
 {
     // Decide on certain features of the outliner which kind of iterator to
@@ -203,7 +183,7 @@ Iterator OutlinerContainer::CreateIterator (IteratorLocation aLocation)
 Iterator OutlinerContainer::CreateSelectionIterator (
     const ::std::vector<SdrObjectWeakRef>& rObjectList,
     SdDrawDocument* pDocument,
-    const ::boost::shared_ptr<ViewShell>& rpViewShell,
+    const std::shared_ptr<ViewShell>& rpViewShell,
     bool bDirectionIsForward,
     IteratorLocation aLocation)
 {
@@ -242,7 +222,7 @@ Iterator OutlinerContainer::CreateSelectionIterator (
 
 Iterator OutlinerContainer::CreateDocumentIterator (
     SdDrawDocument* pDocument,
-    const ::boost::shared_ptr<ViewShell>& rpViewShell,
+    const std::shared_ptr<ViewShell>& rpViewShell,
     bool bDirectionIsForward,
     IteratorLocation aLocation)
 {
@@ -257,32 +237,32 @@ Iterator OutlinerContainer::CreateDocumentIterator (
         default:
             if (bDirectionIsForward)
             {
-                ePageKind = PK_STANDARD;
-                eEditMode = EM_PAGE;
+                ePageKind = PageKind::Standard;
+                eEditMode = EditMode::Page;
             }
             else
             {
-                ePageKind = PK_HANDOUT;
-                eEditMode = EM_MASTERPAGE;
+                ePageKind = PageKind::Handout;
+                eEditMode = EditMode::MasterPage;
             }
             break;
 
         case END:
             if (bDirectionIsForward)
             {
-                ePageKind = PK_HANDOUT;
-                eEditMode = EM_MASTERPAGE;
+                ePageKind = PageKind::Handout;
+                eEditMode = EditMode::MasterPage;
             }
             else
             {
-                ePageKind = PK_STANDARD;
-                eEditMode = EM_PAGE;
+                ePageKind = PageKind::Standard;
+                eEditMode = EditMode::Page;
             }
             break;
 
         case CURRENT:
-            const ::boost::shared_ptr<DrawViewShell> pDrawViewShell(
-                ::boost::dynamic_pointer_cast<DrawViewShell>(rpViewShell));
+            const std::shared_ptr<DrawViewShell> pDrawViewShell(
+                std::dynamic_pointer_cast<DrawViewShell>(rpViewShell));
             if (pDrawViewShell.get())
             {
                 ePageKind = pDrawViewShell->GetPageKind();
@@ -290,8 +270,8 @@ Iterator OutlinerContainer::CreateDocumentIterator (
             }
             else
             {
-                ePageKind = PK_STANDARD;
-                eEditMode = EM_PAGE;
+                ePageKind = PageKind::Standard;
+                eEditMode = EditMode::Page;
             }
             break;
     }
@@ -305,8 +285,8 @@ Iterator OutlinerContainer::CreateDocumentIterator (
 }
 
 sal_Int32 OutlinerContainer::GetPageIndex (
-    SdDrawDocument* pDocument,
-    const ::boost::shared_ptr<ViewShell>& rpViewShell,
+    SdDrawDocument const * pDocument,
+    const std::shared_ptr<ViewShell>& rpViewShell,
     PageKind ePageKind,
     EditMode eEditMode,
     bool bDirectionIsForward,
@@ -317,15 +297,15 @@ sal_Int32 OutlinerContainer::GetPageIndex (
     sal_Int32 nPageIndex;
     sal_Int32 nPageCount;
 
-    const ::boost::shared_ptr<DrawViewShell> pDrawViewShell(
-        ::boost::dynamic_pointer_cast<DrawViewShell>(rpViewShell));
+    const std::shared_ptr<DrawViewShell> pDrawViewShell(
+        std::dynamic_pointer_cast<DrawViewShell>(rpViewShell));
 
     switch (eEditMode)
     {
-        case EM_PAGE:
+        case EditMode::Page:
             nPageCount = pDocument->GetSdPageCount (ePageKind);
             break;
-        case EM_MASTERPAGE:
+        case EditMode::MasterPage:
             nPageCount = pDocument->GetMasterSdPageCount(ePageKind);
             break;
         default:
@@ -336,11 +316,11 @@ sal_Int32 OutlinerContainer::GetPageIndex (
     {
         case CURRENT:
             if (pDrawViewShell.get())
-                nPageIndex = pDrawViewShell->GetCurPageId() - 1;
+                nPageIndex = pDrawViewShell->GetCurPagePos();
             else
             {
                 const SdPage* pPage = rpViewShell->GetActualPage();
-                if (pPage != NULL)
+                if (pPage != nullptr)
                     nPageIndex = (pPage->GetPageNum()-1)/2;
                 else
                     nPageIndex = 0;
@@ -366,22 +346,19 @@ sal_Int32 OutlinerContainer::GetPageIndex (
     return nPageIndex;
 }
 
-
-
-
 //===== IteratorImplBase ====================================================
 
 IteratorImplBase::IteratorImplBase(SdDrawDocument* pDocument,
-    const ::boost::weak_ptr<ViewShell>& rpViewShellWeak,
+    const std::weak_ptr<ViewShell>& rpViewShellWeak,
     bool bDirectionIsForward)
 :   maPosition()
 ,   mpDocument (pDocument)
 ,   mpViewShellWeak (rpViewShellWeak)
 ,   mbDirectionIsForward (bDirectionIsForward)
 {
-    ::boost::shared_ptr<DrawViewShell> pDrawViewShell;
+    std::shared_ptr<DrawViewShell> pDrawViewShell;
     if ( ! mpViewShellWeak.expired())
-        pDrawViewShell = ::boost::dynamic_pointer_cast<DrawViewShell>(rpViewShellWeak.lock());
+        pDrawViewShell = std::dynamic_pointer_cast<DrawViewShell>(rpViewShellWeak.lock());
 
     if (pDrawViewShell.get())
     {
@@ -390,13 +367,13 @@ IteratorImplBase::IteratorImplBase(SdDrawDocument* pDocument,
     }
     else
     {
-        maPosition.mePageKind = PK_STANDARD;
-        maPosition.meEditMode = EM_PAGE;
+        maPosition.mePageKind = PageKind::Standard;
+        maPosition.meEditMode = EditMode::Page;
     }
 }
 
 IteratorImplBase::IteratorImplBase( SdDrawDocument* pDocument,
-    const ::boost::weak_ptr<ViewShell>& rpViewShellWeak,
+    const std::weak_ptr<ViewShell>& rpViewShellWeak,
     bool bDirectionIsForward, PageKind ePageKind, EditMode eEditMode)
 : maPosition()
 , mpDocument (pDocument)
@@ -407,7 +384,7 @@ IteratorImplBase::IteratorImplBase( SdDrawDocument* pDocument,
     maPosition.meEditMode = eEditMode;
 }
 
-IteratorImplBase::~IteratorImplBase (void)
+IteratorImplBase::~IteratorImplBase()
 {}
 
 bool IteratorImplBase::operator== (const IteratorImplBase& rIterator) const
@@ -415,7 +392,7 @@ bool IteratorImplBase::operator== (const IteratorImplBase& rIterator) const
     return maPosition == rIterator.maPosition;
 }
 
-bool IteratorImplBase::IsEqual (const IteratorImplBase& rIterator, IteratorType ) const
+bool IteratorImplBase::IsEqualSelection(const IteratorImplBase& rIterator) const
 {
     // When this method is executed instead of the ones from derived classes
     // then the argument is of another type then the object itself.  In this
@@ -423,17 +400,14 @@ bool IteratorImplBase::IsEqual (const IteratorImplBase& rIterator, IteratorType
     return maPosition == rIterator.maPosition;
 }
 
-const IteratorPosition& IteratorImplBase::GetPosition (void)
+const IteratorPosition& IteratorImplBase::GetPosition()
 {
     return maPosition;
 }
 
-
-
-
 IteratorImplBase* IteratorImplBase::Clone (IteratorImplBase* pObject) const
 {
-    if (pObject != NULL)
+    if (pObject != nullptr)
     {
         pObject->maPosition = maPosition;
         pObject->mpDocument = mpDocument;
@@ -443,22 +417,18 @@ IteratorImplBase* IteratorImplBase::Clone (IteratorImplBase* pObject) const
     return pObject;
 }
 
-
-
-void IteratorImplBase::Reverse (void)
+void IteratorImplBase::Reverse()
 {
     mbDirectionIsForward = ! mbDirectionIsForward;
 }
 
-
-
 //===== SelectionIteratorImpl ===========================================
 
 SelectionIteratorImpl::SelectionIteratorImpl (
     const ::std::vector<SdrObjectWeakRef>& rObjectList,
     sal_Int32 nObjectIndex,
     SdDrawDocument* pDocument,
-    const ::boost::weak_ptr<ViewShell>& rpViewShellWeak,
+    const std::weak_ptr<ViewShell>& rpViewShellWeak,
     bool bDirectionIsForward)
     : IteratorImplBase (pDocument, rpViewShellWeak, bDirectionIsForward),
       mrObjectList(rObjectList),
@@ -466,20 +436,19 @@ SelectionIteratorImpl::SelectionIteratorImpl (
 {
 }
 
-SelectionIteratorImpl::~SelectionIteratorImpl (void)
+SelectionIteratorImpl::~SelectionIteratorImpl()
 {}
 
 IteratorImplBase* SelectionIteratorImpl::Clone (IteratorImplBase* pObject) const
 {
     SelectionIteratorImpl* pIterator = static_cast<SelectionIteratorImpl*>(pObject);
-    if (pIterator == NULL)
+    if (pIterator == nullptr)
         pIterator = new SelectionIteratorImpl (
             mrObjectList, mnObjectIndex, mpDocument, mpViewShellWeak, mbDirectionIsForward);
     return pIterator;
 }
 
-
-void SelectionIteratorImpl::GotoNextText (void)
+void SelectionIteratorImpl::GotoNextText()
 {
     SdrTextObj* pTextObj = dynamic_cast< SdrTextObj* >( mrObjectList.at(mnObjectIndex).get() );
     if (mbDirectionIsForward)
@@ -527,110 +496,86 @@ void SelectionIteratorImpl::GotoNextText (void)
     }
 }
 
-
-const IteratorPosition& SelectionIteratorImpl::GetPosition (void)
+const IteratorPosition& SelectionIteratorImpl::GetPosition()
 {
     maPosition.mxObject = mrObjectList.at(mnObjectIndex);
 
     return maPosition;
 }
 
-
 bool SelectionIteratorImpl::operator== (const IteratorImplBase& rIterator) const
 {
-    return rIterator.IsEqual (*this, SELECTION);
+    return rIterator.IsEqualSelection(*this);
 }
 
-
-bool SelectionIteratorImpl::IsEqual (
-    const IteratorImplBase& rIterator,
-    IteratorType aType) const
+bool SelectionIteratorImpl::IsEqualSelection(const IteratorImplBase& rIterator) const
 {
-    if (aType == SELECTION)
-    {
-        const SelectionIteratorImpl* pSelectionIterator =
-            static_cast<const SelectionIteratorImpl*>(&rIterator);
-        return mpDocument == pSelectionIterator->mpDocument
-            && mnObjectIndex == pSelectionIterator->mnObjectIndex;
-    }
-    else
-        return false;
+    const SelectionIteratorImpl* pSelectionIterator =
+        static_cast<const SelectionIteratorImpl*>(&rIterator);
+    return mpDocument == pSelectionIterator->mpDocument
+        && mnObjectIndex == pSelectionIterator->mnObjectIndex;
 }
 
-
-
-
 //===== ViewIteratorImpl ================================================
 
 ViewIteratorImpl::ViewIteratorImpl (
     sal_Int32 nPageIndex,
     SdDrawDocument* pDocument,
-    const ::boost::weak_ptr<ViewShell>& rpViewShellWeak,
+    const std::weak_ptr<ViewShell>& rpViewShellWeak,
     bool bDirectionIsForward)
     : IteratorImplBase (pDocument, rpViewShellWeak, bDirectionIsForward),
       mbPageChangeOccurred(false),
-      mpPage(NULL),
-      mpObjectIterator(NULL)
+      mpPage(nullptr),
+      mpObjectIterator(nullptr)
 {
     SetPage (nPageIndex);
 }
 
-
-
-
 ViewIteratorImpl::ViewIteratorImpl (
     sal_Int32 nPageIndex,
     SdDrawDocument* pDocument,
-    const ::boost::weak_ptr<ViewShell>& rpViewShellWeak,
+    const std::weak_ptr<ViewShell>& rpViewShellWeak,
     bool bDirectionIsForward,
     PageKind ePageKind,
     EditMode eEditMode)
     : IteratorImplBase (pDocument, rpViewShellWeak, bDirectionIsForward, ePageKind, eEditMode),
       mbPageChangeOccurred(false),
-      mpPage(NULL),
-      mpObjectIterator(NULL)
+      mpPage(nullptr),
+      mpObjectIterator(nullptr)
 {
     SetPage (nPageIndex);
 }
 
-
-
-
-ViewIteratorImpl::~ViewIteratorImpl (void)
+ViewIteratorImpl::~ViewIteratorImpl()
 {
 }
 
-
-
-
 IteratorImplBase* ViewIteratorImpl::Clone (IteratorImplBase* pObject) const
 {
 
     ViewIteratorImpl* pIterator = static_cast<ViewIteratorImpl*>(pObject);
-    if (pIterator == NULL)
+    if (pIterator == nullptr)
         pIterator = new ViewIteratorImpl (
             maPosition.mnPageIndex, mpDocument, mpViewShellWeak, mbDirectionIsForward);
 
     IteratorImplBase::Clone (pObject);
 
-    if (mpObjectIterator != NULL)
+    if (mpObjectIterator != nullptr)
     {
-        pIterator->mpObjectIterator = new SdrObjListIter(*mpPage, IM_DEEPNOGROUPS, !mbDirectionIsForward);
+        pIterator->mpObjectIterator = new SdrObjListIter(*mpPage, SdrIterMode::DeepNoGroups, !mbDirectionIsForward);
 
         // No direct way to set the object iterator to the current object.
-        pIterator->maPosition.mxObject.reset(NULL);
+        pIterator->maPosition.mxObject.reset(nullptr);
         while (pIterator->mpObjectIterator->IsMore() && pIterator->maPosition.mxObject!=maPosition.mxObject)
             pIterator->maPosition.mxObject.reset(pIterator->mpObjectIterator->Next());
     }
     else
-        pIterator->mpObjectIterator = NULL;
+        pIterator->mpObjectIterator = nullptr;
 
     return pIterator;
 }
 
-
-
-void ViewIteratorImpl::GotoNextText(void)
+void ViewIteratorImpl::GotoNextText()
 {
     SdrTextObj* pTextObj = dynamic_cast< SdrTextObj* >( maPosition.mxObject.get() );
     if( pTextObj )
@@ -649,10 +594,10 @@ void ViewIteratorImpl::GotoNextText(void)
         }
     }
 
-    if (mpObjectIterator != NULL && mpObjectIterator->IsMore())
+    if (mpObjectIterator != nullptr && mpObjectIterator->IsMore())
         maPosition.mxObject.reset(mpObjectIterator->Next());
     else
-        maPosition.mxObject.reset(NULL);
+        maPosition.mxObject.reset(nullptr);
 
     if (!maPosition.mxObject.is() )
     {
@@ -661,12 +606,12 @@ void ViewIteratorImpl::GotoNextText(void)
         else
             SetPage (maPosition.mnPageIndex-1);
 
-        if (mpPage != NULL)
-            mpObjectIterator = new SdrObjListIter(*mpPage, IM_DEEPNOGROUPS, !mbDirectionIsForward);
-        if (mpObjectIterator!=NULL && mpObjectIterator->IsMore())
+        if (mpPage != nullptr)
+            mpObjectIterator = new SdrObjListIter(*mpPage, SdrIterMode::DeepNoGroups, !mbDirectionIsForward);
+        if (mpObjectIterator!=nullptr && mpObjectIterator->IsMore())
             maPosition.mxObject.reset(mpObjectIterator->Next());
         else
-            maPosition.mxObject.reset(NULL);
+            maPosition.mxObject.reset(nullptr);
     }
 
     maPosition.mnText = 0;
@@ -678,9 +623,6 @@ void ViewIteratorImpl::GotoNextText(void)
     }
 }
 
-
-
-
 void ViewIteratorImpl::SetPage (sal_Int32 nPageIndex)
 {
     mbPageChangeOccurred = (maPosition.mnPageIndex!=nPageIndex);
@@ -689,7 +631,7 @@ void ViewIteratorImpl::SetPage (sal_Int32 nPageIndex)
         maPosition.mnPageIndex = nPageIndex;
 
         sal_Int32 nPageCount;
-        if (maPosition.meEditMode == EM_PAGE)
+        if (maPosition.meEditMode == EditMode::Page)
             nPageCount = mpDocument->GetSdPageCount(maPosition.mePageKind);
         else
             nPageCount = mpDocument->GetMasterSdPageCount(
@@ -702,7 +644,7 @@ void ViewIteratorImpl::SetPage (sal_Int32 nPageIndex)
         // side is detected here and has to be reacted to by the caller.
         if (nPageIndex>=0 && nPageIndex < nPageCount)
         {
-            if (maPosition.meEditMode == EM_PAGE)
+            if (maPosition.meEditMode == EditMode::Page)
                 mpPage = mpDocument->GetSdPage (
                     (sal_uInt16)nPageIndex,
                     maPosition.mePageKind);
@@ -712,20 +654,20 @@ void ViewIteratorImpl::SetPage (sal_Int32 nPageIndex)
                     maPosition.mePageKind);
         }
         else
-            mpPage = NULL;
+            mpPage = nullptr;
     }
 
     // Set up object list iterator.
-    if (mpPage != NULL)
-        mpObjectIterator = new SdrObjListIter(*mpPage, IM_DEEPNOGROUPS, ! mbDirectionIsForward);
+    if (mpPage != nullptr)
+        mpObjectIterator = new SdrObjListIter(*mpPage, SdrIterMode::DeepNoGroups, ! mbDirectionIsForward);
     else
-        mpObjectIterator = NULL;
+        mpObjectIterator = nullptr;
 
     // Get object pointer.
-    if (mpObjectIterator!=NULL && mpObjectIterator->IsMore())
+    if (mpObjectIterator!=nullptr && mpObjectIterator->IsMore())
         maPosition.mxObject.reset( mpObjectIterator->Next() );
     else
-        maPosition.mxObject.reset( NULL );
+        maPosition.mxObject.reset( nullptr );
 
     maPosition.mnText = 0;
     if( !mbDirectionIsForward && maPosition.mxObject.is() )
@@ -737,24 +679,20 @@ void ViewIteratorImpl::SetPage (sal_Int32 nPageIndex)
 
 }
 
-
-
-
-void ViewIteratorImpl::Reverse (void)
+void ViewIteratorImpl::Reverse()
 {
     IteratorImplBase::Reverse ();
 
     // Create reversed object list iterator.
-    if (mpObjectIterator != NULL)
-        delete mpObjectIterator;
-    if (mpPage != NULL)
-        mpObjectIterator = new SdrObjListIter(*mpPage, IM_DEEPNOGROUPS, ! mbDirectionIsForward);
+    delete mpObjectIterator;
+    if (mpPage != nullptr)
+        mpObjectIterator = new SdrObjListIter(*mpPage, SdrIterMode::DeepNoGroups, ! mbDirectionIsForward);
     else
-        mpObjectIterator = NULL;
+        mpObjectIterator = nullptr;
 
     // Move iterator to the current object.
     SdrObjectWeakRef xObject = maPosition.mxObject;
-    maPosition.mxObject.reset(NULL);
+    maPosition.mxObject.reset(nullptr);
 
     if (!mpObjectIterator)
         return;
@@ -763,39 +701,30 @@ void ViewIteratorImpl::Reverse (void)
         maPosition.mxObject.reset(mpObjectIterator->Next());
 }
 
-
-
-
 //===== DocumentIteratorImpl ============================================
 
 DocumentIteratorImpl::DocumentIteratorImpl (
     sal_Int32 nPageIndex,
     PageKind ePageKind, EditMode eEditMode,
     SdDrawDocument* pDocument,
-    const ::boost::weak_ptr<ViewShell>& rpViewShellWeak,
+    const std::weak_ptr<ViewShell>& rpViewShellWeak,
     bool bDirectionIsForward)
     : ViewIteratorImpl (nPageIndex, pDocument, rpViewShellWeak, bDirectionIsForward,
         ePageKind, eEditMode)
 {
-    if (eEditMode == EM_PAGE)
+    if (eEditMode == EditMode::Page)
         mnPageCount = pDocument->GetSdPageCount (ePageKind);
     else
         mnPageCount = pDocument->GetMasterSdPageCount(ePageKind);
 }
 
-
-
-
-DocumentIteratorImpl::~DocumentIteratorImpl (void)
+DocumentIteratorImpl::~DocumentIteratorImpl()
 {}
 
-
-
-
 IteratorImplBase* DocumentIteratorImpl::Clone (IteratorImplBase* pObject) const
 {
     DocumentIteratorImpl* pIterator = static_cast<DocumentIteratorImpl*>(pObject);
-    if (pIterator == NULL)
+    if (pIterator == nullptr)
         pIterator = new DocumentIteratorImpl (
             maPosition.mnPageIndex, maPosition.mePageKind, maPosition.meEditMode,
             mpDocument, mpViewShellWeak, mbDirectionIsForward);
@@ -803,10 +732,7 @@ IteratorImplBase* DocumentIteratorImpl::Clone (IteratorImplBase* pObject) const
     return ViewIteratorImpl::Clone (pIterator);
 }
 
-
-
-
-void DocumentIteratorImpl::GotoNextText (void)
+void DocumentIteratorImpl::GotoNextText()
 {
     bool bSetToOnePastLastPage = false;
     bool bViewChanged = false;
@@ -818,25 +744,25 @@ void DocumentIteratorImpl::GotoNextText (void)
         if (maPosition.mnPageIndex >= mnPageCount)
         {
             // Switch to master page.
-            if (maPosition.meEditMode == EM_PAGE)
+            if (maPosition.meEditMode == EditMode::Page)
             {
-                maPosition.meEditMode = EM_MASTERPAGE;
+                maPosition.meEditMode = EditMode::MasterPage;
                 SetPage (0);
             }
 
             // Switch to next view mode.
             else
             {
-                if (maPosition.mePageKind == PK_HANDOUT)
+                if (maPosition.mePageKind == PageKind::Handout)
                     // Not really necessary but makes things more clear.
                     bSetToOnePastLastPage = true;
                 else
                 {
-                    maPosition.meEditMode = EM_PAGE;
-                    if (maPosition.mePageKind == PK_STANDARD)
-                        maPosition.mePageKind = PK_NOTES;
-                    else if (maPosition.mePageKind == PK_NOTES)
-                        maPosition.mePageKind = PK_HANDOUT;
+                    maPosition.meEditMode = EditMode::Page;
+                    if (maPosition.mePageKind == PageKind::Standard)
+                        maPosition.mePageKind = PageKind::Notes;
+                    else if (maPosition.mePageKind == PageKind::Notes)
+                        maPosition.mePageKind = PageKind::Handout;
                     SetPage (0);
                 }
             }
@@ -847,24 +773,24 @@ void DocumentIteratorImpl::GotoNextText (void)
         if (maPosition.mnPageIndex < 0)
         {
             // Switch from master pages to draw pages.
-            if (maPosition.meEditMode == EM_MASTERPAGE)
+            if (maPosition.meEditMode == EditMode::MasterPage)
             {
-                maPosition.meEditMode = EM_PAGE;
+                maPosition.meEditMode = EditMode::Page;
                 bSetToOnePastLastPage = true;
             }
 
             // Switch to previous view mode.
             else
             {
-                if (maPosition.mePageKind == PK_STANDARD)
+                if (maPosition.mePageKind == PageKind::Standard)
                     SetPage (-1);
                 else
                 {
-                    maPosition.meEditMode = EM_MASTERPAGE;
-                    if (maPosition.mePageKind == PK_HANDOUT)
-                        maPosition.mePageKind = PK_NOTES;
-                    else if (maPosition.mePageKind == PK_NOTES)
-                        maPosition.mePageKind = PK_STANDARD;
+                    maPosition.meEditMode = EditMode::MasterPage;
+                    if (maPosition.mePageKind == PageKind::Handout)
+                        maPosition.mePageKind = PageKind::Notes;
+                    else if (maPosition.mePageKind == PageKind::Notes)
+                        maPosition.mePageKind = PageKind::Standard;
                     bSetToOnePastLastPage = true;
                 }
             }
@@ -875,7 +801,7 @@ void DocumentIteratorImpl::GotoNextText (void)
     {
         // Get new page count;
         sal_Int32 nPageCount;
-        if (maPosition.meEditMode == EM_PAGE)
+        if (maPosition.meEditMode == EditMode::Page)
             nPageCount = mpDocument->GetSdPageCount (maPosition.mePageKind);
         else
             nPageCount = mpDocument->GetMasterSdPageCount(maPosition.mePageKind);
@@ -886,7 +812,6 @@ void DocumentIteratorImpl::GotoNextText (void)
     }
 }
 
-
 } } // end of namespace ::sd::outliner
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
