@@ -17,7 +17,8 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "TextObjectBar.hxx"
+#include <memory>
+#include <TextObjectBar.hxx>
 
 #include <svx/svxids.hrc>
 
@@ -50,25 +51,25 @@
 
 #include <sfx2/objface.hxx>
 
-#include "app.hrc"
-#include "glob.hrc"
-#include "res_bmp.hrc"
+#include <app.hrc>
+#include <strings.hrc>
 
-#include "drawdoc.hxx"
-#include "DrawViewShell.hxx"
-#include "OutlineViewShell.hxx"
-#include "ViewShellBase.hxx"
-#include "ToolBarManager.hxx"
-#include "futempl.hxx"
-#include "sdresid.hxx"
-#include "Window.hxx"
-#include "OutlineView.hxx"
+
+#include <drawdoc.hxx>
+#include <DrawViewShell.hxx>
+#include <OutlineViewShell.hxx>
+#include <ViewShellBase.hxx>
+#include <ToolBarManager.hxx>
+#include <futempl.hxx>
+#include <sdresid.hxx>
+#include <Window.hxx>
+#include <OutlineView.hxx>
 
 using namespace sd;
 using namespace ::com::sun::star;
 
 #define TextObjectBar
-#include "sdslots.hxx"
+#include <sdslots.hxx>
 
 namespace sd {
 
@@ -76,14 +77,12 @@ namespace sd {
  * Declare default interface (Slotmap must not be empty, therefore enter
  * something that (hopefully) never occurs.
  */
-
-SFX_IMPL_INTERFACE(TextObjectBar, SfxShell, SdResId(STR_TEXTOBJECTBARSHELL))
+SFX_IMPL_INTERFACE(TextObjectBar, SfxShell)
 
 void TextObjectBar::InitInterface_Impl()
 {
 }
 
-TYPEINIT1( TextObjectBar, SfxShell );
 
 TextObjectBar::TextObjectBar (
     ViewShell* pSdViewSh,
@@ -115,14 +114,14 @@ TextObjectBar::TextObjectBar (
         }
     }
 
-    SetName( OUString( "TextObjectBar" ));
+    SetName( "TextObjectBar");
 
     // SetHelpId( SD_IF_SDDRAWTEXTOBJECTBAR );
 }
 
 TextObjectBar::~TextObjectBar()
 {
-    SetRepeatTarget(NULL);
+    SetRepeatTarget(nullptr);
 }
 
 void TextObjectBar::GetCharState( SfxItemSet& rSet )
@@ -130,16 +129,16 @@ void TextObjectBar::GetCharState( SfxItemSet& rSet )
     SfxItemSet  aCharAttrSet( mpView->GetDoc().GetPool() );
     mpView->GetAttributes( aCharAttrSet );
 
-    SfxItemSet aNewAttr( mpViewShell->GetPool(),EE_ITEMS_START,EE_ITEMS_END);
+    SfxItemSet aNewAttr( mpViewShell->GetPool(),svl::Items<EE_ITEMS_START,EE_ITEMS_END>{});
 
     aNewAttr.Put(aCharAttrSet, false);
     rSet.Put(aNewAttr, false);
 
-    SvxKerningItem aKern = static_cast<const SvxKerningItem&>( aCharAttrSet.Get( EE_CHAR_KERNING ) );
+    SvxKerningItem aKern = aCharAttrSet.Get( EE_CHAR_KERNING );
     //aKern.SetWhich(SID_ATTR_CHAR_KERNING);
     rSet.Put(aKern);
 
-    SfxItemState eState = aCharAttrSet.GetItemState( EE_CHAR_KERNING, true );
+    SfxItemState eState = aCharAttrSet.GetItemState( EE_CHAR_KERNING );
     if ( eState == SfxItemState::DONTCARE )
     {
         rSet.InvalidateItem(EE_CHAR_KERNING);
@@ -172,15 +171,16 @@ void TextObjectBar::GetAttrState( SfxItemSet& rSet )
             case SID_ATTR_CHAR_FONTHEIGHT:
             case SID_ATTR_CHAR_WEIGHT:
             case SID_ATTR_CHAR_POSTURE:
-        case SID_ATTR_CHAR_SHADOWED:
+            case SID_ATTR_CHAR_SHADOWED:
             case SID_ATTR_CHAR_STRIKEOUT:
+            case SID_ATTR_CHAR_CASEMAP:
             {
                 sal_uInt16 stretchX = 100;
                 sal_uInt16 stretchY = 100;
                 SvxScriptSetItem aSetItem( nSlotId, GetPool() );
                 aSetItem.GetItemSet().Put( aAttrSet, false );
 
-                sal_uInt16 nScriptType = mpView->GetScriptType();
+                SvtScriptType nScriptType = mpView->GetScriptType();
 
                 if( (nSlotId == SID_ATTR_CHAR_FONT) || (nSlotId == SID_ATTR_CHAR_FONTHEIGHT) )
                 {
@@ -189,7 +189,7 @@ void TextObjectBar::GetAttrState( SfxItemSet& rSet )
                     OutlinerView* pOLV = mpView->GetTextEditOutlinerView();
                     SdrOutliner *pOutliner = mpView->GetTextEditOutliner();
 
-                    if (mpView->ISA(OutlineView))
+                    if( dynamic_cast< const OutlineView *>( mpView ) !=  nullptr)
                     {
                         pOLV = static_cast<OutlineView*>(mpView)->GetViewByWindow(
                             mpViewShell->GetActiveWindow());
@@ -216,11 +216,13 @@ void TextObjectBar::GetAttrState( SfxItemSet& rSet )
                     {
                         SvxFontHeightItem aFontItem = dynamic_cast<const SvxFontHeightItem&>(*pI);
                         aFontItem.SetHeight(aFontItem.GetHeight(), stretchX, aFontItem.GetPropUnit());
-                        aAttrSet.Put( aFontItem, nWhich );
+                        aFontItem.SetWhich(nWhich);
+                        aAttrSet.Put( aFontItem );
                     }
                     else
                     {
-                        aAttrSet.Put( *pI, nWhich );
+                        std::unique_ptr<SfxPoolItem> pNewItem(pI->CloneSetWhich(nWhich));
+                        aAttrSet.Put( *pNewItem );
                     }
                 }
                 else
@@ -255,39 +257,39 @@ void TextObjectBar::GetAttrState( SfxItemSet& rSet )
 
                 //fdo#78151 it doesn't make sense to promote or demote outline levels in master view.
                 const DrawViewShell* pDrawViewShell = dynamic_cast< DrawViewShell* >(mpViewShell);
-                const bool bInMasterView = pDrawViewShell && pDrawViewShell->GetEditMode() == EM_MASTERPAGE;
+                const bool bInMasterView = pDrawViewShell && pDrawViewShell->GetEditMode() == EditMode::MasterPage;
 
                 if (!bInMasterView)
                 {
                     OutlinerView* pOLV = mpView->GetTextEditOutlinerView();
 
-                    if (mpView->ISA(OutlineView))
+                    if( dynamic_cast< const OutlineView *>( mpView ) !=  nullptr)
                     {
                         pOLV = static_cast<OutlineView*>(mpView)->GetViewByWindow(
                             mpViewShell->GetActiveWindow());
                     }
 
-                    bool bOutlineViewSh = mpViewShell->ISA(OutlineViewShell);
+                    bool bOutlineViewSh = dynamic_cast< const OutlineViewShell *>( mpViewShell ) !=  nullptr;
 
                     if (pOLV &&
-                        ( pOLV->GetOutliner()->GetMode() == OUTLINERMODE_OUTLINEOBJECT || bOutlineViewSh ) )
+                        ( pOLV->GetOutliner()->GetMode() == OutlinerMode::OutlineObject || bOutlineViewSh ) )
                     {
                         // Outliner at outline-mode
                         ::Outliner* pOutl = pOLV->GetOutliner();
 
                         std::vector<Paragraph*> aSelList;
                         pOLV->CreateSelectionList(aSelList);
-                        Paragraph* pPara = aSelList.empty() ? NULL : *(aSelList.begin());
+                        Paragraph* pPara = aSelList.empty() ? nullptr : *(aSelList.begin());
 
                         // find out if we are a OutlineView
-                        bool bIsOutlineView(OUTLINERMODE_OUTLINEVIEW == pOLV->GetOutliner()->GetMode());
+                        bool bIsOutlineView(OutlinerMode::OutlineView == pOLV->GetOutliner()->GetMode());
 
                         // This is ONLY for OutlineViews
                         if(bIsOutlineView)
                         {
                             // allow move up if position is 2 or greater OR it
                             // is a title object (and thus depth==1)
-                            if(pOutl->GetAbsPos(pPara) > 1 || ( pOutl->HasParaFlag(pPara,PARAFLAG_ISPAGE) && pOutl->GetAbsPos(pPara) > 0 ) )
+                            if(pOutl->GetAbsPos(pPara) > 1 || ( ::Outliner::HasParaFlag(pPara,ParaFlag::ISPAGE) && pOutl->GetAbsPos(pPara) > 0 ) )
                             {
                                 // not at top
                                 bDisableUp = false;
@@ -295,7 +297,7 @@ void TextObjectBar::GetAttrState( SfxItemSet& rSet )
                         }
                         else
                         {
-                            // old behaviour for OUTLINERMODE_OUTLINEOBJECT
+                            // old behaviour for OutlinerMode::OutlineObject
                             if(pOutl->GetAbsPos(pPara) > 0)
                             {
                                 // not at top
@@ -309,14 +311,14 @@ void TextObjectBar::GetAttrState( SfxItemSet& rSet )
 
                             sal_Int16 nDepth = pOutl->GetDepth( pOutl->GetAbsPos( pPara ) );
 
-                            if (nDepth > 0 || (bOutlineViewSh && (nDepth <= 0) && !pOutl->HasParaFlag( pPara, PARAFLAG_ISPAGE )) )
+                            if (nDepth > 0 || (bOutlineViewSh && (nDepth <= 0) && !::Outliner::HasParaFlag( pPara, ParaFlag::ISPAGE )) )
                             {
                                 // not minimum depth
                                 bDisableLeft = false;
                             }
 
                             if( (nDepth < pOLV->GetOutliner()->GetMaxDepth() && ( !bOutlineViewSh || pOutl->GetAbsPos(pPara) != 0 )) ||
-                                (bOutlineViewSh && (nDepth <= 0) && pOutl->HasParaFlag( pPara, PARAFLAG_ISPAGE ) && pOutl->GetAbsPos(pPara) != 0) )
+                                (bOutlineViewSh && (nDepth <= 0) && ::Outliner::HasParaFlag( pPara, ParaFlag::ISPAGE ) && pOutl->GetAbsPos(pPara) != 0) )
                             {
                                 // not maximum depth and not at top
                                 bDisableRight = false;
@@ -331,13 +333,13 @@ void TextObjectBar::GetAttrState( SfxItemSet& rSet )
                         }
 
                         // disable when first para and 2nd is not a title
-                        pPara = aSelList.empty() ? NULL : *(aSelList.begin());
+                        pPara = aSelList.empty() ? nullptr : *(aSelList.begin());
 
                         if(!bDisableDown && bIsOutlineView
                             && pPara
                             && 0 == pOutl->GetAbsPos(pPara)
                             && pOutl->GetParagraphCount() > 1
-                            && !pOutl->HasParaFlag( pOutl->GetParagraph(1), PARAFLAG_ISPAGE ) )
+                            && !::Outliner::HasParaFlag( pOutl->GetParagraph(1), ParaFlag::ISPAGE ) )
                         {
                             // Needs to be disabled
                             bDisableDown = true;
@@ -375,7 +377,7 @@ void TextObjectBar::GetAttrState( SfxItemSet& rSet )
                             bLeftToRight = false;
                     }
                     else
-                        bLeftToRight = static_cast<const SvxWritingModeItem&>( aAttrSet.Get( SDRATTR_TEXTDIRECTION ) ).GetValue() == com::sun::star::text::WritingMode_LR_TB;
+                        bLeftToRight = aAttrSet.Get( SDRATTR_TEXTDIRECTION ).GetValue() == css::text::WritingMode_LR_TB;
 
                     rSet.Put( SfxBoolItem( SID_TEXTDIRECTION_LEFT_TO_RIGHT, bLeftToRight ) );
                     rSet.Put( SfxBoolItem( SID_TEXTDIRECTION_TOP_TO_BOTTOM, !bLeftToRight ) );
@@ -413,8 +415,6 @@ void TextObjectBar::GetAttrState( SfxItemSet& rSet )
                 {
                     rSet.DisableItem( SID_THES );
                 }
-                //! avoid putting the same item as SfxBoolItem at the end of this function
-                nSlotId = 0;
             }
             break;
 
@@ -428,7 +428,7 @@ void TextObjectBar::GetAttrState( SfxItemSet& rSet )
     rSet.Put( aAttrSet, false ); // <- sal_False, so DontCare-Status gets acquired
 
     // these are disabled in outline-mode
-    if (!mpViewShell || !mpViewShell->ISA(DrawViewShell))
+    if (!mpViewShell || dynamic_cast< const DrawViewShell *>( mpViewShell ) ==  nullptr)
     {
         rSet.DisableItem( SID_ATTR_PARA_ADJUST_LEFT );
         rSet.DisableItem( SID_ATTR_PARA_ADJUST_RIGHT );
@@ -459,14 +459,14 @@ void TextObjectBar::GetAttrState( SfxItemSet& rSet )
                 nStartPara = 0;
                 nEndPara = pOLV->GetOutliner()->GetParagraphCount() - 1;
             }
-            long nUpper = 0L;
+            long nUpper = 0;
             for( sal_Int32 nPara = nStartPara; nPara <= nEndPara; nPara++ )
             {
                 const SfxItemSet& rItems = pOLV->GetOutliner()->GetParaAttribs( nPara );
-                const SvxULSpaceItem& rItem = static_cast<const SvxULSpaceItem&>( rItems.Get( EE_PARA_ULSPACE ) );
+                const SvxULSpaceItem& rItem = rItems.Get( EE_PARA_ULSPACE );
                 nUpper = std::max( nUpper, (long)rItem.GetUpper() );
             }
-            if( nUpper == 0L )
+            if( nUpper == 0 )
                 rSet.DisableItem( SID_PARASPACE_DECREASE );
         }
         else
@@ -477,21 +477,21 @@ void TextObjectBar::GetAttrState( SfxItemSet& rSet )
         }
 
         // paragraph justification
-        SvxLRSpaceItem aLR = static_cast<const SvxLRSpaceItem&>( aAttrSet.Get( EE_PARA_LRSPACE ) );
+        SvxLRSpaceItem aLR = aAttrSet.Get( EE_PARA_LRSPACE );
         rSet.Put(aLR);
-        SvxAdjust eAdj = static_cast<const SvxAdjustItem&>( aAttrSet.Get( EE_PARA_JUST ) ).GetAdjust();
+        SvxAdjust eAdj = aAttrSet.Get( EE_PARA_JUST ).GetAdjust();
         switch( eAdj )
         {
-            case SVX_ADJUST_LEFT:
+            case SvxAdjust::Left:
                 rSet.Put( SfxBoolItem( SID_ATTR_PARA_ADJUST_LEFT, true ) );
             break;
-            case SVX_ADJUST_CENTER:
+            case SvxAdjust::Center:
                 rSet.Put( SfxBoolItem( SID_ATTR_PARA_ADJUST_CENTER, true ) );
             break;
-            case SVX_ADJUST_RIGHT:
+            case SvxAdjust::Right:
                 rSet.Put( SfxBoolItem( SID_ATTR_PARA_ADJUST_RIGHT, true ) );
             break;
-            case SVX_ADJUST_BLOCK:
+            case SvxAdjust::Block:
                 rSet.Put( SfxBoolItem( SID_ATTR_PARA_ADJUST_BLOCK, true ) );
             break;
             default:
@@ -513,35 +513,35 @@ void TextObjectBar::GetAttrState( SfxItemSet& rSet )
         }
         else
         {
-            switch( static_cast<const SvxFrameDirectionItem&>( aAttrSet.Get( EE_PARA_WRITINGDIR ) ).GetValue() )
+            switch( aAttrSet.Get( EE_PARA_WRITINGDIR ).GetValue() )
             {
-                case FRMDIR_VERT_TOP_LEFT:
-                case FRMDIR_VERT_TOP_RIGHT:
+                case SvxFrameDirection::Vertical_LR_TB:
+                case SvxFrameDirection::Vertical_RL_TB:
                 {
                     rSet.DisableItem( SID_ATTR_PARA_LEFT_TO_RIGHT );
                     rSet.DisableItem( SID_ATTR_PARA_RIGHT_TO_LEFT );
                 }
                 break;
 
-                case FRMDIR_HORI_LEFT_TOP:
+                case SvxFrameDirection::Horizontal_LR_TB:
                     rSet.Put( SfxBoolItem( SID_ATTR_PARA_LEFT_TO_RIGHT, true ) );
                     rSet.Put( SfxBoolItem( SID_ATTR_PARA_RIGHT_TO_LEFT, false ) );
                 break;
 
-                case FRMDIR_HORI_RIGHT_TOP:
+                case SvxFrameDirection::Horizontal_RL_TB:
                     rSet.Put( SfxBoolItem( SID_ATTR_PARA_LEFT_TO_RIGHT, false ) );
                     rSet.Put( SfxBoolItem( SID_ATTR_PARA_RIGHT_TO_LEFT, true ) );
                 break;
 
                 // The case for the superordinate object is missing.
-                case FRMDIR_ENVIRONMENT:
+                case SvxFrameDirection::Environment:
                 {
                     SdDrawDocument& rDoc = mpView->GetDoc();
-                    ::com::sun::star::text::WritingMode eMode = rDoc.GetDefaultWritingMode();
+                    css::text::WritingMode eMode = rDoc.GetDefaultWritingMode();
                     bool bIsLeftToRight(false);
 
-                    if(::com::sun::star::text::WritingMode_LR_TB == eMode
-                        || ::com::sun::star::text::WritingMode_TB_RL == eMode)
+                    if(css::text::WritingMode_LR_TB == eMode
+                        || css::text::WritingMode_TB_RL == eMode)
                     {
                         bIsLeftToRight = true;
                     }
@@ -550,10 +550,11 @@ void TextObjectBar::GetAttrState( SfxItemSet& rSet )
                     rSet.Put( SfxBoolItem( SID_ATTR_PARA_RIGHT_TO_LEFT, !bIsLeftToRight ) );
                 }
                 break;
+                default: break;
             }
         }
 
-        SvxLRSpaceItem aLRSpace = static_cast<const SvxLRSpaceItem&>( aAttrSet.Get( EE_PARA_LRSPACE ) );
+        SvxLRSpaceItem aLRSpace = aAttrSet.Get( EE_PARA_LRSPACE );
         aLRSpace.SetWhich(SID_ATTR_PARA_LRSPACE);
         rSet.Put(aLRSpace);
         Invalidate(SID_ATTR_PARA_LRSPACE);
@@ -564,8 +565,7 @@ void TextObjectBar::GetAttrState( SfxItemSet& rSet )
             rSet.InvalidateItem(EE_PARA_LRSPACE);
             rSet.InvalidateItem(SID_ATTR_PARA_LRSPACE);
         }
-        sal_uInt16 nLineSpace = (sal_uInt16) static_cast<const SvxLineSpacingItem&>( aAttrSet.
-                            Get( EE_PARA_SBL ) ).GetPropLineSpace();
+        sal_uInt16 nLineSpace = aAttrSet.Get( EE_PARA_SBL ).GetPropLineSpace();
         switch( nLineSpace )
         {
             case 100:
@@ -581,23 +581,14 @@ void TextObjectBar::GetAttrState( SfxItemSet& rSet )
     }
 
     // justification (superscript, subscript) is also needed in outline-mode
-    SvxEscapement eEsc = (SvxEscapement ) static_cast<const SvxEscapementItem&>(
-                    aAttrSet.Get( EE_CHAR_ESCAPEMENT ) ).GetEnumValue();
+    SvxEscapement eEsc = (SvxEscapement ) aAttrSet.Get( EE_CHAR_ESCAPEMENT ).GetEnumValue();
 
-    if( eEsc == SVX_ESCAPEMENT_SUPERSCRIPT )
+    if( eEsc == SvxEscapement::Superscript )
         rSet.Put( SfxBoolItem( SID_SET_SUPER_SCRIPT, true ) );
-    else if( eEsc == SVX_ESCAPEMENT_SUBSCRIPT )
+    else if( eEsc == SvxEscapement::Subscript )
         rSet.Put( SfxBoolItem( SID_SET_SUB_SCRIPT, true ) );
 }
 
-/**
- * Command event
- */
-
-void TextObjectBar::Command( const CommandEvent& )
-{
-}
-
 } // end of namespace sd
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
