@@ -17,7 +17,7 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "DrawViewShell.hxx"
+#include <DrawViewShell.hxx>
 #include <com/sun/star/scanner/ScannerManager.hpp>
 #include <cppuhelper/implbase.hxx>
 #include <comphelper/processfactory.hxx>
@@ -45,28 +45,28 @@
 #include <svx/float3d.hxx>
 #include <svx/extedit.hxx>
 #include <svx/sidebar/SelectionAnalyzer.hxx>
-#include "helpids.h"
+#include <helpids.h>
 
-#include "view/viewoverlaymanager.hxx"
-#include "app.hrc"
-#include "strings.hrc"
-#include "res_bmp.hrc"
-#include "sdpage.hxx"
-#include "FrameView.hxx"
-#include "drawdoc.hxx"
-#include "sdresid.hxx"
-#include "DrawDocShell.hxx"
-#include "Window.hxx"
-#include "fupoor.hxx"
-#include "fusel.hxx"
-#include "funavig.hxx"
-#include "drawview.hxx"
-#include "SdUnoDrawView.hxx"
-#include "ViewShellBase.hxx"
-#include "slideshow.hxx"
-#include "ToolBarManager.hxx"
-#include "annotationmanager.hxx"
-#include "DrawController.hxx"
+#include <view/viewoverlaymanager.hxx>
+#include <app.hrc>
+#include <strings.hrc>
+
+#include <sdpage.hxx>
+#include <FrameView.hxx>
+#include <drawdoc.hxx>
+#include <sdresid.hxx>
+#include <DrawDocShell.hxx>
+#include <Window.hxx>
+#include <fupoor.hxx>
+#include <fusel.hxx>
+#include <funavig.hxx>
+#include <drawview.hxx>
+#include <SdUnoDrawView.hxx>
+#include <ViewShellBase.hxx>
+#include <slideshow.hxx>
+#include <ToolBarManager.hxx>
+#include <annotationmanager.hxx>
+#include <DrawController.hxx>
 
 #include <memory>
 
@@ -88,33 +88,28 @@ private:
 public:
 
                             explicit ScannerEventListener( DrawViewShell* pParent ) : mpParent( pParent )  {}
-                            virtual ~ScannerEventListener() override;
 
     // XEventListener
-    virtual void SAL_CALL   disposing( const lang::EventObject& rEventObject ) throw (uno::RuntimeException, std::exception) override;
+    virtual void SAL_CALL   disposing( const lang::EventObject& rEventObject ) override;
 
     void                    ParentDestroyed() { mpParent = nullptr; }
 };
 
-ScannerEventListener::~ScannerEventListener()
-{
-}
-
-void SAL_CALL ScannerEventListener::disposing( const lang::EventObject& rEventObject ) throw (uno::RuntimeException, std::exception)
+void SAL_CALL ScannerEventListener::disposing( const lang::EventObject& /*rEventObject*/ )
 {
     if( mpParent )
-        mpParent->ScannerEvent( rEventObject );
+        mpParent->ScannerEvent();
 }
 
-DrawViewShell::DrawViewShell( SfxViewFrame* pFrame, ViewShellBase& rViewShellBase, vcl::Window* pParentWindow, PageKind ePageKind, FrameView* pFrameViewArgument )
-    : ViewShell (pFrame, pParentWindow, rViewShellBase)
+DrawViewShell::DrawViewShell( ViewShellBase& rViewShellBase, vcl::Window* pParentWindow, PageKind ePageKind, FrameView* pFrameViewArgument )
+    : ViewShell (pParentWindow, rViewShellBase)
     , maTabControl(VclPtr<sd::TabControl>::Create(this, pParentWindow))
     , mbIsLayerModeActive(false)
     , mbIsInSwitchPage(false)
     , mpSelectionChangeHandler(new svx::sidebar::SelectionChangeHandler(
           [this] () { return this->GetSidebarContextName(); },
           uno::Reference<frame::XController>(&rViewShellBase.GetDrawController()),
-          vcl::EnumContext::Context_Default))
+          vcl::EnumContext::Context::Default))
 {
     if (pFrameViewArgument != nullptr)
         mpFrameView = pFrameViewArgument;
@@ -161,7 +156,7 @@ DrawViewShell::~DrawViewShell()
     EndListening (*GetDocSh());
 
     if( SlideShow::IsRunning(*this) )
-        StopSlideShow(false);
+        StopSlideShow();
 
     DisposeFunctions();
 
@@ -254,7 +249,7 @@ void DrawViewShell::Construct(DrawDocShell* pDocSh, PageKind eInitialPageKind)
         aVisAreaPos = pDocSh->GetVisArea(ASPECT_CONTENT).TopLeft();
     }
 
-    mpDrawView->SetWorkArea(Rectangle(Point() - aVisAreaPos - aPageOrg, aSize));
+    mpDrawView->SetWorkArea(::tools::Rectangle(Point() - aVisAreaPos - aPageOrg, aSize));
 
     // objects can not grow bigger than ViewSize
     GetDoc()->SetMaxObjSize(aSize);
@@ -278,14 +273,12 @@ void DrawViewShell::Construct(DrawDocShell* pDocSh, PageKind eInitialPageKind)
 
     if( eDocType == DocumentType::Draw )
     {
-        SetHelpId( SD_IF_SDGRAPHICVIEWSHELL );
         GetActiveWindow()->SetHelpId( HID_SDGRAPHICVIEWSHELL );
     }
     else
     {
         if (mePageKind == PageKind::Notes)
         {
-            SetHelpId( SID_NOTES_MODE );
             GetActiveWindow()->SetHelpId( CMD_SID_NOTES_MODE );
 
             // AutoLayouts have to be created
@@ -293,7 +286,6 @@ void DrawViewShell::Construct(DrawDocShell* pDocSh, PageKind eInitialPageKind)
         }
         else if (mePageKind == PageKind::Handout)
         {
-            SetHelpId( SID_HANDOUT_MASTER_MODE );
             GetActiveWindow()->SetHelpId( CMD_SID_HANDOUT_MASTER_MODE );
 
             // AutoLayouts have to be created
@@ -301,7 +293,6 @@ void DrawViewShell::Construct(DrawDocShell* pDocSh, PageKind eInitialPageKind)
         }
         else
         {
-            SetHelpId( SD_IF_SDDRAWVIEWSHELL );
             GetActiveWindow()->SetHelpId( HID_SDDRAWVIEWSHELL );
         }
     }
@@ -322,10 +313,9 @@ void DrawViewShell::Construct(DrawDocShell* pDocSh, PageKind eInitialPageKind)
 
     mbIsRulerDrag = false;
 
-    OUString aName( "DrawViewShell" );
-    SetName (aName);
+    SetName ("DrawViewShell");
 
-    mnLockCount = 0UL;
+    mnLockCount = 0;
 
     uno::Reference< uno::XComponentContext > xContext( ::comphelper::getProcessComponentContext() );
 
@@ -340,7 +330,7 @@ void DrawViewShell::Construct(DrawDocShell* pDocSh, PageKind eInitialPageKind)
     {
         // Eat the exception and log it
         // We can still continue if scanner manager is not available.
-        SAL_WARN("sd", "Scanner manager exception: " << exception.Message);
+        SAL_WARN("sd", "Scanner manager exception: " << exception);
     }
 
     mpAnnotationManager.reset( new AnnotationManager( GetViewShellBase() ) );
@@ -351,7 +341,8 @@ void DrawViewShell::Init (bool bIsMainViewShell)
 {
     ViewShell::Init(bIsMainViewShell);
 
-    StartListening (*GetDocSh());
+    if (!IsListening(*GetDocSh()))
+        StartListening (*GetDocSh());
 }
 
 void DrawViewShell::Shutdown()
@@ -391,7 +382,7 @@ bool DrawViewShell::RelocateToParentWindow (vcl::Window* pParentWindow)
  */
 
 /*
-    Polylines are represented by makros as a sequence of:
+    Polylines are represented by macros as a sequence of:
         MoveTo (x, y)
         LineTo (x, y)   [or BezierTo (x, y)]
         LineTo (x, y)
@@ -404,7 +395,6 @@ bool DrawViewShell::RelocateToParentWindow (vcl::Window* pParentWindow)
 
 void DrawViewShell::CheckLineTo(SfxRequest& rReq)
 {
-    (void)rReq;
 #ifdef DBG_UTIL
     if(rReq.IsAPI())
     {
@@ -421,7 +411,7 @@ void DrawViewShell::CheckLineTo(SfxRequest& rReq)
 /**
  * Change page parameter if SID_PAGESIZE or SID_PAGEMARGIN
  */
-void DrawViewShell::SetupPage (Size &rSize,
+void DrawViewShell::SetupPage (Size const &rSize,
                                  long nLeft,
                                  long nRight,
                                  long nUpper,
@@ -442,17 +432,17 @@ void DrawViewShell::SetupPage (Size &rSize,
         {
             if( bSize )
             {
-                Rectangle aBorderRect(nLeft, nUpper, nRight, nLower);
+                ::tools::Rectangle aBorderRect(nLeft, nUpper, nRight, nLower);
                 pPage->ScaleObjects(rSize, aBorderRect, bScaleAll);
                 pPage->SetSize(rSize);
 
             }
             if( bMargin )
             {
-                pPage->SetLftBorder(nLeft);
-                pPage->SetRgtBorder(nRight);
-                pPage->SetUppBorder(nUpper);
-                pPage->SetLwrBorder(nLower);
+                pPage->SetLeftBorder(nLeft);
+                pPage->SetRightBorder(nRight);
+                pPage->SetUpperBorder(nUpper);
+                pPage->SetLowerBorder(nLower);
             }
 
             if ( mePageKind == PageKind::Standard )
@@ -475,16 +465,16 @@ void DrawViewShell::SetupPage (Size &rSize,
         {
             if( bSize )
             {
-                Rectangle aBorderRect(nLeft, nUpper, nRight, nLower);
+                ::tools::Rectangle aBorderRect(nLeft, nUpper, nRight, nLower);
                 pPage->ScaleObjects(rSize, aBorderRect, bScaleAll);
                 pPage->SetSize(rSize);
             }
             if( bMargin )
             {
-                pPage->SetLftBorder(nLeft);
-                pPage->SetRgtBorder(nRight);
-                pPage->SetUppBorder(nUpper);
-                pPage->SetLwrBorder(nLower);
+                pPage->SetLeftBorder(nLeft);
+                pPage->SetRightBorder(nRight);
+                pPage->SetUpperBorder(nUpper);
+                pPage->SetLowerBorder(nLower);
             }
 
             if ( mePageKind == PageKind::Standard )
@@ -518,11 +508,11 @@ void DrawViewShell::SetupPage (Size &rSize,
         aVisAreaPos = GetDocSh()->GetVisArea(ASPECT_CONTENT).TopLeft();
     }
 
-    GetView()->SetWorkArea(Rectangle(Point() - aVisAreaPos - aPageOrg, aSize));
+    GetView()->SetWorkArea(::tools::Rectangle(Point() - aVisAreaPos - aPageOrg, aSize));
 
     UpdateScrollBars();
 
-    Point aNewOrigin(mpActualPage->GetLftBorder(), mpActualPage->GetUppBorder());
+    Point aNewOrigin(mpActualPage->GetLeftBorder(), mpActualPage->GetUpperBorder());
     GetView()->GetSdrPageView()->SetPageOrigin(aNewOrigin);
 
     GetViewFrame()->GetBindings().Invalidate(SID_RULER_NULL_OFFSET);
@@ -557,8 +547,7 @@ void DrawViewShell::GetStatusBarState(SfxItemSet& rSet)
             SvxZoomEnableFlags nZoomValues = SvxZoomEnableFlags::ALL;
             SdrPageView* pPageView = mpDrawView->GetSdrPageView();
 
-            if( ( pPageView && pPageView->GetObjList()->GetObjCount() == 0 ) )
-                // || ( mpDrawView->GetMarkedObjectList().GetMarkCount() == 0 ) )
+            if( pPageView && pPageView->GetObjList()->GetObjCount() == 0 )
             {
                 nZoomValues &= ~SvxZoomEnableFlags::OPTIMAL;
             }
@@ -594,7 +583,7 @@ void DrawViewShell::GetStatusBarState(SfxItemSet& rSet)
 
                 aPagePos.X() -= aPageSize.Width()  / 2;
 
-                Rectangle aFullPageZoomRect( aPagePos, aPageSize );
+                ::tools::Rectangle aFullPageZoomRect( aPagePos, aPageSize );
                 aZoomItem.AddSnappingPoint( pActiveWindow->GetZoomForRect( aFullPageZoomRect ) );
             }
             aZoomItem.AddSnappingPoint(100);
@@ -608,13 +597,13 @@ void DrawViewShell::GetStatusBarState(SfxItemSet& rSet)
         Point aPos = GetActiveWindow()->PixelToLogic(maMousePos);
         pPageView->LogicToPagePos(aPos);
         Fraction aUIScale(GetDoc()->GetUIScale());
-        aPos.X() = Fraction(aPos.X()) / aUIScale;
-        aPos.Y() = Fraction(aPos.Y()) / aUIScale;
+        aPos.X() = long(aPos.X() / aUIScale);
+        aPos.Y() = long(aPos.Y() / aUIScale);
 
         // position- and size items
         if ( mpDrawView->IsAction() )
         {
-            Rectangle aRect;
+            ::tools::Rectangle aRect;
             mpDrawView->TakeActionRect( aRect );
 
             if ( aRect.IsEmpty() )
@@ -623,12 +612,12 @@ void DrawViewShell::GetStatusBarState(SfxItemSet& rSet)
             {
                 pPageView->LogicToPagePos(aRect);
                 aPos = aRect.TopLeft();
-                aPos.X() = Fraction(aPos.X()) / aUIScale;
-                aPos.Y() = Fraction(aPos.Y()) / aUIScale;
+                aPos.X() = long(aPos.X() / aUIScale);
+                aPos.Y() = long(aPos.Y() / aUIScale);
                 rSet.Put( SfxPointItem( SID_ATTR_POSITION, aPos) );
                 Size aSize( aRect.Right() - aRect.Left(), aRect.Bottom() - aRect.Top() );
-                aSize.Height() = Fraction(aSize.Height()) / aUIScale;
-                aSize.Width()  = Fraction(aSize.Width())  / aUIScale;
+                aSize.Height() = long(aSize.Height() / aUIScale);
+                aSize.Width()  = long(aSize.Width()  / aUIScale);
                 rSet.Put( SvxSizeItem( SID_ATTR_SIZE, aSize) );
             }
         }
@@ -636,18 +625,18 @@ void DrawViewShell::GetStatusBarState(SfxItemSet& rSet)
         {
             if ( mpDrawView->AreObjectsMarked() )
             {
-                Rectangle aRect = mpDrawView->GetAllMarkedRect();
+                ::tools::Rectangle aRect = mpDrawView->GetAllMarkedRect();
                 pPageView->LogicToPagePos(aRect);
 
                 // Show the position of the selected shape(s)
                 Point aShapePosition (aRect.TopLeft());
-                aShapePosition.X() = Fraction(aShapePosition.X()) / aUIScale;
-                aShapePosition.Y() = Fraction(aShapePosition.Y()) / aUIScale;
+                aShapePosition.X() = long(aShapePosition.X() / aUIScale);
+                aShapePosition.Y() = long(aShapePosition.Y() / aUIScale);
                 rSet.Put (SfxPointItem(SID_ATTR_POSITION, aShapePosition));
 
                 Size aSize( aRect.Right() - aRect.Left(), aRect.Bottom() - aRect.Top() );
-                aSize.Height() = Fraction(aSize.Height()) / aUIScale;
-                aSize.Width()  = Fraction(aSize.Width())  / aUIScale;
+                aSize.Height() = long(aSize.Height() / aUIScale);
+                aSize.Width()  = long(aSize.Width()  / aUIScale);
                 rSet.Put( SvxSizeItem( SID_ATTR_SIZE, aSize) );
             }
             else
@@ -664,9 +653,9 @@ void DrawViewShell::GetStatusBarState(SfxItemSet& rSet)
         sal_Int32 nPageCount = sal_Int32(GetDoc()->GetSdPageCount(mePageKind));
         sal_Int32 nActivePageCount = sal_Int32(GetDoc()->GetActiveSdPageCount());
         // Always show the slide/page number.
-        OUString aOUString = (nPageCount == nActivePageCount) ? SD_RESSTR(STR_SD_PAGE_COUNT) : SD_RESSTR(STR_SD_PAGE_COUNT_CUSTOM);
+        OUString aOUString = (nPageCount == nActivePageCount) ? SdResId(STR_SD_PAGE_COUNT) : SdResId(STR_SD_PAGE_COUNT_CUSTOM);
 
-        aOUString = aOUString.replaceFirst("%1", OUString::number(maTabControl->GetCurPageId()));
+        aOUString = aOUString.replaceFirst("%1", OUString::number(maTabControl->GetCurPagePos() + 1));
         aOUString = aOUString.replaceFirst("%2", OUString::number(nPageCount));
         if(nPageCount != nActivePageCount)
             aOUString = aOUString.replaceFirst("%3", OUString::number(nActivePageCount));
@@ -677,7 +666,7 @@ void DrawViewShell::GetStatusBarState(SfxItemSet& rSet)
         if (IsLayerModeActive())
         {
             SdrLayerAdmin& rLayerAdmin = GetDoc()->GetLayerAdmin();
-            SdrLayerID nLayer = 0, nOldLayer = 0;
+            SdrLayerID nLayer(0), nOldLayer(0);
             SdrObject* pObj = nullptr;
             const SdrMarkList& rMarkList = mpDrawView->GetMarkedObjectList();
             const size_t nMarkCount = rMarkList.GetMarkCount();
@@ -728,7 +717,7 @@ void DrawViewShell::GetStatusBarState(SfxItemSet& rSet)
 
 void DrawViewShell::Notify (SfxBroadcaster&, const SfxHint& rHint)
 {
-    if (rHint.GetId()==SFX_HINT_MODECHANGED)
+    if (rHint.GetId()==SfxHintId::ModeChanged)
     {
         // Change to selection when turning on read-only mode.
         if(GetDocSh()->IsReadOnly() && dynamic_cast< FuSelection* >( GetCurrentFunction().get() ) )
@@ -750,7 +739,7 @@ void DrawViewShell::Notify (SfxBroadcaster&, const SfxHint& rHint)
 
 }
 
-void DrawViewShell::ExecuteAnnotation (SfxRequest& rRequest)
+void DrawViewShell::ExecuteAnnotation (SfxRequest const & rRequest)
 {
     if( mpAnnotationManager.get() )
         mpAnnotationManager->ExecuteAnnotation( rRequest );
