@@ -39,51 +39,50 @@
 #include <unotools/useroptions.hxx>
 #include <tools/diagnose_ex.h>
 
-#include "app.hrc"
-#include "strings.hrc"
-#include "res_bmp.hrc"
-#include "glob.hrc"
-#include "Outliner.hxx"
-#include "Window.hxx"
-#include "sdmod.hxx"
-#include "sdattr.hxx"
-#include "drawdoc.hxx"
-#include "DrawDocShell.hxx"
-#include "sdresid.hxx"
-#include "sdpage.hxx"
-#include "DrawViewShell.hxx"
-#include "drawview.hxx"
-#include "unmodpg.hxx"
-#include "undolayer.hxx"
-#include "ViewShellBase.hxx"
-#include "FormShellManager.hxx"
-#include "LayerTabBar.hxx"
-#include "sdabstdlg.hxx"
-#include "SlideSorterViewShell.hxx"
-#include "SlideSorter.hxx"
-#include "controller/SlideSorterController.hxx"
+#include <app.hrc>
+#include <strings.hrc>
+
+#include <Outliner.hxx>
+#include <Window.hxx>
+#include <sdmod.hxx>
+#include <sdattr.hxx>
+#include <drawdoc.hxx>
+#include <DrawDocShell.hxx>
+#include <sdresid.hxx>
+#include <sdpage.hxx>
+#include <DrawViewShell.hxx>
+#include <drawview.hxx>
+#include <unmodpg.hxx>
+#include <undolayer.hxx>
+#include <ViewShellBase.hxx>
+#include <FormShellManager.hxx>
+#include <LayerTabBar.hxx>
+#include <sdabstdlg.hxx>
+#include <SlideSorterViewShell.hxx>
+#include <SlideSorter.hxx>
+#include <controller/SlideSorterController.hxx>
 
 namespace sd {
 
 bool DrawViewShell::RenameSlide( sal_uInt16 nPageId, const OUString & rName  )
 {
-    sal_Bool   bOutDummy;
+    bool   bOutDummy;
     if( GetDoc()->GetPageByName( rName, bOutDummy ) != SDRPAGE_NOTFOUND )
         return false;
 
-    SdPage* pPageToRename = NULL;
+    SdPage* pPageToRename = nullptr;
     PageKind ePageKind = GetPageKind();
 
-    if( GetEditMode() == EM_PAGE )
+    if( GetEditMode() == EditMode::Page )
     {
-        pPageToRename = GetDoc()->GetSdPage( nPageId - 1, ePageKind );
+        pPageToRename = GetDoc()->GetSdPage( maTabControl->GetPagePos(nPageId), ePageKind );
 
         // Undo
         SdPage* pUndoPage = pPageToRename;
         SdrLayerAdmin &  rLayerAdmin = GetDoc()->GetLayerAdmin();
-        sal_uInt8 nBackground = rLayerAdmin.GetLayerID( SD_RESSTR(STR_LAYER_BCKGRND), sal_False );
-        sal_uInt8 nBgObj = rLayerAdmin.GetLayerID( SD_RESSTR(STR_LAYER_BCKGRNDOBJ), sal_False );
-        SetOfByte aVisibleLayers = mpActualPage->TRG_GetMasterPageVisibleLayers();
+        SdrLayerID nBackground = rLayerAdmin.GetLayerID( SdResId(STR_LAYER_BCKGRND) );
+        SdrLayerID nBgObj = rLayerAdmin.GetLayerID( SdResId(STR_LAYER_BCKGRNDOBJ) );
+        SdrLayerIDSet aVisibleLayers = mpActualPage->TRG_GetMasterPageVisibleLayers();
 
         ::svl::IUndoManager* pManager = GetDoc()->GetDocSh()->GetUndoManager();
         ModifyPageUndoAction* pAction = new ModifyPageUndoAction(
@@ -95,17 +94,17 @@ bool DrawViewShell::RenameSlide( sal_uInt16 nPageId, const OUString & rName  )
         // rename
         pPageToRename->SetName( rName );
 
-        if( ePageKind == PK_STANDARD )
+        if( ePageKind == PageKind::Standard )
         {
             // also rename notes-page
-            SdPage* pNotesPage = GetDoc()->GetSdPage( nPageId - 1, PK_NOTES );
+            SdPage* pNotesPage = GetDoc()->GetSdPage( maTabControl->GetPagePos(nPageId), PageKind::Notes );
             pNotesPage->SetName( rName );
         }
     }
     else
     {
         // rename MasterPage -> rename LayoutTemplate
-        pPageToRename = GetDoc()->GetMasterSdPage( nPageId - 1, ePageKind );
+        pPageToRename = GetDoc()->GetMasterSdPage( maTabControl->GetPagePos(nPageId), ePageKind );
         GetDoc()->RenameLayoutTemplate( pPageToRename->GetLayoutName(), rName );
     }
 
@@ -114,49 +113,40 @@ bool DrawViewShell::RenameSlide( sal_uInt16 nPageId, const OUString & rName  )
     if( bSuccess )
     {
         // user edited page names may be changed by the page so update control
-        maTabControl.SetPageText( nPageId, rName );
+        maTabControl->SetPageText( nPageId, rName );
 
         // set document to modified state
-        GetDoc()->SetChanged( sal_True );
+        GetDoc()->SetChanged();
 
         // inform navigator about change
-        SfxBoolItem aItem( SID_NAVIGATOR_INIT, sal_True );
-        GetViewFrame()->GetDispatcher()->Execute(
-            SID_NAVIGATOR_INIT, SFX_CALLMODE_ASYNCHRON | SFX_CALLMODE_RECORD, &aItem, 0L );
+        SfxBoolItem aItem( SID_NAVIGATOR_INIT, true );
+        GetViewFrame()->GetDispatcher()->ExecuteList(SID_NAVIGATOR_INIT,
+                SfxCallMode::ASYNCHRON | SfxCallMode::RECORD, { &aItem });
 
         // Tell the slide sorter about the name change (necessary for
         // accessibility.)
         slidesorter::SlideSorterViewShell* pSlideSorterViewShell
             = slidesorter::SlideSorterViewShell::GetSlideSorter(GetViewShellBase());
-        if (pSlideSorterViewShell != NULL)
+        if (pSlideSorterViewShell != nullptr)
         {
             pSlideSorterViewShell->GetSlideSorter().GetController().PageNameHasChanged(
-                nPageId-1, rName);
+                maTabControl->GetPagePos(nPageId), rName);
         }
     }
 
     return bSuccess;
 }
 
-
-
-
-IMPL_LINK( DrawViewShell, RenameSlideHdl, AbstractSvxNameDialog*, pDialog )
+IMPL_LINK( DrawViewShell, RenameSlideHdl, AbstractSvxNameDialog&, rDialog, bool )
 {
-    if( ! pDialog )
-        return 0;
-
     OUString aNewName;
-    pDialog->GetName( aNewName );
+    rDialog.GetName( aNewName );
 
-    SdPage* pCurrentPage = GetDoc()->GetSdPage( maTabControl.GetCurPageId() - 1, GetPageKind() );
+    SdPage* pCurrentPage = GetDoc()->GetSdPage( maTabControl->GetCurPagePos(), GetPageKind() );
 
     return pCurrentPage && ( aNewName == pCurrentPage->GetName() || GetDocSh()->IsNewPageNameValid( aNewName ) );
 }
 
-
-
-
 void DrawViewShell::ModifyLayer (
     SdrLayer* pLayer,
     const OUString& rLayerName,
@@ -180,7 +170,7 @@ void DrawViewShell::ModifyLayer (
         for( nPos = 0; nPos < nPageCount; nPos++ )
         {
             sal_uInt16 nId = GetLayerTabControl()->GetPageId( nPos );
-            if (GetLayerTabControl()->GetPageText(nId).equals(pLayer->GetName()))
+            if (GetLayerTabControl()->GetPageText(nId) == pLayer->GetName())
             {
                 nCurPage = nId;
                 break;
@@ -194,27 +184,38 @@ void DrawViewShell::ModifyLayer (
         mpDrawView->SetLayerLocked( rLayerName, bIsLocked);
         mpDrawView->SetLayerPrintable(rLayerName, bIsPrintable);
 
-        GetDoc()->SetChanged(sal_True);
+        GetDoc()->SetChanged();
 
         GetLayerTabControl()->SetPageText(nCurPage, rLayerName);
 
-        TabBarPageBits nBits = 0;
+        // Set page bits for modified tab name display
+
+        TabBarPageBits nBits = TabBarPageBits::NONE;
 
         if (!bIsVisible)
         {
-            // invisible layers are presented different
-            nBits = TPB_SPECIAL;
+            nBits = TabBarPageBits::Blue;
         }
+        if (bIsLocked)
+        {
+            nBits |= TabBarPageBits::Italic;
+        }
+        if (!bIsPrintable)
+        {
+            nBits |= TabBarPageBits::Underline;
+        }
+
+        // Save the bits
 
         GetLayerTabControl()->SetPageBits(nCurPage, nBits);
 
         GetViewFrame()->GetDispatcher()->Execute(
             SID_SWITCHLAYER,
-            SFX_CALLMODE_ASYNCHRON | SFX_CALLMODE_RECORD);
+            SfxCallMode::ASYNCHRON | SfxCallMode::RECORD);
 
         // Call Invalidate at the form shell.
         FmFormShell* pFormShell = GetViewShellBase().GetFormShellManager()->GetFormShell();
-        if (pFormShell != NULL)
+        if (pFormShell != nullptr)
             pFormShell->Invalidate();
     }
 }
