@@ -20,7 +20,7 @@
 #include <com/sun/star/embed/NoVisualAreaSizeException.hpp>
 #include <com/sun/star/linguistic2/XSpellChecker1.hpp>
 
-#include "View.hxx"
+#include <View.hxx>
 #include <editeng/unolingu.hxx>
 #include <sfx2/request.hxx>
 #include <svx/obj3d.hxx>
@@ -46,7 +46,7 @@
 
 #include <svx/dialogs.hrc>
 #include <sfx2/viewfrm.hxx>
-#include <sfx2/sidebar/EnumContext.hxx>
+#include <vcl/EnumContext.hxx>
 #include <svx/svdopage.hxx>
 #include <toolkit/helper/vclunohelper.hxx>
 #include <svx/xlndsit.hxx>
@@ -55,30 +55,29 @@
 #include <svx/sidebar/ContextChangeEventMultiplexer.hxx>
 #include <vcl/virdev.hxx>
 
-#include "app.hrc"
-#include "strings.hrc"
-#include "Window.hxx"
-#include "Client.hxx"
-#include "drawdoc.hxx"
-#include "DrawDocShell.hxx"
-#include "sdmod.hxx"
-#include "sdpage.hxx"
-#include "glob.hrc"
-#include "sdresid.hxx"
-#include "DrawViewShell.hxx"
-#include "futext.hxx"
-#include "fuinsfil.hxx"
-#include "slideshow.hxx"
-#include "stlpool.hxx"
-#include "FrameView.hxx"
-#include "ViewClipboard.hxx"
-#include "undo/undomanager.hxx"
+#include <app.hrc>
+#include <strings.hrc>
+#include <Window.hxx>
+#include <Client.hxx>
+#include <drawdoc.hxx>
+#include <DrawDocShell.hxx>
+#include <sdmod.hxx>
+#include <sdpage.hxx>
+#include <sdresid.hxx>
+#include <DrawViewShell.hxx>
+#include <futext.hxx>
+#include <fuinsfil.hxx>
+#include <slideshow.hxx>
+#include <stlpool.hxx>
+#include <FrameView.hxx>
+#include <ViewClipboard.hxx>
+#include <undo/undomanager.hxx>
 #include <svx/sdr/contact/viewobjectcontact.hxx>
 #include <svx/sdr/contact/viewcontact.hxx>
 #include <svx/svdotable.hxx>
-#include "EventMultiplexer.hxx"
-#include "ViewShellBase.hxx"
-#include "ViewShellManager.hxx"
+#include <EventMultiplexer.hxx>
+#include <ViewShellBase.hxx>
+#include <ViewShellManager.hxx>
 
 #include <basegfx/polygon/b2dpolygontools.hxx>
 #include <basegfx/color/bcolor.hxx>
@@ -91,7 +90,12 @@
 #include <drawinglayer/primitive2d/textprimitive2d.hxx>
 #include <svx/unoapi.hxx>
 #include <basegfx/matrix/b2dhommatrixtools.hxx>
-#include "DrawController.hxx"
+#include <comphelper/lok.hxx>
+#include <sfx2/lokhelper.hxx>
+#include <LibreOfficeKit/LibreOfficeKitEnums.h>
+#include <svl/itemiter.hxx>
+#include <editeng/editeng.hxx>
+#include <DrawController.hxx>
 
 #include <memory>
 #include <numeric>
@@ -113,6 +117,8 @@ View::View(SdDrawDocument& rDrawDoc, OutputDevice* pOutDev,
     mpDropMarker(nullptr),
     mnDragSrcPgNum(SDRPAGE_NOTFOUND),
     mnAction(DND_ACTION_NONE),
+    maDropErrorIdle("sd View DropError"),
+    maDropInsertFileIdle("sd View DropInsertFile"),
     mnLockRedrawSmph(0),
     mbIsDropAllowed(true),
     maSmartTags(*this),
@@ -126,21 +132,16 @@ View::View(SdDrawDocument& rDrawDoc, OutputDevice* pOutDev,
 
     EnableExtendedKeyInputDispatcher(false);
     EnableExtendedMouseEventDispatcher(false);
-    EnableExtendedCommandEventDispatcher(false);
 
     SetUseIncompatiblePathCreateInterface(false);
-    SetMarkHdlWhenTextEdit(true);
-    EnableTextEditOnObjectsWithoutTextIfTextTool(true);
 
     SetMinMoveDistancePixel(2);
     SetHitTolerancePixel(2);
-    SetMeasureLayer(SD_RESSTR(STR_LAYER_MEASURELINES));
+    SetMeasureLayer(SdResId(STR_LAYER_MEASURELINES));
 
     // Timer for delayed drop (has to be for MAC)
-    maDropErrorIdle.SetIdleHdl( LINK(this, View, DropErrorHdl) );
-    maDropErrorIdle.SetPriority(SchedulerPriority::MEDIUM);
-    maDropInsertFileIdle.SetIdleHdl( LINK(this, View, DropInsertFileHdl) );
-    maDropInsertFileIdle.SetPriority(SchedulerPriority::MEDIUM);
+    maDropErrorIdle.SetInvokeHandler( LINK(this, View, DropErrorHdl) );
+    maDropInsertFileIdle.SetInvokeHandler( LINK(this, View, DropInsertFileHdl) );
 }
 
 void View::ImplClearDrawDropMarker()
@@ -175,11 +176,10 @@ class ViewRedirector : public sdr::contact::ViewObjectContactRedirector
 {
 public:
     ViewRedirector();
-    virtual ~ViewRedirector();
 
     // all default implementations just call the same methods at the original. To do something
     // different, override the method and at least do what the method does.
-    virtual drawinglayer::primitive2d::Primitive2DSequence createRedirectedPrimitive2DSequence(
+    virtual drawinglayer::primitive2d::Primitive2DContainer createRedirectedPrimitive2DSequence(
         const sdr::contact::ViewObjectContact& rOriginal,
         const sdr::contact::DisplayInfo& rDisplayInfo) override;
 };
@@ -188,22 +188,18 @@ ViewRedirector::ViewRedirector()
 {
 }
 
-ViewRedirector::~ViewRedirector()
-{
-}
-
-drawinglayer::primitive2d::Primitive2DSequence ViewRedirector::createRedirectedPrimitive2DSequence(
+drawinglayer::primitive2d::Primitive2DContainer ViewRedirector::createRedirectedPrimitive2DSequence(
     const sdr::contact::ViewObjectContact& rOriginal,
     const sdr::contact::DisplayInfo& rDisplayInfo)
 {
     SdrObject* pObject = rOriginal.GetViewContact().TryToGetSdrObject();
-    drawinglayer::primitive2d::Primitive2DSequence xRetval;
+    drawinglayer::primitive2d::Primitive2DContainer xRetval;
 
     if(pObject && pObject->GetPage())
     {
         const bool bDoCreateGeometry(pObject->GetPage()->checkVisibility( rOriginal, rDisplayInfo, true ));
 
-        if(!bDoCreateGeometry && !(( pObject->GetObjInventor() == SdrInventor ) && ( pObject->GetObjIdentifier() == OBJ_PAGE )) )
+        if(!bDoCreateGeometry && !(( pObject->GetObjInventor() == SdrInventor::Default ) && ( pObject->GetObjIdentifier() == OBJ_PAGE )) )
             return xRetval;
 
         PresObjKind eKind(PRESOBJ_NONE);
@@ -229,7 +225,7 @@ drawinglayer::primitive2d::Primitive2DSequence ViewRedirector::createRedirectedP
                     bCreateOutline = true;
                 }
             }
-            else if( ( pObject->GetObjInventor() == SdrInventor ) && ( pObject->GetObjIdentifier() == OBJ_TEXT ) )
+            else if( ( pObject->GetObjInventor() == SdrInventor::Default ) && ( pObject->GetObjIdentifier() == OBJ_TEXT ) )
             {
                 if( pObjectsSdPage )
                 {
@@ -245,11 +241,11 @@ drawinglayer::primitive2d::Primitive2DSequence ViewRedirector::createRedirectedP
                     }
                 }
             }
-            else if( ( pObject->GetObjInventor() == SdrInventor ) && ( pObject->GetObjIdentifier() == OBJ_PAGE ) )
+            else if( ( pObject->GetObjInventor() == SdrInventor::Default ) && ( pObject->GetObjIdentifier() == OBJ_PAGE ) )
             {
                 // only for handout page, else this frame will be created for each
                 // page preview object in SlideSorter and PagePane
-                if(pObjectsSdPage && PK_HANDOUT == pObjectsSdPage->GetPageKind())
+                if(pObjectsSdPage && PageKind::Handout == pObjectsSdPage->GetPageKind())
                 {
                     bCreateOutline = true;
                 }
@@ -272,7 +268,7 @@ drawinglayer::primitive2d::Primitive2DSequence ViewRedirector::createRedirectedP
                     // create dashed border
                     {
                         // create object polygon
-                        basegfx::B2DPolygon aPolygon(basegfx::tools::createUnitPolygon());
+                        basegfx::B2DPolygon aPolygon(basegfx::utils::createUnitPolygon());
                         aPolygon.transform(aObjectMatrix);
 
                         // create line and stroke attribute
@@ -290,7 +286,7 @@ drawinglayer::primitive2d::Primitive2DSequence ViewRedirector::createRedirectedP
                             aPolygon,
                             aLine,
                             aStroke));
-                        drawinglayer::primitive2d::appendPrimitive2DReferenceToPrimitive2DSequence(xRetval, xRef);
+                        xRetval.push_back(xRef);
                     }
 
                     // now paint the placeholder description, but only when masterpage
@@ -303,9 +299,9 @@ drawinglayer::primitive2d::Primitive2DSequence ViewRedirector::createRedirectedP
                         {
                             case PRESOBJ_TITLE:
                             {
-                                if(pObjectsSdPage && pObjectsSdPage->GetPageKind() == PK_STANDARD)
+                                if(pObjectsSdPage && pObjectsSdPage->GetPageKind() == PageKind::Standard)
                                 {
-                                    static OUString aTitleAreaStr(SD_RESSTR(STR_PLACEHOLDER_DESCRIPTION_TITLE));
+                                    static OUString aTitleAreaStr(SdResId(STR_PLACEHOLDER_DESCRIPTION_TITLE));
                                     aObjectString = aTitleAreaStr;
                                 }
 
@@ -313,44 +309,44 @@ drawinglayer::primitive2d::Primitive2DSequence ViewRedirector::createRedirectedP
                             }
                             case PRESOBJ_OUTLINE:
                             {
-                                static OUString aOutlineAreaStr(SD_RESSTR(STR_PLACEHOLDER_DESCRIPTION_OUTLINE));
+                                static OUString aOutlineAreaStr(SdResId(STR_PLACEHOLDER_DESCRIPTION_OUTLINE));
                                 aObjectString = aOutlineAreaStr;
                                 break;
                             }
                             case PRESOBJ_FOOTER:
                             {
-                                static OUString aFooterAreaStr(SD_RESSTR(STR_PLACEHOLDER_DESCRIPTION_FOOTER));
+                                static OUString aFooterAreaStr(SdResId(STR_PLACEHOLDER_DESCRIPTION_FOOTER));
                                 aObjectString = aFooterAreaStr;
                                 break;
                             }
                             case PRESOBJ_HEADER:
                             {
-                                static OUString aHeaderAreaStr(SD_RESSTR(STR_PLACEHOLDER_DESCRIPTION_HEADER));
+                                static OUString aHeaderAreaStr(SdResId(STR_PLACEHOLDER_DESCRIPTION_HEADER));
                                 aObjectString = aHeaderAreaStr;
                                 break;
                             }
                             case PRESOBJ_DATETIME:
                             {
-                                static OUString aDateTimeStr(SD_RESSTR(STR_PLACEHOLDER_DESCRIPTION_DATETIME));
+                                static OUString aDateTimeStr(SdResId(STR_PLACEHOLDER_DESCRIPTION_DATETIME));
                                 aObjectString = aDateTimeStr;
                                 break;
                             }
                             case PRESOBJ_NOTES:
                             {
-                                static OUString aDateTimeStr(SD_RESSTR(STR_PLACEHOLDER_DESCRIPTION_NOTES));
+                                static OUString aDateTimeStr(SdResId(STR_PLACEHOLDER_DESCRIPTION_NOTES));
                                 aObjectString = aDateTimeStr;
                                 break;
                             }
                             case PRESOBJ_SLIDENUMBER:
                             {
-                                if(pObjectsSdPage && pObjectsSdPage->GetPageKind() == PK_STANDARD)
+                                if(pObjectsSdPage && pObjectsSdPage->GetPageKind() == PageKind::Standard)
                                 {
-                                    static OUString aSlideAreaStr(SD_RESSTR(STR_PLACEHOLDER_DESCRIPTION_SLIDE));
+                                    static OUString aSlideAreaStr(SdResId(STR_PLACEHOLDER_DESCRIPTION_SLIDE));
                                     aObjectString = aSlideAreaStr;
                                 }
                                 else
                                 {
-                                    static OUString aNumberAreaStr(SD_RESSTR(STR_PLACEHOLDER_DESCRIPTION_NUMBER));
+                                    static OUString aNumberAreaStr(SdResId(STR_PLACEHOLDER_DESCRIPTION_NUMBER));
                                     aObjectString = aNumberAreaStr;
                                 }
                                 break;
@@ -379,7 +375,7 @@ drawinglayer::primitive2d::Primitive2DSequence ViewRedirector::createRedirectedP
                             static sal_uInt32 nTextSizeFactor(100);
 
                             // use a factor to get more linear text size calculations
-                            aScaledVclFont.SetHeight( 500 * nTextSizeFactor );
+                            aScaledVclFont.SetFontHeight( 500 * nTextSizeFactor );
 
                             // get basic geometry and get text size
                             drawinglayer::primitive2d::TextLayouterDevice aTextLayouter;
@@ -400,11 +396,10 @@ drawinglayer::primitive2d::Primitive2DSequence ViewRedirector::createRedirectedP
                                 : (aTranslate.getY() + aScale.getY()) - fVerDist);
 
                             // get font attributes; use normally scaled font
-                            const basegfx::BColor aFontColor(aRGBColor);
                             vcl::Font aVclFont;
                             basegfx::B2DVector aTextSizeAttribute;
 
-                            aVclFont.SetHeight( 500 );
+                            aVclFont.SetFontHeight( 500 );
 
                             const drawinglayer::attribute::FontAttribute aFontAttribute(
                                 drawinglayer::primitive2d::getFontAttributeFromVclFont(
@@ -414,7 +409,7 @@ drawinglayer::primitive2d::Primitive2DSequence ViewRedirector::createRedirectedP
                                     false));
 
                             // fill text matrix
-                            const basegfx::B2DHomMatrix aTextMatrix(basegfx::tools::createScaleShearXRotateTranslateB2DHomMatrix(
+                            const basegfx::B2DHomMatrix aTextMatrix(basegfx::utils::createScaleShearXRotateTranslateB2DHomMatrix(
                                 aTextSizeAttribute.getX(), aTextSizeAttribute.getY(),
                                 fShearX,
                                 fRotate,
@@ -436,8 +431,8 @@ drawinglayer::primitive2d::Primitive2DSequence ViewRedirector::createRedirectedP
                                     aDXArray,
                                     aFontAttribute,
                                     aLocale,
-                                    aFontColor));
-                            drawinglayer::primitive2d::appendPrimitive2DReferenceToPrimitive2DSequence(xRetval, xRef);
+                                    aRGBColor));
+                            xRetval.push_back(xRef);
                         }
                     }
                 }
@@ -446,8 +441,7 @@ drawinglayer::primitive2d::Primitive2DSequence ViewRedirector::createRedirectedP
 
         if(bDoCreateGeometry)
         {
-            drawinglayer::primitive2d::appendPrimitive2DSequenceToPrimitive2DSequence(
-                xRetval,
+            xRetval.append(
                 sdr::contact::ViewObjectContactRedirector::createRedirectedPrimitive2DSequence(
                     rOriginal,
                     rDisplayInfo));
@@ -465,7 +459,7 @@ drawinglayer::primitive2d::Primitive2DSequence ViewRedirector::createRedirectedP
 /**
  * The event will be forwarded to the View
  */
-void View::CompleteRedraw(OutputDevice* pOutDev, const vcl::Region& rReg, sdr::contact::ViewObjectContactRedirector* pRedirector /*=0L*/)
+void View::CompleteRedraw(OutputDevice* pOutDev, const vcl::Region& rReg, sdr::contact::ViewObjectContactRedirector* pRedirector /*=0*/)
 {
     // execute ??
     if (mnLockRedrawSmph == 0)
@@ -519,9 +513,9 @@ bool View::SetAttributes(const SfxItemSet& rSet, bool bReplaceAll)
     return bOk;
 }
 
-bool View::GetAttributes( SfxItemSet& rTargetSet, bool bOnlyHardAttr ) const
+void View::GetAttributes( SfxItemSet& rTargetSet, bool bOnlyHardAttr ) const
 {
-    return FmFormView::GetAttributes( rTargetSet, bOnlyHardAttr );
+    FmFormView::GetAttributes( rTargetSet, bOnlyHardAttr );
 }
 
 /**
@@ -605,12 +599,6 @@ void View::SelectAll()
     }
 }
 
-void View::ModelHasChanged()
-{
-    // First, notify SdrView
-    FmFormView::ModelHasChanged();
-}
-
 bool View::SetStyleSheet(SfxStyleSheet* pStyleSheet, bool bDontRemoveHardAttr)
 {
     // forward to SdrView
@@ -648,6 +636,16 @@ void OutlinerMasterViewFilter::End()
     }
 }
 
+SfxViewShell* View::GetSfxViewShell() const
+{
+    SfxViewShell* pRet = nullptr;
+
+    if (mpViewSh)
+        pRet = &mpViewSh->GetViewShellBase();
+
+    return pRet;
+}
+
 bool View::SdrBeginTextEdit(
     SdrObject* pObj, SdrPageView* pPV, vcl::Window* pWin,
     bool bIsNewObj,
@@ -658,10 +656,10 @@ bool View::SdrBeginTextEdit(
     bool bMasterPage = pPage && pPage->IsMasterPage();
 
     GetViewShell()->GetViewShellBase().GetEventMultiplexer()->MultiplexEvent(
-        sd::tools::EventMultiplexerEvent::EID_BEGIN_TEXT_EDIT, static_cast<void*>(pObj) );
+        EventMultiplexerEventId::BeginTextEdit, static_cast<void*>(pObj) );
 
     if( pOutl==nullptr && pObj )
-        pOutl = SdrMakeOutliner(OUTLINERMODE_TEXTOBJECT, *pObj->GetModel());
+        pOutl = SdrMakeOutliner(OutlinerMode::TextObject, *pObj->GetModel());
 
     // make draw&impress specific initialisations
     if( pOutl )
@@ -700,6 +698,18 @@ bool View::SdrBeginTextEdit(
     if ( mpViewSh )
     {
         mpViewSh->GetViewShellBase().GetDrawController().FireSelectionChangeListener();
+
+        if (comphelper::LibreOfficeKit::isActive())
+        {
+            if (OutlinerView* pView = GetTextEditOutlinerView())
+            {
+                ::tools::Rectangle aRectangle = pView->GetOutputArea();
+                if (pWin && pWin->GetMapMode().GetMapUnit() == MapUnit::Map100thMM)
+                    aRectangle = OutputDevice::LogicToLogic(aRectangle, MapMode(MapUnit::Map100thMM), MapMode(MapUnit::MapTwip));
+                OString sRectangle = aRectangle.toString();
+                SfxLokHelper::notifyOtherViews(&mpViewSh->GetViewShellBase(), LOK_CALLBACK_VIEW_LOCK, "rectangle", sRectangle);
+            }
+        }
     }
 
     if (bReturn)
@@ -709,7 +719,7 @@ bool View::SdrBeginTextEdit(
         if( pObj && pObj->GetPage() )
         {
             Color aBackground;
-            if( pObj->GetObjInventor() == SdrInventor && pObj->GetObjIdentifier() == OBJ_TABLE )
+            if( pObj->GetObjInventor() == SdrInventor::Default && pObj->GetObjIdentifier() == OBJ_TABLE )
             {
                 aBackground = GetTextEditBackgroundColor(*this);
             }
@@ -767,7 +777,7 @@ SdrEndTextEditKind View::SdrEndTextEdit(bool bDontDeleteReally)
         }
         else
         {
-            eKind = SDRENDTEXTEDIT_UNCHANGED;
+            eKind = SdrEndTextEditKind::Unchanged;
         }
     }
     else if( xObj.is() && xObj->IsEmptyPresObj() )
@@ -782,7 +792,7 @@ SdrEndTextEditKind View::SdrEndTextEdit(bool bDontDeleteReally)
     }
 
     GetViewShell()->GetViewShellBase().GetEventMultiplexer()->MultiplexEvent(
-        sd::tools::EventMultiplexerEvent::EID_END_TEXT_EDIT,
+        EventMultiplexerEventId::EndTextEdit,
         static_cast<void*>(xObj.get()) );
 
     if( xObj.is() )
@@ -790,6 +800,10 @@ SdrEndTextEditKind View::SdrEndTextEdit(bool bDontDeleteReally)
         if ( mpViewSh )
         {
             mpViewSh->GetViewShellBase().GetDrawController().FireSelectionChangeListener();
+
+            if (comphelper::LibreOfficeKit::isActive())
+                SfxLokHelper::notifyOtherViews(&mpViewSh->GetViewShellBase(), LOK_CALLBACK_VIEW_LOCK, "rectangle", "EMPTY");
+
         }
 
         SdPage* pPage = dynamic_cast< SdPage* >( xObj->GetPage() );
@@ -843,7 +857,7 @@ void View::SetMarkedOriginalSize()
     {
         SdrObject* pObj = GetMarkedObjectByIndex(i);
 
-        if( pObj->GetObjInventor() == SdrInventor )
+        if( pObj->GetObjInventor() == SdrInventor::Default )
         {
             if( pObj->GetObjIdentifier() == OBJ_OLE2 )
             {
@@ -857,7 +871,7 @@ void View::SetMarkedOriginalSize()
 
                     if ( nAspect == embed::Aspects::MSOLE_ICON )
                     {
-                        MapMode aMap100( MAP_100TH_MM );
+                        MapMode aMap100( MapUnit::Map100thMM );
                         aOleSize = static_cast<SdrOle2Obj*>(pObj)->GetOrigObjSize( &aMap100 );
                         bOK = true;
                     }
@@ -867,7 +881,7 @@ void View::SetMarkedOriginalSize()
                         try
                         {
                             awt::Size aSz = xObj->getVisualAreaSize( nAspect );
-                            aOleSize = OutputDevice::LogicToLogic( Size( aSz.Width, aSz.Height ), aUnit, MAP_100TH_MM );
+                            aOleSize = OutputDevice::LogicToLogic(Size(aSz.Width, aSz.Height), MapMode(aUnit), MapMode(MapUnit::Map100thMM));
                             bOK = true;
                         }
                         catch( embed::NoVisualAreaSizeException& )
@@ -876,7 +890,7 @@ void View::SetMarkedOriginalSize()
 
                     if ( bOK )
                     {
-                        Rectangle   aDrawRect( pObj->GetLogicRect() );
+                        ::tools::Rectangle   aDrawRect( pObj->GetLogicRect() );
 
                         pUndoGroup->AddAction( mrDoc.GetSdrUndoFactory().CreateUndoGeoObject( *pObj ) );
                         pObj->Resize( aDrawRect.TopLeft(), Fraction( aOleSize.Width(), aDrawRect.GetWidth() ),
@@ -886,23 +900,12 @@ void View::SetMarkedOriginalSize()
             }
             else if( pObj->GetObjIdentifier() == OBJ_GRAF )
             {
-                const MapMode   aMap100( MAP_100TH_MM );
-                Size            aSize;
-
-                if ( static_cast< SdrGrafObj* >( pObj )->GetGrafPrefMapMode().GetMapUnit() == MAP_PIXEL )
-                    aSize = Application::GetDefaultDevice()->PixelToLogic( static_cast< SdrGrafObj* >( pObj )->GetGrafPrefSize(), aMap100 );
-                else
-                {
-                    aSize = OutputDevice::LogicToLogic( static_cast< SdrGrafObj* >( pObj )->GetGrafPrefSize(),
-                                                        static_cast< SdrGrafObj* >( pObj )->GetGrafPrefMapMode(),
-                                                        aMap100 );
-                }
-
+                const SdrGrafObj* pSdrGrafObj = static_cast< const SdrGrafObj* >(pObj);
+                const Size aSize = pSdrGrafObj->getOriginalSize( );
                 pUndoGroup->AddAction( GetModel()->GetSdrUndoFactory().CreateUndoGeoObject(*pObj ) );
-                Rectangle aRect( pObj->GetLogicRect() );
+                ::tools::Rectangle aRect( pObj->GetLogicRect() );
                 aRect.SetSize( aSize );
                 pObj->SetLogicRect( aRect );
-
                 bOK = true;
             }
         }
@@ -910,7 +913,7 @@ void View::SetMarkedOriginalSize()
 
     if( bOK )
     {
-        pUndoGroup->SetComment(SD_RESSTR(STR_UNDO_ORIGINALSIZE));
+        pUndoGroup->SetComment(SdResId(STR_UNDO_ORIGINALSIZE));
         mpDocSh->GetUndoManager()->AddUndoAction(pUndoGroup);
     }
     else
@@ -932,11 +935,10 @@ void View::DoConnect(SdrOle2Obj* pObj)
             if ( !pSdClient )
             {
                 pSdClient = new Client(pObj, mpViewSh, pWindow);
-                Rectangle aRect = pObj->GetLogicRect();
+                ::tools::Rectangle aRect = pObj->GetLogicRect();
                 {
                     // TODO/LEAN: working with visual area can switch object to running state
                     Size aDrawSize = aRect.GetSize();
-                    awt::Size aSz;
 
                     MapMode aMapMode( mrDoc.GetScaleUnit() );
                     Size aObjAreaSize = pObj->GetOrigObjSize( &aMapMode );
@@ -985,14 +987,14 @@ bool View::IsMorphingAllowed() const
              ( nKind1 != OBJ_CAPTION && nKind2 !=  OBJ_CAPTION ) &&
              dynamic_cast< const E3dObject *>( pObj1 ) == nullptr && dynamic_cast< const E3dObject *>( pObj2 ) ==  nullptr )
         {
-            SfxItemSet      aSet1( mrDoc.GetPool(), XATTR_FILLSTYLE, XATTR_FILLSTYLE );
-            SfxItemSet      aSet2( mrDoc.GetPool(), XATTR_FILLSTYLE, XATTR_FILLSTYLE );
+            SfxItemSet      aSet1( mrDoc.GetPool(), svl::Items<XATTR_FILLSTYLE, XATTR_FILLSTYLE>{} );
+            SfxItemSet      aSet2( mrDoc.GetPool(), svl::Items<XATTR_FILLSTYLE, XATTR_FILLSTYLE>{} );
 
             aSet1.Put(pObj1->GetMergedItemSet());
             aSet2.Put(pObj2->GetMergedItemSet());
 
-            const drawing::FillStyle eFillStyle1 = static_cast<const XFillStyleItem&>( aSet1.Get( XATTR_FILLSTYLE ) ).GetValue();
-            const drawing::FillStyle eFillStyle2 = static_cast<const XFillStyleItem&>( aSet2.Get( XATTR_FILLSTYLE ) ).GetValue();
+            const drawing::FillStyle eFillStyle1 = aSet1.Get( XATTR_FILLSTYLE ).GetValue();
+            const drawing::FillStyle eFillStyle2 = aSet2.Get( XATTR_FILLSTYLE ).GetValue();
 
             if( ( eFillStyle1 == drawing::FillStyle_NONE || eFillStyle1 == drawing::FillStyle_SOLID ) &&
                 ( eFillStyle2 == drawing::FillStyle_NONE || eFillStyle2 == drawing::FillStyle_SOLID ) )
@@ -1014,7 +1016,7 @@ bool View::IsVectorizeAllowed() const
 
         if(pObj)
         {
-            if(GRAPHIC_BITMAP == pObj->GetGraphicType() && !pObj->isEmbeddedSvg())
+            if(GraphicType::Bitmap == pObj->GetGraphicType() && !pObj->isEmbeddedVectorGraphicData())
             {
                 bRet = true;
             }
@@ -1066,32 +1068,30 @@ void View::onAccessibilityOptionsChanged()
     }
 }
 
-IMPL_LINK_TYPED( View, OnParagraphInsertedHdl, ::Outliner *, pOutliner, void )
+IMPL_LINK( View, OnParagraphInsertedHdl, ::Outliner::ParagraphHdlParam, aParam, void )
 {
-    Paragraph* pPara = pOutliner->GetHdlParagraph();
     SdrObject* pObj = GetTextEditObject();
 
-    if( pPara && pObj )
+    if( aParam.pPara && pObj )
     {
         SdPage* pPage = dynamic_cast< SdPage* >( pObj->GetPage() );
         if( pPage )
-            pPage->onParagraphInserted( pOutliner, pPara, pObj );
+            pPage->onParagraphInserted( aParam.pOutliner, aParam.pPara, pObj );
     }
 }
 
 /**
  * Handler for the deletion of the pages (paragraphs).
  */
-IMPL_LINK_TYPED( View, OnParagraphRemovingHdl, ::Outliner *, pOutliner, void )
+IMPL_LINK( View, OnParagraphRemovingHdl, ::Outliner::ParagraphHdlParam, aParam, void )
 {
-    Paragraph* pPara = pOutliner->GetHdlParagraph();
     SdrObject* pObj = GetTextEditObject();
 
-    if( pPara && pObj )
+    if( aParam.pPara && pObj )
     {
         SdPage* pPage = dynamic_cast< SdPage* >( pObj->GetPage() );
         if( pPage )
-            pPage->onParagraphRemoving( pOutliner, pPara, pObj );
+            pPage->onParagraphRemoving( aParam.pOutliner, aParam.pPara, pObj );
     }
 }
 
@@ -1120,7 +1120,7 @@ void View::updateHandles()
 
 SdrViewContext View::GetContext() const
 {
-    SdrViewContext eContext = SDRCONTEXT_STANDARD;
+    SdrViewContext eContext = SdrViewContext::Standard;
     if( maSmartTags.getContext( eContext ) )
         return eContext;
     else
@@ -1173,7 +1173,7 @@ bool View::MarkPoint(SdrHdl& rHdl, bool bUnmark )
         return FmFormView::MarkPoint( rHdl, bUnmark );
 }
 
-bool View::MarkPoints(const Rectangle* pRect, bool bUnmark)
+bool View::MarkPoints(const ::tools::Rectangle* pRect, bool bUnmark)
 {
     if( maSmartTags.MarkPoints( pRect, bUnmark ) )
         return true;
@@ -1187,64 +1187,45 @@ void View::CheckPossibilities()
     maSmartTags.CheckPossibilities();
 }
 
-void View::OnBeginPasteOrDrop( PasteOrDropInfos* /*pInfos*/ )
+void View::OnBeginPasteOrDrop( PasteOrDropInfos* pInfo )
 {
+    SdrOutliner* pOutliner = GetTextEditOutliner();
+    if (!pOutliner)
+        return;
+
+    // Turn character attributes of the paragraph of the insert position into
+    // character-level attributes, so they are not lost when OnEndPasteOrDrop()
+    // sets the paragraph stylesheet.
+    SfxItemSet aSet(pOutliner->GetParaAttribs(pInfo->nStartPara));
+    pOutliner->SetCharAttribs(pInfo->nStartPara, aSet);
 }
 
 /** this is called after a paste or drop operation, make sure that the newly inserted paragraphs
     get the correct style sheet. */
-void View::OnEndPasteOrDrop( PasteOrDropInfos* pInfos )
+void View::OnEndPasteOrDrop( PasteOrDropInfos* pInfo )
 {
     /* Style Sheet handling */
     SdrTextObj* pTextObj = dynamic_cast< SdrTextObj* >( GetTextEditObject() );
     SdrOutliner* pOutliner = GetTextEditOutliner();
-    if( pOutliner && pTextObj && pTextObj->GetPage() )
+    if( !pOutliner || !pTextObj || !pTextObj->GetPage() )
+        return;
+
+    SdPage* pPage = static_cast< SdPage* >( pTextObj->GetPage() );
+    const PresObjKind eKind = pPage->GetPresObjKind(pTextObj);
+
+    // outline kinds are taken care of in Outliner::ImplSetLevelDependentStyleSheet
+    if( eKind == PRESOBJ_OUTLINE )
+        return;
+
+    SfxStyleSheet* pStyleSheet = nullptr;
+    if( eKind != PRESOBJ_NONE )
+        pStyleSheet = pPage->GetStyleSheetForPresObj(eKind);
+    else
+         pStyleSheet = pTextObj->GetStyleSheet();
+    // just put the object style on each new paragraph
+    for ( sal_Int32 nPara = pInfo->nStartPara; nPara <= pInfo->nEndPara; nPara++ )
     {
-        SdPage* pPage = static_cast< SdPage* >( pTextObj->GetPage() );
-
-        SfxStyleSheet* pStyleSheet = nullptr;
-
-        const PresObjKind eKind = pPage->GetPresObjKind(pTextObj);
-        if( eKind != PRESOBJ_NONE )
-            pStyleSheet = pPage->GetStyleSheetForPresObj(eKind);
-        else
-            pStyleSheet = pTextObj->GetStyleSheet();
-
-        if( eKind == PRESOBJ_OUTLINE )
-        {
-            // for outline shapes, set the correct outline style sheet for each
-            // new paragraph, depending on the paragraph depth
-            SfxStyleSheetBasePool* pStylePool = GetDoc().GetStyleSheetPool();
-
-            for ( sal_Int32 nPara = pInfos->nStartPara; nPara <= pInfos->nEndPara; nPara++ )
-            {
-                sal_Int16 nDepth = pOutliner->GetDepth( nPara );
-
-                SfxStyleSheet* pStyle = nullptr;
-                if( nDepth > 0 )
-                {
-                    OUString aStyleSheetName( pStyleSheet->GetName() );
-                    if (!aStyleSheetName.isEmpty())
-                        aStyleSheetName = aStyleSheetName.copy(0, aStyleSheetName.getLength() - 1);
-                    aStyleSheetName += OUString::number( nDepth );
-                    pStyle = static_cast<SfxStyleSheet*>( pStylePool->Find( aStyleSheetName, pStyleSheet->GetFamily() ) );
-                    DBG_ASSERT( pStyle, "sd::View::OnEndPasteOrDrop(), Style not found!" );
-                }
-
-                if( !pStyle )
-                    pStyle = pStyleSheet;
-
-                pOutliner->SetStyleSheet( nPara, pStyle );
-            }
-        }
-        else
-        {
-            // just put the object style on each new paragraph
-            for ( sal_Int32 nPara = pInfos->nStartPara; nPara <= pInfos->nEndPara; nPara++ )
-            {
-                pOutliner->SetStyleSheet( nPara, pStyleSheet );
-            }
-        }
+        pOutliner->SetStyleSheet( nPara, pStyleSheet );
     }
 }
 
@@ -1260,7 +1241,7 @@ bool View::ShouldToggleOn(
         return false;
 
     bool bToggleOn = false;
-    std::unique_ptr<SdrOutliner> pOutliner(SdrMakeOutliner(OUTLINERMODE_TEXTOBJECT, *pSdrModel));
+    std::unique_ptr<SdrOutliner> pOutliner(SdrMakeOutliner(OutlinerMode::TextObject, *pSdrModel));
     const size_t nMarkCount = GetMarkedObjectCount();
     for (size_t nIndex = 0; nIndex < nMarkCount && !bToggleOn; ++nIndex)
     {
@@ -1328,7 +1309,7 @@ void View::ChangeMarkedObjectsBulletsNumbering(
 
     const bool bToggleOn = ShouldToggleOn( bToggle, bHandleBullets );
 
-    std::unique_ptr<SdrOutliner> pOutliner(SdrMakeOutliner(OUTLINERMODE_TEXTOBJECT, *pSdrModel));
+    std::unique_ptr<SdrOutliner> pOutliner(SdrMakeOutliner(OutlinerMode::TextObject, *pSdrModel));
     std::unique_ptr<OutlinerView> pOutlinerView(new OutlinerView(pOutliner.get(), pWindow));
 
     const size_t nMarkCount = GetMarkedObjectCount();
