@@ -17,7 +17,7 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "View.hxx"
+#include <View.hxx>
 #include <com/sun/star/embed/XEmbedObjectClipboardCreator.hpp>
 #include <com/sun/star/embed/NoVisualAreaSizeException.hpp>
 #include <com/sun/star/embed/MSOLEObjectSystemCreator.hpp>
@@ -54,22 +54,23 @@
 #include <svx/svxids.hrc>
 #include <toolkit/helper/vclunohelper.hxx>
 #include <svtools/embedhlp.hxx>
-#include "DrawDocShell.hxx"
-#include "fupoor.hxx"
-#include "tablefunction.hxx"
-#include "Window.hxx"
-#include "sdxfer.hxx"
-#include "sdpage.hxx"
-#include "DrawViewShell.hxx"
-#include "drawdoc.hxx"
-#include "sdresid.hxx"
-#include "strings.hrc"
-#include "imapinfo.hxx"
-#include "SlideSorterViewShell.hxx"
-#include "strmname.h"
-#include "unomodel.hxx"
-#include "ViewClipboard.hxx"
+#include <DrawDocShell.hxx>
+#include <fupoor.hxx>
+#include <tablefunction.hxx>
+#include <Window.hxx>
+#include <sdxfer.hxx>
+#include <sdpage.hxx>
+#include <DrawViewShell.hxx>
+#include <drawdoc.hxx>
+#include <sdresid.hxx>
+#include <strings.hrc>
+#include <imapinfo.hxx>
+#include <SlideSorterViewShell.hxx>
+#include <strmname.h>
+#include <unomodel.hxx>
+#include <ViewClipboard.hxx>
 #include <sfx2/ipclient.hxx>
+#include <sfx2/classificationhelper.hxx>
 #include <comphelper/storagehelper.hxx>
 #include <comphelper/processfactory.hxx>
 #include <tools/stream.hxx>
@@ -78,7 +79,6 @@
 #include <svx/xbtmpit.hxx>
 #include <memory>
 
-// - Namespaces -
 
 using namespace ::com::sun::star;
 using namespace ::com::sun::star::lang;
@@ -103,22 +103,22 @@ struct ImpRememberOrigAndClone
     SdrObject*      pClone;
 };
 
-SdrObject* ImpGetClone(std::vector<ImpRememberOrigAndClone*>& aConnectorContainer, SdrObject* pConnObj)
+SdrObject* ImpGetClone(std::vector<ImpRememberOrigAndClone*>& aConnectorContainer, SdrObject const * pConnObj)
 {
-    for(size_t a(0); a < aConnectorContainer.size(); a++)
+    for(ImpRememberOrigAndClone* p : aConnectorContainer)
     {
-        if(pConnObj == aConnectorContainer[a]->pOrig)
-            return aConnectorContainer[a]->pClone;
+        if(pConnObj == p->pOrig)
+            return p->pClone;
     }
     return nullptr;
 }
 
 // restrict movement to WorkArea
-void ImpCheckInsertPos(Point& rPos, const Size& rSize, const Rectangle& rWorkArea)
+void ImpCheckInsertPos(Point& rPos, const Size& rSize, const ::tools::Rectangle& rWorkArea)
 {
     if(!rWorkArea.IsEmpty())
     {
-        Rectangle aMarkRect(Point(rPos.X() - (rSize.Width() / 2), rPos.Y() - (rSize.Height() / 2)), rSize);
+        ::tools::Rectangle aMarkRect(Point(rPos.X() - (rSize.Width() / 2), rPos.Y() - (rSize.Height() / 2)), rSize);
 
         if(!aMarkRect.IsInside(rWorkArea))
         {
@@ -145,7 +145,7 @@ void ImpCheckInsertPos(Point& rPos, const Size& rSize, const Rectangle& rWorkAre
     }
 }
 
-bool View::InsertMetaFile( TransferableDataHelper& rDataHelper, const Point& rPos, ImageMap* pImageMap, bool bOptimize )
+bool View::InsertMetaFile( TransferableDataHelper& rDataHelper, const Point& rPos, ImageMap const * pImageMap, bool bOptimize )
 {
     GDIMetaFile aMtf;
 
@@ -193,7 +193,7 @@ bool View::InsertMetaFile( TransferableDataHelper& rDataHelper, const Point& rPo
                 case MetaActionType::BMPSCALE:
                 case MetaActionType::BMPEX:
                 case MetaActionType::BMPEXSCALE:
-                    if( aGraphic.GetType() != GRAPHIC_NONE )
+                    if( aGraphic.GetType() != GraphicType::NONE )
                     {
                         bVector = true;
                     }
@@ -229,6 +229,7 @@ bool View::InsertMetaFile( TransferableDataHelper& rDataHelper, const Point& rPo
                             break;
                         default: break;
                     }
+                    break;
                 default: break;
             }
 
@@ -237,7 +238,7 @@ bool View::InsertMetaFile( TransferableDataHelper& rDataHelper, const Point& rPo
     }
 
     // it is not a vector metafile but it also has no graphic?
-    if( !bVector && (aGraphic.GetType() == GRAPHIC_NONE) )
+    if( !bVector && (aGraphic.GetType() == GraphicType::NONE) )
         bVector = true;
 
     // restrict movement to WorkArea
@@ -258,7 +259,7 @@ bool View::InsertMetaFile( TransferableDataHelper& rDataHelper, const Point& rPo
 
 bool View::InsertData( const TransferableDataHelper& rDataHelper,
                          const Point& rPos, sal_Int8& rDnDAction, bool bDrag,
-                         SotClipboardFormatId nFormat, sal_uInt16 nPage, sal_uInt16 nLayer )
+                         SotClipboardFormatId nFormat, sal_uInt16 nPage, SdrLayerID nLayer )
 {
     maDropPos = rPos;
     mnAction = rDnDAction;
@@ -285,7 +286,7 @@ bool View::InsertData( const TransferableDataHelper& rDataHelper,
     if( bDrag )
     {
         SdrPageView* pPV = nullptr;
-        PickObj( rPos, getHitTolLog(), pPickObj, pPV );
+        pPickObj = PickObj(rPos, getHitTolLog(), pPV);
     }
 
     if( nPage != SDRPAGE_NOTFOUND )
@@ -320,20 +321,22 @@ bool View::InsertData( const TransferableDataHelper& rDataHelper,
         {
             pImageMap.reset(new ImageMap);
             // mba: clipboard always must contain absolute URLs (could be from alien source)
-            pImageMap->Read( *xStm, OUString() );
+            pImageMap->Read( *xStm );
         }
     }
 
     bool bTable = false;
     // check special cases for pasting table formats as RTL
-    if( !bLink && (nFormat == SotClipboardFormatId::NONE || (nFormat == SotClipboardFormatId::RTF)) )
+    if( !bLink && (nFormat == SotClipboardFormatId::NONE || (nFormat == SotClipboardFormatId::RTF) || (nFormat == SotClipboardFormatId::RICHTEXT)) )
     {
-        // if the objekt supports rtf and there is a table involved, default is to create a table
-        if( aDataHelper.HasFormat( SotClipboardFormatId::RTF ) && ! aDataHelper.HasFormat( SotClipboardFormatId::DRAWING ) )
+        // if the object supports rtf and there is a table involved, default is to create a table
+        bool bIsRTF = aDataHelper.HasFormat( SotClipboardFormatId::RTF );
+        if( ( bIsRTF || aDataHelper.HasFormat( SotClipboardFormatId::RICHTEXT ) )
+            && ! aDataHelper.HasFormat( SotClipboardFormatId::DRAWING ) )
         {
             ::tools::SvRef<SotStorageStream> xStm;
 
-            if( aDataHelper.GetSotStorageStream( SotClipboardFormatId::RTF, xStm ) )
+            if( aDataHelper.GetSotStorageStream( bIsRTF ? SotClipboardFormatId::RTF : SotClipboardFormatId::RICHTEXT, xStm ) )
             {
                 xStm->Seek( 0 );
 
@@ -344,7 +347,7 @@ bool View::InsertData( const TransferableDataHelper& rDataHelper,
                     if (x != -1)
                     {
                         bTable = true;
-                        nFormat = SotClipboardFormatId::RTF;
+                        nFormat = bIsRTF ? SotClipboardFormatId::RTF : SotClipboardFormatId::RICHTEXT;
                         break;
                     }
                 }
@@ -356,11 +359,25 @@ bool View::InsertData( const TransferableDataHelper& rDataHelper,
     // the work was done; this allows to check multiple formats and not just fail
     // when a CHECK_FORMAT_TRANS(*format*) detected format does not work. This is
     // e.g. necessary for SotClipboardFormatId::BITMAP
-    if( pOwnData && nFormat == SotClipboardFormatId::NONE )
+
+    if (!bReturn && pOwnData)
+    {
+        // Paste only if SfxClassificationHelper recommends so.
+        const SfxObjectShellRef& pSource = pOwnData->GetDocShell();
+        SfxObjectShell* pDestination = mrDoc.GetDocSh();
+        if (pSource.is() && pDestination)
+        {
+            SfxClassificationCheckPasteResult eResult = SfxClassificationHelper::CheckPaste(pSource->getDocProperties(), pDestination->getDocProperties());
+            if (!SfxClassificationHelper::ShowPasteInfo(eResult))
+                bReturn = true;
+        }
+    }
+
+    if( !bReturn && pOwnData && nFormat == SotClipboardFormatId::NONE )
     {
         const View* pSourceView = pOwnData->GetView();
 
-        if( pOwnData->GetDocShell() && pOwnData->IsPageTransferable() )
+        if( pOwnData->GetDocShell().is() && pOwnData->IsPageTransferable() )
         {
             mpClipboard->HandlePageDrop (*pOwnData);
             bReturn = true;
@@ -393,12 +410,12 @@ bool View::InsertData( const TransferableDataHelper& rDataHelper,
                                 // #i11702#
                                 if( IsUndoEnabled() )
                                 {
-                                    BegUndo(SD_RESSTR(STR_MODIFYLAYER));
-                                    AddUndo(GetModel()->GetSdrUndoFactory().CreateUndoObjectLayerChange(*pO, pO->GetLayer(), (SdrLayerID)nLayer));
+                                    BegUndo(SdResId(STR_MODIFYLAYER));
+                                    AddUndo(GetModel()->GetSdrUndoFactory().CreateUndoObjectLayerChange(*pO, pO->GetLayer(), nLayer));
                                     EndUndo();
                                 }
 
-                                pO->SetLayer( (SdrLayerID) nLayer );
+                                pO->SetLayer( nLayer );
                             }
                         }
 
@@ -448,7 +465,7 @@ bool View::InsertData( const TransferableDataHelper& rDataHelper,
                                 // source objects, if necessary (#103207)
                                 if( pOwnData == SD_MOD()->pTransferSelection )
                                 {
-                                    Rectangle aCurBoundRect;
+                                    ::tools::Rectangle aCurBoundRect;
 
                                     if( pMarkList->TakeBoundRect( pPV, aCurBoundRect ) )
                                         aCurPos = aCurBoundRect.TopLeft();
@@ -477,7 +494,7 @@ bool View::InsertData( const TransferableDataHelper& rDataHelper,
 
                                         if( IsUndoEnabled() )
                                         {
-                                            BegUndo(SD_RESSTR(STR_UNDO_DRAGDROP));
+                                            BegUndo(SdResId(STR_UNDO_DRAGDROP));
                                             AddUndo(GetModel()->GetSdrUndoFactory().CreateUndoNewObject(*pObj));
                                             EndUndo();
                                         }
@@ -528,8 +545,8 @@ bool View::InsertData( const TransferableDataHelper& rDataHelper,
                                                         {
                                                             const SdrGluePoint& rGluePoint = (*pGlueList)[nInd];
                                                             Point aPosition = rGluePoint.GetAbsolutePos(*pConnObj);
-                                                            aPosition.X() += aVector.A();
-                                                            aPosition.Y() += aVector.B();
+                                                            aPosition.X() += aVector.Width();
+                                                            aPosition.Y() += aVector.Height();
                                                             pCloneEdge->SetTailPoint(false, aPosition);
                                                         }
                                                     }
@@ -560,8 +577,8 @@ bool View::InsertData( const TransferableDataHelper& rDataHelper,
                                                         {
                                                             const SdrGluePoint& rGluePoint = (*pGlueList)[nInd];
                                                             Point aPosition = rGluePoint.GetAbsolutePos(*pConnObj);
-                                                            aPosition.X() += aVector.A();
-                                                            aPosition.Y() += aVector.B();
+                                                            aPosition.X() += aVector.Width();
+                                                            aPosition.Y() += aVector.Height();
                                                             pCloneEdge->SetTailPoint(true, aPosition);
                                                         }
                                                     }
@@ -572,8 +589,8 @@ bool View::InsertData( const TransferableDataHelper& rDataHelper,
                                 }
 
                                 // cleanup remember classes
-                                for(size_t a = 0; a < aConnectorContainer.size(); ++a)
-                                    delete aConnectorContainer[a];
+                                for(ImpRememberOrigAndClone* p : aConnectorContainer)
+                                    delete p;
 
                                 if( pMarkList != mpDragSrcMarkList )
                                     delete pMarkList;
@@ -605,7 +622,7 @@ bool View::InsertData( const TransferableDataHelper& rDataHelper,
                     SdDrawDocument* pSourceDoc = static_cast<SdDrawDocument*>( pSourceView->GetModel() );
                     pSourceDoc->CreatingDataObj( pOwnData );
                     SdDrawDocument* pModel = static_cast<SdDrawDocument*>( pSourceView->GetMarkedObjModel() );
-                    bReturn = Paste(*pModel, maDropPos, pPage, nPasteOptions, OUString(), OUString());
+                    bReturn = Paste(*pModel, maDropPos, pPage, nPasteOptions);
 
                     if( !pPage )
                         pPage = static_cast<SdPage*>( GetSdrPageView()->GetPage() );
@@ -627,7 +644,7 @@ bool View::InsertData( const TransferableDataHelper& rDataHelper,
         else
         {
             SdDrawDocument* pWorkModel = const_cast<SdDrawDocument*>(pOwnData->GetWorkDocument());
-            SdPage*         pWorkPage = pWorkModel->GetSdPage( 0, PK_STANDARD );
+            SdPage*         pWorkPage = pWorkModel->GetSdPage( 0, PageKind::Standard );
 
             pWorkPage->SetRectsDirty();
 
@@ -642,11 +659,11 @@ bool View::InsertData( const TransferableDataHelper& rDataHelper,
             {
                 SdPage* pP = static_cast< SdPage* >( pWorkModel->GetPage( (sal_uInt16) i ) );
 
-                if( pP->GetPageKind() != PK_STANDARD )
+                if( pP->GetPageKind() != PageKind::Standard )
                     pWorkModel->DeletePage( (sal_uInt16) i );
             }
 
-            bReturn = Paste(*pWorkModel, maDropPos, pPage, nPasteOptions, OUString(), OUString());
+            bReturn = Paste(*pWorkModel, maDropPos, pPage, nPasteOptions);
 
             if( !pPage )
                 pPage = static_cast<SdPage*>( GetSdrPageView()->GetPage() );
@@ -665,7 +682,7 @@ bool View::InsertData( const TransferableDataHelper& rDataHelper,
 
         if( aDataHelper.GetSotStorageStream( SotClipboardFormatId::DRAWING, xStm ) )
         {
-            DrawDocShellRef xShell = new DrawDocShell(SfxObjectCreateMode::INTERNAL);
+            DrawDocShellRef xShell = new DrawDocShell(SfxObjectCreateMode::INTERNAL, false);
             xShell->DoInitNew();
 
             SdDrawDocument* pModel = xShell->GetDoc();
@@ -687,22 +704,21 @@ bool View::InsertData( const TransferableDataHelper& rDataHelper,
 
                 if( bReturn )
                 {
-                    if( pModel->GetSdPage( 0, PK_STANDARD )->GetObjCount() == 1 )
+                    if( pModel->GetSdPage( 0, PageKind::Standard )->GetObjCount() == 1 )
                     {
                         // only one object
-                        SdrObject*      pObj = pModel->GetSdPage( 0, PK_STANDARD )->GetObj( 0 );
-                        SdrObject*      pPickObj2 = nullptr;
+                        SdrObject*      pObj = pModel->GetSdPage( 0, PageKind::Standard )->GetObj( 0 );
                         SdrPageView*    pPV = nullptr;
-                        PickObj( rPos, getHitTolLog(), pPickObj2, pPV );
+                        SdrObject* pPickObj2 = PickObj(rPos, getHitTolLog(), pPV);
 
                         if( ( mnAction & DND_ACTION_MOVE ) && pPickObj2 && pObj )
                         {
                             // replace object
                             SdrObject*  pNewObj = pObj->Clone();
-                            Rectangle   aPickObjRect( pPickObj2->GetCurrentBoundRect() );
+                            ::tools::Rectangle   aPickObjRect( pPickObj2->GetCurrentBoundRect() );
                             Size        aPickObjSize( aPickObjRect.GetSize() );
                             Point       aVec( aPickObjRect.TopLeft() );
-                            Rectangle   aObjRect( pNewObj->GetCurrentBoundRect() );
+                            ::tools::Rectangle   aObjRect( pNewObj->GetCurrentBoundRect() );
                             Size        aObjSize( aObjRect.GetSize() );
 
                             Fraction aScaleWidth( aPickObjSize.Width(), aObjSize.Width() );
@@ -715,7 +731,7 @@ bool View::InsertData( const TransferableDataHelper& rDataHelper,
                             const bool bUndo = IsUndoEnabled();
 
                             if( bUndo )
-                                BegUndo(SD_RESSTR(STR_UNDO_DRAGDROP));
+                                BegUndo(SdResId(STR_UNDO_DRAGDROP));
                             pNewObj->NbcSetLayer( pPickObj->GetLayer() );
                             SdrPage* pWorkPage = GetSdrPageView()->GetPage();
                             pWorkPage->InsertObject( pNewObj );
@@ -747,7 +763,7 @@ bool View::InsertData( const TransferableDataHelper& rDataHelper,
                             const bool bUndo = IsUndoEnabled();
                             if( bUndo )
                             {
-                                BegUndo( SD_RESSTR(STR_UNDO_DRAGDROP) );
+                                BegUndo( SdResId(STR_UNDO_DRAGDROP) );
                                 AddUndo( mrDoc.GetSdrUndoFactory().CreateUndoAttrObject( *pPickObj ) );
                             }
 
@@ -763,10 +779,10 @@ bool View::InsertData( const TransferableDataHelper& rDataHelper,
 
                             if(pSdrGrafObj)
                             {
-                                // If we have a graphic as source object, use it's graphic
+                                // If we have a graphic as source object, use its graphic
                                 // content as fill style
                                 aSet.Put(XFillStyleItem(drawing::FillStyle_BITMAP));
-                                aSet.Put(XFillBitmapItem(&mrDoc.GetPool(), pSdrGrafObj->GetGraphic()));
+                                aSet.Put(XFillBitmapItem(pSdrGrafObj->GetGraphic()));
                             }
 
                             pPickObj->SetMergedItemSetAndBroadcast( aSet );
@@ -774,8 +790,8 @@ bool View::InsertData( const TransferableDataHelper& rDataHelper,
                             if( dynamic_cast< E3dObject *>( pPickObj ) !=  nullptr && dynamic_cast< E3dObject *>( pObj ) !=  nullptr )
                             {
                                 // handle 3D attribute in addition
-                                SfxItemSet aNewSet( mrDoc.GetPool(), SID_ATTR_3D_START, SID_ATTR_3D_END, 0 );
-                                SfxItemSet aOldSet( mrDoc.GetPool(), SID_ATTR_3D_START, SID_ATTR_3D_END, 0 );
+                                SfxItemSet aNewSet( mrDoc.GetPool(), svl::Items<SID_ATTR_3D_START, SID_ATTR_3D_END>{} );
+                                SfxItemSet aOldSet( mrDoc.GetPool(), svl::Items<SID_ATTR_3D_START, SID_ATTR_3D_END>{} );
 
                                 aOldSet.Put(pPickObj->GetMergedItemSet());
                                 aNewSet.Put( pObj->GetMergedItemSet() );
@@ -794,7 +810,7 @@ bool View::InsertData( const TransferableDataHelper& rDataHelper,
 
                 if( !bChanged )
                 {
-                    SdrPage* pWorkPage = pModel->GetSdPage( 0, PK_STANDARD );
+                    SdrPage* pWorkPage = pModel->GetSdPage( 0, PageKind::Standard );
 
                     pWorkPage->SetRectsDirty();
 
@@ -807,7 +823,7 @@ bool View::InsertData( const TransferableDataHelper& rDataHelper,
                         maDropPos.Y() = pOwnData->GetStartPos().Y() + ( aSize.Height() >> 1 );
                     }
 
-                    bReturn = Paste(*pModel, maDropPos, pPage, nPasteOptions, OUString(), OUString());
+                    bReturn = Paste(*pModel, maDropPos, pPage, nPasteOptions);
                 }
 
                 xShell->DoClose();
@@ -825,7 +841,7 @@ bool View::InsertData( const TransferableDataHelper& rDataHelper,
 
             if( pObj )
             {
-                Rectangle   aRect( pObj->GetLogicRect() );
+                ::tools::Rectangle   aRect( pObj->GetLogicRect() );
                 Size        aSize( aRect.GetSize() );
 
                 maDropPos.X() -= ( aSize.Width() >> 1 );
@@ -868,7 +884,7 @@ bool View::InsertData( const TransferableDataHelper& rDataHelper,
                 if( xDocShRef->DoLoad( pMedium ) )
                 {
                     SdDrawDocument* pModel = xDocShRef->GetDoc();
-                    SdPage*         pWorkPage = pModel->GetSdPage( 0, PK_STANDARD );
+                    SdPage*         pWorkPage = pModel->GetSdPage( 0, PageKind::Standard );
 
                     pWorkPage->SetRectsDirty();
 
@@ -886,11 +902,11 @@ bool View::InsertData( const TransferableDataHelper& rDataHelper,
                     {
                         SdPage* pP = static_cast< SdPage* >( pModel->GetPage( (sal_uInt16) i ) );
 
-                        if( pP->GetPageKind() != PK_STANDARD )
+                        if( pP->GetPageKind() != PageKind::Standard )
                             pModel->DeletePage( (sal_uInt16) i );
                     }
 
-                    bReturn = Paste(*pModel, maDropPos, pPage, nPasteOptions, OUString(), OUString());
+                    bReturn = Paste(*pModel, maDropPos, pPage, nPasteOptions);
 
                     if( !pPage )
                         pPage = static_cast<SdPage*>(GetSdrPageView()->GetPage());
@@ -903,7 +919,7 @@ bool View::InsertData( const TransferableDataHelper& rDataHelper,
                 }
 
                 xDocShRef->DoClose();
-                xDocShRef.Clear();
+                xDocShRef.clear();
 
             }
             else
@@ -933,7 +949,7 @@ bool View::InsertData( const TransferableDataHelper& rDataHelper,
                             aSize = aObjDesc.maSize;
                         else
                         {
-                            MapMode aMapMode( MAP_100TH_MM );
+                            MapMode aMapMode( MapUnit::Map100thMM );
                             aSize = aObjRef.GetSize( &aMapMode );
                         }
                     }
@@ -943,7 +959,7 @@ bool View::InsertData( const TransferableDataHelper& rDataHelper,
                         MapUnit aMapUnit = VCLUnoHelper::UnoEmbed2VCLMapUnit( xObj->getMapUnit( aObjDesc.mnViewAspect ) );
                         if( aObjDesc.maSize.Width() && aObjDesc.maSize.Height() )
                         {
-                            Size aTmp( OutputDevice::LogicToLogic( aObjDesc.maSize, MAP_100TH_MM, aMapUnit ) );
+                            Size aTmp(OutputDevice::LogicToLogic(aObjDesc.maSize, MapMode(MapUnit::Map100thMM), MapMode(aMapUnit)));
                             aSz.Width = aTmp.Width();
                             aSz.Height = aTmp.Height();
                             xObj->setVisualAreaSize( aObjDesc.mnViewAspect, aSz );
@@ -964,13 +980,13 @@ bool View::InsertData( const TransferableDataHelper& rDataHelper,
                         {
                             aSize.Width()  = 14100;
                             aSize.Height() = 10000;
-                            aSize = OutputDevice::LogicToLogic( Size(14100, 10000), MAP_100TH_MM, aMapUnit );
+                            aSize = OutputDevice::LogicToLogic(Size(14100, 10000), MapMode(MapUnit::Map100thMM), MapMode(aMapUnit));
                             aSz.Width = aSize.Width();
                             aSz.Height = aSize.Height();
                             xObj->setVisualAreaSize( aObjDesc.mnViewAspect, aSz );
                         }
 
-                        aSize = OutputDevice::LogicToLogic( aSize, aMapUnit, MAP_100TH_MM );
+                        aSize = OutputDevice::LogicToLogic(aSize, MapMode(aMapUnit), MapMode(MapUnit::Map100thMM));
                     }
 
                     Size aMaxSize( mrDoc.GetMaxObjSize() );
@@ -978,7 +994,7 @@ bool View::InsertData( const TransferableDataHelper& rDataHelper,
                     maDropPos.X() -= std::min( aSize.Width(), aMaxSize.Width() ) >> 1;
                     maDropPos.Y() -= std::min( aSize.Height(), aMaxSize.Height() ) >> 1;
 
-                    Rectangle       aRect( maDropPos, aSize );
+                    ::tools::Rectangle       aRect( maDropPos, aSize );
                     SdrOle2Obj*     pObj = new SdrOle2Obj( aObjRef, aName, aRect );
                     SdrPageView*    pPV = GetSdrPageView();
                     SdrInsertFlags  nOptions = SdrInsertFlags::SETDEFLAYER;
@@ -1006,12 +1022,12 @@ bool View::InsertData( const TransferableDataHelper& rDataHelper,
                              ( xProps->getPropertyValue( "DisableDataTableDialog" ) >>= bDisableDataTableDialog ) &&
                              bDisableDataTableDialog )
                         {
-                            xProps->setPropertyValue( "DisableDataTableDialog" , uno::makeAny( sal_False ) );
-                            xProps->setPropertyValue( "DisableComplexChartTypes" , uno::makeAny( sal_False ) );
+                            xProps->setPropertyValue( "DisableDataTableDialog" , uno::makeAny( false ) );
+                            xProps->setPropertyValue( "DisableComplexChartTypes" , uno::makeAny( false ) );
                             uno::Reference< util::XModifiable > xModifiable( xProps, uno::UNO_QUERY );
                             if ( xModifiable.is() )
                             {
-                                xModifiable->setModified( sal_True );
+                                xModifiable->setModified( true );
                             }
                         }
                     }
@@ -1077,8 +1093,8 @@ bool View::InsertData( const TransferableDataHelper& rDataHelper,
                     Graphic aGraphic;
                     SotClipboardFormatId nGrFormat = SotClipboardFormatId::NONE;
 
-// (wg. Selection Manager bei Trustet Solaris)
-#ifndef SOLARIS
+// (for Selection Manager in Trusted Solaris)
+#ifndef __sun
                     if( aDataHelper.GetGraphic( SotClipboardFormatId::SVXB, aGraphic ) )
                         nGrFormat = SotClipboardFormatId::SVXB;
                     else if( aDataHelper.GetGraphic( SotClipboardFormatId::GDIMETAFILE, aGraphic ) )
@@ -1102,7 +1118,7 @@ bool View::InsertData( const TransferableDataHelper& rDataHelper,
                             aSize = aObjDesc.maSize;
                         else
                         {
-                            MapMode aMapMode( MAP_100TH_MM );
+                            MapMode aMapMode( MapUnit::Map100thMM );
                             aSize = aObjRef.GetSize( &aMapMode );
                         }
                     }
@@ -1121,7 +1137,7 @@ bool View::InsertData( const TransferableDataHelper& rDataHelper,
 
                         if( aObjDesc.maSize.Width() && aObjDesc.maSize.Height() )
                         {
-                            Size aTmp( OutputDevice::LogicToLogic( aObjDesc.maSize, MAP_100TH_MM, aMapUnit ) );
+                            Size aTmp(OutputDevice::LogicToLogic(aObjDesc.maSize, MapMode(MapUnit::Map100thMM), MapMode(aMapUnit)));
                             if ( aSz.Width != aTmp.Width() || aSz.Height != aTmp.Height() )
                             {
                                 aSz.Width = aTmp.Width();
@@ -1134,13 +1150,13 @@ bool View::InsertData( const TransferableDataHelper& rDataHelper,
 
                         if( !aSize.Width() || !aSize.Height() )
                         {
-                            aSize = OutputDevice::LogicToLogic( Size(14100, 10000), MAP_100TH_MM, aMapUnit );
+                            aSize = OutputDevice::LogicToLogic(Size(14100, 10000), MapMode(MapUnit::Map100thMM), MapMode(aMapUnit));
                             aSz.Width = aSize.Width();
                             aSz.Height = aSize.Height();
                             xObj->setVisualAreaSize( aObjDesc.mnViewAspect, aSz );
                         }
 
-                        aSize = OutputDevice::LogicToLogic( aSize, aMapUnit, MAP_100TH_MM );
+                        aSize = OutputDevice::LogicToLogic(aSize, MapMode(aMapUnit), MapMode(MapUnit::Map100thMM));
                     }
 
                     Size aMaxSize( mrDoc.GetMaxObjSize() );
@@ -1148,7 +1164,7 @@ bool View::InsertData( const TransferableDataHelper& rDataHelper,
                     maDropPos.X() -= std::min( aSize.Width(), aMaxSize.Width() ) >> 1;
                     maDropPos.Y() -= std::min( aSize.Height(), aMaxSize.Height() ) >> 1;
 
-                    Rectangle       aRect( maDropPos, aSize );
+                    ::tools::Rectangle       aRect( maDropPos, aSize );
                     SdrOle2Obj*     pObj = new SdrOle2Obj( aObjRef, aName, aRect );
                     SdrPageView*    pPV = GetSdrPageView();
                     SdrInsertFlags  nOptions = SdrInsertFlags::SETDEFLAYER;
@@ -1197,7 +1213,7 @@ bool View::InsertData( const TransferableDataHelper& rDataHelper,
             {
                 const SdDrawDocument*   pWorkModel = pOwnData->GetWorkDocument();
                 SdrPage*                pWorkPage = const_cast<SdrPage*>( ( pWorkModel->GetPageCount() > 1 ) ?
-                                                    pWorkModel->GetSdPage( 0, PK_STANDARD ) :
+                                                    pWorkModel->GetSdPage( 0, PageKind::Standard ) :
                                                     pWorkModel->GetPage( 0 ) );
 
                 pWorkPage->SetRectsDirty();
@@ -1211,7 +1227,7 @@ bool View::InsertData( const TransferableDataHelper& rDataHelper,
 
             // restrict movement to WorkArea
             Size aImageMapSize = OutputDevice::LogicToLogic(aGraphic.GetPrefSize(),
-                aGraphic.GetPrefMapMode(), MapMode(MAP_100TH_MM));
+                aGraphic.GetPrefMapMode(), MapMode(MapUnit::Map100thMM));
 
             ImpCheckInsertPos(aInsertPos, aImageMapSize, GetWorkArea());
 
@@ -1229,7 +1245,7 @@ bool View::InsertData( const TransferableDataHelper& rDataHelper,
         {
             const SdDrawDocument*   pWorkModel = pOwnData->GetWorkDocument();
             SdrPage*                pWorkPage = const_cast<SdrPage*>( ( pWorkModel->GetPageCount() > 1 ) ?
-                                                pWorkModel->GetSdPage( 0, PK_STANDARD ) :
+                                                pWorkModel->GetSdPage( 0, PageKind::Standard ) :
                                                 pWorkModel->GetPage( 0 ) );
 
             pWorkPage->SetRectsDirty();
@@ -1278,7 +1294,7 @@ bool View::InsertData( const TransferableDataHelper& rDataHelper,
             {
                 const SdDrawDocument*   pWorkModel = pOwnData->GetWorkDocument();
                 SdrPage*                pWorkPage = const_cast<SdrPage*>( ( pWorkModel->GetPageCount() > 1 ) ?
-                                                    pWorkModel->GetSdPage( 0, PK_STANDARD ) :
+                                                    pWorkModel->GetSdPage( 0, PageKind::Standard ) :
                                                     pWorkModel->GetPage( 0 ) );
 
                 pWorkPage->SetRectsDirty();
@@ -1311,18 +1327,18 @@ bool View::InsertData( const TransferableDataHelper& rDataHelper,
 
             if( IsUndoEnabled() )
             {
-                BegUndo( SD_RESSTR(STR_UNDO_DRAGDROP) );
+                BegUndo( SdResId(STR_UNDO_DRAGDROP) );
                 AddUndo( GetModel()->GetSdrUndoFactory().CreateUndoAttrObject( *pPickObj ) );
                 EndUndo();
             }
 
             XFillAttrSetItem*   pSetItem = aFillData.GetXFillAttrSetItem();
             SfxItemSet          rSet = pSetItem->GetItemSet();
-            drawing::FillStyle eFill = static_cast<const XFillStyleItem&>( rSet.Get( XATTR_FILLSTYLE ) ).GetValue();
+            drawing::FillStyle eFill = rSet.Get( XATTR_FILLSTYLE ).GetValue();
 
             if( eFill == drawing::FillStyle_SOLID || eFill == drawing::FillStyle_NONE )
             {
-                const XFillColorItem&   rColItem = static_cast<const XFillColorItem&>( rSet.Get( XATTR_FILLCOLOR ) );
+                const XFillColorItem&   rColItem = rSet.Get( XATTR_FILLCOLOR );
                 Color                   aColor( rColItem.GetColorValue() );
                 OUString                aName( rColItem.GetName() );
                 SfxItemSet              aSet( mrDoc.GetPool() );
@@ -1335,7 +1351,7 @@ bool View::InsertData( const TransferableDataHelper& rDataHelper,
                 Point                   aHitPosL( rPos );
                 Point                   aHitPosT( rPos );
                 Point                   aHitPosB( rPos );
-                const SetOfByte*        pVisiLayer = &GetSdrPageView()->GetVisibleLayers();
+                const SdrLayerIDSet*        pVisiLayer = &GetSdrPageView()->GetVisibleLayers();
 
                 aHitPosR.X() += n2HitLog;
                 aHitPosL.X() -= n2HitLog;
@@ -1372,15 +1388,14 @@ bool View::InsertData( const TransferableDataHelper& rDataHelper,
         {
             xStm->Seek( 0 );
             // mba: clipboard always must contain absolute URLs (could be from alien source)
-            bReturn = SdrView::Paste( *xStm, OUString(), EE_FORMAT_HTML, maDropPos, pPage, nPasteOptions );
+            bReturn = SdrView::Paste( *xStm, EE_FORMAT_HTML, maDropPos, pPage, nPasteOptions );
         }
     }
 
-    if(!bReturn && !bLink && CHECK_FORMAT_TRANS(SotClipboardFormatId::EDITENGINE))
+    if(!bReturn && !bLink && CHECK_FORMAT_TRANS(SotClipboardFormatId::EDITENGINE_ODF_TEXT_FLAT))
     {
         ::tools::SvRef<SotStorageStream> xStm;
-
-        if( aDataHelper.GetSotStorageStream( SotClipboardFormatId::EDITENGINE, xStm ) )
+        if( aDataHelper.GetSotStorageStream( SotClipboardFormatId::EDITENGINE_ODF_TEXT_FLAT, xStm ) )
         {
             OutlinerView* pOLV = GetTextEditOutlinerView();
 
@@ -1388,28 +1403,29 @@ bool View::InsertData( const TransferableDataHelper& rDataHelper,
 
             if( pOLV )
             {
-                Rectangle   aRect( pOLV->GetOutputArea() );
-                   Point       aPos( pOLV->GetWindow()->PixelToLogic( maDropPos ) );
+                ::tools::Rectangle   aRect( pOLV->GetOutputArea() );
+                Point       aPos( pOLV->GetWindow()->PixelToLogic( maDropPos ) );
 
                 if( aRect.IsInside( aPos ) || ( !bDrag && IsTextEdit() ) )
                 {
                     // mba: clipboard always must contain absolute URLs (could be from alien source)
-                    pOLV->Read( *xStm, OUString(), EE_FORMAT_BIN, false, mpDocSh->GetHeaderAttributes() );
+                    pOLV->Read( *xStm, EE_FORMAT_XML, mpDocSh->GetHeaderAttributes() );
                     bReturn = true;
                 }
             }
 
             if( !bReturn )
                 // mba: clipboard always must contain absolute URLs (could be from alien source)
-                bReturn = SdrView::Paste( *xStm, OUString(), EE_FORMAT_BIN, maDropPos, pPage, nPasteOptions );
+                bReturn = SdrView::Paste( *xStm, EE_FORMAT_XML, maDropPos, pPage, nPasteOptions );
         }
     }
 
-    if(!bReturn && !bLink && CHECK_FORMAT_TRANS(SotClipboardFormatId::RTF))
+    bool bIsRTF = false;
+    if(!bReturn && !bLink && (( bIsRTF = CHECK_FORMAT_TRANS(SotClipboardFormatId::RTF) ) || CHECK_FORMAT_TRANS(SotClipboardFormatId::RICHTEXT) ))
     {
         ::tools::SvRef<SotStorageStream> xStm;
 
-        if( aDataHelper.GetSotStorageStream( SotClipboardFormatId::RTF, xStm ) )
+        if( aDataHelper.GetSotStorageStream( bIsRTF ? SotClipboardFormatId::RTF : SotClipboardFormatId::RICHTEXT, xStm ) )
         {
             xStm->Seek( 0 );
 
@@ -1423,20 +1439,20 @@ bool View::InsertData( const TransferableDataHelper& rDataHelper,
 
                 if( pOLV )
                 {
-                    Rectangle   aRect( pOLV->GetOutputArea() );
+                    ::tools::Rectangle   aRect( pOLV->GetOutputArea() );
                        Point       aPos( pOLV->GetWindow()->PixelToLogic( maDropPos ) );
 
                     if( aRect.IsInside( aPos ) || ( !bDrag && IsTextEdit() ) )
                     {
                         // mba: clipboard always must contain absolute URLs (could be from alien source)
-                        pOLV->Read( *xStm, OUString(), EE_FORMAT_RTF, false, mpDocSh->GetHeaderAttributes() );
+                        pOLV->Read( *xStm, EE_FORMAT_RTF, mpDocSh->GetHeaderAttributes() );
                         bReturn = true;
                     }
                 }
 
                 if( !bReturn )
                     // mba: clipboard always must contain absolute URLs (could be from alien source)
-                    bReturn = SdrView::Paste( *xStm, OUString(), EE_FORMAT_RTF, maDropPos, pPage, nPasteOptions );
+                    bReturn = SdrView::Paste( *xStm, EE_FORMAT_RTF, maDropPos, pPage, nPasteOptions );
             }
         }
     }
@@ -1504,18 +1520,18 @@ bool View::InsertData( const TransferableDataHelper& rDataHelper,
     return bReturn;
 }
 
-bool View::PasteRTFTable( ::tools::SvRef<SotStorageStream> xStm, SdrPage* pPage, SdrInsertFlags nPasteOptions )
+bool View::PasteRTFTable( const ::tools::SvRef<SotStorageStream>& xStm, SdrPage* pPage, SdrInsertFlags nPasteOptions )
 {
-    std::unique_ptr<SdDrawDocument> pModel(new SdDrawDocument( DOCUMENT_TYPE_IMPRESS, mpDocSh ));
+    std::unique_ptr<SdDrawDocument> pModel(new SdDrawDocument( DocumentType::Impress, mpDocSh ));
     pModel->NewOrLoadCompleted(NEW_DOC);
-    pModel->GetItemPool().SetDefaultMetric(SFX_MAPUNIT_100TH_MM);
+    pModel->GetItemPool().SetDefaultMetric(MapUnit::Map100thMM);
     pModel->InsertPage(pModel->AllocPage(false));
 
     Reference< XComponent > xComponent( new SdXImpressDocument( pModel.get(), true ) );
     pModel->setUnoModel( Reference< XInterface >::query( xComponent ) );
 
     CreateTableFromRTF( *xStm, pModel.get() );
-    bool bRet = Paste(*pModel, maDropPos, pPage, nPasteOptions, OUString(), OUString());
+    bool bRet = Paste(*pModel, maDropPos, pPage, nPasteOptions);
 
     xComponent->dispose();
     xComponent.clear();
