@@ -21,7 +21,6 @@
 #include "graphiccollector.hxx"
 #include <com/sun/star/awt/XDevice.hpp>
 #include <com/sun/star/frame/Desktop.hpp>
-#include <com/sun/star/frame/XFramesSupplier.hpp>
 #include <com/sun/star/drawing/FillStyle.hpp>
 #include <com/sun/star/drawing/BitmapMode.hpp>
 #include <com/sun/star/drawing/XDrawPagesSupplier.hpp>
@@ -88,7 +87,7 @@ void ImpAddEntity( std::vector< GraphicCollector::GraphicEntity >& rGraphicEntit
     }
 }
 
-void ImpAddGraphicEntity( const Reference< XComponentContext >& rxMSF, Reference< XShape >& rxShape, const GraphicSettings& rGraphicSettings, std::vector< GraphicCollector::GraphicEntity >& rGraphicEntities )
+void ImpAddGraphicEntity( const Reference< XComponentContext >& rxMSF, Reference< XShape > const & rxShape, const GraphicSettings& rGraphicSettings, std::vector< GraphicCollector::GraphicEntity >& rGraphicEntities )
 {
     Reference< XGraphic > xGraphic;
     Reference< XPropertySet > xShapePropertySet( rxShape, UNO_QUERY_THROW );
@@ -100,7 +99,6 @@ void ImpAddGraphicEntity( const Reference< XComponentContext >& rxMSF, Reference
         aUser.mxShape = rxShape;
         aUser.mbFillBitmap = false;
         xShapePropertySet->getPropertyValue( "GraphicURL" ) >>= aUser.maGraphicURL;
-        xShapePropertySet->getPropertyValue( "GraphicStreamURL" ) >>= aUser.maGraphicStreamURL;
         xShapePropertySet->getPropertyValue( "GraphicCrop" ) >>= aGraphicCropLogic;
         awt::Size aLogicalSize( rxShape->getSize() );
 
@@ -356,7 +354,6 @@ void ImpCountGraphicObjects( const Reference< XComponentContext >& rxMSF, const
             }
 
             // now check for a fillstyle
-            Reference< XPropertySet > xEmptyPagePropSet;
             Reference< XPropertySet > xShapePropertySet( xShape, UNO_QUERY_THROW );
             FillStyle eFillStyle;
             if ( xShapePropertySet->getPropertyValue( "FillStyle" ) >>= eFillStyle )
