@@ -22,7 +22,7 @@
 #pragma warning(push, 1)
 #endif
 
-#include "pdfparse.hxx"
+#include <pdfparse.hxx>
 
 // workaround windows compiler: do not include multi_pass.hpp
 #include <boost/spirit/include/classic_core.hpp>
@@ -49,7 +49,7 @@ class StringEmitContext : public EmitContext
     OStringBuffer m_aBuf;
     public:
     StringEmitContext() : EmitContext(), m_aBuf(256) {}
-    virtual ~StringEmitContext() {}
+
     virtual bool write( const void* pBuf, unsigned int nLen ) throw() override
     {
         m_aBuf.append( static_cast<const sal_Char*>(pBuf), nLen );
@@ -243,7 +243,7 @@ public:
                                 >> uint_p[boost::bind(&PDFGrammar::push_back_action_uint, pSelf, _1)]
                                 >> ch_p('.')
                                 >> uint_p[boost::bind(&PDFGrammar::push_back_action_uint, pSelf, _1)]
-                                >> *((~ch_p('\r') & ~ch_p('\n')))
+                                >> *(~ch_p('\r') & ~ch_p('\n'))
                                 >> eol_p
                              ])[boost::bind(&PDFGrammar::haveFile,pSelf, _1, _2)]
                           >> *( comment | object | ( xref >> trailer ) );
@@ -309,7 +309,7 @@ public:
         PDFContainer* pContainer = dynamic_cast<PDFContainer*>(m_aObjectStack.back());
         if( pContainer == nullptr )
             parseError( "comment without container", first );
-        pContainer->m_aSubElements.push_back( pComment );
+        pContainer->m_aSubElements.emplace_back( pComment );
     }
 
     void insertNewValue( PDFEntry* pNewValue, iteratorT pPos )
@@ -351,7 +351,7 @@ public:
             }
         }
         if( pContainer )
-            pContainer->m_aSubElements.push_back( pNewValue );
+            pContainer->m_aSubElements.emplace_back( pNewValue );
         else
         {
             if( ! pMsg )
@@ -410,7 +410,7 @@ public:
             ( dynamic_cast<PDFFile*>(pContainer) ||
               dynamic_cast<PDFPart*>(pContainer) ) )
         {
-            pContainer->m_aSubElements.push_back( pObj );
+            pContainer->m_aSubElements.emplace_back( pObj );
             m_aObjectStack.push_back( pObj );
         }
         else
@@ -502,7 +502,7 @@ public:
                 PDFStream* pStream = new PDFStream( first - m_aGlobalBegin, last - m_aGlobalBegin, pDict );
 
                 pObj->m_pStream = pStream;
-                pObj->m_aSubElements.push_back( pStream );
+                pObj->m_aSubElements.emplace_back( pStream );
             }
         }
         else
@@ -522,7 +522,7 @@ public:
             ( dynamic_cast<PDFFile*>(pContainer) ||
               dynamic_cast<PDFPart*>(pContainer) ) )
         {
-            pContainer->m_aSubElements.push_back( pTrailer );
+            pContainer->m_aSubElements.emplace_back( pTrailer );
             m_aObjectStack.push_back( pTrailer );
         }
         else
@@ -540,27 +540,27 @@ public:
     }
 };
 
-#ifdef WIN32
+#ifdef _WIN32
 PDFEntry* PDFReader::read( const char* pBuffer, unsigned int nLen )
 {
     PDFGrammar<const char*> aGrammar( pBuffer );
 
     try
     {
-#if OSL_DEBUG_LEVEL > 1
+#if OSL_DEBUG_LEVEL > 0
         boost::spirit::parse_info<const char*> aInfo =
 #endif
             boost::spirit::parse( pBuffer,
                                   pBuffer+nLen,
                                   aGrammar,
                                   boost::spirit::space_p );
-#if OSL_DEBUG_LEVEL > 1
+#if OSL_DEBUG_LEVEL > 0
         SAL_INFO("sdext.pdfimport.pdfparse", "parseinfo: stop = " << aInfo.stop << " (buff=" << pBuffer << ", offset = " << aInfo.stop - pBuffer << "), hit = " << (aInfo.hit ? OUString("true") : OUString("false")) << ", full = " << (aInfo.full ? OUString("true") : OUString("false")) << ", length = " << (int)aInfo.length );
 #endif
     }
     catch( const parser_error<const char*, const char*>& rError )
     {
-#if OSL_DEBUG_LEVEL > 1
+#if OSL_DEBUG_LEVEL > 0
         OString aTmp;
         unsigned int nElem = aGrammar.m_aObjectStack.size();
         for( unsigned int i = 0; i < nElem; i++ )
@@ -570,14 +570,14 @@ PDFEntry* PDFReader::read( const char* pBuffer, unsigned int nLen )
 #endif
     }
 
-    PDFEntry* pRet = NULL;
+    PDFEntry* pRet = nullptr;
     unsigned int nEntries = aGrammar.m_aObjectStack.size();
     if( nEntries == 1 )
     {
         pRet = aGrammar.m_aObjectStack.back();
         aGrammar.m_aObjectStack.pop_back();
     }
-#if OSL_DEBUG_LEVEL > 1
+#if OSL_DEBUG_LEVEL > 0
     else if( nEntries > 1 )
         SAL_WARN("sdext.pdfimport.pdfparse", "error got " << nEntries << " stack objects in parse" );
 #endif
@@ -588,7 +588,7 @@ PDFEntry* PDFReader::read( const char* pBuffer, unsigned int nLen )
 
 PDFEntry* PDFReader::read( const char* pFileName )
 {
-#ifdef WIN32
+#ifdef _WIN32
     /* #i106583#
        since converting to boost 1.39 file_iterator does not work anymore on all Windows systems
        C++ stdlib istream_iterator does not allow "-" apparently
@@ -597,14 +597,14 @@ PDFEntry* PDFReader::read( const char* pFileName )
        So for the time being bite the bullet and read the whole file.
        FIXME: give Spirit 2.x another try when we upgrade boost again.
     */
-    PDFEntry* pRet = NULL;
+    PDFEntry* pRet = nullptr;
     FILE* fp = fopen( pFileName, "rb" );
     if( fp )
     {
         fseek( fp, 0, SEEK_END );
         unsigned int nLen = (unsigned int)ftell( fp );
         fseek( fp, 0, SEEK_SET );
-        char* pBuf = (char*)rtl_allocateMemory( nLen );
+        char* pBuf = static_cast<char*>(rtl_allocateMemory( nLen ));
         if( pBuf )
         {
             fread( pBuf, 1, nLen, fp );
@@ -623,21 +623,21 @@ PDFEntry* PDFReader::read( const char* pFileName )
 
     try
     {
-#if OSL_DEBUG_LEVEL > 1
+#if OSL_DEBUG_LEVEL > 0
         boost::spirit::parse_info< file_iterator<> > aInfo =
 #endif
             boost::spirit::parse( file_start,
                                   file_end,
                                   aGrammar,
                                   boost::spirit::space_p );
-#if OSL_DEBUG_LEVEL > 1
+#if OSL_DEBUG_LEVEL > 0
         SAL_INFO("sdext.pdfimport.pdfparse", "parseinfo: stop at offset = " << aInfo.stop - file_start << ", hit = " << (aInfo.hit ? "true" : "false") << ", full = " << (aInfo.full ? "true" : "false") << ", length = " << aInfo.length);
 #endif
     }
     catch( const parser_error< const char*, file_iterator<> >& rError )
     {
         SAL_WARN("sdext.pdfimport.pdfparse", "parse error: " << rError.descriptor << " at buffer pos " << rError.where - file_start);
-#if OSL_DEBUG_LEVEL > 1
+#if OSL_DEBUG_LEVEL > 0
         OUString aTmp;
         unsigned int nElem = aGrammar.m_aObjectStack.size();
         for( unsigned int i = 0; i < nElem; i++ )
@@ -658,7 +658,7 @@ PDFEntry* PDFReader::read( const char* pFileName )
         pRet = aGrammar.m_aObjectStack.back();
         aGrammar.m_aObjectStack.pop_back();
     }
-#if OSL_DEBUG_LEVEL > 1
+#if OSL_DEBUG_LEVEL > 0
     else if( nEntries > 1 )
     {
         SAL_WARN("sdext.pdfimport.pdfparse", "error got " << nEntries << " stack objects in parse");
