@@ -18,9 +18,9 @@
  */
 
 
-#include "imagecontainer.hxx"
-#include "genericelements.hxx"
-#include "xmlemitter.hxx"
+#include <imagecontainer.hxx>
+#include <genericelements.hxx>
+#include <xmlemitter.hxx>
 
 #include <rtl/ustrbuf.hxx>
 #include <osl/diagnose.h>
@@ -30,10 +30,6 @@
 #include <com/sun/star/graphic/XGraphicProvider.hpp>
 #include <com/sun/star/beans/PropertyValue.hpp>
 
-#include <comphelper/stl_types.hxx>
-
-#include <boost/bind.hpp>
-
 using namespace com::sun::star;
 
 namespace pdfi
@@ -126,16 +122,23 @@ void ImageContainer::writeBase64EncodedStream( ImageId nId, EmitContext& rContex
     const beans::PropertyValue* pAry(rEntry.getConstArray());
     const sal_Int32             nLen(rEntry.getLength());
     const beans::PropertyValue* pValue(
-        std::find_if(pAry,pAry+nLen,
-                     boost::bind(comphelper::TPropertyValueEqualFunctor(),
-                                 _1,
-                                 OUString("InputSequence"))));
-    OSL_ENSURE( pValue != pAry+nLen,
-                "InputSequence not found" );
+        std::find_if(pAry, pAry+nLen,
+            [] (beans::PropertyValue const& v) -> bool {
+                return v.Name == "InputSequence";
+            }));
+
+    if (pValue == pAry + nLen )
+    {
+        SAL_WARN("sdext.pdfimport", "InputSequence not found");
+        return;
+    }
 
     uno::Sequence<sal_Int8> aData;
     if( !(pValue->Value >>= aData) )
-        OSL_FAIL("Wrong data type");
+    {
+        SAL_WARN("sdext.pdfimport", "Wrong data type");
+        return;
+    }
 
     rContext.rEmitter.write( encodeBase64( aData.getConstArray(), aData.getLength() ));
 }
