@@ -17,7 +17,7 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "vcl/svapp.hxx"
+#include <vcl/svapp.hxx>
 #include "PresenterPaneBorderPainter.hxx"
 #include "PresenterCanvasHelper.hxx"
 #include "PresenterConfigurationAccess.hxx"
@@ -81,7 +81,6 @@ namespace {
         SharedBitmapDescriptor mpBottom;
         SharedBitmapDescriptor mpBottomRight;
         SharedBitmapDescriptor mpBottomCallout;
-        SharedBitmapDescriptor mpBackground;
         SharedBitmapDescriptor mpEmpty;
         PresenterTheme::SharedFontDescriptor mpFont;
         sal_Int32 mnFontXOffset;
@@ -107,7 +106,6 @@ public:
     Renderer (
         const Reference<XComponentContext>& rxContext,
         const std::shared_ptr<PresenterTheme>& rpTheme);
-    ~Renderer();
 
     void SetCanvas (const Reference<rendering::XCanvas>& rxCanvas);
     void PaintBorder (
@@ -120,8 +118,7 @@ public:
         const std::shared_ptr<RendererPaneStyle>& rpStyle,
         const awt::Rectangle& rUpdateBox,
         const awt::Rectangle& rOuterBox,
-        const awt::Rectangle& rInnerBox,
-        const bool bPaintBackground);
+        const awt::Rectangle& rInnerBox);
     void SetupClipping (
         const awt::Rectangle& rUpdateBox,
         const awt::Rectangle& rOuterBox,
@@ -149,8 +146,7 @@ private:
         const sal_Int32 nStartOffset,
         const sal_Int32 nEndOffset,
         const bool bExpand,
-        const SharedBitmapDescriptor& rpBitmap,
-        const SharedBitmapDescriptor& rpBackgroundBitmap);
+        const SharedBitmapDescriptor& rpBitmap);
 };
 
 // ===== PresenterPaneBorderPainter ===========================================
@@ -174,7 +170,6 @@ awt::Rectangle SAL_CALL PresenterPaneBorderPainter::addBorder (
     const OUString& rsPaneBorderStyleName,
     const css::awt::Rectangle& rRectangle,
     drawing::framework::BorderType eBorderType)
-    throw(css::uno::RuntimeException, std::exception)
 {
     ThrowIfDisposed();
 
@@ -187,7 +182,6 @@ awt::Rectangle SAL_CALL PresenterPaneBorderPainter::removeBorder (
     const OUString& rsPaneBorderStyleName,
     const css::awt::Rectangle& rRectangle,
     drawing::framework::BorderType eBorderType)
-    throw(css::uno::RuntimeException, std::exception)
 {
     ThrowIfDisposed();
 
@@ -202,7 +196,6 @@ void SAL_CALL PresenterPaneBorderPainter::paintBorder (
     const css::awt::Rectangle& rOuterBorderRectangle,
     const css::awt::Rectangle& rRepaintArea,
     const OUString& rsTitle)
-    throw(css::uno::RuntimeException, std::exception)
 {
     ThrowIfDisposed();
 
@@ -238,7 +231,6 @@ void SAL_CALL PresenterPaneBorderPainter::paintBorderWithCallout (
     const css::awt::Rectangle& rRepaintArea,
     const OUString& rsTitle,
     const css::awt::Point& rCalloutAnchor)
-    throw(css::uno::RuntimeException, std::exception)
 {
     ThrowIfDisposed();
 
@@ -270,7 +262,6 @@ void SAL_CALL PresenterPaneBorderPainter::paintBorderWithCallout (
 
 awt::Point SAL_CALL PresenterPaneBorderPainter::getCalloutOffset (
     const OUString& rsPaneBorderStyleName)
-    throw(css::uno::RuntimeException, std::exception)
 {
     ThrowIfDisposed();
     ProvideTheme();
@@ -292,7 +283,6 @@ awt::Point SAL_CALL PresenterPaneBorderPainter::getCalloutOffset (
 }
 
 
-
 bool PresenterPaneBorderPainter::ProvideTheme (const Reference<rendering::XCanvas>& rxCanvas)
 {
     bool bModified (false);
@@ -311,7 +301,7 @@ bool PresenterPaneBorderPainter::ProvideTheme (const Reference<rendering::XCanva
     }
     else
     {
-        mpTheme.reset(new PresenterTheme(mxContext, OUString(), rxCanvas));
+        mpTheme.reset(new PresenterTheme(mxContext, rxCanvas));
         bModified = true;
     }
 
@@ -326,19 +316,15 @@ bool PresenterPaneBorderPainter::ProvideTheme (const Reference<rendering::XCanva
     return bModified;
 }
 
-bool PresenterPaneBorderPainter::ProvideTheme()
+void PresenterPaneBorderPainter::ProvideTheme()
 {
     if (mpTheme.get() == nullptr)
     {
         // Create a theme without bitmaps (no canvas => no bitmaps).
-        return ProvideTheme(nullptr);
+        ProvideTheme(nullptr);
     }
-    else
-    {
         // When there already is a theme then without a canvas we can not
         // add anything new.
-        return false;
-    }
 }
 
 void PresenterPaneBorderPainter::SetTheme (const std::shared_ptr<PresenterTheme>& rpTheme)
@@ -377,13 +363,11 @@ awt::Rectangle PresenterPaneBorderPainter::RemoveBorder (
 }
 
 void PresenterPaneBorderPainter::ThrowIfDisposed() const
-    throw (css::lang::DisposedException)
 {
     if (rBHelper.bDisposed || rBHelper.bInDispose)
     {
         throw lang::DisposedException (
-            OUString(
-                "PresenterPaneBorderPainter object has already been disposed"),
+            "PresenterPaneBorderPainter object has already been disposed",
             const_cast<uno::XWeak*>(static_cast<const uno::XWeak*>(this)));
     }
 }
@@ -402,8 +386,6 @@ PresenterPaneBorderPainter::Renderer::Renderer (
       mbHasCallout(false),
       maCalloutAnchor()
 {
-    (void)rxContext;
-
     Reference<lang::XMultiComponentFactory> xFactory (rxContext->getServiceManager());
     if (xFactory.is())
     {
@@ -415,10 +397,6 @@ PresenterPaneBorderPainter::Renderer::Renderer (
     }
 }
 
-PresenterPaneBorderPainter::Renderer::~Renderer()
-{
-}
-
 void PresenterPaneBorderPainter::Renderer::SetCanvas (const Reference<rendering::XCanvas>& rxCanvas)
 {
     if (mxCanvas != rxCanvas)
@@ -456,15 +434,14 @@ void PresenterPaneBorderPainter::Renderer::PaintBorder (
     SharedBitmapDescriptor pBottomLeft (pStyle->mpBottomLeft);
     SharedBitmapDescriptor pBottomRight (pStyle->mpBottomRight);
     SharedBitmapDescriptor pBottom (pStyle->mpBottom);
-    SharedBitmapDescriptor pBackground (pStyle->mpBackground);
 
     // Paint the sides.
     PaintBitmap(aCenterBox, rUpdateBox, 0,-1,
-        pTopLeft->mnXOffset, pTopRight->mnXOffset, true, pTop, pBackground);
+        pTopLeft->mnXOffset, pTopRight->mnXOffset, true, pTop);
     PaintBitmap(aCenterBox, rUpdateBox, -1,0,
-        pTopLeft->mnYOffset, pBottomLeft->mnYOffset, true, pLeft, pBackground);
+        pTopLeft->mnYOffset, pBottomLeft->mnYOffset, true, pLeft);
     PaintBitmap(aCenterBox, rUpdateBox, +1,0,
-        pTopRight->mnYOffset, pBottomRight->mnYOffset, true, pRight, pBackground);
+        pTopRight->mnYOffset, pBottomRight->mnYOffset, true, pRight);
     if (mbHasCallout && pStyle->mpBottomCallout->GetNormalBitmap().is())
     {
         const sal_Int32 nCalloutWidth (pStyle->mpBottomCallout->mnWidth);
@@ -475,33 +452,33 @@ void PresenterPaneBorderPainter::Renderer::PaintBorder (
         if (nCalloutX > pBottomRight->mnXOffset + aCenterBox.X + aCenterBox.Width)
             nCalloutX = pBottomRight->mnXOffset + aCenterBox.X + aCenterBox.Width;
         // Paint bottom callout.
-        PaintBitmap(aCenterBox, rUpdateBox, 0,+1, nCalloutX,0, false, pStyle->mpBottomCallout, pBackground);
+        PaintBitmap(aCenterBox, rUpdateBox, 0,+1, nCalloutX,0, false, pStyle->mpBottomCallout);
         // Paint regular bottom bitmap left and right.
         PaintBitmap(aCenterBox, rUpdateBox, 0,+1,
-            pBottomLeft->mnXOffset, nCalloutX-aCenterBox.Width, true, pBottom, pBackground);
+            pBottomLeft->mnXOffset, nCalloutX-aCenterBox.Width, true, pBottom);
         PaintBitmap(aCenterBox, rUpdateBox, 0,+1,
-            nCalloutX+nCalloutWidth, pBottomRight->mnXOffset, true, pBottom, pBackground);
+            nCalloutX+nCalloutWidth, pBottomRight->mnXOffset, true, pBottom);
     }
     else
     {
         // Stretch the bottom bitmap over the full width.
         PaintBitmap(aCenterBox, rUpdateBox, 0,+1,
-            pBottomLeft->mnXOffset, pBottomRight->mnXOffset, true, pBottom, pBackground);
+            pBottomLeft->mnXOffset, pBottomRight->mnXOffset, true, pBottom);
     }
 
     // Paint the corners.
-    PaintBitmap(aCenterBox, rUpdateBox, -1,-1, 0,0, false, pTopLeft, pBackground);
-    PaintBitmap(aCenterBox, rUpdateBox, +1,-1, 0,0, false, pTopRight, pBackground);
-    PaintBitmap(aCenterBox, rUpdateBox, -1,+1, 0,0, false, pBottomLeft, pBackground);
-    PaintBitmap(aCenterBox, rUpdateBox, +1,+1, 0,0, false, pBottomRight, pBackground);
+    PaintBitmap(aCenterBox, rUpdateBox, -1,-1, 0,0, false, pTopLeft);
+    PaintBitmap(aCenterBox, rUpdateBox, +1,-1, 0,0, false, pTopRight);
+    PaintBitmap(aCenterBox, rUpdateBox, -1,+1, 0,0, false, pBottomLeft);
+    PaintBitmap(aCenterBox, rUpdateBox, +1,+1, 0,0, false, pBottomRight);
 
     // Paint the title.
-    PaintTitle(rsTitle, pStyle, rUpdateBox, aOuterBox, aInnerBox, false);
+    PaintTitle(rsTitle, pStyle, rUpdateBox, aOuterBox, aInnerBox);
 
     // In a double buffering environment request to make the changes visible.
     Reference<rendering::XSpriteCanvas> xSpriteCanvas (mxCanvas, UNO_QUERY);
     if (xSpriteCanvas.is())
-        xSpriteCanvas->updateScreen(sal_False);
+        xSpriteCanvas->updateScreen(false);
 }
 
 void PresenterPaneBorderPainter::Renderer::PaintTitle (
@@ -509,8 +486,7 @@ void PresenterPaneBorderPainter::Renderer::PaintTitle (
     const std::shared_ptr<RendererPaneStyle>& rpStyle,
     const awt::Rectangle& rUpdateBox,
     const awt::Rectangle& rOuterBox,
-    const awt::Rectangle& rInnerBox,
-    bool bPaintBackground)
+    const awt::Rectangle& rInnerBox)
 {
     if ( ! mxCanvas.is())
         return;
@@ -571,35 +547,14 @@ void PresenterPaneBorderPainter::Renderer::PaintTitle (
         Sequence<double>(4),
         rendering::CompositeOperation::SOURCE);
 
-    if (bPaintBackground)
-    {
-        PresenterCanvasHelper::SetDeviceColor(aRenderState, util::Color(0x00ffffff));
-        Sequence<Sequence<geometry::RealPoint2D> > aPolygons(1);
-        aPolygons[0] = Sequence<geometry::RealPoint2D>(4);
-        aPolygons[0][0] = geometry::RealPoint2D(0, -nTextHeight);
-        aPolygons[0][1] = geometry::RealPoint2D(0, 0);
-        aPolygons[0][2] = geometry::RealPoint2D(nTextWidth, 0);
-        aPolygons[0][3] = geometry::RealPoint2D(nTextWidth, -nTextHeight);
-        Reference<rendering::XPolyPolygon2D> xPolygon (
-        mxCanvas->getDevice()->createCompatibleLinePolyPolygon(aPolygons), UNO_QUERY);
-        if (xPolygon.is())
-            xPolygon->setClosed(0, sal_True);
-        mxCanvas->fillPolyPolygon(
-            xPolygon,
-            maViewState,
-            aRenderState);
-    }
-    else
-    {
-        PresenterCanvasHelper::SetDeviceColor(
+    PresenterCanvasHelper::SetDeviceColor(
             aRenderState,
             rpStyle->mpFont->mnColor);
 
-        mxCanvas->drawTextLayout (
+    mxCanvas->drawTextLayout (
             xLayout,
             maViewState,
             aRenderState);
-    }
 }
 
 std::shared_ptr<RendererPaneStyle>
@@ -620,8 +575,7 @@ std::shared_ptr<RendererPaneStyle>
         // Create a new pane style object and initialize it with bitmaps.
         std::shared_ptr<RendererPaneStyle> pStyle (
             new RendererPaneStyle(mpTheme,sPaneStyleName));
-        iStyle = maRendererPaneStyles.insert(
-            RendererPaneStyleContainer::value_type(rsResourceURL, pStyle)).first;
+        iStyle = maRendererPaneStyles.emplace(rsResourceURL, pStyle).first;
     }
     if (iStyle != maRendererPaneStyles.end())
         return iStyle->second;
@@ -644,11 +598,8 @@ void PresenterPaneBorderPainter::Renderer::PaintBitmap(
     const sal_Int32 nStartOffset,
     const sal_Int32 nEndOffset,
     const bool bExpand,
-    const SharedBitmapDescriptor& rpBitmap,
-    const SharedBitmapDescriptor& rpBackgroundBitmap)
+    const SharedBitmapDescriptor& rpBitmap)
 {
-    (void)rpBackgroundBitmap;
-
     bool bUseCanvas (mxCanvas.is());
     if ( ! bUseCanvas)
         return;
@@ -805,7 +756,6 @@ RendererPaneStyle::RendererPaneStyle (
       mpBottom(),
       mpBottomRight(),
       mpBottomCallout(),
-      mpBackground(),
       mpEmpty(new PresenterBitmapDescriptor()),
       mpFont(),
       mnFontXOffset(0),
@@ -826,7 +776,6 @@ RendererPaneStyle::RendererPaneStyle (
         mpBottom = GetBitmap(rpTheme, rsStyleName, "Bottom");
         mpBottomRight = GetBitmap(rpTheme, rsStyleName, "BottomRight");
         mpBottomCallout = GetBitmap(rpTheme, rsStyleName, "BottomCallout");
-        mpBackground = GetBitmap(rpTheme, OUString(), "Background");
 
         // Get font description.
         mpFont = rpTheme->GetFont(rsStyleName);
