@@ -31,9 +31,9 @@
 #include <com/sun/star/rendering/CompositeOperation.hpp>
 #include <com/sun/star/rendering/TexturingMode.hpp>
 #include <com/sun/star/rendering/XPolyPolygon2D.hpp>
-#include <boost/bind.hpp>
-#include <boost/enable_shared_from_this.hpp>
-#include <boost/weak_ptr.hpp>
+
+#include <algorithm>
+#include <memory>
 #include <math.h>
 
 using namespace ::com::sun::star;
@@ -46,18 +46,18 @@ namespace sdext { namespace presenter {
 //===== PresenterScrollBar::MousePressRepeater ================================
 
 class PresenterScrollBar::MousePressRepeater
-    : public ::boost::enable_shared_from_this<MousePressRepeater>
+    : public std::enable_shared_from_this<MousePressRepeater>
 {
 public:
-    MousePressRepeater (const ::rtl::Reference<PresenterScrollBar>& rpScrollBar);
-    void Dispose (void);
+    explicit MousePressRepeater (const ::rtl::Reference<PresenterScrollBar>& rpScrollBar);
+    void Dispose();
     void Start (const PresenterScrollBar::Area& reArea);
-    void Stop (void);
+    void Stop();
     void SetMouseArea (const PresenterScrollBar::Area& reArea);
 
 private:
-    void Callback (const TimeValue& rCurrentTime);
-    void Execute (void);
+    void Callback ();
+    void Execute();
 
     sal_Int32 mnMousePressRepeaterTaskId;
     ::rtl::Reference<PresenterScrollBar> mpScrollBar;
@@ -66,16 +66,15 @@ private:
 
 //===== PresenterScrollBar ====================================================
 
-boost::weak_ptr<PresenterBitmapContainer> PresenterScrollBar::mpSharedBitmaps;
+std::weak_ptr<PresenterBitmapContainer> PresenterScrollBar::mpSharedBitmaps;
 
 PresenterScrollBar::PresenterScrollBar (
     const Reference<XComponentContext>& rxComponentContext,
     const Reference<awt::XWindow>& rxParentWindow,
-    const ::boost::shared_ptr<PresenterPaintManager>& rpPaintManager,
-    const ::boost::function<void(double)>& rThumbMotionListener)
+    const std::shared_ptr<PresenterPaintManager>& rpPaintManager,
+    const ::std::function<void (double)>& rThumbMotionListener)
     : PresenterScrollBarInterfaceBase(m_aMutex),
       mxComponentContext(rxComponentContext),
-      mxParentWindow(rxParentWindow),
       mxWindow(),
       mxCanvas(),
       mxPresenterHelper(),
@@ -108,18 +107,18 @@ PresenterScrollBar::PresenterScrollBar (
         if ( ! xFactory.is())
             throw RuntimeException();
 
-        mxPresenterHelper = Reference<drawing::XPresenterHelper>(
+        mxPresenterHelper.set(
             xFactory->createInstanceWithContext(
-                OUString("com.sun.star.comp.Draw.PresenterHelper"),
+                "com.sun.star.comp.Draw.PresenterHelper",
                 rxComponentContext),
             UNO_QUERY_THROW);
 
         if (mxPresenterHelper.is())
             mxWindow = mxPresenterHelper->createWindow(rxParentWindow,
-                sal_False,
-                sal_False,
-                sal_False,
-                sal_False);
+                false,
+                false,
+                false,
+                false);
 
         // Make the background transparent.  The slide show paints its own background.
         Reference<awt::XWindowPeer> xPeer (mxWindow, UNO_QUERY_THROW);
@@ -128,7 +127,7 @@ PresenterScrollBar::PresenterScrollBar (
             xPeer->setBackground(0xff000000);
         }
 
-        mxWindow->setVisible(sal_True);
+        mxWindow->setVisible(true);
         mxWindow->addWindowListener(this);
         mxWindow->addPaintListener(this);
         mxWindow->addMouseListener(this);
@@ -139,11 +138,11 @@ PresenterScrollBar::PresenterScrollBar (
     }
 }
 
-PresenterScrollBar::~PresenterScrollBar (void)
+PresenterScrollBar::~PresenterScrollBar()
 {
 }
 
-void SAL_CALL PresenterScrollBar::disposing (void)
+void SAL_CALL PresenterScrollBar::disposing()
 {
     mpMousePressRepeater->Dispose();
 
@@ -155,7 +154,7 @@ void SAL_CALL PresenterScrollBar::disposing (void)
         mxWindow->removeMouseMotionListener(this);
 
         Reference<lang::XComponent> xComponent (mxWindow, UNO_QUERY);
-        mxWindow = NULL;
+        mxWindow = nullptr;
         if (xComponent.is())
             xComponent->dispose();
     }
@@ -187,17 +186,7 @@ void PresenterScrollBar::SetThumbPosition (
     double nPosition,
     const bool bAsynchronousUpdate)
 {
-    SetThumbPosition(nPosition, bAsynchronousUpdate, true, true);
-}
-
-void PresenterScrollBar::SetThumbPosition (
-    double nPosition,
-    const bool bAsynchronousUpdate,
-    const bool bValidate,
-    const bool bNotify)
-{
-    if (bValidate)
-        nPosition = ValidateThumbPosition(nPosition);
+    nPosition = ValidateThumbPosition(nPosition);
 
     if (nPosition != mnThumbPosition && ! mbIsNotificationActive)
     {
@@ -205,15 +194,19 @@ void PresenterScrollBar::SetThumbPosition (
 
         UpdateBorders();
         Repaint(GetRectangle(Total), bAsynchronousUpdate);
-        if (bNotify)
-            NotifyThumbPositionChange();
+
+        mbIsNotificationActive = true;
+        try
+        {
+            maThumbMotionListener(mnThumbPosition);
+        }
+        catch (Exception&)
+        {
+        }
+        mbIsNotificationActive = false;
     }
 }
 
-double PresenterScrollBar::GetThumbPosition (void) const
-{
-    return mnThumbPosition;
-}
 
 void PresenterScrollBar::SetTotalSize (const double nTotalSize)
 {
@@ -236,20 +229,12 @@ void PresenterScrollBar::SetThumbSize (const double nThumbSize)
     }
 }
 
-double PresenterScrollBar::GetThumbSize (void) const
-{
-    return mnThumbSize;
-}
 
 void PresenterScrollBar::SetLineHeight (const double nLineHeight)
 {
     mnLineHeight = nLineHeight;
 }
 
-double PresenterScrollBar::GetLineHeight (void) const
-{
-    return mnLineHeight;
-}
 
 void PresenterScrollBar::SetCanvas (const Reference<css::rendering::XCanvas>& rxCanvas)
 {
@@ -258,7 +243,7 @@ void PresenterScrollBar::SetCanvas (const Reference<css::rendering::XCanvas>& rx
         mxCanvas = rxCanvas;
         if (mxCanvas.is())
         {
-            if (mpBitmaps.get()==NULL)
+            if (mpBitmaps.get()==nullptr)
             {
                 if (mpSharedBitmaps.expired())
                 {
@@ -266,7 +251,7 @@ void PresenterScrollBar::SetCanvas (const Reference<css::rendering::XCanvas>& rx
                     {
                         mpBitmaps.reset(new PresenterBitmapContainer(
                             OUString("PresenterScreenSettings/ScrollBar/Bitmaps"),
-                            ::boost::shared_ptr<PresenterBitmapContainer>(),
+                            std::shared_ptr<PresenterBitmapContainer>(),
                             mxComponentContext,
                             mxCanvas));
                         mpSharedBitmaps = mpBitmaps;
@@ -277,7 +262,7 @@ void PresenterScrollBar::SetCanvas (const Reference<css::rendering::XCanvas>& rx
                     }
                 }
                 else
-                    mpBitmaps = ::boost::shared_ptr<PresenterBitmapContainer>(mpSharedBitmaps);
+                    mpBitmaps = std::shared_ptr<PresenterBitmapContainer>(mpSharedBitmaps);
                 UpdateBitmaps();
                 UpdateBorders();
             }
@@ -292,7 +277,7 @@ void PresenterScrollBar::SetBackground (const SharedBitmapDescriptor& rpBackgrou
     mpBackgroundBitmap = rpBackgroundBitmap;
 }
 
-void PresenterScrollBar::CheckValues (void)
+void PresenterScrollBar::CheckValues()
 {
     mnThumbPosition = ValidateThumbPosition(mnThumbPosition);
 }
@@ -307,8 +292,7 @@ double PresenterScrollBar::ValidateThumbPosition (double nPosition)
 }
 
 void PresenterScrollBar::Paint (
-    const awt::Rectangle& rUpdateBox,
-    const bool bNoClip)
+    const awt::Rectangle& rUpdateBox)
 {
     if ( ! mxCanvas.is() || ! mxWindow.is())
     {
@@ -317,11 +301,8 @@ void PresenterScrollBar::Paint (
         return;
     }
 
-    if ( ! bNoClip)
-    {
-        if (PresenterGeometryHelper::AreRectanglesDisjoint (rUpdateBox, mxWindow->getPosSize()))
-            return;
-    }
+    if (PresenterGeometryHelper::AreRectanglesDisjoint (rUpdateBox, mxWindow->getPosSize()))
+        return;
 
     PaintBackground(rUpdateBox);
     PaintComposite(rUpdateBox, PagerUp,
@@ -335,39 +316,22 @@ void PresenterScrollBar::Paint (
 
     Reference<rendering::XSpriteCanvas> xSpriteCanvas (mxCanvas, UNO_QUERY);
     if (xSpriteCanvas.is())
-        xSpriteCanvas->updateScreen(sal_False);
+        xSpriteCanvas->updateScreen(false);
 }
 
 //----- XWindowListener -------------------------------------------------------
 
-void SAL_CALL PresenterScrollBar::windowResized (const css::awt::WindowEvent& rEvent)
-    throw (css::uno::RuntimeException)
-{
-    (void)rEvent;
-}
+void SAL_CALL PresenterScrollBar::windowResized (const css::awt::WindowEvent&) {}
 
-void SAL_CALL PresenterScrollBar::windowMoved (const css::awt::WindowEvent& rEvent)
-    throw (css::uno::RuntimeException)
-{
-    (void)rEvent;
-}
+void SAL_CALL PresenterScrollBar::windowMoved (const css::awt::WindowEvent&) {}
 
-void SAL_CALL PresenterScrollBar::windowShown (const css::lang::EventObject& rEvent)
-    throw (css::uno::RuntimeException)
-{
-    (void)rEvent;
-}
+void SAL_CALL PresenterScrollBar::windowShown (const css::lang::EventObject&) {}
 
-void SAL_CALL PresenterScrollBar::windowHidden (const css::lang::EventObject& rEvent)
-    throw (css::uno::RuntimeException)
-{
-    (void)rEvent;
-}
+void SAL_CALL PresenterScrollBar::windowHidden (const css::lang::EventObject&) {}
 
 //----- XPaintListener --------------------------------------------------------
 
 void SAL_CALL PresenterScrollBar::windowPaint (const css::awt::PaintEvent& rEvent)
-    throw (css::uno::RuntimeException)
 {
     if (mxWindow.is())
     {
@@ -379,14 +343,13 @@ void SAL_CALL PresenterScrollBar::windowPaint (const css::awt::PaintEvent& rEven
 
         Reference<rendering::XSpriteCanvas> xSpriteCanvas (mxCanvas, UNO_QUERY);
         if (xSpriteCanvas.is())
-            xSpriteCanvas->updateScreen(sal_False);
+            xSpriteCanvas->updateScreen(false);
     }
 }
 
 //----- XMouseListener --------------------------------------------------------
 
 void SAL_CALL PresenterScrollBar::mousePressed (const css::awt::MouseEvent& rEvent)
-    throw(css::uno::RuntimeException)
 {
     maDragAnchor.X = rEvent.X;
     maDragAnchor.Y = rEvent.Y;
@@ -395,27 +358,18 @@ void SAL_CALL PresenterScrollBar::mousePressed (const css::awt::MouseEvent& rEve
     mpMousePressRepeater->Start(meButtonDownArea);
 }
 
-void SAL_CALL PresenterScrollBar::mouseReleased (const css::awt::MouseEvent& rEvent)
-    throw(css::uno::RuntimeException)
+void SAL_CALL PresenterScrollBar::mouseReleased (const css::awt::MouseEvent&)
 {
-    (void)rEvent;
-
     mpMousePressRepeater->Stop();
 
     if (mxPresenterHelper.is())
         mxPresenterHelper->releaseMouse(mxWindow);
 }
 
-void SAL_CALL PresenterScrollBar::mouseEntered (const css::awt::MouseEvent& rEvent)
-    throw(css::uno::RuntimeException)
-{
-    (void)rEvent;
-}
+void SAL_CALL PresenterScrollBar::mouseEntered (const css::awt::MouseEvent&) {}
 
-void SAL_CALL PresenterScrollBar::mouseExited (const css::awt::MouseEvent& rEvent)
-    throw(css::uno::RuntimeException)
+void SAL_CALL PresenterScrollBar::mouseExited (const css::awt::MouseEvent&)
 {
-    (void)rEvent;
     if (meMouseMoveArea != None)
     {
         const Area eOldMouseMoveArea (meMouseMoveArea);
@@ -431,7 +385,6 @@ void SAL_CALL PresenterScrollBar::mouseExited (const css::awt::MouseEvent& rEven
 //----- XMouseMotionListener --------------------------------------------------
 
 void SAL_CALL PresenterScrollBar::mouseMoved (const css::awt::MouseEvent& rEvent)
-    throw (css::uno::RuntimeException)
 {
     const Area eArea (GetArea(rEvent.X, rEvent.Y));
     if (eArea != meMouseMoveArea)
@@ -447,7 +400,6 @@ void SAL_CALL PresenterScrollBar::mouseMoved (const css::awt::MouseEvent& rEvent
 }
 
 void SAL_CALL PresenterScrollBar::mouseDragged (const css::awt::MouseEvent& rEvent)
-    throw (css::uno::RuntimeException)
 {
     if (meButtonDownArea != Thumb)
         return;
@@ -461,43 +413,41 @@ void SAL_CALL PresenterScrollBar::mouseDragged (const css::awt::MouseEvent& rEve
     UpdateDragAnchor(nDragDistance);
     if (nDragDistance != 0)
     {
-        SetThumbPosition(mnThumbPosition + nDragDistance, false, true, true);
+        SetThumbPosition(mnThumbPosition + nDragDistance, false);
     }
 }
 
 //----- lang::XEventListener --------------------------------------------------
 
 void SAL_CALL PresenterScrollBar::disposing (const css::lang::EventObject& rEvent)
-    throw (css::uno::RuntimeException)
 {
     if (rEvent.Source == mxWindow)
-        mxWindow = NULL;
+        mxWindow = nullptr;
 }
 
-//-----------------------------------------------------------------------------
 
-geometry::RealRectangle2D PresenterScrollBar::GetRectangle (const Area eArea) const
+geometry::RealRectangle2D const & PresenterScrollBar::GetRectangle (const Area eArea) const
 {
-    OSL_ASSERT(eArea>=0 && eArea<__AreaCount__);
+    OSL_ASSERT(eArea>=0 && eArea<AreaCount);
 
     return maBox[eArea];
 }
 
 void PresenterScrollBar::Repaint (
-    const geometry::RealRectangle2D aBox,
+    const geometry::RealRectangle2D& rBox,
     const bool bAsynchronousUpdate)
 {
-    if (mpPaintManager.get() != NULL)
+    if (mpPaintManager.get() != nullptr)
         mpPaintManager->Invalidate(
             mxWindow,
-            PresenterGeometryHelper::ConvertRectangle(aBox),
+            PresenterGeometryHelper::ConvertRectangle(rBox),
             bAsynchronousUpdate);
 }
 
 void PresenterScrollBar::PaintBackground(
     const css::awt::Rectangle& rUpdateBox)
 {
-    if (mpBackgroundBitmap.get() == NULL)
+    if (mpBackgroundBitmap.get() == nullptr)
         return;
 
     const awt::Rectangle aWindowBox (mxWindow->getPosSize());
@@ -541,7 +491,7 @@ void PresenterScrollBar::PaintBitmap(
             geometry::AffineMatrix2D(
                 1,0,aBox.X1 + (aBox.X2-aBox.X1 - aBitmapSize.Width)/2,
                 0,1,aBox.Y1 + (aBox.Y2-aBox.Y1 - aBitmapSize.Height)/2),
-            NULL,
+            nullptr,
             Sequence<double>(4),
             rendering::CompositeOperation::SOURCE);
 
@@ -552,24 +502,6 @@ void PresenterScrollBar::PaintBitmap(
     }
 }
 
-void PresenterScrollBar::NotifyThumbPositionChange (void)
-{
-    if ( ! mbIsNotificationActive)
-    {
-        mbIsNotificationActive = true;
-
-        try
-        {
-            maThumbMotionListener(mnThumbPosition);
-        }
-        catch (Exception&)
-        {
-        }
-
-        mbIsNotificationActive = false;
-    }
-}
-
 PresenterScrollBar::Area PresenterScrollBar::GetArea (const double nX, const double nY) const
 {
     const geometry::RealPoint2D aPoint(nX, nY);
@@ -595,7 +527,7 @@ void PresenterScrollBar::UpdateWidthOrHeight (
     sal_Int32& rSize,
     const SharedBitmapDescriptor& rpDescriptor)
 {
-    if (rpDescriptor.get() != NULL)
+    if (rpDescriptor.get() != nullptr)
     {
         Reference<rendering::XBitmap> xBitmap (rpDescriptor->GetNormalBitmap());
         if (xBitmap.is())
@@ -612,8 +544,8 @@ css::uno::Reference<css::rendering::XBitmap> PresenterScrollBar::GetBitmap (
     const Area eArea,
     const SharedBitmapDescriptor& rpBitmaps) const
 {
-    if (rpBitmaps.get() == NULL)
-        return NULL;
+    if (rpBitmaps.get() == nullptr)
+        return nullptr;
     else
         return rpBitmaps->GetBitmap(GetBitmapMode(eArea));
 }
@@ -631,7 +563,7 @@ PresenterBitmapContainer::BitmapDescriptor::Mode PresenterScrollBar::GetBitmapMo
 
 bool PresenterScrollBar::IsDisabled (const Area eArea) const
 {
-    OSL_ASSERT(eArea>=0 && eArea<__AreaCount__);
+    OSL_ASSERT(eArea>=0 && eArea<AreaCount);
 
     return ! maEnabledState[eArea];
 }
@@ -641,20 +573,19 @@ bool PresenterScrollBar::IsDisabled (const Area eArea) const
 PresenterVerticalScrollBar::PresenterVerticalScrollBar (
     const Reference<XComponentContext>& rxComponentContext,
     const Reference<awt::XWindow>& rxParentWindow,
-    const ::boost::shared_ptr<PresenterPaintManager>& rpPaintManager,
-    const ::boost::function<void(double)>& rThumbMotionListener)
+    const std::shared_ptr<PresenterPaintManager>& rpPaintManager,
+    const ::std::function<void (double)>& rThumbMotionListener)
     : PresenterScrollBar(rxComponentContext, rxParentWindow, rpPaintManager, rThumbMotionListener),
       mnScrollBarWidth(0)
 {
 }
 
-PresenterVerticalScrollBar::~PresenterVerticalScrollBar (void)
+PresenterVerticalScrollBar::~PresenterVerticalScrollBar()
 {
 }
 
-double PresenterVerticalScrollBar::GetDragDistance (const sal_Int32 nX, const sal_Int32 nY) const
+double PresenterVerticalScrollBar::GetDragDistance (const sal_Int32, const sal_Int32 nY) const
 {
-    (void)nX;
     const double nDistance (nY - maDragAnchor.Y);
     if (nDistance == 0)
         return 0;
@@ -681,29 +612,22 @@ void PresenterVerticalScrollBar::UpdateDragAnchor (const double nDragDistance)
     maDragAnchor.Y += nDragDistance * nPagerHeight /  mnTotalSize;
 }
 
-sal_Int32 PresenterVerticalScrollBar::GetSize (void) const
+sal_Int32 PresenterVerticalScrollBar::GetSize() const
 {
     return mnScrollBarWidth;
 }
 
-geometry::RealPoint2D PresenterVerticalScrollBar::GetPoint (
-    const double nMajor, const double nMinor) const
+double PresenterVerticalScrollBar::GetMinor (const double nX, const double) const
 {
-    return geometry::RealPoint2D(nMinor, nMajor);
-}
-
-double PresenterVerticalScrollBar::GetMinor (const double nX, const double nY) const
-{
-    (void)nY;
     return nX;
 }
 
-void PresenterVerticalScrollBar::UpdateBorders (void)
+void PresenterVerticalScrollBar::UpdateBorders()
 {
     const awt::Rectangle aWindowBox (mxWindow->getPosSize());
     double nBottom = aWindowBox.Height;
 
-    if (mpNextButtonDescriptor.get() != NULL)
+    if (mpNextButtonDescriptor.get() != nullptr)
     {
         Reference<rendering::XBitmap> xBitmap (mpNextButtonDescriptor->GetNormalBitmap());
         if (xBitmap.is())
@@ -714,7 +638,7 @@ void PresenterVerticalScrollBar::UpdateBorders (void)
             nBottom -= aSize.Height + gnScrollBarGap;
         }
     }
-    if (mpPrevButtonDescriptor.get() != NULL)
+    if (mpPrevButtonDescriptor.get() != nullptr)
     {
         Reference<rendering::XBitmap> xBitmap (mpPrevButtonDescriptor->GetNormalBitmap());
         if (xBitmap.is())
@@ -764,9 +688,9 @@ void PresenterVerticalScrollBar::UpdateBorders (void)
         maBox[Pager]);
 }
 
-void PresenterVerticalScrollBar::UpdateBitmaps (void)
+void PresenterVerticalScrollBar::UpdateBitmaps()
 {
-    if (mpBitmaps.get() != NULL)
+    if (mpBitmaps.get() != nullptr)
     {
         mpPrevButtonDescriptor = mpBitmaps->GetBitmap("Up");
         mpNextButtonDescriptor = mpBitmaps->GetBitmap("Down");
@@ -828,10 +752,10 @@ PresenterScrollBar::MousePressRepeater::MousePressRepeater (
 {
 }
 
-void PresenterScrollBar::MousePressRepeater::Dispose (void)
+void PresenterScrollBar::MousePressRepeater::Dispose()
 {
     Stop();
-    mpScrollBar = NULL;
+    mpScrollBar = nullptr;
 }
 
 void PresenterScrollBar::MousePressRepeater::Start (const PresenterScrollBar::Area& reArea)
@@ -844,8 +768,10 @@ void PresenterScrollBar::MousePressRepeater::Start (const PresenterScrollBar::Ar
         Execute();
 
         // Schedule repeated executions.
+        auto pThis(shared_from_this());
         mnMousePressRepeaterTaskId = PresenterTimer::ScheduleRepeatedTask (
-            ::boost::bind(&PresenterScrollBar::MousePressRepeater::Callback, shared_from_this(), _1),
+            mpScrollBar->GetComponentContext(),
+            [pThis] (TimeValue const&) { return pThis->Callback(); },
             500000000,
             250000000);
     }
@@ -855,7 +781,7 @@ void PresenterScrollBar::MousePressRepeater::Start (const PresenterScrollBar::Ar
     }
 }
 
-void PresenterScrollBar::MousePressRepeater::Stop (void)
+void PresenterScrollBar::MousePressRepeater::Stop()
 {
     if (mnMousePressRepeaterTaskId != PresenterTimer::NotAValidTaskId)
     {
@@ -876,11 +802,9 @@ void PresenterScrollBar::MousePressRepeater::SetMouseArea(const PresenterScrollB
     }
 }
 
-void PresenterScrollBar::MousePressRepeater::Callback (const TimeValue& rCurrentTime)
+void PresenterScrollBar::MousePressRepeater::Callback ()
 {
-    (void)rCurrentTime;
-
-    if (mpScrollBar.get() == NULL)
+    if (mpScrollBar.get() == nullptr)
     {
         Stop();
         return;
@@ -889,7 +813,7 @@ void PresenterScrollBar::MousePressRepeater::Callback (const TimeValue& rCurrent
     Execute();
 }
 
-void PresenterScrollBar::MousePressRepeater::Execute (void)
+void PresenterScrollBar::MousePressRepeater::Execute()
 {
     const double nThumbPosition (mpScrollBar->GetThumbPosition());
     switch (meMouseArea)
