@@ -24,9 +24,7 @@
 
 #include <cassert>
 
-#include <com/sun/star/frame/XDesktop.hpp>
 #include <com/sun/star/script/XLibraryContainer.hpp>
-#include <com/sun/star/uno/Reference.h>
 #include <basic/basrdll.hxx>
 #include <officecfg/Office/Common.hxx>
 #include <svl/macitem.hxx>
@@ -46,10 +44,11 @@
 #include <svtools/sfxecode.hxx>
 #include <svtools/ehdl.hxx>
 
+#include <sfx2/dinfdlg.hxx>
 #include <sfx2/module.hxx>
-#include "arrdecl.hxx"
+#include <arrdecl.hxx>
 #include <sfx2/app.hxx>
-#include "sfxtypes.hxx"
+#include <sfxtypes.hxx>
 #include <sfx2/sfxresid.hxx>
 #include <sfx2/msg.hxx>
 #include <sfx2/msgpool.hxx>
@@ -61,38 +60,35 @@
 #include <sfx2/dispatch.hxx>
 #include <sfx2/tplpitem.hxx>
 #include <sfx2/minfitem.hxx>
-#include "app.hrc"
+#include <sfx2/strings.hrc>
 #include <sfx2/evntconf.hxx>
 #include <sfx2/request.hxx>
-#include <sfx2/dinfdlg.hxx>
-#include "appdata.hxx"
+#include <appdata.hxx>
 #include <sfx2/sfxhelp.hxx>
 #include <basic/basmgr.hxx>
-#include <svtools/svtools.hrc>
+#include <svtools/strings.hrc>
 #include <unotools/configmgr.hxx>
-#include "sorgitm.hxx"
-#include "appbaslib.hxx"
+#include <sorgitm.hxx>
+#include <appbaslib.hxx>
 #include <basic/basicmanagerrepository.hxx>
 
 #include <svl/srchitem.hxx>
 #include <osl/socket.hxx>
 
 #define SFX_TYPEMAP
-#include "sfxslots.hxx"
+#include <sfxslots.hxx>
 
 using namespace ::com::sun::star;
 using namespace ::com::sun::star::uno;
-using namespace ::com::sun::star::frame;
 using namespace ::com::sun::star::script;
 
 using ::basic::BasicManagerRepository;
 
 
-sal_uInt16 SfxApplication::SaveBasicAndDialogContainer() const
+void SfxApplication::SaveBasicAndDialogContainer() const
 {
-    if ( pAppData_Impl->pBasicManager->isValid() )
-        pAppData_Impl->pBasicManager->storeAllLibraries();
-    return 0;
+    if ( pImpl->pBasicManager->isValid() )
+        pImpl->pBasicManager->storeAllLibraries();
 }
 
 BasicManager* SfxApplication::GetBasicManager()
@@ -100,9 +96,9 @@ BasicManager* SfxApplication::GetBasicManager()
 #if !HAVE_FEATURE_SCRIPTING
     return 0;
 #else
-    if (utl::ConfigManager::IsAvoidConfig())
+    if (utl::ConfigManager::IsFuzzing())
         return nullptr;
-    return BasicManagerRepository::getApplicationBasicManager( true );
+    return BasicManagerRepository::getApplicationBasicManager();
 #endif
 }
 
@@ -111,26 +107,25 @@ XLibraryContainer * SfxApplication::GetDialogContainer()
 #if !HAVE_FEATURE_SCRIPTING
     return NULL;
 #else
-    if (utl::ConfigManager::IsAvoidConfig())
+    if (utl::ConfigManager::IsFuzzing())
         return nullptr;
-    if ( !pAppData_Impl->pBasicManager->isValid() )
+    if ( !pImpl->pBasicManager->isValid() )
         GetBasicManager();
-    return pAppData_Impl->pBasicManager->getLibraryContainer( SfxBasicManagerHolder::DIALOGS );
+    return pImpl->pBasicManager->getLibraryContainer( SfxBasicManagerHolder::DIALOGS );
 #endif
 }
 
 
-
 XLibraryContainer * SfxApplication::GetBasicContainer()
 {
 #if !HAVE_FEATURE_SCRIPTING
     return NULL;
 #else
-    if (utl::ConfigManager::IsAvoidConfig())
+    if (utl::ConfigManager::IsFuzzing())
         return nullptr;
-    if ( !pAppData_Impl->pBasicManager->isValid() )
+    if ( !pImpl->pBasicManager->isValid() )
         GetBasicManager();
-    return pAppData_Impl->pBasicManager->getLibraryContainer( SfxBasicManagerHolder::SCRIPTS );
+    return pImpl->pBasicManager->getLibraryContainer( SfxBasicManagerHolder::SCRIPTS );
 #endif
 }
 
@@ -139,13 +134,13 @@ StarBASIC* SfxApplication::GetBasic()
 #if !HAVE_FEATURE_SCRIPTING
     return 0;
 #else
-    if (utl::ConfigManager::IsAvoidConfig())
+    if (utl::ConfigManager::IsFuzzing())
         return nullptr;
     return GetBasicManager()->GetLib(0);
 #endif
 }
 
-void SfxApplication::PropExec_Impl( SfxRequest &rReq )
+void SfxApplication::PropExec_Impl( SfxRequest const &rReq )
 {
     sal_uInt16 nSID = rReq.GetSlot();
     switch ( nSID )
