@@ -17,8 +17,7 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include <com/sun/star/uno/Reference.hxx>
-#include <com/sun/star/frame/XDesktop.hpp>
+#include <memory>
 #include <com/sun/star/util/XURLTransformer.hpp>
 #include <com/sun/star/beans/PropertyValue.hpp>
 #include <com/sun/star/beans/XPropertySet.hpp>
@@ -34,7 +33,6 @@
 #include <svl/stritem.hxx>
 #include <svl/intitem.hxx>
 #include <svl/eitem.hxx>
-#include <svl/szitem.hxx>
 #include <svl/undo.hxx>
 
 #include <sfx2/sfxsids.hrc>
@@ -60,46 +58,41 @@
 #include <sfx2/docfile.hxx>
 #include <sfx2/viewfrm.hxx>
 #include <sfx2/sfxhelp.hxx>
-#include "sfxtypes.hxx"
+#include <sfxtypes.hxx>
 #include <sfx2/dispatch.hxx>
 #include <sfx2/objsh.hxx>
-#include "objshimp.hxx"
+#include <objshimp.hxx>
 #include <sfx2/viewsh.hxx>
 #include <sfx2/request.hxx>
 #include <sfx2/evntconf.hxx>
-#include "appdata.hxx"
-#include "workwin.hxx"
-#include "helper.hxx"
-#include "app.hrc"
+#include <appdata.hxx>
+#include <workwin.hxx>
+#include <helper.hxx>
+#include <sfx2/strings.hrc>
 #include <sfx2/sfxresid.hxx>
 #include "shutdownicon.hxx"
 
 using namespace ::com::sun::star::uno;
 using namespace ::com::sun::star::util;
-using namespace ::com::sun::star::frame;
 using namespace ::com::sun::star::beans;
 
 
-
 class SfxEventAsyncer_Impl : public SfxListener
 {
-    SfxEventHint        aHint;
-    Idle*               pIdle;
+    SfxEventHint           aHint;
+    std::unique_ptr<Idle>  pIdle;
 
 public:
 
     virtual void        Notify( SfxBroadcaster& rBC, const SfxHint& rHint ) override;
     explicit SfxEventAsyncer_Impl(const SfxEventHint& rHint);
-    virtual ~SfxEventAsyncer_Impl();
-    DECL_LINK_TYPED( IdleHdl, Idle*, void );
+    DECL_LINK( IdleHdl, Timer*, void );
 };
 
 
-
 void SfxEventAsyncer_Impl::Notify( SfxBroadcaster&, const SfxHint& rHint )
 {
-    const SfxSimpleHint* pHint = dynamic_cast<const SfxSimpleHint*>(&rHint);
-    if( pHint && pHint->GetId() == SFX_HINT_DYING && pIdle->IsActive() )
+    if( rHint.GetId() == SfxHintId::Dying && pIdle->IsActive() )
     {
         pIdle->Stop();
         delete this;
@@ -107,49 +100,32 @@ void SfxEventAsyncer_Impl::Notify( SfxBroadcaster&, const SfxHint& rHint )
 }
 
 
-
 SfxEventAsyncer_Impl::SfxEventAsyncer_Impl( const SfxEventHint& rHint )
  : aHint( rHint )
 {
     if( rHint.GetObjShell() )
         StartListening( *rHint.GetObjShell() );
-    pIdle = new Idle;
-    pIdle->SetIdleHdl( LINK(this, SfxEventAsyncer_Impl, IdleHdl) );
-    pIdle->SetPriority( SchedulerPriority::HIGHEST );
+    pIdle.reset( new Idle("SfxEventASyncer") );
+    pIdle->SetInvokeHandler( LINK(this, SfxEventAsyncer_Impl, IdleHdl) );
+    pIdle->SetPriority( TaskPriority::HIGH_IDLE );
+    pIdle->SetDebugName( "sfx::SfxEventAsyncer_Impl pIdle" );
     pIdle->Start();
 }
 
 
-
-SfxEventAsyncer_Impl::~SfxEventAsyncer_Impl()
-{
-    delete pIdle;
-}
-
-
-
-IMPL_LINK_TYPED(SfxEventAsyncer_Impl, IdleHdl, Idle*, pAsyncIdle, void)
+IMPL_LINK(SfxEventAsyncer_Impl, IdleHdl, Timer*, pAsyncIdle, void)
 {
     SfxObjectShellRef xRef( aHint.GetObjShell() );
     pAsyncIdle->Stop();
-#ifdef DBG_UTIL
-    if (!xRef.Is())
-    {
-        OStringBuffer aTmp("SfxEvent: ");
-        aTmp.append(OUStringToOString(aHint.GetEventName(), RTL_TEXTENCODING_UTF8));
-        OSL_TRACE( "%s", aTmp.getStr() );
-    }
-#endif
+    SAL_INFO_IF(!xRef.is(), "sfx.appl", "SfxEvent: " << aHint.GetEventName());
     SfxGetpApp()->Broadcast( aHint );
-    if ( xRef.Is() )
+    if ( xRef.is() )
         xRef->Broadcast( aHint );
     delete this;
 }
 
 
-
-
-bool SfxApplication::GetOptions( SfxItemSet& rSet )
+void SfxApplication::GetOptions( SfxItemSet& rSet )
 {
     bool bRet = false;
     SfxItemPool &rPool = GetPool();
@@ -180,7 +156,7 @@ bool SfxApplication::GetOptions( SfxItemSet& rSet )
                 case SID_ATTR_BACKUP :
                     {
                         bRet = true;
-                        if (!aSaveOptions.IsReadOnly(SvtSaveOptions::E_BACKUP))
+                        if (!aSaveOptions.IsReadOnly(SvtSaveOptions::EOption::Backup))
                             if (!rSet.Put( SfxBoolItem( rPool.GetWhich( SID_ATTR_BACKUP ),aSaveOptions.IsBackup())))
                                 bRet = false;
                     }
@@ -188,7 +164,7 @@ bool SfxApplication::GetOptions( SfxItemSet& rSet )
                 case SID_ATTR_PRETTYPRINTING:
                     {
                         bRet = true;
-                        if (!aSaveOptions.IsReadOnly(SvtSaveOptions::E_DOPRETTYPRINTING))
+                        if (!aSaveOptions.IsReadOnly(SvtSaveOptions::EOption::DoPrettyPrinting))
                             if (!rSet.Put( SfxBoolItem( rPool.GetWhich( SID_ATTR_PRETTYPRINTING ), aSaveOptions.IsPrettyPrinting())))
                                 bRet = false;
                     }
@@ -196,7 +172,7 @@ bool SfxApplication::GetOptions( SfxItemSet& rSet )
                 case SID_ATTR_WARNALIENFORMAT:
                     {
                         bRet = true;
-                        if (!aSaveOptions.IsReadOnly(SvtSaveOptions::E_WARNALIENFORMAT))
+                        if (!aSaveOptions.IsReadOnly(SvtSaveOptions::EOption::WarnAlienFormat))
                             if (!rSet.Put( SfxBoolItem( rPool.GetWhich( SID_ATTR_WARNALIENFORMAT ), aSaveOptions.IsWarnAlienFormat())))
                                 bRet = false;
                     }
@@ -204,7 +180,7 @@ bool SfxApplication::GetOptions( SfxItemSet& rSet )
                 case SID_ATTR_AUTOSAVE :
                     {
                         bRet = true;
-                        if (!aSaveOptions.IsReadOnly(SvtSaveOptions::E_AUTOSAVE))
+                        if (!aSaveOptions.IsReadOnly(SvtSaveOptions::EOption::AutoSave))
                             if (!rSet.Put( SfxBoolItem( rPool.GetWhich( SID_ATTR_AUTOSAVE ), aSaveOptions.IsAutoSave())))
                                 bRet = false;
                     }
@@ -212,7 +188,7 @@ bool SfxApplication::GetOptions( SfxItemSet& rSet )
                 case SID_ATTR_AUTOSAVEPROMPT :
                     {
                         bRet = true;
-                        if (!aSaveOptions.IsReadOnly(SvtSaveOptions::E_AUTOSAVEPROMPT))
+                        if (!aSaveOptions.IsReadOnly(SvtSaveOptions::EOption::AutoSavePrompt))
                             if (!rSet.Put( SfxBoolItem( rPool.GetWhich( SID_ATTR_AUTOSAVEPROMPT ), aSaveOptions.IsAutoSavePrompt())))
                                 bRet = false;
                     }
@@ -220,7 +196,7 @@ bool SfxApplication::GetOptions( SfxItemSet& rSet )
                 case SID_ATTR_AUTOSAVEMINUTE :
                     {
                         bRet = true;
-                        if (!aSaveOptions.IsReadOnly(SvtSaveOptions::E_AUTOSAVETIME))
+                        if (!aSaveOptions.IsReadOnly(SvtSaveOptions::EOption::AutoSaveTime))
                             if (!rSet.Put( SfxUInt16Item( rPool.GetWhich( SID_ATTR_AUTOSAVEMINUTE ), (sal_uInt16)aSaveOptions.GetAutoSaveTime())))
                                 bRet = false;
                     }
@@ -228,7 +204,7 @@ bool SfxApplication::GetOptions( SfxItemSet& rSet )
                 case SID_ATTR_USERAUTOSAVE :
                     {
                         bRet = true;
-                        if (!aSaveOptions.IsReadOnly(SvtSaveOptions::E_USERAUTOSAVE))
+                        if (!aSaveOptions.IsReadOnly(SvtSaveOptions::EOption::UserAutoSave))
                             if (!rSet.Put( SfxBoolItem( rPool.GetWhich( SID_ATTR_USERAUTOSAVE ), aSaveOptions.IsUserAutoSave())))
                                 bRet = false;
                     }
@@ -236,7 +212,7 @@ bool SfxApplication::GetOptions( SfxItemSet& rSet )
                 case SID_ATTR_DOCINFO :
                     {
                         bRet = true;
-                        if (!aSaveOptions.IsReadOnly(SvtSaveOptions::E_DOCINFSAVE))
+                        if (!aSaveOptions.IsReadOnly(SvtSaveOptions::EOption::DocInfSave))
                             if (!rSet.Put( SfxBoolItem( rPool.GetWhich( SID_ATTR_DOCINFO ), aSaveOptions.IsDocInfoSave())))
                                 bRet = false;
                     }
@@ -244,7 +220,7 @@ bool SfxApplication::GetOptions( SfxItemSet& rSet )
                 case SID_ATTR_WORKINGSET :
                     {
                         bRet = true;
-                        if (!aSaveOptions.IsReadOnly(SvtSaveOptions::E_SAVEWORKINGSET))
+                        if (!aSaveOptions.IsReadOnly(SvtSaveOptions::EOption::SaveWorkingSet))
                             if (!rSet.Put( SfxBoolItem( rPool.GetWhich( SID_ATTR_WORKINGSET ), aSaveOptions.IsSaveWorkingSet())))
                                 bRet = false;
                     }
@@ -252,7 +228,7 @@ bool SfxApplication::GetOptions( SfxItemSet& rSet )
                 case SID_ATTR_SAVEDOCVIEW :
                     {
                         bRet = true;
-                        if (!aSaveOptions.IsReadOnly(SvtSaveOptions::E_SAVEDOCVIEW))
+                        if (!aSaveOptions.IsReadOnly(SvtSaveOptions::EOption::SaveDocView))
                             if (!rSet.Put( SfxBoolItem( rPool.GetWhich( SID_ATTR_SAVEDOCVIEW ), aSaveOptions.IsSaveDocView())))
                                 bRet = false;
                     }
@@ -269,11 +245,6 @@ bool SfxApplication::GetOptions( SfxItemSet& rSet )
                                aHelpOptions.IsHelpTips() ) ) )
                         bRet = true;
                     break;
-                case SID_ATTR_WELCOMESCREEN :
-                    if(rSet.Put( SfxBoolItem ( rPool.GetWhich( SID_ATTR_WELCOMESCREEN ),
-                               aHelpOptions.IsWelcomeScreen() ) ) )
-                        bRet = true;
-                    break;
                 case SID_HELP_STYLESHEET :
                     if(rSet.Put( SfxStringItem ( rPool.GetWhich( SID_HELP_STYLESHEET ),
                                aHelpOptions.GetHelpStyleSheet() ) ) )
@@ -306,7 +277,7 @@ bool SfxApplication::GetOptions( SfxItemSet& rSet )
                 case SID_SAVEREL_INET :
                     {
                         bRet = true;
-                        if (!aSaveOptions.IsReadOnly(SvtSaveOptions::E_SAVERELINET))
+                        if (!aSaveOptions.IsReadOnly(SvtSaveOptions::EOption::SaveRelInet))
                             if (!rSet.Put( SfxBoolItem ( rPool.GetWhich( SID_SAVEREL_INET ), aSaveOptions.IsSaveRelINet() )))
                                 bRet = false;
                     }
@@ -314,7 +285,7 @@ bool SfxApplication::GetOptions( SfxItemSet& rSet )
                 case SID_SAVEREL_FSYS :
                     {
                         bRet = true;
-                        if (!aSaveOptions.IsReadOnly(SvtSaveOptions::E_SAVERELFSYS))
+                        if (!aSaveOptions.IsReadOnly(SvtSaveOptions::EOption::SaveRelFsys))
                             if (!rSet.Put( SfxBoolItem ( rPool.GetWhich( SID_SAVEREL_FSYS ), aSaveOptions.IsSaveRelFSys() )))
                                 bRet = false;
                     }
@@ -322,7 +293,7 @@ bool SfxApplication::GetOptions( SfxItemSet& rSet )
                 case SID_BASIC_ENABLED :
                     {
                         bRet = true;
-                        if (!aSecurityOptions.IsReadOnly(SvtSecurityOptions::E_BASICMODE))
+                        if (!aSecurityOptions.IsReadOnly(SvtSecurityOptions::EOption::BasicMode))
                         {
                             if ( !rSet.Put( SfxUInt16Item( rPool.GetWhich( SID_BASIC_ENABLED ), sal::static_int_cast< sal_uInt16 >(aSecurityOptions.GetBasicMode()))))
                                 bRet = false;
@@ -332,7 +303,7 @@ bool SfxApplication::GetOptions( SfxItemSet& rSet )
                 case SID_INET_EXE_PLUGIN  :
                     {
                         bRet = true;
-                        if (!aSecurityOptions.IsReadOnly(SvtSecurityOptions::E_EXECUTEPLUGINS))
+                        if (!aSecurityOptions.IsReadOnly(SvtSecurityOptions::EOption::ExecutePlugins))
                         {
                             if ( !rSet.Put( SfxBoolItem( SID_INET_EXE_PLUGIN, aSecurityOptions.IsExecutePlugins() ) ) )
                                 bRet = false;
@@ -342,7 +313,7 @@ bool SfxApplication::GetOptions( SfxItemSet& rSet )
                 case SID_MACRO_WARNING :
                     {
                         bRet = true;
-                        if (!aSecurityOptions.IsReadOnly(SvtSecurityOptions::E_WARNING))
+                        if (!aSecurityOptions.IsReadOnly(SvtSecurityOptions::EOption::Warning))
                         {
                             if ( !rSet.Put( SfxBoolItem( SID_MACRO_WARNING, aSecurityOptions.IsWarningEnabled() ) ) )
                                 bRet = false;
@@ -352,7 +323,7 @@ bool SfxApplication::GetOptions( SfxItemSet& rSet )
                 case SID_MACRO_CONFIRMATION :
                     {
                         bRet = true;
-                        if (!aSecurityOptions.IsReadOnly(SvtSecurityOptions::E_CONFIRMATION))
+                        if (!aSecurityOptions.IsReadOnly(SvtSecurityOptions::EOption::Confirmation))
                         {
                             if ( !rSet.Put( SfxBoolItem( SID_MACRO_CONFIRMATION, aSecurityOptions.IsConfirmationEnabled() ) ) )
                                 bRet = false;
@@ -362,7 +333,7 @@ bool SfxApplication::GetOptions( SfxItemSet& rSet )
                 case SID_SECURE_URL :
                     {
                         bRet = true;
-                        if (!aSecurityOptions.IsReadOnly(SvtSecurityOptions::E_SECUREURLS))
+                        if (!aSecurityOptions.IsReadOnly(SvtSecurityOptions::EOption::SecureUrls))
                         {
                             css::uno::Sequence< OUString > seqURLs = aSecurityOptions.GetSecureURLs();
                             std::vector<OUString> aList;
@@ -436,15 +407,12 @@ bool SfxApplication::GetOptions( SfxItemSet& rSet )
                     }
                     break;
                 case SID_ATTR_PATHNAME :
-                case SID_ATTR_PATHGROUP :
                 {
-                    SfxAllEnumItem aNames(rPool.GetWhich(SID_ATTR_PATHGROUP));
                     SfxAllEnumItem aValues(rPool.GetWhich(SID_ATTR_PATHNAME));
                     SvtPathOptions aPathCfg;
                     for ( sal_uInt16 nProp = SvtPathOptions::PATH_ADDIN;
                           nProp <= SvtPathOptions::PATH_WORK; nProp++ )
                     {
-                        aNames.InsertValue( nProp, SfxResId(CONFIG_PATH_START + nProp).toString() );
                         OUString aValue;
                         switch ( nProp )
                         {
@@ -474,24 +442,19 @@ bool SfxApplication::GetOptions( SfxItemSet& rSet )
                         aValues.InsertValue( nProp, aValue );
                     }
 
-                    if ( rSet.Put(aNames) || rSet.Put(aValues) )
+                    if (rSet.Put(aValues))
                         bRet = true;
                 }
                 break;
 
                 default:
-                    SAL_INFO( "sfx", "W1:Wrong ID while getting Options!" );
+                    SAL_INFO( "sfx.appl", "W1:Wrong ID while getting Options!" );
                     break;
             }
-#ifdef DBG_UTIL
-            if ( !bRet )
-                OSL_FAIL( "Putting options failed!" );
-#endif
+            SAL_WARN_IF(!bRet, "sfx.appl", "Putting options failed!");
         }
         pRanges++;
     }
-
-    return bRet;
 }
 
 // TODO/CLEANUP: Why two SetOptions Methods?
@@ -525,8 +488,7 @@ void SfxApplication::SetOptions_Impl( const SfxItemSet& rSet )
         while ( pCurrViewFrame )
         {
             // update all "final" dispatchers
-            if ( !pCurrViewFrame->GetActiveChildFrame_Impl() )
-                pCurrViewFrame->GetDispatcher()->Update_Impl(true);
+            pCurrViewFrame->GetDispatcher()->Update_Impl(true);
             pCurrViewFrame = SfxViewFrame::GetNext(*pCurrViewFrame);
         }
     }
@@ -621,23 +583,6 @@ void SfxApplication::SetOptions_Impl( const SfxItemSet& rSet )
         aHelpOptions.SetHelpTips( static_cast<const SfxBoolItem *>(pItem)->GetValue());
     }
 
-    // WelcomeScreen
-    if ( SfxItemState::SET == rSet.GetItemState(rPool.GetWhich(SID_ATTR_WELCOMESCREEN ), true, &pItem))
-    {
-        DBG_ASSERT(dynamic_cast< const SfxBoolItem *>( pItem ) !=  nullptr, "BoolItem expected");
-        aHelpOptions.SetWelcomeScreen( static_cast<const SfxBoolItem *>(pItem)->GetValue() );
-    }
-
-    // WelcomeScreen
-    if ( SfxItemState::SET == rSet.GetItemState(rPool.GetWhich(SID_WELCOMESCREEN_RESET ), true, &pItem))
-    {
-        DBG_ASSERT(dynamic_cast< const SfxBoolItem *>( pItem ) !=  nullptr, "BoolItem expected");
-        bool bReset = static_cast<const SfxBoolItem *>(pItem)->GetValue();
-        if ( bReset )
-        {
-            OSL_FAIL( "Not implemented, may be EOL!" );
-        }                                                   }
-
     if ( SfxItemState::SET == rSet.GetItemState(rPool.GetWhich(SID_HELP_STYLESHEET ), true, &pItem))
     {
         DBG_ASSERT(dynamic_cast< const SfxStringItem *>( pItem ) !=  nullptr, "StringItem expected");
@@ -746,7 +691,7 @@ void SfxApplication::SetOptions_Impl( const SfxItemSet& rSet )
             static_cast< SfxStringItem const * >(pItem)->GetValue(), batch);
     }
 
-    // Secure-Referers
+    // Secure-Referrer
     if ( SfxItemState::SET == rSet.GetItemState(SID_SECURE_URL, true, &pItem))
     {
         DBG_ASSERT(dynamic_cast< const SfxStringListItem *>( pItem ) !=  nullptr, "StringListItem expected");
@@ -881,14 +826,7 @@ void SfxApplication::NotifyEvent( const SfxEventHint& rEventHint, bool bSynchron
 
     if ( bSynchron )
     {
-#ifdef DBG_UTIL
-        if (!pDoc)
-        {
-            OStringBuffer aTmp("SfxEvent: ");
-            aTmp.append(OUStringToOString(rEventHint.GetEventName(), RTL_TEXTENCODING_UTF8));
-            OSL_TRACE( "%s", aTmp.getStr() );
-        }
-#endif
+        SAL_INFO_IF(!pDoc, "sfx.appl", "SfxEvent: " << rEventHint.GetEventName());
         Broadcast(rEventHint);
         if ( pDoc )
             pDoc->Broadcast( rEventHint );
