@@ -18,7 +18,7 @@
  */
 
 
-#if defined(WNT)
+#if defined(_WIN32)
 #include <prewin.h>
 #include <postwin.h>
 #endif
@@ -47,9 +47,6 @@
 
 #include <unotools/securityoptions.hxx>
 
-#define DDELINK_ERROR_APP   1
-#define DDELINK_ERROR_DATA  2
-
 using namespace ::com::sun::star::uno;
 
 namespace sfx2
@@ -62,15 +59,15 @@ class SvDDELinkEditDialog : public ModalDialog
     VclPtr<Edit>            m_pEdDdeItem;
     VclPtr<OKButton>        m_pOKButton;
 
-    DECL_LINK( EditHdl_Impl, Edit* );
+    DECL_LINK( EditHdl_Impl, Edit&, void );
 public:
-    SvDDELinkEditDialog( vcl::Window* pParent, SvBaseLink* );
-    virtual ~SvDDELinkEditDialog();
-    virtual void dispose() SAL_OVERRIDE;
+    SvDDELinkEditDialog( vcl::Window* pParent, SvBaseLink const * );
+    virtual ~SvDDELinkEditDialog() override;
+    virtual void dispose() override;
     OUString GetCmd() const;
 };
 
-SvDDELinkEditDialog::SvDDELinkEditDialog( vcl::Window* pParent, SvBaseLink* pLink )
+SvDDELinkEditDialog::SvDDELinkEditDialog( vcl::Window* pParent, SvBaseLink const * pLink )
     : ModalDialog( pParent, "LinkEditDialog", "sfx/ui/linkeditdialog.ui" )
 {
     get(m_pOKButton, "ok");
@@ -113,19 +110,18 @@ OUString SvDDELinkEditDialog::GetCmd() const
     return sRet;
 }
 
-IMPL_LINK( SvDDELinkEditDialog, EditHdl_Impl, Edit *, )
+IMPL_LINK_NOARG( SvDDELinkEditDialog, EditHdl_Impl, Edit&, void)
 {
     m_pOKButton->Enable( !m_pEdDdeApp->GetText().isEmpty() &&
                          !m_pEdDdeTopic->GetText().isEmpty() &&
                          !m_pEdDdeItem->GetText().isEmpty() );
-    return 0;
 }
 
 SvDDEObject::SvDDEObject()
-    : pConnection( 0 ), pLink( 0 ), pRequest( 0 ), pGetData( 0 ), nError( 0 )
+    : pConnection( nullptr ), pLink( nullptr ), pRequest( nullptr ), pGetData( nullptr )
 {
     SetUpdateTimeout( 100 );
-    bWaitForData = sal_False;
+    bWaitForData = false;
 }
 
 SvDDEObject::~SvDDEObject()
@@ -135,7 +131,7 @@ SvDDEObject::~SvDDEObject()
     delete pConnection;
 }
 
-bool SvDDEObject::GetData( ::com::sun::star::uno::Any & rData /*out param*/,
+bool SvDDEObject::GetData( css::uno::Any & rData /*out param*/,
                             const OUString & rMimeType,
                             bool bSynchron )
 {
@@ -149,15 +145,13 @@ bool SvDDEObject::GetData( ::com::sun::star::uno::Any & rData /*out param*/,
 
         delete pConnection;
         pConnection = new DdeConnection( sServer, sTopic );
-        if( pConnection->GetError() )
-            nError = DDELINK_ERROR_APP;
     }
 
     if( bWaitForData ) // we are in an rekursive loop, get out again
         return false;
 
     // Lock against Reentrance
-    bWaitForData = sal_True;
+    bWaitForData = true;
 
     // if you want to print, we'll wait until the data is available
     if( bSynchron )
@@ -172,17 +166,13 @@ bool SvDDEObject::GetData( ::com::sun::star::uno::Any & rData /*out param*/,
             aReq.Execute();
         } while( aReq.GetError() && ImplHasOtherFormat( aReq ) );
 
-        if( pConnection->GetError() )
-            nError = DDELINK_ERROR_DATA;
-
-        bWaitForData = sal_False;
+        bWaitForData = false;
     }
     else
     {
         // otherwise it will be executed asynchronously
         {
-            if( pRequest )
-                delete pRequest;
+            delete pRequest;
 
             pRequest = new DdeRequest( *pConnection, sItem );
             pRequest->SetDataHdl( LINK( this, SvDDEObject, ImplGetDDEData ) );
@@ -192,8 +182,7 @@ bool SvDDEObject::GetData( ::com::sun::star::uno::Any & rData /*out param*/,
             pRequest->Execute();
         }
 
-        OUString aEmptyStr;
-        rData <<= aEmptyStr;
+        rData <<= OUString();
     }
     return 0 == pConnection->GetError();
 }
@@ -231,18 +220,15 @@ bool SvDDEObject::Connect( SvBaseLink * pSvLink )
         bool bSysTopic = false;
         if (!sTopic.equalsIgnoreAsciiCase("SYSTEM"))
         {
-            DdeConnection aTmp(sServer, OUString("SYSTEM"));
+            DdeConnection aTmp(sServer, "SYSTEM");
             bSysTopic = !aTmp.GetError();
         }
 
         if( bSysTopic )
         {
             // if the system topic works then the server is up but just doesn't know the original topic
-            nError = DDELINK_ERROR_DATA;
             return false;
         }
-
-        nError = DDELINK_ERROR_APP;
     }
 
     if( SfxLinkUpdateMode::ALWAYS == nLinkType && !pLink && !pConnection->GetError() )
@@ -268,13 +254,13 @@ bool SvDDEObject::Connect( SvBaseLink * pSvLink )
     return true;
 }
 
-void SvDDEObject::Edit( vcl::Window* pParent, sfx2::SvBaseLink* pBaseLink, const Link<>& rEndEditHdl )
+void SvDDEObject::Edit( vcl::Window* pParent, sfx2::SvBaseLink* pBaseLink, const Link<const OUString&, void>& rEndEditHdl )
 {
     ScopedVclPtrInstance< SvDDELinkEditDialog > aDlg(pParent, pBaseLink);
     if ( RET_OK == aDlg->Execute() && rEndEditHdl.IsSet() )
     {
         OUString sCommand = aDlg->GetCmd();
-        rEndEditHdl.Call( &sCommand );
+        rEndEditHdl.Call( sCommand );
     }
 }
 
@@ -309,14 +295,8 @@ bool SvDDEObject::ImplHasOtherFormat( DdeTransaction& rReq )
 }
 
 bool SvDDEObject::IsPending() const
-/*  [Description]
-
+/*
     The method determines whether the data-object can be read from a DDE.
-
-    Returned is the following:
-        ERRCODE_NONE                    if it has been completely read
-        ERRCODE_SO_PENDING              if it has not been completely read
-        ERRCODE_SO_FALSE                otherwise
 */
 {
     return bWaitForData;
@@ -327,7 +307,7 @@ bool SvDDEObject::IsDataComplete() const
     return bWaitForData;
 }
 
-IMPL_LINK( SvDDEObject, ImplGetDDEData, DdeData*, pData )
+IMPL_LINK( SvDDEObject, ImplGetDDEData, const DdeData*, pData, void )
 {
     SotClipboardFormatId nFmt = pData->GetFormat();
     switch( nFmt )
@@ -340,14 +320,14 @@ IMPL_LINK( SvDDEObject, ImplGetDDEData, DdeData*, pData )
 
     default:
         {
-            const sal_Char* p = static_cast<sal_Char const *>(pData->operator const void*());
-            long nLen = SotClipboardFormatId::STRING == nFmt ? (p ? strlen( p ) : 0) : (long)*pData;
+            const sal_Char* p = static_cast<sal_Char const *>(pData->getData());
+            long nLen = SotClipboardFormatId::STRING == nFmt ? (p ? strlen( p ) : 0) : pData->getSize();
 
             Sequence< sal_Int8 > aSeq( reinterpret_cast<const sal_Int8*>(p), nLen );
             if( pGetData )
             {
                 *pGetData <<= aSeq;  // Copy Data
-                pGetData = 0;        // reset the pointer here
+                pGetData = nullptr;        // reset the pointer here
             }
             else
             {
@@ -355,20 +335,17 @@ IMPL_LINK( SvDDEObject, ImplGetDDEData, DdeData*, pData )
                 aVal <<= aSeq;
                 DataChanged( SotExchange::GetFormatMimeType(
                                                 pData->GetFormat() ), aVal );
-                bWaitForData = sal_False;
+                bWaitForData = false;
             }
         }
     }
-
-    return 0;
 }
 
-IMPL_LINK( SvDDEObject, ImplDoneDDEData, void*, pData )
+IMPL_LINK( SvDDEObject, ImplDoneDDEData, bool, bValid, void )
 {
-    bool bValid = (bool)reinterpret_cast<sal_uIntPtr>(pData);
     if( !bValid && ( pRequest || pLink ))
     {
-        DdeTransaction* pReq = 0;
+        DdeTransaction* pReq = nullptr;
         if( !pLink || ( pLink && pLink->IsBusy() ))
             pReq = pRequest;  // only the one that is ready
         else if( pRequest && pRequest->IsBusy() )
@@ -382,15 +359,13 @@ IMPL_LINK( SvDDEObject, ImplDoneDDEData, void*, pData )
             }
             else if( pReq == pRequest )
             {
-                bWaitForData = sal_False;
+                bWaitForData = false;
             }
         }
     }
     else
         // End waiting
-        bWaitForData = sal_False;
-
-    return 0;
+        bWaitForData = false;
 }
 
 }
