@@ -19,24 +19,12 @@
 
 
 #include <sfx2/sfxresid.hxx>
-#include "tools/resmgr.hxx"
+#include <unotools/resmgr.hxx>
 
-static ResMgr* pMgr=nullptr;
-
-ResMgr* SfxResMgr::GetResMgr()
+OUString SfxResId(const char* pId)
 {
-    if ( !pMgr )
-    {
-        pMgr = ResMgr::CreateResMgr("sfx");
-    }
-
-    return pMgr;
+    static std::locale loc = Translate::Create("sfx");
+    return Translate::get(pId, loc);
 }
 
-void SfxResMgr::DeleteResMgr()
-{
-    DELETEZ( pMgr );
-}
-
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
