@@ -18,7 +18,7 @@
  */
 
 
-#include <boost/scoped_ptr.hpp>
+#include <memory>
 
 #include <vcl/msgbox.hxx>
 #include <svl/lstner.hxx>
@@ -30,7 +30,6 @@
 
 #include <rtl/ustring.h>
 #include <com/sun/star/uno/Any.hxx>
-#include <framework/eventsconfiguration.hxx>
 #include <comphelper/processfactory.hxx>
 #include <sfx2/evntconf.hxx>
 
@@ -39,7 +38,7 @@
 #include <sfx2/objsh.hxx>
 #include <sfx2/dispatch.hxx>
 #include <sfx2/sfxresid.hxx>
-#include "eventsupplier.hxx"
+#include <eventsupplier.hxx>
 
 #include <com/sun/star/beans/PropertyValue.hpp>
 #include <com/sun/star/container/XNameReplace.hpp>
@@ -49,8 +48,6 @@
 #include <com/sun/star/uno/Reference.hxx>
 
 
-TYPEINIT1(SfxEventNamesItem, SfxPoolItem);
-
 using namespace com::sun::star;
 
 SfxEventNamesList& SfxEventNamesList::operator=( const SfxEventNamesList& rTbl )
@@ -67,14 +64,14 @@ SfxEventNamesList& SfxEventNamesList::operator=( const SfxEventNamesList& rTbl )
 
 void SfxEventNamesList::DelDtor()
 {
-    for ( size_t i = 0, n = aEventNamesList.size(); i < n; ++i )
-        delete aEventNamesList[ i ];
+    for (SfxEventName* i : aEventNamesList)
+        delete i;
     aEventNamesList.clear();
 }
 
 bool SfxEventNamesItem::operator==( const SfxPoolItem& rAttr ) const
 {
-    DBG_ASSERT( SfxPoolItem::operator==(rAttr), "unequal types" );
+    assert(SfxPoolItem::operator==(rAttr));
 
     const SfxEventNamesList& rOwn = aEventsList;
     const SfxEventNamesList& rOther = static_cast<const SfxEventNamesItem&>( rAttr ).aEventsList;
@@ -97,10 +94,10 @@ bool SfxEventNamesItem::operator==( const SfxPoolItem& rAttr ) const
 }
 
 bool SfxEventNamesItem::GetPresentation( SfxItemPresentation,
-                                    SfxMapUnit,
-                                    SfxMapUnit,
-                                    OUString &rText,
-                                    const IntlWrapper* ) const
+                                         MapUnit,
+                                         MapUnit,
+                                         OUString &rText,
+                                         const IntlWrapper& ) const
 {
     rText.clear();
     return false;
@@ -111,33 +108,18 @@ SfxPoolItem* SfxEventNamesItem::Clone( SfxItemPool *) const
     return new SfxEventNamesItem(*this);
 }
 
-SfxPoolItem* SfxEventNamesItem::Create(SvStream &, sal_uInt16) const
-{
-    OSL_FAIL("not streamable!");
-    return new SfxEventNamesItem(Which());
-}
-
-SvStream& SfxEventNamesItem::Store(SvStream &rStream, sal_uInt16 ) const
-{
-    OSL_FAIL("not streamable!");
-    return rStream;
-}
-
 sal_uInt16 SfxEventNamesItem::GetVersion( sal_uInt16 ) const
 {
     OSL_FAIL("not streamable!");
     return 0;
 }
 
-void SfxEventNamesItem::AddEvent( const OUString& rName, const OUString& rUIName, sal_uInt16 nID )
+void SfxEventNamesItem::AddEvent( const OUString& rName, const OUString& rUIName, SvMacroItemId nID )
 {
     aEventsList.push_back( new SfxEventName( nID, rName, !rUIName.isEmpty() ? rUIName : rName ) );
 }
 
 
-
-
-
 uno::Any CreateEventData_Impl( const SvxMacro *pMacro )
 {
 /*
@@ -159,18 +141,14 @@ uno::Any CreateEventData_Impl( const SvxMacro *pMacro )
             uno::Sequence < beans::PropertyValue > aProperties(3);
             beans::PropertyValue *pValues = aProperties.getArray();
 
-            OUString aType(STAR_BASIC );
-            OUString aLib  = pMacro->GetLibName();
-            OUString aMacro = pMacro->GetMacName();
-
             pValues[ 0 ].Name = PROP_EVENT_TYPE;
-            pValues[ 0 ].Value <<= aType;
+            pValues[ 0 ].Value <<= OUString("STAR_BASIC");
 
             pValues[ 1 ].Name = PROP_LIBRARY;
-            pValues[ 1 ].Value <<= aLib;
+            pValues[ 1 ].Value <<= pMacro->GetLibName();
 
             pValues[ 2 ].Name = PROP_MACRO_NAME;
-            pValues[ 2 ].Value <<= aMacro;
+            pValues[ 2 ].Value <<= pMacro->GetMacName();
 
             aEventData <<= aProperties;
         }
@@ -179,14 +157,11 @@ uno::Any CreateEventData_Impl( const SvxMacro *pMacro )
             uno::Sequence < beans::PropertyValue > aProperties(2);
             beans::PropertyValue *pValues = aProperties.getArray();
 
-            OUString aLib   = pMacro->GetLibName();
-            OUString aMacro = pMacro->GetMacName();
-
             pValues[ 0 ].Name = PROP_EVENT_TYPE;
-            pValues[ 0 ].Value <<= aLib;
+            pValues[ 0 ].Value <<= pMacro->GetLibName();
 
             pValues[ 1 ].Name = PROP_SCRIPT;
-            pValues[ 1 ].Value <<= aMacro;
+            pValues[ 1 ].Value <<= pMacro->GetMacName();
 
             aEventData <<= aProperties;
         }
@@ -195,13 +170,11 @@ uno::Any CreateEventData_Impl( const SvxMacro *pMacro )
             uno::Sequence < beans::PropertyValue > aProperties(2);
             beans::PropertyValue *pValues = aProperties.getArray();
 
-            OUString aMacro  = pMacro->GetMacName();
-
             pValues[ 0 ].Name = PROP_EVENT_TYPE;
             pValues[ 0 ].Value <<= OUString(SVX_MACRO_LANGUAGE_JAVASCRIPT);
 
             pValues[ 1 ].Name = PROP_MACRO_NAME;
-            pValues[ 1 ].Value <<= aMacro;
+            pValues[ 1 ].Value <<= pMacro->GetMacName();
 
             aEventData <<= aProperties;
         }
@@ -220,18 +193,17 @@ uno::Any CreateEventData_Impl( const SvxMacro *pMacro )
 }
 
 
-void PropagateEvent_Impl( SfxObjectShell *pDoc, const OUString& aEventName, const SvxMacro* pMacro )
+void PropagateEvent_Impl( SfxObjectShell const *pDoc, const OUString& aEventName, const SvxMacro* pMacro )
 {
     uno::Reference < document::XEventsSupplier > xSupplier;
     if ( pDoc )
     {
-        xSupplier = uno::Reference < document::XEventsSupplier >( pDoc->GetModel(), uno::UNO_QUERY );
+        xSupplier.set( pDoc->GetModel(), uno::UNO_QUERY );
     }
     else
     {
-        xSupplier = uno::Reference < document::XEventsSupplier >
-                ( frame::theGlobalEventBroadcaster::get(::comphelper::getProcessComponentContext()),
-                  uno::UNO_QUERY );
+        xSupplier.set( frame::theGlobalEventBroadcaster::get(::comphelper::getProcessComponentContext()),
+                       uno::UNO_QUERY );
     }
 
     if ( xSupplier.is() )
@@ -245,34 +217,34 @@ void PropagateEvent_Impl( SfxObjectShell *pDoc, const OUString& aEventName, cons
             {
                 xEvents->replaceByName( aEventName, aEventData );
             }
-            catch( const ::com::sun::star::lang::IllegalArgumentException& )
+            catch( const css::lang::IllegalArgumentException& )
             {
                 SAL_WARN( "sfx.config", "PropagateEvents_Impl: caught IllegalArgumentException" );
             }
-            catch( const ::com::sun::star::container::NoSuchElementException& )
+            catch( const css::container::NoSuchElementException& )
             {
                 SAL_WARN( "sfx.config", "PropagateEvents_Impl: caught NoSuchElementException" );
             }
         }
         else {
-            DBG_WARNING( "PropagateEvents_Impl: Got unknown event" );
+            SAL_INFO( "sfx.config", "PropagateEvents_Impl: Got unknown event" );
         }
     }
 }
 
 
-void SfxEventConfiguration::ConfigureEvent( const OUString& aName, const SvxMacro& rMacro, SfxObjectShell *pDoc )
+void SfxEventConfiguration::ConfigureEvent( const OUString& aName, const SvxMacro& rMacro, SfxObjectShell const *pDoc )
 {
-    boost::scoped_ptr<SvxMacro> pMacro;
+    std::unique_ptr<SvxMacro> pMacro;
     if ( rMacro.HasMacro() )
         pMacro.reset( new SvxMacro( rMacro.GetMacName(), rMacro.GetLibName(), rMacro.GetScriptType() ) );
-    PropagateEvent_Impl( pDoc ? pDoc : 0, aName, pMacro.get() );
+    PropagateEvent_Impl( pDoc ? pDoc : nullptr, aName, pMacro.get() );
 }
 
 
-SvxMacro* SfxEventConfiguration::ConvertToMacro( const com::sun::star::uno::Any& rElement, SfxObjectShell* pDoc, bool bBlowUp )
+SvxMacro* SfxEventConfiguration::ConvertToMacro( const css::uno::Any& rElement, SfxObjectShell* pDoc )
 {
-    return SfxEvents_Impl::ConvertToMacro( rElement, pDoc, bBlowUp );
+    return SfxEvents_Impl::ConvertToMacro( rElement, pDoc, true/*bBlowUp*/ );
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
