@@ -19,10 +19,7 @@
 
 #include <sfx2/minfitem.hxx>
 
-// STATIC DATA -----------------------------------------------------------
-
-SfxPoolItem* SfxMacroInfoItem::CreateDefault() { DBG_ASSERT(false, "No SfxMacroInfItem factory available"); return nullptr; }
-
+SfxPoolItem* SfxMacroInfoItem::CreateDefault() { SAL_WARN( "sfx", "No SfxMacroInfItem factory available"); return nullptr; }
 
 
 SfxMacroInfoItem::SfxMacroInfoItem(
@@ -41,22 +38,6 @@ SfxMacroInfoItem::SfxMacroInfoItem(
 {
 }
 
-
-
-// copy constructor
-
-SfxMacroInfoItem::SfxMacroInfoItem(const SfxMacroInfoItem& rCopy):
-    SfxPoolItem(rCopy),
-    pBasicManager(rCopy.pBasicManager),
-    aLibName(rCopy.aLibName),
-    aModuleName(rCopy.aModuleName),
-    aMethodName(rCopy.aMethodName),
-    aCommentText(rCopy.aCommentText)
-{
-}
-
-
-
 // op ==
 
 bool SfxMacroInfoItem::operator==( const SfxPoolItem& rCmp) const
@@ -71,14 +52,12 @@ bool SfxMacroInfoItem::operator==( const SfxPoolItem& rCmp) const
 }
 
 
-
 SfxPoolItem *SfxMacroInfoItem::Clone( SfxItemPool *) const
 {
     return new SfxMacroInfoItem(*this);
 }
 
 
-
 OUString SfxMacroInfoItem::GetQualifiedName() const
 {
     OUString aMacroName = aLibName;
