@@ -20,7 +20,7 @@
 #include "filtergrouping.hxx"
 #include <sfx2/fcontnr.hxx>
 #include <sfx2/filedlghelper.hxx>
-#include <sfx2/sfx.hrc>
+#include <sfx2/strings.hrc>
 #include <sfx2/docfac.hxx>
 #include <sfx2/sfxresid.hxx>
 #include <osl/thread.h>
@@ -31,6 +31,7 @@
 #include <unotools/confignode.hxx>
 #include <comphelper/processfactory.hxx>
 #include <comphelper/sequenceashashmap.hxx>
+#include <comphelper/sequence.hxx>
 #include <comphelper/string.hxx>
 #include <tools/diagnose_ex.h>
 
@@ -106,7 +107,7 @@ namespace sfx2
     the filter itself) nor indirectly (as part of another local group).</p>
 
     <p>The only exception are filters which are part of a global class <em>and</em> a local class. This is allowed.
-    Being cotained in two local classes isn't.</p>
+    Being contained in two local classes isn't.</p>
 
     <p>So that's all what you need to know: Understand the concept of "filter classes" (a filter class combines
     different filters and acts as if it's a filter itself) and the concept of groups (a group just describes a
@@ -118,8 +119,6 @@ namespace sfx2
     */
 
 
-
-
     typedef StringPair                          FilterDescriptor;   // a single filter or a filter class (display name and filter mask)
     typedef ::std::list< FilterDescriptor >     FilterGroup;        // a list of single filter entries
     typedef ::std::list< FilterGroup >          GroupedFilterList;  // a list of all filters, already grouped
@@ -148,23 +147,19 @@ namespace sfx2
 // = reading of configuration data
 
 
-
     void lcl_ReadFilterClass( const OConfigurationNode& _rClassesNode, const OUString& _rLogicalClassName,
         FilterClass& /* [out] */ _rClass )
     {
-        static const char sDisplaNameNodeName[] = "DisplayName";
-        static const char sSubFiltersNodeName[] = "Filters";
-
             // the description node for the current class
         OConfigurationNode aClassDesc = _rClassesNode.openNode( _rLogicalClassName );
 
         // the values
-        aClassDesc.getNodeValue( sDisplaNameNodeName ) >>= _rClass.sDisplayName;
-        aClassDesc.getNodeValue( sSubFiltersNodeName ) >>= _rClass.aSubFilters;
+        aClassDesc.getNodeValue( "DisplayName" ) >>= _rClass.sDisplayName;
+        aClassDesc.getNodeValue( "Filters" ) >>= _rClass.aSubFilters;
     }
 
 
-    struct CreateEmptyClassRememberPos : public ::std::unary_function< FilterName, void >
+    struct CreateEmptyClassRememberPos
     {
     protected:
         FilterClassList&        m_rClassList;
@@ -181,17 +176,17 @@ namespace sfx2
         void operator() ( const FilterName& _rLogicalFilterName )
         {
             // insert a new (empty) class
-            m_rClassList.push_back( FilterClass() );
+            m_rClassList.emplace_back( );
             // get the position of this new entry
             FilterClassList::iterator aInsertPos = m_rClassList.end();
             --aInsertPos;
             // remember this position
-            m_rClassesReferrer.insert( FilterClassReferrer::value_type( _rLogicalFilterName, aInsertPos ) );
+            m_rClassesReferrer.emplace( _rLogicalFilterName, aInsertPos );
         }
     };
 
 
-    struct ReadGlobalFilter : public ::std::unary_function< FilterName, void >
+    struct ReadGlobalFilter
     {
     protected:
         OConfigurationNode      m_aClassesNode;
@@ -261,14 +256,14 @@ namespace sfx2
             _rFilterClassification.openNode( "GlobalFilters/Classes" );
         Sequence< OUString > aFilterClasses = aFilterClassesNode.getNodeNames();
         ::std::for_each(
-            aFilterClasses.getConstArray(),
-            aFilterClasses.getConstArray() + aFilterClasses.getLength(),
+            aFilterClasses.begin(),
+            aFilterClasses.end(),
             ReadGlobalFilter( aFilterClassesNode, aClassReferrer )
         );
     }
 
 
-    struct ReadLocalFilter : public ::std::unary_function< FilterName, void >
+    struct ReadLocalFilter
     {
     protected:
         OConfigurationNode      m_aClassesNode;
@@ -304,8 +299,8 @@ namespace sfx2
         Sequence< OUString > aFilterClasses = aFilterClassesNode.getNodeNames();
 
         ::std::for_each(
-            aFilterClasses.getConstArray(),
-            aFilterClasses.getConstArray() + aFilterClasses.getLength(),
+            aFilterClasses.begin(),
+            aFilterClasses.end(),
             ReadLocalFilter( aFilterClassesNode, _rLocalClasses )
         );
     }
@@ -336,9 +331,8 @@ namespace sfx2
 // = grouping and classifying
 
 
-
     // a struct which adds helps remembering a reference to a class entry
-    struct ReferToFilterEntry : public ::std::unary_function< FilterName, void >
+    struct ReferToFilterEntry
     {
     protected:
         FilterGroupEntryReferrer&   m_rEntryReferrer;
@@ -355,7 +349,7 @@ namespace sfx2
         void operator() ( const FilterName& _rName )
         {
             ::std::pair< FilterGroupEntryReferrer::iterator, bool > aInsertRes =
-            m_rEntryReferrer.insert( FilterGroupEntryReferrer::value_type( _rName, m_aClassPos ) );
+            m_rEntryReferrer.emplace( _rName, m_aClassPos );
             SAL_WARN_IF(
                 !aInsertRes.second, "sfx.dialog",
                 "already have an element for " << _rName);
@@ -363,7 +357,7 @@ namespace sfx2
     };
 
 
-    struct FillClassGroup : public ::std::unary_function< FilterClass, void >
+    struct FillClassGroup
     {
     protected:
         FilterGroup&                m_rClassGroup;
@@ -393,8 +387,8 @@ namespace sfx2
             // and for all the sub filters of the class, remember the class
             // (respectively the position of the class it the group)
             ::std::for_each(
-                _rClass.aSubFilters.getConstArray(),
-                _rClass.aSubFilters.getConstArray() + _rClass.aSubFilters.getLength(),
+                _rClass.aSubFilters.begin(),
+                _rClass.aSubFilters.end(),
                 ReferToFilterEntry( m_rClassReferrer, aClassEntryPos )
             );
         }
@@ -409,11 +403,11 @@ namespace sfx2
     }
 
 
-    struct CheckAppendSingleWildcard : public ::std::unary_function< OUString, void >
+    struct CheckAppendSingleWildcard
     {
         OUString& _rToBeExtended;
 
-        CheckAppendSingleWildcard( OUString& _rBase ) : _rToBeExtended( _rBase ) { }
+        explicit CheckAppendSingleWildcard( OUString& _rBase ) : _rToBeExtended( _rBase ) { }
 
         void operator() ( const OUString& _rWC )
         {
@@ -421,14 +415,13 @@ namespace sfx2
             sal_Int32 nExistentPos = _rToBeExtended.indexOf( _rWC );
             if  ( -1 < nExistentPos )
             {   // found this wildcard (already part of _rToBeExtended)
-                const sal_Unicode* pBuffer = _rToBeExtended.getStr();
                 if  (   ( 0 == nExistentPos )
-                    ||  ( s_cWildcardSeparator == pBuffer[ nExistentPos - 1 ] )
+                    ||  ( s_cWildcardSeparator == _rToBeExtended[ nExistentPos - 1 ] )
                     )
                 {   // the wildcard really starts at this position (it starts at pos 0 or the previous character is a separator
                     sal_Int32 nExistentWCEnd = nExistentPos + _rWC.getLength();
                     if  (   ( _rToBeExtended.getLength() == nExistentWCEnd )
-                        ||  ( s_cWildcardSeparator == pBuffer[ nExistentWCEnd ] )
+                        ||  ( s_cWildcardSeparator == _rToBeExtended[ nExistentWCEnd ] )
                         )
                     {   // it's really the complete wildcard we found
                         // (not something like _rWC being "*.t" and _rToBeExtended containing "*.txt")
@@ -446,13 +439,13 @@ namespace sfx2
 
 
     // a helper struct which adds a fixed (Sfx-)filter to a filter group entry given by iterator
-    struct AppendWildcardToDescriptor : public ::std::unary_function< FilterGroupEntryReferrer::value_type, void >
+    struct AppendWildcardToDescriptor
     {
     protected:
         ::std::vector< OUString > aWildCards;
 
     public:
-        AppendWildcardToDescriptor( const OUString& _rWildCard );
+        explicit AppendWildcardToDescriptor( const OUString& _rWildCard );
 
         // operate on a single class entry
         void operator() ( const FilterGroupEntryReferrer::value_type& _rClassReference )
@@ -483,7 +476,7 @@ namespace sfx2
         {
             if ( ( s_cWildcardSeparator == *pTokenLoop ) && ( pTokenLoop > pTokenStart ) )
             {   // found a new token separator (and a non-empty token)
-                aWildCards.push_back( OUString( pTokenStart, pTokenLoop - pTokenStart ) );
+                aWildCards.emplace_back( pTokenStart, pTokenLoop - pTokenStart );
 
                 // search the start of the next token
                 while ( ( pTokenStart != pTokenLoopEnd ) && ( *pTokenStart != s_cWildcardSeparator ) )
@@ -499,7 +492,7 @@ namespace sfx2
         }
         if ( pTokenLoop > pTokenStart )
             // the last one ....
-            aWildCards.push_back( OUString( pTokenStart, pTokenLoop - pTokenStart ) );
+            aWildCards.emplace_back( pTokenStart, pTokenLoop - pTokenStart );
     }
 
 
@@ -519,7 +512,7 @@ namespace sfx2
             FillClassGroup( rGlobalFilters, _rGlobalClassesRef )
         );
             // now we have:
-            // in rGlobalFilters: a list of FilterDescriptor's, where each's discriptor's display name is set to the name of a class
+            // in rGlobalFilters: a list of FilterDescriptor's, where each's descriptor's display name is set to the name of a class
             // in aGlobalClassesRef: a mapping from logical filter names to positions within rGlobalFilters
             //  this way, if we encounter an arbitrary filter, we can easily (and efficient) check if it belongs to a global class
             //  and modify the descriptor for this class accordingly
@@ -530,10 +523,10 @@ namespace sfx2
             MapGroupEntry2GroupEntry;
             // this is not really a map - it's just called this way because it is used as a map
 
-    struct FindGroupEntry : public ::std::unary_function< MapGroupEntry2GroupEntry::value_type, sal_Bool >
+    struct FindGroupEntry
     {
         FilterGroupEntryReferrer::mapped_type aLookingFor;
-        FindGroupEntry( FilterGroupEntryReferrer::mapped_type _rLookingFor ) : aLookingFor( _rLookingFor ) { }
+        explicit FindGroupEntry( FilterGroupEntryReferrer::mapped_type const & _rLookingFor ) : aLookingFor( _rLookingFor ) { }
 
         bool operator() ( const MapGroupEntry2GroupEntry::value_type& _rMapEntry )
         {
@@ -541,22 +534,19 @@ namespace sfx2
         }
     };
 
-    struct CopyGroupEntryContent : public ::std::unary_function< MapGroupEntry2GroupEntry::value_type, void >
+    struct CopyGroupEntryContent
     {
         void operator() ( const MapGroupEntry2GroupEntry::value_type& _rMapEntry )
         {
-#ifdef DBG_UTIL
-            FilterDescriptor aHaveALook = *_rMapEntry.first;
-#endif
             *_rMapEntry.second = *_rMapEntry.first;
         }
     };
 
 
-    struct CopyNonEmptyFilter : public ::std::unary_function< FilterDescriptor, void >
+    struct CopyNonEmptyFilter
     {
         FilterGroup& rTarget;
-        CopyNonEmptyFilter( FilterGroup& _rTarget ) :rTarget( _rTarget ) { }
+        explicit CopyNonEmptyFilter( FilterGroup& _rTarget ) :rTarget( _rTarget ) { }
 
         void operator() ( const FilterDescriptor& _rFilter )
         {
@@ -585,7 +575,7 @@ namespace sfx2
         // (this assumes that both numbers are the same, which, speaking strictly, must not hold - but it does, as we know ...)
         sal_Int32 nGlobalClasses = aGlobalClasses.size();
         while ( nGlobalClasses-- )
-            _rAllFilters.push_back( FilterGroup() );
+            _rAllFilters.emplace_back( );
 
 
         // for the local classes:
@@ -613,7 +603,7 @@ namespace sfx2
         OUString sFilterWildcard;
         OUString sFilterName;
         // loop through all the filters
-        for ( const SfxFilter* pFilter = _rFilterMatcher.First(); pFilter; pFilter = _rFilterMatcher.Next() )
+        for ( std::shared_ptr<const SfxFilter> pFilter = _rFilterMatcher.First(); pFilter; pFilter = _rFilterMatcher.Next() )
         {
             sFilterName = pFilter->GetFilterName();
             sFilterWildcard = pFilter->GetWildcard().getGlob();
@@ -627,8 +617,6 @@ namespace sfx2
             if ( aServiceName != aCurrentServiceName )
             {   // we reached a new group
 
-                OUString sDocServName = aServiceName;
-
                 // look for the place in _rAllFilters where this ne group belongs - this is determined
                 // by the order of classes in aGlobalClassNames
                 GroupedFilterList::iterator aGroupPos = _rAllFilters.begin();
@@ -639,14 +627,14 @@ namespace sfx2
                 StringArray::iterator aGlobalIter = aGlobalClassNames.begin();
                 while   (   ( aGroupPos != _rAllFilters.end() )
                         &&  ( aGlobalIter != aGlobalClassNames.end() )
-                        &&  ( *aGlobalIter != sDocServName )
+                        &&  ( *aGlobalIter != aServiceName )
                         )
                 {
                     ++aGlobalIter;
                     ++aGroupPos;
                 }
                 if ( aGroupPos != _rAllFilters.end() )
-                    // we found a global class name which matchies the doc service name -> fill the filters of this
+                    // we found a global class name which matches the doc service name -> fill the filters of this
                     // group in the respective prepared group
                     aCurrentGroup = aGroupPos;
                 else
@@ -674,7 +662,7 @@ namespace sfx2
             );
 
 
-            // add the filter to it's group
+            // add the filter to its group
 
             // for this, check if the filter is part of a local filter
             FilterGroupEntryReferrer::iterator aBelongsToLocal = aLocalClassesRef.find( sFilterName );
@@ -697,7 +685,7 @@ namespace sfx2
                     FilterGroup::iterator aInsertPos = aCurrentGroup->end();
                     --aInsertPos;
                     // remember this pos
-                    aLocalFinalPositions.push_back( MapGroupEntry2GroupEntry::value_type( aBelongsToLocal->second, aInsertPos ) );
+                    aLocalFinalPositions.emplace_back( aBelongsToLocal->second, aInsertPos );
                 }
             }
             else
@@ -727,7 +715,7 @@ namespace sfx2
     }
 
 
-    struct AppendFilter : public ::std::unary_function< FilterDescriptor, void >
+    struct AppendFilter
     {
         protected:
             Reference< XFilterManager >         m_xFilterManager;
@@ -761,15 +749,14 @@ namespace sfx2
 // = handling for the "all files" entry
 
 
-
     bool lcl_hasAllFilesFilter( TSortedFilterList& _rFilterMatcher, OUString& /* [out] */ _rAllFilterName )
     {
         bool        bHasAll = false;
-        _rAllFilterName = SfxResId( STR_SFX_FILTERNAME_ALL ).toString();
+        _rAllFilterName = SfxResId( STR_SFX_FILTERNAME_ALL );
 
 
         // check if there's already a filter <ALL>
-        for ( const SfxFilter* pFilter = _rFilterMatcher.First(); pFilter && !bHasAll; pFilter = _rFilterMatcher.Next() )
+        for ( std::shared_ptr<const SfxFilter> pFilter = _rFilterMatcher.First(); pFilter && !bHasAll; pFilter = _rFilterMatcher.Next() )
         {
             if ( pFilter->GetUIName() == _rAllFilterName )
                 bHasAll = true;
@@ -798,8 +785,7 @@ namespace sfx2
 // = filling an XFilterManager
 
 
-
-    struct AppendFilterGroup : public ::std::unary_function< FilterGroup, void >
+    struct AppendFilterGroup
     {
     protected:
         Reference< XFilterManager >         m_xFilterManager;
@@ -825,18 +811,11 @@ namespace sfx2
                     // create a representation of the group which is understandable by the XFilterGroupManager
                     if ( _rGroup.size() )
                     {
-                        Sequence< StringPair > aFilters( _rGroup.size() );
-                        ::std::copy(
-                            _rGroup.begin(),
-                            _rGroup.end(),
-                            aFilters.getArray()
-                        );
+                        Sequence< StringPair > aFilters( comphelper::containerToSequence(_rGroup) );
                         if ( _bAddExtension )
                         {
-                            StringPair* pFilters = aFilters.getArray();
-                            StringPair* pEnd = pFilters + aFilters.getLength();
-                            for ( ; pFilters != pEnd; ++pFilters )
-                                pFilters->First = addExtension( pFilters->First, pFilters->Second, true, *m_pFileDlgImpl );
+                            for ( StringPair & filter : aFilters )
+                                filter.First = addExtension( filter.First, filter.Second, true, *m_pFileDlgImpl );
                         }
                         m_xFilterGroupManager->appendFilterGroup( OUString(), aFilters );
                     }
@@ -863,7 +842,7 @@ namespace sfx2
     };
 
 
-    TSortedFilterList::TSortedFilterList(const ::com::sun::star::uno::Reference< ::com::sun::star::container::XEnumeration >& xFilterList)
+    TSortedFilterList::TSortedFilterList(const css::uno::Reference< css::container::XEnumeration >& xFilterList)
         : m_nIterator(0)
     {
         if (!xFilterList.is())
@@ -874,7 +853,7 @@ namespace sfx2
         {
             ::comphelper::SequenceAsHashMap lFilterProps (xFilterList->nextElement());
             OUString                 sFilterName  = lFilterProps.getUnpackedValueOrDefault(
-                                                             OUString("Name"),
+                                                             "Name",
                                                              OUString());
             if (!sFilterName.isEmpty())
                 m_lFilters.push_back(sFilterName);
@@ -882,27 +861,27 @@ namespace sfx2
     }
 
 
-    const SfxFilter* TSortedFilterList::First()
+    std::shared_ptr<const SfxFilter> TSortedFilterList::First()
     {
         m_nIterator = 0;
         return impl_getFilter(m_nIterator);
     }
 
 
-    const SfxFilter* TSortedFilterList::Next()
+    std::shared_ptr<const SfxFilter> TSortedFilterList::Next()
     {
         ++m_nIterator;
         return impl_getFilter(m_nIterator);
     }
 
 
-    const SfxFilter* TSortedFilterList::impl_getFilter(sal_Int32 nIndex)
+    std::shared_ptr<const SfxFilter> TSortedFilterList::impl_getFilter(sal_Int32 nIndex)
     {
         if (nIndex<0 || nIndex>=(sal_Int32)m_lFilters.size())
-            return 0;
+            return nullptr;
         const OUString& sFilterName = m_lFilters[nIndex];
         if (sFilterName.isEmpty())
-            return 0;
+            return nullptr;
         return SfxFilter::GetFilterByName(sFilterName);
     }
 
@@ -921,7 +900,7 @@ namespace sfx2
 
         // retrieve the default filter for this application module.
         // It must be set as first of the generated filter list.
-        const SfxFilter* pDefaultFilter = SfxFilterContainer::GetDefaultFilter_Impl(_rFactory);
+        std::shared_ptr<const SfxFilter> pDefaultFilter = SfxFilterContainer::GetDefaultFilter_Impl(_rFactory);
         // Only use one extension (#i32434#)
         // (and always the first if there are more than one)
         sExtension = pDefaultFilter->GetWildcard().getGlob().getToken(0, ';');
@@ -937,7 +916,7 @@ namespace sfx2
             SAL_WARN( "sfx.dialog", "Could not append DefaultFilter" << sUIName );
         }
 
-        for ( const SfxFilter* pFilter = _rFilterMatcher.First(); pFilter; pFilter = _rFilterMatcher.Next() )
+        for ( std::shared_ptr<const SfxFilter> pFilter = _rFilterMatcher.First(); pFilter; pFilter = _rFilterMatcher.Next() )
         {
             if (pFilter->GetName() == pDefaultFilter->GetName())
                 continue;
@@ -987,13 +966,8 @@ namespace sfx2
         std::vector< ExportFilter >         aFilterGroup;
         Reference< XFilterGroupManager >    xFilterGroupManager( _rxFilterManager, UNO_QUERY );
         OUString                     sTypeName;
-        const OUString               sWriterHTMLType( "generic_HTML" );
-        const OUString               sGraphicHTMLType( "graphic_HTML" );
-        const OUString               sXHTMLType( "XHTML_File" );
-        const OUString               sPDFType( "pdf_Portable_Document_Format" );
-        const OUString               sFlashType( "graphic_SWF" );
 
-        for ( const SfxFilter* pFilter = _rFilterMatcher.First(); pFilter; pFilter = _rFilterMatcher.Next() )
+        for ( std::shared_ptr<const SfxFilter> pFilter = _rFilterMatcher.First(); pFilter; pFilter = _rFilterMatcher.Next() )
         {
             sTypeName   = pFilter->GetTypeName();
             sUIName     = pFilter->GetUIName();
@@ -1001,12 +975,12 @@ namespace sfx2
             ExportFilter aExportFilter( sUIName, sExtensions );
 
             if ( nHTMLIndex == -1 &&
-                ( sTypeName.equals( sWriterHTMLType ) || sTypeName.equals( sGraphicHTMLType ) ) )
+                ( sTypeName == "generic_HTML" || sTypeName == "graphic_HTML" ) )
             {
                 aImportantFilterGroup.insert( aImportantFilterGroup.begin(), aExportFilter );
                 nHTMLIndex = 0;
             }
-            else if ( nXHTMLIndex == -1 && sTypeName.equals( sXHTMLType ) )
+            else if ( nXHTMLIndex == -1 && sTypeName == "XHTML_File" )
             {
                 std::vector< ExportFilter >::iterator aIter = aImportantFilterGroup.begin();
                 if ( nHTMLIndex == -1 )
@@ -1015,7 +989,7 @@ namespace sfx2
                     aImportantFilterGroup.insert( ++aIter, aExportFilter );
                 nXHTMLIndex = 0;
             }
-            else if ( nPDFIndex == -1 && sTypeName.equals( sPDFType ) )
+            else if ( nPDFIndex == -1 && sTypeName == "pdf_Portable_Document_Format" )
             {
                 std::vector< ExportFilter >::iterator aIter = aImportantFilterGroup.begin();
                 if ( nHTMLIndex != -1 )
@@ -1025,7 +999,7 @@ namespace sfx2
                 aImportantFilterGroup.insert( aIter, aExportFilter );
                 nPDFIndex = 0;
             }
-            else if ( nFlashIndex == -1 && sTypeName.equals( sFlashType ) )
+            else if ( nFlashIndex == -1 && sTypeName == "graphic_SWF" )
             {
                 std::vector< ExportFilter >::iterator aIter = aImportantFilterGroup.begin();
                 if ( nHTMLIndex != -1 )
@@ -1174,22 +1148,19 @@ namespace sfx2
                                   const OUString& _rExtension,
                                   bool _bForOpen, FileDialogHelper_Impl& _rFileDlgImpl )
     {
-        static const char sAllFilter[] = "(*.*)";
-        static const char sOpenBracket[] = " (";
-        static const char sCloseBracket[] = ")";
         OUString sRet = _rDisplayText;
 
-        if ( sRet.indexOf( sAllFilter ) == -1 )
+        if ( sRet.indexOf( "(*.*)" ) == -1 )
         {
             OUString sExt = _rExtension;
             if ( !_bForOpen )
             {
                 // show '*' in extensions only when opening a document
-                sExt = comphelper::string::remove(sExt, '*');
+                sExt = sExt.replaceAll("*", "");
             }
-            sRet += sOpenBracket;
+            sRet += " (";
             sRet += sExt;
-            sRet += sCloseBracket;
+            sRet += ")";
         }
         _rFileDlgImpl.addFilterPair( _rDisplayText, sRet );
         return sRet;
@@ -1199,5 +1170,4 @@ namespace sfx2
 }   // namespace sfx2
 
 
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
