@@ -18,6 +18,7 @@
  */
 
 #include <comphelper/string.hxx>
+#include <vcl/layout.hxx>
 #include <vcl/msgbox.hxx>
 #include <vcl/field.hxx>
 #include <svl/eitem.hxx>
@@ -26,26 +27,29 @@
 
 #include <sfx2/styfitem.hxx>
 #include <sfx2/styledlg.hxx>
+#include <sfx2/tabdlg.hxx>
 #include <sfx2/app.hxx>
 #include <sfx2/mgetempl.hxx>
 #include <sfx2/objsh.hxx>
-#include "sfxtypes.hxx"
+#include <sfxtypes.hxx>
 #include <sfx2/sfxresid.hxx>
 #include <sfx2/module.hxx>
 
-#include <sfx2/sfx.hrc>
-#include "dialog.hrc"
+#include <sfx2/templdlg.hxx>
+#include <templdgi.hxx>
+#include <sfx2/strings.hrc>
 
-#include <svl/style.hrc>
+#include <svl/stritem.hxx>
+#include <sfx2/dispatch.hxx>
 
 /*  SfxManageStyleSheetPage Constructor
  *
  *  initializes the list box with the templates
  */
-SfxManageStyleSheetPage::SfxManageStyleSheetPage(Window* pParent, const SfxItemSet& rAttrSet)
-    : SfxTabPage(pParent, "ManageStylePage", "sfx/ui/managestylepage.ui", rAttrSet)
-    , pStyle(&((SfxStyleDialog*)GetParentDialog())->GetStyleSheet())
-    , pItem(0)
+SfxManageStyleSheetPage::SfxManageStyleSheetPage(vcl::Window* pParent, const SfxItemSet& rAttrSet)
+    : SfxTabPage(pParent, "ManageStylePage", "sfx/ui/managestylepage.ui", &rAttrSet)
+    , pStyle(&static_cast<SfxStyleDialog*>(GetParentDialog())->GetStyleSheet())
+    , pItem(nullptr)
     , bModified(false)
     , aName(pStyle->GetName())
     , aFollow(pStyle->GetFollow())
@@ -61,8 +65,10 @@ SfxManageStyleSheetPage::SfxManageStyleSheetPage(Window* pParent, const SfxItemS
     m_pFollowLb->SetStyle(m_pFollowLb->GetStyle() | WB_SORT);
     const sal_Int32 nMaxWidth(62);
     m_pFollowLb->setMaxWidthChars(nMaxWidth);
+    get(m_pEditStyleBtn, "editstyle");
     get(m_pBaseFt, "linkedwithft");
     get(m_pBaseLb, "linkedwith");
+    get(m_pEditLinkStyleBtn, "editlinkstyle");
     m_pBaseLb->SetStyle(m_pBaseLb->GetStyle() | WB_SORT);
     m_pBaseLb->setMaxWidthChars(nMaxWidth);
     get(m_pFilterFt, "categoryft");
@@ -76,11 +82,20 @@ SfxManageStyleSheetPage::SfxManageStyleSheetPage(Window* pParent, const SfxItemS
     // this Page needs ExchangeSupport
     SetExchangeSupport();
 
-    ResMgr* pResMgr = SFX_APP()->GetModule_Impl()->GetResMgr();
-    OSL_ENSURE( pResMgr, "No ResMgr in Module" );
-    pFamilies = new SfxStyleFamilies( ResId( DLG_STYLE_DESIGNER, *pResMgr ) );
+    if ( aFollow == aName )
+        m_pEditStyleBtn->Disable();
+    else
+        m_pEditStyleBtn->Enable();
 
-    SfxStyleSheetBasePool* pPool = 0;
+    sal_Int32 linkSelectPos = m_pBaseLb->GetSelectedEntryPos();
+    if ( linkSelectPos == 0 )
+        m_pEditLinkStyleBtn->Disable();
+    else
+        m_pEditLinkStyleBtn->Enable();
+
+    pFamilies = SfxApplication::GetModule_Impl()->CreateStyleFamilies();
+
+    SfxStyleSheetBasePool* pPool = nullptr;
     SfxObjectShell* pDocShell = SfxObjectShell::Current();
 
     if ( pDocShell )
@@ -139,7 +154,7 @@ SfxManageStyleSheetPage::SfxManageStyleSheetPage(Window* pParent, const SfxItemS
     {
         if ( pStyle->HasClearParentSupport() )
             // the base template can be set to NULL
-            m_pBaseLb->InsertEntry( SfxResId(STR_NONE).toString() );
+            m_pBaseLb->InsertEntry( SfxResId(STR_NONE) );
 
         SfxStyleSheetBase* pPoolStyle = pPool->First();
 
@@ -162,7 +177,7 @@ SfxManageStyleSheetPage::SfxManageStyleSheetPage(Window* pParent, const SfxItemS
     size_t i;
     for ( i = 0; i < nCount; ++i )
     {
-        pItem = pFamilies->at( i );
+        pItem = &(pFamilies->at(i));
 
         if ( pItem->GetFamily() == pStyle->GetFamily() )
             break;
@@ -182,17 +197,17 @@ SfxManageStyleSheetPage::SfxManageStyleSheetPage(Window* pParent, const SfxItemS
 
         for ( i = 0; i < nCount; ++i )
         {
-            SfxFilterTupel* pTupel = rList[ i ];
+            const SfxFilterTupel& rTupel = rList[ i ];
 
-            if ( pTupel->nFlags != SFXSTYLEBIT_AUTO     &&
-                 pTupel->nFlags != SFXSTYLEBIT_USED     &&
-                 pTupel->nFlags != SFXSTYLEBIT_ALL_VISIBLE &&
-                 pTupel->nFlags != SFXSTYLEBIT_ALL )
+            if ( rTupel.nFlags != SFXSTYLEBIT_AUTO     &&
+                 rTupel.nFlags != SFXSTYLEBIT_USED     &&
+                 rTupel.nFlags != SFXSTYLEBIT_ALL_VISIBLE &&
+                 rTupel.nFlags != SFXSTYLEBIT_ALL )
             {
-                m_pFilterLb->InsertEntry( pTupel->aName, nIdx );
-                m_pFilterLb->SetEntryData(nIdx, (void*)(sal_IntPtr)i);
+                m_pFilterLb->InsertEntry( rTupel.aName, nIdx );
+                m_pFilterLb->SetEntryData(nIdx, reinterpret_cast<void*>(i));
 
-                if ( ( pTupel->nFlags & nMask ) == nMask )
+                if ( ( rTupel.nFlags & nMask ) == nMask )
                     nStyleFilterIdx = nIdx;
                 ++nIdx;
             }
@@ -204,7 +219,7 @@ SfxManageStyleSheetPage::SfxManageStyleSheetPage(Window* pParent, const SfxItemS
 
     if ( !m_pFilterLb->GetEntryCount() || !pStyle->IsUserDefined() )
     {
-        pItem = 0;
+        pItem = nullptr;
         m_pFilterFt->Disable();
         m_pFilterLb->Disable();
     }
@@ -220,29 +235,42 @@ SfxManageStyleSheetPage::SfxManageStyleSheetPage(Window* pParent, const SfxItemS
             LINK( this, SfxManageStyleSheetPage, LoseFocusHdl ) );
     }
     // It is a style with auto update? (SW only)
-    if(SFX_ITEM_SET == rAttrSet.GetItemState(SID_ATTR_AUTO_STYLE_UPDATE))
+    if(SfxItemState::SET == rAttrSet.GetItemState(SID_ATTR_AUTO_STYLE_UPDATE))
         m_pAutoCB->Show();
+    m_pFollowLb->SetSelectHdl( LINK( this, SfxManageStyleSheetPage, EditStyleSelectHdl_Impl ) );
+    m_pBaseLb->SetSelectHdl( LINK( this, SfxManageStyleSheetPage, EditLinkStyleSelectHdl_Impl ) );
+    m_pEditStyleBtn->SetClickHdl( LINK( this, SfxManageStyleSheetPage, EditStyleHdl_Impl ) );
+    m_pEditLinkStyleBtn->SetClickHdl( LINK( this, SfxManageStyleSheetPage, EditLinkStyleHdl_Impl ) );
 }
 
-//-------------------------------------------------------------------------
 
 SfxManageStyleSheetPage::~SfxManageStyleSheetPage()
-
-/*  [Description]
-
-    Destructor, release of the data
-*/
-
 {
-    m_pNameRw->SetGetFocusHdl( Link() );
-    m_pNameRw->SetLoseFocusHdl( Link() );
+    disposeOnce();
+}
+
+void SfxManageStyleSheetPage::dispose()
+{
+    m_pNameRw->SetGetFocusHdl( Link<Control&,void>() );
+    m_pNameRw->SetLoseFocusHdl( Link<Control&,void>() );
     delete pFamilies;
-    pItem = 0;
-    pStyle = 0;
-
+    pItem = nullptr;
+    pStyle = nullptr;
+    m_pNameRo.clear();
+    m_pNameRw.clear();
+    m_pAutoCB.clear();
+    m_pFollowFt.clear();
+    m_pFollowLb.clear();
+    m_pEditStyleBtn.clear();
+    m_pBaseFt.clear();
+    m_pBaseLb.clear();
+    m_pEditLinkStyleBtn.clear();
+    m_pFilterFt.clear();
+    m_pFilterLb.clear();
+    m_pDescFt.clear();
+    SfxTabPage::dispose();
 }
 
-//-------------------------------------------------------------------------
 
 void SfxManageStyleSheetPage::UpdateName_Impl( ListBox* pBox,
                                                const OUString& rNew )
@@ -261,7 +289,7 @@ void SfxManageStyleSheetPage::UpdateName_Impl( ListBox* pBox,
     if ( pBox->IsEnabled() )
     {
         // it is the current entry, which name was modified
-        const sal_Bool bSelect = pBox->GetSelectEntry() == aBuf;
+        const bool bSelect = pBox->GetSelectedEntry() == aBuf;
         pBox->RemoveEntry( aBuf );
         pBox->InsertEntry( rNew );
 
@@ -270,7 +298,6 @@ void SfxManageStyleSheetPage::UpdateName_Impl( ListBox* pBox,
     }
 }
 
-//-------------------------------------------------------------------------
 
 void SfxManageStyleSheetPage::SetDescriptionText_Impl()
 
@@ -280,27 +307,27 @@ void SfxManageStyleSheetPage::SetDescriptionText_Impl()
 */
 
 {
-    SfxMapUnit eUnit = SFX_MAPUNIT_CM;
+    MapUnit eUnit = MapUnit::MapCM;
     FieldUnit eFieldUnit( FUNIT_CM );
     SfxModule* pModule = SfxModule::GetActiveModule();
     if ( pModule )
     {
         const SfxPoolItem* pPoolItem = pModule->GetItem( SID_ATTR_METRIC );
         if ( pPoolItem )
-            eFieldUnit = (FieldUnit)( (SfxUInt16Item*)pPoolItem )->GetValue();
+            eFieldUnit = (FieldUnit) static_cast<const SfxUInt16Item*>( pPoolItem )->GetValue();
     }
 
     switch ( eFieldUnit )
     {
-        case FUNIT_MM:      eUnit = SFX_MAPUNIT_MM; break;
+        case FUNIT_MM:      eUnit = MapUnit::MapMM; break;
         case FUNIT_CM:
         case FUNIT_M:
-        case FUNIT_KM:      eUnit = SFX_MAPUNIT_CM; break;
+        case FUNIT_KM:      eUnit = MapUnit::MapCM; break;
         case FUNIT_POINT:
-        case FUNIT_PICA:    eUnit = SFX_MAPUNIT_POINT; break;
+        case FUNIT_PICA:    eUnit = MapUnit::MapPoint; break;
         case FUNIT_INCH:
         case FUNIT_FOOT:
-        case FUNIT_MILE:    eUnit = SFX_MAPUNIT_INCH; break;
+        case FUNIT_MILE:    eUnit = MapUnit::MapInch; break;
 
         default:
             OSL_FAIL( "non supported field unit" );
@@ -308,9 +335,68 @@ void SfxManageStyleSheetPage::SetDescriptionText_Impl()
     m_pDescFt->SetText( pStyle->GetDescription( eUnit ) );
 }
 
-//-------------------------------------------------------------------------
+IMPL_LINK_NOARG( SfxManageStyleSheetPage, EditStyleSelectHdl_Impl, ListBox&, void )
+{
+    OUString aTemplName(m_pFollowLb->GetSelectedEntry());
+    OUString aEditTemplName(m_pNameRo->GetText());
+    if (!( aTemplName == aEditTemplName))
+        m_pEditStyleBtn->Enable();
+    else
+        m_pEditStyleBtn->Disable();
+}
 
-IMPL_LINK_INLINE_START( SfxManageStyleSheetPage, GetFocusHdl, Edit *, pEdit )
+IMPL_LINK_NOARG( SfxManageStyleSheetPage, EditStyleHdl_Impl, Button*, void )
+{
+    OUString aTemplName(m_pFollowLb->GetSelectedEntry());
+    if (Execute_Impl( SID_STYLE_EDIT, aTemplName, OUString(),(sal_uInt16)pStyle->GetFamily() ))
+    {
+    }
+}
+
+IMPL_LINK_NOARG( SfxManageStyleSheetPage, EditLinkStyleSelectHdl_Impl, ListBox&, void )
+{
+    sal_Int32 linkSelectPos = m_pBaseLb->GetSelectedEntryPos();
+    if ( linkSelectPos == 0 )
+        m_pEditLinkStyleBtn->Disable();
+    else
+        m_pEditLinkStyleBtn->Enable();
+}
+
+IMPL_LINK_NOARG( SfxManageStyleSheetPage, EditLinkStyleHdl_Impl, Button*, void )
+{
+    OUString aTemplName(m_pBaseLb->GetSelectedEntry());
+    if (aTemplName != SfxResId(STR_NONE))
+        Execute_Impl( SID_STYLE_EDIT, aTemplName, OUString(),(sal_uInt16)pStyle->GetFamily() );
+}
+
+// Internal: Perform functions through the Dispatcher
+bool SfxManageStyleSheetPage::Execute_Impl(
+    sal_uInt16 nId, const OUString &rStr, const OUString& rRefStr, sal_uInt16 nFamily)
+{
+
+    SfxDispatcher &rDispatcher = *SfxGetpApp()->GetDispatcher_Impl();
+    SfxStringItem aItem(nId, rStr);
+    SfxUInt16Item aFamily(SID_STYLE_FAMILY, nFamily);
+    SfxStringItem aRefName( SID_STYLE_REFERENCE, rRefStr );
+    const SfxPoolItem* pItems[ 6 ];
+    sal_uInt16 nCount = 0;
+    if( !rStr.isEmpty() )
+        pItems[ nCount++ ] = &aItem;
+    pItems[ nCount++ ] = &aFamily;
+    if ( !rRefStr.isEmpty() )
+        pItems[ nCount++ ] = &aRefName;
+
+    pItems[ nCount++ ] = nullptr;
+
+    const SfxPoolItem* pItem = rDispatcher.Execute(
+        nId, SfxCallMode::SYNCHRON | SfxCallMode::RECORD | SfxCallMode::MODAL,
+        pItems );
+
+    return pItem != nullptr;
+
+}
+
+IMPL_LINK( SfxManageStyleSheetPage, GetFocusHdl, Control&, rControl, void )
 
 /*  [Description]
 
@@ -318,35 +404,29 @@ IMPL_LINK_INLINE_START( SfxManageStyleSheetPage, GetFocusHdl, Edit *, pEdit )
 */
 
 {
+    Edit* pEdit = static_cast<Edit*>(&rControl);
     aBuf = comphelper::string::stripStart(pEdit->GetText(), ' ');
-    return 0;
 }
-IMPL_LINK_INLINE_END( SfxManageStyleSheetPage, GetFocusHdl, Edit *, pEdit )
 
-//-------------------------------------------------------------------------
-
-IMPL_LINK_INLINE_START( SfxManageStyleSheetPage, LoseFocusHdl, Edit *, pEdit )
+IMPL_LINK( SfxManageStyleSheetPage, LoseFocusHdl, Control&, rControl, void )
 
 /*  [Description]
 
-    StarView Handler; loose-focus-handler of the edits of the template name.
+    StarView Handler; lose-focus-handler of the edits of the template name.
     This will update the listbox with the subsequent templates. The current
     template itself is not returned in the listbox of the base templates.
 */
 
 {
+    Edit* pEdit = static_cast<Edit*>(&rControl);
     const OUString aStr(comphelper::string::stripStart(pEdit->GetText(), ' '));
     pEdit->SetText( aStr );
     // Update the Listbox of the base template if possible
     if ( aStr != aBuf )
         UpdateName_Impl(m_pFollowLb, aStr);
-    return 0;
 }
-IMPL_LINK_INLINE_END( SfxManageStyleSheetPage, LoseFocusHdl, Edit *, pEdit )
 
-//-------------------------------------------------------------------------
-
-sal_Bool SfxManageStyleSheetPage::FillItemSet( SfxItemSet& rSet )
+bool SfxManageStyleSheetPage::FillItemSet( SfxItemSet* rSet )
 
 /*  [Description]
 
@@ -368,32 +448,31 @@ sal_Bool SfxManageStyleSheetPage::FillItemSet( SfxItemSet& rSet )
 */
 
 {
-    const sal_uInt16 nFilterIdx = m_pFilterLb->GetSelectEntryPos();
+    const sal_Int32 nFilterIdx = m_pFilterLb->GetSelectedEntryPos();
 
     // Set Filter
 
     if ( LISTBOX_ENTRY_NOTFOUND  != nFilterIdx      &&
-         nFilterIdx != m_pFilterLb->GetSavedValue()    &&
+         m_pFilterLb->IsValueChangedFromSaved()    &&
          m_pFilterLb->IsEnabled() )
     {
-        bModified = sal_True;
+        bModified = true;
         OSL_ENSURE( pItem, "No Item" );
         // is only possibly for user templates
-        sal_uInt16 nMask = pItem->GetFilterList()[ (size_t)m_pFilterLb->GetEntryData( nFilterIdx ) ]->nFlags | SFXSTYLEBIT_USERDEF;
+        sal_uInt16 nMask = pItem->GetFilterList()[ reinterpret_cast<size_t>(m_pFilterLb->GetEntryData( nFilterIdx )) ].nFlags | SFXSTYLEBIT_USERDEF;
         pStyle->SetMask( nMask );
     }
     if(m_pAutoCB->IsVisible() &&
-        m_pAutoCB->IsChecked() != m_pAutoCB->GetSavedValue())
+       m_pAutoCB->IsValueChangedFromSaved())
     {
-        rSet.Put(SfxBoolItem(SID_ATTR_AUTO_STYLE_UPDATE, m_pAutoCB->IsChecked()));
+        rSet->Put(SfxBoolItem(SID_ATTR_AUTO_STYLE_UPDATE, m_pAutoCB->IsChecked()));
     }
 
     return bModified;
 }
 
-//-------------------------------------------------------------------------
 
-void SfxManageStyleSheetPage::Reset( const SfxItemSet& /*rAttrSet*/ )
+void SfxManageStyleSheetPage::Reset( const SfxItemSet* /*rAttrSet*/ )
 
 /*  [Description]
 
@@ -409,12 +488,13 @@ void SfxManageStyleSheetPage::Reset( const SfxItemSet& /*rAttrSet*/ )
 */
 
 {
-    bModified = sal_False;
+    bModified = false;
     OUString sCmp( pStyle->GetName() );
 
     if ( sCmp != aName )
         pStyle->SetName( aName );
     m_pNameRw->SetText( aName );
+    m_pNameRw->SetSelection( Selection( SELECTION_MIN, SELECTION_MAX ) );
 
     if ( m_pFollowLb->IsEnabled() )
     {
@@ -437,11 +517,11 @@ void SfxManageStyleSheetPage::Reset( const SfxItemSet& /*rAttrSet*/ )
             pStyle->SetParent( aParent );
 
         if ( aParent.isEmpty() )
-            m_pBaseLb->SelectEntry( SfxResId(STR_NONE).toString() );
+            m_pBaseLb->SelectEntry( SfxResId(STR_NONE) );
         else
             m_pBaseLb->SelectEntry( aParent );
 
-        if ( SfxResId(STR_STANDARD).toString().equals(aName) )
+        if ( SfxResId(STR_STANDARD) == aName )
         {
             // the default template can not be linked
             m_pBaseFt->Disable();
@@ -459,25 +539,13 @@ void SfxManageStyleSheetPage::Reset( const SfxItemSet& /*rAttrSet*/ )
     }
 }
 
-//-------------------------------------------------------------------------
-
-SfxTabPage* SfxManageStyleSheetPage::Create( Window* pParent,
-                                             const SfxItemSet &rAttrSet )
-
-/*  [Description]
-
-    Factory for the creation of the page.
-
-    [Cross-reference]
-
-    <class SfxTabDialog>
-*/
 
+VclPtr<SfxTabPage> SfxManageStyleSheetPage::Create( vcl::Window* pParent,
+                                                    const SfxItemSet *rAttrSet )
 {
-    return new SfxManageStyleSheetPage( pParent, rAttrSet );
+    return VclPtr<SfxManageStyleSheetPage>::Create( pParent, *rAttrSet );
 }
 
-//-------------------------------------------------------------------------
 
 void SfxManageStyleSheetPage::ActivatePage( const SfxItemSet& rSet)
 
@@ -502,15 +570,14 @@ void SfxManageStyleSheetPage::ActivatePage( const SfxItemSet& rSet)
     // It is a style with auto update? (SW only)
     const SfxPoolItem* pPoolItem;
 
-    if ( SFX_ITEM_SET ==
-         rSet.GetItemState( SID_ATTR_AUTO_STYLE_UPDATE, sal_False, &pPoolItem ) )
-        m_pAutoCB->Check( ( (const SfxBoolItem*)pPoolItem )->GetValue() );
+    if ( SfxItemState::SET ==
+         rSet.GetItemState( SID_ATTR_AUTO_STYLE_UPDATE, false, &pPoolItem ) )
+        m_pAutoCB->Check( static_cast<const SfxBoolItem*>(pPoolItem)->GetValue() );
     m_pAutoCB->SaveValue();
 }
 
-//-------------------------------------------------------------------------
 
-int SfxManageStyleSheetPage::DeactivatePage( SfxItemSet* pItemSet )
+DeactivateRC SfxManageStyleSheetPage::DeactivatePage( SfxItemSet* pItemSet )
 
 /*  [Description]
 
@@ -527,65 +594,65 @@ int SfxManageStyleSheetPage::DeactivatePage( SfxItemSet* pItemSet )
 */
 
 {
-    int nRet = SfxTabPage::LEAVE_PAGE;
+    DeactivateRC nRet = DeactivateRC::LeavePage;
 
     if ( m_pNameRw->IsModified() )
     {
         // By pressing <Enter> LoseFocus() is not trigged through StarView
         if ( m_pNameRw->HasFocus() )
-            LoseFocusHdl( m_pNameRw );
+            LoseFocusHdl( *m_pNameRw );
 
         if (!pStyle->SetName(comphelper::string::stripStart(m_pNameRw->GetText(), ' ')))
         {
-            InfoBox aBox( this, SfxResId( MSG_TABPAGE_INVALIDNAME ) );
-            aBox.Execute();
+            ScopedVclPtrInstance< MessageDialog > aBox(this, SfxResId( STR_TABPAGE_INVALIDNAME ), VclMessageType::Info);
+            aBox->Execute();
             m_pNameRw->GrabFocus();
             m_pNameRw->SetSelection( Selection( SELECTION_MIN, SELECTION_MAX ) );
-            return SfxTabPage::KEEP_PAGE;
+            return DeactivateRC::KeepPage;
         }
-        bModified = sal_True;
+        bModified = true;
     }
 
     if ( pStyle->HasFollowSupport() && m_pFollowLb->IsEnabled() )
     {
-        const OUString aFollowEntry( m_pFollowLb->GetSelectEntry() );
+        const OUString aFollowEntry( m_pFollowLb->GetSelectedEntry() );
 
         if ( pStyle->GetFollow() != aFollowEntry )
         {
             if ( !pStyle->SetFollow( aFollowEntry ) )
             {
-                InfoBox aBox( this, SfxResId( MSG_TABPAGE_INVALIDSTYLE ) );
-                aBox.Execute();
+                ScopedVclPtrInstance< MessageDialog > aBox(this, SfxResId( STR_TABPAGE_INVALIDSTYLE ), VclMessageType::Info);
+                aBox->Execute();
                 m_pFollowLb->GrabFocus();
-                return SfxTabPage::KEEP_PAGE;
+                return DeactivateRC::KeepPage;
             }
-            bModified = sal_True;
+            bModified = true;
         }
     }
 
     if ( m_pBaseLb->IsEnabled() )
     {
-        OUString aParentEntry( m_pBaseLb->GetSelectEntry() );
+        OUString aParentEntry( m_pBaseLb->GetSelectedEntry() );
 
-        if ( SfxResId(STR_NONE).toString().equals(aParentEntry) || aParentEntry == pStyle->GetName() )
-            aParentEntry = OUString();
+        if ( SfxResId(STR_NONE) == aParentEntry || aParentEntry == pStyle->GetName() )
+            aParentEntry.clear();
 
         if ( pStyle->GetParent() != aParentEntry )
         {
             if ( !pStyle->SetParent( aParentEntry ) )
             {
-                InfoBox aBox( this, SfxResId( MSG_TABPAGE_INVALIDPARENT ) );
-                aBox.Execute();
+                ScopedVclPtrInstance< MessageDialog > aBox(this, SfxResId( STR_TABPAGE_INVALIDPARENT ), VclMessageType::Info);
+                aBox->Execute();
                 m_pBaseLb->GrabFocus();
-                return SfxTabPage::KEEP_PAGE;
+                return DeactivateRC::KeepPage;
             }
-            bModified = sal_True;
-            nRet |= (int)SfxTabPage::REFRESH_SET;
+            bModified = true;
+            nRet = nRet | DeactivateRC::RefreshSet;
         }
     }
 
     if ( pItemSet )
-        FillItemSet( *pItemSet );
+        FillItemSet( pItemSet );
 
     return nRet;
 }
