@@ -17,7 +17,7 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#ifdef SOLARIS
+#ifdef __sun
 #include <ctime>
 #endif
 
@@ -26,19 +26,19 @@
 #include <vcl/wrkwin.hxx>
 #include <unotools/viewoptions.hxx>
 
+#include <vcl/menu.hxx>
 #include <vcl/timer.hxx>
 
-#include "splitwin.hxx"
-#include "workwin.hxx"
+#include <splitwin.hxx>
+#include <workwin.hxx>
 #include <sfx2/dockwin.hxx>
 #include <sfx2/app.hxx>
-#include "dialog.hrc"
+#include <sfx2/strings.hrc>
 #include <sfx2/sfxresid.hxx>
-#include <sfx2/mnumgr.hxx>
-#include "virtmenu.hxx"
 #include <sfx2/msgpool.hxx>
 #include <sfx2/viewfrm.hxx>
 
+#include <memory>
 #include <vector>
 #include <utility>
 
@@ -46,7 +46,7 @@ using namespace ::com::sun::star::uno;
 
 #define VERSION 1
 #define nPixel  30L
-#define USERITEM_NAME           OUString("UserItem")
+#define USERITEM_NAME           "UserItem"
 
 namespace {
     // helper class to deactivate UpdateMode, if needed, for the life time of an instance
@@ -63,7 +63,7 @@ namespace {
             }
         }
 
-        ~DeactivateUpdateMode( void )
+        ~DeactivateUpdateMode()
         {
             if ( mbUpdateMode )
             {
@@ -87,16 +87,17 @@ class SfxEmptySplitWin_Impl : public SplitWindow
 */
 friend class SfxSplitWindow;
 
-    SfxSplitWindow*     pOwner;
-    bool                bFadeIn;
-    bool                bAutoHide;
-    bool                bSplit;
-    bool                bEndAutoHide;
-    Timer               aTimer;
-    Point               aLastPos;
+    VclPtr<SfxSplitWindow>  pOwner;
+    bool                    bFadeIn;
+    bool                    bAutoHide;
+    bool                    bSplit;
+    bool                    bEndAutoHide;
+    Timer                   aTimer;
+    Point                   aLastPos;
     sal_uInt16              nState;
 
-                        SfxEmptySplitWin_Impl( SfxSplitWindow *pParent )
+public:
+   explicit             SfxEmptySplitWin_Impl( SfxSplitWindow *pParent )
                             : SplitWindow( pParent->GetParent(), WinBits( WB_BORDER | WB_3DLOOK ) )
                             , pOwner( pParent )
                             , bFadeIn( false )
@@ -105,23 +106,24 @@ friend class SfxSplitWindow;
                             , bEndAutoHide( false )
                             , nState( 1 )
                         {
-                            aTimer.SetTimeoutHdl(
+                            aTimer.SetInvokeHandler(
                                 LINK(pOwner, SfxSplitWindow, TimerHdl ) );
                             aTimer.SetTimeout( 200 );
                             SetAlign( pOwner->GetAlign() );
                             Actualize();
-                            ShowAutoHideButton( pOwner->IsAutoHideButtonVisible() );
-                            ShowFadeInHideButton( true );
+                            ShowFadeInHideButton();
                         }
 
-                        virtual ~SfxEmptySplitWin_Impl()
+                        virtual ~SfxEmptySplitWin_Impl() override
+                        { disposeOnce(); }
+   virtual void         dispose() override
                         {
                             aTimer.Stop();
+                            pOwner.clear();
+                            SplitWindow::dispose();
                         }
 
-    virtual void        MouseMove( const MouseEvent& ) SAL_OVERRIDE;
-    virtual void        AutoHide() SAL_OVERRIDE;
-    virtual void        FadeIn() SAL_OVERRIDE;
+    virtual void        FadeIn() override;
     void                Actualize();
 };
 
@@ -130,12 +132,12 @@ void SfxEmptySplitWin_Impl::Actualize()
     Size aSize( pOwner->GetSizePixel() );
     switch ( pOwner->GetAlign() )
     {
-        case WINDOWALIGN_LEFT:
-        case WINDOWALIGN_RIGHT:
+        case WindowAlign::Left:
+        case WindowAlign::Right:
             aSize.Width() = GetFadeInSize();
             break;
-        case WINDOWALIGN_TOP:
-        case WINDOWALIGN_BOTTOM:
+        case WindowAlign::Top:
+        case WindowAlign::Bottom:
             aSize.Height() = GetFadeInSize();
             break;
     }
@@ -143,20 +145,11 @@ void SfxEmptySplitWin_Impl::Actualize()
     SetSizePixel( aSize );
 }
 
-void SfxEmptySplitWin_Impl::AutoHide()
-{
-    pOwner->SetPinned_Impl( !pOwner->bPinned );
-    pOwner->SaveConfig_Impl();
-    bAutoHide = true;
-    FadeIn();
-}
-
 void SfxEmptySplitWin_Impl::FadeIn()
 {
     if (!bAutoHide )
         bAutoHide = IsFadeNoButtonMode();
     pOwner->SetFadeIn_Impl( true );
-    pOwner->Show_Impl();
     if ( bAutoHide )
     {
         // Set Timer to close; the caller has to ensure themselves that the
@@ -170,22 +163,14 @@ void SfxEmptySplitWin_Impl::FadeIn()
 }
 
 
-
 void SfxSplitWindow::MouseButtonDown( const MouseEvent& rMEvt )
 {
     if ( rMEvt.GetClicks() != 2 )
         SplitWindow::MouseButtonDown( rMEvt );
 }
 
-void SfxEmptySplitWin_Impl::MouseMove( const MouseEvent& rMEvt )
-{
-    SplitWindow::MouseMove( rMEvt );
-}
-
-
-
 SfxSplitWindow::SfxSplitWindow( vcl::Window* pParent, SfxChildAlignment eAl,
-        SfxWorkWindow *pW, bool bWithButtons, WinBits nBits )
+        SfxWorkWindow *pW, bool bWithButtons )
 
 /*  [Description]
 
@@ -195,45 +180,42 @@ SfxSplitWindow::SfxSplitWindow( vcl::Window* pParent, SfxChildAlignment eAl,
     the arrangement of the SfxDockingWindows.
 */
 
-:   SplitWindow ( pParent, nBits | WB_HIDE ),
+:   SplitWindow ( pParent, WB_BORDER | WB_SIZEABLE | WB_3DLOOK | WB_HIDE ),
     eAlign(eAl),
     pWorkWin(pW),
-    pDockArr( new SfxDockArr_Impl ),
-    bLocked(false),
     bPinned(true),
-    pEmptyWin(NULL),
-    pActive(NULL)
+    pEmptyWin(nullptr),
+    pActive(nullptr)
 {
-    if ( bWithButtons )
+    if (bWithButtons)
     {
-        ShowAutoHideButton( false );    // no autohide button (pin) anymore
-        ShowFadeOutButton( true );
+        ShowFadeOutButton();
     }
 
     // Set SV-Alignment
     WindowAlign eTbxAlign;
     switch ( eAlign )
     {
-        case SFX_ALIGN_LEFT:
-            eTbxAlign = WINDOWALIGN_LEFT;
+        case SfxChildAlignment::LEFT:
+            eTbxAlign = WindowAlign::Left;
             break;
-        case SFX_ALIGN_RIGHT:
-            eTbxAlign = WINDOWALIGN_RIGHT;
+        case SfxChildAlignment::RIGHT:
+            eTbxAlign = WindowAlign::Right;
             break;
-        case SFX_ALIGN_TOP:
-            eTbxAlign = WINDOWALIGN_TOP;
+        case SfxChildAlignment::TOP:
+            eTbxAlign = WindowAlign::Top;
             break;
-        case SFX_ALIGN_BOTTOM:
-            eTbxAlign = WINDOWALIGN_BOTTOM;
+        case SfxChildAlignment::BOTTOM:
+            eTbxAlign = WindowAlign::Bottom;
             bPinned = true;
             break;
         default:
-            eTbxAlign = WINDOWALIGN_TOP;  // some sort of default...
+            eTbxAlign = WindowAlign::Top;  // some sort of default...
             break;  // -Wall lots not handled..
     }
 
     SetAlign (eTbxAlign);
-    pEmptyWin = new SfxEmptySplitWin_Impl( this );
+    pEmptyWin = VclPtr<SfxEmptySplitWin_Impl>::Create( this );
     if ( bPinned )
     {
         pEmptyWin->bFadeIn = true;
@@ -245,7 +227,7 @@ SfxSplitWindow::SfxSplitWindow( vcl::Window* pParent, SfxChildAlignment eAl,
         //  Read Configuration
         OUString aWindowId("SplitWindow");
         aWindowId += OUString::number( (sal_Int32) eTbxAlign );
-        SvtViewOptions aWinOpt( E_WINDOW, aWindowId );
+        SvtViewOptions aWinOpt( EViewType::Window, aWindowId );
         OUString aWinData;
         Any aUserItem = aWinOpt.GetUserItem( USERITEM_NAME );
         OUString aTemp;
@@ -263,7 +245,7 @@ SfxSplitWindow::SfxSplitWindow( vcl::Window* pParent, SfxChildAlignment eAl,
             for ( sal_uInt16 n=0; n<nCount; n++ )
             {
                 SfxDock_Impl *pDock = new SfxDock_Impl;
-                pDock->pWin = 0;
+                pDock->pWin = nullptr;
                 pDock->bNewLine = false;
                 pDock->bHide = true;
                 pDock->nType = (sal_uInt16) aWinData.getToken(i++, ',').toInt32();
@@ -281,7 +263,7 @@ SfxSplitWindow::SfxSplitWindow( vcl::Window* pParent, SfxChildAlignment eAl,
                         pDock->bNewLine = true;
                 }
 
-                pDockArr->insert(pDockArr->begin() + n, pDock);
+                maDockArr.insert(maDockArr.begin() + n, std::unique_ptr<SfxDock_Impl>(pDock));
             }
         }
     }
@@ -291,14 +273,15 @@ SfxSplitWindow::SfxSplitWindow( vcl::Window* pParent, SfxChildAlignment eAl,
         pEmptyWin->bFadeIn = true;
         pEmptyWin->nState = 2;
     }
-
-    SetAutoHideState( !bPinned );
-    pEmptyWin->SetAutoHideState( !bPinned );
 }
 
 
-
 SfxSplitWindow::~SfxSplitWindow()
+{
+    disposeOnce();
+}
+
+void SfxSplitWindow::dispose()
 {
     if ( !pWorkWin->GetParent_Impl() )
         SaveConfig_Impl();
@@ -307,11 +290,13 @@ SfxSplitWindow::~SfxSplitWindow()
     {
         // Set pOwner to NULL, otherwise try to delete pEmptyWin once more. The
         // window that is just being docked is always deleted from the outside.
-        pEmptyWin->pOwner = NULL;
-        delete pEmptyWin;
+        pEmptyWin->pOwner = nullptr;
     }
+    pEmptyWin.disposeAndClear();
 
-    delete pDockArr;
+    maDockArr.clear();
+    pActive.clear();
+    SplitWindow::dispose();
 }
 
 void SfxSplitWindow::SaveConfig_Impl()
@@ -325,35 +310,31 @@ void SfxSplitWindow::SaveConfig_Impl()
     aWinData.append(',');
 
     sal_uInt16 nCount = 0;
-    sal_uInt16 n;
-    for ( n=0; n<pDockArr->size(); n++ )
+    for ( auto const & rDock: maDockArr )
     {
-        const SfxDock_Impl& rDock = (*pDockArr)[n];
-        if ( rDock.bHide || rDock.pWin )
+        if ( rDock->bHide || rDock->pWin )
             nCount++;
     }
 
     aWinData.append(static_cast<sal_Int32>(nCount));
 
-    for ( n=0; n<pDockArr->size(); n++ )
+    for ( auto const & rDock: maDockArr )
     {
-        const SfxDock_Impl& rDock = (*pDockArr)[n];
-        if ( !rDock.bHide && !rDock.pWin )
+        if ( !rDock->bHide && !rDock->pWin )
             continue;
-        if ( rDock.bNewLine )
+        if ( rDock->bNewLine )
             aWinData.append(",0");
         aWinData.append(',');
-        aWinData.append(static_cast<sal_Int32>(rDock.nType));
+        aWinData.append(static_cast<sal_Int32>(rDock->nType));
     }
 
     OUString aWindowId("SplitWindow");
     aWindowId += OUString::number( (sal_Int32) GetAlign() );
-    SvtViewOptions aWinOpt( E_WINDOW, aWindowId );
+    SvtViewOptions aWinOpt( EViewType::Window, aWindowId );
     aWinOpt.SetUserItem( USERITEM_NAME, makeAny( aWinData.makeStringAndClear() ) );
 }
 
 
-
 void SfxSplitWindow::StartSplit()
 {
     long nSize = 0;
@@ -365,15 +346,15 @@ void SfxSplitWindow::StartSplit()
         pEmptyWin->bSplit = true;
     }
 
-    Rectangle aRect = pWorkWin->GetFreeArea( !bPinned );
+    tools::Rectangle aRect = pWorkWin->GetFreeArea( !bPinned );
     switch ( GetAlign() )
     {
-        case WINDOWALIGN_LEFT:
-        case WINDOWALIGN_RIGHT:
+        case WindowAlign::Left:
+        case WindowAlign::Right:
             nSize = aSize.Width() + aRect.GetWidth();
             break;
-        case WINDOWALIGN_TOP:
-        case WINDOWALIGN_BOTTOM:
+        case WindowAlign::Top:
+        case WindowAlign::Bottom:
             nSize = aSize.Height() + aRect.GetHeight();
             break;
     }
@@ -382,7 +363,6 @@ void SfxSplitWindow::StartSplit()
 }
 
 
-
 void SfxSplitWindow::SplitResize()
 {
     if ( bPinned )
@@ -395,7 +375,6 @@ void SfxSplitWindow::SplitResize()
 }
 
 
-
 void SfxSplitWindow::Split()
 {
     if ( pEmptyWin )
@@ -405,14 +384,14 @@ void SfxSplitWindow::Split()
 
     std::vector< std::pair< sal_uInt16, long > > aNewOrgSizes;
 
-    sal_uInt16 nCount = pDockArr->size();
+    sal_uInt16 nCount = maDockArr.size();
     for ( sal_uInt16 n=0; n<nCount; n++ )
     {
-        const SfxDock_Impl& rD = (*pDockArr)[n];
+        const SfxDock_Impl& rD = *maDockArr[n].get();
         if ( rD.pWin )
         {
             const sal_uInt16 nId = rD.nType;
-            const long nSize    = GetItemSize( nId, SWIB_FIXED );
+            const long nSize    = GetItemSize( nId, SplitWindowItemFlags::Fixed );
             const long nSetSize = GetItemSize( GetSet( nId ) );
             Size aSize;
 
@@ -429,7 +408,7 @@ void SfxSplitWindow::Split()
 
             rD.pWin->SetItemSize_Impl( aSize );
 
-            aNewOrgSizes.push_back( std::pair< sal_uInt16, long >( nId, nSize ) );
+            aNewOrgSizes.emplace_back( nId, nSize );
         }
     }
 
@@ -437,9 +416,9 @@ void SfxSplitWindow::Split()
     // apply FIXED item size as 'original' item size to improve layouting of undock-dock-cycle of a window
     {
         DeactivateUpdateMode aDeactivateUpdateMode( *this );
-        for ( sal_uInt16 i = 0; i < aNewOrgSizes.size(); ++i )
+        for (const std::pair< sal_uInt16, long > & rNewOrgSize : aNewOrgSizes)
         {
-            SetItemSize( aNewOrgSizes[i].first, aNewOrgSizes[i].second );
+            SetItemSize( rNewOrgSize.first, rNewOrgSize.second );
         }
     }
 
@@ -447,7 +426,6 @@ void SfxSplitWindow::Split()
 }
 
 
-
 void SfxSplitWindow::InsertWindow( SfxDockingWindow* pDockWin, const Size& rSize)
 
 /*
@@ -461,11 +439,11 @@ void SfxSplitWindow::InsertWindow( SfxDockingWindow* pDockWin, const Size& rSize
     sal_uInt16 nPos = 0;
     bool bNewLine = true;
     bool bSaveConfig = false;
-    SfxDock_Impl *pFoundDock=0;
-    sal_uInt16 nCount = pDockArr->size();
+    SfxDock_Impl *pFoundDock=nullptr;
+    sal_uInt16 nCount = maDockArr.size();
     for ( sal_uInt16 n=0; n<nCount; n++ )
     {
-        SfxDock_Impl& rDock = (*pDockArr)[n];
+        SfxDock_Impl& rDock = *maDockArr[n].get();
         if ( rDock.bNewLine )
         {
             // The window opens a new line
@@ -522,7 +500,7 @@ void SfxSplitWindow::InsertWindow( SfxDockingWindow* pDockWin, const Size& rSize
         // Not found, insert at end
         pFoundDock = new SfxDock_Impl;
         pFoundDock->bHide = true;
-        pDockArr->push_back( pFoundDock );
+        maDockArr.push_back( std::unique_ptr<SfxDock_Impl>(pFoundDock) );
         pFoundDock->nType = pDockWin->GetType();
         nLine++;
         nPos = 0;
@@ -539,21 +517,20 @@ void SfxSplitWindow::InsertWindow( SfxDockingWindow* pDockWin, const Size& rSize
 }
 
 
-
-void SfxSplitWindow::ReleaseWindow_Impl(SfxDockingWindow *pDockWin, bool bSave)
+void SfxSplitWindow::ReleaseWindow_Impl(SfxDockingWindow const *pDockWin, bool bSave)
 {
 //  The docking window is no longer stored in the internal data.
-    sal_uInt16 nCount = pDockArr->size();
+    sal_uInt16 nCount = maDockArr.size();
     for ( sal_uInt16 n=0; n<nCount; n++ )
     {
-        const SfxDock_Impl& rDock = (*pDockArr)[n];
+        const SfxDock_Impl& rDock = *maDockArr[n].get();
         if ( rDock.nType == pDockWin->GetType() )
         {
             if ( rDock.bNewLine && n<nCount-1 )
-                (*pDockArr)[n+1].bNewLine = true;
+                maDockArr[n+1]->bNewLine = true;
 
             // Window has a position, this we forget
-            pDockArr->erase(pDockArr->begin() + n);
+            maDockArr.erase(maDockArr.begin() + n);
             break;
         }
     }
@@ -563,7 +540,6 @@ void SfxSplitWindow::ReleaseWindow_Impl(SfxDockingWindow *pDockWin, bool bSave)
 }
 
 
-
 void SfxSplitWindow::MoveWindow( SfxDockingWindow* pDockWin, const Size& rSize,
                         sal_uInt16 nLine, sal_uInt16 nPos, bool bNewLine)
 
@@ -576,7 +552,7 @@ void SfxSplitWindow::MoveWindow( SfxDockingWindow* pDockWin, const Size& rSize,
     sal_uInt16 nL, nP;
     GetWindowPos( pDockWin, nL, nP );
 
-    if ( nLine > nL && GetItemCount( GetItemId( nL, 0 ) ) == 1 )
+    if ( nLine > nL && GetItemCount( GetItemId( nL ) ) == 1 )
     {
         // If the last window is removed from its line, then everything slips
         // one line to the front!
@@ -587,7 +563,6 @@ void SfxSplitWindow::MoveWindow( SfxDockingWindow* pDockWin, const Size& rSize,
 }
 
 
-
 void SfxSplitWindow::InsertWindow( SfxDockingWindow* pDockWin, const Size& rSize,
                         sal_uInt16 nLine, sal_uInt16 nPos, bool bNewLine)
 
@@ -610,18 +585,18 @@ void SfxSplitWindow::InsertWindow( SfxDockingWindow* pDockWin, const Size& rSize
 
     // The window must be inserted before the first window so that it has the
     // same or a greater position than pDockWin.
-    sal_uInt16 nCount = pDockArr->size();
+    sal_uInt16 nCount = maDockArr.size();
     sal_uInt16 nLastWindowIdx(0);
 
     // If no window is found, a first window is inserted
     sal_uInt16 nInsertPos = 0;
     for ( sal_uInt16 n=0; n<nCount; n++ )
     {
-        SfxDock_Impl& rD = (*pDockArr)[n];
+        SfxDock_Impl& rD = *maDockArr[n].get();
 
         if (rD.pWin)
         {
-            // A docked window has been found. If no suitable window behind the
+            // A docked window has been found. If no suitable window behind
             // the desired insertion point s found, then insertion is done at
             // the end.
             nInsertPos = nCount;
@@ -636,7 +611,7 @@ void SfxSplitWindow::InsertWindow( SfxDockingWindow* pDockWin, const Size& rSize
                 {
                     DBG_ASSERT(rD.bNewLine, "No new line?");
 
-                    // The posption is pushed to nPos==0
+                    // The position is pushed to nPos==0
                     rD.bNewLine = false;
                     pDock->bNewLine = true;
                 }
@@ -651,14 +626,13 @@ void SfxSplitWindow::InsertWindow( SfxDockingWindow* pDockWin, const Size& rSize
         nInsertPos = nLastWindowIdx + 1;    // ignore all non-windows after the last window
     }
 
-    pDockArr->insert(pDockArr->begin() + nInsertPos, pDock);
+    maDockArr.insert(maDockArr.begin() + nInsertPos, std::unique_ptr<SfxDock_Impl>(pDock));
     InsertWindow_Impl( pDock, rSize, nLine, nPos, bNewLine );
     SaveConfig_Impl();
 }
 
 
-
-void SfxSplitWindow::InsertWindow_Impl( SfxDock_Impl* pDock,
+void SfxSplitWindow::InsertWindow_Impl( SfxDock_Impl const * pDock,
                         const Size& rSize,
                         sal_uInt16 nLine, sal_uInt16 nPos, bool bNewLine)
 
@@ -671,7 +645,7 @@ void SfxSplitWindow::InsertWindow_Impl( SfxDock_Impl* pDock,
 {
     SfxDockingWindow* pDockWin = pDock->pWin;
 
-    sal_uInt16 nItemBits = pDockWin->GetWinBits_Impl();
+    SplitWindowItemFlags nItemBits = SplitWindowItemFlags::NONE;
 
     long nWinSize, nSetSize;
     if ( IsHorizontal() )
@@ -685,26 +659,24 @@ void SfxSplitWindow::InsertWindow_Impl( SfxDock_Impl* pDock,
         nWinSize = rSize.Height();
     }
 
-    pDock->nSize = nWinSize;
-
     DeactivateUpdateMode* pDeactivateUpdateMode = new DeactivateUpdateMode( *this );
 
-    if ( bNewLine || nLine == GetItemCount( 0 ) )
+    if ( bNewLine || nLine == GetItemCount() )
     {
         // An existing row should not be inserted, instead a new one
         // will be created
 
         sal_uInt16 nId = 1;
-        for ( sal_uInt16 n=0; n<GetItemCount(0); n++ )
+        for ( sal_uInt16 n=0; n<GetItemCount(); n++ )
         {
             if ( GetItemId(n) >= nId )
                 nId = GetItemId(n)+1;
         }
 
         // Create a new nLine:th line
-        sal_uInt16 nBits = nItemBits;
-        if ( GetAlign() == WINDOWALIGN_TOP || GetAlign() == WINDOWALIGN_BOTTOM )
-            nBits |= SWIB_COLSET;
+        SplitWindowItemFlags nBits = nItemBits;
+        if ( GetAlign() == WindowAlign::Top || GetAlign() == WindowAlign::Bottom )
+            nBits |= SplitWindowItemFlags::ColSet;
         InsertItem( nId, nSetSize, nLine, 0, nBits );
     }
 
@@ -712,17 +684,16 @@ void SfxSplitWindow::InsertWindow_Impl( SfxDock_Impl* pDock,
     // "percentage" share since the SV then does the re-sizing as expected,
     // "pixel" actually only makes sense if also items with percentage or
     // relative sizes are present.
-    nItemBits |= SWIB_PERCENTSIZE;
-    bLocked = true;
+    nItemBits |= SplitWindowItemFlags::PercentSize;
     sal_uInt16 nSet = GetItemId( nLine );
     InsertItem( pDockWin->GetType(), pDockWin, nWinSize, nPos, nSet, nItemBits );
 
     // SplitWindows are once created in SFX and when inserting the first
     // DockingWindows is made visible.
-    if ( GetItemCount( 0 ) == 1 && GetItemCount( 1 ) == 1 )
+    if ( GetItemCount() == 1 && GetItemCount( 1 ) == 1 )
     {
         // The Rearranging in WorkWindow and a Show() on the SplitWindow is
-        // caues by SfxDockingwindow (->SfxWorkWindow::ConfigChild_Impl)
+        // caused by SfxDockingwindow (->SfxWorkWindow::ConfigChild_Impl)
         if ( !bPinned && !IsFloatingMode() )
         {
             bPinned = true;
@@ -730,8 +701,8 @@ void SfxSplitWindow::InsertWindow_Impl( SfxDock_Impl* pDock,
             pEmptyWin->bFadeIn = false;
             SetPinned_Impl( false );
             pEmptyWin->Actualize();
-            OSL_TRACE( "SfxSplitWindow::InsertWindow_Impl - registering empty Splitwindow" );
-            pWorkWin->RegisterChild_Impl( *GetSplitWindow(), eAlign, true )->nVisible = CHILD_VISIBLE;
+            SAL_INFO("sfx", "SfxSplitWindow::InsertWindow_Impl - registering empty Splitwindow" );
+            pWorkWin->RegisterChild_Impl( *GetSplitWindow(), eAlign )->nVisible = SfxChildVisibility::VISIBLE;
             pWorkWin->ArrangeChildren_Impl();
             if ( bFadeIn )
                 FadeIn();
@@ -741,17 +712,15 @@ void SfxSplitWindow::InsertWindow_Impl( SfxDock_Impl* pDock,
             bool bFadeIn = ( pEmptyWin->nState & 2 ) != 0;
             pEmptyWin->bFadeIn = false;
             pEmptyWin->Actualize();
-#ifdef DBG_UTIL
             if ( !bPinned || !pEmptyWin->bFadeIn )
             {
-                OSL_TRACE( "SfxSplitWindow::InsertWindow_Impl - registering empty Splitwindow" );
+                SAL_INFO("sfx", "SfxSplitWindow::InsertWindow_Impl - registering empty Splitwindow" );
             }
             else
             {
-                OSL_TRACE( "SfxSplitWindow::InsertWindow_Impl - registering real Splitwindow" );
+                SAL_INFO("sfx", "SfxSplitWindow::InsertWindow_Impl - registering real Splitwindow" );
             }
-#endif
-            pWorkWin->RegisterChild_Impl( *GetSplitWindow(), eAlign, true )->nVisible = CHILD_VISIBLE;
+            pWorkWin->RegisterChild_Impl( *GetSplitWindow(), eAlign )->nVisible = SfxChildVisibility::VISIBLE;
             pWorkWin->ArrangeChildren_Impl();
             if ( bFadeIn )
                 FadeIn();
@@ -761,36 +730,34 @@ void SfxSplitWindow::InsertWindow_Impl( SfxDock_Impl* pDock,
     }
 
     delete pDeactivateUpdateMode;
-    bLocked = false;
 
     // workaround insuffiency of <SplitWindow> regarding dock layouting:
     // apply FIXED item size as 'original' item size to improve layouting of undock-dock-cycle of a window
     {
         std::vector< std::pair< sal_uInt16, long > > aNewOrgSizes;
         // get FIXED item sizes
-        sal_uInt16 nCount = pDockArr->size();
+        sal_uInt16 nCount = maDockArr.size();
         for ( sal_uInt16 n=0; n<nCount; ++n )
         {
-            const SfxDock_Impl& rD = (*pDockArr)[n];
+            const SfxDock_Impl& rD = *maDockArr[n].get();
             if ( rD.pWin )
             {
                 const sal_uInt16 nId = rD.nType;
-                const long nSize    = GetItemSize( nId, SWIB_FIXED );
-                aNewOrgSizes.push_back( std::pair< sal_uInt16, long >( nId, nSize ) );
+                const long nSize    = GetItemSize( nId, SplitWindowItemFlags::Fixed );
+                aNewOrgSizes.emplace_back( nId, nSize );
             }
         }
         // apply new item sizes
         DeactivateUpdateMode aDeactivateUpdateMode( *this );
-        for ( sal_uInt16 i = 0; i < aNewOrgSizes.size(); ++i )
+        for (const std::pair< sal_uInt16, long > & rNewOrgSize : aNewOrgSizes)
         {
-            SetItemSize( aNewOrgSizes[i].first, aNewOrgSizes[i].second );
+            SetItemSize( rNewOrgSize.first, rNewOrgSize.second );
         }
     }
 }
 
 
-
-void SfxSplitWindow::RemoveWindow( SfxDockingWindow* pDockWin, bool bHide )
+void SfxSplitWindow::RemoveWindow( SfxDockingWindow const * pDockWin, bool bHide )
 
 /*  [Description]
 
@@ -802,9 +769,9 @@ void SfxSplitWindow::RemoveWindow( SfxDockingWindow* pDockWin, bool bHide )
 
     // SplitWindows are once created in SFX and is made invisible after
     // removing the last DockingWindows.
-    if ( GetItemCount( nSet ) == 1 && GetItemCount( 0 ) == 1 )
+    if ( GetItemCount( nSet ) == 1 && GetItemCount() == 1 )
     {
-        // The Rearranging in WorkWindow is caues by SfxDockingwindow
+        // The Rearranging in WorkWindow is caused by SfxDockingwindow
         Hide();
         pEmptyWin->aTimer.Stop();
         sal_uInt16 nRealState = pEmptyWin->nState;
@@ -813,11 +780,11 @@ void SfxSplitWindow::RemoveWindow( SfxDockingWindow* pDockWin, bool bHide )
 #ifdef DBG_UTIL
         if ( !bPinned || !pEmptyWin->bFadeIn )
         {
-            OSL_TRACE( "SfxSplitWindow::RemoveWindow - releasing empty Splitwindow" );
+            SAL_INFO("sfx", "SfxSplitWindow::RemoveWindow - releasing empty Splitwindow" );
         }
         else
         {
-            OSL_TRACE( "SfxSplitWindow::RemoveWindow - releasing real Splitwindow" );
+            SAL_INFO("sfx", "SfxSplitWindow::RemoveWindow - releasing real Splitwindow" );
         }
 #endif
         pWorkWin->ReleaseChild_Impl( *GetSplitWindow() );
@@ -825,13 +792,13 @@ void SfxSplitWindow::RemoveWindow( SfxDockingWindow* pDockWin, bool bHide )
         pWorkWin->ArrangeAutoHideWindows( this );
     }
 
-    sal_uInt16 nCount = pDockArr->size();
+    sal_uInt16 nCount = maDockArr.size();
     for ( sal_uInt16 n=0; n<nCount; n++ )
     {
-        SfxDock_Impl& rDock = (*pDockArr)[n];
+        SfxDock_Impl& rDock = *maDockArr[n].get();
         if ( rDock.nType == pDockWin->GetType() )
         {
-            rDock.pWin = 0;
+            rDock.pWin = nullptr;
             rDock.bHide = bHide;
             break;
         }
@@ -839,20 +806,15 @@ void SfxSplitWindow::RemoveWindow( SfxDockingWindow* pDockWin, bool bHide )
 
     // Remove Windows, and if it was the last of the line, then also remove
     // the line (line = itemset)
-    DeactivateUpdateMode* pDeactivateUpdateMode = new DeactivateUpdateMode( *this );
-    bLocked = true;
+    std::unique_ptr<DeactivateUpdateMode> pDeactivateUpdateMode( new DeactivateUpdateMode( *this ) );
 
     RemoveItem( pDockWin->GetType() );
 
     if ( nSet && !GetItemCount( nSet ) )
         RemoveItem( nSet );
-
-    delete pDeactivateUpdateMode;
-    bLocked = false;
 };
 
 
-
 bool SfxSplitWindow::GetWindowPos( const SfxDockingWindow* pWindow,
                                         sal_uInt16& rLine, sal_uInt16& rPos ) const
 /*  [Description]
@@ -872,7 +834,6 @@ bool SfxSplitWindow::GetWindowPos( const SfxDockingWindow* pWindow,
 }
 
 
-
 bool SfxSplitWindow::GetWindowPos( const Point& rTestPos,
                                       sal_uInt16& rLine, sal_uInt16& rPos ) const
 /*  [Description]
@@ -893,7 +854,6 @@ bool SfxSplitWindow::GetWindowPos( const Point& rTestPos,
 }
 
 
-
 sal_uInt16 SfxSplitWindow::GetLineCount() const
 
 /*  [Description]
@@ -901,11 +861,10 @@ sal_uInt16 SfxSplitWindow::GetLineCount() const
     Returns the number of rows = number of sub-itemsets in the root set.
 */
 {
-    return GetItemCount( 0 );
+    return GetItemCount();
 }
 
 
-
 long SfxSplitWindow::GetLineSize( sal_uInt16 nLine ) const
 
 /*  [Description]
@@ -918,7 +877,6 @@ long SfxSplitWindow::GetLineSize( sal_uInt16 nLine ) const
 }
 
 
-
 sal_uInt16 SfxSplitWindow::GetWindowCount( sal_uInt16 nLine ) const
 
 /*  [Description]
@@ -931,7 +889,6 @@ sal_uInt16 SfxSplitWindow::GetWindowCount( sal_uInt16 nLine ) const
 }
 
 
-
 sal_uInt16 SfxSplitWindow::GetWindowCount() const
 
 /*  [Description]
@@ -939,24 +896,16 @@ sal_uInt16 SfxSplitWindow::GetWindowCount() const
     Returns the total number of windows
 */
 {
-    return GetItemCount( 0 );
+    return GetItemCount();
 }
 
 
-
-void SfxSplitWindow::Command( const CommandEvent& rCEvt )
-{
-    SplitWindow::Command( rCEvt );
-}
-
-
-
-IMPL_LINK( SfxSplitWindow, TimerHdl, Timer*, pTimer)
+IMPL_LINK( SfxSplitWindow, TimerHdl, Timer*, pTimer, void)
 {
     if ( pTimer )
         pTimer->Stop();
 
-    if ( CursorIsOverRect( false ) || !pTimer )
+    if ( CursorIsOverRect() || !pTimer )
     {
         // If the cursor is within the window, display the SplitWindow and set
         // up the timer for close
@@ -975,7 +924,7 @@ IMPL_LINK( SfxSplitWindow, TimerHdl, Timer*, pTimer)
             // do nothing
             pEmptyWin->aLastPos = GetPointerPosPixel();
             pEmptyWin->aTimer.Start();
-            return 0L;
+            return;
         }
 
         // Especially for TF_AUTOSHOW_ON_MOUSEMOVE :
@@ -997,7 +946,7 @@ IMPL_LINK( SfxSplitWindow, TimerHdl, Timer*, pTimer)
 
             if ( pEmptyWin->bEndAutoHide )
             {
-               // As far as I am concered this can be the end of AutoShow
+               // As far as I am concerned this can be the end of AutoShow
                // But maybe some other SfxSplitWindow will remain open,
                // then all others remain open too.
                 if ( !pWorkWin->IsAutoHideMode( this ) )
@@ -1018,13 +967,10 @@ IMPL_LINK( SfxSplitWindow, TimerHdl, Timer*, pTimer)
             }
         }
     }
-
-    return 0L;
 }
 
 
-
-bool SfxSplitWindow::CursorIsOverRect( bool bForceAdding ) const
+bool SfxSplitWindow::CursorIsOverRect() const
 {
     bool bVisible = IsVisible();
 
@@ -1032,16 +978,7 @@ bool SfxSplitWindow::CursorIsOverRect( bool bForceAdding ) const
     Point aPos = pEmptyWin->GetParent()->OutputToScreenPixel( pEmptyWin->GetPosPixel() );
     Size aSize = pEmptyWin->GetSizePixel();
 
-    if ( bForceAdding )
-    {
-        // Extend with +/- a few pixels, otherwise it is too nervous
-        aPos.X() -= nPixel;
-        aPos.Y() -= nPixel;
-        aSize.Width() += 2 * nPixel;
-        aSize.Height() += 2 * nPixel;
-    }
-
-    Rectangle aRect( aPos, aSize );
+    tools::Rectangle aRect( aPos, aSize );
 
     if ( bVisible )
     {
@@ -1054,17 +991,14 @@ bool SfxSplitWindow::CursorIsOverRect( bool bForceAdding ) const
         aVisSize.Width() += 2 * nPixel;
         aVisSize.Height() += 2 * nPixel;
 
-        Rectangle aVisRect( aVisPos, aVisSize );
+        tools::Rectangle aVisRect( aVisPos, aVisSize );
         aRect = aRect.GetUnion( aVisRect );
     }
 
-    if ( aRect.IsInside( OutputToScreenPixel( ((vcl::Window*)this)->GetPointerPosPixel() ) ) )
-        return true;
-    return false;
+    return aRect.IsInside( OutputToScreenPixel( static_cast<vcl::Window*>(const_cast<SfxSplitWindow *>(this))->GetPointerPosPixel() ) );
 }
 
 
-
 SplitWindow* SfxSplitWindow::GetSplitWindow()
 {
     if ( !bPinned || !pEmptyWin->bFadeIn )
@@ -1084,14 +1018,13 @@ bool SfxSplitWindow::IsAutoHide( bool bSelf ) const
 }
 
 
-
 void SfxSplitWindow::SetPinned_Impl( bool bOn )
 {
     if ( bPinned == bOn )
         return;
 
     bPinned = bOn;
-    if ( GetItemCount( 0 ) == 0 )
+    if ( GetItemCount() == 0 )
         return;
 
     if ( !bOn )
@@ -1100,12 +1033,12 @@ void SfxSplitWindow::SetPinned_Impl( bool bOn )
         if ( pEmptyWin->bFadeIn )
         {
             // Unregister replacement windows
-            OSL_TRACE( "SfxSplitWindow::SetPinned_Impl - releasing real Splitwindow" );
+            SAL_INFO("sfx", "SfxSplitWindow::SetPinned_Impl - releasing real Splitwindow" );
             pWorkWin->ReleaseChild_Impl( *this );
             Hide();
             pEmptyWin->Actualize();
-            OSL_TRACE( "SfxSplitWindow::SetPinned_Impl - registering empty Splitwindow" );
-            pWorkWin->RegisterChild_Impl( *pEmptyWin, eAlign, true )->nVisible = CHILD_VISIBLE;
+            SAL_INFO("sfx", "SfxSplitWindow::SetPinned_Impl - registering empty Splitwindow" );
+            pWorkWin->RegisterChild_Impl( *pEmptyWin, eAlign )->nVisible = SfxChildVisibility::VISIBLE;
         }
 
         Point aPos( GetPosPixel() );
@@ -1121,31 +1054,26 @@ void SfxSplitWindow::SetPinned_Impl( bool bOn )
     {
         pEmptyWin->nState &= ~1;
         SetOutputSizePixel( GetFloatingWindow()->GetOutputSizePixel() );
-        SetFloatingMode( false );
+        SetFloatingMode(false);
 
         if ( pEmptyWin->bFadeIn )
         {
             // Unregister replacement windows
-            OSL_TRACE( "SfxSplitWindow::SetPinned_Impl - releasing empty Splitwindow" );
+            SAL_INFO("sfx", "SfxSplitWindow::SetPinned_Impl - releasing empty Splitwindow" );
             pWorkWin->ReleaseChild_Impl( *pEmptyWin );
             pEmptyWin->Hide();
-            OSL_TRACE( "SfxSplitWindow::SetPinned_Impl - registering real Splitwindow" );
-            pWorkWin->RegisterChild_Impl( *this, eAlign, true )->nVisible = CHILD_VISIBLE;
+            SAL_INFO("sfx", "SfxSplitWindow::SetPinned_Impl - registering real Splitwindow" );
+            pWorkWin->RegisterChild_Impl( *this, eAlign )->nVisible = SfxChildVisibility::VISIBLE;
         }
     }
-
-    SetAutoHideState( !bPinned );
-    pEmptyWin->SetAutoHideState( !bPinned );
 }
 
-
-
 void SfxSplitWindow::SetFadeIn_Impl( bool bOn )
 {
     if ( bOn == pEmptyWin->bFadeIn )
         return;
 
-    if ( GetItemCount( 0 ) == 0 )
+    if ( GetItemCount() == 0 )
         return;
 
     pEmptyWin->bFadeIn = bOn;
@@ -1160,11 +1088,11 @@ void SfxSplitWindow::SetFadeIn_Impl( bool bOn )
         }
         else
         {
-            OSL_TRACE( "SfxSplitWindow::SetFadeIn_Impl - releasing empty Splitwindow" );
+            SAL_INFO("sfx", "SfxSplitWindow::SetFadeIn_Impl - releasing empty Splitwindow" );
             pWorkWin->ReleaseChild_Impl( *pEmptyWin );
             pEmptyWin->Hide();
-            OSL_TRACE( "SfxSplitWindow::SetFadeIn_Impl - registering real Splitwindow" );
-            pWorkWin->RegisterChild_Impl( *this, eAlign, true )->nVisible = CHILD_VISIBLE;
+            SAL_INFO("sfx", "SfxSplitWindow::SetFadeIn_Impl - registering real Splitwindow" );
+            pWorkWin->RegisterChild_Impl( *this, eAlign )->nVisible = SfxChildVisibility::VISIBLE;
             pWorkWin->ArrangeChildren_Impl();
             pWorkWin->ShowChildren_Impl();
         }
@@ -1176,12 +1104,12 @@ void SfxSplitWindow::SetFadeIn_Impl( bool bOn )
         if ( !IsFloatingMode() )
         {
             // The window is not "floating", should be hidden
-            OSL_TRACE( "SfxSplitWindow::SetFadeIn_Impl - releasing real Splitwindow" );
+            SAL_INFO("sfx", "SfxSplitWindow::SetFadeIn_Impl - releasing real Splitwindow" );
             pWorkWin->ReleaseChild_Impl( *this );
             Hide();
             pEmptyWin->Actualize();
-            OSL_TRACE( "SfxSplitWindow::SetFadeIn_Impl - registering empty Splitwindow" );
-            pWorkWin->RegisterChild_Impl( *pEmptyWin, eAlign, true )->nVisible = CHILD_VISIBLE;
+            SAL_INFO("sfx", "SfxSplitWindow::SetFadeIn_Impl - registering empty Splitwindow" );
+            pWorkWin->RegisterChild_Impl( *pEmptyWin, eAlign )->nVisible = SfxChildVisibility::VISIBLE;
             pWorkWin->ArrangeChildren_Impl();
             pWorkWin->ShowChildren_Impl();
             pWorkWin->ArrangeAutoHideWindows( this );
@@ -1194,28 +1122,6 @@ void SfxSplitWindow::SetFadeIn_Impl( bool bOn )
     }
 }
 
-void SfxSplitWindow::AutoHide()
-{
-    // If this handler is called in the "real" SplitWindow, it is
-    // either docked and should be displayed as floating, or vice versa
-    if ( !bPinned )
-    {
-        // It "floats", thus dock it again
-        SetPinned_Impl( true );
-        pWorkWin->ArrangeChildren_Impl();
-    }
-    else
-    {
-        // In "limbo"
-        SetPinned_Impl( false );
-        pWorkWin->ArrangeChildren_Impl();
-        pWorkWin->ArrangeAutoHideWindows( this );
-    }
-
-    pWorkWin->ShowChildren_Impl();
-    SaveConfig_Impl();
-}
-
 void SfxSplitWindow::FadeOut_Impl()
 {
     if ( pEmptyWin->aTimer.IsActive() )
@@ -1225,7 +1131,6 @@ void SfxSplitWindow::FadeOut_Impl()
     }
 
     SetFadeIn_Impl( false );
-    Show_Impl();
 }
 
 void SfxSplitWindow::FadeOut()
@@ -1237,73 +1142,6 @@ void SfxSplitWindow::FadeOut()
 void SfxSplitWindow::FadeIn()
 {
     SetFadeIn_Impl( true );
-    Show_Impl();
-}
-
-void SfxSplitWindow::Show_Impl()
-{
-    sal_uInt16 nCount = pDockArr->size();
-    for ( sal_uInt16 n=0; n<nCount; n++ )
-    {
-        const SfxDock_Impl& rDock = (*pDockArr)[n];
-        if ( rDock.pWin )
-            rDock.pWin->FadeIn( pEmptyWin->bFadeIn );
-    }
-}
-
-bool SfxSplitWindow::ActivateNextChild_Impl( bool bForward )
-{
-    // If no pActive, go to first and last window (!bForward is first
-    // decremented in the loop)
-    sal_uInt16 nCount = pDockArr->size();
-    sal_uInt16 n = bForward ? 0 : nCount;
-
-    // if Focus is within, then move to a window forward or backwards
-    // if possible
-    if ( pActive )
-    {
-        // Determine the active window
-        for ( n=0; n<nCount; n++ )
-        {
-            const SfxDock_Impl& rD = (*pDockArr)[n];
-            if ( rD.pWin && rD.pWin->HasChildPathFocus() )
-                break;
-        }
-
-        if ( bForward )
-            // up window counter (then when n>nCount, the loop below is
-            // not entered)
-            n++;
-    }
-
-    if ( bForward )
-    {
-        // Search for next window
-        for ( sal_uInt16 nNext=n; nNext<nCount; nNext++ )
-        {
-            const SfxDock_Impl& rD = (*pDockArr)[nNext];
-            if ( rD.pWin )
-            {
-                rD.pWin->GrabFocus();
-                return true;
-            }
-        }
-    }
-    else
-    {
-        // Search for previous window
-        for ( sal_uInt16 nNext=n; nNext--; )
-        {
-            const SfxDock_Impl& rD = (*pDockArr)[nNext];
-            if ( rD.pWin )
-            {
-                rD.pWin->GrabFocus();
-                return true;
-            }
-        }
-    }
-
-    return false;
 }
 
 void SfxSplitWindow::SetActiveWindow_Impl( SfxDockingWindow* pWin )
