@@ -21,7 +21,8 @@
 #include <sfx2/titledockwin.hxx>
 #include <sfx2/bindings.hxx>
 #include <sfx2/dispatch.hxx>
-#include "sfxlocal.hrc"
+#include <sfx2/strings.hrc>
+#include <bitmaps.hlst>
 #include <sfx2/sfxresid.hxx>
 
 #include <svl/eitem.hxx>
@@ -143,7 +144,7 @@ namespace sfx2
         rRenderContext.SetTextFillColor();
     }
 
-    void TitledDockingWindow::Paint(vcl::RenderContext& rRenderContext, const Rectangle& i_rArea)
+    void TitledDockingWindow::Paint(vcl::RenderContext& rRenderContext, const tools::Rectangle& i_rArea)
     {
         const StyleSettings& rStyleSettings = rRenderContext.GetSettings().GetStyleSettings();
 
@@ -173,15 +174,15 @@ namespace sfx2
         int nInnerBottom = nOuterBottom - m_aBorder.Bottom() + 1;
 
         // Paint title bar background.
-        Rectangle aTitleBarBox(Rectangle(nOuterLeft, 0, nOuterRight, nInnerTop - 1));
+        tools::Rectangle aTitleBarBox(tools::Rectangle(nOuterLeft, 0, nOuterRight, nInnerTop - 1));
         rRenderContext.DrawRect(aTitleBarBox);
 
         if (nInnerLeft > nOuterLeft)
-            rRenderContext.DrawRect(Rectangle(nOuterLeft, nInnerTop, nInnerLeft, nInnerBottom));
+            rRenderContext.DrawRect(tools::Rectangle(nOuterLeft, nInnerTop, nInnerLeft, nInnerBottom));
         if (nOuterRight > nInnerRight)
-            rRenderContext.DrawRect(Rectangle(nInnerRight, nInnerTop, nOuterRight, nInnerBottom));
+            rRenderContext.DrawRect(tools::Rectangle(nInnerRight, nInnerTop, nOuterRight, nInnerBottom));
         if (nInnerBottom < nOuterBottom)
-            rRenderContext.DrawRect(Rectangle(nOuterLeft, nInnerBottom, nOuterRight, nOuterBottom));
+            rRenderContext.DrawRect(tools::Rectangle(nOuterLeft, nInnerBottom, nOuterRight, nOuterBottom));
 
         // Paint bevel border.
         rRenderContext.SetFillColor();
@@ -214,8 +215,9 @@ namespace sfx2
         m_aToolbox->Clear();
 
         // Get the closer bitmap and set it as right most button.
-        Image aImage( SfxResId( SFX_IMG_CLOSE_DOC ) );
-        m_aToolbox->InsertItem( 1, aImage );
+        BitmapEx aBitmapEx(SFX_BMP_CLOSE_DOC);
+        m_aToolbox->InsertItem(1, Image(aBitmapEx));
+        m_aToolbox->SetQuickHelpText(1, SfxResId(STR_CLOSE_PANE));
         m_aToolbox->ShowItem( 1 );
     }
 
@@ -251,14 +253,6 @@ namespace sfx2
         SfxDockingWindow::StateChanged( i_nType );
     }
 
-    void TitledDockingWindow::EndDocking( const Rectangle& i_rRect, bool i_bFloatMode )
-    {
-        SfxDockingWindow::EndDocking( i_rRect, i_bFloatMode );
-
-        m_aEndDockingHdl.Call( this );
-    }
-
-
     void TitledDockingWindow::DataChanged( const DataChangedEvent& i_rDataChangedEvent )
     {
         SfxDockingWindow::DataChanged( i_rDataChangedEvent );
