@@ -23,30 +23,13 @@
 
 #include <sfx2/frmdescr.hxx>
 #include <sfx2/app.hxx>
-
-struct SfxFrameDescriptor_Impl
-{
-    Wallpaper*  pWallpaper;
-    SfxItemSet* pArgs;
-    bool        bEditable;
-
-    SfxFrameDescriptor_Impl() : pWallpaper( nullptr ), pArgs( nullptr ), bEditable( true ) {}
-    ~SfxFrameDescriptor_Impl()
-    {
-        delete pWallpaper;
-        delete pArgs;
-    }
-};
+#include <memory>
 
 SfxFrameDescriptor::SfxFrameDescriptor() :
     aMargin( -1, -1 ),
     eScroll( ScrollingMode::Auto ),
     bHasBorder( true ),
-    bHasBorderSet( false ),
-    bResizeHorizontal( true ),
-    bResizeVertical( true ),
-    bReadOnly( false ),
-    pImpl( new SfxFrameDescriptor_Impl )
+    bHasBorderSet( false )
 {
 }
 
@@ -56,9 +39,9 @@ SfxFrameDescriptor::~SfxFrameDescriptor()
 
 SfxItemSet* SfxFrameDescriptor::GetArgs()
 {
-    if( !pImpl->pArgs )
-        pImpl->pArgs = new SfxAllItemSet( SfxGetpApp()->GetPool() );
-    return pImpl->pArgs;
+    if( !m_pArgs )
+        m_pArgs.reset( new SfxAllItemSet( SfxGetpApp()->GetPool() ) );
+    return m_pArgs.get();
 }
 
 void SfxFrameDescriptor::SetURL( const OUString& rURL )
@@ -70,21 +53,8 @@ void SfxFrameDescriptor::SetURL( const OUString& rURL )
 void SfxFrameDescriptor::SetActualURL( const OUString& rURL )
 {
     aActualURL = INetURLObject(rURL);
-    if ( pImpl->pArgs )
-        pImpl->pArgs->ClearItem();
-}
-
-void SfxFrameDescriptor::SetEditable( bool bSet )
-{
-    pImpl->bEditable = bSet;
-}
-
-void SfxFrameDescriptor::SetWallpaper( const Wallpaper& rWallpaper )
-{
-    DELETEZ( pImpl->pWallpaper );
-
-    if ( rWallpaper.GetStyle() != WallpaperStyle::NONE )
-        pImpl->pWallpaper = new Wallpaper( rWallpaper );
+    if ( m_pArgs )
+        m_pArgs->ClearItem();
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
