@@ -18,7 +18,7 @@
  */
 
 
-#ifdef WNT
+#ifdef _WIN32
 #include <prewin.h>
 #include <postwin.h>
 #endif
@@ -34,7 +34,7 @@
 
 #include <osl/thread.h>
 #include <vcl/gdimtf.hxx>
-#include <vcl/graphic.hxx>
+#include <vcl/graph.hxx>
 #include <vcl/cvtgrf.hxx>
 #include <vcl/outdev.hxx>
 #include <vcl/virdev.hxx>
@@ -47,11 +47,12 @@
 #include <unotools/ucbstreamhelper.hxx>
 #include <unotools/streamwrap.hxx>
 #include <comphelper/processfactory.hxx>
-
+#include <o3tl/char16_t2wchar_t.hxx>
 
 #include <sfx2/sfxresid.hxx>
 #include "graphhelp.hxx"
-#include "doc.hrc"
+#include <sfx2/strings.hrc>
+#include <bitmaps.hlst>
 
 #include <memory>
 
@@ -64,7 +65,7 @@ SvMemoryStream* GraphicHelper::getFormatStrFromGDI_Impl( const GDIMetaFile* pGDI
     {
         SvMemoryStream* pStream = new SvMemoryStream( 65535, 65535 );
         Graphic aGraph( *pGDIMeta );
-        if ( GraphicConverter::Export( *pStream, aGraph, nFormat ) == 0 )
+        if ( GraphicConverter::Export( *pStream, aGraph, nFormat ) == ERRCODE_NONE )
             pResult = pStream;
         else
             delete pStream;
@@ -77,10 +78,9 @@ SvMemoryStream* GraphicHelper::getFormatStrFromGDI_Impl( const GDIMetaFile* pGDI
 // static
 void* GraphicHelper::getEnhMetaFileFromGDI_Impl( const GDIMetaFile* pGDIMeta )
 {
-    (void)pGDIMeta;  // unused
     void* pResult = nullptr;
 
-#ifdef WNT
+#ifdef _WIN32
     if ( pGDIMeta )
     {
         OUString const aStr(".emf");
@@ -88,20 +88,21 @@ void* GraphicHelper::getEnhMetaFileFromGDI_Impl( const GDIMetaFile* pGDIMeta )
 
         OUString aMetaFile = aTempFile.GetFileName();
         OUString aMetaURL = aTempFile.GetURL();
-        OString aWinFile = OUStringToOString( aMetaFile, osl_getThreadTextEncoding() );
 
-        SvStream* pStream = ::utl::UcbStreamHelper::CreateStream( aMetaURL, STREAM_STD_READWRITE );
+        SvStream* pStream = ::utl::UcbStreamHelper::CreateStream( aMetaURL, StreamMode::STD_READWRITE );
         if ( pStream )
         {
             Graphic aGraph( *pGDIMeta );
-            sal_Bool bFailed = (sal_Bool)GraphicConverter::Export( *pStream, aGraph, ConvertDataFormat::EMF );
+            ErrCode nFailed = GraphicConverter::Export( *pStream, aGraph, ConvertDataFormat::EMF );
             pStream->Flush();
             delete pStream;
 
-            if ( !bFailed )
-                pResult = GetEnhMetaFileA( aWinFile.getStr() );
+            if ( !nFailed )
+                pResult = GetEnhMetaFileW( o3tl::toW(aMetaFile.getStr()) );
         }
     }
+#else
+    (void)pGDIMeta;  // unused
 #endif
 
     return pResult;
@@ -111,24 +112,22 @@ void* GraphicHelper::getEnhMetaFileFromGDI_Impl( const GDIMetaFile* pGDIMeta )
 // static
 void* GraphicHelper::getWinMetaFileFromGDI_Impl( const GDIMetaFile* pGDIMeta, const Size& aMetaSize )
 {
-    (void)pGDIMeta;  // unused
-    (void)aMetaSize; // unused
     void* pResult = nullptr;
 
-#ifdef WNT
+#ifdef _WIN32
     if ( pGDIMeta )
     {
-        SvMemoryStream* pStream = new SvMemoryStream( 65535, 65535 );
+        SvMemoryStream pStream( 65535, 65535 );
         Graphic aGraph( *pGDIMeta );
-        sal_Bool bFailed = (sal_Bool)GraphicConverter::Export( *pStream, aGraph, ConvertDataFormat::WMF );
-        pStream->Flush();
-        if ( !bFailed )
+        ErrCode nFailed = GraphicConverter::Export( pStream, aGraph, ConvertDataFormat::WMF );
+        pStream.Flush();
+        if ( !nFailed )
         {
-            sal_Int32 nLength = pStream->Seek( STREAM_SEEK_TO_END );
+            sal_Int32 nLength = pStream.Seek( STREAM_SEEK_TO_END );
             if ( nLength > 22 )
             {
                 HMETAFILE hMeta = SetMetaFileBitsEx( nLength - 22,
-                                ( reinterpret_cast< const unsigned char*>( pStream->GetData() ) ) + 22 );
+                                static_cast< const unsigned char*>( pStream.GetData() ) + 22 );
 
                 if ( hMeta )
                 {
@@ -136,13 +135,13 @@ void* GraphicHelper::getWinMetaFileFromGDI_Impl( const GDIMetaFile* pGDIMeta, co
 
                     if ( hMemory )
                     {
-                           METAFILEPICT* pMF = (METAFILEPICT*)GlobalLock( hMemory );
+                           METAFILEPICT* pMF = static_cast<METAFILEPICT*>(GlobalLock( hMemory ));
 
                            pMF->hMF = hMeta;
                            pMF->mm = MM_ANISOTROPIC;
 
                         MapMode aMetaMode = pGDIMeta->GetPrefMapMode();
-                        MapMode aWinMode( MAP_100TH_MM );
+                        MapMode aWinMode( MapUnit::Map100thMM );
 
                         if ( aWinMode == pGDIMeta->GetPrefMapMode() )
                         {
@@ -159,16 +158,17 @@ void* GraphicHelper::getWinMetaFileFromGDI_Impl( const GDIMetaFile* pGDIMeta, co
                         }
 
                         GlobalUnlock( hMemory );
-                        pResult = (void*)hMemory;
+                        pResult = static_cast<void*>(hMemory);
                     }
                     else
                            DeleteMetaFile( hMeta );
                 }
             }
         }
-
-        delete pStream;
     }
+#else
+    (void)pGDIMeta;  // unused
+    (void)aMetaSize; // unused
 #endif
 
 
@@ -177,7 +177,7 @@ void* GraphicHelper::getWinMetaFileFromGDI_Impl( const GDIMetaFile* pGDIMeta, co
 
 
 // static
-bool GraphicHelper::getThumbnailFormatFromGDI_Impl(GDIMetaFile* pMetaFile, const uno::Reference<io::XStream>& xStream)
+bool GraphicHelper::getThumbnailFormatFromGDI_Impl(GDIMetaFile const * pMetaFile, const uno::Reference<io::XStream>& xStream)
 {
     bool bResult = false;
 
@@ -191,14 +191,14 @@ bool GraphicHelper::getThumbnailFormatFromGDI_Impl(GDIMetaFile* pMetaFile, const
 
     BitmapEx aResultBitmap;
 
-    bResult = pMetaFile->CreateThumbnail(aResultBitmap, 256, BMP_CONVERSION_8BIT_COLORS, BmpScaleFlag::Default);
+    bResult = pMetaFile->CreateThumbnail(aResultBitmap, BmpConversion::N8BitColors, BmpScaleFlag::Default);
 
     if (!bResult || aResultBitmap.IsEmpty())
         return false;
 
     GraphicFilter& rFilter = GraphicFilter::GetGraphicFilter();
 
-    if (rFilter.compressAsPNG(aResultBitmap, *pStream.get(), 9) != GRFILTER_OK)
+    if (rFilter.compressAsPNG(aResultBitmap, *pStream.get()) != ERRCODE_NONE)
         return false;
 
     pStream->Flush();
@@ -207,17 +207,16 @@ bool GraphicHelper::getThumbnailFormatFromGDI_Impl(GDIMetaFile* pMetaFile, const
 }
 
 // static
-bool GraphicHelper::getThumbnailReplacement_Impl( sal_Int32 nResID, const uno::Reference< io::XStream >& xStream )
+bool GraphicHelper::getThumbnailReplacement_Impl(const OUString& rResID, const uno::Reference< io::XStream >& xStream )
 {
     bool bResult = false;
-    if ( nResID && xStream.is() )
+    if (!rResID.isEmpty() && xStream.is())
     {
         uno::Reference< uno::XComponentContext > xContext = ::comphelper::getProcessComponentContext();
         try
         {
             uno::Reference< graphic::XGraphicProvider > xGraphProvider(graphic::GraphicProvider::create(xContext));
-            OUString aURL("private:resource/sfx/bitmapex/");
-            aURL += OUString::number( nResID );
+            const OUString aURL{"private:graphicrepository/" + rResID};
 
             uno::Sequence< beans::PropertyValue > aMediaProps( 1 );
             aMediaProps[0].Name = "URL";
@@ -244,34 +243,33 @@ bool GraphicHelper::getThumbnailReplacement_Impl( sal_Int32 nResID, const uno::R
     return bResult;
 }
 
-
 // static
-sal_uInt16 GraphicHelper::getThumbnailReplacementIDByFactoryName_Impl( const OUString& aFactoryShortName, bool /*bIsTemplate*/ )
+OUString GraphicHelper::getThumbnailReplacementIDByFactoryName_Impl( const OUString& aFactoryShortName )
 {
-    sal_uInt16 nResult = 0;
+    OUString sResult;
 
     if ( aFactoryShortName == "scalc" )
     {
-        nResult = BMP_128X128_CALC_DOC;
+        sResult = BMP_128X128_CALC_DOC;
     }
     else if ( aFactoryShortName == "sdraw" )
     {
-        nResult = BMP_128X128_DRAW_DOC;
+        sResult = BMP_128X128_DRAW_DOC;
     }
     else if ( aFactoryShortName == "simpress" )
     {
-        nResult = BMP_128X128_IMPRESS_DOC;
+        sResult = BMP_128X128_IMPRESS_DOC;
     }
     else if ( aFactoryShortName == "smath" )
     {
-        nResult = BMP_128X128_MATH_DOC;
+        sResult = BMP_128X128_MATH_DOC;
     }
     else if ( aFactoryShortName == "swriter" || aFactoryShortName.startsWith("swriter/") )
     {
-        nResult = BMP_128X128_WRITER_DOC;
+        sResult = BMP_128X128_WRITER_DOC;
     }
 
-    return nResult;
+    return sResult;
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
