@@ -47,15 +47,14 @@ namespace {
         css::ui::LayoutSize maLayoutSize;
         sal_Int32 mnDistributedHeight;
         sal_Int32 mnWeight;
-        sal_Int32 mnPanelIndex;
         bool mbShowTitleBar;
 
         LayoutItem()
-            : mpPanel(),maLayoutSize(0,0,0),mnDistributedHeight(0),mnWeight(0),mnPanelIndex(0),mbShowTitleBar(true)
+            : mpPanel(),maLayoutSize(0,0,0),mnDistributedHeight(0),mnWeight(0),mbShowTitleBar(true)
         {}
     };
-    Rectangle LayoutPanels (
-        const Rectangle& rContentArea,
+    tools::Rectangle LayoutPanels (
+        const tools::Rectangle& rContentArea,
         sal_Int32& rMinimalWidth,
         ::std::vector<LayoutItem>& rLayoutItems,
         vcl::Window& rScrollClipWindow,
@@ -66,7 +65,7 @@ namespace {
         ::std::vector<LayoutItem>& rLayoutItem,
         sal_Int32& rAvailableHeight,
         sal_Int32& rMinimalWidth,
-        const Rectangle& rContentBox);
+        const tools::Rectangle& rContentBox);
     void DistributeHeights (
         ::std::vector<LayoutItem>& rLayoutItems,
         const sal_Int32 nHeightToDistribute,
@@ -77,12 +76,12 @@ namespace {
         const sal_Int32 nWidth,
         const LayoutMode eMode,
         vcl::Window& rScrollContainer);
-    Rectangle PlaceDeckTitle (
+    tools::Rectangle PlaceDeckTitle (
         vcl::Window& rTittleBar,
-        const Rectangle& rAvailableSpace);
-    Rectangle PlaceVerticalScrollBar (
+        const tools::Rectangle& rAvailableSpace);
+    tools::Rectangle PlaceVerticalScrollBar (
         ScrollBar& rVerticalScrollBar,
-        const Rectangle& rAvailableSpace,
+        const tools::Rectangle& rAvailableSpace,
         const bool bShowVerticalScrollBar);
     void SetupVerticalScrollBar(
         ScrollBar& rVerticalScrollBar,
@@ -90,18 +89,11 @@ namespace {
         const sal_Int32 nVisibleHeight);
     void UpdateFiller (
         vcl::Window& rFiller,
-        const Rectangle& rBox);
+        const tools::Rectangle& rBox);
 }
 
-#define IterateLayoutItems(iterator_name,container)                     \
-    for(::std::vector<LayoutItem>::iterator                             \
-                   iterator_name(container.begin()),                    \
-                   iEnd(container.end());                               \
-        iterator_name!=iEnd;                                            \
-        ++iterator_name)
-
 void DeckLayouter::LayoutDeck (
-    const Rectangle& rContentArea,
+    const tools::Rectangle& rContentArea,
     sal_Int32& rMinimalWidth,
     SharedPanelContainer& rPanels,
     vcl::Window& rDeckTitleBar,
@@ -112,7 +104,7 @@ void DeckLayouter::LayoutDeck (
 {
     if (rContentArea.GetWidth()<=0 || rContentArea.GetHeight()<=0)
         return;
-    Rectangle aBox (PlaceDeckTitle(rDeckTitleBar, rContentArea));
+    tools::Rectangle aBox (PlaceDeckTitle(rDeckTitleBar, rContentArea));
 
     if ( ! rPanels.empty())
     {
@@ -122,7 +114,6 @@ void DeckLayouter::LayoutDeck (
         for (sal_Int32 nIndex(0),nCount(rPanels.size()); nIndex<nCount; ++nIndex)
         {
             aLayoutItems[nIndex].mpPanel = rPanels[nIndex];
-            aLayoutItems[nIndex].mnPanelIndex = nIndex;
         }
         aBox = LayoutPanels(
             aBox,
@@ -138,8 +129,8 @@ void DeckLayouter::LayoutDeck (
 
 namespace {
 
-Rectangle LayoutPanels (
-    const Rectangle& rContentArea,
+tools::Rectangle LayoutPanels (
+    const tools::Rectangle& rContentArea,
     sal_Int32& rMinimalWidth,
     ::std::vector<LayoutItem>& rLayoutItems,
     vcl::Window& rScrollClipWindow,
@@ -147,7 +138,7 @@ Rectangle LayoutPanels (
     ScrollBar& rVerticalScrollBar,
     const bool bShowVerticalScrollBar)
 {
-    Rectangle aBox (PlaceVerticalScrollBar(rVerticalScrollBar, rContentArea, bShowVerticalScrollBar));
+    tools::Rectangle aBox (PlaceVerticalScrollBar(rVerticalScrollBar, rContentArea, bShowVerticalScrollBar));
 
     const sal_Int32 nWidth (aBox.GetWidth());
 
@@ -163,7 +154,11 @@ Rectangle LayoutPanels (
     // and count the different layouts.
     sal_Int32 nTotalPreferredHeight (0);
     sal_Int32 nTotalMinimumHeight (0);
-    IterateLayoutItems(iItem,rLayoutItems)
+
+    for(::std::vector<LayoutItem>::const_iterator iItem(rLayoutItems.begin()),
+         iEnd(rLayoutItems.end());
+        iItem!=iEnd;
+        ++iItem)
     {
         nTotalMinimumHeight += iItem->maLayoutSize.Minimum;
         nTotalPreferredHeight += iItem->maLayoutSize.Preferred;
@@ -187,10 +182,10 @@ Rectangle LayoutPanels (
 
     // We are now in one of three modes.
     // - The preferred height fits into the available size:
-    //   Use the preferred size, distribute the remaining height bei
+    //   Use the preferred size, distribute the remaining height by
     //   enlarging panels.
     // - The total minimum height fits into the available size:
-    //   Use the minimum size, distribute the remaining height bei
+    //   Use the minimum size, distribute the remaining height by
     //   enlarging panels.
     // - The total minimum height does not fit into the available
     //   size:
@@ -254,7 +249,10 @@ sal_Int32 PlacePanels (
     sal_Int32 nY (0);
 
     // Assign heights and places.
-    IterateLayoutItems(iItem,rLayoutItems)
+    for(::std::vector<LayoutItem>::const_iterator iItem(rLayoutItems.begin()),
+         iEnd(rLayoutItems.end());
+        iItem!=iEnd;
+        ++iItem)
     {
         if (!iItem->mpPanel)
             continue;
@@ -266,8 +264,8 @@ sal_Int32 PlacePanels (
         nY += nDeckSeparatorHeight;
 
         // Place the title bar.
-        PanelTitleBar* pTitleBar = rPanel.GetTitleBar();
-        if (pTitleBar != nullptr)
+        VclPtr<PanelTitleBar> pTitleBar = rPanel.GetTitleBar();
+        if (pTitleBar)
         {
             const sal_Int32 nPanelTitleBarHeight (Theme::GetInteger(Theme::Int_PanelTitleBarHeight) * rPanel.GetDPIScaleFactor());
 
@@ -339,13 +337,17 @@ void GetRequestedSizes (
     ::std::vector<LayoutItem>& rLayoutItems,
     sal_Int32& rAvailableHeight,
     sal_Int32& rMinimalWidth,
-    const Rectangle& rContentBox)
+    const tools::Rectangle& rContentBox)
 {
     rAvailableHeight = rContentBox.GetHeight();
 
     const sal_Int32 nDeckSeparatorHeight (Theme::GetInteger(Theme::Int_DeckSeparatorHeight));
 
-    IterateLayoutItems(iItem,rLayoutItems)
+    ::std::vector<LayoutItem>::const_iterator iEnd(rLayoutItems.end());
+
+    for(::std::vector<LayoutItem>::iterator iItem(rLayoutItems.begin());
+        iItem!=iEnd;
+        ++iItem)
     {
         ui::LayoutSize aLayoutSize (ui::LayoutSize(0,0,0));
         if (iItem->mpPanel != nullptr)
@@ -402,7 +404,12 @@ void DistributeHeights (
     // (either its minimum or preferred height) and the container height.
     sal_Int32 nTotalWeight (0);
     sal_Int32 nNoMaximumCount (0);
-    IterateLayoutItems(iItem,rLayoutItems)
+
+    ::std::vector<LayoutItem>::const_iterator iEnd(rLayoutItems.end());
+
+    for(::std::vector<LayoutItem>::iterator iItem(rLayoutItems.begin());
+        iItem!=iEnd;
+        ++iItem)
     {
         if (iItem->maLayoutSize.Maximum == 0)
             continue;
@@ -424,7 +431,9 @@ void DistributeHeights (
         return;
 
     // First pass of height distribution.
-    IterateLayoutItems(iItem,rLayoutItems)
+    for(::std::vector<LayoutItem>::iterator iItem(rLayoutItems.begin());
+        iItem!=iEnd;
+        ++iItem)
     {
         const sal_Int32 nBaseHeight (
             bMinimumHeightIsBase
@@ -457,7 +466,10 @@ void DistributeHeights (
     // Handle rounding error.
     sal_Int32 nAdditionalHeightForFirstPanel (nRemainingHeightToDistribute
         - nNoMaximumCount*nAdditionalHeightPerPanel);
-    IterateLayoutItems(iItem,rLayoutItems)
+
+    for(::std::vector<LayoutItem>::iterator iItem(rLayoutItems.begin());
+        iItem!=iEnd;
+        ++iItem)
     {
         if (iItem->maLayoutSize.Maximum < 0)
         {
@@ -469,9 +481,9 @@ void DistributeHeights (
     OSL_ASSERT(nRemainingHeightToDistribute==0);
 }
 
-Rectangle PlaceDeckTitle (
+tools::Rectangle PlaceDeckTitle (
     vcl::Window& rDeckTitleBar,
-    const Rectangle& rAvailableSpace)
+    const tools::Rectangle& rAvailableSpace)
 {
     if (static_cast<DockingWindow*>(rDeckTitleBar.GetParent()->GetParent())->IsFloatingMode())
     {
@@ -488,7 +500,7 @@ Rectangle PlaceDeckTitle (
             rAvailableSpace.GetWidth(),
             nDeckTitleBarHeight);
         rDeckTitleBar.Show();
-        return Rectangle(
+        return tools::Rectangle(
             rAvailableSpace.Left(),
             rAvailableSpace.Top() + nDeckTitleBarHeight,
             rAvailableSpace.Right(),
@@ -496,9 +508,9 @@ Rectangle PlaceDeckTitle (
     }
 }
 
-Rectangle PlaceVerticalScrollBar (
+tools::Rectangle PlaceVerticalScrollBar (
     ScrollBar& rVerticalScrollBar,
-    const Rectangle& rAvailableSpace,
+    const tools::Rectangle& rAvailableSpace,
     const bool bShowVerticalScrollBar)
 {
     if (bShowVerticalScrollBar)
@@ -510,7 +522,7 @@ Rectangle PlaceVerticalScrollBar (
             nScrollBarWidth,
             rAvailableSpace.GetHeight());
         rVerticalScrollBar.Show();
-        return Rectangle(
+        return tools::Rectangle(
             rAvailableSpace.Left(),
             rAvailableSpace.Top(),
             rAvailableSpace.Right() - nScrollBarWidth,
@@ -537,7 +549,7 @@ void SetupVerticalScrollBar(
 
 void UpdateFiller (
     vcl::Window& rFiller,
-    const Rectangle& rBox)
+    const tools::Rectangle& rBox)
 {
     if (rBox.GetHeight() > 0)
     {
