@@ -26,9 +26,9 @@
 #include <sfx2/sidebar/Tools.hxx>
 #include <sfx2/sidebar/FocusManager.hxx>
 #include <sfx2/sidebar/SidebarController.hxx>
+#include <sfx2/strings.hrc>
 
 #include <sfx2/sfxresid.hxx>
-#include <sfx2/sidebar/Sidebar.hrc>
 
 #include <vcl/gradient.hxx>
 #include <vcl/image.hxx>
@@ -62,7 +62,7 @@ TabBar::TabBar(vcl::Window* pParentWindow,
 
     mpMenuButton->SetModeImage(Theme::GetImage(Theme::Image_TabBarMenu));
     mpMenuButton->SetClickHdl(LINK(this, TabBar, OnToolboxClicked));
-    mpMenuButton->SetQuickHelpText(SFX2_RESSTR(SFX_STR_SIDEBAR_SETTINGS));
+    mpMenuButton->SetQuickHelpText(SfxResId(SFX_STR_SIDEBAR_SETTINGS));
     Layout();
 
 #ifdef DEBUG
@@ -87,7 +87,7 @@ void TabBar::dispose()
     vcl::Window::dispose();
 }
 
-void TabBar::Paint(vcl::RenderContext& rRenderContext, const Rectangle& rUpdateArea)
+void TabBar::Paint(vcl::RenderContext& rRenderContext, const tools::Rectangle& rUpdateArea)
 {
     Window::Paint(rRenderContext, rUpdateArea);
 
@@ -119,20 +119,20 @@ void TabBar::SetDecks(const ResourceManager::DeckContextDescriptorContainer& rDe
     for (ResourceManager::DeckContextDescriptorContainer::const_iterator
              iDeck(rDecks.begin()); iDeck != rDecks.end(); ++iDeck)
     {
-        const DeckDescriptor* pDescriptor = pParentSidebarController->GetResourceManager()->GetDeckDescriptor(iDeck->msId);
-        if (pDescriptor == nullptr)
+        std::shared_ptr<DeckDescriptor> xDescriptor = pParentSidebarController->GetResourceManager()->GetDeckDescriptor(iDeck->msId);
+        if (xDescriptor == nullptr)
         {
-            OSL_ASSERT(pDescriptor!=nullptr);
+            OSL_ASSERT(xDescriptor!=nullptr);
             continue;
         }
 
         Item& rItem (maItems[nIndex++]);
-        rItem.msDeckId = pDescriptor->msId;
+        rItem.msDeckId = xDescriptor->msId;
         rItem.mpButton.disposeAndClear();
-        rItem.mpButton = CreateTabItem(*pDescriptor);
+        rItem.mpButton = CreateTabItem(*xDescriptor);
         rItem.mpButton->SetClickHdl(LINK(&rItem, TabBar::Item, HandleClick));
         rItem.maDeckActivationFunctor = maDeckActivationFunctor;
-        rItem.mbIsHidden = ! pDescriptor->mbIsEnabled;
+        rItem.mbIsHidden = ! xDescriptor->mbIsEnabled;
         rItem.mbIsHiddenByDefault = rItem.mbIsHidden; // the default is the state while creating
 
         rItem.mpButton->Enable(iDeck->mbIsEnabled);
@@ -145,12 +145,6 @@ void TabBar::SetDecks(const ResourceManager::DeckContextDescriptorContainer& rDe
 void TabBar::UpdateButtonIcons()
 {
     Image aImage = Theme::GetImage(Theme::Image_TabBarMenu);
-    if ( mpMenuButton->GetDPIScaleFactor() > 1 )
-    {
-        BitmapEx b = aImage.GetBitmapEx();
-        b.Scale(mpMenuButton->GetDPIScaleFactor(), mpMenuButton->GetDPIScaleFactor(), BmpScaleFlag::Fast);
-        aImage = Image(b);
-    }
     mpMenuButton->SetModeImage(aImage);
 
     for(ItemContainer::const_iterator
@@ -158,18 +152,11 @@ void TabBar::UpdateButtonIcons()
         iItem!=iEnd;
         ++iItem)
     {
-        const DeckDescriptor* pDeckDescriptor = pParentSidebarController->GetResourceManager()->GetDeckDescriptor(iItem->msDeckId);
+        std::shared_ptr<DeckDescriptor> xDeckDescriptor = pParentSidebarController->GetResourceManager()->GetDeckDescriptor(iItem->msDeckId);
 
-        if (pDeckDescriptor != nullptr)
+        if (xDeckDescriptor)
         {
-            aImage = GetItemImage(*pDeckDescriptor);
-            if ( mpMenuButton->GetDPIScaleFactor() > 1 )
-            {
-                BitmapEx b = aImage.GetBitmapEx();
-                b.Scale(mpMenuButton->GetDPIScaleFactor(), mpMenuButton->GetDPIScaleFactor(), BmpScaleFlag::Fast);
-                aImage = Image(b);
-            }
-
+            aImage = GetItemImage(*xDeckDescriptor);
             iItem->mpButton->SetModeImage(aImage);
         }
     }
@@ -228,7 +215,7 @@ void TabBar::HighlightDeck (const OUString& rsDeckId)
 {
     for (ItemContainer::iterator iItem(maItems.begin()); iItem != maItems.end(); ++iItem)
     {
-        if (iItem->msDeckId.equals(rsDeckId))
+        if (iItem->msDeckId == rsDeckId)
             iItem->mpButton->Check();
         else
             iItem->mpButton->Check(false);
@@ -253,7 +240,7 @@ void TabBar::DataChanged (const DataChangedEvent& rDataChangedEvent)
     Window::DataChanged(rDataChangedEvent);
 }
 
-bool TabBar::Notify (NotifyEvent& rEvent)
+bool TabBar::EventNotify(NotifyEvent& rEvent)
 {
     if(rEvent.GetType() == MouseNotifyEvent::COMMAND)
     {
@@ -309,7 +296,7 @@ Image TabBar::GetItemImage(const DeckDescriptor& rDeckDescriptor) const
         mxFrame);
 }
 
-IMPL_LINK_NOARG_TYPED(TabBar::Item, HandleClick, Button*, void)
+IMPL_LINK_NOARG(TabBar::Item, HandleClick, Button*, void)
 {
     try
     {
@@ -323,34 +310,31 @@ const ::rtl::OUString TabBar::GetDeckIdForIndex (const sal_Int32 nIndex) const
 {
     if (nIndex<0 || static_cast<size_t>(nIndex)>=maItems.size())
         throw RuntimeException();
-    else
-        return maItems[nIndex].msDeckId;
+    return maItems[nIndex].msDeckId;
 }
 
 void TabBar::ToggleHideFlag (const sal_Int32 nIndex)
 {
     if (nIndex<0 || static_cast<size_t>(nIndex) >= maItems.size())
         throw RuntimeException();
-    else
+
+    maItems[nIndex].mbIsHidden = ! maItems[nIndex].mbIsHidden;
+
+    std::shared_ptr<DeckDescriptor> xDeckDescriptor = pParentSidebarController->GetResourceManager()->GetDeckDescriptor(maItems[nIndex].msDeckId);
+    if (xDeckDescriptor)
     {
-        maItems[nIndex].mbIsHidden = ! maItems[nIndex].mbIsHidden;
+        xDeckDescriptor->mbIsEnabled = ! maItems[nIndex].mbIsHidden;
 
-        DeckDescriptor* pDeckDescriptor = pParentSidebarController->GetResourceManager()->GetDeckDescriptor(maItems[nIndex].msDeckId);
-        if (pDeckDescriptor)
-        {
-            pDeckDescriptor->mbIsEnabled = ! maItems[nIndex].mbIsHidden;
+        Context aContext;
+        aContext.msApplication = pParentSidebarController->GetCurrentContext().msApplication;
+        // leave aContext.msContext on default 'any' ... this func is used only for decks
+        // and we don't have context-sensitive decks anyway
 
-            Context aContext;
-            aContext.msApplication = pParentSidebarController->GetCurrentContext().msApplication;
-            // leave aContext.msContext on default 'any' ... this func is used only for decks
-            // and we don't have context-sensitive decks anyway
-
-            pDeckDescriptor->maContextList.ToggleVisibilityForContext(
-                aContext, pDeckDescriptor->mbIsEnabled );
-        }
-
-        Layout();
+        xDeckDescriptor->maContextList.ToggleVisibilityForContext(
+            aContext, xDeckDescriptor->mbIsEnabled );
     }
+
+    Layout();
 }
 
 void TabBar::RestoreHideFlags()
@@ -363,9 +347,9 @@ void TabBar::RestoreHideFlags()
             iItem->mbIsHidden = iItem->mbIsHiddenByDefault;
             bNeedsLayout = true;
 
-            DeckDescriptor* pDeckDescriptor = pParentSidebarController->GetResourceManager()->GetDeckDescriptor(iItem->msDeckId);
-            if (pDeckDescriptor)
-                pDeckDescriptor->mbIsEnabled = ! iItem->mbIsHidden;
+            std::shared_ptr<DeckDescriptor> xDeckDescriptor = pParentSidebarController->GetResourceManager()->GetDeckDescriptor(iItem->msDeckId);
+            if (xDeckDescriptor)
+                xDeckDescriptor->mbIsEnabled = ! iItem->mbIsHidden;
 
         }
     }
@@ -386,7 +370,7 @@ void TabBar::UpdateFocusManager(FocusManager& rFocusManager)
     rFocusManager.SetButtons(aButtons);
 }
 
-IMPL_LINK_NOARG_TYPED(TabBar, OnToolboxClicked, Button*, void)
+IMPL_LINK_NOARG(TabBar, OnToolboxClicked, Button*, void)
 {
     if (!mpMenuButton)
         return;
@@ -395,13 +379,13 @@ IMPL_LINK_NOARG_TYPED(TabBar, OnToolboxClicked, Button*, void)
 
     for (ItemContainer::const_iterator iItem(maItems.begin()); iItem != maItems.end(); ++iItem)
     {
-        const DeckDescriptor* pDeckDescriptor = pParentSidebarController->GetResourceManager()->GetDeckDescriptor(iItem->msDeckId);
+        std::shared_ptr<DeckDescriptor> xDeckDescriptor = pParentSidebarController->GetResourceManager()->GetDeckDescriptor(iItem->msDeckId);
 
-        if (pDeckDescriptor != nullptr)
+        if (xDeckDescriptor)
         {
             DeckMenuData aData;
-            aData.msDisplayName = pDeckDescriptor->msTitle;
-            aData.msDeckId = pDeckDescriptor->msId;
+            aData.msDisplayName = xDeckDescriptor->msTitle;
+            aData.msDeckId = xDeckDescriptor->msId;
             aData.mbIsCurrentDeck = iItem->mpButton->IsChecked();
             aData.mbIsActive = !iItem->mbIsHidden;
             aData.mbIsEnabled = iItem->mpButton->IsEnabled();
@@ -411,7 +395,7 @@ IMPL_LINK_NOARG_TYPED(TabBar, OnToolboxClicked, Button*, void)
     }
 
     maPopupMenuProvider(
-        Rectangle(
+        tools::Rectangle(
             mpMenuButton->GetPosPixel(),
             mpMenuButton->GetSizePixel()),
         aMenuData);
