@@ -16,14 +16,13 @@
  *   except in compliance with the License. You may obtain a copy of
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
+
 #include <sfx2/sidebar/Theme.hxx>
 #include <sfx2/sidebar/Paint.hxx>
-#include <sfx2/sidebar/SidebarResource.hxx>
 #include <sfx2/sidebar/Tools.hxx>
 #include <sfx2/app.hxx>
 
 #include <tools/svborder.hxx>
-#include <tools/rc.hxx>
 #include <vcl/svapp.hxx>
 #include <vcl/settings.hxx>
 
@@ -129,7 +128,7 @@ void Theme::HandleDataChange()
     {
         // Do not modify mbIsHighContrastMode when it was manually set.
         GetCurrentTheme().mbIsHighContrastMode = Application::GetSettings().GetStyleSettings().GetHighContrastMode();
-        rTheme.maRawValues[Bool_IsHighContrastModeActive] = Any(GetCurrentTheme().mbIsHighContrastMode);
+        rTheme.maRawValues[Bool_IsHighContrastModeActive] <<= GetCurrentTheme().mbIsHighContrastMode;
     }
 
     GetCurrentTheme().UpdateTheme();
@@ -144,8 +143,6 @@ void Theme::InitializeTheme()
 
 void Theme::UpdateTheme()
 {
-    SidebarResource aLocalResource;
-
     try
     {
         const StyleSettings& rStyle (Application::GetSettings().GetStyleSettings());
@@ -205,7 +202,7 @@ void Theme::UpdateTheme()
         setPropertyValue(
             maPropertyIdToNameMap[Paint_PanelTitleBarBackground],
             Any(Tools::VclToAwtGradient(Gradient(
-                        GradientStyle_LINEAR,
+                        GradientStyle::Linear,
                         aSecondColor.GetRGBColor(),
                         aBaseBackgroundColor.GetRGBColor()
                         ))));
@@ -253,7 +250,6 @@ void Theme::UpdateTheme()
         setPropertyValue(
             maPropertyIdToNameMap[Color_TabItemBorder],
             Any(sal_Int32(rStyle.GetActiveBorderColor().GetRGBColor())));
-        //                    mbIsHighContrastMode ? 0x00ff00 : 0xbfbfbf)));
 
         setPropertyValue(
             maPropertyIdToNameMap[Paint_DropDownBackground],
@@ -275,12 +271,11 @@ void Theme::UpdateTheme()
         setPropertyValue(
             maPropertyIdToNameMap[Paint_TabItemBackgroundHighlight],
             Any(sal_Int32(rStyle.GetActiveTabColor().GetRGBColor())));
-        //                    mbIsHighContrastMode ? 0x000000 : 0x00ffffff)));
 
         setPropertyValue(
             maPropertyIdToNameMap[Paint_HorizontalBorder],
             Any(sal_Int32(aBorderColor.GetRGBColor())));
-        //                    mbIsHighContrastMode ? 0x00ff00 :  0xe4e4e4)));
+
         setPropertyValue(
             maPropertyIdToNameMap[Paint_VerticalBorder],
             Any(sal_Int32(aBorderColor.GetRGBColor())));
@@ -305,38 +300,7 @@ void Theme::UpdateTheme()
         setPropertyValue(
             maPropertyIdToNameMap[Image_CloseIndicator],
             Any(OUString("private:graphicrepository/cmd/lc_decrementlevel.png")));
-        setPropertyValue(
-            maPropertyIdToNameMap[Image_ToolBoxItemSeparator],
-            Any(
-                OUString("private:graphicrepository/sfx2/res/separator.png")));
 
-        // ToolBox
-
-        /*
-        // Separator style
-        setPropertyValue(
-            maPropertyIdToNameMap[Paint_ToolBoxBackground],
-            Any(sal_Int32(rStyle.GetMenuColor().GetRGBColor())));
-        setPropertyValue(
-            maPropertyIdToNameMap[Paint_ToolBoxBorderTopLeft],
-            Any());
-        setPropertyValue(
-            maPropertyIdToNameMap[Paint_ToolBoxBorderCenterCorners],
-            Any());
-        setPropertyValue(
-            maPropertyIdToNameMap[Paint_ToolBoxBorderBottomRight],
-            Any());
-        setPropertyValue(
-            maPropertyIdToNameMap[Rect_ToolBoxPadding],
-            Any(awt::Rectangle(2,2,2,2)));
-        setPropertyValue(
-            maPropertyIdToNameMap[Rect_ToolBoxBorder],
-            Any(awt::Rectangle(0,0,0,0)));
-        setPropertyValue(
-            maPropertyIdToNameMap[Bool_UseToolBoxItemSeparator],
-            Any(true));
-
-        */
         // Gradient style
         Color aGradientStop2 (aBaseBackgroundColor);
         aGradientStop2.IncreaseLuminance(17);
@@ -345,7 +309,7 @@ void Theme::UpdateTheme()
         setPropertyValue(
             maPropertyIdToNameMap[Paint_ToolBoxBackground],
             Any(Tools::VclToAwtGradient(Gradient(
-                        GradientStyle_LINEAR,
+                        GradientStyle::Linear,
                         aBaseBackgroundColor.GetRGBColor(),
                         aGradientStop2.GetRGBColor()
                         ))));
@@ -370,16 +334,10 @@ void Theme::UpdateTheme()
         setPropertyValue(
             maPropertyIdToNameMap[Rect_ToolBoxBorder],
             Any(awt::Rectangle(1,1,1,1)));
-        setPropertyValue(
-            maPropertyIdToNameMap[Bool_UseToolBoxItemSeparator],
-            Any(false));
     }
     catch(beans::UnknownPropertyException& rException)
     {
-        OSL_TRACE("unknown property: %s",
-            OUStringToOString(
-                rException.Message,
-                RTL_TEXTENCODING_ASCII_US).getStr());
+        SAL_WARN("sfx", "unknown property: " << rException);
         OSL_ASSERT(false);
     }
 }
@@ -420,7 +378,6 @@ Reference<beans::XPropertySet> Theme::GetPropertySet()
 }
 
 Reference<beans::XPropertySetInfo> SAL_CALL Theme::getPropertySetInfo()
-    throw(css::uno::RuntimeException, std::exception)
 {
     return Reference<beans::XPropertySetInfo>(this);
 }
@@ -428,9 +385,6 @@ Reference<beans::XPropertySetInfo> SAL_CALL Theme::getPropertySetInfo()
 void SAL_CALL Theme::setPropertyValue (
     const ::rtl::OUString& rsPropertyName,
     const css::uno::Any& rValue)
-    throw (css::beans::UnknownPropertyException,
-           css::uno::RuntimeException,
-           std::exception)
 {
     PropertyNameToIdMap::const_iterator iId (maPropertyNameToIdMap.find(rsPropertyName));
     if (iId == maPropertyNameToIdMap.end())
@@ -454,12 +408,12 @@ void SAL_CALL Theme::setPropertyValue (
     const beans::PropertyChangeEvent aEvent(
         static_cast<XWeak*>(this),
         rsPropertyName,
-        sal_False,
+        false,
         eItem,
         aOldValue,
         rValue);
 
-    if (DoVetoableListenersVeto(GetVetoableListeners(__AnyItem, false), aEvent))
+    if (DoVetoableListenersVeto(GetVetoableListeners(AnyItem_, false), aEvent))
         return;
     if (DoVetoableListenersVeto(GetVetoableListeners(eItem, false), aEvent))
         return;
@@ -467,15 +421,12 @@ void SAL_CALL Theme::setPropertyValue (
     maRawValues[eItem] = rValue;
     ProcessNewValue(rValue, eItem, eType);
 
-    BroadcastPropertyChange(GetChangeListeners(__AnyItem, false), aEvent);
+    BroadcastPropertyChange(GetChangeListeners(AnyItem_, false), aEvent);
     BroadcastPropertyChange(GetChangeListeners(eItem, false), aEvent);
 }
 
 Any SAL_CALL Theme::getPropertyValue (
     const ::rtl::OUString& rsPropertyName)
-    throw(css::beans::UnknownPropertyException,
-        css::lang::WrappedTargetException,
-        css::uno::RuntimeException, std::exception)
 {
     PropertyNameToIdMap::const_iterator iId (maPropertyNameToIdMap.find(rsPropertyName));
     if (iId == maPropertyNameToIdMap.end())
@@ -493,11 +444,8 @@ Any SAL_CALL Theme::getPropertyValue (
 void SAL_CALL Theme::addPropertyChangeListener(
     const ::rtl::OUString& rsPropertyName,
     const css::uno::Reference<css::beans::XPropertyChangeListener>& rxListener)
-    throw(css::beans::UnknownPropertyException,
-        css::lang::WrappedTargetException,
-        css::uno::RuntimeException, std::exception)
 {
-    ThemeItem eItem (__AnyItem);
+    ThemeItem eItem (AnyItem_);
     if (rsPropertyName.getLength() > 0)
     {
         PropertyNameToIdMap::const_iterator iId (maPropertyNameToIdMap.find(rsPropertyName));
@@ -518,11 +466,8 @@ void SAL_CALL Theme::addPropertyChangeListener(
 void SAL_CALL Theme::removePropertyChangeListener(
     const ::rtl::OUString& rsPropertyName,
     const css::uno::Reference<css::beans::XPropertyChangeListener>& rxListener)
-    throw(css::beans::UnknownPropertyException,
-        css::lang::WrappedTargetException,
-        css::uno::RuntimeException, std::exception)
 {
-    ThemeItem eItem (__AnyItem);
+    ThemeItem eItem (AnyItem_);
     if (rsPropertyName.getLength() > 0)
     {
         PropertyNameToIdMap::const_iterator iId (maPropertyNameToIdMap.find(rsPropertyName));
@@ -553,11 +498,8 @@ void SAL_CALL Theme::removePropertyChangeListener(
 void SAL_CALL Theme::addVetoableChangeListener(
     const ::rtl::OUString& rsPropertyName,
     const css::uno::Reference<css::beans::XVetoableChangeListener>& rxListener)
-    throw(css::beans::UnknownPropertyException,
-        css::lang::WrappedTargetException,
-        css::uno::RuntimeException, std::exception)
 {
-    ThemeItem eItem (__AnyItem);
+    ThemeItem eItem (AnyItem_);
     if (rsPropertyName.getLength() > 0)
     {
         PropertyNameToIdMap::const_iterator iId (maPropertyNameToIdMap.find(rsPropertyName));
@@ -578,11 +520,8 @@ void SAL_CALL Theme::addVetoableChangeListener(
 void SAL_CALL Theme::removeVetoableChangeListener(
     const ::rtl::OUString& rsPropertyName,
     const css::uno::Reference<css::beans::XVetoableChangeListener>& rxListener)
-    throw(css::beans::UnknownPropertyException,
-        css::lang::WrappedTargetException,
-        css::uno::RuntimeException, std::exception)
 {
-    ThemeItem eItem (__AnyItem);
+    ThemeItem eItem (AnyItem_);
     if (rsPropertyName.getLength() > 0)
     {
         PropertyNameToIdMap::const_iterator iId (maPropertyNameToIdMap.find(rsPropertyName));
@@ -610,11 +549,11 @@ void SAL_CALL Theme::removeVetoableChangeListener(
 }
 
 css::uno::Sequence<css::beans::Property> SAL_CALL Theme::getProperties()
-    throw(css::uno::RuntimeException, std::exception)
 {
     ::std::vector<beans::Property> aProperties;
 
-    for (sal_Int32 nItem(__Begin),nEnd(__End); nItem!=nEnd; ++nItem)
+    sal_Int32 const nEnd(End_);
+    for (sal_Int32 nItem(Begin_); nItem!=nEnd; ++nItem)
     {
         const ThemeItem eItem (static_cast<ThemeItem>(nItem));
         const PropertyType eType (GetPropertyType(eItem));
@@ -630,13 +569,11 @@ css::uno::Sequence<css::beans::Property> SAL_CALL Theme::getProperties()
     }
 
     return css::uno::Sequence<css::beans::Property>(
-        &aProperties.front(),
+        aProperties.data(),
         aProperties.size());
 }
 
 beans::Property SAL_CALL Theme::getPropertyByName (const ::rtl::OUString& rsPropertyName)
-    throw(css::beans::UnknownPropertyException,
-        css::uno::RuntimeException, std::exception)
 {
     PropertyNameToIdMap::const_iterator iId (maPropertyNameToIdMap.find(rsPropertyName));
     if (iId == maPropertyNameToIdMap.end())
@@ -656,89 +593,179 @@ beans::Property SAL_CALL Theme::getPropertyByName (const ::rtl::OUString& rsProp
 }
 
 sal_Bool SAL_CALL Theme::hasPropertyByName (const ::rtl::OUString& rsPropertyName)
-    throw(css::uno::RuntimeException, std::exception)
 {
     PropertyNameToIdMap::const_iterator iId (maPropertyNameToIdMap.find(rsPropertyName));
     if (iId == maPropertyNameToIdMap.end())
-        return sal_False;
+        return false;
 
     const PropertyType eType (GetPropertyType(iId->second));
     if (eType == PT_Invalid)
-        return sal_False;
+        return false;
 
-    return sal_True;
+    return true;
 }
 
 void Theme::SetupPropertyMaps()
 {
-    maPropertyIdToNameMap.resize(__Post_Rect);
-    maImages.resize(__Image_Color - __Pre_Image - 1);
-    maColors.resize(__Color_Paint - __Image_Color - 1);
-    maPaints.resize(__Paint_Int - __Color_Paint - 1);
-    maIntegers.resize(__Int_Bool - __Paint_Int - 1);
-    maBooleans.resize(__Bool_Rect - __Int_Bool - 1);
-    maRectangles.resize(__Post_Rect - __Bool_Rect - 1);
+    maPropertyIdToNameMap.resize(Post_Rect_);
+    maImages.resize(Image_Color_ - Pre_Image_ - 1);
+    maColors.resize(Color_Paint_ - Image_Color_ - 1);
+    maPaints.resize(Paint_Int_ - Color_Paint_ - 1);
+    maIntegers.resize(Int_Bool_ - Paint_Int_ - 1);
+    maBooleans.resize(Bool_Rect_ - Int_Bool_ - 1);
+    maRectangles.resize(Post_Rect_ - Bool_Rect_ - 1);
 
-    #define AddEntry(e) maPropertyNameToIdMap[OUString(#e)]=e; maPropertyIdToNameMap[e]=#e
+    maPropertyNameToIdMap["Image_Grip"]=Image_Grip;
+    maPropertyIdToNameMap[Image_Grip]="Image_Grip";
 
-    AddEntry(Image_Grip);
-    AddEntry(Image_Expand);
-    AddEntry(Image_Collapse);
-    AddEntry(Image_TabBarMenu);
-    AddEntry(Image_PanelMenu);
-    AddEntry(Image_ToolBoxItemSeparator);
-    AddEntry(Image_Closer);
-    AddEntry(Image_CloseIndicator);
+    maPropertyNameToIdMap["Image_Expand"]=Image_Expand;
+    maPropertyIdToNameMap[Image_Expand]="Image_Expand";
 
-    AddEntry(Color_DeckTitleFont);
-    AddEntry(Color_PanelTitleFont);
-    AddEntry(Color_TabMenuSeparator);
-    AddEntry(Color_TabItemBorder);
-    AddEntry(Color_DropDownBorder);
-    AddEntry(Color_Highlight);
-    AddEntry(Color_HighlightText);
+    maPropertyNameToIdMap["Image_Collapse"]=Image_Collapse;
+    maPropertyIdToNameMap[Image_Collapse]="Image_Collapse";
 
-    AddEntry(Paint_DeckBackground);
-    AddEntry(Paint_DeckTitleBarBackground);
-    AddEntry(Paint_PanelBackground);
-    AddEntry(Paint_PanelTitleBarBackground);
-    AddEntry(Paint_TabBarBackground);
-    AddEntry(Paint_TabItemBackgroundNormal);
-    AddEntry(Paint_TabItemBackgroundHighlight);
-    AddEntry(Paint_HorizontalBorder);
-    AddEntry(Paint_VerticalBorder);
-    AddEntry(Paint_ToolBoxBackground);
-    AddEntry(Paint_ToolBoxBorderTopLeft);
-    AddEntry(Paint_ToolBoxBorderCenterCorners);
-    AddEntry(Paint_ToolBoxBorderBottomRight);
-    AddEntry(Paint_DropDownBackground);
+    maPropertyNameToIdMap["Image_TabBarMenu"]=Image_TabBarMenu;
+    maPropertyIdToNameMap[Image_TabBarMenu]="Image_TabBarMenu";
 
-    AddEntry(Int_DeckTitleBarHeight);
-    AddEntry(Int_DeckBorderSize);
-    AddEntry(Int_DeckSeparatorHeight);
-    AddEntry(Int_PanelTitleBarHeight);
-    AddEntry(Int_TabMenuPadding);
-    AddEntry(Int_TabMenuSeparatorPadding);
-    AddEntry(Int_TabItemWidth);
-    AddEntry(Int_TabItemHeight);
-    AddEntry(Int_DeckLeftPadding);
-    AddEntry(Int_DeckTopPadding);
-    AddEntry(Int_DeckRightPadding);
-    AddEntry(Int_DeckBottomPadding);
-    AddEntry(Int_TabBarLeftPadding);
-    AddEntry(Int_TabBarTopPadding);
-    AddEntry(Int_TabBarRightPadding);
-    AddEntry(Int_TabBarBottomPadding);
-    AddEntry(Int_ButtonCornerRadius);
+    maPropertyNameToIdMap["Image_PanelMenu"]=Image_PanelMenu;
+    maPropertyIdToNameMap[Image_PanelMenu]="Image_PanelMenu";
 
-    AddEntry(Bool_UseSystemColors);
-    AddEntry(Bool_UseToolBoxItemSeparator);
-    AddEntry(Bool_IsHighContrastModeActive);
+    maPropertyNameToIdMap["Image_Closer"]=Image_Closer;
+    maPropertyIdToNameMap[Image_Closer]="Image_Closer";
 
-    AddEntry(Rect_ToolBoxPadding);
-    AddEntry(Rect_ToolBoxBorder);
+    maPropertyNameToIdMap["Image_CloseIndicator"]=Image_CloseIndicator;
+    maPropertyIdToNameMap[Image_CloseIndicator]="Image_CloseIndicator";
 
-    #undef AddEntry
+
+    maPropertyNameToIdMap["Color_DeckTitleFont"]=Color_DeckTitleFont;
+    maPropertyIdToNameMap[Color_DeckTitleFont]="Color_DeckTitleFont";
+
+    maPropertyNameToIdMap["Color_PanelTitleFont"]=Color_PanelTitleFont;
+    maPropertyIdToNameMap[Color_PanelTitleFont]="Color_PanelTitleFont";
+
+    maPropertyNameToIdMap["Color_TabMenuSeparator"]=Color_TabMenuSeparator;
+    maPropertyIdToNameMap[Color_TabMenuSeparator]="Color_TabMenuSeparator";
+
+    maPropertyNameToIdMap["Color_TabItemBorder"]=Color_TabItemBorder;
+    maPropertyIdToNameMap[Color_TabItemBorder]="Color_TabItemBorder";
+
+    maPropertyNameToIdMap["Color_DropDownBorder"]=Color_DropDownBorder;
+    maPropertyIdToNameMap[Color_DropDownBorder]="Color_DropDownBorder";
+
+    maPropertyNameToIdMap["Color_Highlight"]=Color_Highlight;
+    maPropertyIdToNameMap[Color_Highlight]="Color_Highlight";
+
+    maPropertyNameToIdMap["Color_HighlightText"]=Color_HighlightText;
+    maPropertyIdToNameMap[Color_HighlightText]="Color_HighlightText";
+
+
+    maPropertyNameToIdMap["Paint_DeckBackground"]=Paint_DeckBackground;
+    maPropertyIdToNameMap[Paint_DeckBackground]="Paint_DeckBackground";
+
+    maPropertyNameToIdMap["Paint_DeckTitleBarBackground"]=Paint_DeckTitleBarBackground;
+    maPropertyIdToNameMap[Paint_DeckTitleBarBackground]="Paint_DeckTitleBarBackground";
+
+    maPropertyNameToIdMap["Paint_PanelBackground"]=Paint_PanelBackground;
+    maPropertyIdToNameMap[Paint_PanelBackground]="Paint_PanelBackground";
+
+    maPropertyNameToIdMap["Paint_PanelTitleBarBackground"]=Paint_PanelTitleBarBackground;
+    maPropertyIdToNameMap[Paint_PanelTitleBarBackground]="Paint_PanelTitleBarBackground";
+
+    maPropertyNameToIdMap["Paint_TabBarBackground"]=Paint_TabBarBackground;
+    maPropertyIdToNameMap[Paint_TabBarBackground]="Paint_TabBarBackground";
+
+    maPropertyNameToIdMap["Paint_TabItemBackgroundNormal"]=Paint_TabItemBackgroundNormal;
+    maPropertyIdToNameMap[Paint_TabItemBackgroundNormal]="Paint_TabItemBackgroundNormal";
+
+    maPropertyNameToIdMap["Paint_TabItemBackgroundHighlight"]=Paint_TabItemBackgroundHighlight;
+    maPropertyIdToNameMap[Paint_TabItemBackgroundHighlight]="Paint_TabItemBackgroundHighlight";
+
+    maPropertyNameToIdMap["Paint_HorizontalBorder"]=Paint_HorizontalBorder;
+    maPropertyIdToNameMap[Paint_HorizontalBorder]="Paint_HorizontalBorder";
+
+    maPropertyNameToIdMap["Paint_VerticalBorder"]=Paint_VerticalBorder;
+    maPropertyIdToNameMap[Paint_VerticalBorder]="Paint_VerticalBorder";
+
+    maPropertyNameToIdMap["Paint_ToolBoxBackground"]=Paint_ToolBoxBackground;
+    maPropertyIdToNameMap[Paint_ToolBoxBackground]="Paint_ToolBoxBackground";
+
+    maPropertyNameToIdMap["Paint_ToolBoxBorderTopLeft"]=Paint_ToolBoxBorderTopLeft;
+    maPropertyIdToNameMap[Paint_ToolBoxBorderTopLeft]="Paint_ToolBoxBorderTopLeft";
+
+    maPropertyNameToIdMap["Paint_ToolBoxBorderCenterCorners"]=Paint_ToolBoxBorderCenterCorners;
+    maPropertyIdToNameMap[Paint_ToolBoxBorderCenterCorners]="Paint_ToolBoxBorderCenterCorners";
+
+    maPropertyNameToIdMap["Paint_ToolBoxBorderBottomRight"]=Paint_ToolBoxBorderBottomRight;
+    maPropertyIdToNameMap[Paint_ToolBoxBorderBottomRight]="Paint_ToolBoxBorderBottomRight";
+
+    maPropertyNameToIdMap["Paint_DropDownBackground"]=Paint_DropDownBackground;
+    maPropertyIdToNameMap[Paint_DropDownBackground]="Paint_DropDownBackground";
+
+
+    maPropertyNameToIdMap["Int_DeckTitleBarHeight"]=Int_DeckTitleBarHeight;
+    maPropertyIdToNameMap[Int_DeckTitleBarHeight]="Int_DeckTitleBarHeight";
+
+    maPropertyNameToIdMap["Int_DeckBorderSize"]=Int_DeckBorderSize;
+    maPropertyIdToNameMap[Int_DeckBorderSize]="Int_DeckBorderSize";
+
+    maPropertyNameToIdMap["Int_DeckSeparatorHeight"]=Int_DeckSeparatorHeight;
+    maPropertyIdToNameMap[Int_DeckSeparatorHeight]="Int_DeckSeparatorHeight";
+
+    maPropertyNameToIdMap["Int_PanelTitleBarHeight"]=Int_PanelTitleBarHeight;
+    maPropertyIdToNameMap[Int_PanelTitleBarHeight]="Int_PanelTitleBarHeight";
+
+    maPropertyNameToIdMap["Int_TabMenuPadding"]=Int_TabMenuPadding;
+    maPropertyIdToNameMap[Int_TabMenuPadding]="Int_TabMenuPadding";
+
+    maPropertyNameToIdMap["Int_TabMenuSeparatorPadding"]=Int_TabMenuSeparatorPadding;
+    maPropertyIdToNameMap[Int_TabMenuSeparatorPadding]="Int_TabMenuSeparatorPadding";
+
+    maPropertyNameToIdMap["Int_TabItemWidth"]=Int_TabItemWidth;
+    maPropertyIdToNameMap[Int_TabItemWidth]="Int_TabItemWidth";
+
+    maPropertyNameToIdMap["Int_TabItemHeight"]=Int_TabItemHeight;
+    maPropertyIdToNameMap[Int_TabItemHeight]="Int_TabItemHeight";
+
+    maPropertyNameToIdMap["Int_DeckLeftPadding"]=Int_DeckLeftPadding;
+    maPropertyIdToNameMap[Int_DeckLeftPadding]="Int_DeckLeftPadding";
+
+    maPropertyNameToIdMap["Int_DeckTopPadding"]=Int_DeckTopPadding;
+    maPropertyIdToNameMap[Int_DeckTopPadding]="Int_DeckTopPadding";
+
+    maPropertyNameToIdMap["Int_DeckRightPadding"]=Int_DeckRightPadding;
+    maPropertyIdToNameMap[Int_DeckRightPadding]="Int_DeckRightPadding";
+
+    maPropertyNameToIdMap["Int_DeckBottomPadding"]=Int_DeckBottomPadding;
+    maPropertyIdToNameMap[Int_DeckBottomPadding]="Int_DeckBottomPadding";
+
+    maPropertyNameToIdMap["Int_TabBarLeftPadding"]=Int_TabBarLeftPadding;
+    maPropertyIdToNameMap[Int_TabBarLeftPadding]="Int_TabBarLeftPadding";
+
+    maPropertyNameToIdMap["Int_TabBarTopPadding"]=Int_TabBarTopPadding;
+    maPropertyIdToNameMap[Int_TabBarTopPadding]="Int_TabBarTopPadding";
+
+    maPropertyNameToIdMap["Int_TabBarRightPadding"]=Int_TabBarRightPadding;
+    maPropertyIdToNameMap[Int_TabBarRightPadding]="Int_TabBarRightPadding";
+
+    maPropertyNameToIdMap["Int_TabBarBottomPadding"]=Int_TabBarBottomPadding;
+    maPropertyIdToNameMap[Int_TabBarBottomPadding]="Int_TabBarBottomPadding";
+
+    maPropertyNameToIdMap["Int_ButtonCornerRadius"]=Int_ButtonCornerRadius;
+    maPropertyIdToNameMap[Int_ButtonCornerRadius]="Int_ButtonCornerRadius";
+
+
+    maPropertyNameToIdMap["Bool_UseSystemColors"]=Bool_UseSystemColors;
+    maPropertyIdToNameMap[Bool_UseSystemColors]="Bool_UseSystemColors";
+
+    maPropertyNameToIdMap["Bool_IsHighContrastModeActive"]=Bool_IsHighContrastModeActive;
+    maPropertyIdToNameMap[Bool_IsHighContrastModeActive]="Bool_IsHighContrastModeActive";
+
+
+    maPropertyNameToIdMap["Rect_ToolBoxPadding"]=Rect_ToolBoxPadding;
+    maPropertyIdToNameMap[Rect_ToolBoxPadding]="Rect_ToolBoxPadding";
+
+    maPropertyNameToIdMap["Rect_ToolBoxBorder"]=Rect_ToolBoxBorder;
+    maPropertyIdToNameMap[Rect_ToolBoxBorder]="Rect_ToolBoxBorder";
 
     maRawValues.resize(maPropertyIdToNameMap.size());
 }
@@ -752,7 +779,6 @@ Theme::PropertyType Theme::GetPropertyType (const ThemeItem eItem)
         case Image_Collapse:
         case Image_TabBarMenu:
         case Image_PanelMenu:
-        case Image_ToolBoxItemSeparator:
         case Image_Closer:
         case Image_CloseIndicator:
             return PT_Image;
@@ -802,7 +828,6 @@ Theme::PropertyType Theme::GetPropertyType (const ThemeItem eItem)
             return PT_Integer;
 
         case Bool_UseSystemColors:
-        case Bool_UseToolBoxItemSeparator:
         case Bool_IsHighContrastModeActive:
             return PT_Boolean;
 
@@ -848,17 +873,17 @@ sal_Int32 Theme::GetIndex (const ThemeItem eItem, const PropertyType eType)
     switch(eType)
     {
         case PT_Image:
-            return eItem - __Pre_Image-1;
+            return eItem - Pre_Image_-1;
         case PT_Color:
-            return eItem - __Image_Color-1;
+            return eItem - Image_Color_-1;
         case PT_Paint:
-            return eItem - __Color_Paint-1;
+            return eItem - Color_Paint_-1;
         case PT_Integer:
-            return eItem - __Paint_Int-1;
+            return eItem - Paint_Int_-1;
         case PT_Boolean:
-            return eItem - __Int_Bool-1;
+            return eItem - Int_Bool_-1;
         case PT_Rectangle:
-            return eItem - __Bool_Rect-1;
+            return eItem - Bool_Rect_-1;
 
         default:
             OSL_ASSERT(false);
@@ -1017,7 +1042,7 @@ void Theme::ProcessNewValue (
             awt::Rectangle aBox;
             if (rValue >>= aBox)
             {
-                maRectangles[nIndex] = Rectangle(
+                maRectangles[nIndex] = tools::Rectangle(
                     aBox.X,
                     aBox.Y,
                     aBox.Width,
