@@ -28,7 +28,7 @@
 #include <unotools/ucbstreamhelper.hxx>
 #include <unotools/streamwrap.hxx>
 #include <cppuhelper/implbase.hxx>
-#include <sfx2/sfx.hrc>
+#include <sfx2/strings.hrc>
 #include <sfx2/sfxresid.hxx>
 #include <sfx2/viewfrm.hxx>
 #include <tools/datetime.hxx>
@@ -37,6 +37,8 @@
 #include <svl/fstathelper.hxx>
 #include <config_folders.h>
 
+#include <officecfg/Office/Common.hxx>
+
 using namespace com::sun::star;
 
 namespace
@@ -90,6 +92,9 @@ class SfxClassificationCategory
 public:
     /// PROP_BACNAME() is stored separately for easier lookup.
     OUString m_aName;
+    OUString m_aAbbreviatedName; //< An abbreviation to display instead of m_aName.
+    OUString m_aIdentifier; //< The Identifier of this entry.
+    size_t m_nConfidentiality; //< 0 is the lowest (least-sensitive).
     std::map<OUString, OUString> m_aLabels;
 };
 
@@ -98,6 +103,9 @@ class SfxClassificationParser : public cppu::WeakImplHelper<xml::sax::XDocumentH
 {
 public:
     std::vector<SfxClassificationCategory> m_aCategories;
+    std::vector<OUString> m_aMarkings;
+    std::vector<OUString> m_aIPParts;
+    std::vector<OUString> m_aIPPartNumbers;
 
     OUString m_aPolicyAuthorityName;
     bool m_bInPolicyAuthorityName = false;
@@ -123,15 +131,15 @@ public:
 
     void SAL_CALL endDocument() override;
 
-    void SAL_CALL startElement(const OUString& aName, const uno::Reference<xml::sax::XAttributeList>& xAttribs) override;
+    void SAL_CALL startElement(const OUString& rName, const uno::Reference<xml::sax::XAttributeList>& xAttribs) override;
 
-    void SAL_CALL endElement(const OUString& aName) override;
+    void SAL_CALL endElement(const OUString& rName) override;
 
-    void SAL_CALL characters(const OUString& aChars) override;
+    void SAL_CALL characters(const OUString& rChars) override;
 
-    void SAL_CALL ignorableWhitespace(const OUString& aWhitespaces) override;
+    void SAL_CALL ignorableWhitespace(const OUString& rWhitespaces) override;
 
-    void SAL_CALL processingInstruction(const OUString& aTarget, const OUString& aData) override;
+    void SAL_CALL processingInstruction(const OUString& rTarget, const OUString& rData) override;
 
     void SAL_CALL setDocumentLocator(const uno::Reference<xml::sax::XLocator>& xLocator) override;
 };
@@ -165,7 +173,7 @@ void SAL_CALL SfxClassificationParser::startElement(const OUString& rName, const
     }
     else if (rName == "baf:BusinessAuthorizationCategory")
     {
-        OUString aName = xAttribs->getValueByName("Name");
+        const OUString aName = xAttribs->getValueByName("Name");
         if (!m_pCategory && !aName.isEmpty())
         {
             OUString aIdentifier = xAttribs->getValueByName("Identifier");
@@ -173,7 +181,13 @@ void SAL_CALL SfxClassificationParser::startElement(const OUString& rName, const
             // Create a new category and initialize it with the data that's true for all categories.
             m_aCategories.emplace_back(SfxClassificationCategory());
             SfxClassificationCategory& rCategory = m_aCategories.back();
+
             rCategory.m_aName = aName;
+            // Set the abbreviated name, if any, otherwise fallback on the full name.
+            const OUString aAbbreviatedName = xAttribs->getValueByName("loextAbbreviatedName");
+            rCategory.m_aAbbreviatedName = !aAbbreviatedName.isEmpty() ? aAbbreviatedName : aName;
+            rCategory.m_aIdentifier = aIdentifier;
+
             rCategory.m_aLabels["PolicyAuthority:Name"] = m_aPolicyAuthorityName;
             rCategory.m_aLabels["Policy:Name"] = m_aPolicyName;
             rCategory.m_aLabels["BusinessAuthorization:Identifier"] = m_aProgramID;
@@ -210,6 +224,21 @@ void SAL_CALL SfxClassificationParser::startElement(const OUString& rName, const
             m_pCategory = &rCategory;
         }
     }
+    else if (rName == "loext:Marking")
+    {
+        OUString aName = xAttribs->getValueByName("Name");
+        m_aMarkings.push_back(aName);
+    }
+    else if (rName == "loext:IntellectualPropertyPart")
+    {
+        OUString aName = xAttribs->getValueByName("Name");
+        m_aIPParts.push_back(aName);
+    }
+    else if (rName == "loext:IntellectualPropertyPartNumber")
+    {
+        OUString aName = xAttribs->getValueByName("Name");
+        m_aIPPartNumbers.push_back(aName);
+    }
     else if (rName == "baf:Scale")
     {
         m_aScale.clear();
@@ -255,6 +284,7 @@ void SAL_CALL SfxClassificationParser::endElement(const OUString& rName)
         {
             std::map<OUString, OUString>& rLabels = m_pCategory->m_aLabels;
             rLabels[PROP_IMPACTLEVEL()] = m_aConfidentalityValue;
+            m_pCategory->m_nConfidentiality = m_aConfidentalityValue.toInt32(); // 0-based class sensitivity; 0 is lowest.
             // Set the two other type of levels as well, if they're not set
             // yet: they're optional in BAF, but not in BAILS.
             if (rLabels.find("Impact:Level:Integrity") == rLabels.end())
@@ -319,9 +349,15 @@ public:
     std::map<SfxClassificationPolicyType, SfxClassificationCategory> m_aCategory;
     /// Possible categories of a policy to choose from.
     std::vector<SfxClassificationCategory> m_aCategories;
+    std::vector<OUString> m_aMarkings;
+    std::vector<OUString> m_aIPParts;
+    std::vector<OUString> m_aIPPartNumbers;
+
     uno::Reference<document::XDocumentProperties> m_xDocumentProperties;
 
-    explicit Impl(uno::Reference<document::XDocumentProperties> xDocumentProperties);
+    bool m_bUseLocalized;
+
+    explicit Impl(uno::Reference<document::XDocumentProperties> xDocumentProperties, bool bUseLocalized);
     void parsePolicy();
     /// Synchronize m_aLabels back to the document properties.
     void pushToDocumentProperties();
@@ -329,9 +365,11 @@ public:
     void setStartValidity(SfxClassificationPolicyType eType);
 };
 
-SfxClassificationHelper::Impl::Impl(uno::Reference<document::XDocumentProperties> xDocumentProperties)
+SfxClassificationHelper::Impl::Impl(uno::Reference<document::XDocumentProperties> xDocumentProperties, bool bUseLocalized)
     : m_xDocumentProperties(std::move(xDocumentProperties))
+    , m_bUseLocalized(bUseLocalized)
 {
+    parsePolicy();
 }
 
 void SfxClassificationHelper::Impl::parsePolicy()
@@ -342,7 +380,7 @@ void SfxClassificationHelper::Impl::parsePolicy()
 
     // See if there is a localized variant next to the configured XML.
     OUString aExtension(".xml");
-    if (aPath.endsWith(aExtension))
+    if (aPath.endsWith(aExtension) && m_bUseLocalized)
     {
         OUString aBase = aPath.copy(0, aPath.getLength() - aExtension.getLength());
         const LanguageTag& rLanguageTag = Application::GetSettings().GetLanguageTag();
@@ -367,12 +405,15 @@ void SfxClassificationHelper::Impl::parsePolicy()
     }
     catch (const xml::sax::SAXParseException& rException)
     {
-        SAL_WARN("sfx.view", "parsePolicy() failed: " << rException.Message);
+        SAL_WARN("sfx.view", "parsePolicy() failed: " << rException);
     }
     m_aCategories = xClassificationParser->m_aCategories;
+    m_aMarkings = xClassificationParser->m_aMarkings;
+    m_aIPParts = xClassificationParser->m_aIPParts;
+    m_aIPPartNumbers = xClassificationParser->m_aIPPartNumbers;
 }
 
-bool lcl_containsProperty(const uno::Sequence<beans::Property>& rProperties, const OUString& rName)
+static bool lcl_containsProperty(const uno::Sequence<beans::Property>& rProperties, const OUString& rName)
 {
     return std::find_if(rProperties.begin(), rProperties.end(), [&](const beans::Property& rProperty)
     {
@@ -422,7 +463,7 @@ void SfxClassificationHelper::Impl::pushToDocumentProperties()
             }
             catch (const uno::Exception& rException)
             {
-                SAL_WARN("sfx.view", "pushDocumentProperties() failed for property " << rLabel.first << ": " << rException.Message);
+                SAL_WARN("sfx.view", "pushDocumentProperties() failed for property " << rLabel.first << ": " << rException);
             }
         }
     }
@@ -503,9 +544,12 @@ bool SfxClassificationHelper::ShowPasteInfo(SfxClassificationCheckPasteResult eR
     return true;
 }
 
-SfxClassificationHelper::SfxClassificationHelper(const uno::Reference<document::XDocumentProperties>& xDocumentProperties)
-    : m_pImpl(o3tl::make_unique<Impl>(xDocumentProperties))
+SfxClassificationHelper::SfxClassificationHelper(const uno::Reference<document::XDocumentProperties>& xDocumentProperties, bool bUseLocalizedPolicy)
+    : m_pImpl(o3tl::make_unique<Impl>(xDocumentProperties, bUseLocalizedPolicy))
 {
+    if (!xDocumentProperties.is())
+        return;
+
     uno::Reference<beans::XPropertyContainer> xPropertyContainer = xDocumentProperties->getUserDefinedProperties();
     if (!xPropertyContainer.is())
         return;
@@ -527,6 +571,7 @@ SfxClassificationHelper::SfxClassificationHelper(const uno::Reference<document::
                 // It's a prefix we did not recognize, ignore.
                 continue;
 
+            //TODO: Support abbreviated names(?)
             if (rProperty.Name == (aPrefix + PROP_BACNAME()))
                 m_pImpl->m_aCategory[eType].m_aName = aValue;
             else
@@ -537,11 +582,67 @@ SfxClassificationHelper::SfxClassificationHelper(const uno::Reference<document::
 
 SfxClassificationHelper::~SfxClassificationHelper() = default;
 
+const std::vector<OUString> SfxClassificationHelper::GetMarkings()
+{
+    return m_pImpl->m_aMarkings;
+}
+
+const std::vector<OUString> SfxClassificationHelper::GetIntellectualPropertyParts()
+{
+    return m_pImpl->m_aIPParts;
+}
+
+const std::vector<OUString> SfxClassificationHelper::GetIntellectualPropertyPartNumbers()
+{
+    return m_pImpl->m_aIPPartNumbers;
+}
+
 const OUString& SfxClassificationHelper::GetBACName(SfxClassificationPolicyType eType)
 {
     return m_pImpl->m_aCategory[eType].m_aName;
 }
 
+const OUString& SfxClassificationHelper::GetAbbreviatedBACName(const OUString& sFullName)
+{
+    for (const auto& category : m_pImpl->m_aCategories)
+    {
+        if (category.m_aName == sFullName)
+            return category.m_aAbbreviatedName;
+    }
+
+    return sFullName;
+}
+
+OUString SfxClassificationHelper::GetBACNameForIdentifier(const OUString& sIdentifier)
+{
+    OUString aRet;
+    if (sIdentifier.isEmpty())
+        return aRet;
+
+    for (const auto& category : m_pImpl->m_aCategories)
+    {
+        if (category.m_aIdentifier == sIdentifier)
+            return category.m_aName;
+    }
+
+    return aRet;
+}
+
+OUString SfxClassificationHelper::GetHigherClass(const OUString& first, const OUString& second)
+{
+    size_t nFirstConfidentiality = 0;
+    size_t nSecondConfidentiality = 0;
+    for (const auto& category : m_pImpl->m_aCategories)
+    {
+        if (category.m_aName == first)
+            nFirstConfidentiality = category.m_nConfidentiality;
+        if (category.m_aName == second)
+            nSecondConfidentiality = category.m_nConfidentiality;
+    }
+
+    return nFirstConfidentiality >= nSecondConfidentiality ? first : second;
+}
+
 bool SfxClassificationHelper::HasImpactLevel()
 {
     auto itCategory = m_pImpl->m_aCategory.find(SfxClassificationPolicyType::IntellectualProperty);
@@ -709,6 +810,32 @@ std::vector<OUString> SfxClassificationHelper::GetBACNames()
     return aRet;
 }
 
+std::vector<OUString> SfxClassificationHelper::GetBACIdentifiers()
+{
+    if (m_pImpl->m_aCategories.empty())
+        m_pImpl->parsePolicy();
+
+    std::vector<OUString> aRet;
+    std::transform(m_pImpl->m_aCategories.begin(), m_pImpl->m_aCategories.end(), std::back_inserter(aRet), [](const SfxClassificationCategory& rCategory)
+    {
+        return rCategory.m_aIdentifier;
+    });
+    return aRet;
+}
+
+std::vector<OUString> SfxClassificationHelper::GetAbbreviatedBACNames()
+{
+    if (m_pImpl->m_aCategories.empty())
+        m_pImpl->parsePolicy();
+
+    std::vector<OUString> aRet;
+    std::transform(m_pImpl->m_aCategories.begin(), m_pImpl->m_aCategories.end(), std::back_inserter(aRet), [](const SfxClassificationCategory& rCategory)
+    {
+        return rCategory.m_aAbbreviatedName;
+    });
+    return aRet;
+}
+
 void SfxClassificationHelper::SetBACName(const OUString& rName, SfxClassificationPolicyType eType)
 {
     if (m_pImpl->m_aCategories.empty())
@@ -725,6 +852,8 @@ void SfxClassificationHelper::SetBACName(const OUString& rName, SfxClassificatio
     }
 
     m_pImpl->m_aCategory[eType].m_aName = it->m_aName;
+    m_pImpl->m_aCategory[eType].m_aAbbreviatedName = it->m_aAbbreviatedName;
+    m_pImpl->m_aCategory[eType].m_nConfidentiality = it->m_nConfidentiality;
     m_pImpl->m_aCategory[eType].m_aLabels.clear();
     const OUString& rPrefix = policyTypeToString(eType);
     for (const auto& rLabel : it->m_aLabels)
@@ -804,4 +933,48 @@ const OUString& SfxClassificationHelper::PROP_PREFIX_INTELLECTUALPROPERTY()
     return sProp;
 }
 
+SfxClassificationPolicyType SfxClassificationHelper::getPolicyType()
+{
+    sal_Int32 nPolicyTypeNumber = officecfg::Office::Common::Classification::Policy::get();
+    auto eType = static_cast<SfxClassificationPolicyType>(nPolicyTypeNumber);
+    return eType;
+}
+
+namespace sfx
+{
+
+namespace
+{
+
+OUString getProperty(uno::Reference<beans::XPropertyContainer> const& rxPropertyContainer,
+                     OUString const& rName)
+{
+    try
+    {
+        uno::Reference<beans::XPropertySet> xPropertySet(rxPropertyContainer, uno::UNO_QUERY);
+        return xPropertySet->getPropertyValue(rName).get<OUString>();
+    }
+    catch (const css::uno::Exception&)
+    {
+    }
+
+    return OUString();
+}
+
+} // end anonymous namespace
+
+sfx::ClassificationCreationOrigin getCreationOriginProperty(uno::Reference<beans::XPropertyContainer> const & rxPropertyContainer,
+                                                            sfx::ClassificationKeyCreator const & rKeyCreator)
+{
+    OUString sValue = getProperty(rxPropertyContainer, rKeyCreator.makeCreationOriginKey());
+    if (sValue.isEmpty())
+        return sfx::ClassificationCreationOrigin::NONE;
+
+    return (sValue == "BAF_POLICY")
+                ? sfx::ClassificationCreationOrigin::BAF_POLICY
+                : sfx::ClassificationCreationOrigin::MANUAL;
+}
+
+}
+
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
