@@ -19,24 +19,23 @@
 
 #include <sal/config.h>
 
-#include "boost/noncopyable.hpp"
-#include "osl/process.h"
-#include "rtl/ustring.hxx"
-#include "rtl/string.hxx"
-#include "rtl/strbuf.hxx"
+#include <osl/process.h>
+#include <rtl/ustring.hxx>
+#include <rtl/string.hxx>
+#include <rtl/strbuf.hxx>
 
-#include "osl/thread.h"
+#include <osl/thread.h>
 #include <osl/diagnose.h>
 #include "recently_used_file.hxx"
 
-#include "internal/xml_parser.hxx"
-#include "internal/i_xml_parser_event_handler.hxx"
+#include <xml_parser.hxx>
+#include <i_xml_parser_event_handler.hxx>
 
 #include <map>
 #include <vector>
 #include <algorithm>
-#include <functional>
 #include <string.h>
+#include <time.h>
 
 namespace /* private */ {
     typedef std::vector<string_t> string_container_t;
@@ -50,18 +49,6 @@ namespace /* private */ {
     #define TAG_GROUPS       "Groups"
     #define TAG_GROUP        "Group"
 
-
-    // compare two string_t's case insensitive, may also be done
-    // by specifying special traits for the string type but in this
-    // case it's easier to do it this way
-    struct str_icase_cmp :
-        public std::binary_function<string_t, string_t, bool>
-    {
-        bool operator() (const string_t& s1, const string_t& s2) const
-        { return (0 == strcasecmp(s1.c_str(), s2.c_str())); }
-    };
-
-
     struct recently_used_item
     {
         recently_used_item()
@@ -72,14 +59,13 @@ namespace /* private */ {
         recently_used_item(
             const string_t& uri,
             const string_t& mime_type,
-            const string_container_t& groups,
-            bool is_private = false) :
+            const string_container_t& groups) :
             uri_(uri),
             mime_type_(mime_type),
-            is_private_(is_private),
+            is_private_(false),
             groups_(groups)
         {
-            timestamp_ = time(NULL);
+            timestamp_ = time(nullptr);
         }
 
         void set_uri(const string_t& character)
@@ -90,11 +76,11 @@ namespace /* private */ {
 
         void set_timestamp(const string_t& character)
         {
-            time_t t;
+            long t;
             if (sscanf(character.c_str(), "%ld", &t) != 1)
                 timestamp_ = -1;
             else
-                timestamp_ = t;
+                timestamp_ = static_cast<time_t>(t);
         }
 
         void set_is_private(SAL_UNUSED_PARAMETER const string_t& /*character*/)
@@ -117,7 +103,11 @@ namespace /* private */ {
             return (has_groups() &&
                     iter_end != std::find_if(
                         groups_.begin(), iter_end,
-                        std::bind2nd(str_icase_cmp(), name)));
+                        [&name](const string_t& s)
+                        { return (0 == strcasecmp(s.c_str(), name.c_str())); })
+                        // compare two string_t's case insensitive
+                   );
+
         }
 
         void write_xml(const recently_used_file& file) const
@@ -150,16 +140,16 @@ namespace /* private */ {
         static OString escape_content(const string_t &text)
         {
             OStringBuffer aBuf;
-            for (sal_uInt32 i = 0; i < text.length(); i++)
+            for (auto i : text)
             {
-                switch (text[i])
+                switch (i)
                 {
                     case '&':  aBuf.append("&amp;");  break;
                     case '<':  aBuf.append("&lt;");   break;
                     case '>':  aBuf.append("&gt;");   break;
                     case '\'': aBuf.append("&apos;"); break;
                     case '"':  aBuf.append("&quot;"); break;
-                    default:   aBuf.append(text[i]);  break;
+                    default:   aBuf.append(i);  break;
                 }
             }
             return aBuf.makeStringAndClear();
@@ -167,7 +157,7 @@ namespace /* private */ {
 
         void write_xml_tag(const string_t& name, const string_t& value, const recently_used_file& file) const
         {
-            write_xml_start_tag(name, file);
+            write_xml_start_tag(name, file, false);
             OString escaped = escape_content (value);
             file.write(escaped.getStr(), escaped.getLength());
             write_xml_end_tag(name, file);
@@ -180,7 +170,7 @@ namespace /* private */ {
             file.write("/>\n", 3);
         }
 
-        void write_xml_start_tag(const string_t& name, const recently_used_file& file, bool linefeed = false) const
+        void write_xml_start_tag(const string_t& name, const recently_used_file& file, bool linefeed) const
         {
             file.write("<", 1);
             file.write(name.c_str(), name.length());
@@ -211,11 +201,11 @@ namespace /* private */ {
     class unknown_xml_format_exception {};
 
     class recently_used_file_filter:
-        public i_xml_parser_event_handler, private boost::noncopyable
+        public i_xml_parser_event_handler
     {
     public:
-        recently_used_file_filter(recently_used_item_list_t& item_list) :
-            item_(NULL),
+        explicit recently_used_file_filter(recently_used_item_list_t& item_list) :
+            item_(nullptr),
             item_list_(item_list)
         {
             named_command_map_[TAG_RECENT_FILES] = &recently_used_item::set_nothing;
@@ -228,19 +218,22 @@ namespace /* private */ {
             named_command_map_[TAG_GROUP]        = &recently_used_item::set_groups;
         }
 
+        recently_used_file_filter(const recently_used_file_filter&) = delete;
+        recently_used_file_filter& operator=(const recently_used_file_filter&) = delete;
+
         virtual void start_element(
             const string_t& /*raw_name*/,
             const string_t& local_name,
-            const xml_tag_attribute_container_t& /*attributes*/) SAL_OVERRIDE
+            const xml_tag_attribute_container_t& /*attributes*/) override
         {
-            if ((local_name == TAG_RECENT_ITEM) && (NULL == item_))
+            if ((local_name == TAG_RECENT_ITEM) && (nullptr == item_))
                 item_ = new recently_used_item;
         }
 
-        virtual void end_element(const string_t& /*raw_name*/, const string_t& local_name) SAL_OVERRIDE
+        virtual void end_element(const string_t& /*raw_name*/, const string_t& local_name) override
         {
             // check for end tags w/o start tag
-            if( local_name != TAG_RECENT_FILES && NULL == item_ )
+            if( local_name != TAG_RECENT_FILES && nullptr == item_ )
                 return; // will result in an XML parser error anyway
 
             if (named_command_map_.find(local_name) != named_command_map_.end())
@@ -254,28 +247,21 @@ namespace /* private */ {
             if (local_name == TAG_RECENT_ITEM)
             {
                 item_list_.push_back(item_);
-                item_ = NULL;
+                item_ = nullptr;
             }
             current_element_.clear();
         }
 
-        virtual void characters(const string_t& character) SAL_OVERRIDE
+        virtual void characters(const string_t& character) override
         {
             if (character != "\n")
                 current_element_ += character;
         }
 
-        virtual void start_document() SAL_OVERRIDE {}
-        virtual void end_document() SAL_OVERRIDE   {}
-
-        virtual void ignore_whitespace(const string_t& /*whitespaces*/) SAL_OVERRIDE
+        virtual void ignore_whitespace(const string_t& /*whitespaces*/) override
         {}
 
-        virtual void processing_instruction(
-            const string_t& /*target*/, const string_t& /*data*/) SAL_OVERRIDE
-        {}
-
-        virtual void comment(const string_t& /*comment*/) SAL_OVERRIDE
+        virtual void comment(const string_t& /*comment*/) override
         {}
     private:
         recently_used_item* item_;
@@ -286,7 +272,7 @@ namespace /* private */ {
 
 
     void read_recently_used_items(
-        recently_used_file& file,
+        recently_used_file const & file,
         recently_used_item_list_t& item_list)
     {
         xml_parser xparser;
@@ -310,28 +296,24 @@ namespace /* private */ {
     class recent_item_writer
     {
     public:
-        recent_item_writer(
-            recently_used_file& file,
-            int max_items_to_write = MAX_RECENTLY_USED_ITEMS) :
+        explicit recent_item_writer( recently_used_file& file ) :
             file_(file),
-            max_items_to_write_(max_items_to_write),
             items_written_(0)
         {}
 
         void operator() (const recently_used_item* item)
         {
-            if (items_written_++ < max_items_to_write_)
+            if (items_written_++ < MAX_RECENTLY_USED_ITEMS)
                 item->write_xml(file_);
         }
     private:
         recently_used_file& file_;
-        int max_items_to_write_;
         int items_written_;
     };
 
 
-    const char* XML_HEADER = "<?xml version=\"1.0\"?>\n<RecentFiles>\n";
-    const char* XML_FOOTER = "</RecentFiles>";
+    const char* const XML_HEADER = "<?xml version=\"1.0\"?>\n<RecentFiles>\n";
+    const char* const XML_FOOTER = "</RecentFiles>";
 
 
     // assumes that the list is ordered decreasing
@@ -376,7 +358,7 @@ namespace /* private */ {
     class find_item_predicate
     {
     public:
-        find_item_predicate(const string_t& uri) :
+        explicit find_item_predicate(const string_t& uri) :
             uri_(uri)
         {}
 
@@ -394,9 +376,9 @@ namespace /* private */ {
     };
 
 
-    const char* GROUP_OOO         = "openoffice.org";
-    const char* GROUP_STAR_OFFICE = "staroffice";
-    const char* GROUP_STAR_SUITE  = "starsuite";
+    const char* const GROUP_OOO         = "openoffice.org";
+    const char* const GROUP_STAR_OFFICE = "staroffice";
+    const char* const GROUP_STAR_SUITE  = "starsuite";
 
 
     void recently_used_item_list_add(
@@ -412,7 +394,7 @@ namespace /* private */ {
 
         if (iter != item_list.end())
         {
-            (*iter)->timestamp_ = time(NULL);
+            (*iter)->timestamp_ = time(nullptr);
 
             if (!(*iter)->has_group(GROUP_OOO))
                 (*iter)->groups_.push_back(GROUP_OOO);
@@ -448,7 +430,7 @@ namespace /* private */ {
 
     struct cleanup_guard
     {
-        cleanup_guard(recently_used_item_list_t& item_list) :
+        explicit cleanup_guard(recently_used_item_list_t& item_list) :
             item_list_(item_list)
         {}
         ~cleanup_guard()
