@@ -18,7 +18,6 @@
  */
 
 
-
 //  File:       ooofilt.cxx
 //  Contents:   Filter Implementation for OpenOffice.Org Document using
 //              Indexing Service
@@ -29,10 +28,10 @@
 
 //  Platform:   Windows 2000, Windows XP
 
-#include "internal/contentreader.hxx"
-#include "internal/metainforeader.hxx"
-#include "internal/registry.hxx"
-#include "internal/fileextensions.hxx"
+#include <contentreader.hxx>
+#include <metainforeader.hxx>
+#include <registry.hxx>
+#include <fileextensions.hxx>
 
 
 //  Include file    Purpose
@@ -49,6 +48,9 @@
 #if defined _MSC_VER
 #pragma warning(push, 1)
 #endif
+#if !defined WIN32_LEAN_AND_MEAN
+# define WIN32_LEAN_AND_MEAN
+#endif
 #include <windows.h>
 #if defined _MSC_VER
 #pragma warning(pop)
@@ -57,17 +59,13 @@
 #include <filter.h>
 #include <filterr.h>
 #include <ntquery.h>
-#include "assert.h"
+#include <assert.h>
 #include "ooofilt.hxx"
 #include <objidl.h>
 #include <stdio.h>
 #include "propspec.hxx"
-#ifdef __MINGW32__
-#include <algorithm>
-using ::std::min;
-#endif
 
-#include "internal/stream_helper.hxx"
+#include <stream_helper.hxx>
 
 //C-------------------------------------------------------------------------
 //  Class:      COooFilter
@@ -81,8 +79,8 @@ using ::std::min;
 
 COooFilter::COooFilter() :
     m_lRefs(1),
-    m_pContentReader(NULL),
-    m_pMetaInfoReader(NULL),
+    m_pContentReader(nullptr),
+    m_pMetaInfoReader(nullptr),
     m_eState(FilteringContent),
     m_ulUnicodeBufferLen(0),
     m_ulUnicodeCharsRead(0),
@@ -93,8 +91,8 @@ COooFilter::COooFilter() :
     m_fEof(FALSE),
     m_ChunkPosition(0),
     m_cAttributes(0),
-    m_pAttributes(0),
-    m_pStream(NULL)
+    m_pAttributes(nullptr),
+    m_pStream(nullptr)
 
 {
     InterlockedIncrement( &g_lInstances );
@@ -130,23 +128,23 @@ SCODE STDMETHODCALLTYPE COooFilter::QueryInterface(
     REFIID riid,
     void  ** ppvObject)
 {
-    IUnknown *pUnkTemp = 0;
+    IUnknown *pUnkTemp = nullptr;
     if ( IID_IFilter == riid )
-        pUnkTemp = (IUnknown *)(IFilter *)this;
+        pUnkTemp = static_cast<IUnknown *>(static_cast<IFilter *>(this));
     else if ( IID_IPersistFile == riid )
-        pUnkTemp = (IUnknown *)(IPersistFile *)this;
+        pUnkTemp = static_cast<IUnknown *>(static_cast<IPersistFile *>(this));
     else if ( IID_IPersist == riid )
-        pUnkTemp = (IUnknown *)(IPersist *)(IPersistFile *)this;
+        pUnkTemp = static_cast<IUnknown *>(static_cast<IPersist *>(static_cast<IPersistFile *>(this)));
     else if (IID_IPersistStream == riid)
-        pUnkTemp = (IUnknown *)(IPersistStream *)this;
+        pUnkTemp = static_cast<IUnknown *>(static_cast<IPersistStream *>(this));
     else if ( IID_IUnknown == riid )
-        pUnkTemp = (IUnknown *)(IPersist *)(IPersistFile *)this;
+        pUnkTemp = static_cast<IUnknown *>(static_cast<IPersist *>(static_cast<IPersistFile *>(this)));
     else
     {
-        *ppvObject = NULL;
+        *ppvObject = nullptr;
         return E_NOINTERFACE;
     }
-    *ppvObject = (void  *)pUnkTemp;
+    *ppvObject = pUnkTemp;
     pUnkTemp->AddRef();
     return S_OK;
 }
@@ -214,18 +212,18 @@ SCODE STDMETHODCALLTYPE COooFilter::Init(
         if ( m_cAttributes > 0 )
         {
             delete[] m_pAttributes;
-            m_pAttributes = 0;
+            m_pAttributes = nullptr;
             m_cAttributes = 0;
         }
         if( 0 < cAttributes )
         {
             // Filter properties specified in aAttributes
-            if ( 0 == aAttributes )
+            if ( nullptr == aAttributes )
                 return E_INVALIDARG;
             m_pAttributes = new CFullPropSpec[cAttributes];
             m_cAttributes = cAttributes;
             // Is caller want to filter contents?
-            CFullPropSpec *pAttrib = (CFullPropSpec *) aAttributes;
+            CFullPropSpec const *pAttrib = reinterpret_cast<CFullPropSpec const *>(aAttributes);
             ULONG ulNumAttr;
             for ( ulNumAttr = 0 ; ulNumAttr < cAttributes; ulNumAttr++ )
             {
@@ -314,7 +312,6 @@ SCODE STDMETHODCALLTYPE COooFilter::GetChunk(STAT_CHUNK * pStat)
         {
         case FilteringContent:
         {
-            // Read Unicodes from buffer.
             if( m_ChunkPosition == m_pContentReader ->getChunkBuffer().size() )
             {
                 m_ulUnicodeBufferLen=0;
@@ -475,8 +472,8 @@ SCODE STDMETHODCALLTYPE COooFilter::GetValue(PROPVARIANT ** ppPropValue)
     {
         if ( m_cAttributes == 0 || ( m_ulCurrentPropertyNum == m_ulPropertyNum ) )
             return FILTER_E_NO_MORE_VALUES;
-        PROPVARIANT *pPropVar = (PROPVARIANT *) CoTaskMemAlloc( sizeof (PROPVARIANT) );
-        if ( pPropVar == 0 )
+        PROPVARIANT *pPropVar = static_cast<PROPVARIANT *>(CoTaskMemAlloc( sizeof (PROPVARIANT) ));
+        if ( pPropVar == nullptr )
             return E_OUTOFMEMORY;
         ::std::wstring wsTagName= GetMetaInfoNameFromPropertyId( m_pAttributes[m_ulCurrentPropertyNum].GetPropertyPropid() );
         if ( wsTagName == EMPTY_STRING )
@@ -485,7 +482,7 @@ SCODE STDMETHODCALLTYPE COooFilter::GetValue(PROPVARIANT ** ppPropValue)
         pPropVar->vt = VT_LPWSTR;
         size_t cw = wsTagData.length() + 1; // reserve one for the '\0'
         pPropVar->pwszVal = static_cast<WCHAR*>( CoTaskMemAlloc(cw*sizeof(WCHAR)) );
-        if (pPropVar->pwszVal == 0)
+        if (pPropVar->pwszVal == nullptr)
         {
             CoTaskMemFree(pPropVar);
             return E_OUTOFMEMORY;
@@ -574,10 +571,10 @@ SCODE STDMETHODCALLTYPE COooFilter::Load(LPCWSTR pszFileName, DWORD /*dwMode*/)
     try
     {
         delete m_pMetaInfoReader;
-        m_pMetaInfoReader = new CMetaInfoReader(WStringToString(m_pwszFileName));
+        m_pMetaInfoReader = new CMetaInfoReader(m_pwszFileName);
 
         delete m_pContentReader;
-        m_pContentReader = new CContentReader(WStringToString(m_pwszFileName), m_pMetaInfoReader->getDefaultLocale());
+        m_pContentReader = new CContentReader(m_pwszFileName, m_pMetaInfoReader->getDefaultLocale());
     }
     catch (const std::exception&)
     {
@@ -692,7 +689,7 @@ SCODE STDMETHODCALLTYPE COooFilter::GetCurFile(LPWSTR * ppszFileName)
     if ( EMPTY_STRING == m_pwszFileName )
         return E_FAIL;
     else
-        *ppszFileName = (LPWSTR)m_pwszFileName.c_str();
+        *ppszFileName = const_cast<LPWSTR>(m_pwszFileName.c_str());
     return S_OK;
 }
 
@@ -734,20 +731,20 @@ SCODE STDMETHODCALLTYPE COooFilterCF::QueryInterface(REFIID riid, void  ** ppvOb
     IUnknown *pUnkTemp;
 
     if ( IID_IClassFactory == riid )
-        pUnkTemp = (IUnknown *)(IClassFactory *)this;
+        pUnkTemp = static_cast<IUnknown *>(static_cast<IClassFactory *>(this));
     else if ( IID_IUnknown == riid )
-        pUnkTemp = (IUnknown *)this;
+        pUnkTemp = static_cast<IUnknown *>(this);
     else
     {
-        *ppvObject = NULL;
+        *ppvObject = nullptr;
         return E_NOINTERFACE;
     }
-    *ppvObject = (void  *)pUnkTemp;
+    *ppvObject = pUnkTemp;
     pUnkTemp->AddRef();
     return S_OK;
 }
 //M-------------------------------------------------------------------------
-//  Method:     COooFilterCF::AddRef            (IUknown::AddRef)
+//  Method:     COooFilterCF::AddRef            (IUnknown::AddRef)
 //  Summary:    Increments interface refcount
 //  Arguments:  void
 //  Returns:    Value of incremented interface refcount
@@ -796,8 +793,8 @@ SCODE STDMETHODCALLTYPE COooFilterCF::CreateInstance(
     REFIID riid,
     void  * * ppvObject)
 {
-    COooFilter *pIUnk = 0;
-    if ( 0 != pUnkOuter )
+    COooFilter *pIUnk = nullptr;
+    if ( nullptr != pUnkOuter )
         return CLASS_E_NOAGGREGATION;
     pIUnk = new COooFilter();
     if ( SUCCEEDED( pIUnk->QueryInterface( riid , ppvObject ) ) )
@@ -887,13 +884,13 @@ extern "C" SCODE STDMETHODCALLTYPE DllGetClassObject(
     void **    ppvObj
 )
 {
-    COooFilterCF* pImpl = 0;
-    IUnknown *pResult = 0;
+    COooFilterCF* pImpl = nullptr;
+    IUnknown *pResult = nullptr;
 
     if ( CLSID_COooFilter == cid )
     {
         pImpl = new COooFilterCF;
-        pResult = (IUnknown *) pImpl;
+        pResult = static_cast<IUnknown *>(pImpl);
     }
     else
         return CLASS_E_CLASSNOTAVAILABLE;
@@ -953,287 +950,12 @@ extern "C" SCODE STDMETHODCALLTYPE DllCanUnloadNow()
 //                  E_UNEXPECTED
 //                      (not implemented)
 
-
-
-//F-------------------------------------------------------------------------
-//  helper functions to register the Indexing Service.
-
-
-namespace /* private */
-{
-    const char* GUID_PLACEHOLDER         = "{GUID}";
-    const char* GUID_PERSIST_PLACEHOLDER = "{GUIDPERSIST}";
-    const char* EXTENSION_PLACEHOLDER    = "{EXT}";
-
-    const char* CLSID_GUID_INPROC_ENTRY             = "CLSID\\{GUID}\\InProcServer32";
-    const char* CLSID_GUID_ENTRY                    = "CLSID\\{GUID}";
-    const char* CLSID_GUID_PERSIST_ADDIN_ENTRY      = "CLSID\\{GUID}\\PersistentAddinsRegistered\\{GUIDPERSIST}";
-    const char* CLSID_PERSIST_ENTRY                 = "CLSID\\{GUID}\\PersistentHandler";
-    const char* EXT_PERSIST_ENTRY                   = "{EXT}\\PersistentHandler";
-
-    const char* INDEXING_FILTER_DLLSTOREGISTER      = "SYSTEM\\CurrentControlSet\\Control\\ContentIndex";
-
-
-    // "String Placeholder" ->
-    // "String Replacement"
-
-
-    void SubstitutePlaceholder(std::string& String, const std::string& Placeholder, const std::string& Replacement)
-    {
-        std::string::size_type idx = String.find(Placeholder);
-        std::string::size_type len = Placeholder.length();
-
-        while (std::string::npos != idx)
-        {
-            String.replace(idx, len, Replacement);
-            idx = String.find(Placeholder);
-        }
-    }
-
-
-    // Make the registry entry and set Filter Handler
-    // HKCR\CLSID\{7BC0E710-5703-45be-A29D-5D46D8B39262} = LibreOffice Filter
-    //                   InProcServer32  (Default)       = Path\ooofilt.dll
-    //                                   ThreadingModel  = Both
-
-
-    HRESULT RegisterFilterHandler(const char* FilePath, const CLSID& FilterGuid)
-    {
-        std::string ClsidEntry = CLSID_GUID_ENTRY;
-        SubstitutePlaceholder(ClsidEntry, GUID_PLACEHOLDER, ClsidToString(FilterGuid));
-
-        if (!SetRegistryKey(HKEY_CLASSES_ROOT, ClsidEntry.c_str(), "", "LibreOffice Filter"))
-            return E_FAIL;
-
-        ClsidEntry = CLSID_GUID_INPROC_ENTRY;
-        SubstitutePlaceholder(ClsidEntry, GUID_PLACEHOLDER, ClsidToString(FilterGuid));
-
-        if (!SetRegistryKey(HKEY_CLASSES_ROOT, ClsidEntry.c_str(), "", FilePath))
-            return E_FAIL;
-
-        if (!SetRegistryKey(HKEY_CLASSES_ROOT, ClsidEntry.c_str(), "ThreadingModel", "Both"))
-            return E_FAIL;
-
-        return S_OK;
-    }
-
-
-    // Make the registry entry and set Persistent Handler
-    // HKCR\CLSID\{7BC0E713-5703-45be-A29D-5D46D8B39262}  = LibreOffice Persistent Handler
-    //      PersistentAddinsRegistered
-    //          {89BCB740-6119-101A-BCB7-00DD010655AF} = {7BC0E710-5703-45be-A29D-5D46D8B39262}
-
-
-    HRESULT RegisterPersistentHandler(const CLSID& FilterGuid, const CLSID& PersistentGuid)
-    {
-        std::string ClsidEntry_Persist = CLSID_GUID_ENTRY;
-        SubstitutePlaceholder(ClsidEntry_Persist, GUID_PLACEHOLDER, ClsidToString(PersistentGuid));
-
-
-        if (!SetRegistryKey(HKEY_CLASSES_ROOT, ClsidEntry_Persist.c_str(), "", "LibreOffice Persistent Handler"))
-            return E_FAIL;
-
-        // Add missing entry
-        std::string ClsidEntry_Persist_Entry = CLSID_PERSIST_ENTRY;
-        SubstitutePlaceholder(ClsidEntry_Persist_Entry,
-                              GUID_PLACEHOLDER,
-                              ClsidToString(PersistentGuid));
-
-        if (!SetRegistryKey(HKEY_CLASSES_ROOT, ClsidEntry_Persist_Entry.c_str(), "", ClsidToString(PersistentGuid).c_str()))
-            return E_FAIL;
-
-        std::string ClsidEntry_Persist_Addin = CLSID_GUID_PERSIST_ADDIN_ENTRY;
-        SubstitutePlaceholder(ClsidEntry_Persist_Addin,
-                              GUID_PLACEHOLDER,
-                              ClsidToString(PersistentGuid));
-        SubstitutePlaceholder(ClsidEntry_Persist_Addin,
-                              GUID_PERSIST_PLACEHOLDER,
-                              ClsidToString(CLSID_PERSISTENT_HANDLER_ADDIN));
-
-        if (!SetRegistryKey(HKEY_CLASSES_ROOT, ClsidEntry_Persist_Addin.c_str(), "", ClsidToString(FilterGuid).c_str() ))
-            return E_FAIL;
-
-        return S_OK;
-    }
-
-
-    // Unregister Filter Handler or persistent handler
-
-
-    HRESULT UnregisterHandler(const CLSID& Guid)
-    {
-        std::string tmp = "CLSID\\";
-        tmp += ClsidToString(Guid);
-        return DeleteRegistryKey(HKEY_CLASSES_ROOT, tmp.c_str()) ? S_OK : E_FAIL;
-    }
-
-
-    // Register Indexing Service ext and class.
-    // HKCR\{EXT}\PersistentHandler = {7BC0E713-5703-45be-A29D-5D46D8B39262}
-    // HKCR\{GUID\PersistentHandler = {7BC0E713-5703-45be-A29D-5D46D8B39262}
-
-
-    HRESULT RegisterSearchHandler(const char* ModuleFileName)
-    {
-        if (FAILED(RegisterFilterHandler(ModuleFileName, CLSID_FILTER_HANDLER)))
-            return E_FAIL;
-
-        if (FAILED(RegisterPersistentHandler(CLSID_FILTER_HANDLER, CLSID_PERSISTENT_HANDLER )))
-            return E_FAIL;
-
-        std::string sExtPersistEntry;
-
-        for(size_t i = 0; i < OOFileExtensionTableSize; i++)
-        {
-            // first, register extension.
-            sExtPersistEntry = EXT_PERSIST_ENTRY;
-            SubstitutePlaceholder(sExtPersistEntry, EXTENSION_PLACEHOLDER, OOFileExtensionTable[i].ExtensionAnsi);
-            if (!SetRegistryKey(HKEY_CLASSES_ROOT,
-                                sExtPersistEntry.c_str(),
-                                "",
-                                ClsidToString(CLSID_PERSISTENT_HANDLER).c_str()))
-                return E_FAIL;
-
-            // second, register class.
-            char extClassName[MAX_PATH];
-            if (QueryRegistryKey(HKEY_CLASSES_ROOT, OOFileExtensionTable[i].ExtensionAnsi, "", extClassName,MAX_PATH))
-            {
-                ::std::string extCLSIDName( extClassName );
-                extCLSIDName += "\\CLSID";
-                char extCLSID[MAX_PATH];
-
-                if (QueryRegistryKey( HKEY_CLASSES_ROOT, extCLSIDName.c_str(), "", extCLSID, MAX_PATH))
-                {
-                    std::string ClsidEntry_CLSID_Persist = CLSID_PERSIST_ENTRY;
-                    SubstitutePlaceholder(ClsidEntry_CLSID_Persist,
-                                        GUID_PLACEHOLDER,
-                                        extCLSID);
-
-                    if (!SetRegistryKey(HKEY_CLASSES_ROOT,
-                                        ClsidEntry_CLSID_Persist.c_str(),
-                                        "",
-                                        ClsidToString(CLSID_PERSISTENT_HANDLER).c_str() ))
-                        return E_FAIL;
-                }
-            }
-        }
-
-        return S_OK;
-    }
-
-    // Register Indexing Service ext and class.
-    HRESULT UnregisterSearchHandler()
-    {
-        std::string sExtPersistEntry;
-
-        for (size_t i = 0; i < OOFileExtensionTableSize; i++)
-        {
-            // first, unregister extension
-            sExtPersistEntry = EXT_PERSIST_ENTRY;
-            SubstitutePlaceholder(sExtPersistEntry, EXTENSION_PLACEHOLDER, OOFileExtensionTable[i].ExtensionAnsi);
-            DeleteRegistryKey(HKEY_CLASSES_ROOT, sExtPersistEntry.c_str());
-
-            // second, unregister class
-            char extClassName[MAX_PATH];
-            if (QueryRegistryKey(HKEY_CLASSES_ROOT, OOFileExtensionTable[i].ExtensionAnsi, "", extClassName,MAX_PATH))
-            {
-                ::std::string extCLSIDName( extClassName );
-                extCLSIDName += "\\CLSID";
-                char extCLSID[MAX_PATH];
-
-                if (QueryRegistryKey( HKEY_CLASSES_ROOT, extCLSIDName.c_str(), "", extCLSID, MAX_PATH))
-                {
-                    std::string ClsidEntry_CLSID_Persist = CLSID_PERSIST_ENTRY;
-                    SubstitutePlaceholder(ClsidEntry_CLSID_Persist,
-                                        GUID_PLACEHOLDER,
-                                        extCLSID);
-
-                    DeleteRegistryKey(HKEY_CLASSES_ROOT, ClsidEntry_CLSID_Persist.c_str());
-                }
-            }
-        }
-
-        return ((UnregisterHandler(CLSID_FILTER_HANDLER)==S_OK) && (UnregisterHandler(CLSID_PERSISTENT_HANDLER)==S_OK))?S_OK:E_FAIL;
-    }
-
-
-    //    add or remove an entry to DllsToRegister entry of Indexing
-    //    Filter to let Indexing Service register our filter automatically
-    //    each time.
-
-    HRESULT AddOrRemoveDllsToRegisterList( const ::std::string & DllPath, bool isAdd )
-    {
-        char DllsToRegisterList[4096];
-        if (QueryRegistryKey(HKEY_LOCAL_MACHINE,
-                             INDEXING_FILTER_DLLSTOREGISTER,
-                             "DLLsToRegister",
-                             DllsToRegisterList,
-                             4096))
-        {
-            char * pChar = DllsToRegisterList;
-            for ( ; *pChar != '\0' || *(pChar +1) != '\0'; pChar++)
-                if ( *pChar == '\0')
-                    *pChar = ';';
-            *pChar = ';';
-            *(pChar+1) = '\0';
-
-            ::std::string DllList(DllsToRegisterList);
-            if ( ( isAdd )&&( DllList.find( DllPath ) == ::std::string::npos ) )
-                DllList.append( DllPath );
-            else if ( ( !isAdd )&&( DllList.find( DllPath ) != ::std::string::npos ) )
-                DllList.erase( DllList.find( DllPath )-1, DllPath.length()+1 );
-            else
-                return S_OK;
-
-            pChar = DllsToRegisterList;
-            for ( size_t nChar = 0; nChar < DllList.length(); pChar++,nChar++)
-            {
-                if ( DllList[nChar] == ';')
-                    *pChar = '\0';
-                else
-                    *pChar = DllList[nChar];
-            }
-            *pChar = *( pChar+1 ) ='\0';
-
-            HKEY hSubKey;
-            char dummy[] = "";
-            int rc = RegCreateKeyExA(HKEY_LOCAL_MACHINE,
-                                    INDEXING_FILTER_DLLSTOREGISTER,
-                                    0,
-                                    dummy,
-                                    REG_OPTION_NON_VOLATILE,
-                                    KEY_WRITE,
-                                    0,
-                                    &hSubKey,
-                                    0);
-
-            if (ERROR_SUCCESS == rc)
-            {
-                rc = RegSetValueExA( hSubKey,
-                                    "DLLsToRegister",
-                                    0,
-                                    REG_MULTI_SZ,
-                                    reinterpret_cast<const BYTE*>(DllsToRegisterList),
-                                    static_cast<DWORD>(DllList.length() + 2));
-
-                RegCloseKey(hSubKey);
-            }
-
-            return (ERROR_SUCCESS == rc)?S_OK:E_FAIL;
-        }
-
-        return S_OK;
-    }
-
-} // namespace /* private */
-
 STDAPI DllRegisterServer()
 {
     return S_OK;
 }
 
 
-
 STDAPI DllUnregisterServer()
 {
     return S_OK;
