@@ -18,7 +18,6 @@
  */
 
 
-#include <boost/current_function.hpp>
 #include <rtl/ustrbuf.hxx>
 #include <vcl/svapp.hxx>
 #include <vcl/gdimtf.hxx>
@@ -37,12 +36,12 @@
 #include <com/sun/star/awt/MouseEvent.hpp>
 #include <com/sun/star/rendering/XBitmap.hpp>
 
-#include "eventqueue.hxx"
-#include "screenupdater.hxx"
-#include "eventmultiplexer.hxx"
-#include "activitiesqueue.hxx"
-#include "slideshowcontext.hxx"
-#include "mouseeventhandler.hxx"
+#include <eventqueue.hxx>
+#include <screenupdater.hxx>
+#include <eventmultiplexer.hxx>
+#include <activitiesqueue.hxx>
+#include <slideshowcontext.hxx>
+#include <mouseeventhandler.hxx>
 #include "rehearsetimingsactivity.hxx"
 
 #include <algorithm>
@@ -104,7 +103,7 @@ public:
 private:
     ::canvas::tools::ElapsedTime    maTimer;
     double                          mnNextTime;
-    boost::weak_ptr<Activity>       mpActivity;
+    std::weak_ptr<Activity>       mpActivity;
     ActivitiesQueue&                mrActivityQueue;
 };
 
@@ -145,7 +144,7 @@ RehearseTimingsActivity::RehearseTimingsActivity( const SlideShowContext& rConte
     maElapsedTime( rContext.mrEventQueue.getTimer() ),
     maViews(),
     maSpriteRectangle(),
-    maFont( Application::GetSettings().GetStyleSettings().GetInfoFont() ),
+    maFont( Application::GetSettings().GetStyleSettings().GetLabelFont() ),
     mpWakeUpEvent(),
     mpMouseHandler(),
     maSpriteSizePixel(),
@@ -153,17 +152,17 @@ RehearseTimingsActivity::RehearseTimingsActivity( const SlideShowContext& rConte
     mbActive(false),
     mbDrawPressed(false)
 {
-    maFont.SetHeight( maFont.GetHeight() * 2 );
-    maFont.SetWidth( maFont.GetWidth() * 2 );
-    maFont.SetAlign( ALIGN_BASELINE );
+    maFont.SetFontHeight( maFont.GetFontHeight() * 2 );
+    maFont.SetAverageFontWidth( maFont.GetAverageFontWidth() * 2 );
+    maFont.SetAlignment( ALIGN_BASELINE );
     maFont.SetColor( COL_BLACK );
 
     // determine sprite size (in pixel):
     ScopedVclPtrInstance< VirtualDevice > blackHole;
     blackHole->EnableOutput(false);
     blackHole->SetFont( maFont );
-    blackHole->SetMapMode( MAP_PIXEL );
-    Rectangle rect;
+    blackHole->SetMapMode(MapMode(MapUnit::MapPixel));
+    tools::Rectangle rect;
     const FontMetric metric( blackHole->GetFontMetric() );
     blackHole->GetTextBoundRect( rect, "XX:XX:XX" );
     maSpriteSizePixel.setX( rect.getWidth() * 12 / 10 );
@@ -180,19 +179,16 @@ RehearseTimingsActivity::~RehearseTimingsActivity()
     {
         stop();
     }
-    catch (uno::Exception &)
+    catch (const uno::Exception& e)
     {
-        OSL_FAIL( OUStringToOString(
-                        comphelper::anyToString(
-                            cppu::getCaughtException() ),
-                        RTL_TEXTENCODING_UTF8 ).getStr() );
+        SAL_WARN("slideshow", e);
     }
 }
 
-boost::shared_ptr<RehearseTimingsActivity> RehearseTimingsActivity::create(
+std::shared_ptr<RehearseTimingsActivity> RehearseTimingsActivity::create(
     const SlideShowContext& rContext )
 {
-    boost::shared_ptr<RehearseTimingsActivity> pActivity(
+    std::shared_ptr<RehearseTimingsActivity> pActivity(
         new RehearseTimingsActivity( rContext ));
 
     pActivity->mpMouseHandler.reset(
@@ -218,7 +214,7 @@ void RehearseTimingsActivity::start()
     for_each_sprite( []( const ::cppcanvas::CustomSpriteSharedPtr& pSprite )
                      { return pSprite->show(); } );
 
-    mrActivitiesQueue.addActivity( shared_from_this() );
+    mrActivitiesQueue.addActivity( std::dynamic_pointer_cast<Activity>(shared_from_this()) );
 
     mpMouseHandler->reset();
     mrEventMultiplexer.addClickHandler(
@@ -347,7 +343,7 @@ void RehearseTimingsActivity::viewAdded( const UnoViewSharedPtr& rView )
     if( maViews.empty() )
         maSpriteRectangle = spriteRectangle;
 
-    maViews.push_back( ViewsVecT::value_type( rView, sprite ) );
+    maViews.emplace_back( rView, sprite );
 
     if (isActive())
         sprite->show();
@@ -386,7 +382,7 @@ void RehearseTimingsActivity::viewChanged( const UnoViewSharedPtr& rView )
     aModifiedEntry->second->move( maSpriteRectangle.getMinimum() );
 
     // sprites changed, need screen update
-    mrScreenUpdater.notifyUpdate( rView );
+    mrScreenUpdater.notifyUpdate( rView, false );
 }
 
 void RehearseTimingsActivity::viewsChanged()
@@ -441,9 +437,9 @@ void RehearseTimingsActivity::paint( cppcanvas::CanvasSharedPtr const & canvas )
     metaFile.Record( blackHole );
     metaFile.SetPrefSize( Size( 1, 1 ) );
     blackHole->EnableOutput(false);
-    blackHole->SetMapMode( MAP_PIXEL );
+    blackHole->SetMapMode(MapMode(MapUnit::MapPixel));
     blackHole->SetFont( maFont );
-    Rectangle rect = Rectangle( 0,0,
+    tools::Rectangle rect = tools::Rectangle( 0,0,
                                 maSpriteSizePixel.getX(),
                                 maSpriteSizePixel.getY());
     if (mbDrawPressed)
@@ -472,7 +468,6 @@ void RehearseTimingsActivity::paint( cppcanvas::CanvasSharedPtr const & canvas )
             canvas, metaFile, cppcanvas::Renderer::Parameters() ) );
     const bool succ = renderer->draw();
     OSL_ASSERT( succ );
-    (void)succ;
 }
 
 
