@@ -19,9 +19,7 @@
 
 #include <config_features.h>
 
-#include <canvas/debug.hxx>
 #include <tools/diagnose_ex.h>
-#include <canvas/verbosetrace.hxx>
 
 #include <math.h>
 
@@ -34,7 +32,7 @@
 #include <vcl/window.hxx>
 #include <vcl/graph.hxx>
 
-#include <basegfx/tools/canvastools.hxx>
+#include <basegfx/utils/canvastools.hxx>
 #include <basegfx/matrix/b2dhommatrixtools.hxx>
 #include <basegfx/numeric/ftools.hxx>
 #include <basegfx/polygon/b2dpolygon.hxx>
@@ -46,24 +44,26 @@
 #include <cppcanvas/vclfactory.hxx>
 #include <cppcanvas/basegfxfactory.hxx>
 #include <avmedia/mediawindow.hxx>
-#include <avmedia/modeltools.hxx>
 
+#if HAVE_FEATURE_OPENGL
 #include <vcl/opengl/OpenGLContext.hxx>
+#endif
 
+#include <com/sun/star/awt/XWindow.hpp>
+#include <com/sun/star/beans/XPropertySet.hpp>
+#include <com/sun/star/lang/XComponent.hpp>
+#include <com/sun/star/lang/XMultiComponentFactory.hpp>
+#include <com/sun/star/lang/NoSupportException.hpp>
 #include <com/sun/star/media/XManager.hpp>
 #include <com/sun/star/media/XPlayer.hpp>
 #include <com/sun/star/media/XPlayerWindow.hpp>
-#include <com/sun/star/beans/XPropertySet.hpp>
-#include <com/sun/star/lang/XMultiComponentFactory.hpp>
-#include <com/sun/star/lang/NoSupportException.hpp>
-#include <com/sun/star/awt/XWindow.hpp>
+#include <com/sun/star/presentation/XSlideShowView.hpp>
 #include <com/sun/star/rendering/XCanvas.hpp>
-#include <com/sun/star/lang/XComponent.hpp>
 
 #include "viewmediashape.hxx"
 #include "mediashape.hxx"
-#include "tools.hxx"
-#include "unoview.hxx"
+#include <tools.hxx>
+#include <unoview.hxx>
 
 using namespace ::com::sun::star;
 
@@ -75,7 +75,7 @@ namespace slideshow
                                         const uno::Reference< drawing::XShape >&        rxShape,
                                         const uno::Reference< uno::XComponentContext >& rxContext ) :
             mpViewLayer( rViewLayer ),
-            mpEventHandlerParent(0),
+            mpEventHandlerParent(nullptr),
             maWindowOffset( 0, 0 ),
             maBounds(),
             mxShape( rxShape ),
@@ -89,52 +89,39 @@ namespace slideshow
             ENSURE_OR_THROW( mpViewLayer->getCanvas(), "ViewMediaShape::ViewMediaShape(): Invalid ViewLayer canvas" );
             ENSURE_OR_THROW( mxComponentContext.is(), "ViewMediaShape::ViewMediaShape(): Invalid component context" );
 
-            UnoViewSharedPtr pUnoView (::boost::dynamic_pointer_cast<UnoView>(rViewLayer));
-            if (pUnoView)
+            UnoViewSharedPtr xUnoView(std::dynamic_pointer_cast<UnoView>(rViewLayer));
+            if (xUnoView)
             {
-                mbIsSoundEnabled = pUnoView->isSoundEnabled();
+                mbIsSoundEnabled = xUnoView->isSoundEnabled();
             }
         }
 
-
-
         ViewMediaShape::~ViewMediaShape()
         {
             try
             {
                 endMedia();
             }
-            catch (uno::Exception &)
+            catch (const uno::Exception &e)
             {
-                OSL_FAIL( OUStringToOString(
-                                comphelper::anyToString(
-                                    cppu::getCaughtException() ),
-                                RTL_TEXTENCODING_UTF8 ).getStr() );
+                SAL_WARN("slideshow", e);
             }
         }
 
-
-
-        ViewLayerSharedPtr ViewMediaShape::getViewLayer() const
+        const ViewLayerSharedPtr& ViewMediaShape::getViewLayer() const
         {
             return mpViewLayer;
         }
 
-
-
-        bool ViewMediaShape::startMedia()
+        void ViewMediaShape::startMedia()
         {
             if( !mxPlayer.is() )
                 implInitialize( maBounds );
 
             if (mxPlayer.is())
                 mxPlayer->start();
-
-            return true;
         }
 
-
-
         void ViewMediaShape::endMedia()
         {
             // shutdown player window
@@ -165,24 +152,18 @@ namespace slideshow
             }
         }
 
-
-
         void ViewMediaShape::pauseMedia()
         {
             if (mxPlayer.is())
                 mxPlayer->stop();
         }
 
-
-
         void ViewMediaShape::setMediaTime(double fTime)
         {
             if (mxPlayer.is())
                 mxPlayer->setMediaTime(fTime);
         }
 
-
-
         bool ViewMediaShape::render( const ::basegfx::B2DRectangle& rBounds ) const
         {
 #if !HAVE_FEATURE_AVMEDIA
@@ -205,8 +186,7 @@ namespace slideshow
                 Graphic aGraphic(xGraphic);
                 const BitmapEx aBmp = aGraphic.GetBitmapEx();
 
-                uno::Reference< rendering::XBitmap > xBitmap(vcl::unotools::xBitmapFromBitmapEx(
-                    pCanvas->getUNOCanvas()->getDevice(), aBmp));
+                uno::Reference< rendering::XBitmap > xBitmap(vcl::unotools::xBitmapFromBitmapEx(aBmp));
 
                 rendering::ViewState aViewState;
                 aViewState.AffineTransform = pCanvas->getViewState().AffineTransform;
@@ -218,7 +198,7 @@ namespace slideshow
 
                 const ::basegfx::B2DVector aScale( rBounds.getWidth() / aBmpSize.Width(),
                                                    rBounds.getHeight() / aBmpSize.Height() );
-                const basegfx::B2DHomMatrix aTranslation(basegfx::tools::createScaleTranslateB2DHomMatrix(
+                const basegfx::B2DHomMatrix aTranslation(basegfx::utils::createScaleTranslateB2DHomMatrix(
                     aScale, rBounds.getMinimum()));
                 ::canvas::tools::setRenderStateTransform( aRenderState, aTranslation );
 
@@ -249,7 +229,7 @@ namespace slideshow
             if( xPropSet.is() &&
                 getPropertyValue( xParentWindow,
                                   xPropSet,
-                                  OUString("Window" )) )
+                                  "Window") )
             {
                 const awt::Rectangle aRect( xParentWindow->getPosSize() );
 
@@ -300,7 +280,6 @@ namespace slideshow
         }
 
 
-
         bool ViewMediaShape::implInitialize( const ::basegfx::B2DRectangle& rBounds )
         {
             if( !mxPlayer.is() && mxShape.is() )
@@ -323,14 +302,12 @@ namespace slideshow
                         {
                             OUString aURL;
                             xPropSet->getPropertyValue("MediaMimeType") >>= sMimeType;
-                            if ((xPropSet->getPropertyValue(
-                                  OUString( "PrivateTempFileURL")) >>= aURL)
+                            if ((xPropSet->getPropertyValue("PrivateTempFileURL") >>= aURL)
                                 && !aURL.isEmpty())
                             {
                                 implInitializeMediaPlayer( aURL, sMimeType );
                             }
-                            else if (xPropSet->getPropertyValue(
-                                  OUString( "MediaURL")) >>= aURL)
+                            else if (xPropSet->getPropertyValue("MediaURL") >>= aURL)
                             {
                                 implInitializeMediaPlayer( aURL, sMimeType );
                             }
@@ -353,9 +330,7 @@ namespace slideshow
                     }
                     catch( uno::Exception& )
                     {
-                        OSL_FAIL( OUStringToOString(
-                                        comphelper::anyToString( cppu::getCaughtException() ),
-                                        RTL_TEXTENCODING_UTF8 ).getStr() );
+                        SAL_WARN( "slideshow", comphelper::anyToString( cppu::getCaughtException() ) );
                     }
                 }
             }
@@ -364,7 +339,6 @@ namespace slideshow
         }
 
 
-
         void ViewMediaShape::implSetMediaProperties( const uno::Reference< beans::XPropertySet >& rxProps )
         {
             if( mxPlayer.is() )
@@ -376,19 +350,19 @@ namespace slideshow
                     bool bLoop( false );
                     getPropertyValue( bLoop,
                                       rxProps,
-                                      OUString( "Loop" ));
+                                      "Loop");
                     mxPlayer->setPlaybackLoop( bLoop );
 
                     bool bMute( false );
                     getPropertyValue( bMute,
                                       rxProps,
-                                      OUString( "Mute" ));
+                                      "Mute");
                     mxPlayer->setMute( bMute || !mbIsSoundEnabled);
 
                     sal_Int16 nVolumeDB(0);
                     getPropertyValue( nVolumeDB,
                                       rxProps,
-                                      OUString( "VolumeDB" ));
+                                      "VolumeDB");
                     mxPlayer->setVolumeDB( nVolumeDB );
 
                     if( mxPlayerWindow.is() )
@@ -396,7 +370,7 @@ namespace slideshow
                         media::ZoomLevel eZoom(media::ZoomLevel_FIT_TO_WINDOW);
                         getPropertyValue( eZoom,
                                           rxProps,
-                                          OUString( "Zoom" ));
+                                          "Zoom");
                         mxPlayerWindow->setZoomLevel( eZoom );
                     }
                 }
@@ -404,7 +378,6 @@ namespace slideshow
         }
 
 
-
         void ViewMediaShape::implInitializeMediaPlayer( const OUString& rMediaURL, const OUString& rMimeType )
         {
 #if !HAVE_FEATURE_AVMEDIA
@@ -434,12 +407,11 @@ namespace slideshow
         }
 
 
-
-        bool ViewMediaShape::implInitializePlayerWindow( const ::basegfx::B2DRectangle&   rBounds,
+        void ViewMediaShape::implInitializePlayerWindow( const ::basegfx::B2DRectangle&   rBounds,
                                                                  const uno::Sequence< uno::Any >& rVCLDeviceParams,
-                                                                 const OUString& rMimeType )
+                                                                 const OUString& )
         {
-            OSL_TRACE( "ViewMediaShape::implInitializePlayerWindow" );
+            SAL_INFO("slideshow", "ViewMediaShape::implInitializePlayerWindow" );
             if( !mpMediaWindow.get() && !rBounds.isEmpty() )
             {
                 try
@@ -466,33 +438,21 @@ namespace slideshow
                                                                   rRangePix.getMinY(),
                                                                     rRangePix.getMaxX() - rRangePix.getMinX(),
                                                                     rRangePix.getMaxY() - rRangePix.getMinY() );
-#if !HAVE_FEATURE_GLTF
-                            (void)rMimeType;
-#else
-                            if( avmedia::IsModel(rMimeType) )
-                            {
-                                mpMediaWindow.disposeAndClear();
-                                mpEventHandlerParent.disposeAndClear();
-                                mpEventHandlerParent = VclPtr<vcl::Window>::Create(pWindow, WB_NOBORDER|WB_NODIALOGCONTROL);
-                                mpEventHandlerParent->SetPosSizePixel( Point( aAWTRect.X, aAWTRect.Y ),
-                                                           Size( aAWTRect.Width, aAWTRect.Height ) );
-                                mpEventHandlerParent->EnablePaint(false);
-                                mpEventHandlerParent->Show();
-                                SystemWindowData aWinData = OpenGLContext::generateWinData(mpEventHandlerParent.get(), false);
-                                mpMediaWindow = VclPtr<SystemChildWindow>::Create(mpEventHandlerParent.get(), 0, &aWinData);
-                                mpMediaWindow->SetPosSizePixel( Point( 0, 0 ),
-                                                           Size( aAWTRect.Width, aAWTRect.Height ) );
-                            }
-                            else
-#endif
                             {
                                 mpMediaWindow.disposeAndClear();
                                 mpMediaWindow = VclPtr<SystemChildWindow>::Create( pWindow, WB_CLIPCHILDREN );
+                                UnoViewSharedPtr xUnoView(std::dynamic_pointer_cast<UnoView>(mpViewLayer));
+                                if (xUnoView)
+                                {
+                                    awt::Rectangle aCanvasArea = xUnoView->getUnoView()->getCanvasArea();
+                                    aAWTRect.X += aCanvasArea.X;
+                                    aAWTRect.Y += aCanvasArea.Y;
+                                }
                                 mpMediaWindow->SetPosSizePixel( Point( aAWTRect.X, aAWTRect.Y ),
                                                            Size( aAWTRect.Width, aAWTRect.Height ) );
                             }
                             mpMediaWindow->SetBackground( Color( COL_BLACK ) );
-                            mpMediaWindow->SetParentClipMode( PARENTCLIPMODE_NOCLIP );
+                            mpMediaWindow->SetParentClipMode( ParentClipMode::NoClip );
                             mpMediaWindow->EnableEraseBackground( false );
                             mpMediaWindow->EnablePaint( false );
                             mpMediaWindow->SetForwardKey( true );
@@ -501,12 +461,12 @@ namespace slideshow
 
                             if( mxPlayer.is() )
                             {
-                                aArgs[ 0 ] = uno::makeAny(
-                                    sal::static_int_cast< sal_IntPtr >( mpMediaWindow->GetParentWindowHandle() ) );
+                                aArgs[ 0 ] <<=
+                                    sal::static_int_cast< sal_IntPtr >( mpMediaWindow->GetParentWindowHandle() );
 
                                 aAWTRect.X = aAWTRect.Y = 0;
-                                aArgs[ 1 ] = uno::makeAny( aAWTRect );
-                                aArgs[ 2 ] = uno::makeAny( reinterpret_cast< sal_IntPtr >( mpMediaWindow.get() ) );
+                                aArgs[ 1 ] <<= aAWTRect;
+                                aArgs[ 2 ] <<= reinterpret_cast< sal_IntPtr >( mpMediaWindow.get() );
 
                                 mxPlayerWindow.set( mxPlayer->createPlayerWindow( aArgs ) );
 
@@ -533,13 +493,9 @@ namespace slideshow
                 }
                 catch( uno::Exception& )
                 {
-                    OSL_FAIL( OUStringToOString(
-                                    comphelper::anyToString( cppu::getCaughtException() ),
-                                    RTL_TEXTENCODING_UTF8 ).getStr() );
+                    SAL_WARN( "slideshow", comphelper::anyToString( cppu::getCaughtException() ) );
                 }
             }
-
-            return mxPlayerWindow.is();
         }
     }
 }
