@@ -17,18 +17,17 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include <canvas/debug.hxx>
 #include <tools/diagnose_ex.h>
 #include <canvas/canvastools.hxx>
 
-#include "eventqueue.hxx"
-#include "eventmultiplexer.hxx"
-#include "slideview.hxx"
-#include "delayevent.hxx"
-#include "unoview.hxx"
+#include <eventqueue.hxx>
+#include <eventmultiplexer.hxx>
+#include <slideview.hxx>
+#include <delayevent.hxx>
+#include <unoview.hxx>
 
 #include <cppuhelper/basemutex.hxx>
-#include <cppuhelper/compbase2.hxx>
+#include <cppuhelper/compbase.hxx>
 #include <cppuhelper/implementationentry.hxx>
 #include <cppuhelper/interfacecontainer.h>
 #include <comphelper/make_shared_from_uno.hxx>
@@ -46,16 +45,14 @@
 #include <basegfx/matrix/b2dhommatrix.hxx>
 #include <basegfx/polygon/b2dpolygontools.hxx>
 #include <basegfx/polygon/b2dpolypolygontools.hxx>
-#include <basegfx/tools/canvastools.hxx>
+#include <basegfx/utils/canvastools.hxx>
 #include <basegfx/polygon/b2dpolygonclipper.hxx>
 #include <basegfx/polygon/b2dpolypolygoncutter.hxx>
 
 #include <com/sun/star/presentation/XSlideShow.hpp>
+#include <com/sun/star/rendering/CompositeOperation.hpp>
 
-#include <boost/noncopyable.hpp>
-#include <boost/bind.hpp>
-#include <boost/weak_ptr.hpp>
-
+#include <memory>
 #include <vector>
 #include <iterator>
 #include <algorithm>
@@ -86,7 +83,7 @@ struct SpriteEntry
         return mnPriority < rRHS.mnPriority;
     }
 
-    boost::weak_ptr< cppcanvas::CustomSprite > mpSprite;
+    std::weak_ptr< cppcanvas::CustomSprite > mpSprite;
     double                                     mnPriority;
 };
 
@@ -120,11 +117,11 @@ basegfx::B2DPolyPolygon createClipPolygon( const basegfx::B2DPolyPolygon&    rCl
 
     if(rClip.count())
     {
-        return basegfx::tools::clipPolyPolygonOnRange(rClip, aClipRange, true, false);
+        return basegfx::utils::clipPolyPolygonOnRange(rClip, aClipRange, true, false);
     }
     else
     {
-        return basegfx::B2DPolyPolygon(basegfx::tools::createPolygonFromRect(aClipRange));
+        return basegfx::B2DPolyPolygon(basegfx::utils::createPolygonFromRect(aClipRange));
     }
 }
 
@@ -142,14 +139,14 @@ basegfx::B2DPolyPolygon prepareClip( const basegfx::B2DPolyPolygon& rClip )
     // TODO(P2): unnecessary, once XCanvas is correctly handling this
     // AW: Should be no longer necessary; tools are now bezier-safe
     if( aClip.areControlPointsUsed() )
-        aClip = basegfx::tools::adaptiveSubdivideByAngle( aClip );
+        aClip = basegfx::utils::adaptiveSubdivideByAngle( aClip );
 
     // normalize polygon, preparation for clipping
     // in updateCanvas()
-    aClip = basegfx::tools::correctOrientations(aClip);
-    aClip = basegfx::tools::solveCrossovers(aClip);
-    aClip = basegfx::tools::stripNeutralPolygons(aClip);
-    aClip = basegfx::tools::stripDispensablePolygons(aClip, false);
+    aClip = basegfx::utils::correctOrientations(aClip);
+    aClip = basegfx::utils::solveCrossovers(aClip);
+    aClip = basegfx::utils::stripNeutralPolygons(aClip);
+    aClip = basegfx::utils::stripDispensablePolygons(aClip);
 
     return aClip;
 }
@@ -176,7 +173,7 @@ void clearRect( ::cppcanvas::CanvasSharedPtr const& pCanvas,
     // depending on the slide content a one pixel wide
     // line will show to the bottom and the right.
     const ::basegfx::B2DPolygon aPoly(
-        ::basegfx::tools::createPolygonFromRect(
+        ::basegfx::utils::createPolygonFromRect(
             basegfx::B2DRange(rArea)));
 
     ::cppcanvas::PolyPolygonSharedPtr pPolyPoly(
@@ -184,12 +181,12 @@ void clearRect( ::cppcanvas::CanvasSharedPtr const& pCanvas,
 
     if( pPolyPoly )
     {
-        pPolyPoly->setCompositeOp( cppcanvas::CanvasGraphic::SOURCE );
+        pPolyPoly->setCompositeOp( css::rendering::CompositeOperation::SOURCE );
         pPolyPoly->setRGBAFillColor( 0xFFFFFF00U );
         pPolyPoly->draw();
     }
 
-#if OSL_DEBUG_LEVEL >= 2 && defined(DBG_UTIL)
+#if defined(DBG_UTIL)
     ::cppcanvas::CanvasSharedPtr pCliplessCanvas( pCanvas->clone() );
     pCliplessCanvas->setClip();
 
@@ -238,8 +235,6 @@ basegfx::B2IRange getLayerBoundsPixel( basegfx::B2DRange const&     rLayerBounds
 }
 
 
-
-
 /** Container class for sprites issued by a ViewLayer
 
     This class handles the sprite prioritization issues, that are
@@ -285,23 +280,19 @@ class LayerSpriteContainer
         SpriteVector aValidSprites;
 
         // check all sprites for validity and set new priority
-        SpriteVector::iterator       aCurrSprite( maSprites.begin() );
-        const SpriteVector::iterator aEnd( maSprites.end() );
-        while( aCurrSprite != aEnd )
+        for( const auto& rSprite : maSprites )
         {
-            cppcanvas::CustomSpriteSharedPtr pCurrSprite( aCurrSprite->mpSprite.lock() );
+            cppcanvas::CustomSpriteSharedPtr pCurrSprite( rSprite.mpSprite.lock() );
 
             if( pCurrSprite )
             {
                 // only copy still valid sprites over to the refreshed
                 // sprite vector.
-                aValidSprites.push_back( *aCurrSprite );
+                aValidSprites.push_back( rSprite );
 
                 pCurrSprite->setPriority(
                     getSpritePriority( aValidSprites.size()-1 ));
             }
-
-            ++aCurrSprite;
         }
 
         // replace sprite list with pruned one
@@ -315,7 +306,7 @@ public:
     {
     }
 
-    basegfx::B1DRange getLayerPriority() const
+    const basegfx::B1DRange& getLayerPriority() const
     {
         return maLayerPrioRange;
     }
@@ -373,9 +364,6 @@ public:
 };
 
 
-
-
-
 /** This class provides layers for a slide view
 
     Layers are used to render animations with the correct z order -
@@ -388,8 +376,7 @@ public:
     the layer priority changes, the sprites change z order together
     with their parent.
  */
-class SlideViewLayer : public ViewLayer,
-                       private boost::noncopyable
+class SlideViewLayer : public ViewLayer
 {
     /// Smart container for all sprites issued by this layer
     mutable LayerSpriteContainer             maSpriteContainer;
@@ -453,6 +440,9 @@ public:
     {
     }
 
+    SlideViewLayer(const SlideViewLayer&) = delete;
+    SlideViewLayer& operator=(const SlideViewLayer&) = delete;
+
     void updateView( const basegfx::B2DHomMatrix& rMatrix,
                      const basegfx::B2DSize&      rUserSize )
     {
@@ -476,7 +466,7 @@ public:
         }
     }
 
-    virtual ::com::sun::star::geometry::IntegerSize2D getTranslationOffset() const SAL_OVERRIDE
+    virtual css::geometry::IntegerSize2D getTranslationOffset() const override
     {
         basegfx::B2DRectangle aTmpRect;
         canvas::tools::calcTransformedRectBounds( aTmpRect,
@@ -500,7 +490,7 @@ private:
 
     virtual cppcanvas::CustomSpriteSharedPtr createSprite(
         const ::basegfx::B2DSize& rSpriteSizePixel,
-        double                    nPriority ) const SAL_OVERRIDE
+        double                    nPriority ) const override
     {
         cppcanvas::CustomSpriteSharedPtr pSprite(
             mpSpriteCanvas->createCustomSprite( rSpriteSizePixel ) );
@@ -511,7 +501,7 @@ private:
         return pSprite;
     }
 
-    virtual void setPriority( const basegfx::B1DRange& rRange ) SAL_OVERRIDE
+    virtual void setPriority( const basegfx::B1DRange& rRange ) override
     {
         OSL_ENSURE( !rRange.isEmpty() &&
                     rRange.getMinimum() >= 1.0,
@@ -524,7 +514,7 @@ private:
             mpSprite->setPriority( rRange.getMinimum() );
     }
 
-    virtual basegfx::B2DHomMatrix getTransformation() const SAL_OVERRIDE
+    virtual basegfx::B2DHomMatrix getTransformation() const override
     {
         // Offset given transformation by left, top border of given
         // range (after transformation through given transformation)
@@ -546,12 +536,12 @@ private:
         return aMatrix;
     }
 
-    virtual basegfx::B2DHomMatrix getSpriteTransformation() const SAL_OVERRIDE
+    virtual basegfx::B2DHomMatrix getSpriteTransformation() const override
     {
         return maTransformation;
     }
 
-    virtual void clear() const SAL_OVERRIDE
+    virtual void clear() const override
     {
         // grab canvas - that also lazy-initializes maLayerBoundsPixel
         cppcanvas::CanvasSharedPtr pCanvas=getCanvas()->clone();
@@ -562,7 +552,7 @@ private:
                   basegfx::B2IRange(0,0,rSpriteSize.getX(),rSpriteSize.getY()));
     }
 
-    virtual void clearAll() const SAL_OVERRIDE
+    virtual void clearAll() const override
     {
         // grab canvas - that also lazy-initializes maLayerBoundsPixel
         ::cppcanvas::CanvasSharedPtr pCanvas( getCanvas()->clone() );
@@ -576,12 +566,12 @@ private:
                   basegfx::B2IRange(0,0,rSpriteSize.getX(),rSpriteSize.getY()));
     }
 
-    virtual bool isOnView(boost::shared_ptr<View> const& rView) const SAL_OVERRIDE
+    virtual bool isOnView(std::shared_ptr<View> const& rView) const override
     {
         return rView.get() == mpParentView;
     }
 
-    virtual cppcanvas::CanvasSharedPtr getCanvas() const SAL_OVERRIDE
+    virtual cppcanvas::CanvasSharedPtr getCanvas() const override
     {
         if( !mpOutputCanvas )
         {
@@ -606,7 +596,7 @@ private:
                 mpSprite->setPriority(
                     maSpriteContainer.getLayerPriority().getMinimum() );
 
-#if OSL_DEBUG_LEVEL >= 2 && defined(DBG_UTIL)
+#if defined(DBG_UTIL)
                 mpSprite->movePixel(
                     basegfx::B2DPoint(maLayerBoundsPixel.getMinimum()) +
                     basegfx::B2DPoint(10,10) );
@@ -640,7 +630,7 @@ private:
         return mpOutputCanvas;
     }
 
-    virtual void setClip( const basegfx::B2DPolyPolygon& rClip ) SAL_OVERRIDE
+    virtual void setClip( const basegfx::B2DPolyPolygon& rClip ) override
     {
         basegfx::B2DPolyPolygon aNewClip = prepareClip( rClip );
 
@@ -656,7 +646,7 @@ private:
         }
     }
 
-    virtual bool resize( const ::basegfx::B2DRange& rArea ) SAL_OVERRIDE
+    virtual bool resize( const ::basegfx::B2DRange& rArea ) override
     {
         const bool bRet( maLayerBounds != rArea );
         maLayerBounds = rArea;
@@ -668,11 +658,9 @@ private:
 };
 
 
-
-
-typedef cppu::WeakComponentImplHelper2<
-    ::com::sun::star::util::XModifyListener,
-      ::com::sun::star::awt::XPaintListener> SlideViewBase;
+typedef cppu::WeakComponentImplHelper<
+      css::util::XModifyListener,
+      css::awt::XPaintListener> SlideViewBase;
 
 /** SlideView class
 
@@ -691,49 +679,46 @@ public:
 
 private:
     // View:
-    virtual ViewLayerSharedPtr createViewLayer( const basegfx::B2DRange& rLayerBounds ) const SAL_OVERRIDE;
-    virtual bool updateScreen() const SAL_OVERRIDE;
-    virtual bool paintScreen() const SAL_OVERRIDE;
-    virtual void setViewSize( const ::basegfx::B2DSize& ) SAL_OVERRIDE;
-    virtual void setCursorShape( sal_Int16 nPointerShape ) SAL_OVERRIDE;
+    virtual ViewLayerSharedPtr createViewLayer( const basegfx::B2DRange& rLayerBounds ) const override;
+    virtual bool updateScreen() const override;
+    virtual bool paintScreen() const override;
+    virtual void setViewSize( const ::basegfx::B2DSize& ) override;
+    virtual void setCursorShape( sal_Int16 nPointerShape ) override;
 
     // ViewLayer interface
-    virtual bool isOnView(boost::shared_ptr<View> const& rView) const SAL_OVERRIDE;
-    virtual void clear() const SAL_OVERRIDE;
-    virtual void clearAll() const SAL_OVERRIDE;
-    virtual cppcanvas::CanvasSharedPtr getCanvas() const SAL_OVERRIDE;
+    virtual bool isOnView(std::shared_ptr<View> const& rView) const override;
+    virtual void clear() const override;
+    virtual void clearAll() const override;
+    virtual cppcanvas::CanvasSharedPtr getCanvas() const override;
     virtual cppcanvas::CustomSpriteSharedPtr createSprite( const ::basegfx::B2DSize& rSpriteSizePixel,
-                                                           double                    nPriority ) const SAL_OVERRIDE;
-    virtual void setPriority( const basegfx::B1DRange& rRange ) SAL_OVERRIDE;
-    virtual geometry::IntegerSize2D getTranslationOffset() const SAL_OVERRIDE;
-    virtual ::basegfx::B2DHomMatrix getTransformation() const SAL_OVERRIDE;
-    virtual basegfx::B2DHomMatrix getSpriteTransformation() const SAL_OVERRIDE;
-    virtual void setClip( const ::basegfx::B2DPolyPolygon& rClip ) SAL_OVERRIDE;
-    virtual bool resize( const ::basegfx::B2DRange& rArea ) SAL_OVERRIDE;
+                                                           double                    nPriority ) const override;
+    virtual void setPriority( const basegfx::B1DRange& rRange ) override;
+    virtual geometry::IntegerSize2D getTranslationOffset() const override;
+    virtual ::basegfx::B2DHomMatrix getTransformation() const override;
+    virtual basegfx::B2DHomMatrix getSpriteTransformation() const override;
+    virtual void setClip( const ::basegfx::B2DPolyPolygon& rClip ) override;
+    virtual bool resize( const ::basegfx::B2DRange& rArea ) override;
 
     // UnoView:
-    virtual void _dispose() SAL_OVERRIDE;
-    virtual uno::Reference<presentation::XSlideShowView> getUnoView()const SAL_OVERRIDE;
-    virtual void setIsSoundEnabled (const bool bValue) SAL_OVERRIDE;
-    virtual bool isSoundEnabled() const SAL_OVERRIDE;
+    virtual void _dispose() override;
+    virtual uno::Reference<presentation::XSlideShowView> getUnoView()const override;
+    virtual void setIsSoundEnabled (const bool bValue) override;
+    virtual bool isSoundEnabled() const override;
 
     // XEventListener:
-    virtual void SAL_CALL disposing( lang::EventObject const& evt )
-        throw (uno::RuntimeException, std::exception) SAL_OVERRIDE;
+    virtual void SAL_CALL disposing( lang::EventObject const& evt ) override;
     // XModifyListener:
-    virtual void SAL_CALL modified( const lang::EventObject& aEvent )
-        throw (uno::RuntimeException, std::exception) SAL_OVERRIDE;
+    virtual void SAL_CALL modified( const lang::EventObject& aEvent ) override;
     // XPaintListener:
-    virtual void SAL_CALL windowPaint( const awt::PaintEvent& e )
-        throw (uno::RuntimeException, std::exception) SAL_OVERRIDE;
+    virtual void SAL_CALL windowPaint( const awt::PaintEvent& e ) override;
 
     // WeakComponentImplHelperBase:
-    virtual void SAL_CALL disposing() SAL_OVERRIDE;
+    virtual void SAL_CALL disposing() override;
 
     void updateClip();
 
 private:
-    typedef std::vector< boost::weak_ptr<SlideViewLayer> > ViewLayerVector;
+    typedef std::vector< std::weak_ptr<SlideViewLayer> > ViewLayerVector;
 
     /// Prune viewlayers from deceased ones, optionally update them
     void pruneLayers( bool bWithViewLayerUpdate=false ) const;
@@ -839,14 +824,14 @@ ViewLayerSharedPtr SlideView::createViewLayer( const basegfx::B2DRange& rLayerBo
     if( nNumLayers > LAYER_ULLAGE )
         pruneLayers();
 
-    boost::shared_ptr<SlideViewLayer> pViewLayer( new SlideViewLayer(mpCanvas,
+    std::shared_ptr<SlideViewLayer> xViewLayer( new SlideViewLayer(mpCanvas,
                                                                      getTransformation(),
                                                                      rLayerBounds,
                                                                      maUserSize,
                                                                      this) );
-    maViewLayers.push_back( pViewLayer );
+    maViewLayers.push_back(xViewLayer);
 
-    return pViewLayer;
+    return xViewLayer;
 }
 
 bool SlideView::updateScreen() const
@@ -921,7 +906,7 @@ void SlideView::setCursorShape( sal_Int16 nPointerShape )
         mxView->setMouseCursor( nPointerShape );
 }
 
-bool SlideView::isOnView(boost::shared_ptr<View> const& rView) const
+bool SlideView::isOnView(std::shared_ptr<View> const& rView) const
 {
     return rView.get() == this;
 }
@@ -1028,10 +1013,7 @@ void SlideView::_dispose()
 
 // XEventListener
 void SlideView::disposing( lang::EventObject const& evt )
-    throw (uno::RuntimeException, std::exception)
 {
-    (void)evt;
-
     // no deregistration necessary anymore, XView has left:
     osl::MutexGuard const guard( m_aMutex );
 
@@ -1044,9 +1026,32 @@ void SlideView::disposing( lang::EventObject const& evt )
     dispose();
 }
 
+// silly wrapper to check that event handlers don't touch dead SlideView
+struct WeakRefWrapper
+{
+    SlideView & m_rObj;
+    uno::WeakReference<uno::XInterface> const m_wObj;
+    std::function<void (SlideView&)> const m_func;
+
+    WeakRefWrapper(SlideView & rObj, std::function<void (SlideView&)> const& func)
+        : m_rObj(rObj)
+        , m_wObj(static_cast<::cppu::OWeakObject*>(&rObj))
+        , m_func(func)
+    {
+    }
+
+    void operator()()
+    {
+        uno::Reference<uno::XInterface> const xObj(m_wObj);
+        if (xObj.is())
+        {
+            m_func(m_rObj);
+        }
+    }
+};
+
 // XModifyListener
 void SlideView::modified( const lang::EventObject& /*aEvent*/ )
-    throw (uno::RuntimeException, std::exception)
 {
     osl::MutexGuard const guard( m_aMutex );
 
@@ -1087,16 +1092,13 @@ void SlideView::modified( const lang::EventObject& /*aEvent*/ )
     // notify view change. Don't call EventMultiplexer directly, this
     // might not be the main thread!
     mrEventQueue.addEvent(
-        makeEvent( boost::bind( (bool (EventMultiplexer::*)(
-                                     const uno::Reference<presentation::XSlideShowView>&))
-                                &EventMultiplexer::notifyViewChanged,
-                                boost::ref(mrEventMultiplexer), mxView ),
+        makeEvent( WeakRefWrapper(*this,
+            [] (SlideView & rThis) { rThis.mrEventMultiplexer.notifyViewChanged(rThis.mxView); }),
                    "EventMultiplexer::notifyViewChanged"));
 }
 
 // XPaintListener
 void SlideView::windowPaint( const awt::PaintEvent& /*e*/ )
-    throw (uno::RuntimeException, std::exception)
 {
     osl::MutexGuard aGuard( m_aMutex );
 
@@ -1105,8 +1107,8 @@ void SlideView::windowPaint( const awt::PaintEvent& /*e*/ )
     // notify view clobbering. Don't call EventMultiplexer directly,
     // this might not be the main thread!
     mrEventQueue.addEvent(
-        makeEvent( boost::bind( &EventMultiplexer::notifyViewClobbered,
-                                boost::ref(mrEventMultiplexer), mxView ),
+        makeEvent( WeakRefWrapper(*this,
+            [] (SlideView & rThis) { rThis.mrEventMultiplexer.notifyViewClobbered(rThis.mxView); }),
                    "EventMultiplexer::notifyViewClobbered") );
 }
 
@@ -1142,7 +1144,7 @@ void SlideView::updateClip()
                            mpCanvas,
                            maUserSize ));
 
-    pruneLayers( false );
+    pruneLayers();
 }
 
 void SlideView::pruneLayers( bool bWithViewLayerUpdate ) const
@@ -1153,22 +1155,18 @@ void SlideView::pruneLayers( bool bWithViewLayerUpdate ) const
         getTransformation() );
 
     // check all layers for validity, and retain only the live ones
-    ViewLayerVector::const_iterator       aCurr( maViewLayers.begin() );
-    const ViewLayerVector::const_iterator aEnd( maViewLayers.end() );
-    while( aCurr != aEnd )
+    for( const auto& rView : maViewLayers )
     {
-        boost::shared_ptr< SlideViewLayer > pCurrLayer( aCurr->lock() );
+        std::shared_ptr< SlideViewLayer > xCurrLayer( rView.lock() );
 
-        if( pCurrLayer )
+        if ( xCurrLayer )
         {
-            aValidLayers.push_back( pCurrLayer );
+            aValidLayers.push_back( xCurrLayer );
 
             if( bWithViewLayerUpdate )
-                pCurrLayer->updateView( rCurrTransform,
+                xCurrLayer->updateView( rCurrTransform,
                                         maUserSize );
         }
-
-        ++aCurr;
     }
 
     // replace layer list with pruned one
@@ -1181,7 +1179,7 @@ UnoViewSharedPtr createSlideView( uno::Reference< presentation::XSlideShowView>
                                   EventQueue&                                          rEventQueue,
                                   EventMultiplexer&                                    rEventMultiplexer )
 {
-    boost::shared_ptr<SlideView> const that(
+    std::shared_ptr<SlideView> const that(
         comphelper::make_shared_from_UNO(
             new SlideView(xView,
                           rEventQueue,
