@@ -17,72 +17,43 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include <tools/globname.hxx>
-#include <vcl/status.hxx>
-#include <sfx2/msg.hxx>
+#include <sal/config.h>
+
+#include <o3tl/make_unique.hxx>
 #include <sfx2/objface.hxx>
 #include <svl/whiter.hxx>
-#include <sfx2/request.hxx>
-#include <sfx2/sfx.hrc>
 #include <sfx2/viewsh.hxx>
-#include <vcl/wrkwin.hxx>
 #include <svx/svxids.hrc>
-#include <vcl/msgbox.hxx>
+#include <unotools/resmgr.hxx>
 #include <vcl/virdev.hxx>
 #include <unotools/syslocale.hxx>
-#include "smmod.hxx"
-#include "symbol.hxx"
+#include <smmod.hxx>
 #include "cfgitem.hxx"
-#include "dialog.hxx"
-#include "edit.hxx"
-#include "view.hxx"
-#include "starmath.hrc"
-#include "svx/modctrl.hxx"
+#include <dialog.hxx>
+#include <edit.hxx>
+#include <view.hxx>
+#include <smmod.hrc>
+#include <starmath.hrc>
+#include <svx/modctrl.hxx>
 
 
 #define SmModule
-#include "smslots.hxx"
+#include <smslots.hxx>
 
-#include <svx/xmlsecctrl.hxx>
-
-
-
-SmResId::SmResId( sal_uInt16 nId )
-    : ResId(nId, *SM_MOD()->GetResMgr())
+OUString SmResId(const char* pId)
 {
+    return Translate::get(pId, SM_MOD()->GetResLocale());
 }
 
-
-
-SmLocalizedSymbolData::SmLocalizedSymbolData() :
-    Resource( SmResId(RID_LOCALIZED_NAMES) ),
-    aUiSymbolNamesAry       ( SmResId(RID_UI_SYMBOL_NAMES) ),
-    aExportSymbolNamesAry   ( SmResId(RID_EXPORT_SYMBOL_NAMES) ),
-    aUiSymbolSetNamesAry    ( SmResId(RID_UI_SYMBOLSET_NAMES) ),
-    aExportSymbolSetNamesAry( SmResId(RID_EXPORT_SYMBOLSET_NAMES) )
-{
-    FreeResource();
-}
-
-
-SmLocalizedSymbolData::~SmLocalizedSymbolData()
-{
-}
-
-
 const OUString SmLocalizedSymbolData::GetUiSymbolName( const OUString &rExportName )
 {
     OUString aRes;
 
-    const SmLocalizedSymbolData &rData = SM_MOD()->GetLocSymbolData();
-    const ResStringArray &rUiNames = rData.GetUiSymbolNamesArray();
-    const ResStringArray &rExportNames = rData.GetExportSymbolNamesArray();
-    sal_uInt32 nCount = rExportNames.Count();
-    for (sal_uInt32 i = 0;  i < nCount  &&  aRes.isEmpty();  ++i)
+    for (size_t i = 0; i < SAL_N_ELEMENTS(RID_UI_SYMBOL_NAMES); ++i)
     {
-        if (rExportNames.GetString(i).equals(rExportName))
+        if (rExportName.equalsAscii(strchr(RID_UI_SYMBOL_NAMES[i], '\004') + 1))
         {
-            aRes = rUiNames.GetString(i);
+            aRes = SmResId(RID_UI_SYMBOL_NAMES[i]);
             break;
         }
     }
@@ -90,20 +61,16 @@ const OUString SmLocalizedSymbolData::GetUiSymbolName( const OUString &rExportNa
     return aRes;
 }
 
-
 const OUString SmLocalizedSymbolData::GetExportSymbolName( const OUString &rUiName )
 {
     OUString aRes;
 
-    const SmLocalizedSymbolData &rData = SM_MOD()->GetLocSymbolData();
-    const ResStringArray &rUiNames = rData.GetUiSymbolNamesArray();
-    const ResStringArray &rExportNames = rData.GetExportSymbolNamesArray();
-    sal_uInt32 nCount = rUiNames.Count();
-    for (sal_uInt32 i = 0;  i < nCount  &&  aRes.isEmpty();  ++i)
+    for (size_t i = 0; i < SAL_N_ELEMENTS(RID_UI_SYMBOL_NAMES); ++i)
     {
-        if (rUiNames.GetString(i).equals(rUiName))
+        if (rUiName == SmResId(RID_UI_SYMBOL_NAMES[i]))
         {
-            aRes = rExportNames.GetString(i);
+            const char *pKey = strchr(RID_UI_SYMBOL_NAMES[i], '\004') + 1;
+            aRes = OUString(pKey, strlen(pKey), RTL_TEXTENCODING_UTF8);
             break;
         }
     }
@@ -111,20 +78,15 @@ const OUString SmLocalizedSymbolData::GetExportSymbolName( const OUString &rUiNa
     return aRes;
 }
 
-
 const OUString SmLocalizedSymbolData::GetUiSymbolSetName( const OUString &rExportName )
 {
     OUString aRes;
 
-    const SmLocalizedSymbolData &rData = SM_MOD()->GetLocSymbolData();
-    const ResStringArray &rUiNames = rData.GetUiSymbolSetNamesArray();
-    const ResStringArray &rExportNames = rData.GetExportSymbolSetNamesArray();
-    sal_uInt32 nCount = rExportNames.Count();
-    for (sal_uInt32 i = 0;  i < nCount  &&  aRes.isEmpty();  ++i)
+    for (size_t i = 0; i < SAL_N_ELEMENTS(RID_UI_SYMBOLSET_NAMES); ++i)
     {
-        if (rExportNames.GetString(i).equals(rExportName))
+        if (rExportName.equalsAscii(strchr(RID_UI_SYMBOLSET_NAMES[i], '\004') + 1))
         {
-            aRes = rUiNames.GetString(i);
+            aRes = SmResId(RID_UI_SYMBOLSET_NAMES[i]);
             break;
         }
     }
@@ -132,20 +94,16 @@ const OUString SmLocalizedSymbolData::GetUiSymbolSetName( const OUString &rExpor
     return aRes;
 }
 
-
 const OUString SmLocalizedSymbolData::GetExportSymbolSetName( const OUString &rUiName )
 {
     OUString aRes;
 
-    const SmLocalizedSymbolData &rData = SM_MOD()->GetLocSymbolData();
-    const ResStringArray &rUiNames = rData.GetUiSymbolSetNamesArray();
-    const ResStringArray &rExportNames = rData.GetExportSymbolSetNamesArray();
-    sal_uInt32 nCount = rUiNames.Count();
-    for (sal_uInt32 i = 0;  i < nCount  &&  aRes.isEmpty();  ++i)
+    for (size_t i = 0; i < SAL_N_ELEMENTS(RID_UI_SYMBOLSET_NAMES); ++i)
     {
-        if (rUiNames.GetString(i).equals(rUiName))
+        if (rUiName == SmResId(RID_UI_SYMBOLSET_NAMES[i]))
         {
-            aRes = rExportNames.GetString(i);
+            const char *pKey = strchr(RID_UI_SYMBOLSET_NAMES[i], '\004') + 1;
+            aRes = OUString(pKey, strlen(pKey), RTL_TEXTENCODING_UTF8);
             break;
         }
     }
@@ -157,11 +115,11 @@ SFX_IMPL_INTERFACE(SmModule, SfxModule)
 
 void SmModule::InitInterface_Impl()
 {
-    GetStaticInterface()->RegisterStatusBar(SmResId(RID_STATUSBAR));
+    GetStaticInterface()->RegisterStatusBar(StatusBarId::MathStatusBar);
 }
 
-SmModule::SmModule(SfxObjectFactory* pObjFact) :
-    SfxModule(ResMgr::CreateResMgr("sm"), false, pObjFact, nullptr)
+SmModule::SmModule(SfxObjectFactory* pObjFact)
+    : SfxModule(Translate::Create("sm"), {pObjFact})
 {
     SetName("StarMath");
 
@@ -181,7 +139,7 @@ void SmModule::ApplyColorConfigValues( const svtools::ColorConfig &rColorCfg )
     SfxViewShell* pViewShell = SfxViewShell::GetFirst();
     while (pViewShell)
     {
-        if ((dynamic_cast<const SmViewShell *>(pViewShell) != nullptr))
+        if (dynamic_cast<const SmViewShell *>(pViewShell) != nullptr)
         {
             SmViewShell *pSmView = static_cast<SmViewShell *>(pViewShell);
             pSmView->GetGraphicWindow().ApplyColorConfigValues( rColorCfg );
@@ -204,7 +162,7 @@ svtools::ColorConfig & SmModule::GetColorConfig()
     return *mpColorConfig;
 }
 
-void SmModule::ConfigurationChanged( utl::ConfigurationBroadcaster*, sal_uInt32 )
+void SmModule::ConfigurationChanged( utl::ConfigurationBroadcaster*, ConfigurationHints )
 {
     ApplyColorConfigValues(*mpColorConfig);
 }
@@ -221,13 +179,6 @@ SmSymbolManager & SmModule::GetSymbolManager()
     return GetConfig()->GetSymbolManager();
 }
 
-SmLocalizedSymbolData & SmModule::GetLocSymbolData()
-{
-    if (!mpLocSymbolData)
-        mpLocSymbolData.reset(new SmLocalizedSymbolData);
-    return *mpLocSymbolData;
-}
-
 const SvtSysLocale& SmModule::GetSysLocale()
 {
     if( !mpSysLocale )
@@ -240,7 +191,7 @@ VirtualDevice &SmModule::GetDefaultVirtualDev()
     if (!mpVirtualDev)
     {
         mpVirtualDev.reset( VclPtr<VirtualDevice>::Create() );
-        mpVirtualDev->SetReferenceDevice( VirtualDevice::REFDEV_MODE_MSO1 );
+        mpVirtualDev->SetReferenceDevice( VirtualDevice::RefDevMode::MSO1 );
     }
     return *mpVirtualDev;
 }
@@ -258,27 +209,23 @@ void SmModule::GetState(SfxItemSet &rSet)
         }
 }
 
-SfxItemSet*  SmModule::CreateItemSet( sal_uInt16 nId )
+std::unique_ptr<SfxItemSet> SmModule::CreateItemSet( sal_uInt16 nId )
 {
-    SfxItemSet*  pRet = nullptr;
+    std::unique_ptr<SfxItemSet> pRet;
     if(nId == SID_SM_EDITOPTIONS)
     {
-        pRet = new SfxItemSet(GetPool(),
-                             //TP_SMPRINT
-                             SID_PRINTSIZE,         SID_PRINTSIZE,
-                             SID_PRINTZOOM,         SID_PRINTZOOM,
-                             SID_PRINTTITLE,        SID_PRINTTITLE,
-                             SID_PRINTTEXT,         SID_PRINTTEXT,
-                             SID_PRINTFRAME,        SID_PRINTFRAME,
-                             SID_NO_RIGHT_SPACES,   SID_NO_RIGHT_SPACES,
-                             SID_SAVE_ONLY_USED_SYMBOLS, SID_SAVE_ONLY_USED_SYMBOLS,
-                             SID_AUTO_CLOSE_BRACKETS,    SID_AUTO_CLOSE_BRACKETS,
-                             0 );
+        pRet = o3tl::make_unique<SfxItemSet>(
+            GetPool(),
+            svl::Items< //TP_SMPRINT
+                SID_PRINTTITLE, SID_PRINTZOOM,
+                SID_NO_RIGHT_SPACES, SID_SAVE_ONLY_USED_SYMBOLS,
+                SID_AUTO_CLOSE_BRACKETS, SID_AUTO_CLOSE_BRACKETS>{});
 
             GetConfig()->ConfigToItemSet(*pRet);
     }
     return pRet;
 }
+
 void SmModule::ApplyItemSet( sal_uInt16 nId, const SfxItemSet& rSet )
 {
     if(nId == SID_SM_EDITOPTIONS)
@@ -286,6 +233,7 @@ void SmModule::ApplyItemSet( sal_uInt16 nId, const SfxItemSet& rSet )
         GetConfig()->ItemSetToConfig(rSet);
     }
 }
+
 VclPtr<SfxTabPage> SmModule::CreateTabPage( sal_uInt16 nId, vcl::Window* pParent, const SfxItemSet& rSet )
 {
     VclPtr<SfxTabPage> pRet;
