@@ -43,18 +43,12 @@ void ButtonFrame::Draw( OutputDevice& rDev )
     rDev.SetFillColor( aColFace );
     rDev.DrawRect( aRect );
 
-    if( rDev.GetOutDevType() == OUTDEV_WINDOW )
+    if( rDev.GetOutDevType() != OUTDEV_WINDOW )
     {
-        vcl::Window *pWin = static_cast<vcl::Window*>( &rDev );
-        if( bPressed )
-            pWin->DrawSelectionBackground( aRect, 0, true, false, false );
-    }
-    else
-    {
-        rDev.SetLineColor( bPressed ? aColShadow : aColLight );
+        rDev.SetLineColor( aColLight );
         rDev.DrawLine( aRect.TopLeft(), Point( aRect.Right(), aRect.Top() ) );
         rDev.DrawLine( aRect.TopLeft(), Point( aRect.Left(), aRect.Bottom() - 1 ) );
-        rDev.SetLineColor( bPressed ? aColLight : aColShadow );
+        rDev.SetLineColor( aColShadow );
         rDev.DrawLine( aRect.BottomRight(), Point( aRect.Right(), aRect.Top() ) );
         rDev.DrawLine( aRect.BottomRight(), Point( aRect.Left(), aRect.Bottom() ) );
     }
@@ -89,23 +83,14 @@ void ButtonFrame::Draw( OutputDevice& rDev )
             rDev.SetTextColor(aOldColor);
     }
 
-    if ( bCurs )
-    {
-        rDev.SetLineColor( Color( COL_BLACK ) );
-        rDev.SetFillColor();
-        rDev.DrawRect( Rectangle(
-            Point( aRect.Left(), aRect.Top() ), Point( aRect.Right(), aRect.Bottom() ) ) );
-    }
-
     rDev.SetLineColor( aOldLineColor );
     rDev.SetFillColor( aOldFillColor );
 }
 
-BrowserColumn::BrowserColumn( sal_uInt16 nItemId, const class Image &rImage,
+BrowserColumn::BrowserColumn( sal_uInt16 nItemId,
                               const OUString& rTitle, sal_uLong nWidthPixel, const Fraction& rCurrentZoom )
 :   _nId( nItemId ),
     _nWidth( nWidthPixel ),
-    _aImage( rImage ),
     _aTitle( rTitle ),
     _bFrozen( false )
 {
@@ -141,13 +126,13 @@ void BrowserColumn::SetWidth(sal_uLong nNewWidthPixel, const Fraction& rCurrentZ
     }
 }
 
-void BrowserColumn::Draw( BrowseBox& rBox, OutputDevice& rDev, const Point& rPos, bool bCurs  )
+void BrowserColumn::Draw( BrowseBox const & rBox, OutputDevice& rDev, const Point& rPos  )
 {
     if ( _nId == 0 )
     {
         // paint handle column
         ButtonFrame( rPos, Size( Width()-1, rBox.GetDataRowHeight()-1 ),
-                     "", false, bCurs, false ).Draw( rDev );
+                     "", false ).Draw( rDev );
         Color aOldLineColor = rDev.GetLineColor();
         rDev.SetLineColor( Color( COL_BLACK ) );
         rDev.DrawLine(
@@ -159,7 +144,7 @@ void BrowserColumn::Draw( BrowseBox& rBox, OutputDevice& rDev, const Point& rPos
         rDev.SetLineColor( aOldLineColor );
 
         rBox.DoPaintField( rDev,
-            Rectangle(
+            tools::Rectangle(
                 Point( rPos.X() + 2, rPos.Y() + 2 ),
                 Size( Width()-1, rBox.GetDataRowHeight()-1 ) ),
             GetId(),
@@ -171,7 +156,7 @@ void BrowserColumn::Draw( BrowseBox& rBox, OutputDevice& rDev, const Point& rPos
         long nWidth = Width() == LONG_MAX ? rBox.GetDataWindow().GetSizePixel().Width() : Width();
 
         rBox.DoPaintField( rDev,
-            Rectangle(
+            tools::Rectangle(
                 Point( rPos.X() + MIN_COLUMNWIDTH, rPos.Y() ),
                 Size( nWidth-2*MIN_COLUMNWIDTH, rBox.GetDataRowHeight()-1 ) ),
             GetId(),
@@ -180,18 +165,13 @@ void BrowserColumn::Draw( BrowseBox& rBox, OutputDevice& rDev, const Point& rPos
 }
 
 
-
 void BrowserColumn::ZoomChanged(const Fraction& rNewZoom)
 {
-    double n = (double)_nOriginalWidth;
-    n *= (double)rNewZoom.GetNumerator();
-    n /= (double)rNewZoom.GetDenominator();
-
+    double n(_nOriginalWidth * rNewZoom);
     _nWidth = n>0 ? (long)(n+0.5) : -(long)(-n+0.5);
 }
 
 
-
 BrowserDataWin::BrowserDataWin( BrowseBox* pParent )
     :Control( pParent, WinBits(WB_CLIPCHILDREN) )
     ,DragSourceHelper( this )
@@ -220,7 +200,7 @@ BrowserDataWin::BrowserDataWin( BrowseBox* pParent )
     ,m_nDragRowDividerLimit( 0 )
     ,m_nDragRowDividerOffset( 0 )
 {
-    aMouseTimer.SetTimeoutHdl( LINK( this, BrowserDataWin, RepeatedMouseMove ) );
+    aMouseTimer.SetInvokeHandler( LINK( this, BrowserDataWin, RepeatedMouseMove ) );
     aMouseTimer.SetTimeout( 100 );
 }
 
@@ -234,12 +214,14 @@ void BrowserDataWin::dispose()
 {
     bInDtor = true;
 
-    for ( size_t i = 0, n = aInvalidRegion.size(); i < n; ++i )
-        delete aInvalidRegion[ i ];
+    for (tools::Rectangle* i : aInvalidRegion)
+        delete i;
     aInvalidRegion.clear();
     pHeaderBar.clear();
     pEventWin.clear();
     pCornerWin.clear();
+    DragSourceHelper::dispose();
+    DropTargetHelper::dispose();
     Control::dispose();
 }
 
@@ -257,18 +239,13 @@ void BrowserDataWin::LeaveUpdateLock()
     }
 }
 
-void InitSettings_Impl(vcl::Window* pWin, bool bFont, bool bForeground, bool bBackground)
+void InitSettings_Impl(vcl::Window* pWin)
 {
     const StyleSettings& rStyleSettings = pWin->GetSettings().GetStyleSettings();
 
-    if (bFont)
-        pWin->ApplyControlFont(*pWin, rStyleSettings.GetFieldFont());
-
-    if (bFont || bForeground)
-        pWin->ApplyControlForeground(*pWin, rStyleSettings.GetWindowTextColor());
-
-    if (bBackground)
-        pWin->ApplyControlBackground(*pWin, rStyleSettings.GetWindowColor());
+    pWin->ApplyControlFont(*pWin, rStyleSettings.GetFieldFont());
+    pWin->ApplyControlForeground(*pWin, rStyleSettings.GetWindowTextColor());
+    pWin->ApplyControlBackground(*pWin, rStyleSettings.GetWindowColor());
 }
 
 
@@ -300,13 +277,13 @@ void BrowserDataWin::DataChanged( const DataChangedEvent& rDCEvt )
 }
 
 
-void BrowserDataWin::Paint(vcl::RenderContext& rRenderContext, const Rectangle& rRect)
+void BrowserDataWin::Paint(vcl::RenderContext& rRenderContext, const tools::Rectangle& rRect)
 {
     if (!nUpdateLock && GetUpdateMode())
     {
         if (bInPaint)
         {
-            aInvalidRegion.push_back(new Rectangle(rRect));
+            aInvalidRegion.push_back(new tools::Rectangle(rRect));
             return;
         }
         bInPaint = true;
@@ -316,12 +293,11 @@ void BrowserDataWin::Paint(vcl::RenderContext& rRenderContext, const Rectangle&
     }
     else
     {
-        aInvalidRegion.push_back(new Rectangle(rRect));
+        aInvalidRegion.push_back(new tools::Rectangle(rRect));
     }
 }
 
 
-
 BrowseEvent BrowserDataWin::CreateBrowseEvent( const Point& rPosPixel )
 {
     BrowseBox *pBox = GetParent();
@@ -337,26 +313,26 @@ BrowseEvent BrowserDataWin::CreateBrowseEvent( const Point& rPosPixel )
     long nColX = 0;
     size_t nCol;
     for ( nCol = 0;
-          nCol < pBox->pCols->size() && nColX < GetSizePixel().Width();
+          nCol < pBox->pCols.size() && nColX < GetSizePixel().Width();
           ++nCol )
-        if ( (*pBox->pCols)[ nCol ]->IsFrozen() || nCol >= pBox->nFirstCol )
+        if ( pBox->pCols[ nCol ]->IsFrozen() || nCol >= pBox->nFirstCol )
         {
-            nColX += (*pBox->pCols)[ nCol ]->Width();
+            nColX += pBox->pCols[ nCol ]->Width();
             if ( nMouseX < nColX )
                 break;
         }
     sal_uInt16 nColId = BROWSER_INVALIDID;
-    if ( nCol < pBox->pCols->size() )
-        nColId = (*pBox->pCols)[ nCol ]->GetId();
+    if ( nCol < pBox->pCols.size() )
+        nColId = pBox->pCols[ nCol ]->GetId();
 
     // compute the field rectangle and field relative MouseEvent
-    Rectangle aFieldRect;
-    if ( nCol < pBox->pCols->size() )
+    tools::Rectangle aFieldRect;
+    if ( nCol < pBox->pCols.size() )
     {
-        nColX -= (*pBox->pCols)[ nCol ]->Width();
-        aFieldRect = Rectangle(
+        nColX -= pBox->pCols[ nCol ]->Width();
+        aFieldRect = tools::Rectangle(
             Point( nColX, nRelRow * pBox->GetDataRowHeight() ),
-            Size( (*pBox->pCols)[ nCol ]->Width(),
+            Size( pBox->pCols[ nCol ]->Width(),
                   pBox->GetDataRowHeight() ) );
     }
 
@@ -436,7 +412,6 @@ void BrowserDataWin::Command( const CommandEvent& rEvt )
 }
 
 
-
 bool BrowserDataWin::ImplRowDividerHitTest( const BrowserMouseEvent& _rEvent )
 {
     if ( ! (  GetParent()->IsInteractiveRowHeightEnabled()
@@ -452,7 +427,6 @@ bool BrowserDataWin::ImplRowDividerHitTest( const BrowserMouseEvent& _rEvent )
 }
 
 
-
 void BrowserDataWin::MouseButtonDown( const MouseEvent& rEvt )
 {
     aLastMousePos = OutputToScreenPixel( rEvt.GetPosPixel() );
@@ -468,12 +442,11 @@ void BrowserDataWin::MouseButtonDown( const MouseEvent& rEvt )
 }
 
 
-
 void BrowserDataWin::MouseMove( const MouseEvent& rEvt )
 {
     // avoid pseudo MouseMoves
     Point aNewPos = OutputToScreenPixel( rEvt.GetPosPixel() );
-    if ( ( aNewPos == aLastMousePos ) )
+    if ( aNewPos == aLastMousePos )
         return;
     aLastMousePos = aNewPos;
 
@@ -503,8 +476,7 @@ void BrowserDataWin::MouseMove( const MouseEvent& rEvt )
 }
 
 
-
-IMPL_LINK_NOARG_TYPED(BrowserDataWin, RepeatedMouseMove, Timer *, void)
+IMPL_LINK_NOARG(BrowserDataWin, RepeatedMouseMove, Timer *, void)
 {
     GetParent()->MouseMove( BrowserMouseEvent( this, aRepeatEvt ) );
 }
@@ -526,7 +498,6 @@ void BrowserDataWin::MouseButtonUp( const MouseEvent& rEvt )
 }
 
 
-
 void BrowserDataWin::StartRowDividerDrag( const Point& _rStartPos )
 {
     long nDataRowHeight = GetParent()->GetDataRowHeight();
@@ -544,14 +515,13 @@ void BrowserDataWin::StartRowDividerDrag( const Point& _rStartPos )
     GetParent()->bRowDividerDrag = true;
     GetParent()->ImplStartTracking();
 
-    Rectangle aDragSplitRect( 0, m_nDragRowDividerLimit, GetOutputSizePixel().Width(), nDragRowDividerCurrentPos );
+    tools::Rectangle aDragSplitRect( 0, m_nDragRowDividerLimit, GetOutputSizePixel().Width(), nDragRowDividerCurrentPos );
     ShowTracking( aDragSplitRect );
 
     StartTracking();
 }
 
 
-
 void BrowserDataWin::Tracking( const TrackingEvent& rTEvt )
 {
     if ( !GetParent()->bRowDividerDrag )
@@ -582,21 +552,18 @@ void BrowserDataWin::Tracking( const TrackingEvent& rTEvt )
     }
     else
     {
-        GetParent()->ImplTracking();
-
         long nDragRowDividerCurrentPos = aMousePos.Y() + m_nDragRowDividerOffset;
 
         // care for minimum row height
         if ( nDragRowDividerCurrentPos < m_nDragRowDividerLimit + GetParent()->QueryMinimumRowHeight() )
             nDragRowDividerCurrentPos = m_nDragRowDividerLimit + GetParent()->QueryMinimumRowHeight();
 
-        Rectangle aDragSplitRect( 0, m_nDragRowDividerLimit, GetOutputSizePixel().Width(), nDragRowDividerCurrentPos );
+        tools::Rectangle aDragSplitRect( 0, m_nDragRowDividerLimit, GetOutputSizePixel().Width(), nDragRowDividerCurrentPos );
         ShowTracking( aDragSplitRect );
     }
 }
 
 
-
 void BrowserDataWin::KeyInput( const KeyEvent& rEvt )
 {
     // pass to parent window
@@ -605,7 +572,6 @@ void BrowserDataWin::KeyInput( const KeyEvent& rEvt )
 }
 
 
-
 void BrowserDataWin::RequestHelp( const HelpEvent& rHEvt )
 {
     pEventWin = this;
@@ -614,10 +580,9 @@ void BrowserDataWin::RequestHelp( const HelpEvent& rHEvt )
 }
 
 
-
 BrowseEvent::BrowseEvent( vcl::Window* pWindow,
                           long nAbsRow, sal_uInt16 nColumn, sal_uInt16 nColumnId,
-                          const Rectangle& rRect ):
+                          const tools::Rectangle& rRect ):
     pWin(pWindow),
     nRow(nAbsRow),
     aRect(rRect),
@@ -635,17 +600,15 @@ BrowserMouseEvent::BrowserMouseEvent( BrowserDataWin *pWindow,
 }
 
 
-
 BrowserMouseEvent::BrowserMouseEvent( vcl::Window *pWindow, const MouseEvent& rEvt,
                           long nAbsRow, sal_uInt16 nColumn, sal_uInt16 nColumnId,
-                          const Rectangle& rRect ):
+                          const tools::Rectangle& rRect ):
     MouseEvent(rEvt),
     BrowseEvent( pWindow, nAbsRow, nColumn, nColumnId, rRect )
 {
 }
 
 
-
 BrowserAcceptDropEvent::BrowserAcceptDropEvent( BrowserDataWin *pWindow, const AcceptDropEvent& rEvt )
     :AcceptDropEvent(rEvt)
     ,BrowseEvent( pWindow->CreateBrowseEvent( rEvt.maPosPixel ) )
@@ -653,7 +616,6 @@ BrowserAcceptDropEvent::BrowserAcceptDropEvent( BrowserDataWin *pWindow, const A
 }
 
 
-
 BrowserExecuteDropEvent::BrowserExecuteDropEvent( BrowserDataWin *pWindow, const ExecuteDropEvent& rEvt )
     :ExecuteDropEvent(rEvt)
     ,BrowseEvent( pWindow->CreateBrowseEvent( rEvt.maPosPixel ) )
@@ -661,13 +623,10 @@ BrowserExecuteDropEvent::BrowserExecuteDropEvent( BrowserDataWin *pWindow, const
 }
 
 
-
-
-
 void BrowserDataWin::SetUpdateMode( bool bMode )
 {
     DBG_ASSERT( !bUpdateMode || aInvalidRegion.empty(), "invalid region not empty" );
-    if ( (bool) bMode == bUpdateMode )
+    if ( bMode == bUpdateMode )
         return;
 
     bUpdateMode = bMode;
@@ -678,34 +637,32 @@ void BrowserDataWin::SetUpdateMode( bool bMode )
 
 void BrowserDataWin::DoOutstandingInvalidations()
 {
-    for ( size_t i = 0, n = aInvalidRegion.size(); i < n; ++i ) {
-        Control::Invalidate( *aInvalidRegion[ i ] );
-        delete aInvalidRegion[ i ];
+    for (tools::Rectangle* i : aInvalidRegion) {
+        Control::Invalidate( *i );
+        delete i;
     }
     aInvalidRegion.clear();
 }
 
 
-
 void BrowserDataWin::Invalidate( InvalidateFlags nFlags )
 {
     if ( !GetUpdateMode() )
     {
-        for ( size_t i = 0, n = aInvalidRegion.size(); i < n; ++i )
-            delete aInvalidRegion[ i ];
+        for (tools::Rectangle* i : aInvalidRegion)
+            delete i;
         aInvalidRegion.clear();
-        aInvalidRegion.push_back( new Rectangle( Point( 0, 0 ), GetOutputSizePixel() ) );
+        aInvalidRegion.push_back( new tools::Rectangle( Point( 0, 0 ), GetOutputSizePixel() ) );
     }
     else
         Window::Invalidate( nFlags );
 }
 
 
-
-void BrowserDataWin::Invalidate( const Rectangle& rRect, InvalidateFlags nFlags )
+void BrowserDataWin::Invalidate( const tools::Rectangle& rRect, InvalidateFlags nFlags )
 {
     if ( !GetUpdateMode() )
-        aInvalidRegion.push_back( new Rectangle( rRect ) );
+        aInvalidRegion.push_back( new tools::Rectangle( rRect ) );
     else
         Window::Invalidate( rRect, nFlags );
 }
@@ -733,26 +690,18 @@ void BrowserScrollBar::Tracking( const TrackingEvent& rTEvt )
         else
             aTip += OUString::number(GetRangeMax());
 
-        Rectangle aRect(GetPointerPosPixel(), Size(GetTextWidth(aTip), GetTextHeight()));
-        if ( _nTip )
-            Help::UpdateTip( _nTip, this, aRect, aTip );
-        else
-            _nTip = Help::ShowTip( this, aRect, aTip );
+        tools::Rectangle aRect(GetPointerPosPixel(), Size(GetTextWidth(aTip), GetTextHeight()));
+        Help::ShowQuickHelp(this, aRect, aTip);
         _nLastPos = nPos;
     }
 
     ScrollBar::Tracking( rTEvt );
 }
 
-
-
 void BrowserScrollBar::EndScroll()
 {
-    if ( _nTip )
-        Help::HideTip( _nTip );
-    _nTip = 0;
+    Help::HideBalloonAndQuickHelp();
     ScrollBar::EndScroll();
 }
 
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
