@@ -95,7 +95,7 @@ SvtAccessibilityOptions_Impl::SvtAccessibilityOptions_Impl()
     catch(const css::uno::Exception& ex)
     {
         m_xCfg.clear();
-        SAL_WARN("svtools.config", "Caught unexpected: " << ex.Message);
+        SAL_WARN("svtools.config", "Caught unexpected: " << ex);
     }
 }
 
@@ -111,7 +111,7 @@ bool SvtAccessibilityOptions_Impl::GetIsForPagePreviews() const
     }
     catch(const css::uno::Exception& ex)
     {
-        SAL_WARN("svtools.config", "Caught unexpected: " << ex.Message);
+        SAL_WARN("svtools.config", "Caught unexpected: " << ex);
     }
     return bRet;
 }
@@ -128,7 +128,7 @@ bool SvtAccessibilityOptions_Impl::GetIsHelpTipsDisappear() const
     }
     catch(const css::uno::Exception& ex)
     {
-        SAL_WARN("svtools.config", "Caught unexpected: " << ex.Message);
+        SAL_WARN("svtools.config", "Caught unexpected: " << ex);
     }
 
     return bRet;
@@ -146,7 +146,7 @@ bool SvtAccessibilityOptions_Impl::GetIsAllowAnimatedGraphics() const
     }
     catch(const css::uno::Exception& ex)
     {
-        SAL_WARN("svtools.config", "Caught unexpected: " << ex.Message);
+        SAL_WARN("svtools.config", "Caught unexpected: " << ex);
     }
 
     return bRet;
@@ -164,7 +164,7 @@ bool SvtAccessibilityOptions_Impl::GetIsAllowAnimatedText() const
     }
     catch(const css::uno::Exception& ex)
     {
-        SAL_WARN("svtools.config", "Caught unexpected: " << ex.Message);
+        SAL_WARN("svtools.config", "Caught unexpected: " << ex);
     }
 
     return bRet;
@@ -182,7 +182,7 @@ bool SvtAccessibilityOptions_Impl::GetIsAutomaticFontColor() const
     }
     catch(const css::uno::Exception& ex)
     {
-        SAL_WARN("svtools.config", "Caught unexpected: " << ex.Message);
+        SAL_WARN("svtools.config", "Caught unexpected: " << ex);
     }
 
     return bRet;
@@ -200,7 +200,7 @@ sal_Int16 SvtAccessibilityOptions_Impl::GetHelpTipSeconds() const
     }
     catch(const css::uno::Exception& ex)
     {
-        SAL_WARN("svtools.config", "Caught unexpected: " << ex.Message);
+        SAL_WARN("svtools.config", "Caught unexpected: " << ex);
     }
 
     return nRet;
@@ -218,7 +218,7 @@ bool SvtAccessibilityOptions_Impl::IsSelectionInReadonly() const
     }
     catch(const css::uno::Exception& ex)
     {
-        SAL_WARN("svtools.config", "Caught unexpected: " << ex.Message);
+        SAL_WARN("svtools.config", "Caught unexpected: " << ex);
     }
 
     return bRet;
@@ -236,7 +236,7 @@ sal_Int16 SvtAccessibilityOptions_Impl::GetEdgeBlending() const
     }
     catch(const css::uno::Exception& ex)
     {
-        SAL_WARN("svtools.config", "Caught unexpected: " << ex.Message);
+        SAL_WARN("svtools.config", "Caught unexpected: " << ex);
     }
 
     return nRet;
@@ -254,7 +254,7 @@ sal_Int16 SvtAccessibilityOptions_Impl::GetListBoxMaximumLineCount() const
     }
     catch(const css::uno::Exception& ex)
     {
-        SAL_WARN("svtools.config", "Caught unexpected: " << ex.Message);
+        SAL_WARN("svtools.config", "Caught unexpected: " << ex);
     }
 
     return nRet;
@@ -272,7 +272,7 @@ sal_Int16 SvtAccessibilityOptions_Impl::GetColorValueSetColumnCount() const
     }
     catch(const css::uno::Exception& ex)
     {
-        SAL_WARN("svtools.config", "Caught unexpected: " << ex.Message);
+        SAL_WARN("svtools.config", "Caught unexpected: " << ex);
     }
 
     return nRet;
@@ -290,7 +290,7 @@ bool SvtAccessibilityOptions_Impl::GetPreviewUsesCheckeredBackground() const
     }
     catch(const css::uno::Exception& ex)
     {
-        SAL_WARN("svtools.config", "Caught unexpected: " << ex.Message);
+        SAL_WARN("svtools.config", "Caught unexpected: " << ex);
     }
 
     return bRet;
@@ -357,7 +357,7 @@ void SvtAccessibilityOptions_Impl::SetVCLSettings()
 
 SvtAccessibilityOptions::SvtAccessibilityOptions()
 {
-    if (!utl::ConfigManager::IsAvoidConfig())
+    if (!utl::ConfigManager::IsFuzzing())
     {
         ::osl::MutexGuard aGuard( SingletonMutex::get() );
         if(!sm_pSingleImplConfig)
