@@ -17,57 +17,70 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "sal/config.h"
+#include <sal/config.h>
 
-#include "com/sun/star/beans/XPropertySet.hpp"
-#include "com/sun/star/document/XDocumentProperties.hpp"
-#include "com/sun/star/script/Converter.hpp"
-#include "com/sun/star/script/XTypeConverter.hpp"
-#include "comphelper/processfactory.hxx"
-#include "comphelper/string.hxx"
-#include "rtl/ustring.hxx"
-#include "svl/inettype.hxx"
-#include "svtools/DocumentInfoPreview.hxx"
-#include "svtools/imagemgr.hxx"
-#include "vcl/txtattr.hxx"
-#include "tools/datetime.hxx"
-#include "tools/urlobj.hxx"
-#include "unotools/pathoptions.hxx"
-#include "unotools/ucbhelper.hxx"
+#include <com/sun/star/beans/XPropertySet.hpp>
+#include <com/sun/star/document/XDocumentProperties.hpp>
+#include <com/sun/star/script/CannotConvertException.hpp>
+#include <com/sun/star/script/Converter.hpp>
+#include <com/sun/star/script/XTypeConverter.hpp>
+#include <comphelper/processfactory.hxx>
+#include <comphelper/string.hxx>
+#include <rtl/ustring.hxx>
+#include <svl/inettype.hxx>
+#include <svtools/DocumentInfoPreview.hxx>
+#include <svtools/imagemgr.hxx>
+#include <svtools/svmedit2.hxx>
+#include <vcl/builder.hxx>
+#include <vcl/txtattr.hxx>
+#include <vcl/settings.hxx>
+#include <vcl/builderfactory.hxx>
+#include <tools/datetime.hxx>
+#include <tools/urlobj.hxx>
+#include <unotools/ucbhelper.hxx>
 
 #include "fileview.hxx"
-#include "templwin.hrc"
+#include <templwin.hrc>
 #include "templwin.hxx"
 
 namespace svtools {
 
-ODocumentInfoPreview::ODocumentInfoPreview(Window * pParent, WinBits nBits):
-    Window(pParent, WB_DIALOGCONTROL), m_pEditWin(this, nBits),
-    m_pInfoTable(new SvtDocInfoTable_Impl),
-    m_aLanguageTag(SvtPathOptions().GetLanguageTag()) // detect application language
+ODocumentInfoPreview::ODocumentInfoPreview(vcl::Window * pParent, WinBits nBits)
+    : Window(pParent, WB_DIALOGCONTROL)
+    , m_pEditWin( VclPtr<ExtMultiLineEdit>::Create(this, nBits) )
 {
-    m_pEditWin.SetLeftMargin(10);
-    m_pEditWin.Show();
-    m_pEditWin.EnableCursor(false);
+    m_pEditWin->SetLeftMargin(10);
+    m_pEditWin->Show();
+    m_pEditWin->EnableCursor(false);
 }
 
-ODocumentInfoPreview::~ODocumentInfoPreview() {}
+ODocumentInfoPreview::~ODocumentInfoPreview()
+{
+    disposeOnce();
+}
+
+void ODocumentInfoPreview::dispose()
+{
+    m_pEditWin.disposeAndClear();
+    Window::dispose();
+}
+
+VCL_BUILDER_FACTORY_ARGS(ODocumentInfoPreview, WB_BORDER | WB_READONLY)
 
 void ODocumentInfoPreview::Resize() {
-    m_pEditWin.SetPosSizePixel(Point(0, 0), GetOutputSize());
+    m_pEditWin->SetPosSizePixel(Point(0, 0), GetOutputSize());
 }
 
 void ODocumentInfoPreview::clear() {
-    m_pEditWin.SetText(OUString());
+    m_pEditWin->SetText(OUString());
 }
 
 void ODocumentInfoPreview::fill(
-    css::uno::Reference< css::document::XDocumentProperties > const & xDocProps,
-    OUString const & rURL)
+    css::uno::Reference< css::document::XDocumentProperties > const & xDocProps)
 {
     assert(xDocProps.is());
 
-    m_pEditWin.SetAutoScroll(false);
+    m_pEditWin->SetAutoScroll(false);
 
     insertNonempty(DI_TITLE, xDocProps->getTitle());
     insertNonempty(DI_FROM, xDocProps->getAuthor());
@@ -81,19 +94,6 @@ void ODocumentInfoPreview::fill(
         DI_KEYWORDS,
         comphelper::string::convertCommaSeparated(xDocProps->getKeywords()));
     insertNonempty(DI_DESCRIPTION, xDocProps->getDescription());
-    if (!rURL.isEmpty()) {
-        insertNonempty(
-            DI_SIZE, CreateExactSizeText(utl::UCBContentHelper::GetSize(rURL)));
-        INetContentType eTypeID = INetContentTypes::GetContentTypeFromURL(rURL);
-        if(eTypeID == CONTENT_TYPE_APP_OCTSTREAM)
-        {
-            insertNonempty( DI_MIMETYPE, SvFileInformationManager::GetDescription(INetURLObject(rURL)));
-        }
-        else
-        {
-            insertNonempty( DI_MIMETYPE, INetContentTypes::GetPresentation(eTypeID, m_aLanguageTag));
-        }
-    }
 
     // User-defined (custom) properties:
     css::uno::Reference< css::beans::XPropertySet > user(
@@ -112,35 +112,35 @@ void ODocumentInfoPreview::fill(
             value = conv->convertToSimpleType(aAny, css::uno::TypeClass_STRING).
                 get< OUString >();
         } catch (css::script::CannotConvertException & e) {
-            SAL_INFO("svtools.contnr", "ignored CannotConvertException " << e.Message);
+            SAL_INFO("svtools.contnr", "ignored " << e);
         }
         if (!value.isEmpty()) {
             insertEntry(name, value);
         }
     }
 
-    m_pEditWin.SetSelection(Selection(0, 0));
-    m_pEditWin.SetAutoScroll(true);
+    m_pEditWin->SetSelection(Selection(0, 0));
+    m_pEditWin->SetAutoScroll(true);
 }
 
 void ODocumentInfoPreview::insertEntry(
     OUString const & title, OUString const & value)
 {
-    if (!m_pEditWin.GetText().isEmpty()) {
-        m_pEditWin.InsertText(OUString("\n\n"));
+    if (!m_pEditWin->GetText().isEmpty()) {
+        m_pEditWin->InsertText("\n\n");
     }
-    OUString caption(title + OUString(":\n"));
-    m_pEditWin.InsertText(caption);
-    m_pEditWin.SetAttrib(
-        TextAttribFontWeight(WEIGHT_BOLD), m_pEditWin.GetParagraphCount() - 2,
+    OUString caption(title + ":\n");
+    m_pEditWin->InsertText(caption);
+    m_pEditWin->SetAttrib(
+        TextAttribFontWeight(WEIGHT_BOLD), m_pEditWin->GetParagraphCount() - 2,
         0, caption.getLength() - 1);
-    m_pEditWin.InsertText(value);
+    m_pEditWin->InsertText(value);
 }
 
 void ODocumentInfoPreview::insertNonempty(long id, OUString const & value)
 {
     if (!value.isEmpty()) {
-        insertEntry(m_pInfoTable->GetString(id), value);
+        insertEntry(SvtDocInfoTable_Impl::GetString(id), value);
     }
 }
 
@@ -149,14 +149,14 @@ void ODocumentInfoPreview::insertDateTime(
 {
     DateTime aToolsDT(
         Date(value.Day, value.Month, value.Year),
-        Time(
+        tools::Time(
             value.Hours, value.Minutes, value.Seconds, value.NanoSeconds));
     if (aToolsDT.IsValidAndGregorian()) {
         const LocaleDataWrapper& rLocaleWrapper( Application::GetSettings().GetLocaleDataWrapper() );
         OUStringBuffer buf(rLocaleWrapper.getDate(aToolsDT));
         buf.append(", ");
         buf.append(rLocaleWrapper.getTime(aToolsDT));
-        insertEntry(m_pInfoTable->GetString(id), buf.makeStringAndClear());
+        insertEntry(SvtDocInfoTable_Impl::GetString(id), buf.makeStringAndClear());
     }
 }
 
