@@ -21,6 +21,7 @@
 #include <com/sun/star/accessibility/AccessibleEventId.hpp>
 #include <com/sun/star/accessibility/AccessibleRole.hpp>
 #include <com/sun/star/accessibility/AccessibleStateType.hpp>
+#include <com/sun/star/lang/IndexOutOfBoundsException.hpp>
 
 #include <unotools/accessiblestatesethelper.hxx>
 
@@ -40,9 +41,6 @@ using namespace ::com::sun::star::accessibility;
 namespace svtools {
 
 
-// - ToolbarMenuAcc -
-
-
 ToolbarMenuAcc::ToolbarMenuAcc( ToolbarMenu_Impl& rParent )
 : ToolbarMenuAccComponentBase(m_aMutex)
 , mpParent( &rParent )
@@ -52,7 +50,6 @@ ToolbarMenuAcc::ToolbarMenuAcc( ToolbarMenu_Impl& rParent )
 }
 
 
-
 ToolbarMenuAcc::~ToolbarMenuAcc()
 {
     if( mpParent )
@@ -60,40 +57,28 @@ ToolbarMenuAcc::~ToolbarMenuAcc()
 }
 
 
-
-IMPL_LINK( ToolbarMenuAcc, WindowEventListener, VclSimpleEvent*, pEvent )
+IMPL_LINK( ToolbarMenuAcc, WindowEventListener, VclWindowEvent&, rEvent, void )
 {
-    DBG_ASSERT( pEvent && pEvent->ISA( VclWindowEvent ), "Unknown WindowEvent!" );
-
-    /* Ignore VCLEVENT_WINDOW_ENDPOPUPMODE, because the UNO accessibility wrapper
+    /* Ignore VclEventId::WindowEndPopupMode, because the UNO accessibility wrapper
      * might have been destroyed by the previous VCLEventListener (if no AT tool
      * is running), e.g. sub-toolbars in impress.
      */
-    if ( mpParent && pEvent && pEvent->ISA( VclWindowEvent ) && (pEvent->GetId() != VCLEVENT_WINDOW_ENDPOPUPMODE) )
+    if ( !mpParent || (rEvent.GetId() == VclEventId::WindowEndPopupMode) )
+        return;
+    DBG_ASSERT( rEvent.GetWindow(), "Window???" );
+    if( rEvent.GetWindow()->IsAccessibilityEventsSuppressed() && ( rEvent.GetId() != VclEventId::ObjectDying ) )
+        return;
+
+    switch ( rEvent.GetId() )
     {
-        DBG_ASSERT( static_cast<VclWindowEvent*>(pEvent)->GetWindow(), "Window???" );
-        if( !static_cast<VclWindowEvent*>(pEvent)->GetWindow()->IsAccessibilityEventsSuppressed() || ( pEvent->GetId() == VCLEVENT_OBJECT_DYING ) )
-        {
-            ProcessWindowEvent( *static_cast<VclWindowEvent*>(pEvent) );
-        }
-    }
-    return 0;
-}
-
-
-
-void ToolbarMenuAcc::ProcessWindowEvent( const VclWindowEvent& rVclWindowEvent )
-{
-    switch ( rVclWindowEvent.GetId() )
-    {
-        case VCLEVENT_OBJECT_DYING:
+        case VclEventId::ObjectDying:
         {
             mpParent->mrMenu.RemoveEventListener( LINK( this, ToolbarMenuAcc, WindowEventListener ) );
-            mpParent = 0;
+            mpParent = nullptr;
         }
         break;
 
-        case VCLEVENT_WINDOW_GETFOCUS:
+        case VclEventId::WindowGetFocus:
         {
             if( !mbIsFocused )
             {
@@ -102,7 +87,7 @@ void ToolbarMenuAcc::ProcessWindowEvent( const VclWindowEvent& rVclWindowEvent )
             }
         }
         break;
-        case VCLEVENT_WINDOW_LOSEFOCUS:
+        case VclEventId::WindowLoseFocus:
         {
             if( mbIsFocused )
             {
@@ -118,44 +103,41 @@ void ToolbarMenuAcc::ProcessWindowEvent( const VclWindowEvent& rVclWindowEvent )
 }
 
 
-
 void ToolbarMenuAcc::FireAccessibleEvent( short nEventId, const Any& rOldValue, const Any& rNewValue )
 {
-    if( nEventId )
+    if( !nEventId )
+        return;
+
+    EventListenerVector                  aTmpListeners( mxEventListeners );
+    AccessibleEventObject aEvtObject;
+
+    aEvtObject.EventId = nEventId;
+    aEvtObject.Source = static_cast<XWeak*>(this);
+    aEvtObject.NewValue = rNewValue;
+    aEvtObject.OldValue = rOldValue;
+
+    for (EventListenerVector::const_iterator aIter( aTmpListeners.begin() ), aEnd( aTmpListeners.end() );
+        aIter != aEnd ; ++aIter)
     {
-        EventListenerVector                  aTmpListeners( mxEventListeners );
-        AccessibleEventObject aEvtObject;
-
-        aEvtObject.EventId = nEventId;
-        aEvtObject.Source = static_cast<XWeak*>(this);
-        aEvtObject.NewValue = rNewValue;
-        aEvtObject.OldValue = rOldValue;
-
-        for (EventListenerVector::const_iterator aIter( aTmpListeners.begin() ), aEnd( aTmpListeners.end() );
-            aIter != aEnd ; ++aIter)
+        try
+        {
+            (*aIter)->notifyEvent( aEvtObject );
+        }
+        catch( Exception& )
         {
-            try
-            {
-                (*aIter)->notifyEvent( aEvtObject );
-            }
-            catch( Exception& )
-            {
-            }
         }
     }
 }
 
 
-
-Reference< XAccessibleContext > SAL_CALL ToolbarMenuAcc::getAccessibleContext() throw (RuntimeException, std::exception)
+Reference< XAccessibleContext > SAL_CALL ToolbarMenuAcc::getAccessibleContext()
 {
     ThrowIfDisposed();
     return this;
 }
 
 
-
-sal_Int32 SAL_CALL ToolbarMenuAcc::getAccessibleChildCount() throw (RuntimeException, std::exception)
+sal_Int32 SAL_CALL ToolbarMenuAcc::getAccessibleChildCount()
 {
     const SolarMutexGuard aSolarGuard;
     ThrowIfDisposed();
@@ -164,8 +146,7 @@ sal_Int32 SAL_CALL ToolbarMenuAcc::getAccessibleChildCount() throw (RuntimeExcep
 }
 
 
-
-Reference< XAccessible > SAL_CALL ToolbarMenuAcc::getAccessibleChild( sal_Int32 i ) throw (IndexOutOfBoundsException, RuntimeException, std::exception)
+Reference< XAccessible > SAL_CALL ToolbarMenuAcc::getAccessibleChild( sal_Int32 i )
 {
     const SolarMutexGuard aSolarGuard;
     ThrowIfDisposed();
@@ -174,8 +155,7 @@ Reference< XAccessible > SAL_CALL ToolbarMenuAcc::getAccessibleChild( sal_Int32
 }
 
 
-
-Reference< XAccessible > SAL_CALL ToolbarMenuAcc::getAccessibleParent() throw (RuntimeException, std::exception)
+Reference< XAccessible > SAL_CALL ToolbarMenuAcc::getAccessibleParent()
 {
     ThrowIfDisposed();
     const SolarMutexGuard aSolarGuard;
@@ -190,8 +170,7 @@ Reference< XAccessible > SAL_CALL ToolbarMenuAcc::getAccessibleParent() throw (R
 }
 
 
-
-sal_Int32 SAL_CALL ToolbarMenuAcc::getAccessibleIndexInParent() throw (RuntimeException, std::exception)
+sal_Int32 SAL_CALL ToolbarMenuAcc::getAccessibleIndexInParent()
 {
     const SolarMutexGuard aSolarGuard;
     ThrowIfDisposed();
@@ -210,24 +189,21 @@ sal_Int32 SAL_CALL ToolbarMenuAcc::getAccessibleIndexInParent() throw (RuntimeEx
 }
 
 
-
-sal_Int16 SAL_CALL ToolbarMenuAcc::getAccessibleRole() throw (RuntimeException, std::exception)
+sal_Int16 SAL_CALL ToolbarMenuAcc::getAccessibleRole()
 {
     ThrowIfDisposed();
     return AccessibleRole::LIST;
 }
 
 
-
-OUString SAL_CALL ToolbarMenuAcc::getAccessibleDescription() throw (RuntimeException, std::exception)
+OUString SAL_CALL ToolbarMenuAcc::getAccessibleDescription()
 {
     ThrowIfDisposed();
     return OUString( "ToolbarMenu" );
 }
 
 
-
-OUString SAL_CALL ToolbarMenuAcc::getAccessibleName() throw (RuntimeException, std::exception)
+OUString SAL_CALL ToolbarMenuAcc::getAccessibleName()
 {
     ThrowIfDisposed();
     const SolarMutexGuard aSolarGuard;
@@ -247,16 +223,14 @@ OUString SAL_CALL ToolbarMenuAcc::getAccessibleName() throw (RuntimeException, s
 }
 
 
-
-Reference< XAccessibleRelationSet > SAL_CALL ToolbarMenuAcc::getAccessibleRelationSet() throw (RuntimeException, std::exception)
+Reference< XAccessibleRelationSet > SAL_CALL ToolbarMenuAcc::getAccessibleRelationSet()
 {
     ThrowIfDisposed();
     return Reference< XAccessibleRelationSet >();
 }
 
 
-
-Reference< XAccessibleStateSet > SAL_CALL ToolbarMenuAcc::getAccessibleStateSet() throw (RuntimeException, std::exception)
+Reference< XAccessibleStateSet > SAL_CALL ToolbarMenuAcc::getAccessibleStateSet()
 {
     ThrowIfDisposed();
     ::utl::AccessibleStateSetHelper* pStateSet = new ::utl::AccessibleStateSetHelper();
@@ -275,14 +249,12 @@ Reference< XAccessibleStateSet > SAL_CALL ToolbarMenuAcc::getAccessibleStateSet(
 }
 
 
-
-Locale SAL_CALL ToolbarMenuAcc::getLocale() throw (IllegalAccessibleComponentStateException, RuntimeException, std::exception)
+Locale SAL_CALL ToolbarMenuAcc::getLocale()
 {
     ThrowIfDisposed();
     const SolarMutexGuard aSolarGuard;
-    const OUString aEmptyStr;
     Reference< XAccessible > xParent( getAccessibleParent() );
-    Locale aRet( aEmptyStr, aEmptyStr, aEmptyStr );
+    Locale aRet( "", "", "" );
 
     if( xParent.is() )
     {
@@ -296,33 +268,31 @@ Locale SAL_CALL ToolbarMenuAcc::getLocale() throw (IllegalAccessibleComponentSta
 }
 
 
-
-void SAL_CALL ToolbarMenuAcc::addAccessibleEventListener( const Reference< XAccessibleEventListener >& rxListener ) throw (RuntimeException, std::exception)
+void SAL_CALL ToolbarMenuAcc::addAccessibleEventListener( const Reference< XAccessibleEventListener >& rxListener )
 {
     ThrowIfDisposed();
     ::osl::MutexGuard aGuard(m_aMutex);
 
-    if( rxListener.is() )
+    if( !rxListener.is() )
+           return;
+
+       EventListenerVector::const_iterator aIter = mxEventListeners.begin();
+    bool bFound = false;
+
+    while( !bFound && ( aIter != mxEventListeners.end() ) )
     {
-           EventListenerVector::const_iterator aIter = mxEventListeners.begin();
-        bool bFound = false;
-
-        while( !bFound && ( aIter != mxEventListeners.end() ) )
-        {
-            if( *aIter == rxListener )
-                bFound = true;
-            else
-                ++aIter;
-        }
-
-        if (!bFound)
-            mxEventListeners.push_back( rxListener );
+        if( *aIter == rxListener )
+            bFound = true;
+        else
+            ++aIter;
     }
+
+    if (!bFound)
+        mxEventListeners.push_back( rxListener );
 }
 
 
-
-void SAL_CALL ToolbarMenuAcc::removeAccessibleEventListener( const Reference< XAccessibleEventListener >& rxListener ) throw (RuntimeException, std::exception)
+void SAL_CALL ToolbarMenuAcc::removeAccessibleEventListener( const Reference< XAccessibleEventListener >& rxListener )
 {
     ThrowIfDisposed();
     ::osl::MutexGuard aGuard(m_aMutex);
@@ -336,20 +306,18 @@ void SAL_CALL ToolbarMenuAcc::removeAccessibleEventListener( const Reference< XA
 }
 
 
-
-sal_Bool SAL_CALL ToolbarMenuAcc::containsPoint( const awt::Point& aPoint ) throw (RuntimeException, std::exception)
+sal_Bool SAL_CALL ToolbarMenuAcc::containsPoint( const awt::Point& aPoint )
 {
     ThrowIfDisposed();
     const awt::Rectangle aRect( getBounds() );
     const Point aSize( aRect.Width, aRect.Height );
     const Point aNullPoint, aTestPoint( aPoint.X, aPoint.Y );
 
-    return Rectangle( aNullPoint, aSize ).IsInside( aTestPoint );
+    return tools::Rectangle( aNullPoint, aSize ).IsInside( aTestPoint );
 }
 
 
-
-Reference< XAccessible > SAL_CALL ToolbarMenuAcc::getAccessibleAtPoint( const awt::Point& aPoint ) throw (RuntimeException, std::exception)
+Reference< XAccessible > SAL_CALL ToolbarMenuAcc::getAccessibleAtPoint( const awt::Point& aPoint )
 {
     const SolarMutexGuard aSolarGuard;
     ThrowIfDisposed();
@@ -361,18 +329,18 @@ Reference< XAccessible > SAL_CALL ToolbarMenuAcc::getAccessibleAtPoint( const aw
     const int nEntryCount = mpParent->maEntryVector.size();
     for( int nEntry = 0; (nEntry < nEntryCount) && !xRet.is(); nEntry++ )
     {
-        ToolbarMenuEntry* pEntry = mpParent->maEntryVector[nEntry];
+        ToolbarMenuEntry* pEntry = mpParent->maEntryVector[nEntry].get();
         if( pEntry && pEntry->maRect.IsInside( aVclPoint ) )
         {
             if( pEntry->mpControl )
             {
                 awt::Point aChildPoint( aPoint.X - pEntry->maRect.Left(), aPoint.Y - pEntry->maRect.Top() );
-                Reference< XAccessibleComponent > xComp( pEntry->GetAccessible(true), UNO_QUERY_THROW );
+                Reference< XAccessibleComponent > xComp( pEntry->GetAccessible(), UNO_QUERY_THROW );
                 xRet = xComp->getAccessibleAtPoint(aChildPoint);
             }
             else
             {
-                xRet = Reference< XAccessible >( pEntry->GetAccessible(true), UNO_QUERY );
+                xRet.set( pEntry->GetAccessible(), UNO_QUERY );
             }
         }
     }
@@ -380,8 +348,7 @@ Reference< XAccessible > SAL_CALL ToolbarMenuAcc::getAccessibleAtPoint( const aw
 }
 
 
-
-awt::Rectangle SAL_CALL ToolbarMenuAcc::getBounds() throw (RuntimeException, std::exception)
+awt::Rectangle SAL_CALL ToolbarMenuAcc::getBounds()
 {
     ThrowIfDisposed();
     const SolarMutexGuard aSolarGuard;
@@ -398,8 +365,7 @@ awt::Rectangle SAL_CALL ToolbarMenuAcc::getBounds() throw (RuntimeException, std
 }
 
 
-
-awt::Point SAL_CALL ToolbarMenuAcc::getLocation() throw (RuntimeException, std::exception)
+awt::Point SAL_CALL ToolbarMenuAcc::getLocation()
 {
     ThrowIfDisposed();
     const SolarMutexGuard aSolarGuard;
@@ -408,8 +374,7 @@ awt::Point SAL_CALL ToolbarMenuAcc::getLocation() throw (RuntimeException, std::
 }
 
 
-
-awt::Point SAL_CALL ToolbarMenuAcc::getLocationOnScreen()  throw (RuntimeException, std::exception)
+awt::Point SAL_CALL ToolbarMenuAcc::getLocationOnScreen()
 {
     ThrowIfDisposed();
     const SolarMutexGuard aSolarGuard;
@@ -418,8 +383,7 @@ awt::Point SAL_CALL ToolbarMenuAcc::getLocationOnScreen()  throw (RuntimeExcepti
 }
 
 
-
-awt::Size SAL_CALL ToolbarMenuAcc::getSize() throw (RuntimeException, std::exception)
+awt::Size SAL_CALL ToolbarMenuAcc::getSize()
 {
     ThrowIfDisposed();
     const SolarMutexGuard aSolarGuard;
@@ -427,28 +391,28 @@ awt::Size SAL_CALL ToolbarMenuAcc::getSize() throw (RuntimeException, std::excep
     return awt::Size( aOutSize.Width(), aOutSize.Height() );
 }
 
-void SAL_CALL ToolbarMenuAcc::grabFocus() throw (RuntimeException, std::exception)
+void SAL_CALL ToolbarMenuAcc::grabFocus()
 {
     ThrowIfDisposed();
     const SolarMutexGuard aSolarGuard;
     mpParent->mrMenu.GrabFocus();
 }
 
-sal_Int32 SAL_CALL ToolbarMenuAcc::getForeground() throw (RuntimeException, std::exception)
+sal_Int32 SAL_CALL ToolbarMenuAcc::getForeground()
 {
     ThrowIfDisposed();
     sal_uInt32 nColor = Application::GetSettings().GetStyleSettings().GetMenuTextColor().GetColor();
     return static_cast<sal_Int32>(nColor);
 }
 
-sal_Int32 SAL_CALL ToolbarMenuAcc::getBackground() throw (RuntimeException, std::exception)
+sal_Int32 SAL_CALL ToolbarMenuAcc::getBackground()
 {
     ThrowIfDisposed();
     sal_uInt32 nColor = Application::GetSettings().GetStyleSettings().GetMenuColor().GetColor();
     return static_cast<sal_Int32>(nColor);
 }
 
-void SAL_CALL ToolbarMenuAcc::selectAccessibleChild( sal_Int32 nChildIndex ) throw (IndexOutOfBoundsException, RuntimeException, std::exception)
+void SAL_CALL ToolbarMenuAcc::selectAccessibleChild( sal_Int32 nChildIndex )
 {
     const SolarMutexGuard aSolarGuard;
     ThrowIfDisposed();
@@ -456,7 +420,7 @@ void SAL_CALL ToolbarMenuAcc::selectAccessibleChild( sal_Int32 nChildIndex ) thr
     mpParent->selectAccessibleChild( nChildIndex );
 }
 
-sal_Bool SAL_CALL ToolbarMenuAcc::isAccessibleChildSelected( sal_Int32 nChildIndex ) throw (IndexOutOfBoundsException, RuntimeException, std::exception)
+sal_Bool SAL_CALL ToolbarMenuAcc::isAccessibleChildSelected( sal_Int32 nChildIndex )
 {
     const SolarMutexGuard aSolarGuard;
     ThrowIfDisposed();
@@ -464,8 +428,7 @@ sal_Bool SAL_CALL ToolbarMenuAcc::isAccessibleChildSelected( sal_Int32 nChildInd
 }
 
 
-
-void SAL_CALL ToolbarMenuAcc::clearAccessibleSelection() throw (RuntimeException, std::exception)
+void SAL_CALL ToolbarMenuAcc::clearAccessibleSelection()
 {
     const SolarMutexGuard aSolarGuard;
     ThrowIfDisposed();
@@ -473,16 +436,14 @@ void SAL_CALL ToolbarMenuAcc::clearAccessibleSelection() throw (RuntimeException
 }
 
 
-
-void SAL_CALL ToolbarMenuAcc::selectAllAccessibleChildren() throw (RuntimeException, std::exception)
+void SAL_CALL ToolbarMenuAcc::selectAllAccessibleChildren()
 {
     ThrowIfDisposed();
     // unsupported due to single selection only
 }
 
 
-
-sal_Int32 SAL_CALL ToolbarMenuAcc::getSelectedAccessibleChildCount() throw (RuntimeException, std::exception)
+sal_Int32 SAL_CALL ToolbarMenuAcc::getSelectedAccessibleChildCount()
 {
     const SolarMutexGuard aSolarGuard;
     ThrowIfDisposed();
@@ -491,24 +452,23 @@ sal_Int32 SAL_CALL ToolbarMenuAcc::getSelectedAccessibleChildCount() throw (Runt
 }
 
 
-
-Reference< XAccessible > SAL_CALL ToolbarMenuAcc::getSelectedAccessibleChild( sal_Int32 nSelectedChildIndex ) throw (IndexOutOfBoundsException, RuntimeException, std::exception)
+Reference< XAccessible > SAL_CALL ToolbarMenuAcc::getSelectedAccessibleChild( sal_Int32 nSelectedChildIndex )
 {
     ThrowIfDisposed();
     const SolarMutexGuard aSolarGuard;
 
     if( (mpParent->mnHighlightedEntry != -1) && (nSelectedChildIndex == 0) )
     {
-        ToolbarMenuEntry* pEntry = mpParent->maEntryVector[ mpParent->mnHighlightedEntry ];
+        ToolbarMenuEntry* pEntry = mpParent->maEntryVector[ mpParent->mnHighlightedEntry ].get();
         if( pEntry )
         {
             if( pEntry->mpControl )
             {
-                Reference< XAccessibleSelection > xSel( pEntry->GetAccessible(true), UNO_QUERY_THROW );
+                Reference< XAccessibleSelection > xSel( pEntry->GetAccessible(), UNO_QUERY_THROW );
                 return xSel->getSelectedAccessibleChild(0);
             }
             else
-                return Reference< XAccessible >( pEntry->GetAccessible(true), UNO_QUERY );
+                return Reference< XAccessible >( pEntry->GetAccessible(), UNO_QUERY );
         }
     }
 
@@ -516,8 +476,7 @@ Reference< XAccessible > SAL_CALL ToolbarMenuAcc::getSelectedAccessibleChild( sa
 }
 
 
-
-void SAL_CALL ToolbarMenuAcc::deselectAccessibleChild( sal_Int32 nChildIndex ) throw (IndexOutOfBoundsException, RuntimeException, std::exception)
+void SAL_CALL ToolbarMenuAcc::deselectAccessibleChild( sal_Int32 nChildIndex )
 {
     ThrowIfDisposed();
     const SolarMutexGuard aSolarGuard;
@@ -528,7 +487,6 @@ void SAL_CALL ToolbarMenuAcc::deselectAccessibleChild( sal_Int32 nChildIndex ) t
 }
 
 
-
 void SAL_CALL ToolbarMenuAcc::disposing()
 {
     EventListenerVector aListenerListCopy;
@@ -542,7 +500,7 @@ void SAL_CALL ToolbarMenuAcc::disposing()
 
         // Reset the pointer to the parent.  It has to be the one who has
         // disposed us because he is dying.
-        mpParent = NULL;
+        mpParent = nullptr;
     }
 
     // Inform all listeners that this objects is disposing.
@@ -563,7 +521,7 @@ void SAL_CALL ToolbarMenuAcc::disposing()
     }
 }
 
-void ToolbarMenuAcc::ThrowIfDisposed() throw (DisposedException)
+void ToolbarMenuAcc::ThrowIfDisposed()
 {
     if(rBHelper.bDisposed || rBHelper.bInDispose || !mpParent)
     {
@@ -572,9 +530,6 @@ void ToolbarMenuAcc::ThrowIfDisposed() throw (DisposedException)
 }
 
 
-// - ToolbarMenuEntryAcc -
-
-
 ToolbarMenuEntryAcc::ToolbarMenuEntryAcc( ToolbarMenuEntry* pParent )
 : ToolbarMenuEntryAccBase( m_aMutex )
 , mpParent( pParent )
@@ -582,13 +537,11 @@ ToolbarMenuEntryAcc::ToolbarMenuEntryAcc( ToolbarMenuEntry* pParent )
 }
 
 
-
 ToolbarMenuEntryAcc::~ToolbarMenuEntryAcc()
 {
 }
 
 
-
 void SAL_CALL ToolbarMenuEntryAcc::disposing()
 {
     EventListenerVector aListenerListCopy;
@@ -602,7 +555,7 @@ void SAL_CALL ToolbarMenuEntryAcc::disposing()
 
         // Reset the pointer to the parent.  It has to be the one who has
         // disposed us because he is dying.
-        mpParent = NULL;
+        mpParent = nullptr;
     }
 
     // Inform all listeners that this objects is disposing.
@@ -624,28 +577,25 @@ void SAL_CALL ToolbarMenuEntryAcc::disposing()
 }
 
 
-Reference< XAccessibleContext > SAL_CALL ToolbarMenuEntryAcc::getAccessibleContext() throw (RuntimeException, std::exception)
+Reference< XAccessibleContext > SAL_CALL ToolbarMenuEntryAcc::getAccessibleContext()
 {
     return this;
 }
 
 
-
-sal_Int32 SAL_CALL ToolbarMenuEntryAcc::getAccessibleChildCount() throw (RuntimeException, std::exception)
+sal_Int32 SAL_CALL ToolbarMenuEntryAcc::getAccessibleChildCount()
 {
     return 0;
 }
 
 
-
-Reference< XAccessible > SAL_CALL ToolbarMenuEntryAcc::getAccessibleChild( sal_Int32 ) throw (IndexOutOfBoundsException, RuntimeException, std::exception)
+Reference< XAccessible > SAL_CALL ToolbarMenuEntryAcc::getAccessibleChild( sal_Int32 )
 {
     throw IndexOutOfBoundsException();
 }
 
 
-
-Reference< XAccessible > SAL_CALL ToolbarMenuEntryAcc::getAccessibleParent() throw (RuntimeException, std::exception)
+Reference< XAccessible > SAL_CALL ToolbarMenuEntryAcc::getAccessibleParent()
 {
     const SolarMutexGuard aSolarGuard;
     Reference< XAccessible > xRet;
@@ -657,8 +607,7 @@ Reference< XAccessible > SAL_CALL ToolbarMenuEntryAcc::getAccessibleParent() thr
 }
 
 
-
-sal_Int32 SAL_CALL ToolbarMenuEntryAcc::getAccessibleIndexInParent() throw (RuntimeException, std::exception)
+sal_Int32 SAL_CALL ToolbarMenuEntryAcc::getAccessibleIndexInParent()
 {
     const SolarMutexGuard aSolarGuard;
     // The index defaults to -1 to indicate the child does not belong to its
@@ -689,22 +638,19 @@ sal_Int32 SAL_CALL ToolbarMenuEntryAcc::getAccessibleIndexInParent() throw (Runt
 }
 
 
-
-sal_Int16 SAL_CALL ToolbarMenuEntryAcc::getAccessibleRole() throw (RuntimeException, std::exception)
+sal_Int16 SAL_CALL ToolbarMenuEntryAcc::getAccessibleRole()
 {
     return AccessibleRole::LIST_ITEM;
 }
 
 
-
-OUString SAL_CALL ToolbarMenuEntryAcc::getAccessibleDescription() throw (RuntimeException, std::exception)
+OUString SAL_CALL ToolbarMenuEntryAcc::getAccessibleDescription()
 {
     return OUString();
 }
 
 
-
-OUString SAL_CALL ToolbarMenuEntryAcc::getAccessibleName() throw (RuntimeException, std::exception)
+OUString SAL_CALL ToolbarMenuEntryAcc::getAccessibleName()
 {
     const SolarMutexGuard aSolarGuard;
     OUString              aRet;
@@ -724,15 +670,13 @@ OUString SAL_CALL ToolbarMenuEntryAcc::getAccessibleName() throw (RuntimeExcepti
 }
 
 
-
-Reference< XAccessibleRelationSet > SAL_CALL ToolbarMenuEntryAcc::getAccessibleRelationSet() throw (RuntimeException, std::exception)
+Reference< XAccessibleRelationSet > SAL_CALL ToolbarMenuEntryAcc::getAccessibleRelationSet()
 {
     return Reference< XAccessibleRelationSet >();
 }
 
 
-
-Reference< XAccessibleStateSet > SAL_CALL ToolbarMenuEntryAcc::getAccessibleStateSet() throw (RuntimeException, std::exception)
+Reference< XAccessibleStateSet > SAL_CALL ToolbarMenuEntryAcc::getAccessibleStateSet()
 {
     const SolarMutexGuard aSolarGuard;
     ::utl::AccessibleStateSetHelper*    pStateSet = new ::utl::AccessibleStateSetHelper;
@@ -758,11 +702,9 @@ Reference< XAccessibleStateSet > SAL_CALL ToolbarMenuEntryAcc::getAccessibleStat
 }
 
 
-
-Locale SAL_CALL ToolbarMenuEntryAcc::getLocale() throw (IllegalAccessibleComponentStateException, RuntimeException, std::exception)
+Locale SAL_CALL ToolbarMenuEntryAcc::getLocale()
 {
-    const OUString aEmptyStr;
-    Locale aRet( aEmptyStr, aEmptyStr, aEmptyStr );
+    Locale aRet( "", "", "" );
 
     Reference< XAccessible > xParent( getAccessibleParent() );
     if( xParent.is() )
@@ -777,8 +719,7 @@ Locale SAL_CALL ToolbarMenuEntryAcc::getLocale() throw (IllegalAccessibleCompone
 }
 
 
-
-void SAL_CALL ToolbarMenuEntryAcc::addAccessibleEventListener( const Reference< XAccessibleEventListener >& rxListener ) throw (RuntimeException, std::exception)
+void SAL_CALL ToolbarMenuEntryAcc::addAccessibleEventListener( const Reference< XAccessibleEventListener >& rxListener )
 {
     const ::osl::MutexGuard aGuard( maMutex );
 
@@ -796,8 +737,7 @@ void SAL_CALL ToolbarMenuEntryAcc::addAccessibleEventListener( const Reference<
 }
 
 
-
-void SAL_CALL ToolbarMenuEntryAcc::removeAccessibleEventListener( const Reference< XAccessibleEventListener >& rxListener ) throw (RuntimeException, std::exception)
+void SAL_CALL ToolbarMenuEntryAcc::removeAccessibleEventListener( const Reference< XAccessibleEventListener >& rxListener )
 {
     const ::osl::MutexGuard aGuard( maMutex );
 
@@ -810,36 +750,33 @@ void SAL_CALL ToolbarMenuEntryAcc::removeAccessibleEventListener( const Referenc
 }
 
 
-
-sal_Bool SAL_CALL ToolbarMenuEntryAcc::containsPoint( const awt::Point& aPoint ) throw (RuntimeException, std::exception)
+sal_Bool SAL_CALL ToolbarMenuEntryAcc::containsPoint( const awt::Point& aPoint )
 {
     const awt::Rectangle    aRect( getBounds() );
     const Point             aSize( aRect.Width, aRect.Height );
     const Point             aNullPoint, aTestPoint( aPoint.X, aPoint.Y );
 
-    return Rectangle( aNullPoint, aSize ).IsInside( aTestPoint );
+    return tools::Rectangle( aNullPoint, aSize ).IsInside( aTestPoint );
 }
 
 
-
-Reference< XAccessible > SAL_CALL ToolbarMenuEntryAcc::getAccessibleAtPoint( const awt::Point& ) throw (RuntimeException, std::exception)
+Reference< XAccessible > SAL_CALL ToolbarMenuEntryAcc::getAccessibleAtPoint( const awt::Point& )
 {
     Reference< XAccessible > xRet;
     return xRet;
 }
 
 
-
-awt::Rectangle SAL_CALL ToolbarMenuEntryAcc::getBounds() throw (RuntimeException, std::exception)
+awt::Rectangle SAL_CALL ToolbarMenuEntryAcc::getBounds()
 {
     const SolarMutexGuard aSolarGuard;
     awt::Rectangle      aRet;
 
     if( mpParent )
     {
-        Rectangle   aRect( mpParent->maRect );
+        tools::Rectangle   aRect( mpParent->maRect );
         Point       aOrigin;
-        Rectangle   aParentRect( aOrigin, mpParent->mrMenu.GetOutputSizePixel() );
+        tools::Rectangle   aParentRect( aOrigin, mpParent->mrMenu.GetOutputSizePixel() );
 
         aRect.Intersection( aParentRect );
 
@@ -853,16 +790,14 @@ awt::Rectangle SAL_CALL ToolbarMenuEntryAcc::getBounds() throw (RuntimeException
 }
 
 
-
-awt::Point SAL_CALL ToolbarMenuEntryAcc::getLocation() throw (RuntimeException, std::exception)
+awt::Point SAL_CALL ToolbarMenuEntryAcc::getLocation()
 {
     const awt::Rectangle aRect( getBounds() );
     return awt::Point( aRect.X, aRect.Y );
 }
 
 
-
-awt::Point SAL_CALL ToolbarMenuEntryAcc::getLocationOnScreen() throw (RuntimeException, std::exception)
+awt::Point SAL_CALL ToolbarMenuEntryAcc::getLocationOnScreen()
 {
     const SolarMutexGuard aSolarGuard;
     awt::Point aRet;
@@ -879,8 +814,7 @@ awt::Point SAL_CALL ToolbarMenuEntryAcc::getLocationOnScreen() throw (RuntimeExc
 }
 
 
-
-awt::Size SAL_CALL ToolbarMenuEntryAcc::getSize() throw (RuntimeException, std::exception)
+awt::Size SAL_CALL ToolbarMenuEntryAcc::getSize()
 {
     const awt::Rectangle aRect( getBounds() );
     awt::Size aRet;
@@ -891,17 +825,17 @@ awt::Size SAL_CALL ToolbarMenuEntryAcc::getSize() throw (RuntimeException, std::
     return aRet;
 }
 
-void SAL_CALL ToolbarMenuEntryAcc::grabFocus() throw (RuntimeException, std::exception)
+void SAL_CALL ToolbarMenuEntryAcc::grabFocus()
 {
     // nothing to do
 }
 
-sal_Int32 SAL_CALL ToolbarMenuEntryAcc::getForeground(  ) throw (RuntimeException, std::exception)
+sal_Int32 SAL_CALL ToolbarMenuEntryAcc::getForeground(  )
 {
     return static_cast<sal_Int32>(Application::GetSettings().GetStyleSettings().GetMenuTextColor().GetColor());
 }
 
-sal_Int32 SAL_CALL ToolbarMenuEntryAcc::getBackground(  )  throw (RuntimeException, std::exception)
+sal_Int32 SAL_CALL ToolbarMenuEntryAcc::getBackground(  )
 {
     return static_cast<sal_Int32>(Application::GetSettings().GetStyleSettings().GetMenuColor().GetColor());
 }
