@@ -23,9 +23,8 @@
 #include <com/sun/star/frame/XDispatchProvider.hpp>
 #include <com/sun/star/lang/DisposedException.hpp>
 #include <com/sun/star/lang/XMultiServiceFactory.hpp>
-#include <com/sun/star/frame/XLayoutManager.hpp>
 #include <com/sun/star/util/URLTransformer.hpp>
-#include <osl/mutex.hxx>
+#include <cppuhelper/queryinterface.hxx>
 #include <vcl/svapp.hxx>
 #include <vcl/window.hxx>
 #include <vcl/status.hxx>
@@ -35,12 +34,12 @@
 #include <comphelper/processfactory.hxx>
 
 using namespace ::cppu;
-using namespace ::com::sun::star::awt;
-using namespace ::com::sun::star::uno;
-using namespace ::com::sun::star::util;
-using namespace ::com::sun::star::beans;
-using namespace ::com::sun::star::lang;
-using namespace ::com::sun::star::frame;
+using namespace css::awt;
+using namespace css::uno;
+using namespace css::util;
+using namespace css::beans;
+using namespace css::lang;
+using namespace css::frame;
 
 namespace svt
 {
@@ -51,8 +50,8 @@ StatusbarController::StatusbarController(
     const OUString& aCommandURL,
     unsigned short nID ) :
     OWeakObject()
-    ,   m_bInitialized( sal_False )
-    ,   m_bDisposed( sal_False )
+    ,   m_bInitialized( false )
+    ,   m_bDisposed( false )
     ,   m_nID( nID )
     ,   m_xFrame( xFrame )
     ,   m_xContext( rxContext )
@@ -63,8 +62,8 @@ StatusbarController::StatusbarController(
 
 StatusbarController::StatusbarController() :
     OWeakObject()
-    ,   m_bInitialized( sal_False )
-    ,   m_bDisposed( sal_False )
+    ,   m_bInitialized( false )
+    ,   m_bDisposed( false )
     ,   m_nID( 0 )
     ,   m_aListenerContainer( m_aMutex )
 {
@@ -85,7 +84,7 @@ Reference< XURLTransformer > StatusbarController::getURLTransformer() const
     SolarMutexGuard aSolarMutexGuard;
     if ( !m_xURLTransformer.is() && m_xContext.is() )
     {
-        m_xURLTransformer = com::sun::star::util::URLTransformer::create( m_xContext );
+        m_xURLTransformer = css::util::URLTransformer::create( m_xContext );
     }
 
     return m_xURLTransformer;
@@ -93,7 +92,6 @@ Reference< XURLTransformer > StatusbarController::getURLTransformer() const
 
 // XInterface
 Any SAL_CALL StatusbarController::queryInterface( const Type& rType )
-throw ( RuntimeException )
 {
     Any a = ::cppu::queryInterface(
                 rType ,
@@ -121,7 +119,6 @@ void SAL_CALL StatusbarController::release() throw ()
 }
 
 void SAL_CALL StatusbarController::initialize( const Sequence< Any >& aArguments )
-throw ( Exception, RuntimeException )
 {
     bool bInitialized( true );
 
@@ -134,43 +131,42 @@ throw ( Exception, RuntimeException )
         bInitialized = m_bInitialized;
     }
 
-    if ( !bInitialized )
+    if ( bInitialized )
+        return;
+
+    SolarMutexGuard aSolarMutexGuard;
+    m_bInitialized = true;
+
+    PropertyValue aPropValue;
+    for ( int i = 0; i < aArguments.getLength(); i++ )
     {
-        SolarMutexGuard aSolarMutexGuard;
-        m_bInitialized = sal_True;
-
-        PropertyValue aPropValue;
-        for ( int i = 0; i < aArguments.getLength(); i++ )
+        if ( aArguments[i] >>= aPropValue )
         {
-            if ( aArguments[i] >>= aPropValue )
+            if ( aPropValue.Name == "Frame" )
+                aPropValue.Value >>= m_xFrame;
+            else if ( aPropValue.Name == "CommandURL" )
+                aPropValue.Value >>= m_aCommandURL;
+            else if ( aPropValue.Name == "ServiceManager" )
             {
-                if ( aPropValue.Name == "Frame" )
-                    aPropValue.Value >>= m_xFrame;
-                else if ( aPropValue.Name == "CommandURL" )
-                    aPropValue.Value >>= m_aCommandURL;
-                else if ( aPropValue.Name == "ServiceManager" )
-                {
-                    Reference<XMultiServiceFactory> xMSF;
-                    aPropValue.Value >>= xMSF;
-                    if( xMSF.is() )
-                        m_xContext = comphelper::getComponentContext(xMSF);
-                }
-                else if ( aPropValue.Name == "ParentWindow" )
-                    aPropValue.Value >>= m_xParentWindow;
-                else if ( aPropValue.Name == "Identifier" )
-                    aPropValue.Value >>= m_nID;
-                else if ( aPropValue.Name == "StatusbarItem" )
-                    aPropValue.Value >>= m_xStatusbarItem;
+                Reference<XMultiServiceFactory> xMSF;
+                aPropValue.Value >>= xMSF;
+                if( xMSF.is() )
+                    m_xContext = comphelper::getComponentContext(xMSF);
             }
+            else if ( aPropValue.Name == "ParentWindow" )
+                aPropValue.Value >>= m_xParentWindow;
+            else if ( aPropValue.Name == "Identifier" )
+                aPropValue.Value >>= m_nID;
+            else if ( aPropValue.Name == "StatusbarItem" )
+                aPropValue.Value >>= m_xStatusbarItem;
         }
-
-        if ( !m_aCommandURL.isEmpty() )
-            m_aListenerMap.insert( URLToDispatchMap::value_type( m_aCommandURL, Reference< XDispatch >() ));
     }
+
+    if ( !m_aCommandURL.isEmpty() )
+        m_aListenerMap.emplace( m_aCommandURL, Reference< XDispatch >() );
 }
 
 void SAL_CALL StatusbarController::update()
-throw ( RuntimeException )
 {
     {
         SolarMutexGuard aSolarMutexGuard;
@@ -184,7 +180,6 @@ throw ( RuntimeException )
 
 // XComponent
 void SAL_CALL StatusbarController::dispose()
-throw (::com::sun::star::uno::RuntimeException)
 {
     Reference< XComponent > xThis( static_cast< OWeakObject* >(this), UNO_QUERY );
 
@@ -194,14 +189,14 @@ throw (::com::sun::star::uno::RuntimeException)
             throw DisposedException();
     }
 
-    com::sun::star::lang::EventObject aEvent( xThis );
+    css::lang::EventObject aEvent( xThis );
     m_aListenerContainer.disposeAndClear( aEvent );
 
     SolarMutexGuard aSolarMutexGuard;
     Reference< XStatusListener > xStatusListener( static_cast< OWeakObject* >( this ), UNO_QUERY );
     Reference< XURLTransformer > xURLTransformer = getURLTransformer();
     URLToDispatchMap::iterator pIter = m_aListenerMap.begin();
-    com::sun::star::util::URL aTargetURL;
+    css::util::URL aTargetURL;
     while ( pIter != m_aListenerMap.end() )
     {
         try
@@ -230,24 +225,21 @@ throw (::com::sun::star::uno::RuntimeException)
     m_xParentWindow.clear();
     m_xStatusbarItem.clear();
 
-    m_bDisposed = sal_True;
+    m_bDisposed = true;
 }
 
 void SAL_CALL StatusbarController::addEventListener( const Reference< XEventListener >& xListener )
-throw ( RuntimeException )
 {
-    m_aListenerContainer.addInterface( ::getCppuType( ( const Reference< XEventListener >* ) NULL ), xListener );
+    m_aListenerContainer.addInterface( cppu::UnoType<XEventListener>::get(), xListener );
 }
 
 void SAL_CALL StatusbarController::removeEventListener( const Reference< XEventListener >& aListener )
-throw ( RuntimeException )
 {
-    m_aListenerContainer.removeInterface( ::getCppuType( ( const Reference< XEventListener >* ) NULL ), aListener );
+    m_aListenerContainer.removeInterface( cppu::UnoType<XEventListener>::get(), aListener );
 }
 
 // XEventListener
 void SAL_CALL StatusbarController::disposing( const EventObject& Source )
-throw ( RuntimeException )
 {
     SolarMutexGuard aSolarMutexGuard;
 
@@ -278,18 +270,17 @@ throw ( RuntimeException )
 
 // XStatusListener
 void SAL_CALL StatusbarController::statusChanged( const FeatureStateEvent& Event )
-throw ( RuntimeException )
 {
     SolarMutexGuard aSolarMutexGuard;
 
     if ( m_bDisposed )
         return;
 
-    Window* pWindow = VCLUnoHelper::GetWindow( m_xParentWindow );
-    if ( pWindow && pWindow->GetType() == WINDOW_STATUSBAR && m_nID != 0 )
+    VclPtr<vcl::Window> pWindow = VCLUnoHelper::GetWindow( m_xParentWindow );
+    if ( pWindow && pWindow->GetType() == WindowType::STATUSBAR && m_nID != 0 )
     {
-        OUString aStrValue;
-        StatusBar*    pStatusBar = (StatusBar *)pWindow;
+        OUString   aStrValue;
+        StatusBar* pStatusBar = static_cast<StatusBar *>(pWindow.get());
 
         if ( Event.State >>= aStrValue )
             pStatusBar->SetItemText( m_nID, aStrValue );
@@ -299,50 +290,44 @@ throw ( RuntimeException )
 }
 
 // XStatusbarController
-::sal_Bool SAL_CALL StatusbarController::mouseButtonDown(
-    const ::com::sun::star::awt::MouseEvent& )
-throw (::com::sun::star::uno::RuntimeException)
+sal_Bool SAL_CALL StatusbarController::mouseButtonDown(
+    const css::awt::MouseEvent& )
 {
-    return sal_False;
+    return false;
 }
 
-::sal_Bool SAL_CALL StatusbarController::mouseMove(
-    const ::com::sun::star::awt::MouseEvent& )
-throw (::com::sun::star::uno::RuntimeException)
+sal_Bool SAL_CALL StatusbarController::mouseMove(
+    const css::awt::MouseEvent& )
 {
-    return sal_False;
+    return false;
 }
 
-::sal_Bool SAL_CALL StatusbarController::mouseButtonUp(
-    const ::com::sun::star::awt::MouseEvent& )
-throw (::com::sun::star::uno::RuntimeException)
+sal_Bool SAL_CALL StatusbarController::mouseButtonUp(
+    const css::awt::MouseEvent& )
 {
-    return sal_False;
+    return false;
 }
 
 void SAL_CALL StatusbarController::command(
-    const ::com::sun::star::awt::Point&,
+    const css::awt::Point&,
     ::sal_Int32,
-    ::sal_Bool,
-    const ::com::sun::star::uno::Any& )
-throw (::com::sun::star::uno::RuntimeException)
+    sal_Bool,
+    const css::uno::Any& )
 {
 }
 
 void SAL_CALL StatusbarController::paint(
-    const ::com::sun::star::uno::Reference< ::com::sun::star::awt::XGraphics >&,
-    const ::com::sun::star::awt::Rectangle&,
+    const css::uno::Reference< css::awt::XGraphics >&,
+    const css::awt::Rectangle&,
     ::sal_Int32 )
-throw (::com::sun::star::uno::RuntimeException)
 {
 }
 
-void SAL_CALL StatusbarController::click( const ::com::sun::star::awt::Point& )
-throw (::com::sun::star::uno::RuntimeException)
+void SAL_CALL StatusbarController::click( const css::awt::Point& )
 {
 }
 
-void SAL_CALL StatusbarController::doubleClick( const ::com::sun::star::awt::Point& ) throw (::com::sun::star::uno::RuntimeException)
+void SAL_CALL StatusbarController::doubleClick( const css::awt::Point& )
 {
     SolarMutexGuard aSolarMutexGuard;
 
@@ -357,7 +342,7 @@ void StatusbarController::addStatusListener( const OUString& aCommandURL )
 {
     Reference< XDispatch >       xDispatch;
     Reference< XStatusListener > xStatusListener;
-    com::sun::star::util::URL    aTargetURL;
+    css::util::URL    aTargetURL;
 
     {
         SolarMutexGuard aSolarMutexGuard;
@@ -368,16 +353,16 @@ void StatusbarController::addStatusListener( const OUString& aCommandURL )
             return;
 
         // Check if we are already initialized. Implementation starts adding itself as status listener when
-        // intialize is called.
+        // initialize is called.
         if ( !m_bInitialized )
         {
-            // Put into the boost::unordered_map of status listener. Will be activated when initialized is called
-            m_aListenerMap.insert( URLToDispatchMap::value_type( aCommandURL, Reference< XDispatch >() ));
+            // Put into the unordered_map of status listener. Will be activated when initialized is called
+            m_aListenerMap.emplace( aCommandURL, Reference< XDispatch >() );
             return;
         }
         else
         {
-            // Add status listener directly as intialize has already been called.
+            // Add status listener directly as initialize has already been called.
             Reference< XDispatchProvider > xDispatchProvider( m_xFrame, UNO_QUERY );
             if ( m_xContext.is() && xDispatchProvider.is() )
             {
@@ -386,7 +371,7 @@ void StatusbarController::addStatusListener( const OUString& aCommandURL )
                 xURLTransformer->parseStrict( aTargetURL );
                 xDispatch = xDispatchProvider->queryDispatch( aTargetURL, OUString(), 0 );
 
-                xStatusListener = Reference< XStatusListener >( static_cast< OWeakObject* >( this ), UNO_QUERY );
+                xStatusListener.set( static_cast< OWeakObject* >( this ), UNO_QUERY );
                 URLToDispatchMap::iterator aIter = m_aListenerMap.find( aCommandURL );
                 if ( aIter != m_aListenerMap.end() )
                 {
@@ -403,7 +388,7 @@ void StatusbarController::addStatusListener( const OUString& aCommandURL )
                     }
                 }
                 else
-                    m_aListenerMap.insert( URLToDispatchMap::value_type( aCommandURL, xDispatch ));
+                    m_aListenerMap.emplace( aCommandURL, xDispatch );
             }
         }
     }
@@ -434,12 +419,12 @@ void StatusbarController::bindListener()
         Reference< XDispatchProvider > xDispatchProvider( m_xFrame, UNO_QUERY );
         if ( m_xContext.is() && xDispatchProvider.is() )
         {
-            xStatusListener = Reference< XStatusListener >( static_cast< OWeakObject* >( this ), UNO_QUERY );
+            xStatusListener.set( static_cast< OWeakObject* >( this ), UNO_QUERY );
             URLToDispatchMap::iterator pIter = m_aListenerMap.begin();
             while ( pIter != m_aListenerMap.end() )
             {
                 Reference< XURLTransformer > xURLTransformer = getURLTransformer();
-                com::sun::star::util::URL aTargetURL;
+                css::util::URL aTargetURL;
                 aTargetURL.Complete = pIter->first;
                 xURLTransformer->parseStrict( aTargetURL );
 
@@ -481,11 +466,10 @@ void StatusbarController::bindListener()
     if ( !xStatusListener.is() )
         return;
 
-    for ( sal_uInt32 i = 0; i < aDispatchVector.size(); i++ )
+    for (Listener & rListener : aDispatchVector)
     {
         try
         {
-            Listener& rListener = aDispatchVector[i];
             if ( rListener.xDispatch.is() )
                 rListener.xDispatch->addStatusListener( xStatusListener, rListener.aURL );
             else if ( rListener.aURL.Complete == m_aCommandURL )
@@ -494,7 +478,7 @@ void StatusbarController::bindListener()
                 // UI disables the button. Catch exception as we release our mutex, it is possible
                 // that someone else already disposed this instance!
                 FeatureStateEvent aFeatureStateEvent;
-                aFeatureStateEvent.IsEnabled = sal_False;
+                aFeatureStateEvent.IsEnabled = false;
                 aFeatureStateEvent.FeatureURL = rListener.aURL;
                 aFeatureStateEvent.State = Any();
                 xStatusListener->statusChanged( aFeatureStateEvent );
@@ -504,9 +488,9 @@ void StatusbarController::bindListener()
     }
 }
 
-::Rectangle StatusbarController::getControlRect() const
+::tools::Rectangle StatusbarController::getControlRect() const
 {
-    ::Rectangle aRect;
+    ::tools::Rectangle aRect;
 
     {
         SolarMutexGuard aSolarMutexGuard;
@@ -516,8 +500,8 @@ void StatusbarController::bindListener()
 
         if ( m_xParentWindow.is() )
         {
-            StatusBar* pStatusBar = dynamic_cast< StatusBar* >( VCLUnoHelper::GetWindow( m_xParentWindow ));
-            if ( pStatusBar && pStatusBar->GetType() == WINDOW_STATUSBAR )
+            VclPtr< StatusBar > pStatusBar = dynamic_cast< StatusBar* >( VCLUnoHelper::GetWindow( m_xParentWindow ).get() );
+            if ( pStatusBar && pStatusBar->GetType() == WindowType::STATUSBAR )
                 aRect = pStatusBar->GetItemRect( m_nID );
         }
     }
@@ -525,7 +509,7 @@ void StatusbarController::bindListener()
     return aRect;
 }
 
-void StatusbarController::execute( const ::com::sun::star::uno::Sequence< ::com::sun::star::beans::PropertyValue >& aArgs )
+void StatusbarController::execute( const css::uno::Sequence< css::beans::PropertyValue >& aArgs )
 {
     Reference< XDispatch >       xDispatch;
     Reference< XURLTransformer > xURLTransformer;
@@ -550,28 +534,28 @@ void StatusbarController::execute( const ::com::sun::star::uno::Sequence< ::com:
         }
     }
 
-    if ( xDispatch.is() && xURLTransformer.is() )
-    {
-        try
-        {
-            com::sun::star::util::URL aTargetURL;
+    if ( !(xDispatch.is() && xURLTransformer.is()) )
+        return;
 
-            aTargetURL.Complete = aCommandURL;
-            xURLTransformer->parseStrict( aTargetURL );
-            xDispatch->dispatch( aTargetURL, aArgs );
-        }
-        catch ( DisposedException& )
-        {
-        }
+    try
+    {
+        css::util::URL aTargetURL;
+
+        aTargetURL.Complete = aCommandURL;
+        xURLTransformer->parseStrict( aTargetURL );
+        xDispatch->dispatch( aTargetURL, aArgs );
+    }
+    catch ( DisposedException& )
+    {
     }
 }
 
 void StatusbarController::execute(
     const OUString& aCommandURL,
-    const Sequence< ::com::sun::star::beans::PropertyValue >& aArgs )
+    const Sequence< css::beans::PropertyValue >& aArgs )
 {
     Reference< XDispatch >      xDispatch;
-    com::sun::star::util::URL   aTargetURL;
+    css::util::URL   aTargetURL;
 
     {
         SolarMutexGuard aSolarMutexGuard;
@@ -593,7 +577,7 @@ void StatusbarController::execute(
                 xDispatch = pIter->second;
             else
             {
-                Reference< ::com::sun::star::frame::XDispatchProvider > xDispatchProvider(
+                Reference< css::frame::XDispatchProvider > xDispatchProvider(
                     m_xFrame->getController(), UNO_QUERY );
                 if ( xDispatchProvider.is() )
                     xDispatch = xDispatchProvider->queryDispatch( aTargetURL, OUString(), 0 );
