@@ -25,29 +25,27 @@
 
 static const sal_Unicode TOKEN_SEPARATOR = '\001';
 
-bool INetImage::Write( SvStream& rOStm, SotClipboardFormatId nFormat ) const
+void INetImage::Write( SvStream& rOStm, SotClipboardFormatId nFormat ) const
 {
-    bool bRet = false;
     switch( nFormat )
     {
     case SotClipboardFormatId::INET_IMAGE:
         {
             OUString sString(
-                aImageURL + OUStringLiteral1<TOKEN_SEPARATOR>() + aTargetURL
-                + OUStringLiteral1<TOKEN_SEPARATOR>() + aTargetFrame
-                + OUStringLiteral1<TOKEN_SEPARATOR>() + aAlternateText
-                + OUStringLiteral1<TOKEN_SEPARATOR>()
+                aImageURL + OUStringLiteral1(TOKEN_SEPARATOR) + aTargetURL
+                + OUStringLiteral1(TOKEN_SEPARATOR) + aTargetFrame
+                + OUStringLiteral1(TOKEN_SEPARATOR) /* + aAlternateText */
+                + OUStringLiteral1(TOKEN_SEPARATOR)
                 + OUString::number(aSizePixel.Width())
-                + OUStringLiteral1<TOKEN_SEPARATOR>()
+                + OUStringLiteral1(TOKEN_SEPARATOR)
                 + OUString::number(aSizePixel.Height()));
 
             OString sOut(OUStringToOString(sString,
                 RTL_TEXTENCODING_UTF8));
 
-            rOStm.Write(sOut.getStr(), sOut.getLength());
+            rOStm.WriteBytes(sOut.getStr(), sOut.getLength());
             static const sal_Char aEndChar[2] = { 0 };
-            rOStm.Write( aEndChar, sizeof( aEndChar ));
-            bRet = 0 == rOStm.GetError();
+            rOStm.WriteBytes(aEndChar, sizeof(aEndChar));
         }
         break;
 
@@ -55,7 +53,6 @@ bool INetImage::Write( SvStream& rOStm, SotClipboardFormatId nFormat ) const
         break;
     default: break;
     }
-    return bRet;
 }
 
 bool INetImage::Read( SvStream& rIStm, SotClipboardFormatId nFormat )
@@ -70,7 +67,7 @@ bool INetImage::Read( SvStream& rIStm, SotClipboardFormatId nFormat )
             aImageURL = sINetImg.getToken( 0, TOKEN_SEPARATOR, nStart );
             aTargetURL = sINetImg.getToken( 0, TOKEN_SEPARATOR, nStart );
             aTargetFrame = sINetImg.getToken( 0, TOKEN_SEPARATOR, nStart );
-            aAlternateText = sINetImg.getToken( 0, TOKEN_SEPARATOR, nStart );
+            /*aAlternateText =*/ sINetImg.getToken( 0, TOKEN_SEPARATOR, nStart );
             aSizePixel.Width() = sINetImg.getToken( 0, TOKEN_SEPARATOR,
                                                     nStart ).toInt32();
             aSizePixel.Height() = sINetImg.getToken( 0, TOKEN_SEPARATOR,
@@ -97,7 +94,8 @@ bool INetImage::Read( SvStream& rIStm, SotClipboardFormatId nFormat )
     sal_Char pImageURL[1];      // Append all variable-length strings starting here
 */
             rtl_TextEncoding eSysCSet = osl_getThreadTextEncoding();
-            sal_Int32 nVal, nAnchorOffset, nAltOffset, nFilePos;
+            sal_Int32 nVal, nAnchorOffset, nAltOffset;
+            sal_uInt64 nFilePos;
 
             nFilePos = rIStm.Tell();
             // skip over iSize (int), bIsMao ( sal_Bool ) alignment of 4 !!!!
@@ -115,10 +113,8 @@ bool INetImage::Read( SvStream& rIStm, SotClipboardFormatId nFormat )
             if( nAltOffset )
             {
                 rIStm.Seek( nFilePos + nAltOffset );
-                aAlternateText = read_zeroTerminated_uInt8s_ToOUString(rIStm, eSysCSet);
+                /*aAlternateText =*/ read_zeroTerminated_uInt8s_ToOUString(rIStm, eSysCSet);
             }
-            else if( !aAlternateText.isEmpty() )
-                aAlternateText.clear();
 
             if( nAnchorOffset )
             {
@@ -128,7 +124,7 @@ bool INetImage::Read( SvStream& rIStm, SotClipboardFormatId nFormat )
             else if( !aTargetURL.isEmpty() )
                 aTargetURL.clear();
 
-            bRet = 0 == rIStm.GetError();
+            bRet = ERRCODE_NONE == rIStm.GetError();
         }
         break;
     default: break;
