@@ -25,7 +25,7 @@
 
 #include <cppuhelper/queryinterface.hxx>
 
-using namespace accessibility;
+using namespace ::accessibility;
 using namespace ::com::sun::star;
 using namespace ::com::sun::star::uno;
 using namespace ::com::sun::star::accessibility;
@@ -39,54 +39,39 @@ AccessibleOLEShape::AccessibleOLEShape (
 }
 
 
-
-
 AccessibleOLEShape::~AccessibleOLEShape()
 {
 }
 
 // XAccessibleAction
 sal_Int32 SAL_CALL AccessibleOLEShape::getAccessibleActionCount()
-    throw (::com::sun::star::uno::RuntimeException, std::exception)
 {
     return 0;
 }
 
 
-
-
 sal_Bool SAL_CALL AccessibleOLEShape::doAccessibleAction (sal_Int32 /*nIndex*/)
-    throw (lang::IndexOutOfBoundsException, uno::RuntimeException, std::exception)
 {
     throw lang::IndexOutOfBoundsException();
 }
 
 
-
-
 OUString SAL_CALL AccessibleOLEShape::getAccessibleActionDescription (sal_Int32 /*nIndex*/)
-    throw (::com::sun::star::lang::IndexOutOfBoundsException,
-        ::com::sun::star::uno::RuntimeException, std::exception)
 {
     throw lang::IndexOutOfBoundsException();
 }
 
 
-
-
 Reference<XAccessibleKeyBinding> SAL_CALL AccessibleOLEShape::getAccessibleActionKeyBinding (sal_Int32 /*nIndex*/)
-    throw (::com::sun::star::lang::IndexOutOfBoundsException,
-        ::com::sun::star::uno::RuntimeException, std::exception)
 {
     throw lang::IndexOutOfBoundsException();
 }
 
 // XInterface
-com::sun::star::uno::Any SAL_CALL
-    AccessibleOLEShape::queryInterface (const com::sun::star::uno::Type & rType)
-    throw (::com::sun::star::uno::RuntimeException, std::exception)
+css::uno::Any SAL_CALL
+    AccessibleOLEShape::queryInterface (const css::uno::Type & rType)
 {
-    ::com::sun::star::uno::Any aReturn = AccessibleShape::queryInterface (rType);
+    css::uno::Any aReturn = AccessibleShape::queryInterface (rType);
     if ( ! aReturn.hasValue())
         aReturn = ::cppu::queryInterface (rType,
             static_cast<XAccessibleAction*>(this));
@@ -94,7 +79,6 @@ com::sun::star::uno::Any SAL_CALL
 }
 
 
-
 void SAL_CALL
     AccessibleOLEShape::acquire()
     throw ()
@@ -103,7 +87,6 @@ void SAL_CALL
 }
 
 
-
 void SAL_CALL
     AccessibleOLEShape::release()
     throw ()
@@ -114,17 +97,13 @@ void SAL_CALL
 // XServiceInfo
 OUString SAL_CALL
     AccessibleOLEShape::getImplementationName()
-    throw (::com::sun::star::uno::RuntimeException, std::exception)
 {
     return OUString("AccessibleOLEShape");
 }
 
 
-
-
-::com::sun::star::uno::Sequence< OUString> SAL_CALL
+css::uno::Sequence< OUString> SAL_CALL
     AccessibleOLEShape::getSupportedServiceNames()
-    throw (::com::sun::star::uno::RuntimeException, std::exception)
 {
     ThrowIfDisposed();
     // Get list of supported service names from base class...
@@ -142,7 +121,6 @@ OUString SAL_CALL
 // XTypeProvider
 uno::Sequence<uno::Type> SAL_CALL
     AccessibleOLEShape::getTypes()
-    throw (uno::RuntimeException, std::exception)
 {
     // Get list of types from the context base implementation...
     uno::Sequence<uno::Type> aTypeList (AccessibleShape::getTypes());
@@ -158,7 +136,6 @@ uno::Sequence<uno::Type> SAL_CALL
 
 // XAccessibleExtendedAttributes
 uno::Any SAL_CALL AccessibleOLEShape::getExtendedAttributes()
-        throw (::com::sun::star::lang::IndexOutOfBoundsException, ::com::sun::star::uno::RuntimeException, std::exception)
 {
     uno::Any strRet;
     ::rtl::OUString style;
@@ -174,7 +151,6 @@ uno::Any SAL_CALL AccessibleOLEShape::getExtendedAttributes()
 /// Set this object's name if is different to the current name.
 OUString
     AccessibleOLEShape::CreateAccessibleBaseName()
-    throw (::com::sun::star::uno::RuntimeException)
 {
     OUString sName;
 
@@ -204,11 +180,8 @@ OUString
     return sName;
 }
 
-
-
 OUString
     AccessibleOLEShape::CreateAccessibleDescription()
-    throw (::com::sun::star::uno::RuntimeException)
 {
     return CreateAccessibleName ();
 }
