@@ -29,117 +29,90 @@ namespace accessibility {
 
 // AccessibleChildrenManager
 ChildrenManager::ChildrenManager (
-    const ::com::sun::star::uno::Reference<XAccessible>& rxParent,
-    const ::com::sun::star::uno::Reference<drawing::XShapes>& rxShapeList,
+    const css::uno::Reference<XAccessible>& rxParent,
+    const css::uno::Reference<drawing::XShapes>& rxShapeList,
     const AccessibleShapeTreeInfo& rShapeTreeInfo,
     AccessibleContextBase& rContext)
-    : mpImpl (NULL)
+    : mpImpl(
+        new ChildrenManagerImpl(
+            rxParent, rxShapeList, rShapeTreeInfo, rContext))
 {
-    mpImpl = new ChildrenManagerImpl (rxParent, rxShapeList, rShapeTreeInfo, rContext);
-    if (mpImpl != NULL)
-        mpImpl->Init ();
-    else
-        throw uno::RuntimeException(
-            "ChildrenManager::ChildrenManager can't create implementation object", NULL);
+    mpImpl->Init ();
 }
 
 
-
-
-ChildrenManager::~ChildrenManager (void)
+ChildrenManager::~ChildrenManager()
 {
-    if (mpImpl != NULL)
-        mpImpl->dispose();
+    mpImpl->dispose();
 
-    // emtpy
-    OSL_TRACE ("~ChildrenManager");
+    // empty
+    SAL_INFO("svx", "~ChildrenManager");
 }
 
-long ChildrenManager::GetChildCount (void) const throw ()
+long ChildrenManager::GetChildCount() const throw ()
 {
-    assert(mpImpl != NULL);
     return mpImpl->GetChildCount();
 }
 
-::com::sun::star::uno::Reference<XAccessible> ChildrenManager::GetChild (long nIndex)
-    throw (::com::sun::star::uno::RuntimeException,
-           ::com::sun::star::lang::IndexOutOfBoundsException)
+css::uno::Reference<XAccessible> ChildrenManager::GetChild (long nIndex)
 {
-    assert(mpImpl != NULL);
     return mpImpl->GetChild (nIndex);
 }
 
 Reference<XAccessible> ChildrenManager::GetChild (const Reference<drawing::XShape>& xShape)
-    throw (::com::sun::star::uno::RuntimeException)
 {
-    assert(mpImpl != NULL);
     return mpImpl->GetChild (xShape);
 }
 
-::com::sun::star::uno::Reference<
-        ::com::sun::star::drawing::XShape> ChildrenManager::GetChildShape(long nIndex)
-    throw (::com::sun::star::uno::RuntimeException,
-           ::com::sun::star::lang::IndexOutOfBoundsException)
+css::uno::Reference<css::drawing::XShape> ChildrenManager::GetChildShape(long nIndex)
 {
-    assert(mpImpl != NULL);
     return mpImpl->GetChildShape(nIndex);
 }
 
 void ChildrenManager::Update (bool bCreateNewObjectsOnDemand)
 {
-    assert(mpImpl != NULL);
     mpImpl->Update (bCreateNewObjectsOnDemand);
 }
 
-void ChildrenManager::SetShapeList (const ::com::sun::star::uno::Reference<
-    ::com::sun::star::drawing::XShapes>& xShapeList)
+void ChildrenManager::SetShapeList (const css::uno::Reference<css::drawing::XShapes>& xShapeList)
 {
-    assert(mpImpl != NULL);
     mpImpl->SetShapeList (xShapeList);
 }
 
 void ChildrenManager::AddAccessibleShape (css::uno::Reference<css::accessibility::XAccessible> const & shape)
 {
-    assert(mpImpl != NULL);
     mpImpl->AddAccessibleShape (shape);
 }
 
-void ChildrenManager::ClearAccessibleShapeList (void)
+void ChildrenManager::ClearAccessibleShapeList()
 {
-    assert(mpImpl != NULL);
     mpImpl->ClearAccessibleShapeList ();
 }
 
-void ChildrenManager::SetInfo (AccessibleShapeTreeInfo& rShapeTreeInfo)
+void ChildrenManager::SetInfo (AccessibleShapeTreeInfo const & rShapeTreeInfo)
 {
-    assert(mpImpl != NULL);
     mpImpl->SetInfo (rShapeTreeInfo);
 }
 
-void ChildrenManager::UpdateSelection (void)
+void ChildrenManager::UpdateSelection()
 {
-    assert(mpImpl != NULL);
     mpImpl->UpdateSelection ();
 }
 
-bool ChildrenManager::HasFocus (void)
+bool ChildrenManager::HasFocus()
 {
-    assert(mpImpl != NULL);
     return mpImpl->HasFocus ();
 }
 
-void ChildrenManager::RemoveFocus (void)
+void ChildrenManager::RemoveFocus()
 {
-    assert(mpImpl != NULL);
     mpImpl->RemoveFocus ();
 }
 
 // IAccessibleViewForwarderListener
-void ChildrenManager::ViewForwarderChanged (ChangeType aChangeType,
-        const IAccessibleViewForwarder* pViewForwarder)
+void ChildrenManager::ViewForwarderChanged()
 {
-    assert(mpImpl != NULL);
-    mpImpl->ViewForwarderChanged (aChangeType, pViewForwarder);
+    mpImpl->ViewForwarderChanged();
 }
 
 } // end of namespace accessibility
