@@ -22,15 +22,14 @@
 #include <svx/SvxShapeTypes.hxx>
 #include <svx/AccessibleShapeInfo.hxx>
 #include <com/sun/star/drawing/XShapeDescriptor.hpp>
-#include <osl/mutex.hxx>
 #include <vcl/svapp.hxx>
 #include <svx/dialmgr.hxx>
 
 #include <svx/unoshape.hxx>
 #include <svx/svdoashp.hxx>
-#include "svx/unoapi.hxx"
+#include <svx/unoapi.hxx>
 
-#include "svx/svdstr.hrc"
+#include <svx/strings.hrc>
 
 using namespace ::com::sun::star;
 using namespace ::com::sun::star::accessibility;
@@ -52,8 +51,6 @@ AccessibleShape*
 }
 
 
-
-
 ShapeTypeHandler& ShapeTypeHandler::Instance()
 {
     // Using double check pattern to make sure that exactly one instance of
@@ -75,15 +72,13 @@ ShapeTypeHandler& ShapeTypeHandler::Instance()
 }
 
 
-
-
 /** The given service name is first transformed into a slot id that
     identifies the place of the type descriptor.  From that descriptor the
     shape type id is returned.
 */
 ShapeTypeId ShapeTypeHandler::GetTypeId (const OUString& aServiceName) const
 {
-    tServiceNameToSlotId::iterator I (maServiceNameToSlotId.find (aServiceName));
+    tServiceNameToSlotId::const_iterator I (maServiceNameToSlotId.find (aServiceName));
     if (I != maServiceNameToSlotId.end())
     {
         return maShapeTypeDescriptorList[I->second].mnShapeTypeId;
@@ -93,7 +88,6 @@ ShapeTypeId ShapeTypeHandler::GetTypeId (const OUString& aServiceName) const
 }
 
 
-
 /** Extract the specified shape's service name and forward the request to
     the appropriate method.
 */
@@ -107,8 +101,6 @@ ShapeTypeId ShapeTypeHandler::GetTypeId (const uno::Reference<drawing::XShape>&
 }
 
 
-
-
 /** This factory method determines the type descriptor for the type of the
     given shape, then calls the descriptor's create function, and finally
     initializes the new object.
@@ -128,8 +120,6 @@ rtl::Reference<AccessibleShape>
 }
 
 
-
-
 /** Create the single instance of this class and initialize its list of
     type descriptors with an entry of an unknown type.
 */
@@ -145,8 +135,6 @@ ShapeTypeHandler::ShapeTypeHandler()
 }
 
 
-
-
 ShapeTypeHandler::~ShapeTypeHandler()
 {
     //  Because this class is a singleton and the only instance, whose
@@ -158,9 +146,7 @@ ShapeTypeHandler::~ShapeTypeHandler()
 }
 
 
-
-
-bool ShapeTypeHandler::AddShapeTypeList (int nDescriptorCount,
+void ShapeTypeHandler::AddShapeTypeList (int nDescriptorCount,
     ShapeTypeDescriptor aDescriptorList[])
 {
     SolarMutexGuard aGuard;
@@ -173,11 +159,6 @@ bool ShapeTypeHandler::AddShapeTypeList (int nDescriptorCount,
 
     for (int i=0; i<nDescriptorCount; i++)
     {
-    #if OSL_DEBUG_LEVEL > 0
-        ShapeTypeId nId (aDescriptorList[i].mnShapeTypeId);
-        (void)nId;
-    #endif
-
         // Fill Type descriptor.
         maShapeTypeDescriptorList[nFirstId+i].mnShapeTypeId = aDescriptorList[i].mnShapeTypeId;
         maShapeTypeDescriptorList[nFirstId+i].msServiceName = aDescriptorList[i].msServiceName;
@@ -186,16 +167,12 @@ bool ShapeTypeHandler::AddShapeTypeList (int nDescriptorCount,
         // Update inverse mapping from service name to the descriptor's position.
         maServiceNameToSlotId[aDescriptorList[i].msServiceName] = nFirstId+i;
     }
-
-    return true;
 }
 
 
-
-
 long ShapeTypeHandler::GetSlotId (const OUString& aServiceName) const
 {
-    tServiceNameToSlotId::iterator I (maServiceNameToSlotId.find (aServiceName));
+    tServiceNameToSlotId::const_iterator I (maServiceNameToSlotId.find (aServiceName));
     if (I != maServiceNameToSlotId.end())
         return I->second;
     else
@@ -203,8 +180,6 @@ long ShapeTypeHandler::GetSlotId (const OUString& aServiceName) const
 }
 
 
-
-
 // Extract the given shape's service name and forward request to appropriate
 // method.
 long ShapeTypeHandler::GetSlotId (const uno::Reference<drawing::XShape>& rxShape) const
@@ -217,11 +192,9 @@ long ShapeTypeHandler::GetSlotId (const uno::Reference<drawing::XShape>& rxShape
 }
 
 /// get the accessible base name for an object
-OUString
-    ShapeTypeHandler::CreateAccessibleBaseName (const uno::Reference<drawing::XShape>& rxShape)
-    throw (css::uno::RuntimeException, std::exception)
+OUString ShapeTypeHandler::CreateAccessibleBaseName (const uno::Reference<drawing::XShape>& rxShape)
 {
-    sal_Int32 nResourceId;
+    const char* pResourceId;
     OUString sName;
 
     switch (ShapeTypeHandler::Instance().GetTypeId (rxShape))
@@ -230,74 +203,74 @@ OUString
       // AccessibleShape::CreateAccessibleBaseName.  See issue 11190 for details.
       // Id can be removed from SvxShapeTypes.hxx as well.
         case DRAWING_3D_CUBE:
-            nResourceId = STR_ObjNameSingulCube3d;
+            pResourceId = STR_ObjNameSingulCube3d;
             break;
         case DRAWING_3D_EXTRUDE:
-            nResourceId = STR_ObjNameSingulExtrude3d;
+            pResourceId = STR_ObjNameSingulExtrude3d;
             break;
         case DRAWING_3D_LATHE:
-            nResourceId = STR_ObjNameSingulLathe3d;
+            pResourceId = STR_ObjNameSingulLathe3d;
             break;
         case DRAWING_3D_SCENE:
-            nResourceId = STR_ObjNameSingulScene3d;
+            pResourceId = STR_ObjNameSingulScene3d;
             break;
         case DRAWING_3D_SPHERE:
-            nResourceId = STR_ObjNameSingulSphere3d;
+            pResourceId = STR_ObjNameSingulSphere3d;
             break;
         case DRAWING_CAPTION:
-            nResourceId = STR_ObjNameSingulCAPTION;
+            pResourceId = STR_ObjNameSingulCAPTION;
             break;
         case DRAWING_CLOSED_BEZIER:
-            nResourceId = STR_ObjNameSingulPATHFILL;
+            pResourceId = STR_ObjNameSingulPATHFILL;
             break;
         case DRAWING_CLOSED_FREEHAND:
-            nResourceId = STR_ObjNameSingulFREEFILL;
+            pResourceId = STR_ObjNameSingulFREEFILL;
             break;
         case DRAWING_CONNECTOR:
-            nResourceId = STR_ObjNameSingulEDGE;
+            pResourceId = STR_ObjNameSingulEDGE;
             break;
         case DRAWING_CONTROL:
-            nResourceId = STR_ObjNameSingulUno;
+            pResourceId = STR_ObjNameSingulUno;
             break;
         case DRAWING_ELLIPSE:
-            nResourceId = STR_ObjNameSingulCIRCE;
+            pResourceId = STR_ObjNameSingulCIRCE;
             break;
         case DRAWING_GROUP:
-            nResourceId = STR_ObjNameSingulGRUP;
+            pResourceId = STR_ObjNameSingulGRUP;
             break;
         case DRAWING_LINE:
-            nResourceId = STR_ObjNameSingulLINE;
+            pResourceId = STR_ObjNameSingulLINE;
             break;
         case DRAWING_MEASURE:
-            nResourceId = STR_ObjNameSingulMEASURE;
+            pResourceId = STR_ObjNameSingulMEASURE;
             break;
         case DRAWING_OPEN_BEZIER:
-            nResourceId = STR_ObjNameSingulPATHLINE;
+            pResourceId = STR_ObjNameSingulPATHLINE;
             break;
         case DRAWING_OPEN_FREEHAND:
-            nResourceId = STR_ObjNameSingulFREELINE;
+            pResourceId = STR_ObjNameSingulFREELINE;
             break;
         case DRAWING_PAGE:
-            nResourceId = STR_ObjNameSingulPAGE;
+            pResourceId = STR_ObjNameSingulPAGE;
             break;
         case DRAWING_POLY_LINE:
-            nResourceId = STR_ObjNameSingulPLIN;
+            pResourceId = STR_ObjNameSingulPLIN;
             break;
         case DRAWING_POLY_LINE_PATH:
-            nResourceId = STR_ObjNameSingulPLIN;
+            pResourceId = STR_ObjNameSingulPLIN;
             break;
         case DRAWING_POLY_POLYGON:
-            nResourceId = STR_ObjNameSingulPOLY;
+            pResourceId = STR_ObjNameSingulPOLY;
             break;
         case DRAWING_POLY_POLYGON_PATH:
-            nResourceId = STR_ObjNameSingulPOLY;
+            pResourceId = STR_ObjNameSingulPOLY;
             break;
         case DRAWING_RECTANGLE:
-            nResourceId = STR_ObjNameSingulRECT;
+            pResourceId = STR_ObjNameSingulRECT;
             break;
         case DRAWING_CUSTOM:
             {
-                nResourceId = STR_ObjNameSingulCUSTOMSHAPE;
+                pResourceId = STR_ObjNameSingulCUSTOMSHAPE;
 
                 SvxShape* pShape = SvxShape::getImplementation( rxShape );
                 if (pShape)
@@ -311,10 +284,10 @@ OUString
                             if(pCustomShape)
                             {
                                 if (pCustomShape->IsTextPath())
-                                    nResourceId = STR_ObjNameSingulFONTWORK;
+                                    pResourceId = STR_ObjNameSingulFONTWORK;
                                 else
                                 {
-                                    nResourceId = -1;
+                                    pResourceId = nullptr;
                                     sName = pCustomShape->GetCustomShapeName();
                                 }
                             }
@@ -324,10 +297,10 @@ OUString
                 break;
             }
         case DRAWING_TEXT:
-            nResourceId = STR_ObjNameSingulTEXT;
+            pResourceId = STR_ObjNameSingulTEXT;
             break;
         default:
-            nResourceId = -1;
+            pResourceId = nullptr;
             sName = "UnknownAccessibleShape";
             uno::Reference<drawing::XShapeDescriptor> xDescriptor (rxShape, uno::UNO_QUERY);
             if (xDescriptor.is())
@@ -335,10 +308,10 @@ OUString
             break;
     }
 
-    if (nResourceId != -1)
+    if (pResourceId)
     {
         SolarMutexGuard aGuard;
-        sName = OUString (SVX_RESSTR((unsigned short)nResourceId));
+        sName = SvxResId(pResourceId);
     }
 
     return sName;
