@@ -27,14 +27,14 @@
 #include <sfx2/module.hxx>
 #include <unotools/textsearch.hxx>
 #include <svtools/svlbitm.hxx>
-#include "svtools/viewdataentry.hxx"
+#include <svtools/viewdataentry.hxx>
 #include <unotools/charclass.hxx>
 
 #include <editeng/unolingu.hxx>
 #include <svx/dialmgr.hxx>
-#include "svx/dialogs.hrc"
+#include <svx/strings.hrc>
 #include <svx/ctredlin.hxx>
-#include "helpid.hrc"
+#include <helpids.h>
 
 #define WRITER_DATE     2
 #define CALC_DATE       3
@@ -95,7 +95,6 @@ void SvLBoxColorString::Paint(const Point& rPos, SvTreeListBox& rDev, vcl::Rende
 
 SvxRedlinTable::SvxRedlinTable(SvSimpleTableContainer& rParent, WinBits nBits)
     : SvSimpleTable(rParent,nBits)
-    , bIsCalc(false)
     , nDatePos(WRITER_DATE)
     , bAuthor(false)
     , bDate(false)
@@ -163,9 +162,9 @@ sal_Int32 SvxRedlinTable::ColCompare(SvTreeListEntry* pLeft,SvTreeListEntry* pRi
 
     return nCompare;
 }
+
 void SvxRedlinTable::SetCalcView()
 {
-    bIsCalc=true;
     nDatePos=CALC_DATE;
 }
 
@@ -381,7 +380,7 @@ SvxTPView::SvxTPView(vcl::Window *pParent, VclBuilderContainer *pTopLevel)
 
     SvSimpleTableContainer* pTable = get<SvSimpleTableContainer>("changes");
     Size aControlSize(80, 65);
-    aControlSize = LogicToPixel(aControlSize, MapUnit::MapAppFont);
+    aControlSize = LogicToPixel(aControlSize, MapMode(MapUnit::MapAppFont));
     pTable->set_width_request(aControlSize.Width());
     pTable->set_height_request(aControlSize.Height());
     m_pViewData = VclPtr<SvxRedlinTable>::Create(*pTable, 0);
@@ -715,7 +714,7 @@ void SvxTPFilter::SetDateMode(sal_uInt16 nMode)
 
 SvxRedlinDateMode SvxTPFilter::GetDateMode()
 {
-    return static_cast<SvxRedlinDateMode>(m_pLbDate->GetSelectEntryPos());
+    return static_cast<SvxRedlinDateMode>(m_pLbDate->GetSelectedEntryPos());
 }
 void SvxTPFilter::ClearAuthors()
 {
@@ -729,7 +728,7 @@ void SvxTPFilter::InsertAuthor( const OUString& rString)
 
 OUString SvxTPFilter::GetSelectedAuthor() const
 {
-    return m_pLbAuthor->GetSelectEntry();
+    return m_pLbAuthor->GetSelectedEntry();
 }
 
 void SvxTPFilter::SelectedAuthorPos(sal_Int32 nPos)
@@ -740,7 +739,7 @@ void SvxTPFilter::SelectedAuthorPos(sal_Int32 nPos)
 sal_Int32 SvxTPFilter::SelectAuthor(const OUString& aString)
 {
     m_pLbAuthor->SelectEntry(aString);
-    return m_pLbAuthor->GetSelectEntryPos();
+    return m_pLbAuthor->GetSelectedEntryPos();
 }
 
 void SvxTPFilter::SetRange(const OUString& rString)
@@ -863,7 +862,7 @@ void SvxTPFilter::ShowAction(bool bShow)
 
 IMPL_LINK_NOARG( SvxTPFilter, SelDateHdl, ListBox&, void )
 {
-    SvxRedlinDateMode nKind = static_cast<SvxRedlinDateMode>(m_pLbDate->GetSelectEntryPos());
+    SvxRedlinDateMode nKind = static_cast<SvxRedlinDateMode>(m_pLbDate->GetSelectedEntryPos());
     switch(nKind)
     {
         case SvxRedlinDateMode::BEFORE:
