@@ -17,7 +17,7 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "svx/dlgutil.hxx"
+#include <svx/dlgutil.hxx>
 #include <svl/itemset.hxx>
 #include <sfx2/sfxsids.hrc>
 #include <sfx2/module.hxx>
@@ -27,7 +27,6 @@
 #include <sfx2/objsh.hxx>
 
 
-
 FieldUnit GetModuleFieldUnit( const SfxItemSet& rSet )
 {
     FieldUnit eUnit = FUNIT_INCH;
