@@ -38,7 +38,8 @@
 #include <svtools/sampletext.hxx>
 
 #include <svx/fntctrl.hxx>
-#include <svx/dialogs.hrc>
+#include <svx/svxids.hrc>
+#include <svx/strings.hrc>
 #include <svx/sdasitm.hxx>
 
 // Item set includes
@@ -83,7 +84,7 @@ using ::com::sun::star::i18n::BreakIterator;
 
 namespace
 {
-void scaleFontWidth(vcl::Font& rFont, vcl::RenderContext& rRenderContext,long& n100PercentFont)
+void scaleFontWidth(vcl::Font& rFont, vcl::RenderContext const & rRenderContext,long& n100PercentFont)
 {
     rFont.SetAverageFontWidth(0);
     n100PercentFont = rRenderContext.GetFontMetric(rFont).GetAverageFontWidth();
@@ -194,13 +195,13 @@ public:
     }
 
     void CheckScript();
-    Size CalcTextSize(vcl::RenderContext& rRenderContext, OutputDevice* pPrinter, const SvxFont& rFont);
+    Size CalcTextSize(vcl::RenderContext& rRenderContext, OutputDevice const * pPrinter, const SvxFont& rFont);
     void DrawPrev(vcl::RenderContext& rRenderContext, Printer* pPrinter, Point& rPt, const SvxFont& rFont);
 
     bool SetFontWidthScale(sal_uInt16 nScaleInPercent);
     inline void Invalidate100PercentFontWidth();
     inline bool Is100PercentFontWidthValid() const;
-    void ScaleFontWidth(vcl::RenderContext& rRenderContext);
+    void ScaleFontWidth(vcl::RenderContext const & rRenderContext);
                             // scales rNonCJKFont and aCJKFont depending on nFontWidthScale and
                             // sets the 100%-Font-Widths
 };
@@ -287,7 +288,7 @@ void FontPrevWin_Impl::CheckScript()
  * The member nAscent is calculated to the maximal ascent of all used fonts.
  */
 
-Size FontPrevWin_Impl::CalcTextSize(vcl::RenderContext& rRenderContext, OutputDevice* _pPrinter, const SvxFont& rInFont)
+Size FontPrevWin_Impl::CalcTextSize(vcl::RenderContext& rRenderContext, OutputDevice const * _pPrinter, const SvxFont& rInFont)
 {
     sal_uInt16 nScript;
     sal_uInt16 nIdx = 0;
@@ -434,7 +435,7 @@ bool FontPrevWin_Impl::SetFontWidthScale(sal_uInt16 nScale)
     return false;
 }
 
-void FontPrevWin_Impl::ScaleFontWidth(vcl::RenderContext& rOutDev)
+void FontPrevWin_Impl::ScaleFontWidth(vcl::RenderContext const & rOutDev)
 {
     if (!Is100PercentFontWidthValid())
     {
@@ -611,6 +612,24 @@ void SvxFontPrevWindow::UseResourceText()
     pImpl->mbUseResText = true;
 }
 
+/*
+ * removes line feeds and carriage returns from string
+ * returns if param is empty
+ */
+bool CleanAndCheckEmpty(OUString& rText)
+{
+    bool bEmpty = true;
+    for (sal_Int32 i = 0; i < rText.getLength(); ++i)
+    {
+        if (0xa == rText[i] || 0xd == rText[i])
+            rText = rText.replaceAt(i, 1, " ");
+        else
+            bEmpty = false;
+    }
+    return bEmpty;
+}
+
+
 void SvxFontPrevWindow::Paint(vcl::RenderContext& rRenderContext, const tools::Rectangle&)
 {
     ApplySettings(rRenderContext);
@@ -644,7 +663,7 @@ void SvxFontPrevWindow::Paint(vcl::RenderContext& rRenderContext, const tools::R
             {
                 pImpl->maText = pSh->GetSelectionText();
                 pImpl->mbGetSelection = true;
-                pImpl->mbSelection = !pImpl->maText.isEmpty();
+                pImpl->mbSelection = !CleanAndCheckEmpty(pImpl->maText);
             }
 
             if (!pImpl->mbSelection || pImpl->mbUseFontNameAsText)
@@ -680,16 +699,8 @@ void SvxFontPrevWindow::Paint(vcl::RenderContext& rRenderContext, const tools::R
                 pImpl->maText = makeRepresentativeTextForFont(LATIN, rFont);
             }
 
-            // remove line feeds and carriage returns from string
-            bool bNotEmpty = false;
-            for (sal_Int32 i = 0; i < pImpl->maText.getLength(); ++i)
-            {
-                if (0xa == pImpl->maText[i] || 0xd == pImpl->maText[i])
-                     pImpl->maText = pImpl->maText.replaceAt(i, 1, " ");
-                else
-                    bNotEmpty = true;
-            }
-            if (!bNotEmpty)
+            bool bEmpty = CleanAndCheckEmpty(pImpl->maText);
+            if (bEmpty)
                 pImpl->maText = GetText();
 
             if (pImpl->maText.getLength() > (TEXT_WIDTH - 1))
@@ -1012,7 +1023,7 @@ void SvxFontPrevWindow::SetFromItemSet(const SfxItemSet &rSet, bool bPreviewBack
     if( GetWhich( rSet, SID_ATTR_CHAR_CASEMAP, nWhich ) )
     {
         const SvxCaseMapItem& rItem = static_cast<const SvxCaseMapItem&>( rSet.Get( nWhich ) );
-        SvxCaseMap eCaseMap = ( SvxCaseMap ) rItem.GetValue();
+        SvxCaseMap eCaseMap = rItem.GetValue();
         rFont.SetCaseMap( eCaseMap );
         rCJKFont.SetCaseMap( eCaseMap );
         // #i78474# small caps do not exist in CTL fonts
@@ -1254,7 +1265,7 @@ void SvxFontPrevWindow::Init(const SfxItemSet& rSet)
     if( ISITEMSET )
     {
         const SvxCaseMapItem& rItem = static_cast<const SvxCaseMapItem&>( rSet.Get( nWhich ) );
-        SvxCaseMap eCaseMap = ( SvxCaseMap ) rItem.GetValue();
+        SvxCaseMap eCaseMap = rItem.GetValue();
         rFont.SetCaseMap( eCaseMap );
         rCJKFont.SetCaseMap( eCaseMap );
         // #i78474# small caps do not exist in CTL fonts
