@@ -22,17 +22,17 @@
 #include <sfx2/objsh.hxx>
 #include <sfx2/module.hxx>
 #include <vcl/msgbox.hxx>
-#include <vcl/graphic.hxx>
+#include <vcl/graph.hxx>
 #include <sfx2/sfxsids.hrc>
 #include <svx/svxids.hrc>
-#include <svx/dialogs.hrc>
+#include <svx/strings.hrc>
 
 #include <svl/intitem.hxx>
 
 #include <svx/hdft.hxx>
 #include <svx/pageitem.hxx>
 
-#include "svx/dlgutil.hxx"
+#include <svx/dlgutil.hxx>
 #include <svx/dialmgr.hxx>
 #include <sfx2/htmlmode.hxx>
 
@@ -46,7 +46,6 @@
 #include <svx/svxdlg.hxx>
 #include <memory>
 
-//UUUU
 #include <svx/xdef.hxx>
 #include <svx/xenum.hxx>
 #include <svx/xfillit0.hxx>
@@ -66,7 +65,7 @@ const sal_uInt16 SvxHFPage::pRanges[] =
 {
     SID_ATTR_BRUSH,          SID_ATTR_BRUSH,
 
-    //UUUU Support DrawingLayer FillStyles (no real call to below GetRanges()
+    // Support DrawingLayer FillStyles (no real call to below GetRanges()
     // detected, still do the complete transition)
     XATTR_FILL_FIRST,        XATTR_FILL_LAST,
 
@@ -88,14 +87,13 @@ const sal_uInt16 SvxHFPage::pRanges[] =
 
 namespace svx {
 
-    bool ShowBorderBackgroundDlg( vcl::Window* pParent, SfxItemSet* pBBSet,
-            bool bEnableBackgroundSelector )
+    bool ShowBorderBackgroundDlg( vcl::Window* pParent, SfxItemSet* pBBSet )
     {
         bool bRes = false;
         SvxAbstractDialogFactory* pFact = SvxAbstractDialogFactory::Create();
         if(pFact)
         {
-            std::unique_ptr<SfxAbstractTabDialog> pDlg(pFact->CreateSvxBorderBackgroundDlg( pParent, *pBBSet, bEnableBackgroundSelector ));
+            ScopedVclPtr<SfxAbstractTabDialog> pDlg(pFact->CreateSvxBorderBackgroundDlg( pParent, *pBBSet, true/*bEnableBackgroundSelector*/ ));
             DBG_ASSERT(pDlg, "Dialog creation failed!");
             if ( pDlg->Execute() == RET_OK && pDlg->GetOutputItemSet() )
             {
@@ -121,14 +119,12 @@ VclPtr<SfxTabPage> SvxHeaderPage::Create( vcl::Window* pParent, const SfxItemSet
 }
 
 
-
 VclPtr<SfxTabPage> SvxFooterPage::Create( vcl::Window* pParent, const SfxItemSet* rSet )
 {
     return VclPtr<SvxFooterPage>::Create( pParent, *rSet );
 }
 
 
-
 SvxHeaderPage::SvxHeaderPage( vcl::Window* pParent, const SfxItemSet& rAttr ) :
 
     SvxHFPage( pParent, rAttr, SID_ATTR_PAGE_HEADERSET )
@@ -137,7 +133,6 @@ SvxHeaderPage::SvxHeaderPage( vcl::Window* pParent, const SfxItemSet& rAttr ) :
 }
 
 
-
 SvxFooterPage::SvxFooterPage( vcl::Window* pParent, const SfxItemSet& rAttr ) :
 
     SvxHFPage( pParent, rAttr, SID_ATTR_PAGE_FOOTERSET )
@@ -150,9 +145,7 @@ SvxHFPage::SvxHFPage( vcl::Window* pParent, const SfxItemSet& rSet, sal_uInt16 n
     SfxTabPage(pParent, "HFFormatPage", "svx/ui/headfootformatpage.ui", &rSet),
     nId(nSetId),
     pBBSet(nullptr),
-    // bitfield
     mbDisableQueryBox(false),
-    mbEnableBackgroundSelector(true),
     mbEnableDrawingLayerFillStyles(false)
 {
     get(m_pCntSharedBox,"checkSameLR");
@@ -175,6 +168,19 @@ SvxHFPage::SvxHFPage( vcl::Window* pParent, const SfxItemSet& rSet, sal_uInt16 n
     {
         get(m_pPageLbl,"labelFooterFormat");
         get(m_pTurnOnBox, "checkFooterOn");
+
+        /* Set custom HIDs for the Footer help page (shared/01/05040400.xhp)
+        otherwise it would display the same extended help
+        on both the Header and Footer tabs */
+        m_pCntSharedBox->SetHelpId( "SVX_HID_FOOTER_CHECKSAMELR" );
+        m_pCntSharedFirstBox->SetHelpId( "SVX_HID_FOOTER_CHECKSAMEFP" );
+        m_pLMEdit->SetHelpId( "SVX_HID_FOOTER_SPINMARGLEFT" );
+        m_pRMEdit->SetHelpId( "SVX_HID_FOOTER_SPINMARGRIGHT" );
+        m_pDistEdit->SetHelpId( "SVX_HID_FOOTER_SPINSPACING" );
+        m_pDynSpacingCB->SetHelpId( "SVX_HID_FOOTER_CHECKDYNSPACING" );
+        m_pHeightEdit->SetHelpId( "SVX_HID_FOOTER_SPINHEIGHT" );
+        m_pHeightDynBtn->SetHelpId( "SVX_HID_FOOTER_CHECKAUTOFIT" );
+        m_pBackgroundBtn->SetHelpId( "SVX_HID_FOOTER_BUTTONMORE" );
     }
     else //Header
     {
@@ -200,7 +206,6 @@ SvxHFPage::SvxHFPage( vcl::Window* pParent, const SfxItemSet& rSet, sal_uInt16 n
 }
 
 
-
 SvxHFPage::~SvxHFPage()
 {
     disposeOnce();
@@ -229,7 +234,6 @@ void SvxHFPage::dispose()
 }
 
 
-
 bool SvxHFPage::FillItemSet( SfxItemSet* rSet )
 {
     const sal_uInt16 nWSize = GetWhich(SID_ATTR_PAGE_SIZE);
@@ -259,7 +263,7 @@ bool SvxHFPage::FillItemSet( SfxItemSet* rSet )
         nWShadow, nWShadow,
         nWDynSpacing, nWDynSpacing,
 
-        //UUUU take over DrawingLayer FillStyles
+        // take over DrawingLayer FillStyles
         XATTR_FILL_FIRST, XATTR_FILL_LAST,                // [1014
 
         0, 0};
@@ -267,12 +271,12 @@ bool SvxHFPage::FillItemSet( SfxItemSet* rSet )
     const SfxItemSet& rOldSet = GetItemSet();
     SfxItemPool* pPool = rOldSet.GetPool();
     DBG_ASSERT(pPool,"no pool :-(");
-    SfxMapUnit eUnit = pPool->GetMetric(nWSize);
+    MapUnit eUnit = pPool->GetMetric(nWSize);
     SfxItemSet aSet(*pPool,aWhichTab);
 
     if(mbEnableDrawingLayerFillStyles)
     {
-        //UUUU When using the XATTR_FILLSTYLE DrawingLayer FillStyle definition
+        // When using the XATTR_FILLSTYLE DrawingLayer FillStyle definition
         // extra action has to be done here since the pool default is drawing::FillStyle_SOLID
         // instead of drawing::FillStyle_NONE (to have the default blue fill color at start).
         aSet.Put(XFillStyleItem(drawing::FillStyle_NONE));
@@ -283,7 +287,7 @@ bool SvxHFPage::FillItemSet( SfxItemSet* rSet )
     aSet.Put( SfxBoolItem( nWShared,  m_pCntSharedBox->IsChecked() ) );
     if(m_pCntSharedFirstBox->IsVisible())
         aSet.Put( SfxBoolItem( nWSharedFirst,  m_pCntSharedFirstBox->IsChecked() ) );
-    if(m_pDynSpacingCB->IsVisible() && SFX_WHICH_MAX > nWDynSpacing)
+    if (m_pDynSpacingCB->IsVisible() && SfxItemPool::IsWhich(nWDynSpacing))
     {
         std::unique_ptr<SfxBoolItem> pBoolItem(static_cast<SfxBoolItem*>(pPool->GetDefaultItem(nWDynSpacing).Clone()));
         pBoolItem->SetValue(m_pDynSpacingCB->IsChecked());
@@ -347,7 +351,7 @@ bool SvxHFPage::FillItemSet( SfxItemSet* rSet )
                 aSet.Put(_pSet->Get(nWShadow));
             }
 
-            //UUUU take care of [XATTR_XATTR_FILL_FIRST .. XATTR_FILL_LAST]
+            // take care of [XATTR_XATTR_FILL_FIRST .. XATTR_FILL_LAST]
             for(sal_uInt16 nFillStyleId(XATTR_FILL_FIRST); nFillStyleId <= XATTR_FILL_LAST; nFillStyleId++)
             {
                 if(_pSet->GetItemState(nFillStyleId) == SfxItemState::SET)
@@ -373,7 +377,7 @@ void SvxHFPage::Reset( const SfxItemSet* rSet )
 
     SfxItemPool* pPool = GetItemSet().GetPool();
     DBG_ASSERT( pPool, "Where is the pool" );
-    SfxMapUnit eUnit = pPool->GetMetric( GetWhich( SID_ATTR_PAGE_SIZE ) );
+    MapUnit eUnit = pPool->GetMetric( GetWhich( SID_ATTR_PAGE_SIZE ) );
 
     //hide "same content on first page when this is calc
     bool bIsCalc = false;
@@ -445,8 +449,8 @@ void SvxHFPage::Reset( const SfxItemSet* rSet )
     {
         // defaults for distance and height
         long nDefaultDist = bIsCalc ? DEF_DIST_CALC : DEF_DIST_WRITER;
-        SetMetricValue( *m_pDistEdit, nDefaultDist, SFX_MAPUNIT_100TH_MM );
-        SetMetricValue( *m_pHeightEdit, 500, SFX_MAPUNIT_100TH_MM );
+        SetMetricValue( *m_pDistEdit, nDefaultDist, MapUnit::Map100thMM );
+        SetMetricValue( *m_pHeightEdit, 500, MapUnit::Map100thMM );
     }
 
     if ( !pSetItem )
@@ -501,7 +505,7 @@ void SvxHFPage::InitHandler()
     m_pBackgroundBtn->SetClickHdl(LINK(this,SvxHFPage, BackgroundHdl));
 }
 
-IMPL_LINK_TYPED( SvxHFPage, TurnOnHdl, Button *, pButton, void )
+IMPL_LINK( SvxHFPage, TurnOnHdl, Button *, pButton, void )
 {
     CheckBox* pBox = static_cast<CheckBox*>(pButton);
     if ( m_pTurnOnBox->IsChecked() )
@@ -517,9 +521,9 @@ IMPL_LINK_TYPED( SvxHFPage, TurnOnHdl, Button *, pButton, void )
         m_pRMLbl->Enable();
         m_pRMEdit->Enable();
 
-        sal_uInt16 nUsage = m_pBspWin->GetUsage();
+        SvxPageUsage nUsage = m_pBspWin->GetUsage();
 
-        if( nUsage == SVX_PAGE_RIGHT || nUsage == SVX_PAGE_LEFT )
+        if( nUsage == SvxPageUsage::Right || nUsage == SvxPageUsage::Left )
             m_pCntSharedBox->Disable();
         else
         {
@@ -536,9 +540,9 @@ IMPL_LINK_TYPED( SvxHFPage, TurnOnHdl, Button *, pButton, void )
         {
             short nResult;
             if (nId == SID_ATTR_PAGE_HEADERSET)
-                nResult = ScopedVclPtrInstance<DeleteHeaderDialog>::Create(this)->Execute();
+                nResult = ScopedVclPtrInstance<DeleteHeaderDialog>(this)->Execute();
             else
-                nResult = ScopedVclPtrInstance<DeleteFooterDialog>::Create(this)->Execute();
+                nResult = ScopedVclPtrInstance<DeleteFooterDialog>(this)->Execute();
             bDelete = nResult == RET_YES;
         }
 
@@ -566,22 +570,22 @@ IMPL_LINK_TYPED( SvxHFPage, TurnOnHdl, Button *, pButton, void )
     UpdateExample();
 }
 
-IMPL_LINK_NOARG_TYPED(SvxHFPage, DistModify, Edit&, void)
+IMPL_LINK_NOARG(SvxHFPage, DistModify, Edit&, void)
 {
     UpdateExample();
 }
 
-IMPL_LINK_NOARG_TYPED(SvxHFPage, HeightModify, Edit&, void)
+IMPL_LINK_NOARG(SvxHFPage, HeightModify, Edit&, void)
 {
     UpdateExample();
 }
 
-IMPL_LINK_NOARG_TYPED(SvxHFPage, BorderModify, Edit&, void)
+IMPL_LINK_NOARG(SvxHFPage, BorderModify, Edit&, void)
 {
     UpdateExample();
 }
 
-IMPL_LINK_NOARG_TYPED(SvxHFPage, BackgroundHdl, Button*, void)
+IMPL_LINK_NOARG(SvxHFPage, BackgroundHdl, Button*, void)
 {
     if(!pBBSet)
     {
@@ -594,20 +598,20 @@ IMPL_LINK_NOARG_TYPED(SvxHFPage, BackgroundHdl, Button*, void)
         {
             pBBSet = new SfxItemSet(
                 *GetItemSet().GetPool(),
-                XATTR_FILL_FIRST, XATTR_FILL_LAST,  // DrawingLayer FillStyle definitions
-                SID_COLOR_TABLE, SID_BITMAP_LIST,   // XPropertyLists for Color, Gradient, Hatch and Graphic fills
-                nOuter, nOuter,
-                nInner, nInner,
-                nShadow, nShadow,
-                0, 0);
+                {{XATTR_FILL_FIRST, XATTR_FILL_LAST},  // DrawingLayer FillStyle definitions
+                {SID_COLOR_TABLE, SID_PATTERN_LIST},   // XPropertyLists for Color, Gradient, Hatch and Graphic fills
+                {nOuter, nOuter},
+                {nInner, nInner},
+                {nShadow, nShadow}});
 
-            //UUUU copy items for XPropertyList entries from the DrawModel so that
+            // copy items for XPropertyList entries from the DrawModel so that
             // the Area TabPage can access them
             static const sal_uInt16 nCopyFlags[] = {
                 SID_COLOR_TABLE,
                 SID_GRADIENT_LIST,
                 SID_HATCH_LIST,
                 SID_BITMAP_LIST,
+                SID_PATTERN_LIST,
                 0
             };
 
@@ -631,11 +635,10 @@ IMPL_LINK_NOARG_TYPED(SvxHFPage, BackgroundHdl, Button*, void)
 
             pBBSet = new SfxItemSet(
                 *GetItemSet().GetPool(),
-                nBrush, nBrush,
-                nOuter, nOuter,
-                nInner, nInner,
-                nShadow, nShadow,
-                0, 0);
+                {{nBrush, nBrush},
+                {nOuter, nOuter},
+                {nInner, nInner},
+                {nShadow, nShadow}});
         }
 
         const SfxPoolItem* pItem;
@@ -643,14 +646,14 @@ IMPL_LINK_NOARG_TYPED(SvxHFPage, BackgroundHdl, Button*, void)
         if(SfxItemState::SET == GetItemSet().GetItemState(GetWhich(nId), false, &pItem))
         {
             // If a SfxItemSet from the SetItem for SID_ATTR_PAGE_HEADERSET or
-            // SID_ATTR_PAGE_FOOTERSET exists, use it's content
+            // SID_ATTR_PAGE_FOOTERSET exists, use its content
             pBBSet->Put(static_cast<const SvxSetItem*>(pItem)->GetItemSet());
         }
         else
         {
             if(mbEnableDrawingLayerFillStyles)
             {
-                //UUUU The style for header/footer is not yet created, need to reset
+                // The style for header/footer is not yet created, need to reset
                 // XFillStyleItem to drawing::FillStyle_NONE which is the same as in the style
                 // initialization. This needs to be done since the pool default for
                 // XFillStyleItem is drawing::FillStyle_SOLID
@@ -669,12 +672,11 @@ IMPL_LINK_NOARG_TYPED(SvxHFPage, BackgroundHdl, Button*, void)
 
     if(pFact)
     {
-        //UUUU
-        SfxAbstractTabDialog* pDlg = pFact->CreateSvxBorderBackgroundDlg(
+        ScopedVclPtr<SfxAbstractTabDialog> pDlg(pFact->CreateSvxBorderBackgroundDlg(
             this,
             *pBBSet,
-            mbEnableBackgroundSelector,
-            mbEnableDrawingLayerFillStyles);
+            true/*EnableBackgroundSelector*/,
+            mbEnableDrawingLayerFillStyles));
 
         DBG_ASSERT(pDlg,"Dialog creation failed!");
         if(RET_OK == pDlg->Execute() && pDlg->GetOutputItemSet())
@@ -697,7 +699,7 @@ IMPL_LINK_NOARG_TYPED(SvxHFPage, BackgroundHdl, Button*, void)
 
                 if(mbEnableDrawingLayerFillStyles)
                 {
-                    //UUUU create FillAttributes directly from DrawingLayer FillStyle entries
+                    // create FillAttributes directly from DrawingLayer FillStyle entries
                     aFillAttributes.reset(new drawinglayer::attribute::SdrAllFillAttributesHelper(*pBBSet));
                 }
                 else
@@ -706,9 +708,9 @@ IMPL_LINK_NOARG_TYPED(SvxHFPage, BackgroundHdl, Button*, void)
 
                     if(pBBSet->GetItemState(nWhich) == SfxItemState::SET)
                     {
-                        //UUUU create FillAttributes from SvxBrushItem
+                        // create FillAttributes from SvxBrushItem
                         const SvxBrushItem& rItem = static_cast< const SvxBrushItem& >(pBBSet->Get(nWhich));
-                        SfxItemSet aTempSet(*pBBSet->GetPool(), XATTR_FILL_FIRST, XATTR_FILL_LAST);
+                        SfxItemSet aTempSet(*pBBSet->GetPool(), svl::Items<XATTR_FILL_FIRST, XATTR_FILL_LAST>{});
 
                         setSvxBrushItemAsFillAttributesToTargetSet(rItem, aTempSet);
                         aFillAttributes.reset(new drawinglayer::attribute::SdrAllFillAttributesHelper(aTempSet));
@@ -727,20 +729,6 @@ IMPL_LINK_NOARG_TYPED(SvxHFPage, BackgroundHdl, Button*, void)
                 }
             }
 
-            {
-                const sal_uInt16 nWhich = GetWhich(SID_ATTR_BORDER_OUTER);
-
-                if(pBBSet->GetItemState(nWhich) == SfxItemState::SET)
-                {
-                    const SvxBoxItem& rItem = static_cast<const SvxBoxItem&>(pBBSet->Get(nWhich));
-
-                    if(nId == SID_ATTR_PAGE_HEADERSET)
-                        m_pBspWin->SetHdBorder(rItem);
-                    else
-                        m_pBspWin->SetFtBorder(rItem);
-                }
-            }
-
         }
 
         UpdateExample();
@@ -752,18 +740,18 @@ void SvxHFPage::UpdateExample()
     if ( nId == SID_ATTR_PAGE_HEADERSET )
     {
         m_pBspWin->SetHeader( m_pTurnOnBox->IsChecked() );
-        m_pBspWin->SetHdHeight( GetCoreValue( *m_pHeightEdit, SFX_MAPUNIT_TWIP ) );
-        m_pBspWin->SetHdDist( GetCoreValue( *m_pDistEdit, SFX_MAPUNIT_TWIP ) );
-        m_pBspWin->SetHdLeft( GetCoreValue( *m_pLMEdit, SFX_MAPUNIT_TWIP ) );
-        m_pBspWin->SetHdRight( GetCoreValue( *m_pRMEdit, SFX_MAPUNIT_TWIP ) );
+        m_pBspWin->SetHdHeight( GetCoreValue( *m_pHeightEdit, MapUnit::MapTwip ) );
+        m_pBspWin->SetHdDist( GetCoreValue( *m_pDistEdit, MapUnit::MapTwip ) );
+        m_pBspWin->SetHdLeft( GetCoreValue( *m_pLMEdit, MapUnit::MapTwip ) );
+        m_pBspWin->SetHdRight( GetCoreValue( *m_pRMEdit, MapUnit::MapTwip ) );
     }
     else
     {
         m_pBspWin->SetFooter( m_pTurnOnBox->IsChecked() );
-        m_pBspWin->SetFtHeight( GetCoreValue( *m_pHeightEdit, SFX_MAPUNIT_TWIP ) );
-        m_pBspWin->SetFtDist( GetCoreValue( *m_pDistEdit, SFX_MAPUNIT_TWIP ) );
-        m_pBspWin->SetFtLeft( GetCoreValue( *m_pLMEdit, SFX_MAPUNIT_TWIP ) );
-        m_pBspWin->SetFtRight( GetCoreValue( *m_pRMEdit, SFX_MAPUNIT_TWIP ) );
+        m_pBspWin->SetFtHeight( GetCoreValue( *m_pHeightEdit, MapUnit::MapTwip ) );
+        m_pBspWin->SetFtDist( GetCoreValue( *m_pDistEdit, MapUnit::MapTwip ) );
+        m_pBspWin->SetFtLeft( GetCoreValue( *m_pLMEdit, MapUnit::MapTwip ) );
+        m_pBspWin->SetFtRight( GetCoreValue( *m_pRMEdit, MapUnit::MapTwip ) );
     }
     m_pBspWin->Invalidate();
 }
@@ -784,7 +772,7 @@ void SvxHFPage::ResetBackground_Impl( const SfxItemSet& rSet )
 
             if(mbEnableDrawingLayerFillStyles)
             {
-                //UUUU create FillAttributes directly from DrawingLayer FillStyle entries
+                // create FillAttributes directly from DrawingLayer FillStyle entries
                 aHeaderFillAttributes.reset(new drawinglayer::attribute::SdrAllFillAttributesHelper(rTmpSet));
             }
             else
@@ -793,9 +781,9 @@ void SvxHFPage::ResetBackground_Impl( const SfxItemSet& rSet )
 
                 if(SfxItemState::SET == rTmpSet.GetItemState(nWhich))
                 {
-                    //UUUU create FillAttributes from SvxBrushItem
+                    // create FillAttributes from SvxBrushItem
                     const SvxBrushItem& rItem = static_cast< const SvxBrushItem& >(rTmpSet.Get(nWhich));
-                    SfxItemSet aTempSet(*rTmpSet.GetPool(), XATTR_FILL_FIRST, XATTR_FILL_LAST);
+                    SfxItemSet aTempSet(*rTmpSet.GetPool(), svl::Items<XATTR_FILL_FIRST, XATTR_FILL_LAST>{});
 
                     setSvxBrushItemAsFillAttributesToTargetSet(rItem, aTempSet);
                     aHeaderFillAttributes.reset(new drawinglayer::attribute::SdrAllFillAttributesHelper(aTempSet));
@@ -803,14 +791,6 @@ void SvxHFPage::ResetBackground_Impl( const SfxItemSet& rSet )
             }
 
             m_pBspWin->setHeaderFillAttributes(aHeaderFillAttributes);
-            nWhich = GetWhich(SID_ATTR_BORDER_OUTER);
-
-            if(rTmpSet.GetItemState(nWhich) == SfxItemState::SET)
-            {
-                const SvxBoxItem& rItem =
-                    static_cast<const SvxBoxItem&>(rTmpSet.Get(nWhich));
-                m_pBspWin->SetHdBorder(rItem);
-            }
         }
     }
 
@@ -828,7 +808,7 @@ void SvxHFPage::ResetBackground_Impl( const SfxItemSet& rSet )
 
             if(mbEnableDrawingLayerFillStyles)
             {
-                //UUUU create FillAttributes directly from DrawingLayer FillStyle entries
+                // create FillAttributes directly from DrawingLayer FillStyle entries
                 aFooterFillAttributes.reset(new drawinglayer::attribute::SdrAllFillAttributesHelper(rTmpSet));
             }
             else
@@ -837,9 +817,9 @@ void SvxHFPage::ResetBackground_Impl( const SfxItemSet& rSet )
 
                 if(SfxItemState::SET == rTmpSet.GetItemState(nWhich))
                 {
-                    //UUUU create FillAttributes from SvxBrushItem
+                    // create FillAttributes from SvxBrushItem
                     const SvxBrushItem& rItem = static_cast< const SvxBrushItem& >(rTmpSet.Get(nWhich));
-                    SfxItemSet aTempSet(*rTmpSet.GetPool(), XATTR_FILL_FIRST, XATTR_FILL_LAST);
+                    SfxItemSet aTempSet(*rTmpSet.GetPool(), svl::Items<XATTR_FILL_FIRST, XATTR_FILL_LAST>{});
 
                     setSvxBrushItemAsFillAttributesToTargetSet(rItem, aTempSet);
                     aFooterFillAttributes.reset(new drawinglayer::attribute::SdrAllFillAttributesHelper(aTempSet));
@@ -847,13 +827,6 @@ void SvxHFPage::ResetBackground_Impl( const SfxItemSet& rSet )
             }
 
             m_pBspWin->setFooterFillAttributes(aFooterFillAttributes);
-            nWhich = GetWhich(SID_ATTR_BORDER_OUTER);
-
-            if(rTmpSet.GetItemState(nWhich) == SfxItemState::SET)
-            {
-                const SvxBoxItem& rItem = static_cast< const SvxBoxItem& >(rTmpSet.Get(nWhich));
-                m_pBspWin->SetFtBorder(rItem);
-            }
         }
     }
 
@@ -861,7 +834,7 @@ void SvxHFPage::ResetBackground_Impl( const SfxItemSet& rSet )
 
     if(mbEnableDrawingLayerFillStyles)
     {
-        //UUUU create FillAttributes directly from DrawingLayer FillStyle entries
+        // create FillAttributes directly from DrawingLayer FillStyle entries
         aPageFillAttributes.reset(new drawinglayer::attribute::SdrAllFillAttributesHelper(rSet));
     }
     else
@@ -870,9 +843,9 @@ void SvxHFPage::ResetBackground_Impl( const SfxItemSet& rSet )
 
         if(rSet.GetItemState(nWhich) >= SfxItemState::DEFAULT)
         {
-            //UUUU create FillAttributes from SvxBrushItem
+            // create FillAttributes from SvxBrushItem
             const SvxBrushItem& rItem = static_cast< const SvxBrushItem& >(rSet.Get(nWhich));
-            SfxItemSet aTempSet(*rSet.GetPool(), XATTR_FILL_FIRST, XATTR_FILL_LAST);
+            SfxItemSet aTempSet(*rSet.GetPool(), svl::Items<XATTR_FILL_FIRST, XATTR_FILL_LAST>{});
 
             setSvxBrushItemAsFillAttributesToTargetSet(rItem, aTempSet);
             aPageFillAttributes.reset(new drawinglayer::attribute::SdrAllFillAttributesHelper(aTempSet));
@@ -880,13 +853,6 @@ void SvxHFPage::ResetBackground_Impl( const SfxItemSet& rSet )
     }
 
     m_pBspWin->setPageFillAttributes(aPageFillAttributes);
-    nWhich = GetWhich(SID_ATTR_BORDER_OUTER);
-
-    if(rSet.GetItemState(nWhich) >= SfxItemState::DEFAULT)
-    {
-        const SvxBoxItem& rItem = static_cast< const SvxBoxItem& >(rSet.Get(nWhich));
-        m_pBspWin->SetBorder(rItem);
-    }
 }
 
 void SvxHFPage::ActivatePage( const SfxItemSet& rSet )
@@ -923,7 +889,7 @@ void SvxHFPage::ActivatePage( const SfxItemSet& rSet )
         m_pBspWin->SetBottom( 0 );
     }
 
-    sal_uInt16 nUsage = SVX_PAGE_ALL;
+    SvxPageUsage nUsage = SvxPageUsage::All;
     pItem = GetItem( rSet, SID_ATTR_PAGE );
 
     if ( pItem )
@@ -931,7 +897,7 @@ void SvxHFPage::ActivatePage( const SfxItemSet& rSet )
 
     m_pBspWin->SetUsage( nUsage );
 
-    if ( SVX_PAGE_RIGHT == nUsage || SVX_PAGE_LEFT == nUsage )
+    if ( SvxPageUsage::Right == nUsage || SvxPageUsage::Left == nUsage )
         m_pCntSharedBox->Disable();
     else
     {
@@ -1049,14 +1015,14 @@ void SvxHFPage::ActivatePage( const SfxItemSet& rSet )
     RangeHdl();
 }
 
-SfxTabPage::sfxpg SvxHFPage::DeactivatePage( SfxItemSet* _pSet )
+DeactivateRC SvxHFPage::DeactivatePage( SfxItemSet* _pSet )
 {
     if ( _pSet )
         FillItemSet( _pSet );
-    return LEAVE_PAGE;
+    return DeactivateRC::LeavePage;
 }
 
-IMPL_LINK_NOARG_TYPED(SvxHFPage, RangeFocusHdl, Control&, void)
+IMPL_LINK_NOARG(SvxHFPage, RangeFocusHdl, Control&, void)
 {
     RangeHdl();
 }
@@ -1159,14 +1125,13 @@ void SvxHFPage::EnableDynamicSpacing()
 
 void SvxHFPage::PageCreated(const SfxAllItemSet &rSet)
 {
-    //UUUU
     const SfxBoolItem* pSupportDrawingLayerFillStyleItem = rSet.GetItem<SfxBoolItem>(SID_DRAWINGLAYER_FILLSTYLES, false);
 
     if(pSupportDrawingLayerFillStyleItem)
     {
         const bool bNew(pSupportDrawingLayerFillStyleItem->GetValue());
 
-        EnableDrawingLayerFillStyles(bNew);
+        mbEnableDrawingLayerFillStyles = bNew;
     }
 }
 
