@@ -23,7 +23,7 @@
 #include <svx/svxids.hrc>
 
 #include "srchctrl.hxx"
-#include "svx/srchdlg.hxx"
+#include <svx/srchdlg.hxx>
 #include <svl/srchitem.hxx>
 
 SvxSearchController::SvxSearchController
@@ -39,7 +39,6 @@ SvxSearchController::SvxSearchController
 }
 
 
-
 void SvxSearchController::StateChanged( sal_uInt16 nSID, SfxItemState eState,
                                         const SfxPoolItem* pState )
 {
