@@ -18,12 +18,11 @@
  */
 
 #include <svx/dialmgr.hxx>
-#include <svx/dialogs.hrc>
-#include <tools/shl.hxx>
+#include <svx/strings.hrc>
 #include <i18nlangtag/mslangid.hxx>
 #include <svtools/valueset.hxx>
 #include <svl/languageoptions.hxx>
-#include <helpid.hrc>
+#include <helpids.h>
 #include <editeng/numitem.hxx>
 #include <svl/eitem.hxx>
 #include <vcl/svapp.hxx>
@@ -35,6 +34,7 @@
 #include <vcl/graph.hxx>
 #include <vcl/msgbox.hxx>
 #include <vcl/settings.hxx>
+#include <vcl/builderfactory.hxx>
 #include <editeng/flstitem.hxx>
 #include <svx/dlgutil.hxx>
 #include <svx/xtable.hxx>
@@ -64,18 +64,6 @@ using namespace com::sun::star::text;
 using namespace com::sun::star::container;
 using namespace com::sun::star::style;
 
-#define NUM_PAGETYPE_BULLET         0
-#define NUM_PAGETYPE_SINGLENUM      1
-#define NUM_PAGETYPE_NUM            2
-#define NUM_PAGETYPE_BMP            3
-
-static const sal_Char cNumberingType[] = "NumberingType";
-static const sal_Char cValue[] = "Value";
-static const sal_Char cParentNumbering[] = "ParentNumbering";
-static const sal_Char cPrefix[] = "Prefix";
-static const sal_Char cSuffix[] = "Suffix";
-static const sal_Char cBulletChar[] = "BulletChar";
-static const sal_Char cBulletFontName[] = "BulletFontName";
 
 // The selection of bullets from the star symbol
 static const sal_Unicode aBulletTypes[] =
@@ -90,10 +78,10 @@ static const sal_Unicode aBulletTypes[] =
     0x2714
 };
 
-static Font& lcl_GetDefaultBulletFont()
+static vcl::Font& lcl_GetDefaultBulletFont()
 {
     static bool bInit = false;
-    static Font aDefBulletFont( "StarSymbol", "", Size( 0, 14 ) );
+    static vcl::Font aDefBulletFont("OpenSymbol", "", Size(0, 14));
     if(!bInit)
     {
         aDefBulletFont.SetCharSet( RTL_TEXTENCODING_SYMBOL );
@@ -108,7 +96,7 @@ static Font& lcl_GetDefaultBulletFont()
 
 static void lcl_PaintLevel(OutputDevice* pVDev, sal_Int16 nNumberingType,
                         const OUString& rBulletChar, const OUString& rText, const OUString& rFontName,
-                        Point& rLeft, Font& rRuleFont, const Font& rTextFont)
+                        Point& rLeft, vcl::Font& rRuleFont, const vcl::Font& rTextFont)
 {
 
     if(NumberingType::CHAR_SPECIAL == nNumberingType )
@@ -134,65 +122,61 @@ void  SvxNumValueSet::UserDraw( const UserDrawEvent& rUDEvt )
         25, 50,
         30, 70,
         35, 90, // up to here line positions
-        05, 10, // character positions
+         5, 10, // character positions
         10, 30,
         15, 50,
         20, 70,
         25, 90,
     };
 
-    const StyleSettings& rStyleSettings = GetSettings().GetStyleSettings();
-    const Color aBackColor = rStyleSettings.GetFieldColor();
-    const Color aTextColor = rStyleSettings.GetFieldTextColor();
+    const Color aBackColor(COL_WHITE);
+    const Color aTextColor(COL_BLACK);
+
+    vcl::RenderContext* pDev = rUDEvt.GetRenderContext();
+    tools::Rectangle aRect = rUDEvt.GetRect();
+    sal_uInt16 nItemId = rUDEvt.GetItemId();
 
-    OutputDevice*  pDev = rUDEvt.GetDevice();
-    Rectangle aRect = rUDEvt.GetRect();
-    sal_uInt16  nItemId = rUDEvt.GetItemId();
     long nRectWidth = aRect.GetWidth();
     long nRectHeight = aRect.GetHeight();
     Size aRectSize(nRectWidth, aRect.GetHeight());
     Point aBLPos = aRect.TopLeft();
-    Font aOldFont = pDev->GetFont();
+    vcl::Font aOldFont = pDev->GetFont();
     Color aOldColor = pDev->GetLineColor();
     pDev->SetLineColor(aTextColor);
-    Font aFont(OutputDevice::GetDefaultFont(
-                DEFAULTFONT_UI_SANS, MsLangId::getSystemLanguage(), DEFAULTFONT_FLAGS_ONLYONE));
+    vcl::Font aFont(OutputDevice::GetDefaultFont(
+                DefaultFontType::UI_SANS, MsLangId::getSystemLanguage(), GetDefaultFontFlags::OnlyOne));
 
-    Size aSize = aFont.GetSize();
+    Size aSize = aFont.GetFontSize();
 
-    Font aRuleFont( lcl_GetDefaultBulletFont() );
+    vcl::Font aRuleFont( lcl_GetDefaultBulletFont() );
     aSize.Height() = nRectHeight/6;
-    aRuleFont.SetSize(aSize);
+    aRuleFont.SetFontSize(aSize);
     aRuleFont.SetColor(aTextColor);
     aRuleFont.SetFillColor(aBackColor);
-    if(nPageType == NUM_PAGETYPE_BULLET)
+    if(ePageType == NumberingPageType::BULLET)
         aFont = aRuleFont;
-    else if(nPageType == NUM_PAGETYPE_NUM)
+    else if(ePageType == NumberingPageType::OUTLINE)
     {
         aSize.Height() = nRectHeight/8;
     }
     aFont.SetColor(aTextColor);
     aFont.SetFillColor(aBackColor);
-    aFont.SetSize( aSize );
+    aFont.SetFontSize( aSize );
     pDev->SetFont(aFont);
 
     if(!pVDev)
     {
         // The lines are only one time in the virtual device, only the outline
         // page is currently done
-        pVDev = new VirtualDevice(*pDev);
+        pVDev = VclPtr<VirtualDevice>::Create(*pDev);
         pVDev->SetMapMode(pDev->GetMapMode());
         pVDev->EnableRTL( IsRTLEnabled() );
          pVDev->SetOutputSize( aRectSize );
         aOrgRect = aRect;
         pVDev->SetFillColor( aBackColor );
-        pVDev->DrawRect(aOrgRect);
-
-        if(aBackColor == aLineColor)
-            aLineColor.Invert();
-        pVDev->SetLineColor(aLineColor);
+        pVDev->SetLineColor(COL_LIGHTGRAY);
         // Draw line only once
-        if(nPageType != NUM_PAGETYPE_NUM)
+        if(ePageType != NumberingPageType::OUTLINE)
         {
             Point aStart(aBLPos.X() + nRectWidth *25 / 100,0);
             Point aEnd(aBLPos.X() + nRectWidth * 9 / 10,0);
@@ -209,9 +193,9 @@ void  SvxNumValueSet::UserDraw( const UserDrawEvent& rUDEvt )
                         aOrgRect.TopLeft(), aRectSize,
                         *pVDev );
     // Now comes the text
-    const OUString sValue(cValue);
-    if( NUM_PAGETYPE_SINGLENUM == nPageType ||
-            NUM_PAGETYPE_BULLET == nPageType )
+    const OUString sValue("Value");
+    if( NumberingPageType::SINGLENUM == ePageType ||
+           NumberingPageType::BULLET == ePageType )
     {
         Point aStart(aBLPos.X() + nRectWidth / 9,0);
         for( sal_uInt16 i = 0; i < 3; i++ )
@@ -219,7 +203,7 @@ void  SvxNumValueSet::UserDraw( const UserDrawEvent& rUDEvt )
             sal_uInt16 nY = 11 + i * 33;
             aStart.Y() = aBLPos.Y() + nRectHeight  * nY / 100;
             OUString sText;
-            if(nPageType == NUM_PAGETYPE_BULLET)
+            if(ePageType == NumberingPageType::BULLET)
             {
                 sText = OUString( aBulletTypes[nItemId - 1] );
                 aStart.Y() -= pDev->GetTextHeight()/2;
@@ -250,11 +234,12 @@ void  SvxNumValueSet::UserDraw( const UserDrawEvent& rUDEvt )
             pDev->DrawText(aStart, sText);
         }
     }
-    else if(NUM_PAGETYPE_NUM == nPageType )
+    else if(NumberingPageType::OUTLINE == ePageType )
     {
         // Outline numbering has to be painted into the virtual device
         // to get correct lines
         // has to be made again
+        pVDev->SetLineColor(aBackColor);
         pVDev->DrawRect(aOrgRect);
         long nStartX = aOrgRect.TopLeft().X();
         long nStartY = aOrgRect.TopLeft().Y();
@@ -288,17 +273,17 @@ void  SvxNumValueSet::UserDraw( const UserDrawEvent& rUDEvt )
                     aParentNumberings[i] = 0;
                     for(sal_Int32 nProperty = 0; nProperty < aLevel.getLength() - 1; nProperty++)
                     {
-                        if ( pValues[nProperty].Name == cNumberingType )
+                        if ( pValues[nProperty].Name == "NumberingType" )
                             pValues[nProperty].Value >>= aNumberingTypes[i];
-                        else if ( pValues[nProperty].Name == cBulletFontName )
+                        else if ( pValues[nProperty].Name == "BulletFontName" )
                             pValues[nProperty].Value >>= sFontNames[i];
-                        else if ( pValues[nProperty].Name == cBulletChar )
+                        else if ( pValues[nProperty].Name == "BulletChar" )
                             pValues[nProperty].Value >>= sBulletChars[i];
-                        else if ( pValues[nProperty].Name == cPrefix )
+                        else if ( pValues[nProperty].Name == "Prefix" )
                             pValues[nProperty].Value >>= sPrefixes[i];
-                        else if ( pValues[nProperty].Name == cSuffix )
+                        else if ( pValues[nProperty].Name == "Suffix" )
                             pValues[nProperty].Value >>= sSuffixes[i];
-                        else if ( pValues[nProperty].Name == cParentNumbering )
+                        else if ( pValues[nProperty].Name == "ParentNumbering" )
                             pValues[nProperty].Value >>= aParentNumberings[i];
                     }
                     Sequence< PropertyValue > aProperties(2);
@@ -361,6 +346,7 @@ void  SvxNumValueSet::UserDraw( const UserDrawEvent& rUDEvt )
                     long nLineTop = nStartY + nRectHeight * aLinesArr[2 * i + 1]/100 ;
                     Point aLineLeft(aLeft.X(), nLineTop );
                     Point aLineRight(nStartX + nRectWidth * 90 /100, nLineTop );
+                    pVDev->SetLineColor(COL_LIGHTGRAY);
                     pVDev->DrawLine(aLineLeft,  aLineRight);
                 }
 
@@ -390,47 +376,83 @@ void  SvxNumValueSet::UserDraw( const UserDrawEvent& rUDEvt )
     pDev->SetLineColor(aOldColor);
 }
 
-SvxNumValueSet::SvxNumValueSet(Window* pParent, WinBits nWinBits)
+SvxNumValueSet::SvxNumValueSet(vcl::Window* pParent, WinBits nWinBits)
     : ValueSet(pParent, nWinBits)
-    , nPageType(0)
-    , bHTMLMode(false)
-    , pVDev(NULL)
+    , ePageType(NumberingPageType::BULLET)
+    , pVDev(nullptr)
 {
 }
 
-extern "C" SAL_DLLPUBLIC_EXPORT Window* SAL_CALL makeSvxNumValueSet(Window *pParent, VclBuilder::stringmap &)
-{
-    return new SvxNumValueSet(pParent, WB_TABSTOP);
-}
+VCL_BUILDER_FACTORY_ARGS(SvxNumValueSet, WB_TABSTOP)
 
-void SvxNumValueSet::init(sal_uInt16 nType)
+static const char* RID_SVXSTR_BULLET_DESCRIPTIONS[] =
 {
-    aLineColor = COL_LIGHTGRAY;
-    nPageType = nType;
-    bHTMLMode = false;
-    pVDev = NULL;
+    RID_SVXSTR_BULLET_DESCRIPTION_0,
+    RID_SVXSTR_BULLET_DESCRIPTION_1,
+    RID_SVXSTR_BULLET_DESCRIPTION_2,
+    RID_SVXSTR_BULLET_DESCRIPTION_3,
+    RID_SVXSTR_BULLET_DESCRIPTION_4,
+    RID_SVXSTR_BULLET_DESCRIPTION_5,
+    RID_SVXSTR_BULLET_DESCRIPTION_6,
+    RID_SVXSTR_BULLET_DESCRIPTION_7
+};
+
+static const char* RID_SVXSTR_SINGLENUM_DESCRIPTIONS[] =
+{
+    RID_SVXSTR_SINGLENUM_DESCRIPTION_0,
+    RID_SVXSTR_SINGLENUM_DESCRIPTION_1,
+    RID_SVXSTR_SINGLENUM_DESCRIPTION_2,
+    RID_SVXSTR_SINGLENUM_DESCRIPTION_3,
+    RID_SVXSTR_SINGLENUM_DESCRIPTION_4,
+    RID_SVXSTR_SINGLENUM_DESCRIPTION_5,
+    RID_SVXSTR_SINGLENUM_DESCRIPTION_6,
+    RID_SVXSTR_SINGLENUM_DESCRIPTION_7
+};
+
+static const char* RID_SVXSTR_OUTLINENUM_DESCRIPTIONS[] =
+{
+    RID_SVXSTR_OUTLINENUM_DESCRIPTION_0,
+    RID_SVXSTR_OUTLINENUM_DESCRIPTION_1,
+    RID_SVXSTR_OUTLINENUM_DESCRIPTION_2,
+    RID_SVXSTR_OUTLINENUM_DESCRIPTION_3,
+    RID_SVXSTR_OUTLINENUM_DESCRIPTION_4,
+    RID_SVXSTR_OUTLINENUM_DESCRIPTION_5,
+    RID_SVXSTR_OUTLINENUM_DESCRIPTION_6,
+    RID_SVXSTR_OUTLINENUM_DESCRIPTION_7
+};
+
+void SvxNumValueSet::init(NumberingPageType eType)
+{
+    ePageType = eType;
+    pVDev = nullptr;
 
     SetColCount( 4 );
     SetLineCount( 2 );
     SetStyle( GetStyle() | WB_ITEMBORDER | WB_DOUBLEBORDER );
-    if(NUM_PAGETYPE_BULLET == nType)
+    if(NumberingPageType::BULLET == eType)
     {
         for ( sal_uInt16 i = 0; i < 8; i++ )
         {
             InsertItem( i + 1, i );
-            SetItemText( i + 1, SVX_RESSTR( RID_SVXSTR_BULLET_DESCRIPTIONS + i ) );
+            SetItemText(i + 1, SvxResId(RID_SVXSTR_BULLET_DESCRIPTIONS[i]));
         }
     }
 }
 
 SvxNumValueSet::~SvxNumValueSet()
 {
-    delete pVDev;
+    disposeOnce();
+}
+
+void SvxNumValueSet::dispose()
+{
+    pVDev.disposeAndClear();
+    ValueSet::dispose();
 }
 
 void SvxNumValueSet::SetNumberingSettings(
     const Sequence<Sequence<PropertyValue> >& aNum,
-    Reference<XNumberingFormatter>& xFormat,
+    Reference<XNumberingFormatter> const & xFormat,
     const Locale& rLocale   )
 {
     aNumSettings = aNum;
@@ -438,17 +460,17 @@ void SvxNumValueSet::SetNumberingSettings(
     aLocale = rLocale;
     if(aNum.getLength() > 8)
             SetStyle( GetStyle()|WB_VSCROLL);
-    for ( sal_uInt16 i = 0; i < aNum.getLength(); i++ )
+    for ( sal_Int32 i = 0; i < aNum.getLength(); i++ )
     {
             InsertItem( i + 1, i );
             if( i < 8 )
-                SetItemText( i + 1, SVX_RESSTR( RID_SVXSTR_SINGLENUM_DESCRIPTIONS + i ));
+                SetItemText(i + 1, SvxResId(RID_SVXSTR_SINGLENUM_DESCRIPTIONS[i]));
     }
 }
 
 void SvxNumValueSet::SetOutlineNumberingSettings(
-            Sequence<Reference<XIndexAccess> >& rOutline,
-            Reference<XNumberingFormatter>& xFormat,
+            Sequence<Reference<XIndexAccess> > const & rOutline,
+            Reference<XNumberingFormatter> const & xFormat,
             const Locale& rLocale)
 {
     aOutlineSettings = rOutline;
@@ -456,58 +478,62 @@ void SvxNumValueSet::SetOutlineNumberingSettings(
     aLocale = rLocale;
     if(aOutlineSettings.getLength() > 8)
         SetStyle( GetStyle() | WB_VSCROLL );
-    for ( sal_uInt16 i = 0; i < aOutlineSettings.getLength(); i++ )
+    for ( sal_Int32 i = 0; i < aOutlineSettings.getLength(); i++ )
     {
         InsertItem( i + 1, i );
         if( i < 8 )
-            SetItemText( i + 1, SVX_RESSTR( RID_SVXSTR_OUTLINENUM_DESCRIPTIONS + i ));
+            SetItemText(i + 1, SvxResId(RID_SVXSTR_OUTLINENUM_DESCRIPTIONS[i]));
     }
 }
 
-SvxBmpNumValueSet::SvxBmpNumValueSet(Window* pParent, WinBits nWinBits)
+SvxBmpNumValueSet::SvxBmpNumValueSet(vcl::Window* pParent, WinBits nWinBits)
     : SvxNumValueSet(pParent, nWinBits)
+    , aFormatIdle("SvxBmpNumValueSet FormatIdle")
 {
     init();
 }
 
-extern "C" SAL_DLLPUBLIC_EXPORT Window* SAL_CALL makeSvxBmpNumValueSet(Window *pParent, VclBuilder::stringmap &)
-{
-    return new SvxBmpNumValueSet(pParent, WB_TABSTOP);
-}
+VCL_BUILDER_FACTORY_ARGS(SvxBmpNumValueSet, WB_TABSTOP)
 
 void SvxBmpNumValueSet::init()
 {
-    SvxNumValueSet::init(NUM_PAGETYPE_BMP);
+    SvxNumValueSet::init(NumberingPageType::BITMAP);
     bGrfNotFound = false;
     GalleryExplorer::BeginLocking(GALLERY_THEME_BULLETS);
     SetStyle( GetStyle() | WB_VSCROLL );
     SetLineCount( 3 );
-    aFormatTimer.SetTimeout(300);
-    aFormatTimer.SetTimeoutHdl(LINK(this, SvxBmpNumValueSet, FormatHdl_Impl));
+    aFormatIdle.SetPriority(TaskPriority::LOWEST);
+    aFormatIdle.SetInvokeHandler(LINK(this, SvxBmpNumValueSet, FormatHdl_Impl));
 }
 
 
 SvxBmpNumValueSet::~SvxBmpNumValueSet()
 {
-    GalleryExplorer::EndLocking(GALLERY_THEME_BULLETS);
-    aFormatTimer.Stop();
+    disposeOnce();
 }
 
-void SvxBmpNumValueSet::UserDraw( const UserDrawEvent& rUDEvt )
+void SvxBmpNumValueSet::dispose()
+{
+    GalleryExplorer::EndLocking(GALLERY_THEME_BULLETS);
+    aFormatIdle.Stop();
+    SvxNumValueSet::dispose();
+}
+
+void SvxBmpNumValueSet::UserDraw(const UserDrawEvent& rUDEvt)
 {
     SvxNumValueSet::UserDraw(rUDEvt);
 
-    Rectangle aRect = rUDEvt.GetRect();
-    OutputDevice*  pDev = rUDEvt.GetDevice();
+    tools::Rectangle aRect = rUDEvt.GetRect();
+    vcl::RenderContext* pDev = rUDEvt.GetRenderContext();
     sal_uInt16  nItemId = rUDEvt.GetItemId();
     Point aBLPos = aRect.TopLeft();
 
-    int nRectHeight = aRect.GetHeight();
+    long nRectHeight = aRect.GetHeight();
     Size aSize(nRectHeight/8, nRectHeight/8);
 
     Graphic aGraphic;
     if(!GalleryExplorer::GetGraphicObj( GALLERY_THEME_BULLETS, nItemId - 1,
-                        &aGraphic, NULL))
+                        &aGraphic))
     {
         bGrfNotFound = true;
     }
@@ -523,16 +549,15 @@ void SvxBmpNumValueSet::UserDraw( const UserDrawEvent& rUDEvt )
     }
 }
 
-IMPL_LINK_NOARG(SvxBmpNumValueSet, FormatHdl_Impl)
+IMPL_LINK_NOARG(SvxBmpNumValueSet, FormatHdl_Impl, Timer *, void)
 {
     // only when a graphics was not there, it needs to be formatted
-    if(bGrfNotFound)
+    if (bGrfNotFound)
     {
+        SetFormat();
         bGrfNotFound = false;
-        Format();
     }
     Invalidate();
-    return 0;
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
