@@ -18,11 +18,11 @@
  */
 
 
-#include "svx/svdstr.hrc"
-#include "svdglob.hxx"
+#include <svx/strings.hrc>
+#include <svdglob.hxx>
 #include <tools/poly.hxx>
 #include <svx/svdpage.hxx>
-#include "svx/globl3d.hxx"
+#include <svx/globl3d.hxx>
 #include <svx/lathe3d.hxx>
 #include <svx/xpoly.hxx>
 #include <svx/svxids.hrc>
@@ -44,15 +44,12 @@ sdr::contact::ViewContact* E3dLatheObj::CreateObjectSpecificViewContact()
 }
 
 
-
 sdr::properties::BaseProperties* E3dLatheObj::CreateObjectSpecificProperties()
 {
     return new sdr::properties::E3dLatheProperties(*this);
 }
 
 
-
-
 // Constructor from 3D polygon, scale is the conversion factor for the coordinates
 
 E3dLatheObj::E3dLatheObj(E3dDefaultAttributes& rDefault, const basegfx::B2DPolyPolygon& rPoly2D)
@@ -73,7 +70,7 @@ E3dLatheObj::E3dLatheObj(E3dDefaultAttributes& rDefault, const basegfx::B2DPolyP
 
     if(maPolyPoly2D.count())
     {
-        const basegfx::B2DPolygon rPoly(maPolyPoly2D.getB2DPolygon(0L));
+        const basegfx::B2DPolygon rPoly(maPolyPoly2D.getB2DPolygon(0));
         sal_uInt32 nSegCnt(rPoly.count());
 
         if(nSegCnt && !rPoly.isClosed())
@@ -93,7 +90,7 @@ E3dLatheObj::E3dLatheObj()
     SetDefaultAttributes(aDefault);
 }
 
-void E3dLatheObj::SetDefaultAttributes(E3dDefaultAttributes& rDefault)
+void E3dLatheObj::SetDefaultAttributes(E3dDefaultAttributes const & rDefault)
 {
     GetProperties().SetObjectItemDirect(Svx3DSmoothNormalsItem(rDefault.GetDefaultLatheSmoothed()));
     GetProperties().SetObjectItemDirect(Svx3DSmoothLidsItem(rDefault.GetDefaultLatheSmoothFrontBack()));
@@ -130,7 +127,7 @@ void E3dLatheObj::SetPolyPoly2D(const basegfx::B2DPolyPolygon& rNew)
 
         if(maPolyPoly2D.count())
         {
-            const basegfx::B2DPolygon rPoly(maPolyPoly2D.getB2DPolygon(0L));
+            const basegfx::B2DPolygon rPoly(maPolyPoly2D.getB2DPolygon(0));
             sal_uInt32 nSegCnt(rPoly.count());
 
             if(nSegCnt && !rPoly.isClosed())
@@ -177,7 +174,7 @@ bool E3dLatheObj::IsBreakObjPossible()
 SdrAttrObj* E3dLatheObj::GetBreakObj()
 {
     // create PathObj
-    basegfx::B3DPolyPolygon aLathePoly3D(basegfx::tools::createB3DPolyPolygonFromB2DPolyPolygon(maPolyPoly2D));
+    basegfx::B3DPolyPolygon aLathePoly3D(basegfx::utils::createB3DPolyPolygonFromB2DPolyPolygon(maPolyPoly2D));
     basegfx::B2DPolyPolygon aTransPoly(TransformToScreenCoor(aLathePoly3D));
     SdrPathObj* pPathObj = new SdrPathObj(OBJ_PLIN, aTransPoly);
 
