@@ -17,16 +17,16 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "filtnav.hxx"
-#include "fmexch.hxx"
-#include "fmhelp.hrc"
-#include "fmitems.hxx"
-#include "fmprop.hrc"
-#include "svx/fmresids.hrc"
+#include <memory>
+#include <filtnav.hxx>
+#include <fmexch.hxx>
+#include <helpids.h>
+#include <fmitems.hxx>
+#include <fmprop.hxx>
+#include <svx/strings.hrc>
 
 #include <com/sun/star/awt/XControlModel.hpp>
 #include <com/sun/star/awt/XControl.hpp>
-#include <com/sun/star/awt/XTextComponent.hpp>
 #include <com/sun/star/form/runtime/XFormController.hpp>
 #include <com/sun/star/lang/XUnoTunnel.hpp>
 #include <com/sun/star/util/NumberFormatter.hpp>
@@ -54,17 +54,19 @@
 #include <vcl/settings.hxx>
 #include <tools/diagnose_ex.h>
 #include <svtools/svlbitm.hxx>
-#include "svtools/treelistentry.hxx"
-#include "svtools/viewdataentry.hxx"
+#include <svtools/treelistentry.hxx>
+#include <svtools/viewdataentry.hxx>
+
+#include <bitmaps.hlst>
 
 #include <functional>
 
 #define DROP_ACTION_TIMER_INITIAL_TICKS     10
-    // solange dauert es, bis das Scrollen anspringt
+    // it takes this long for the scrolling to begin
 #define DROP_ACTION_TIMER_SCROLL_TICKS      3
-    // in diesen Intervallen wird jeweils eine Zeile gescrollt
+    // a line is scrolled in these intervals
 #define DROP_ACTION_TIMER_TICK_BASE         10
-    // das ist die Basis, mit der beide Angaben multipliziert werden (in ms)
+    // this is the basis for multiplying both figures (in ms)
 
 using namespace ::svxform;
 using namespace ::connectivity;
@@ -76,8 +78,6 @@ namespace svxform
 
 
     using ::com::sun::star::uno::Reference;
-    using ::com::sun::star::lang::XMultiServiceFactory;
-    using ::com::sun::star::awt::TextEvent;
     using ::com::sun::star::container::XIndexAccess;
     using ::com::sun::star::uno::UNO_QUERY;
     using ::com::sun::star::beans::XPropertySet;
@@ -93,7 +93,6 @@ namespace svxform
     using ::com::sun::star::sdbc::XConnection;
     using ::com::sun::star::util::XNumberFormatsSupplier;
     using ::com::sun::star::util::XNumberFormatter;
-    using ::com::sun::star::util::XNumberFormatter2;
     using ::com::sun::star::util::NumberFormatter;
     using ::com::sun::star::sdbc::XRowSet;
     using ::com::sun::star::lang::Locale;
@@ -102,7 +101,6 @@ namespace svxform
     using ::com::sun::star::uno::UNO_QUERY_THROW;
     using ::com::sun::star::uno::UNO_SET_THROW;
     using ::com::sun::star::uno::Exception;
-    using ::com::sun::star::awt::XTextComponent;
     using ::com::sun::star::uno::Sequence;
 
 
@@ -140,8 +138,6 @@ Image FmFilterData::GetImage() const
     return Image();
 }
 
-
-
 FmParentData::~FmParentData()
 {
     for (::std::vector<FmFilterData*>::const_iterator i = m_aChildren.begin();
@@ -149,16 +145,11 @@ FmParentData::~FmParentData()
         delete (*i);
 }
 
-
-
 Image FmFormItem::GetImage() const
 {
-    ImageList aNavigatorImages( SVX_RES( RID_SVXIMGLIST_FMEXPL ) );
-    return aNavigatorImages.GetImage( RID_SVXIMG_FORM );
+    return Image(BitmapEx(RID_SVXBMP_FORM));
 }
 
-
-
 FmFilterItem* FmFilterItems::Find( const ::sal_Int32 _nFilterComponentIndex ) const
 {
     for (   ::std::vector< FmFilterData* >::const_iterator i = m_aChildren.begin();
@@ -174,15 +165,11 @@ FmFilterItem* FmFilterItems::Find( const ::sal_Int32 _nFilterComponentIndex ) co
     return nullptr;
 }
 
-
 Image FmFilterItems::GetImage() const
 {
-    ImageList aNavigatorImages( SVX_RES( RID_SVXIMGLIST_FMEXPL ) );
-    return aNavigatorImages.GetImage( RID_SVXIMG_FILTER );
+    return Image(BitmapEx(RID_SVXBMP_FILTER));
 }
 
-
-
 FmFilterItem::FmFilterItem( FmFilterItems* pParent,
                             const OUString& aFieldName,
                             const OUString& aText,
@@ -193,14 +180,11 @@ FmFilterItem::FmFilterItem( FmFilterItems* pParent,
 {
 }
 
-
 Image FmFilterItem::GetImage() const
 {
-    ImageList aNavigatorImages( SVX_RES( RID_SVXIMGLIST_FMEXPL ) );
-    return aNavigatorImages.GetImage( RID_SVXIMG_FIELD );
+    return Image(BitmapEx(RID_SVXBMP_FIELD));
 }
 
-
 // Hints for communication between model and view
 
 class FmFilterHint : public SfxHint
@@ -212,7 +196,6 @@ public:
     FmFilterData* GetData() const { return m_pData; }
 };
 
-
 class FmFilterInsertedHint : public FmFilterHint
 {
     sal_uLong m_nPos;   // Position relative to the parent of the data
@@ -225,7 +208,6 @@ public:
     sal_uLong GetPos() const { return m_nPos; }
 };
 
-
 class FmFilterRemovedHint : public FmFilterHint
 {
 public:
@@ -241,23 +223,19 @@ public:
         :FmFilterHint(pData){}
 };
 
-
 class FilterClearingHint : public SfxHint
 {
 public:
     FilterClearingHint(){}
 };
 
-
 class FmFilterCurrentChangedHint : public SfxHint
 {
 public:
     FmFilterCurrentChangedHint(){}
 };
 
-
-// class FmFilterAdapter, Listener an den FilterControls
-
+// class FmFilterAdapter, listener at the FilterControls
 class FmFilterAdapter : public ::cppu::WeakImplHelper< XFilterControllerListener >
 {
     FmFilterModel*              m_pModel;
@@ -267,15 +245,16 @@ public:
     FmFilterAdapter(FmFilterModel* pModel, const Reference< XIndexAccess >& xControllers);
 
 // XEventListener
-    virtual void SAL_CALL disposing(const EventObject& Source) throw( RuntimeException, std::exception ) override;
+    virtual void SAL_CALL disposing(const EventObject& Source) override;
 
 // XFilterControllerListener
-    virtual void SAL_CALL predicateExpressionChanged( const FilterEvent& _Event ) throw (RuntimeException, std::exception) override;
-    virtual void SAL_CALL disjunctiveTermRemoved( const FilterEvent& _Event ) throw (RuntimeException, std::exception) override;
-    virtual void SAL_CALL disjunctiveTermAdded( const FilterEvent& _Event ) throw (RuntimeException, std::exception) override;
+    virtual void SAL_CALL predicateExpressionChanged( const FilterEvent& Event ) override;
+    virtual void SAL_CALL disjunctiveTermRemoved( const FilterEvent& Event ) override;
+    virtual void SAL_CALL disjunctiveTermAdded( const FilterEvent& Event ) override;
 
 // helpers
-    void dispose() throw( RuntimeException );
+    /// @throws RuntimeException
+    void dispose();
 
     void AddOrRemoveListener( const Reference< XIndexAccess >& _rxControllers, const bool _bAdd );
 
@@ -293,7 +272,7 @@ FmFilterAdapter::FmFilterAdapter(FmFilterModel* pModel, const Reference< XIndexA
 }
 
 
-void FmFilterAdapter::dispose() throw( RuntimeException )
+void FmFilterAdapter::dispose()
 {
     AddOrRemoveListener( m_xControllers, false );
 }
@@ -342,7 +321,7 @@ void FmFilterAdapter::setText(sal_Int32 nRowPos,
 
 // XEventListener
 
-void SAL_CALL FmFilterAdapter::disposing(const EventObject& /*e*/) throw( RuntimeException, std::exception )
+void SAL_CALL FmFilterAdapter::disposing(const EventObject& /*e*/)
 {
 }
 
@@ -382,7 +361,7 @@ namespace
 
 // XFilterControllerListener
 
-void FmFilterAdapter::predicateExpressionChanged( const FilterEvent& _Event ) throw( RuntimeException, std::exception )
+void FmFilterAdapter::predicateExpressionChanged( const FilterEvent& Event )
 {
     SolarMutexGuard aGuard;
 
@@ -390,8 +369,8 @@ void FmFilterAdapter::predicateExpressionChanged( const FilterEvent& _Event ) th
         return;
 
     // the controller which sent the event
-    Reference< XFormController > xController( _Event.Source, UNO_QUERY_THROW );
-    Reference< XFilterController > xFilterController( _Event.Source, UNO_QUERY_THROW );
+    Reference< XFormController > xController( Event.Source, UNO_QUERY_THROW );
+    Reference< XFilterController > xFilterController( Event.Source, UNO_QUERY_THROW );
     Reference< XForm > xForm( xController->getModel(), UNO_QUERY_THROW );
 
     FmFormItem* pFormItem = m_pModel->Find( m_pModel->m_aChildren, xForm );
@@ -403,13 +382,13 @@ void FmFilterAdapter::predicateExpressionChanged( const FilterEvent& _Event ) th
 
     FmFilterData* pData = pFormItem->GetChildren()[nActiveTerm];
     FmFilterItems& rFilter = dynamic_cast<FmFilterItems&>(*pData);
-    FmFilterItem* pFilterItem = rFilter.Find( _Event.FilterComponent );
+    FmFilterItem* pFilterItem = rFilter.Find( Event.FilterComponent );
     if ( pFilterItem )
     {
-        if ( !_Event.PredicateExpression.isEmpty())
+        if ( !Event.PredicateExpression.isEmpty())
         {
-            pFilterItem->SetText( _Event.PredicateExpression );
-            // UI benachrichtigen
+            pFilterItem->SetText( Event.PredicateExpression );
+            // notify the UI
             FmFilterTextChangedHint aChangeHint(pFilterItem);
             m_pModel->Broadcast( aChangeHint );
         }
@@ -422,9 +401,9 @@ void FmFilterAdapter::predicateExpressionChanged( const FilterEvent& _Event ) th
     else
     {
         // searching the component by field name
-        OUString aFieldName( lcl_getLabelName_nothrow( xFilterController->getFilterComponent( _Event.FilterComponent ) ) );
+        OUString aFieldName( lcl_getLabelName_nothrow( xFilterController->getFilterComponent( Event.FilterComponent ) ) );
 
-        pFilterItem = new FmFilterItem(&rFilter, aFieldName, _Event.PredicateExpression, _Event.FilterComponent);
+        pFilterItem = new FmFilterItem(&rFilter, aFieldName, Event.PredicateExpression, Event.FilterComponent);
         m_pModel->Insert(rFilter.GetChildren().end(), pFilterItem);
     }
 
@@ -433,12 +412,12 @@ void FmFilterAdapter::predicateExpressionChanged( const FilterEvent& _Event ) th
 }
 
 
-void SAL_CALL FmFilterAdapter::disjunctiveTermRemoved( const FilterEvent& _Event ) throw (RuntimeException, std::exception)
+void SAL_CALL FmFilterAdapter::disjunctiveTermRemoved( const FilterEvent& Event )
 {
     SolarMutexGuard aGuard;
 
-    Reference< XFormController > xController( _Event.Source, UNO_QUERY_THROW );
-    Reference< XFilterController > xFilterController( _Event.Source, UNO_QUERY_THROW );
+    Reference< XFormController > xController( Event.Source, UNO_QUERY_THROW );
+    Reference< XFilterController > xFilterController( Event.Source, UNO_QUERY_THROW );
     Reference< XForm > xForm( xController->getModel(), UNO_QUERY_THROW );
 
     FmFormItem* pFormItem = m_pModel->Find( m_pModel->m_aChildren, xForm );
@@ -447,33 +426,33 @@ void SAL_CALL FmFilterAdapter::disjunctiveTermRemoved( const FilterEvent& _Event
         return;
 
     ::std::vector< FmFilterData* >& rTermItems = pFormItem->GetChildren();
-    const bool bValidIndex = ( _Event.DisjunctiveTerm >= 0 ) && ( (size_t)_Event.DisjunctiveTerm < rTermItems.size() );
+    const bool bValidIndex = ( Event.DisjunctiveTerm >= 0 ) && ( (size_t)Event.DisjunctiveTerm < rTermItems.size() );
     OSL_ENSURE( bValidIndex, "FmFilterAdapter::disjunctiveTermRemoved: invalid term index!" );
     if ( !bValidIndex )
         return;
 
     // if the first term was removed, then the to-be first term needs its text updated
-    if ( _Event.DisjunctiveTerm == 0 )
+    if ( Event.DisjunctiveTerm == 0 )
     {
-        rTermItems[1]->SetText( SVX_RESSTR(RID_STR_FILTER_FILTER_FOR));
+        rTermItems[1]->SetText( SvxResId(RID_STR_FILTER_FILTER_FOR));
         FmFilterTextChangedHint aChangeHint( rTermItems[1] );
         m_pModel->Broadcast( aChangeHint );
     }
 
     // finally remove the entry from the model
-    m_pModel->Remove( rTermItems.begin() + _Event.DisjunctiveTerm );
+    m_pModel->Remove( rTermItems.begin() + Event.DisjunctiveTerm );
 
     // ensure there's one empty term in the filter, just in case the currently removed one was the last empty one
     m_pModel->EnsureEmptyFilterRows( *pFormItem );
 }
 
 
-void SAL_CALL FmFilterAdapter::disjunctiveTermAdded( const FilterEvent& _Event ) throw (RuntimeException, std::exception)
+void SAL_CALL FmFilterAdapter::disjunctiveTermAdded( const FilterEvent& Event )
 {
     SolarMutexGuard aGuard;
 
-    Reference< XFormController > xController( _Event.Source, UNO_QUERY_THROW );
-    Reference< XFilterController > xFilterController( _Event.Source, UNO_QUERY_THROW );
+    Reference< XFormController > xController( Event.Source, UNO_QUERY_THROW );
+    Reference< XFilterController > xFilterController( Event.Source, UNO_QUERY_THROW );
     Reference< XForm > xForm( xController->getModel(), UNO_QUERY_THROW );
 
     FmFormItem* pFormItem = m_pModel->Find( m_pModel->m_aChildren, xForm );
@@ -481,7 +460,7 @@ void SAL_CALL FmFilterAdapter::disjunctiveTermAdded( const FilterEvent& _Event )
     if ( !pFormItem )
         return;
 
-    const sal_Int32 nInsertPos = _Event.DisjunctiveTerm;
+    const sal_Int32 nInsertPos = Event.DisjunctiveTerm;
     bool bValidIndex = ( nInsertPos >= 0 ) && ( (size_t)nInsertPos <= pFormItem->GetChildren().size() );
     if ( !bValidIndex )
     {
@@ -491,7 +470,7 @@ void SAL_CALL FmFilterAdapter::disjunctiveTermAdded( const FilterEvent& _Event )
 
     const ::std::vector< FmFilterData* >::iterator insertPos = pFormItem->GetChildren().begin() + nInsertPos;
 
-    FmFilterItems* pFilterItems = new FmFilterItems(pFormItem, SVX_RESSTR(RID_STR_FILTER_FILTER_OR));
+    FmFilterItems* pFilterItems = new FmFilterItems(pFormItem, SvxResId(RID_STR_FILTER_FILTER_OR));
     m_pModel->Insert( insertPos, pFilterItems );
 }
 
@@ -499,7 +478,6 @@ void SAL_CALL FmFilterAdapter::disjunctiveTermAdded( const FilterEvent& _Event )
 FmFilterModel::FmFilterModel()
               :FmParentData(nullptr, OUString())
               ,OSQLParserClient(comphelper::getProcessComponentContext())
-              ,m_pAdapter(nullptr)
               ,m_pCurrentItems(nullptr)
 {
 }
@@ -518,11 +496,10 @@ void FmFilterModel::Clear()
     Broadcast( aClearedHint );
 
     // lose endings
-    if (m_pAdapter)
+    if (m_pAdapter.is())
     {
         m_pAdapter->dispose();
-        m_pAdapter->release();
-        m_pAdapter= nullptr;
+        m_pAdapter.clear();
     }
 
     m_pCurrentItems  = nullptr;
@@ -560,7 +537,6 @@ void FmFilterModel::Update(const Reference< XIndexAccess > & xControllers, const
 
         // Listening for TextChanges
         m_pAdapter = new FmFilterAdapter(this, xControllers);
-        m_pAdapter->acquire();
 
         SetCurrentController(xCurrent);
         EnsureEmptyFilterRows( *this );
@@ -590,20 +566,17 @@ void FmFilterModel::Update(const Reference< XIndexAccess > & xControllers, FmPar
             Reference< XFilterController > xFilterController( pFormItem->GetFilterController(), UNO_SET_THROW );
 
             // insert the existing filters for the form
-            OUString aTitle(SVX_RESSTR(RID_STR_FILTER_FILTER_FOR));
+            OUString aTitle(SvxResId(RID_STR_FILTER_FILTER_FOR));
 
             Sequence< Sequence< OUString > > aExpressions = xFilterController->getPredicateExpressions();
-            for (   const Sequence< OUString >* pConjunctionTerm = aExpressions.getConstArray();
-                    pConjunctionTerm != aExpressions.getConstArray() + aExpressions.getLength();
-                    ++pConjunctionTerm
-                )
+            for ( auto const & conjunctionTerm : aExpressions )
             {
                 // we always display one row, even if there's no term to be displayed
                 FmFilterItems* pFilterItems = new FmFilterItems( pFormItem, aTitle );
                 Insert( pFormItem->GetChildren().end(), pFilterItems );
 
-                const Sequence< OUString >& rDisjunction( *pConjunctionTerm );
-                for (   const OUString* pDisjunctiveTerm = rDisjunction.getConstArray();
+                const Sequence< OUString >& rDisjunction( conjunctionTerm );
+                for (  const OUString* pDisjunctiveTerm = rDisjunction.getConstArray();
                         pDisjunctiveTerm != rDisjunction.getConstArray() + rDisjunction.getLength();
                         ++pDisjunctiveTerm
                     )
@@ -624,7 +597,7 @@ void FmFilterModel::Update(const Reference< XIndexAccess > & xControllers, FmPar
                 }
 
                 // title for the next conditions
-                aTitle = SVX_RESSTR( RID_STR_FILTER_FILTER_OR );
+                aTitle = SvxResId( RID_STR_FILTER_FILTER_OR );
             }
 
             // now add dependent controllers
@@ -712,9 +685,10 @@ void FmFilterModel::SetCurrentController(const Reference< XFormController > & xC
 void FmFilterModel::AppendFilterItems( FmFormItem& _rFormItem )
 {
     // insert the condition behind the last filter items
+    ::std::vector<FmFilterData*>::const_reverse_iterator aEnd = _rFormItem.GetChildren().rend();
     ::std::vector<FmFilterData*>::reverse_iterator iter;
     for (   iter = _rFormItem.GetChildren().rbegin();
-            iter != _rFormItem.GetChildren().rend();
+            iter != aEnd;
             ++iter
         )
     {
@@ -751,7 +725,7 @@ void FmFilterModel::Insert(const ::std::vector<FmFilterData*>::iterator& rPos, F
         rItems.insert(rPos, pData);
     }
 
-    // UI benachrichtigen
+    // notify the UI
     FmFilterInsertedHint aInsertedHint(pData, nPos);
     Broadcast( aInsertedHint );
 }
@@ -782,8 +756,10 @@ void FmFilterModel::Remove(FmFilterData* pData)
                 while ( !rChildren.empty() )
                 {
                     ::std::vector< FmFilterData* >::iterator removePos = rChildren.end() - 1;
-                    FmFilterItem* pFilterItem = dynamic_cast<FmFilterItem*>( *removePos  );
-                    FmFilterAdapter::setText( nPos, pFilterItem, OUString() );
+                    if (FmFilterItem* pFilterItem = dynamic_cast<FmFilterItem*>( *removePos))
+                    {
+                        FmFilterAdapter::setText( nPos, pFilterItem, OUString() );
+                    }
                     Remove( removePos );
                 }
             }
@@ -801,7 +777,7 @@ void FmFilterModel::Remove(FmFilterData* pData)
     {
         FmFilterItem& rFilterItem = dynamic_cast<FmFilterItem&>(*pData);
 
-        // if its the last condition remove the parent
+        // if it's the last condition remove the parent
         if (rItems.size() == 1)
             Remove(rFilterItem.GetParent());
         else
@@ -833,7 +809,7 @@ void FmFilterModel::Remove( const ::std::vector<FmFilterData*>::iterator& rPos )
 }
 
 
-bool FmFilterModel::ValidateText(FmFilterItem* pItem, OUString& rText, OUString& rErrorMsg) const
+bool FmFilterModel::ValidateText(FmFilterItem const * pItem, OUString& rText, OUString& rErrorMsg) const
 {
     FmFormItem* pFormItem = dynamic_cast<FmFormItem*>( pItem->GetParent()->GetParent()  );
     try
@@ -886,7 +862,7 @@ void FmFilterModel::Append(FmFilterItems* pItems, FmFilterItem* pFilterItem)
 void FmFilterModel::SetTextForItem(FmFilterItem* pItem, const OUString& rText)
 {
     ::std::vector<FmFilterData*>& rItems = pItem->GetParent()->GetParent()->GetChildren();
-    ::std::vector<FmFilterData*>::iterator i = ::std::find(rItems.begin(), rItems.end(), pItem->GetParent());
+    ::std::vector<FmFilterData*>::const_iterator i = ::std::find(rItems.begin(), rItems.end(), pItem->GetParent());
     sal_Int32 nParentPos = i - rItems.begin();
 
     FmFilterAdapter::setText(nParentPos, pItem, rText);
@@ -942,7 +918,7 @@ void FmFilterModel::SetCurrentItems(FmFilterItems* pCurrent)
         m_pCurrentItems = nullptr;
 
 
-    // UI benachrichtigen
+    // notify the UI
     FmFilterCurrentChangedHint aHint;
     Broadcast( aHint );
 }
@@ -953,9 +929,10 @@ void FmFilterModel::EnsureEmptyFilterRows( FmParentData& _rItem )
     // checks whether for each form there's one free level for input
     ::std::vector< FmFilterData* >& rChildren = _rItem.GetChildren();
     bool bAppendLevel = dynamic_cast<const FmFormItem*>(&_rItem) !=  nullptr;
+    ::std::vector<FmFilterData*>::const_iterator aEnd = rChildren.end();
 
     for (   ::std::vector<FmFilterData*>::iterator i = rChildren.begin();
-            i != rChildren.end();
+            i != aEnd;
             ++i
         )
     {
@@ -986,12 +963,14 @@ void FmFilterModel::EnsureEmptyFilterRows( FmParentData& _rItem )
 class FmFilterItemsString : public SvLBoxString
 {
 public:
-    FmFilterItemsString( SvTreeListEntry* pEntry, sal_uInt16 nFlags, const OUString& rStr )
-        :SvLBoxString(pEntry,nFlags,rStr){}
+    explicit FmFilterItemsString(const OUString& rStr)
+        : SvLBoxString(rStr)
+    {
+    }
 
     virtual void Paint(const Point& rPos, SvTreeListBox& rDev, vcl::RenderContext& rRenderContext,
                        const SvViewDataEntry* pView, const SvTreeListEntry& rEntry) override;
-    virtual void InitViewData( SvTreeListBox* pView,SvTreeListEntry* pEntry, SvViewDataItem* pViewData) override;
+    virtual void InitViewData( SvTreeListBox* pView,SvTreeListEntry* pEntry, SvViewDataItem* pViewData = nullptr) override;
 };
 
 const int nxDBmp = 12;
@@ -1009,7 +988,7 @@ void FmFilterItemsString::Paint(const Point& rPos, SvTreeListBox& rDev, vcl::Ren
         rRenderContext.Push(PushFlags::LINECOLOR);
         rRenderContext.SetLineColor(rRenderContext.GetTextColor());
 
-        Rectangle aRect(rPos, GetSize(&rDev, &rEntry));
+        tools::Rectangle aRect(rPos, GetSize(&rDev, &rEntry));
         Point aFirst(rPos.X(), aRect.Bottom() - 6);
         Point aSecond(aFirst .X() + 2, aFirst.Y() + 3);
 
@@ -1043,8 +1022,8 @@ class FmFilterString : public SvLBoxString
     OUString m_aName;
 
 public:
-    FmFilterString( SvTreeListEntry* pEntry, sal_uInt16 nFlags, const OUString& rStr, const OUString& aName)
-        : SvLBoxString(pEntry,nFlags,rStr)
+    FmFilterString( const OUString& rStr, const OUString& aName)
+        : SvLBoxString(rStr)
         , m_aName(aName)
     {
         m_aName += ": ";
@@ -1052,7 +1031,7 @@ public:
 
     virtual void Paint(const Point& rPos, SvTreeListBox& rDev, vcl::RenderContext& rRenderContext,
                        const SvViewDataEntry* pView, const SvTreeListEntry& rEntry) override;
-    virtual void InitViewData( SvTreeListBox* pView,SvTreeListEntry* pEntry, SvViewDataItem* pViewData) override;
+    virtual void InitViewData( SvTreeListBox* pView,SvTreeListEntry* pEntry, SvViewDataItem* pViewData = nullptr) override;
 };
 
 const int nxD = 4;
@@ -1102,23 +1081,20 @@ FmFilterNavigator::FmFilterNavigator( vcl::Window* pParent )
 {
     SetHelpId( HID_FILTER_NAVIGATOR );
 
-    {
-        ImageList aNavigatorImages( SVX_RES( RID_SVXIMGLIST_FMEXPL ) );
-        SetNodeBitmaps(
-            aNavigatorImages.GetImage( RID_SVXIMG_COLLAPSEDNODE ),
-            aNavigatorImages.GetImage( RID_SVXIMG_EXPANDEDNODE )
-        );
-    }
+    SetNodeBitmaps(
+        Image(BitmapEx(RID_SVXBMP_COLLAPSEDNODE)),
+        Image(BitmapEx(RID_SVXBMP_EXPANDEDNODE))
+    );
 
     m_pModel = new FmFilterModel();
     StartListening( *m_pModel );
 
     EnableInplaceEditing( true );
-    SetSelectionMode(MULTIPLE_SELECTION);
+    SetSelectionMode(SelectionMode::Multiple);
 
     SetDragDropMode(DragDropMode::ALL);
 
-    m_aDropActionTimer.SetTimeoutHdl(LINK(this, FmFilterNavigator, OnDropActionTimer));
+    m_aDropActionTimer.SetInvokeHandler(LINK(this, FmFilterNavigator, OnDropActionTimer));
 }
 
 
@@ -1168,7 +1144,7 @@ bool FmFilterNavigator::EditingEntry( SvTreeListEntry* pEntry, Selection& rSelec
     if (!SvTreeListBox::EditingEntry( pEntry, rSelection ))
         return false;
 
-    return pEntry && dynamic_cast<const FmFilterItem*>(static_cast<FmFilterData*>(pEntry->GetUserData())) == nullptr;
+    return pEntry && dynamic_cast<const FmFilterItem*>(static_cast<FmFilterData*>(pEntry->GetUserData())) != nullptr;
 }
 
 
@@ -1207,7 +1183,7 @@ bool FmFilterNavigator::EditedEntry( SvTreeListEntry* pEntry, const OUString& rN
         {
             // display the error and return sal_False
             SQLContext aError;
-            aError.Message = SVX_RESSTR(RID_STR_SYNTAXERROR);
+            aError.Message = SvxResId(RID_STR_SYNTAXERROR);
             aError.Details = aErrorMsg;
             displayException(aError, this);
 
@@ -1218,7 +1194,7 @@ bool FmFilterNavigator::EditedEntry( SvTreeListEntry* pEntry, const OUString& rN
 }
 
 
-IMPL_LINK_TYPED( FmFilterNavigator, OnRemove, void*, p, void )
+IMPL_LINK( FmFilterNavigator, OnRemove, void*, p, void )
 {
     SvTreeListEntry* pEntry = static_cast<SvTreeListEntry*>(p);
     // now remove the entry
@@ -1226,7 +1202,7 @@ IMPL_LINK_TYPED( FmFilterNavigator, OnRemove, void*, p, void )
 }
 
 
-IMPL_LINK_NOARG_TYPED(FmFilterNavigator, OnDropActionTimer, Timer *, void)
+IMPL_LINK_NOARG(FmFilterNavigator, OnDropActionTimer, Timer *, void)
 {
     if (--m_aTimerCounter > 0)
         return;
@@ -1253,7 +1229,6 @@ IMPL_LINK_NOARG_TYPED(FmFilterNavigator, OnDropActionTimer, Timer *, void)
 }
 
 
-
 sal_Int8 FmFilterNavigator::AcceptDrop( const AcceptDropEvent& rEvt )
 {
     Point aDropPos = rEvt.maPosPixel;
@@ -1342,7 +1317,7 @@ sal_Int8 FmFilterNavigator::AcceptDrop( const AcceptDropEvent& rEvt )
 
 namespace
 {
-    FmFilterItems* getTargetItems(SvTreeListEntry* _pTarget)
+    FmFilterItems* getTargetItems(SvTreeListEntry const * _pTarget)
     {
         FmFilterData*   pData = static_cast<FmFilterData*>(_pTarget->GetUserData());
         FmFilterItems*  pTargetItems = dynamic_cast<FmFilterItems*>(pData);
@@ -1389,10 +1364,10 @@ void FmFilterNavigator::InitEntry(SvTreeListEntry* pEntry,
     std::unique_ptr<SvLBoxString> pString;
 
     if (dynamic_cast<const FmFilterItem*>(static_cast<FmFilterData*>(pEntry->GetUserData())) != nullptr)
-        pString.reset(new FmFilterString(pEntry, 0, rStr,
+        pString.reset(new FmFilterString(rStr,
             static_cast<FmFilterItem*>(pEntry->GetUserData())->GetFieldName()));
     else if (dynamic_cast<const FmFilterItems*>(static_cast<FmFilterData*>(pEntry->GetUserData())) != nullptr)
-        pString.reset(new FmFilterItemsString(pEntry, 0, rStr));
+        pString.reset(new FmFilterItemsString(rStr));
 
     if (pString)
         pEntry->ReplaceItem(std::move(pString), 1 );
@@ -1401,7 +1376,7 @@ void FmFilterNavigator::InitEntry(SvTreeListEntry* pEntry,
 
 bool FmFilterNavigator::Select( SvTreeListEntry* pEntry, bool bSelect )
 {
-    if (bSelect == IsSelected(pEntry))  // das passiert manchmal, ich glaube, die Basisklasse geht zu sehr auf Nummer sicher ;)
+    if (bSelect == IsSelected(pEntry))  // This happens sometimes. I think the basic class errs too much on the side of caution. ;)
         return true;
 
     if (SvTreeListBox::Select(pEntry, bSelect))
@@ -1490,9 +1465,9 @@ void FmFilterNavigator::Insert(FmFilterData* pItem, sal_uLong nPos)
 }
 
 
-void FmFilterNavigator::Remove(FmFilterData* pItem)
+void FmFilterNavigator::Remove(FmFilterData const * pItem)
 {
-    // der Entry zu den Daten
+    // the entry for the data
     SvTreeListEntry* pEntry = FindEntry(pItem);
 
     if (pEntry == m_pEditingCurrently)
@@ -1592,7 +1567,7 @@ void FmFilterNavigator::Command( const CommandEvent& rEvt )
     {
         case CommandEventId::ContextMenu:
         {
-            // die Stelle, an der geklickt wurde
+            // the place where it was clicked
             Point aWhere;
             SvTreeListEntry* pClicked = nullptr;
             if (rEvt.IsMouseEvent())
@@ -1636,48 +1611,45 @@ void FmFilterNavigator::Command( const CommandEvent& rEvt )
                     aSelectList.clear();
             }
 
-            PopupMenu aContextMenu(SVX_RES(RID_FM_FILTER_MENU));
+            VclBuilder aBuilder(nullptr, VclBuilderContainer::getUIRootDir(), "svx/ui/filtermenu.ui", "");
+            VclPtr<PopupMenu> aContextMenu(aBuilder.get_menu("menu"));
 
-            // every condition could be deleted except the first one if its the only one
-            aContextMenu.EnableItem( SID_FM_DELETE, !aSelectList.empty() );
+            // every condition could be deleted except the first one if it's the only one
+            aContextMenu->EnableItem(aContextMenu->GetItemId("delete"), !aSelectList.empty());
 
 
             bool bEdit = dynamic_cast<FmFilterItem*>( static_cast<FmFilterData*>(pClicked->GetUserData()) ) != nullptr &&
                 IsSelected(pClicked) && GetSelectionCount() == 1;
 
-            aContextMenu.EnableItem( SID_FM_FILTER_EDIT,
-                bEdit );
-            aContextMenu.EnableItem( SID_FM_FILTER_IS_NULL,
-                bEdit );
-            aContextMenu.EnableItem( SID_FM_FILTER_IS_NOT_NULL,
-                bEdit );
+            aContextMenu->EnableItem(aContextMenu->GetItemId("edit"), bEdit);
+            aContextMenu->EnableItem(aContextMenu->GetItemId("isnull"), bEdit);
+            aContextMenu->EnableItem(aContextMenu->GetItemId("isnotnull"), bEdit);
 
-            aContextMenu.RemoveDisabledEntries(true, true);
-            sal_uInt16 nSlotId = aContextMenu.Execute( this, aWhere );
-            switch( nSlotId )
+            aContextMenu->RemoveDisabledEntries(true, true);
+            aContextMenu->Execute(this, aWhere);
+            OString sIdent = aContextMenu->GetCurItemIdent();
+            if (sIdent == "edit")
+                EditEntry( pClicked );
+            else if (sIdent == "isnull")
             {
-                case SID_FM_FILTER_EDIT:
-                {
-                    EditEntry( pClicked );
-                }   break;
-                case SID_FM_FILTER_IS_NULL:
-                case SID_FM_FILTER_IS_NOT_NULL:
-                {
-                    OUString aErrorMsg;
-                    OUString aText;
-                    if (nSlotId == SID_FM_FILTER_IS_NULL)
-                        aText = "IS NULL";
-                    else
-                        aText = "IS NOT NULL";
+                OUString aErrorMsg;
+                OUString aText = "IS NULL";
+                m_pModel->ValidateText(static_cast<FmFilterItem*>(pClicked->GetUserData()),
+                                        aText, aErrorMsg);
+                m_pModel->SetTextForItem(static_cast<FmFilterItem*>(pClicked->GetUserData()), aText);
+            }
+            else if (sIdent == "isnotnull")
+            {
+                OUString aErrorMsg;
+                OUString aText = "IS NOT NULL";
 
-                    m_pModel->ValidateText(static_cast<FmFilterItem*>(pClicked->GetUserData()),
-                                            aText, aErrorMsg);
-                    m_pModel->SetTextForItem(static_cast<FmFilterItem*>(pClicked->GetUserData()), aText);
-                }   break;
-                case SID_FM_DELETE:
-                {
-                    DeleteSelection();
-                }   break;
+                m_pModel->ValidateText(static_cast<FmFilterItem*>(pClicked->GetUserData()),
+                                        aText, aErrorMsg);
+                m_pModel->SetTextForItem(static_cast<FmFilterItem*>(pClicked->GetUserData()), aText);
+            }
+            else if (sIdent == "delete")
+            {
+                DeleteSelection();
             }
             bHandled = true;
         }
@@ -1777,7 +1749,7 @@ void FmFilterNavigator::KeyInput(const KeyEvent& rKEvt)
 
         if ( pTargetItems )
         {
-            insertFilterItem( aItemList, pTargetItems );
+            insertFilterItem( aItemList, pTargetItems, false );
             return;
         }
     }
@@ -1801,7 +1773,7 @@ void FmFilterNavigator::KeyInput(const KeyEvent& rKEvt)
 void FmFilterNavigator::DeleteSelection()
 {
     // to avoid the deletion of an entry twice (e.g. deletion of a parent and afterward
-    // the deletion of its child, I have to shrink the selecton list
+    // the deletion of its child, I have to shrink the selection list
     ::std::vector<SvTreeListEntry*> aEntryList;
     for (SvTreeListEntry* pEntry = FirstSelected();
          pEntry != nullptr;
@@ -1836,7 +1808,7 @@ FmFilterNavigatorWin::FmFilterNavigatorWin( SfxBindings* _pBindings, SfxChildWin
 
     m_pNavigator = VclPtr<FmFilterNavigator>::Create( this );
     m_pNavigator->Show();
-    SetText( SVX_RES(RID_STR_FILTER_NAVIGATOR) );
+    SetText( SvxResId(RID_STR_FILTER_NAVIGATOR) );
     SfxDockingWindow::SetFloatingSize( Size(200,200) );
 }
 
@@ -1854,7 +1826,7 @@ void FmFilterNavigatorWin::dispose()
 }
 
 
-void FmFilterNavigatorWin::UpdateContent(FmFormShell* pFormShell)
+void FmFilterNavigatorWin::UpdateContent(FmFormShell const * pFormShell)
 {
     if (!m_pNavigator)
         return;
@@ -1863,7 +1835,7 @@ void FmFilterNavigatorWin::UpdateContent(FmFormShell* pFormShell)
         m_pNavigator->UpdateContent( nullptr, nullptr );
     else
     {
-        Reference< XFormController >  xController(pFormShell->GetImpl()->getActiveInternalController());
+        Reference<XFormController> const xController(pFormShell->GetImpl()->getActiveInternalController_Lock());
         Reference< XIndexAccess >   xContainer;
         if (xController.is())
         {
@@ -1946,13 +1918,13 @@ void FmFilterNavigatorWin::Resize()
 {
     SfxDockingWindow::Resize();
 
-    Size aLogOutputSize = PixelToLogic( GetOutputSizePixel(), MAP_APPFONT );
+    Size aLogOutputSize = PixelToLogic(GetOutputSizePixel(), MapMode(MapUnit::MapAppFont));
     Size aLogExplSize = aLogOutputSize;
     aLogExplSize.Width() -= 6;
     aLogExplSize.Height() -= 6;
 
-    Point aExplPos = LogicToPixel( Point(3,3), MAP_APPFONT );
-    Size aExplSize = LogicToPixel( aLogExplSize, MAP_APPFONT );
+    Point aExplPos = LogicToPixel(Point(3,3), MapMode(MapUnit::MapAppFont));
+    Size aExplSize = LogicToPixel(aLogExplSize, MapMode(MapUnit::MapAppFont));
 
     m_pNavigator->SetPosSizePixel( aExplPos, aExplSize );
 }
@@ -1978,5 +1950,4 @@ FmFilterNavigatorWinMgr::FmFilterNavigatorWinMgr( vcl::Window *_pParent, sal_uIn
 
 }
 
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
