@@ -18,9 +18,9 @@
  */
 
 
-#include "fmundo.hxx"
-#include "fmdocumentclassification.hxx"
-#include "fmcontrollayout.hxx"
+#include <fmundo.hxx>
+#include <fmdocumentclassification.hxx>
+#include <fmcontrollayout.hxx>
 
 #include <svx/fmmodel.hxx>
 #include <svx/fmpage.hxx>
@@ -37,70 +37,60 @@ using namespace svxform;
 
 struct FmFormModelImplData
 {
-    FmXUndoEnvironment*     pUndoEnv;
+    rtl::Reference<FmXUndoEnvironment>  mxUndoEnv;
     bool                bOpenInDesignIsDefaulted;
-    bool                bMovingPage;
     ::boost::optional< sal_Bool >
                             aControlsUseRefDevice;
 
     FmFormModelImplData()
-        :pUndoEnv( nullptr )
-        ,bOpenInDesignIsDefaulted( true )
-        ,bMovingPage( false )
+        :bOpenInDesignIsDefaulted( true )
         ,aControlsUseRefDevice()
     {
     }
 };
 
 FmFormModel::FmFormModel(SfxItemPool* pPool, SfxObjectShell* pPers)
-    : SdrModel(pPool, pPers, false, LOADREFCOUNTS)
+    : SdrModel(pPool, pPers)
     , m_pImpl(nullptr)
     , m_pObjShell(nullptr)
     , m_bOpenInDesignMode(false)
     , m_bAutoControlFocus(false)
 {
-    m_pImpl = new FmFormModelImplData;
-    m_pImpl->pUndoEnv = new FmXUndoEnvironment(*this);
-    m_pImpl->pUndoEnv->acquire();
+    m_pImpl.reset( new FmFormModelImplData );
+    m_pImpl->mxUndoEnv = new FmXUndoEnvironment(*this);
 }
 
 FmFormModel::FmFormModel(const OUString& rPath, SfxItemPool* pPool, SfxObjectShell* pPers)
-    : SdrModel(rPath, pPool, pPers, false, LOADREFCOUNTS)
+    : SdrModel(rPath, pPool, pPers, false)
     , m_pImpl(nullptr)
     , m_pObjShell(nullptr)
     , m_bOpenInDesignMode(false)
     , m_bAutoControlFocus(false)
 {
-    m_pImpl = new FmFormModelImplData;
-    m_pImpl->pUndoEnv = new FmXUndoEnvironment(*this);
-    m_pImpl->pUndoEnv->acquire();
+    m_pImpl.reset( new FmFormModelImplData );
+    m_pImpl->mxUndoEnv = new FmXUndoEnvironment(*this);
 }
 
 FmFormModel::FmFormModel(const OUString& rPath, SfxItemPool* pPool, SfxObjectShell* pPers,
                          bool bUseExtColorTable)
-    : SdrModel(rPath, pPool, pPers, bUseExtColorTable, LOADREFCOUNTS)
+    : SdrModel(rPath, pPool, pPers, bUseExtColorTable)
     , m_pImpl(nullptr)
     , m_pObjShell(nullptr)
     , m_bOpenInDesignMode(false)
     , m_bAutoControlFocus(false)
 {
-    m_pImpl = new FmFormModelImplData;
-    m_pImpl->pUndoEnv = new FmXUndoEnvironment(*this);
-    m_pImpl->pUndoEnv->acquire();
+    m_pImpl.reset( new FmFormModelImplData );
+    m_pImpl->mxUndoEnv = new FmXUndoEnvironment(*this);
 }
 
 FmFormModel::~FmFormModel()
 {
-    if (m_pObjShell && m_pImpl->pUndoEnv->IsListening(*m_pObjShell))
+    if (m_pObjShell && m_pImpl->mxUndoEnv->IsListening(*m_pObjShell))
         SetObjectShell(nullptr);
 
     ClearUndoBuffer();
-    // minimale grenze fuer undos
+    // minimum limit for undos
     SetMaxUndoActionCount(1);
-
-    m_pImpl->pUndoEnv->release();
-    delete m_pImpl;
-
 }
 
 SdrPage* FmFormModel::AllocPage(bool bMasterPage)
@@ -110,23 +100,13 @@ SdrPage* FmFormModel::AllocPage(bool bMasterPage)
 
 void FmFormModel::InsertPage(SdrPage* pPage, sal_uInt16 nPos)
 {
-    // hack solange Methode intern
-    if (m_pObjShell && !m_pImpl->pUndoEnv->IsListening( *m_pObjShell ))
+    // hack solange method intern
+    if (m_pObjShell && !m_pImpl->mxUndoEnv->IsListening( *m_pObjShell ))
         SetObjectShell(m_pObjShell);
 
     SdrModel::InsertPage( pPage, nPos );
 }
 
-void FmFormModel::MovePage( sal_uInt16 nPgNum, sal_uInt16 nNewPos )
-{
-    m_pImpl->bMovingPage = true;
-        // see InsertPage for this
-
-    SdrModel::MovePage( nPgNum, nNewPos );
-
-    m_pImpl->bMovingPage = false;
-}
-
 SdrPage* FmFormModel::RemovePage(sal_uInt16 nPgNum)
 {
     FmFormPage* pToBeRemovedPage = dynamic_cast< FmFormPage* >( GetPage( nPgNum ) );
@@ -136,7 +116,7 @@ SdrPage* FmFormModel::RemovePage(sal_uInt16 nPgNum)
     {
         Reference< XNameContainer > xForms( pToBeRemovedPage->GetForms( false ), css::uno::UNO_QUERY );
         if ( xForms.is() )
-            m_pImpl->pUndoEnv->RemoveForms( xForms );
+            m_pImpl->mxUndoEnv->RemoveForms( xForms );
     }
 
     FmFormPage* pRemovedPage = static_cast<FmFormPage*>(SdrModel::RemovePage(nPgNum));
@@ -146,8 +126,8 @@ SdrPage* FmFormModel::RemovePage(sal_uInt16 nPgNum)
 
 void FmFormModel::InsertMasterPage(SdrPage* pPage, sal_uInt16 nPos)
 {
-    // hack solange Methode intern
-    if (m_pObjShell && !m_pImpl->pUndoEnv->IsListening( *m_pObjShell ))
+    // hack solange method intern
+    if (m_pObjShell && !m_pImpl->mxUndoEnv->IsListening( *m_pObjShell ))
         SetObjectShell(m_pObjShell);
 
     SdrModel::InsertMasterPage(pPage, nPos);
@@ -161,16 +141,16 @@ SdrPage* FmFormModel::RemoveMasterPage(sal_uInt16 nPgNum)
     {
         Reference< XNameContainer > xForms( pPage->GetForms( false ), css::uno::UNO_QUERY );
         if ( xForms.is() )
-            m_pImpl->pUndoEnv->RemoveForms( xForms );
+            m_pImpl->mxUndoEnv->RemoveForms( xForms );
     }
 
     return pPage;
 }
 
 
-void FmFormModel::implSetOpenInDesignMode( bool _bOpenDesignMode, bool _bForce )
+void FmFormModel::implSetOpenInDesignMode( bool _bOpenDesignMode )
 {
-    if( ( _bOpenDesignMode != m_bOpenInDesignMode ) || _bForce )
+    if( _bOpenDesignMode != m_bOpenInDesignMode )
     {
         m_bOpenInDesignMode = _bOpenDesignMode;
 
@@ -184,7 +164,7 @@ void FmFormModel::implSetOpenInDesignMode( bool _bOpenDesignMode, bool _bForce )
 
 void FmFormModel::SetOpenInDesignMode( bool bOpenDesignMode )
 {
-    implSetOpenInDesignMode( bOpenDesignMode, false );
+    implSetOpenInDesignMode( bOpenDesignMode );
 }
 
 
@@ -224,27 +204,27 @@ void FmFormModel::SetObjectShell( SfxObjectShell* pShell )
 
     if (m_pObjShell)
     {
-        m_pImpl->pUndoEnv->EndListening( *this );
-        m_pImpl->pUndoEnv->EndListening( *m_pObjShell );
+        m_pImpl->mxUndoEnv->EndListening( *this );
+        m_pImpl->mxUndoEnv->EndListening( *m_pObjShell );
     }
 
     m_pObjShell = pShell;
 
     if (m_pObjShell)
     {
-        m_pImpl->pUndoEnv->SetReadOnly( m_pObjShell->IsReadOnly() || m_pObjShell->IsReadOnlyUI(), FmXUndoEnvironment::Accessor() );
+        m_pImpl->mxUndoEnv->SetReadOnly( m_pObjShell->IsReadOnly() || m_pObjShell->IsReadOnlyUI(), FmXUndoEnvironment::Accessor() );
 
-        if (!m_pImpl->pUndoEnv->IsReadOnly())
-             m_pImpl->pUndoEnv->StartListening(*this);
+        if (!m_pImpl->mxUndoEnv->IsReadOnly())
+             m_pImpl->mxUndoEnv->StartListening(*this);
 
-        m_pImpl->pUndoEnv->StartListening( *m_pObjShell );
+        m_pImpl->mxUndoEnv->StartListening( *m_pObjShell );
     }
 }
 
 
 FmXUndoEnvironment& FmFormModel::GetUndoEnv()
 {
-    return *m_pImpl->pUndoEnv;
+    return *m_pImpl->mxUndoEnv;
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
