@@ -18,19 +18,18 @@
  */
 
 
-#include "fmprop.hrc"
-#include "svx/fmresids.hrc"
-#include "fmtextcontroldialogs.hxx"
-#include "fmtextcontrolfeature.hxx"
-#include "fmtextcontrolshell.hxx"
-#include "editeng/crossedoutitem.hxx"
-#include "svx/dialmgr.hxx"
-#include "editeng/editeng.hxx"
-#include "editeng/eeitem.hxx"
-#include "svx/fmglob.hxx"
-#include "editeng/scriptspaceitem.hxx"
-#include "svx/svxids.hrc"
-#include "editeng/udlnitem.hxx"
+#include <fmprop.hxx>
+#include <fmtextcontroldialogs.hxx>
+#include <fmtextcontrolfeature.hxx>
+#include <fmtextcontrolshell.hxx>
+#include <editeng/crossedoutitem.hxx>
+#include <svx/dialmgr.hxx>
+#include <editeng/editeng.hxx>
+#include <editeng/eeitem.hxx>
+#include <svx/fmglob.hxx>
+#include <editeng/scriptspaceitem.hxx>
+#include <svx/svxids.hrc>
+#include <editeng/udlnitem.hxx>
 
 #include <com/sun/star/beans/XPropertySet.hpp>
 #include <com/sun/star/awt/FontDescriptor.hpp>
@@ -42,7 +41,7 @@
 #include <com/sun/star/util/URLTransformer.hpp>
 
 #include <comphelper/processfactory.hxx>
-#include <cppuhelper/implbase1.hxx>
+#include <cppuhelper/implbase.hxx>
 #include <sfx2/app.hxx>
 #include <sfx2/bindings.hxx>
 #include <sfx2/dispatch.hxx>
@@ -61,7 +60,8 @@
 #include <tools/diagnose_ex.h>
 #include <vcl/msgbox.hxx>
 #include <vcl/outdev.hxx>
-#include <osl/mutex.hxx>
+
+#include <memory>
 
 
 namespace svx
@@ -70,7 +70,6 @@ namespace svx
 
     using namespace ::com::sun::star;
     using namespace ::com::sun::star::uno;
-    using namespace ::com::sun::star::awt;
     using namespace ::com::sun::star::form;
     using namespace ::com::sun::star::form::runtime;
     using namespace ::com::sun::star::lang;
@@ -158,35 +157,31 @@ namespace svx
         0
     };
 
-
-    //= FmFocusListenerAdapter
-
-    typedef ::cppu::WeakImplHelper1 <   XFocusListener
+    typedef ::cppu::WeakImplHelper <   css::awt::XFocusListener
                                     >   FmFocusListenerAdapter_Base;
     class FmFocusListenerAdapter : public FmFocusListenerAdapter_Base
     {
     private:
         IFocusObserver*         m_pObserver;
-        Reference< XWindow >    m_xWindow;
+        Reference< css::awt::XWindow >    m_xWindow;
 
     public:
-        FmFocusListenerAdapter( const Reference< XControl >& _rxControl, IFocusObserver* _pObserver );
+        FmFocusListenerAdapter( const Reference< css::awt::XControl >& _rxControl, IFocusObserver* _pObserver );
 
         // clean up the instance
         void    dispose();
 
     protected:
-        virtual ~FmFocusListenerAdapter();
+        virtual ~FmFocusListenerAdapter() override;
 
     protected:
-        virtual void SAL_CALL focusGained( const FocusEvent& e ) throw (RuntimeException, std::exception) SAL_OVERRIDE;
-        virtual void SAL_CALL focusLost( const FocusEvent& e ) throw (RuntimeException, std::exception) SAL_OVERRIDE;
-        virtual void SAL_CALL disposing( const EventObject& Source ) throw (RuntimeException, std::exception) SAL_OVERRIDE;
+        virtual void SAL_CALL focusGained( const css::awt::FocusEvent& e ) override;
+        virtual void SAL_CALL focusLost( const css::awt::FocusEvent& e ) override;
+        virtual void SAL_CALL disposing( const EventObject& Source ) override;
     };
 
 
-
-    FmFocusListenerAdapter::FmFocusListenerAdapter( const Reference< XControl >& _rxControl, IFocusObserver* _pObserver )
+    FmFocusListenerAdapter::FmFocusListenerAdapter( const Reference< css::awt::XControl >& _rxControl, IFocusObserver* _pObserver )
         :m_pObserver( _pObserver )
         ,m_xWindow( _rxControl, UNO_QUERY )
     {
@@ -226,61 +221,52 @@ namespace svx
     }
 
 
-    void SAL_CALL FmFocusListenerAdapter::focusGained( const FocusEvent& e ) throw (RuntimeException, std::exception)
+    void SAL_CALL FmFocusListenerAdapter::focusGained( const css::awt::FocusEvent& e )
     {
         if ( m_pObserver )
             m_pObserver->focusGained( e );
     }
 
 
-    void SAL_CALL FmFocusListenerAdapter::focusLost( const FocusEvent& e ) throw (RuntimeException, std::exception)
+    void SAL_CALL FmFocusListenerAdapter::focusLost( const css::awt::FocusEvent& e )
     {
         if ( m_pObserver )
             m_pObserver->focusLost( e );
     }
 
 
-    void SAL_CALL FmFocusListenerAdapter::disposing( const EventObject& Source ) throw (RuntimeException, std::exception)
+    void SAL_CALL FmFocusListenerAdapter::disposing( const EventObject& Source )
     {
-        (void)Source;
         DBG_ASSERT( Source.Source == m_xWindow, "FmFocusListenerAdapter::disposing: where did this come from?" );
         m_xWindow.clear();
     }
 
-
-    //= FmMouseListenerAdapter
-
-    typedef ::cppu::WeakImplHelper1 <   XMouseListener
+    typedef ::cppu::WeakImplHelper <   css::awt::XMouseListener
                                     >   FmMouseListenerAdapter_Base;
     class FmMouseListenerAdapter : public FmMouseListenerAdapter_Base
     {
     private:
         IContextRequestObserver*  m_pObserver;
-        Reference< XWindow >    m_xWindow;
+        Reference< css::awt::XWindow >    m_xWindow;
 
     public:
-        FmMouseListenerAdapter( const Reference< XControl >& _rxControl, IContextRequestObserver* _pObserver );
+        FmMouseListenerAdapter( const Reference< css::awt::XControl >& _rxControl, IContextRequestObserver* _pObserver );
 
         // clean up the instance
         void    dispose();
 
     protected:
-        virtual ~FmMouseListenerAdapter();
+        virtual ~FmMouseListenerAdapter() override;
 
     protected:
-        virtual void SAL_CALL mousePressed( const awt::MouseEvent& e ) throw (RuntimeException, std::exception) SAL_OVERRIDE;
-        virtual void SAL_CALL mouseReleased( const awt::MouseEvent& e ) throw (RuntimeException, std::exception) SAL_OVERRIDE;
-        virtual void SAL_CALL mouseEntered( const awt::MouseEvent& e ) throw (RuntimeException, std::exception) SAL_OVERRIDE;
-        virtual void SAL_CALL mouseExited( const awt::MouseEvent& e ) throw (RuntimeException, std::exception) SAL_OVERRIDE;
-        virtual void SAL_CALL disposing( const EventObject& Source ) throw (RuntimeException, std::exception) SAL_OVERRIDE;
+        virtual void SAL_CALL mousePressed( const css::awt::MouseEvent& e ) override;
+        virtual void SAL_CALL mouseReleased( const css::awt::MouseEvent& e ) override;
+        virtual void SAL_CALL mouseEntered( const css::awt::MouseEvent& e ) override;
+        virtual void SAL_CALL mouseExited( const css::awt::MouseEvent& e ) override;
+        virtual void SAL_CALL disposing( const EventObject& Source ) override;
     };
 
-
-    //= FmMouseListenerAdapter
-
-
-
-    FmMouseListenerAdapter::FmMouseListenerAdapter( const Reference< XControl >& _rxControl, IContextRequestObserver* _pObserver )
+    FmMouseListenerAdapter::FmMouseListenerAdapter( const Reference< css::awt::XControl >& _rxControl, IContextRequestObserver* _pObserver )
         :m_pObserver( _pObserver )
         ,m_xWindow( _rxControl, UNO_QUERY )
     {
@@ -320,7 +306,7 @@ namespace svx
     }
 
 
-    void SAL_CALL FmMouseListenerAdapter::mousePressed( const awt::MouseEvent& _rEvent ) throw (::com::sun::star::uno::RuntimeException, std::exception)
+    void SAL_CALL FmMouseListenerAdapter::mousePressed( const css::awt::MouseEvent& _rEvent )
     {
         SolarMutexGuard aGuard;
         // is this a request for a context menu?
@@ -332,27 +318,26 @@ namespace svx
     }
 
 
-    void SAL_CALL FmMouseListenerAdapter::mouseReleased( const awt::MouseEvent& /*e*/ ) throw (::com::sun::star::uno::RuntimeException, std::exception)
+    void SAL_CALL FmMouseListenerAdapter::mouseReleased( const css::awt::MouseEvent& /*e*/ )
     {
         // not interested in
     }
 
 
-    void SAL_CALL FmMouseListenerAdapter::mouseEntered( const awt::MouseEvent& /*e*/ ) throw (::com::sun::star::uno::RuntimeException, std::exception)
+    void SAL_CALL FmMouseListenerAdapter::mouseEntered( const css::awt::MouseEvent& /*e*/ )
     {
         // not interested in
     }
 
 
-    void SAL_CALL FmMouseListenerAdapter::mouseExited( const awt::MouseEvent& /*e*/ ) throw (::com::sun::star::uno::RuntimeException, std::exception)
+    void SAL_CALL FmMouseListenerAdapter::mouseExited( const css::awt::MouseEvent& /*e*/ )
     {
         // not interested in
     }
 
 
-    void SAL_CALL FmMouseListenerAdapter::disposing( const EventObject& Source ) throw (RuntimeException, std::exception)
+    void SAL_CALL FmMouseListenerAdapter::disposing( const EventObject& Source )
     {
-        (void)Source;
         DBG_ASSERT( Source.Source == m_xWindow, "FmMouseListenerAdapter::disposing: where did this come from?" );
         m_xWindow.clear();
     }
@@ -421,14 +406,14 @@ namespace svx
         }
 
 
-        OUString lcl_getUnoSlotName( SfxApplication&, SfxSlotId _nSlotId )
+        OUString lcl_getUnoSlotName( SfxSlotId _nSlotId )
         {
             OUString sSlotUnoName;
 
-            SfxSlotPool& rSlotPool = SfxSlotPool::GetSlotPool( NULL );
+            SfxSlotPool& rSlotPool = SfxSlotPool::GetSlotPool();
             const SfxSlot* pSlot = rSlotPool.GetSlot( _nSlotId );
 
-            const sal_Char* pAsciiUnoName = NULL;
+            const sal_Char* pAsciiUnoName = nullptr;
             if ( pSlot )
             {
                 pAsciiUnoName = pSlot->GetUnoName();
@@ -450,28 +435,23 @@ namespace svx
                 sSlotUnoName = ".uno:";
                 sSlotUnoName += OUString::createFromAscii( pAsciiUnoName );
             }
-#if OSL_DEBUG_LEVEL > 0
             else
             {
-                OString sMessage( "lcl_getUnoSlotName: invalid slot id, or invalid slot, or no UNO name!\n" );
-                sMessage += "(slot id: ";
-                sMessage += OString::number( _nSlotId );
-                sMessage += ")";
-                OSL_FAIL( sMessage.getStr() );
+                SAL_WARN( "svx", "lcl_getUnoSlotName: invalid slot id, or invalid slot, or no UNO name! "
+                        "(slot id: " << _nSlotId << ")");
             }
-#endif
             return sSlotUnoName;
         }
 
 
-        bool lcl_determineReadOnly( const Reference< XControl >& _rxControl )
+        bool lcl_determineReadOnly( const Reference< css::awt::XControl >& _rxControl )
         {
             bool bIsReadOnlyModel = true;
             try
             {
                 Reference< XPropertySet > xModelProps;
                 if ( _rxControl.is() )
-                    xModelProps = xModelProps.query( _rxControl->getModel() );
+                    xModelProps.set(_rxControl->getModel(), css::uno::UNO_QUERY);
                 Reference< XPropertySetInfo > xModelPropInfo;
                 if ( xModelProps.is() )
                     xModelPropInfo = xModelProps->getPropertySetInfo();
@@ -493,16 +473,16 @@ namespace svx
         }
 
 
-        static Window* lcl_getWindow( const Reference< XControl >& _rxControl )
+        vcl::Window* lcl_getWindow( const Reference< css::awt::XControl >& _rxControl )
         {
-            Window* pWindow = NULL;
+            vcl::Window* pWindow = nullptr;
             try
             {
-                Reference< XWindowPeer > xControlPeer;
+                Reference< css::awt::XWindowPeer > xControlPeer;
                 if ( _rxControl.is() )
                     xControlPeer = _rxControl->getPeer();
                 if ( xControlPeer.is() )
-                    pWindow = VCLUnoHelper::GetWindow( xControlPeer );
+                    pWindow = VCLUnoHelper::GetWindow( xControlPeer ).get();
             }
             catch( const Exception& )
             {
@@ -513,7 +493,7 @@ namespace svx
         }
 
 
-        bool lcl_isRichText( const Reference< XControl >& _rxControl )
+        bool lcl_isRichText( const Reference< css::awt::XControl >& _rxControl )
         {
             if ( !_rxControl.is() )
                 return false;
@@ -548,7 +528,7 @@ namespace svx
         ,m_rBindings( _pFrame->GetBindings() )
         ,m_bNeedClipboardInvalidation( true )
     {
-        m_aClipboardInvalidation.SetTimeoutHdl( LINK( this, FmTextControlShell, OnInvalidateClipboard ) );
+        m_aClipboardInvalidation.SetInvokeHandler( LINK( this, FmTextControlShell, OnInvalidateClipboard ) );
         m_aClipboardInvalidation.SetTimeout( 200 );
     }
 
@@ -559,17 +539,16 @@ namespace svx
     }
 
 
-    IMPL_LINK( FmTextControlShell, OnInvalidateClipboard, void*, /*_pNotInterestedIn*/ )
+    IMPL_LINK_NOARG( FmTextControlShell, OnInvalidateClipboard, Timer*, void )
     {
         if ( m_bNeedClipboardInvalidation )
         {
-            OSL_TRACE( "FmTextControlShell::ClipBoard: invalidating clipboard slots" );
+            SAL_INFO("svx.form", "invalidating clipboard slots" );
             m_rBindings.Invalidate( SID_CUT );
             m_rBindings.Invalidate( SID_COPY );
             m_rBindings.Invalidate( SID_PASTE );
             m_bNeedClipboardInvalidation = false;
         }
-        return 0L;
     }
 
 
@@ -585,8 +564,8 @@ namespace svx
             SfxSlotId nSlotId( aFeature->first );
             #if OSL_DEBUG_LEVEL > 0
                 OUString sUnoSlotName;
-                if ( SFX_APP() )
-                    sUnoSlotName = lcl_getUnoSlotName( *SFX_APP(), nSlotId );
+                if ( SfxGetpApp() )
+                    sUnoSlotName = lcl_getUnoSlotName( nSlotId );
                 else
                     sUnoSlotName = "<unknown>";
                 OString sUnoSlotNameAscii( "\"" );
@@ -600,7 +579,7 @@ namespace svx
                 // Sadly, the semantics of the dispatches is that the feature "Font" depends
                 // on the current cursor position: If it's on latin text, it's the "latin font"
                 // which is set up at the control. If it's on CJK text, it's the "CJK font", and
-                // aequivalent for "CTL font".
+                // equivalent for "CTL font".
                 // The same holds for some other font related features/slots.
                 // Thus, we have separate dispatches for "Latin Font", "Latin Font Size", etc,
                 // which are only "virtual", in a sense that there exist no item with this id.
@@ -623,11 +602,10 @@ namespace svx
             {
                 #if OSL_DEBUG_LEVEL > 0
                     bool bFeatureIsEnabled = aFeature->second->isFeatureEnabled();
-                    OString sMessage( "FmTextControlShell::transferFeatureStatesToItemSet: found a feature state for " );
-                    sMessage += sUnoSlotNameAscii;
+                    OString sMessage =  "found a feature state for "  + sUnoSlotNameAscii;
                     if ( !bFeatureIsEnabled )
                         sMessage += " (disabled)";
-                    OSL_TRACE( "%s", sMessage.getStr() );
+                    SAL_INFO("svx.form", sMessage );
                 #endif
 
                 lcl_translateUnoStateToItem( nSlotId, aFeature->second->getFeatureState(), _rSet );
@@ -635,10 +613,7 @@ namespace svx
             #if OSL_DEBUG_LEVEL > 0
             else
             {
-                OString sMessage( "FmTextControlShell::transferFeatureStatesToItemSet: found a feature state for " );
-                sMessage += sUnoSlotNameAscii;
-                sMessage += ", but could not translate it into an item!";
-                OSL_TRACE( "%s", sMessage.getStr() );
+                SAL_WARN("svx.form", "found a feature state for " << sUnoSlotNameAscii << ", but could not translate it into an item!" );
             }
             #endif
         }
@@ -647,18 +622,18 @@ namespace svx
 
     void FmTextControlShell::executeAttributeDialog( AttributeSet _eSet, SfxRequest& _rReq )
     {
-        const SvxFontListItem* pFontList = PTR_CAST( SvxFontListItem, m_pViewFrame->GetObjectShell()->GetItem( SID_ATTR_CHAR_FONTLIST ) );
+        const SvxFontListItem* pFontList = dynamic_cast<const SvxFontListItem*>( m_pViewFrame->GetObjectShell()->GetItem( SID_ATTR_CHAR_FONTLIST )  );
         DBG_ASSERT( pFontList, "FmTextControlShell::executeAttributeDialog: no font list item!" );
         if ( !pFontList )
             return;
 
         SfxItemPool* pPool = EditEngine::CreatePool();
         pPool->FreezeIdRanges();
-        boost::scoped_ptr< SfxItemSet > xPureItems( new SfxItemSet( *pPool ) );
+        std::unique_ptr< SfxItemSet > xPureItems( new SfxItemSet( *pPool ) );
 
         // put the current states of the items into the set
-        boost::scoped_ptr<SfxAllItemSet> xCurrentItems( new SfxAllItemSet( *xPureItems ) );
-        transferFeatureStatesToItemSet( m_aControlFeatures, *xCurrentItems );
+        std::unique_ptr<SfxAllItemSet> xCurrentItems( new SfxAllItemSet( *xPureItems ) );
+        transferFeatureStatesToItemSet( m_aControlFeatures, *xCurrentItems, false );
 
         // additional items, which we are not responsible for at the SfxShell level,
         // but which need to be forwarded to the dialog, anyway
@@ -666,15 +641,17 @@ namespace svx
         fillFeatureDispatchers( m_xActiveControl, pDialogSlots, aAdditionalFestures );
         transferFeatureStatesToItemSet( aAdditionalFestures, *xCurrentItems, true );
 
-        boost::scoped_ptr<SfxTabDialog> xDialog ( _eSet == eCharAttribs
-                                                ? static_cast< SfxTabDialog* >( new TextControlCharAttribDialog( NULL, *xCurrentItems, *pFontList ) )
-                                                : static_cast< SfxTabDialog* >( new TextControlParaAttribDialog( NULL, *xCurrentItems ) ) );
+        VclPtr<SfxTabDialog> xDialog;
+        if ( _eSet == eCharAttribs)
+            xDialog = VclPtr<TextControlCharAttribDialog>::Create( nullptr, *xCurrentItems, *pFontList );
+        else
+            xDialog = VclPtr<TextControlParaAttribDialog>::Create( nullptr, *xCurrentItems );
         if ( RET_OK == xDialog->Execute() )
         {
             const SfxItemSet& rModifiedItems = *xDialog->GetOutputItemSet();
             for ( WhichId nWhich = pPool->GetFirstWhich(); nWhich <= pPool->GetLastWhich(); ++nWhich )
             {
-                if ( rModifiedItems.GetItemState( nWhich ) == SFX_ITEM_SET )
+                if ( rModifiedItems.GetItemState( nWhich ) == SfxItemState::SET )
                 {
                     SfxSlotId nSlotForItemSet = pPool->GetSlotId( nWhich );
                     const SfxPoolItem* pModifiedItem = rModifiedItems.GetItem( nWhich );
@@ -718,7 +695,7 @@ namespace svx
                             // handle them
                             DBG_ASSERT( aArgs.getLength() == 0, "FmTextControlShell::executeAttributeDialog: these are no UNO slots - are they?" );
 
-                            const SfxBoolItem* pBoolItem = PTR_CAST( SfxBoolItem, pModifiedItem );
+                            const SfxBoolItem* pBoolItem = dynamic_cast<const SfxBoolItem*>( pModifiedItem  );
                             DBG_ASSERT( pBoolItem, "FmTextControlShell::executeAttributeDialog: no bool item?!" );
                             if ( pBoolItem )
                             {
@@ -734,17 +711,13 @@ namespace svx
                 #if OSL_DEBUG_LEVEL > 0
                     else
                     {
-                        OString sError( "FmTextControShell::executeAttributeDialog: Could not handle the following item:" );
-                        sError += "\n  SlotID: "; sError += OString::number( nSlotForItemSet );
-                        sError += "\n  WhichID: "; sError += OString::number( nWhich );
-                        sError += "\n  UNO name: ";
-
-                        OUString sUnoSlotName = lcl_getUnoSlotName( *SFX_APP(), nSlotForItemSet );
-                        if ( !sUnoSlotName.isEmpty() )
-                            sError += OString( sUnoSlotName.getStr(), sUnoSlotName.getLength(), RTL_TEXTENCODING_ASCII_US );
-                        else
-                            sError += "unknown (no SfxSlot)";
-                        OSL_FAIL( sError.getStr() );
+                        OUString sUnoSlotName = lcl_getUnoSlotName( nSlotForItemSet );
+                        if ( sUnoSlotName.isEmpty() )
+                            sUnoSlotName = "unknown (no SfxSlot)";
+                        SAL_WARN( "svx", "FmTextControShell::executeAttributeDialog: Could not handle the following item:"
+                                "\n  SlotID: " << nSlotForItemSet
+                                << "\n  WhichID: " << nWhich
+                                << "\n  UNO name: " << sUnoSlotName );
                     }
                 #endif
                 }
@@ -759,26 +732,24 @@ namespace svx
     }
 
 
-    bool FmTextControlShell::executeSelectAll( )
+    void FmTextControlShell::executeSelectAll( )
     {
         try
         {
             if ( m_xActiveTextComponent.is() )
             {
                 sal_Int32 nTextLen = m_xActiveTextComponent->getText().getLength();
-                m_xActiveTextComponent->setSelection( awt::Selection( 0, nTextLen ) );
-                return true;
+                m_xActiveTextComponent->setSelection( css::awt::Selection( 0, nTextLen ) );
             }
         }
         catch( const Exception& )
         {
             DBG_UNHANDLED_EXCEPTION();
         }
-        return false;   // not handled
     }
 
 
-    bool FmTextControlShell::executeClipboardSlot( SfxSlotId _nSlot )
+    void FmTextControlShell::executeClipboardSlot( SfxSlotId _nSlot )
     {
         try
         {
@@ -793,7 +764,7 @@ namespace svx
                     ::svt::OStringTransfer::CopyString( sSelectedText, lcl_getWindow( m_xActiveControl ) );
                     if ( SID_CUT == _nSlot )
                     {
-                        awt::Selection aSelection( m_xActiveTextComponent->getSelection() );
+                        css::awt::Selection aSelection( m_xActiveTextComponent->getSelection() );
                         m_xActiveTextComponent->insertText( aSelection, OUString() );
                     }
                 }
@@ -802,21 +773,19 @@ namespace svx
                 {
                     OUString sClipboardContent;
                     OSL_VERIFY( ::svt::OStringTransfer::PasteString( sClipboardContent, lcl_getWindow( m_xActiveControl ) ) );
-                    awt::Selection aSelection( m_xActiveTextComponent->getSelection() );
+                    css::awt::Selection aSelection( m_xActiveTextComponent->getSelection() );
                     m_xActiveTextComponent->insertText( aSelection, sClipboardContent );
                 }
                 break;
                 default:
                     OSL_FAIL( "FmTextControlShell::executeClipboardSlot: invalid slot!" );
                 }
-                return true;
             }
         }
         catch( const Exception& )
         {
             DBG_UNHANDLED_EXCEPTION();
         }
-        return false;   // not handled
     }
 
 
@@ -870,21 +839,21 @@ namespace svx
                 const SfxPoolItem* pItem = aToggled.GetItem( nWhich );
                 if ( ( SID_ATTR_CHAR_UNDERLINE == nSlot ) || ( SID_ATTR_CHAR_OVERLINE == nSlot ) )
                 {
-                    const SvxOverlineItem* pTextLine = PTR_CAST( SvxOverlineItem, pItem );
+                    const SvxOverlineItem* pTextLine = dynamic_cast<const SvxOverlineItem*>( pItem  );
                     DBG_ASSERT( pTextLine, "FmTextControlShell::ExecuteTextAttribute: ooops - no underline/overline item!" );
                     if ( pTextLine )
                     {
-                        FontUnderline eTL = pTextLine->GetLineStyle();
+                        FontLineStyle eTL = pTextLine->GetLineStyle();
                         if ( SID_ATTR_CHAR_UNDERLINE == nSlot ) {
-                            aToggled.Put( SvxUnderlineItem( eTL == UNDERLINE_SINGLE ? UNDERLINE_NONE : UNDERLINE_SINGLE, nWhich ) );
+                            aToggled.Put( SvxUnderlineItem( eTL == LINESTYLE_SINGLE ? LINESTYLE_NONE : LINESTYLE_SINGLE, nWhich ) );
                         } else {
-                            aToggled.Put( SvxOverlineItem( eTL == UNDERLINE_SINGLE ? UNDERLINE_NONE : UNDERLINE_SINGLE, nWhich ) );
+                            aToggled.Put( SvxOverlineItem( eTL == LINESTYLE_SINGLE ? LINESTYLE_NONE : LINESTYLE_SINGLE, nWhich ) );
                         }
                     }
                 }
                 else
                 {
-                    const SvxCrossedOutItem* pCrossedOut = PTR_CAST( SvxCrossedOutItem, pItem );
+                    const SvxCrossedOutItem* pCrossedOut = dynamic_cast<const SvxCrossedOutItem*>( pItem  );
                     DBG_ASSERT( pCrossedOut, "FmTextControlShell::ExecuteTextAttribute: ooops - no CrossedOut item!" );
                     if ( pCrossedOut )
                     {
@@ -972,20 +941,20 @@ namespace svx
                     bNeedSelection = true;
                     bNeedTextComponent = true;
                     bNeedWriteableControl = true;
-                    OSL_TRACE( "FmTextControlShell::ClipBoard: need to invalidate again" );
+                    SAL_INFO("svx.form", "need to invalidate again" );
                     m_bNeedClipboardInvalidation = true;
                     break;
 
                 case SID_PASTE:
                 {
-                    Window* pActiveControlVCLWindow = lcl_getWindow( m_xActiveControl );
+                    vcl::Window* pActiveControlVCLWindow = lcl_getWindow( m_xActiveControl );
                     if ( pActiveControlVCLWindow )
                     {
                         TransferableDataHelper aDataHelper( TransferableDataHelper::CreateFromSystemClipboard( pActiveControlVCLWindow) );
-                        bDisable |= !aDataHelper.HasFormat( SOT_FORMAT_STRING );
+                        bDisable |= !aDataHelper.HasFormat( SotClipboardFormatId::STRING );
                     }
                     else
-                        bDisable |= true;
+                        bDisable = true;
 
                     bNeedTextComponent = true;
                     bNeedWriteableControl = true;
@@ -1003,7 +972,7 @@ namespace svx
 
                 default:
                     // slot is unknown at all
-                    bDisable |= true;
+                    bDisable = true;
                     break;
                 }
                 SAL_WARN_IF( bNeedSelection && !bNeedTextComponent, "svx.form", "FmTextControlShell::GetTextAttributeState: bNeedSelection should imply bNeedTextComponent!" );
@@ -1016,7 +985,7 @@ namespace svx
 
                 if ( !bDisable && bNeedSelection )
                 {
-                    awt::Selection aSelection = m_xActiveTextComponent->getSelection();
+                    css::awt::Selection aSelection = m_xActiveTextComponent->getSelection();
                     bDisable |= aSelection.Min == aSelection.Max;
                 }
 
@@ -1047,18 +1016,16 @@ namespace svx
     }
 
 
-    void FmTextControlShell::designModeChanged( bool /*_bNewDesignMode*/ )
+    void FmTextControlShell::designModeChanged()
     {
         m_rBindings.Invalidate( pTextControlSlots );
     }
 
 
-    void FmTextControlShell::formActivated( const Reference< XFormController >& _rxController )
+    void FmTextControlShell::formActivated( const Reference< runtime::XFormController >& _rxController )
     {
 #if OSL_DEBUG_LEVEL > 0
-        OString sTrace( "FmTextControlShell::formActivated: 0x" );
-        sTrace += OString::number( (sal_IntPtr)_rxController.get(), 16 );
-        OSL_TRACE( "%s", sTrace.getStr() );
+        SAL_INFO("svx.form", "0x" << OUString::number( reinterpret_cast<sal_IntPtr>(_rxController.get()), 16 ));
 #endif
 
         DBG_ASSERT( _rxController.is(), "FmTextControlShell::formActivated: invalid controller!" );
@@ -1081,14 +1048,9 @@ namespace svx
     }
 
 
-    void FmTextControlShell::formDeactivated( const Reference< XFormController >& _rxController )
+    void FmTextControlShell::formDeactivated( const Reference< runtime::XFormController >& _rxController )
     {
-#if OSL_DEBUG_LEVEL > 0
-        OString sTrace( "FmTextControlShell::formDeactivated: 0x" );
-        sTrace += OString::number( (sal_IntPtr)_rxController.get(), 16 );
-        OSL_TRACE( "%s", sTrace.getStr() );
-#endif
-        (void)_rxController;
+        SAL_INFO("svx.form", "0x" << OUString::number( reinterpret_cast<sal_IntPtr>(_rxController.get()), 16 ));
 
         if ( IsActiveControl() )
             controlDeactivated();
@@ -1097,7 +1059,7 @@ namespace svx
     }
 
 
-    void FmTextControlShell::startControllerListening( const Reference< XFormController >& _rxController )
+    void FmTextControlShell::startControllerListening( const Reference< runtime::XFormController >& _rxController )
     {
         OSL_PRECOND( _rxController.is(), "FmTextControlShell::startControllerListening: invalid controller!" );
         if ( !_rxController.is() )
@@ -1110,12 +1072,12 @@ namespace svx
 
         try
         {
-            Sequence< Reference< XControl > > aControls( _rxController->getControls() );
+            Sequence< Reference< css::awt::XControl > > aControls( _rxController->getControls() );
             m_aControlObservers.resize( 0 );
             m_aControlObservers.reserve( aControls.getLength() );
 
-            const Reference< XControl >* pControls = aControls.getConstArray();
-            const Reference< XControl >* pControlsEnd = pControls + aControls.getLength();
+            const Reference< css::awt::XControl >* pControls = aControls.getConstArray();
+            const Reference< css::awt::XControl >* pControlsEnd = pControls + aControls.getLength();
             for ( ; pControls != pControlsEnd; ++pControls )
             {
                 m_aControlObservers.push_back( FocusListenerAdapter( new FmFocusListenerAdapter( *pControls, this ) ) );
@@ -1135,8 +1097,9 @@ namespace svx
         OSL_PRECOND( isControllerListening(), "FmTextControlShell::stopControllerListening: inconsistence!" );
 
         // dispose all listeners associated with the controls of the active controller
+        FocusListenerAdapters::const_iterator aEnd = m_aControlObservers.end();
         for (   FocusListenerAdapters::iterator aLoop = m_aControlObservers.begin();
-                aLoop != m_aControlObservers.end();
+                aLoop != aEnd;
                 ++aLoop
             )
         {
@@ -1153,8 +1116,9 @@ namespace svx
     void FmTextControlShell::implClearActiveControlRef()
     {
         // no more features for this control
+        ControlFeatures::const_iterator aEnd = m_aControlFeatures.end();
         for (   ControlFeatures::iterator aLoop = m_aControlFeatures.begin();
-                aLoop != m_aControlFeatures.end();
+                aLoop != aEnd;
                 ++aLoop
             )
         {
@@ -1172,7 +1136,7 @@ namespace svx
 
         if ( m_xActiveTextComponent.is() )
         {
-            OSL_TRACE( "FmTextControlShell::ClipBoard: stopping timer for clipboard invalidation" );
+            SAL_INFO("svx.form", "stopping timer for clipboard invalidation" );
             m_aClipboardInvalidation.Stop();
         }
         // no more active control
@@ -1194,7 +1158,7 @@ namespace svx
     }
 
 
-    void FmTextControlShell::controlActivated( const Reference< XControl >& _rxControl )
+    void FmTextControlShell::controlActivated( const Reference< css::awt::XControl >& _rxControl )
     {
         // ensure that all knittings with the previously active control are lost
         if ( m_xActiveControl.is() )
@@ -1203,14 +1167,14 @@ namespace svx
 
 #if OSL_DEBUG_LEVEL > 0
         {
-            Sequence< Reference< XControl > > aActiveControls;
+            Sequence< Reference< css::awt::XControl > > aActiveControls;
             if ( m_xActiveController.is() )
                 aActiveControls = m_xActiveController->getControls();
 
             bool bFoundThisControl = false;
 
-            const Reference< XControl >* pControls = aActiveControls.getConstArray();
-            const Reference< XControl >* pControlsEnd = pControls + aActiveControls.getLength();
+            const Reference< css::awt::XControl >* pControls = aActiveControls.getConstArray();
+            const Reference< css::awt::XControl >* pControlsEnd = pControls + aActiveControls.getLength();
             for ( ; ( pControls != pControlsEnd ) && !bFoundThisControl; ++pControls )
             {
                 if ( *pControls == _rxControl )
@@ -1224,20 +1188,20 @@ namespace svx
 
         // remember this control
         m_xActiveControl = _rxControl;
-        m_xActiveTextComponent = m_xActiveTextComponent.query( _rxControl );
+        m_xActiveTextComponent.set(_rxControl, css::uno::UNO_QUERY);
         m_bActiveControlIsReadOnly = lcl_determineReadOnly( m_xActiveControl );
         m_bActiveControlIsRichText = lcl_isRichText( m_xActiveControl );
 
         // if we found a rich text control, we need context menu support
         if ( m_bActiveControlIsRichText )
         {
-            DBG_ASSERT( NULL == m_aContextMenuObserver.get(), "FmTextControlShell::controlActivated: already have an observer!" );
+            DBG_ASSERT( nullptr == m_aContextMenuObserver.get(), "FmTextControlShell::controlActivated: already have an observer!" );
             m_aContextMenuObserver = MouseListenerAdapter( new FmMouseListenerAdapter( _rxControl, this ) );
         }
 
         if ( m_xActiveTextComponent.is() )
         {
-            OSL_TRACE( "FmTextControlShell::ClipBoard: starting timer for clipboard invalidation" );
+            SAL_INFO("svx.form", "starting timer for clipboard invalidation" );
             m_aClipboardInvalidation.Start();
         }
 
@@ -1264,18 +1228,17 @@ namespace svx
         // #i51621# / 2005-08-19 / frank.schoenheit@sun.com
         // bool bHaveAnyServeableSlots = m_xActiveTextComponent.is() || !m_aControlFeatures.empty();
         // LEM: not calling m_aControlActivatonHandler causes fdo#63695, so disable this hack for now.
-        if ( m_aControlActivationHandler.IsSet() /* && bHaveAnyServeableSlots */ )
-            m_aControlActivationHandler.Call( NULL );
+        m_aControlActivationHandler.Call( nullptr );
 
         m_bNeedClipboardInvalidation = true;
     }
 
 
-    void FmTextControlShell::fillFeatureDispatchers(  const Reference< XControl > _rxControl, SfxSlotId* _pZeroTerminatedSlots,
-            ControlFeatures& _rDispatchers )
+    void FmTextControlShell::fillFeatureDispatchers(const Reference< css::awt::XControl >& _rxControl, SfxSlotId* _pZeroTerminatedSlots,
+            ControlFeatures& _rDispatchers)
     {
         Reference< XDispatchProvider > xProvider( _rxControl, UNO_QUERY );
-        SfxApplication* pApplication = SFX_APP();
+        SfxApplication* pApplication = SfxGetpApp();
         DBG_ASSERT( pApplication, "FmTextControlShell::fillFeatureDispatchers: no SfxApplication!" );
         if ( xProvider.is() && pApplication )
         {
@@ -1284,7 +1247,7 @@ namespace svx
             {
                 FmTextControlFeature* pDispatcher = implGetFeatureDispatcher( xProvider, pApplication, *pSlots );
                 if ( pDispatcher )
-                    _rDispatchers.insert( ControlFeatures::value_type( *pSlots, ControlFeature( pDispatcher ) ) );
+                    _rDispatchers.emplace( *pSlots, ControlFeature( pDispatcher ) );
 
                 ++pSlots;
             }
@@ -1292,8 +1255,11 @@ namespace svx
     }
 
 
-    void FmTextControlShell::impl_parseURL_nothrow( URL& _rURL )
+    FmTextControlFeature* FmTextControlShell::implGetFeatureDispatcher( const Reference< XDispatchProvider >& _rxProvider, SfxApplication const * _pApplication, SfxSlotId _nSlot )
     {
+        OSL_PRECOND( _rxProvider.is() && _pApplication, "FmTextControlShell::implGetFeatureDispatcher: invalid arg(s)!" );
+        URL aFeatureURL;
+        aFeatureURL.Complete = lcl_getUnoSlotName( _nSlot );
         try
         {
             if ( !m_xURLTransformer.is() )
@@ -1301,25 +1267,16 @@ namespace svx
                 m_xURLTransformer = util::URLTransformer::create( ::comphelper::getProcessComponentContext() );
             }
             if ( m_xURLTransformer.is() )
-                m_xURLTransformer->parseStrict( _rURL );
+                m_xURLTransformer->parseStrict( aFeatureURL );
         }
         catch( const Exception& )
         {
             DBG_UNHANDLED_EXCEPTION();
         }
-    }
-
-
-    FmTextControlFeature* FmTextControlShell::implGetFeatureDispatcher( const Reference< XDispatchProvider >& _rxProvider, SfxApplication* _pApplication, SfxSlotId _nSlot )
-    {
-        OSL_PRECOND( _rxProvider.is() && _pApplication, "FmTextControlShell::implGetFeatureDispatcher: invalid arg(s)!" );
-        URL aFeatureURL;
-        aFeatureURL.Complete = lcl_getUnoSlotName( *_pApplication, _nSlot );
-        impl_parseURL_nothrow( aFeatureURL );
         Reference< XDispatch > xDispatcher = _rxProvider->queryDispatch( aFeatureURL, OUString(), 0xFF );
         if ( xDispatcher.is() )
             return new FmTextControlFeature( xDispatcher, aFeatureURL, _nSlot, this );
-        return NULL;
+        return nullptr;
     }
 
 
@@ -1332,14 +1289,12 @@ namespace svx
     }
 
 
-    void FmTextControlShell::focusGained( const ::com::sun::star::awt::FocusEvent& _rEvent )
+    void FmTextControlShell::focusGained( const css::awt::FocusEvent& _rEvent )
     {
-        Reference< XControl > xControl( _rEvent.Source, UNO_QUERY );
+        Reference< css::awt::XControl > xControl( _rEvent.Source, UNO_QUERY );
 
 #if OSL_DEBUG_LEVEL > 0
-        OString sTrace( "FmTextControlShell::focusGained: 0x" );
-        sTrace += OString::number( (sal_IntPtr)xControl.get(), 16 );
-        OSL_TRACE( "%s", sTrace.getStr() );
+        SAL_INFO("svx.form", "0x" << OUString::number( reinterpret_cast<sal_IntPtr>(xControl.get()), 16 ));
 #endif
 
         DBG_ASSERT( xControl.is(), "FmTextControlShell::focusGained: suspicious focus event!" );
@@ -1348,14 +1303,12 @@ namespace svx
     }
 
 
-    void FmTextControlShell::focusLost( const ::com::sun::star::awt::FocusEvent& _rEvent )
+    void FmTextControlShell::focusLost( const css::awt::FocusEvent& _rEvent )
     {
-        Reference< XControl > xControl( _rEvent.Source, UNO_QUERY );
+        Reference< css::awt::XControl > xControl( _rEvent.Source, UNO_QUERY );
 
 #if OSL_DEBUG_LEVEL > 0
-        OString sTrace( "FmTextControlShell::focusLost: 0x" );
-        sTrace += OString::number( (sal_IntPtr)xControl.get(), 16 );
-        OSL_TRACE( "%s", sTrace.getStr() );
+        SAL_INFO("svx.form", "0x" << OUString::number( reinterpret_cast<sal_IntPtr>(xControl.get()), 16 ));
 #endif
 
         m_bActiveControl = false;
@@ -1368,13 +1321,13 @@ namespace svx
     }
 
 
-    void FmTextControlShell::contextMenuRequested( const awt::MouseEvent& /*_rEvent*/ )
+    void FmTextControlShell::contextMenuRequested( const css::awt::MouseEvent& /*_rEvent*/ )
     {
-        m_rBindings.GetDispatcher()->ExecutePopup( SVX_RES( RID_FM_TEXTATTRIBUTE_MENU ) );
+        m_rBindings.GetDispatcher()->ExecutePopup( "formrichtext" );
     }
 
 
-} // namespace svx
+}
 
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
