@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
  * This file is part of the LibreOffice project.
  *
@@ -18,22 +19,13 @@
 
 #include "GallerySplitter.hxx"
 
-
-DBG_NAME(GallerySplitter)
-
 GallerySplitter::GallerySplitter(
-    Window* pParent,
-    const ResId& rResId,
-    const ::boost::function<void(void)>& rDataChangeFunctor)
-    : Splitter( pParent, rResId ),
-      maDataChangeFunctor(rDataChangeFunctor)
+    vcl::Window* pParent,
+    WinBits nStyle,
+    const ::std::function<void ()>& rDataChangeFunctor)
+    : Splitter(pParent, nStyle)
+    , maDataChangeFunctor(rDataChangeFunctor)
 {
-    DBG_CTOR(GallerySplitter,NULL);
-}
-
-GallerySplitter::~GallerySplitter()
-{
-    DBG_DTOR(GallerySplitter,NULL);
 }
 
 void GallerySplitter::DataChanged( const DataChangedEvent& rDCEvt )
@@ -42,3 +34,5 @@ void GallerySplitter::DataChanged( const DataChangedEvent& rDCEvt )
     if (maDataChangeFunctor)
         maDataChangeFunctor();
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
