@@ -32,23 +32,23 @@
 #include <sfx2/sfxsids.hrc>
 #include <vcl/graphicfilter.hxx>
 #include <editeng/brushitem.hxx>
-#include "helpid.hrc"
-#include "svx/gallery.hxx"
-#include "galobj.hxx"
-#include "svx/gallery1.hxx"
-#include "svx/galtheme.hxx"
-#include "svx/galctrl.hxx"
-#include "svx/galmisc.hxx"
-#include "galbrws2.hxx"
-#include "gallery.hrc"
+#include <helpids.h>
+#include <svx/gallery.hxx>
+#include <svx/svxids.hrc>
+#include <galobj.hxx>
+#include <svx/gallery1.hxx>
+#include <svx/galtheme.hxx>
+#include <svx/galctrl.hxx>
+#include <svx/galmisc.hxx>
+#include <galbrws2.hxx>
 #include <vcl/svapp.hxx>
 #include <vcl/settings.hxx>
 #include <svx/fmmodel.hxx>
 #include <svx/dialmgr.hxx>
 #include <svx/svxdlg.hxx>
-#include <svx/dialogs.hrc>
-#include "GalleryControl.hxx"
-#include "bitmaps.hlst"
+#include <svx/strings.hrc>
+#include <GalleryControl.hxx>
+#include <bitmaps.hlst>
 
 #include <svx/svxcommands.h>
 #include <svx/galleryitem.hxx>
@@ -155,20 +155,17 @@ GalleryThemePopup::GalleryThemePopup(
     mpPopupMenu->SetPopupMenu(mpPopupMenu->GetItemId("background"), mpBackgroundPopup);
 
     // SID_GALLERY_ENABLE_ADDCOPY
-    m_aCommandInfo.insert(
-        CommandInfoMap::value_type(
+    m_aCommandInfo.emplace(
             SID_GALLERY_ENABLE_ADDCOPY,
-            CommandInfo( CMD_SID_GALLERY_ENABLE_ADDCOPY )));
+            CommandInfo( CMD_SID_GALLERY_ENABLE_ADDCOPY ));
     // SID_GALLERY_BG_BRUSH
-    m_aCommandInfo.insert(
-        CommandInfoMap::value_type(
+    m_aCommandInfo.emplace(
             SID_GALLERY_BG_BRUSH,
-            CommandInfo( CMD_SID_GALLERY_BG_BRUSH )));
+            CommandInfo( CMD_SID_GALLERY_BG_BRUSH ));
     // SID_GALLERY_FORMATS
-    m_aCommandInfo.insert(
-        CommandInfoMap::value_type(
+    m_aCommandInfo.emplace(
             SID_GALLERY_FORMATS,
-            CommandInfo( CMD_SID_GALLERY_FORMATS )));
+            CommandInfo( CMD_SID_GALLERY_FORMATS ));
 
 }
 
@@ -402,12 +399,12 @@ GalleryBrowser2::GalleryBrowser2( vcl::Window* pParent, Gallery* pGallery ) :
     maViewBox->InsertItem( TBX_ID_ICON, aDummyImage );
     maViewBox->SetItemBits( TBX_ID_ICON, ToolBoxItemBits::RADIOCHECK | ToolBoxItemBits::AUTOCHECK );
     maViewBox->SetHelpId( TBX_ID_ICON, HID_GALLERY_ICONVIEW );
-    maViewBox->SetQuickHelpText( TBX_ID_ICON, GalResId(RID_SVXSTR_GALLERY_ICONVIEW) );
+    maViewBox->SetQuickHelpText( TBX_ID_ICON, SvxResId(RID_SVXSTR_GALLERY_ICONVIEW) );
 
     maViewBox->InsertItem( TBX_ID_LIST, aDummyImage );
     maViewBox->SetItemBits( TBX_ID_LIST, ToolBoxItemBits::RADIOCHECK | ToolBoxItemBits::AUTOCHECK );
     maViewBox->SetHelpId( TBX_ID_LIST, HID_GALLERY_LISTVIEW );
-    maViewBox->SetQuickHelpText( TBX_ID_LIST, GalResId(RID_SVXSTR_GALLERY_LISTVIEW) );
+    maViewBox->SetQuickHelpText( TBX_ID_LIST, SvxResId(RID_SVXSTR_GALLERY_LISTVIEW) );
 
     MiscHdl( nullptr );
     maViewBox->SetSelectHdl( LINK( this, GalleryBrowser2, SelectTbxHdl ) );
@@ -516,7 +513,7 @@ void GalleryBrowser2::Notify( SfxBroadcaster&, const SfxHint& rHint )
 
     switch( rGalleryHint.GetType() )
     {
-        case( GalleryHintType::THEME_UPDATEVIEW ):
+        case GalleryHintType::THEME_UPDATEVIEW:
         {
             if( GALLERYBROWSERMODE_PREVIEW == GetMode() )
                 SetMode( meLastMode );
@@ -899,7 +896,7 @@ void GalleryBrowser2::ImplUpdateViews( sal_uInt16 nSelectionId )
             mpIconView->InsertItem( (sal_uInt16) i );
         }
 
-        ImplSelectItemId( ( ( nSelectionId > mpCurTheme->GetObjectCount() ) ? mpCurTheme->GetObjectCount() : nSelectionId ) );
+        ImplSelectItemId( ( nSelectionId > mpCurTheme->GetObjectCount() ) ? mpCurTheme->GetObjectCount() : nSelectionId );
     }
 
     switch( GetMode() )
@@ -962,8 +959,8 @@ sal_uIntPtr GalleryBrowser2::ImplGetSelectedItemId( const Point* pSelPos, Point&
         }
     }
 
-    rSelPos.X() = std::max( std::min( rSelPos.X(), aOutputSizePixel.Width() - 1L ), 0L );
-    rSelPos.Y() = std::max( std::min( rSelPos.Y(), aOutputSizePixel.Height() - 1L ), 0L );
+    rSelPos.X() = std::max( std::min( rSelPos.X(), aOutputSizePixel.Width() - 1 ), 0L );
+    rSelPos.Y() = std::max( std::min( rSelPos.Y(), aOutputSizePixel.Height() - 1 ), 0L );
 
     if( nRet && ( !mpCurTheme || ( nRet > mpCurTheme->GetObjectCount() ) ) )
     {
@@ -1031,7 +1028,7 @@ void GalleryBrowser2::DispatchAdd(
         return;
 
     sal_Int8 nType = 0;
-    OUString aFileURL, aFilterName;
+    OUString aFilterName;
     css::uno::Reference< css::lang::XComponent > xDrawing;
     css::uno::Reference< css::graphic::XGraphic > xGraphic;
 
@@ -1067,7 +1064,7 @@ void GalleryBrowser2::DispatchAdd(
     aSeq[0].Name = SVXGALLERYITEM_TYPE;
     aSeq[0].Value <<= nType;
     aSeq[1].Name = SVXGALLERYITEM_URL;
-    aSeq[1].Value <<= aFileURL;
+    aSeq[1].Value <<= OUString();
     aSeq[2].Name = SVXGALLERYITEM_FILTER;
     aSeq[2].Value <<= aFilterName;
     aSeq[3].Name = SVXGALLERYITEM_DRAWING;
