@@ -22,19 +22,21 @@
 #include <sfx2/viewfrm.hxx>
 #include <sfx2/dispatch.hxx>
 #include <avmedia/mediaplayer.hxx>
-#include "helpid.hrc"
-#include "galbrws2.hxx"
-#include "svx/galtheme.hxx"
-#include "svx/galmisc.hxx"
-#include "svx/galctrl.hxx"
-#include "editeng/AccessibleStringWrap.hxx"
+#include <helpids.h>
+#include <galbrws2.hxx>
+#include <svx/dialmgr.hxx>
+#include <svx/galtheme.hxx>
+#include <svx/galmisc.hxx>
+#include <svx/galctrl.hxx>
+#include <editeng/AccessibleStringWrap.hxx>
 #include <editeng/svxfont.hxx>
-#include "galobj.hxx"
+#include <galobj.hxx>
 #include <avmedia/mediawindow.hxx>
-#include "gallery.hrc"
+#include <svx/strings.hrc>
 #include <vcl/graphicfilter.hxx>
 #include <vcl/settings.hxx>
 #include <vcl/builderfactory.hxx>
+#include <bitmaps.hlst>
 
 #define GALLERY_BRWBOX_TITLE    1
 
@@ -48,27 +50,20 @@ GalleryPreview::GalleryPreview(vcl::Window* pParent, WinBits nStyle, GalleryThem
     InitSettings();
 }
 
-VCL_BUILDER_DECL_FACTORY(GalleryPreview)
-{
-    WinBits nWinBits = WB_TABSTOP;
-    OString sBorder = VclBuilder::extractCustomProperty(rMap);
-    if (!sBorder.isEmpty())
-        nWinBits |= WB_BORDER;
-    rRet = VclPtr<GalleryPreview>::Create(pParent, nWinBits);
-}
+VCL_BUILDER_FACTORY_CONSTRUCTOR(GalleryPreview, WB_TABSTOP)
 
 Size GalleryPreview::GetOptimalSize() const
 {
-    return LogicToPixel(Size(70, 88), MAP_APPFONT);
+    return LogicToPixel(Size(70, 88), MapMode(MapUnit::MapAppFont));
 }
 
 bool GalleryPreview::SetGraphic( const INetURLObject& _aURL )
 {
     bool bRet = true;
     Graphic aGraphic;
-    if( ::avmedia::MediaWindow::isMediaURL( _aURL.GetMainURL( INetURLObject::DECODE_UNAMBIGUOUS ), "" ) )
+    if( ::avmedia::MediaWindow::isMediaURL( _aURL.GetMainURL( INetURLObject::DecodeMechanism::Unambiguous ), "" ) )
     {
-        aGraphic = BitmapEx( GAL_RES( RID_SVXBMP_GALLERY_MEDIA ) );
+        aGraphic = BitmapEx(RID_SVXBMP_GALLERY_MEDIA);
     }
     else
     {
@@ -98,7 +93,7 @@ void GalleryPreview::DataChanged( const DataChangedEvent& rDCEvt )
         Window::DataChanged( rDCEvt );
 }
 
-bool GalleryPreview::ImplGetGraphicCenterRect( const Graphic& rGraphic, Rectangle& rResultRect ) const
+bool GalleryPreview::ImplGetGraphicCenterRect( const Graphic& rGraphic, tools::Rectangle& rResultRect ) const
 {
     const Size  aWinSize( GetOutputSizePixel() );
     Size        aNewSize( LogicToPixel( rGraphic.GetPrefSize(), rGraphic.GetPrefMapMode() ) );
@@ -124,14 +119,14 @@ bool GalleryPreview::ImplGetGraphicCenterRect( const Graphic& rGraphic, Rectangl
         const Point aNewPos( ( aWinSize.Width()  - aNewSize.Width() ) >> 1,
                              ( aWinSize.Height() - aNewSize.Height() ) >> 1 );
 
-        rResultRect = Rectangle( aNewPos, aNewSize );
+        rResultRect = tools::Rectangle( aNewPos, aNewSize );
         bRet = true;
     }
 
     return bRet;
 }
 
-void GalleryPreview::Paint(vcl::RenderContext& rRenderContext, const Rectangle& rRect)
+void GalleryPreview::Paint(vcl::RenderContext& rRenderContext, const tools::Rectangle& rRect)
 {
     Window::Paint(rRenderContext, rRect);
 
@@ -150,7 +145,7 @@ void GalleryPreview::Paint(vcl::RenderContext& rRenderContext, const Rectangle&
 void GalleryPreview::MouseButtonDown(const MouseEvent& rMEvt)
 {
     if (mpTheme && (rMEvt.GetClicks() == 2))
-        static_cast<GalleryBrowser2*>(GetParent())->TogglePreview(this);
+        static_cast<GalleryBrowser2*>(GetParent())->TogglePreview();
 }
 
 void GalleryPreview::Command(const CommandEvent& rCEvt)
@@ -160,7 +155,7 @@ void GalleryPreview::Command(const CommandEvent& rCEvt)
     if (mpTheme && (rCEvt.GetCommand() == CommandEventId::ContextMenu))
     {
         GalleryBrowser2* pGalleryBrowser = static_cast<GalleryBrowser2*>(GetParent());
-        pGalleryBrowser->ShowContextMenu(this, (rCEvt.IsMouseEvent() ? &rCEvt.GetMousePosPixel() : nullptr));
+        pGalleryBrowser->ShowContextMenu(rCEvt.IsMouseEvent() ? &rCEvt.GetMousePosPixel() : nullptr);
     }
 }
 
@@ -172,26 +167,26 @@ void GalleryPreview::KeyInput(const KeyEvent& rKEvt)
 
         switch( rKEvt.GetKeyCode().GetCode() )
         {
-            case( KEY_BACKSPACE ):
-                pBrowser->TogglePreview( this );
+            case KEY_BACKSPACE:
+                pBrowser->TogglePreview();
             break;
 
-            case( KEY_HOME ):
-                pBrowser->Travel( GALLERYBROWSERTRAVEL_FIRST );
+            case KEY_HOME:
+                pBrowser->Travel( GalleryBrowserTravel::First );
             break;
 
-            case( KEY_END ):
-                pBrowser->Travel( GALLERYBROWSERTRAVEL_LAST );
+            case KEY_END:
+                pBrowser->Travel( GalleryBrowserTravel::Last );
             break;
 
-            case( KEY_LEFT ):
-            case( KEY_UP ):
-                pBrowser->Travel( GALLERYBROWSERTRAVEL_PREVIOUS );
+            case KEY_LEFT:
+            case KEY_UP:
+                pBrowser->Travel( GalleryBrowserTravel::Previous );
             break;
 
-            case( KEY_RIGHT ):
-            case( KEY_DOWN ):
-                pBrowser->Travel( GALLERYBROWSERTRAVEL_NEXT );
+            case KEY_RIGHT:
+            case KEY_DOWN:
+                pBrowser->Travel( GalleryBrowserTravel::Next );
             break;
 
             default:
@@ -208,12 +203,12 @@ void GalleryPreview::KeyInput(const KeyEvent& rKEvt)
     }
 }
 
-sal_Int8 GalleryPreview::AcceptDrop( const AcceptDropEvent& rEvt )
+sal_Int8 GalleryPreview::AcceptDrop( const AcceptDropEvent& /*rEvt*/ )
 {
     sal_Int8 nRet;
 
     if (mpTheme)
-        nRet = static_cast<GalleryBrowser2*>(GetParent())->AcceptDrop(*this, rEvt);
+        nRet = static_cast<GalleryBrowser2*>(GetParent())->AcceptDrop(*this);
     else
         nRet = DND_ACTION_NONE;
 
@@ -225,7 +220,7 @@ sal_Int8 GalleryPreview::ExecuteDrop( const ExecuteDropEvent& rEvt )
     sal_Int8 nRet;
 
     if (mpTheme)
-        nRet = static_cast<GalleryBrowser2*>(GetParent())->ExecuteDrop(*this, rEvt);
+        nRet = static_cast<GalleryBrowser2*>(GetParent())->ExecuteDrop(rEvt);
     else
         nRet = DND_ACTION_NONE;
 
@@ -235,7 +230,7 @@ sal_Int8 GalleryPreview::ExecuteDrop( const ExecuteDropEvent& rEvt )
 void GalleryPreview::StartDrag( sal_Int8, const Point& )
 {
     if(mpTheme)
-        static_cast<GalleryBrowser2*>(GetParent())->StartDrag(this);
+        static_cast<GalleryBrowser2*>(GetParent())->StartDrag();
 }
 
 void GalleryPreview::PreviewMedia( const INetURLObject& rURL )
@@ -251,7 +246,7 @@ void GalleryPreview::PreviewMedia( const INetURLObject& rURL )
         }
 
         if (pFloater)
-            pFloater->setURL( rURL.GetMainURL( INetURLObject::DECODE_UNAMBIGUOUS ), "", true );
+            pFloater->setURL( rURL.GetMainURL( INetURLObject::DecodeMechanism::Unambiguous ), "", true );
     }
 }
 
@@ -302,62 +297,62 @@ void GalleryIconView::UserDraw(const UserDrawEvent& rUDEvt)
 {
     const sal_uInt16 nId = rUDEvt.GetItemId();
 
-    if (nId && mpTheme)
+    if (!nId || !mpTheme)
+        return;
+
+    const tools::Rectangle& rRect = rUDEvt.GetRect();
+    const Size aSize(rRect.GetWidth(), rRect.GetHeight());
+    BitmapEx aBitmapEx;
+    Size aPreparedSize;
+    OUString aItemTextTitle;
+    OUString aItemTextPath;
+
+    mpTheme->GetPreviewBitmapExAndStrings(nId - 1, aBitmapEx, aPreparedSize, aItemTextTitle, aItemTextPath);
+
+    bool bNeedToCreate(aBitmapEx.IsEmpty());
+
+    if (!bNeedToCreate && aItemTextTitle.isEmpty())
     {
-        const Rectangle& rRect = rUDEvt.GetRect();
-        const Size aSize(rRect.GetWidth(), rRect.GetHeight());
-        BitmapEx aBitmapEx;
-        Size aPreparedSize;
-        OUString aItemTextTitle;
-        OUString aItemTextPath;
-
-        mpTheme->GetPreviewBitmapExAndStrings(nId - 1, aBitmapEx, aPreparedSize, aItemTextTitle, aItemTextPath);
-
-        bool bNeedToCreate(aBitmapEx.IsEmpty());
-
-        if (!bNeedToCreate && aItemTextTitle.isEmpty())
-        {
-            bNeedToCreate = true;
-        }
-
-        if (!bNeedToCreate && aPreparedSize != aSize)
-        {
-            bNeedToCreate = true;
-        }
-
-        if (bNeedToCreate)
-        {
-            SgaObject* pObj = mpTheme->AcquireObject(nId - 1);
-
-            if(pObj)
-            {
-                aBitmapEx = pObj->createPreviewBitmapEx(aSize);
-                aItemTextTitle = GalleryBrowser2::GetItemText(*mpTheme, *pObj, GALLERY_ITEM_TITLE);
-
-                mpTheme->SetPreviewBitmapExAndStrings(nId - 1, aBitmapEx, aSize, aItemTextTitle, aItemTextPath);
-                GalleryTheme::ReleaseObject(pObj);
-            }
-        }
-
-        if (!aBitmapEx.IsEmpty())
-        {
-            const Size aBitmapExSizePixel(aBitmapEx.GetSizePixel());
-            const Point aPos(
-                ((aSize.Width() - aBitmapExSizePixel.Width()) >> 1) + rRect.Left(),
-                ((aSize.Height() - aBitmapExSizePixel.Height()) >> 1) + rRect.Top());
-            OutputDevice* pDev = rUDEvt.GetRenderContext();
-
-            if(aBitmapEx.IsTransparent())
-            {
-                // draw checkered background for full rectangle.
-                drawTransparenceBackground(*pDev, rRect.TopLeft(), rRect.GetSize());
-            }
-
-            pDev->DrawBitmapEx(aPos, aBitmapEx);
-        }
-
-        SetItemText(nId, aItemTextTitle);
+        bNeedToCreate = true;
     }
+
+    if (!bNeedToCreate && aPreparedSize != aSize)
+    {
+        bNeedToCreate = true;
+    }
+
+    if (bNeedToCreate)
+    {
+        SgaObject* pObj = mpTheme->AcquireObject(nId - 1);
+
+        if(pObj)
+        {
+            aBitmapEx = pObj->createPreviewBitmapEx(aSize);
+            aItemTextTitle = GalleryBrowser2::GetItemText(*mpTheme, *pObj, GalleryItemFlags::Title);
+
+            mpTheme->SetPreviewBitmapExAndStrings(nId - 1, aBitmapEx, aSize, aItemTextTitle, aItemTextPath);
+            GalleryTheme::ReleaseObject(pObj);
+        }
+    }
+
+    if (!aBitmapEx.IsEmpty())
+    {
+        const Size aBitmapExSizePixel(aBitmapEx.GetSizePixel());
+        const Point aPos(
+            ((aSize.Width() - aBitmapExSizePixel.Width()) >> 1) + rRect.Left(),
+            ((aSize.Height() - aBitmapExSizePixel.Height()) >> 1) + rRect.Top());
+        OutputDevice* pDev = rUDEvt.GetRenderContext();
+
+        if(aBitmapEx.IsTransparent())
+        {
+            // draw checkered background for full rectangle.
+            drawTransparenceBackground(*pDev, rRect.TopLeft(), rRect.GetSize());
+        }
+
+        pDev->DrawBitmapEx(aPos, aBitmapEx);
+    }
+
+    SetItemText(nId, aItemTextTitle);
 }
 
 void GalleryIconView::MouseButtonDown(const MouseEvent& rMEvt)
@@ -365,7 +360,7 @@ void GalleryIconView::MouseButtonDown(const MouseEvent& rMEvt)
     ValueSet::MouseButtonDown(rMEvt);
 
     if (rMEvt.GetClicks() == 2)
-        static_cast<GalleryBrowser2*>(GetParent())->TogglePreview(this, &rMEvt.GetPosPixel());
+        static_cast<GalleryBrowser2*>(GetParent())->TogglePreview();
 }
 
 void GalleryIconView::Command(const CommandEvent& rCEvt)
@@ -375,7 +370,7 @@ void GalleryIconView::Command(const CommandEvent& rCEvt)
     if (rCEvt.GetCommand() == CommandEventId::ContextMenu)
     {
         GalleryBrowser2* pGalleryBrowser = static_cast<GalleryBrowser2*>(GetParent());
-        pGalleryBrowser->ShowContextMenu(this, (rCEvt.IsMouseEvent() ? &rCEvt.GetMousePosPixel() : nullptr));
+        pGalleryBrowser->ShowContextMenu(rCEvt.IsMouseEvent() ? &rCEvt.GetMousePosPixel() : nullptr);
     }
 }
 
@@ -385,14 +380,14 @@ void GalleryIconView::KeyInput(const KeyEvent& rKEvt)
         ValueSet::KeyInput(rKEvt);
 }
 
-sal_Int8 GalleryIconView::AcceptDrop(const AcceptDropEvent& rEvt)
+sal_Int8 GalleryIconView::AcceptDrop(const AcceptDropEvent& /*rEvt*/)
 {
-    return(static_cast<GalleryBrowser2*>(GetParent())->AcceptDrop(*this, rEvt));
+    return static_cast<GalleryBrowser2*>(GetParent())->AcceptDrop(*this);
 }
 
 sal_Int8 GalleryIconView::ExecuteDrop(const ExecuteDropEvent& rEvt)
 {
-    return(static_cast<GalleryBrowser2*>(GetParent())->ExecuteDrop(*this, rEvt));
+    return static_cast<GalleryBrowser2*>(GetParent())->ExecuteDrop(rEvt);
 }
 
 void GalleryIconView::StartDrag(sal_Int8, const Point&)
@@ -402,7 +397,7 @@ void GalleryIconView::StartDrag(sal_Int8, const Point&)
 
     // call this to initiate dragging for ValueSet
     ValueSet::StartDrag(aEvt, aRegion);
-    static_cast<GalleryBrowser2*>(GetParent())->StartDrag(this);
+    static_cast<GalleryBrowser2*>(GetParent())->StartDrag();
 }
 
 GalleryListView::GalleryListView( GalleryBrowser2* pParent, GalleryTheme* pTheme ) :
@@ -417,7 +412,7 @@ GalleryListView::GalleryListView( GalleryBrowser2* pParent, GalleryTheme* pTheme
 
     SetMode( BrowserMode::AUTO_VSCROLL | BrowserMode::AUTOSIZE_LASTCOL | BrowserMode::AUTO_HSCROLL );
     SetDataRowHeight( 28 );
-    InsertDataColumn( GALLERY_BRWBOX_TITLE, GAL_RESSTR(RID_SVXSTR_GALLERY_TITLE), 256  );
+    InsertDataColumn( GALLERY_BRWBOX_TITLE, SvxResId(RID_SVXSTR_GALLERY_TITLE), 256  );
 }
 
 void GalleryListView::InitSettings()
@@ -450,7 +445,7 @@ OUString GalleryListView::GetCellText(long _nRow, sal_uInt16 /*nColumnId*/) cons
 
         if( pObj )
         {
-            sRet = GalleryBrowser2::GetItemText( *mpTheme, *pObj, GALLERY_ITEM_TITLE );
+            sRet = GalleryBrowser2::GetItemText( *mpTheme, *pObj, GalleryItemFlags::Title );
             GalleryTheme::ReleaseObject( pObj );
         }
     }
@@ -458,10 +453,10 @@ OUString GalleryListView::GetCellText(long _nRow, sal_uInt16 /*nColumnId*/) cons
     return sRet;
 }
 
-Rectangle GalleryListView::GetFieldCharacterBounds(sal_Int32 _nRow,sal_Int32 _nColumnPos,sal_Int32 nIndex)
+tools::Rectangle GalleryListView::GetFieldCharacterBounds(sal_Int32 _nRow,sal_Int32 _nColumnPos,sal_Int32 nIndex)
 {
     DBG_ASSERT(_nColumnPos >= 0 && _nColumnPos <= USHRT_MAX, "GalleryListView::GetFieldCharacterBounds: _nColumnId overflow");
-    Rectangle aRect;
+    tools::Rectangle aRect;
     if ( SeekRow(_nRow) )
     {
         SvxFont aFont( GetFont() );
@@ -488,7 +483,7 @@ sal_Int32 GalleryListView::GetFieldIndexAtPoint(sal_Int32 _nRow,sal_Int32 _nColu
     return nRet;
 }
 
-void GalleryListView::PaintField(vcl::RenderContext& rDev, const Rectangle& rRect, sal_uInt16 /*nColumnId*/) const
+void GalleryListView::PaintField(vcl::RenderContext& rDev, const tools::Rectangle& rRect, sal_uInt16 /*nColumnId*/) const
 {
     rDev.Push( PushFlags::CLIPREGION );
     rDev.IntersectClipRegion( rRect );
@@ -515,8 +510,8 @@ void GalleryListView::PaintField(vcl::RenderContext& rDev, const Rectangle& rRec
             if(pObj)
             {
                 aBitmapEx = pObj->createPreviewBitmapEx(aSize);
-                aItemTextTitle = GalleryBrowser2::GetItemText(*mpTheme, *pObj, GALLERY_ITEM_TITLE);
-                aItemTextPath = GalleryBrowser2::GetItemText(*mpTheme, *pObj, GALLERY_ITEM_PATH);
+                aItemTextTitle = GalleryBrowser2::GetItemText(*mpTheme, *pObj, GalleryItemFlags::Title);
+                aItemTextPath = GalleryBrowser2::GetItemText(*mpTheme, *pObj, GalleryItemFlags::Path);
 
                 mpTheme->SetPreviewBitmapExAndStrings(mnCurRow, aBitmapEx, aSize, aItemTextTitle, aItemTextPath);
                 GalleryTheme::ReleaseObject(pObj);
@@ -558,7 +553,7 @@ void GalleryListView::Command( const CommandEvent& rCEvt )
         if( rCEvt.IsMouseEvent() && ( GetRowAtYPosPixel( rCEvt.GetMousePosPixel().Y() ) != BROWSER_ENDOFSELECTION ) )
             pPos = &rCEvt.GetMousePosPixel();
 
-        static_cast<GalleryBrowser2*>( GetParent() )->ShowContextMenu( this, pPos );
+        static_cast<GalleryBrowser2*>( GetParent() )->ShowContextMenu( pPos );
     }
 }
 
@@ -573,7 +568,7 @@ void GalleryListView::DoubleClick( const BrowserMouseEvent& rEvt )
     BrowseBox::DoubleClick( rEvt );
 
     if( rEvt.GetRow() != BROWSER_ENDOFSELECTION )
-        static_cast<GalleryBrowser2*>( GetParent() )->TogglePreview( this, &rEvt.GetPosPixel() );
+        static_cast<GalleryBrowser2*>( GetParent() )->TogglePreview();
 }
 
 void GalleryListView::Select()
@@ -597,12 +592,12 @@ sal_Int8 GalleryListView::ExecuteDrop( const BrowserExecuteDropEvent& rEvt )
 
     aEvt.maPosPixel.Y() += GetTitleHeight();
 
-    return( static_cast<GalleryBrowser2*>( GetParent() )->ExecuteDrop( *this, aEvt ) );
+    return static_cast<GalleryBrowser2*>( GetParent() )->ExecuteDrop( aEvt );
 }
 
 void GalleryListView::StartDrag( sal_Int8, const Point& rPosPixel )
 {
-    static_cast<GalleryBrowser2*>( GetParent() )->StartDrag( this, &rPosPixel );
+    static_cast<GalleryBrowser2*>( GetParent() )->StartDrag( &rPosPixel );
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
