@@ -36,10 +36,11 @@
 #include <svx/sdr/primitive2d/sdrdecompositiontools.hxx>
 #include <vcl/lazydelete.hxx>
 #include <vcl/settings.hxx>
-#include <svx/svdstr.hrc>
+#include <svx/strings.hrc>
 #include <svdglob.hxx>
 #include <drawinglayer/primitive2d/discreteshadowprimitive2d.hxx>
 #include <drawinglayer/attribute/sdrfillattribute.hxx>
+#include <bitmaps.hlst>
 
 namespace sdr { namespace contact {
 
@@ -70,7 +71,7 @@ ViewObjectContact& ViewContactOfPageBackground::CreateObjectSpecificViewObjectCo
     return *pRetval;
 }
 
-drawinglayer::primitive2d::Primitive2DSequence ViewContactOfPageBackground::createViewIndependentPrimitive2DSequence() const
+drawinglayer::primitive2d::Primitive2DContainer ViewContactOfPageBackground::createViewIndependentPrimitive2DSequence() const
 {
     // We have only the page information, not the view information. Use the
     // svtools::DOCCOLOR color for initialisation
@@ -80,7 +81,7 @@ drawinglayer::primitive2d::Primitive2DSequence ViewContactOfPageBackground::crea
     const drawinglayer::primitive2d::Primitive2DReference xReference(
         new drawinglayer::primitive2d::BackgroundColorPrimitive2D(aRGBColor));
 
-    return drawinglayer::primitive2d::Primitive2DSequence(&xReference, 1);
+    return drawinglayer::primitive2d::Primitive2DContainer { xReference };
 }
 
 ViewContactOfPageBackground::ViewContactOfPageBackground(ViewContactOfSdrPage& rParentViewContactOfSdrPage)
@@ -100,13 +101,13 @@ ViewObjectContact& ViewContactOfPageShadow::CreateObjectSpecificViewObjectContac
     return *pRetval;
 }
 
-drawinglayer::primitive2d::Primitive2DSequence ViewContactOfPageShadow::createViewIndependentPrimitive2DSequence() const
+drawinglayer::primitive2d::Primitive2DContainer ViewContactOfPageShadow::createViewIndependentPrimitive2DSequence() const
 {
     static bool bUseOldPageShadow(false);
     const SdrPage& rPage = getPage();
     basegfx::B2DHomMatrix aPageMatrix;
-    aPageMatrix.set(0, 0, (double)rPage.GetWdt());
-    aPageMatrix.set(1, 1, (double)rPage.GetHgt());
+    aPageMatrix.set(0, 0, (double)rPage.GetWidth());
+    aPageMatrix.set(1, 1, (double)rPage.GetHeight());
 
     if(bUseOldPageShadow)
     {
@@ -132,16 +133,13 @@ drawinglayer::primitive2d::Primitive2DSequence ViewContactOfPageShadow::createVi
                 basegfx::B2DPolyPolygon(aPageShadowPolygon),
                 aRGBShadowColor));
 
-        return drawinglayer::primitive2d::Primitive2DSequence(&xReference, 1);
+        return drawinglayer::primitive2d::Primitive2DContainer { xReference };
     }
     else
     {
         static vcl::DeleteOnDeinit< drawinglayer::primitive2d::DiscreteShadow > aDiscreteShadow(
             new drawinglayer::primitive2d::DiscreteShadow(
-                BitmapEx(
-                    ResId(
-                        SIP_SA_PAGESHADOW35X35,
-                        *ImpGetResMgr()))));
+                BitmapEx(SIP_SA_PAGESHADOW35X35)));
 
         if(aDiscreteShadow.get())
         {
@@ -150,10 +148,10 @@ drawinglayer::primitive2d::Primitive2DSequence ViewContactOfPageShadow::createVi
                     aPageMatrix,
                     *aDiscreteShadow.get()));
 
-            return drawinglayer::primitive2d::Primitive2DSequence(&xReference, 1);
+            return drawinglayer::primitive2d::Primitive2DContainer { xReference };
         }
 
-        return drawinglayer::primitive2d::Primitive2DSequence();
+        return drawinglayer::primitive2d::Primitive2DContainer();
     }
 }
 
@@ -174,9 +172,9 @@ ViewObjectContact& ViewContactOfMasterPage::CreateObjectSpecificViewObjectContac
     return *pRetval;
 }
 
-drawinglayer::primitive2d::Primitive2DSequence ViewContactOfMasterPage::createViewIndependentPrimitive2DSequence() const
+drawinglayer::primitive2d::Primitive2DContainer ViewContactOfMasterPage::createViewIndependentPrimitive2DSequence() const
 {
-    drawinglayer::primitive2d::Primitive2DSequence xRetval;
+    drawinglayer::primitive2d::Primitive2DContainer xRetval;
 
     // this class is used when the page is a MasterPage and is responsible to
     // create a visualisation for the MPBGO, if exists. This needs to be suppressed
@@ -211,16 +209,16 @@ drawinglayer::primitive2d::Primitive2DSequence ViewContactOfMasterPage::createVi
             {
                 // direct model data is the page size, get and use it
                 const basegfx::B2DRange aInnerRange(
-                    rPage.GetLftBorder(), rPage.GetUppBorder(),
-                    rPage.GetWdt() - rPage.GetRgtBorder(), rPage.GetHgt() - rPage.GetLwrBorder());
-                const basegfx::B2DPolygon aInnerPolgon(basegfx::tools::createPolygonFromRect(aInnerRange));
+                    rPage.GetLeftBorder(), rPage.GetUpperBorder(),
+                    rPage.GetWidth() - rPage.GetRightBorder(), rPage.GetHeight() - rPage.GetLowerBorder());
+                const basegfx::B2DPolygon aInnerPolgon(basegfx::utils::createPolygonFromRect(aInnerRange));
                 const drawinglayer::primitive2d::Primitive2DReference xReference(
                     drawinglayer::primitive2d::createPolyPolygonFillPrimitive(
                         basegfx::B2DPolyPolygon(aInnerPolgon),
                         aFill,
                         drawinglayer::attribute::FillGradientAttribute()));
 
-                xRetval = drawinglayer::primitive2d::Primitive2DSequence(&xReference, 1);
+                xRetval = drawinglayer::primitive2d::Primitive2DContainer { xReference };
             }
         }
     }
@@ -245,11 +243,11 @@ ViewObjectContact& ViewContactOfPageFill::CreateObjectSpecificViewObjectContact(
     return *pRetval;
 }
 
-drawinglayer::primitive2d::Primitive2DSequence ViewContactOfPageFill::createViewIndependentPrimitive2DSequence() const
+drawinglayer::primitive2d::Primitive2DContainer ViewContactOfPageFill::createViewIndependentPrimitive2DSequence() const
 {
     const SdrPage& rPage = getPage();
-    const basegfx::B2DRange aPageFillRange(0.0, 0.0, (double)rPage.GetWdt(), (double)rPage.GetHgt());
-    const basegfx::B2DPolygon aPageFillPolygon(basegfx::tools::createPolygonFromRect(aPageFillRange));
+    const basegfx::B2DRange aPageFillRange(0.0, 0.0, (double)rPage.GetWidth(), (double)rPage.GetHeight());
+    const basegfx::B2DPolygon aPageFillPolygon(basegfx::utils::createPolygonFromRect(aPageFillRange));
 
     // We have only the page information, not the view information. Use the
     // svtools::DOCCOLOR color for initialisation
@@ -260,7 +258,7 @@ drawinglayer::primitive2d::Primitive2DSequence ViewContactOfPageFill::createView
     const basegfx::BColor aRGBColor(aPageFillColor.getBColor());
     const drawinglayer::primitive2d::Primitive2DReference xReference(new drawinglayer::primitive2d::PolyPolygonColorPrimitive2D(basegfx::B2DPolyPolygon(aPageFillPolygon), aRGBColor));
 
-    return drawinglayer::primitive2d::Primitive2DSequence(&xReference, 1);
+    return drawinglayer::primitive2d::Primitive2DContainer { xReference };
 }
 
 ViewContactOfPageFill::ViewContactOfPageFill(ViewContactOfSdrPage& rParentViewContactOfSdrPage)
@@ -280,11 +278,11 @@ ViewObjectContact& ViewContactOfOuterPageBorder::CreateObjectSpecificViewObjectC
     return *pRetval;
 }
 
-drawinglayer::primitive2d::Primitive2DSequence ViewContactOfOuterPageBorder::createViewIndependentPrimitive2DSequence() const
+drawinglayer::primitive2d::Primitive2DContainer ViewContactOfOuterPageBorder::createViewIndependentPrimitive2DSequence() const
 {
-    drawinglayer::primitive2d::Primitive2DSequence xRetval;
+    drawinglayer::primitive2d::Primitive2DContainer xRetval;
     const SdrPage& rPage = getPage();
-    const basegfx::B2DRange aPageBorderRange(0.0, 0.0, (double)rPage.GetWdt(), (double)rPage.GetHgt());
+    const basegfx::B2DRange aPageBorderRange(0.0, 0.0, (double)rPage.GetWidth(), (double)rPage.GetHeight());
 
     // Changed to 0x949599 for renaissance, before svtools::FONTCOLOR was used.
     // Added old case as fallback for HighContrast.
@@ -310,14 +308,14 @@ drawinglayer::primitive2d::Primitive2DSequence ViewContactOfOuterPageBorder::cre
         aRight.append(basegfx::B2DPoint(aPageBorderRange.getMaxX(), aPageBorderRange.getMinY()));
         aRight.append(basegfx::B2DPoint(aPageBorderRange.getMaxX(), aPageBorderRange.getMaxY()));
 
-        xRetval.realloc(2);
+        xRetval.resize(2);
         xRetval[0] = drawinglayer::primitive2d::Primitive2DReference(new drawinglayer::primitive2d::PolygonHairlinePrimitive2D(aLeft, aRGBBorderColor));
         xRetval[1] = drawinglayer::primitive2d::Primitive2DReference(new drawinglayer::primitive2d::PolygonHairlinePrimitive2D(aRight, aRGBBorderColor));
     }
     else
     {
-        xRetval.realloc(1);
-        const basegfx::B2DPolygon aPageBorderPolygon(basegfx::tools::createPolygonFromRect(aPageBorderRange));
+        xRetval.resize(1);
+        const basegfx::B2DPolygon aPageBorderPolygon(basegfx::utils::createPolygonFromRect(aPageBorderRange));
         xRetval[0] = drawinglayer::primitive2d::Primitive2DReference(new drawinglayer::primitive2d::PolygonHairlinePrimitive2D(aPageBorderPolygon, aRGBBorderColor));
     }
 
@@ -341,13 +339,13 @@ ViewObjectContact& ViewContactOfInnerPageBorder::CreateObjectSpecificViewObjectC
     return *pRetval;
 }
 
-drawinglayer::primitive2d::Primitive2DSequence ViewContactOfInnerPageBorder::createViewIndependentPrimitive2DSequence() const
+drawinglayer::primitive2d::Primitive2DContainer ViewContactOfInnerPageBorder::createViewIndependentPrimitive2DSequence() const
 {
     const SdrPage& rPage = getPage();
     const basegfx::B2DRange aPageBorderRange(
-        (double)rPage.GetLftBorder(), (double)rPage.GetUppBorder(),
-        (double)(rPage.GetWdt() - rPage.GetRgtBorder()), (double)(rPage.GetHgt() - rPage.GetLwrBorder()));
-    const basegfx::B2DPolygon aPageBorderPolygon(basegfx::tools::createPolygonFromRect(aPageBorderRange));
+        (double)rPage.GetLeftBorder(), (double)rPage.GetUpperBorder(),
+        (double)(rPage.GetWidth() - rPage.GetRightBorder()), (double)(rPage.GetHeight() - rPage.GetLowerBorder()));
+    const basegfx::B2DPolygon aPageBorderPolygon(basegfx::utils::createPolygonFromRect(aPageBorderRange));
 
     // We have only the page information, not the view information. Use the
     // svtools::FONTCOLOR or svtools::DOCBOUNDARIES color for initialisation
@@ -360,14 +358,16 @@ drawinglayer::primitive2d::Primitive2DSequence ViewContactOfInnerPageBorder::cre
     }
     else
     {
-        aBorderColor = aColorConfig.GetColorValue(svtools::DOCBOUNDARIES).nColor;
+        svtools::ColorConfigValue aBorderConfig = aColorConfig.GetColorValue(svtools::DOCBOUNDARIES);
+        aBorderColor = aBorderConfig.bIsVisible ? aBorderConfig.nColor :
+                           aColorConfig.GetColorValue(svtools::DOCCOLOR).nColor;
     }
 
     // create page outer border primitive
     const basegfx::BColor aRGBBorderColor(aBorderColor.getBColor());
     const drawinglayer::primitive2d::Primitive2DReference xReference(new drawinglayer::primitive2d::PolygonHairlinePrimitive2D(aPageBorderPolygon, aRGBBorderColor));
 
-    return drawinglayer::primitive2d::Primitive2DSequence(&xReference, 1);
+    return drawinglayer::primitive2d::Primitive2DContainer { xReference };
 }
 
 ViewContactOfInnerPageBorder::ViewContactOfInnerPageBorder(ViewContactOfSdrPage& rParentViewContactOfSdrPage)
@@ -387,19 +387,19 @@ ViewObjectContact& ViewContactOfPageHierarchy::CreateObjectSpecificViewObjectCon
     return *pRetval;
 }
 
-drawinglayer::primitive2d::Primitive2DSequence ViewContactOfPageHierarchy::createViewIndependentPrimitive2DSequence() const
+drawinglayer::primitive2d::Primitive2DContainer ViewContactOfPageHierarchy::createViewIndependentPrimitive2DSequence() const
 {
     // collect sub-hierarchy
-    drawinglayer::primitive2d::Primitive2DSequence xRetval;
+    drawinglayer::primitive2d::Primitive2DContainer xRetval;
     const sal_uInt32 nObjectCount(GetObjectCount());
 
     // collect all sub-primitives
     for(sal_uInt32 a(0); a < nObjectCount; a++)
     {
         const ViewContact& rCandidate(GetViewContact(a));
-        const drawinglayer::primitive2d::Primitive2DSequence aCandSeq(rCandidate.getViewIndependentPrimitive2DSequence());
+        const drawinglayer::primitive2d::Primitive2DContainer aCandSeq(rCandidate.getViewIndependentPrimitive2DContainer());
 
-        drawinglayer::primitive2d::appendPrimitive2DSequenceToPrimitive2DSequence(xRetval, aCandSeq);
+        xRetval.insert(xRetval.end(), aCandSeq.begin(), aCandSeq.end());
     }
 
     return xRetval;
@@ -434,11 +434,11 @@ ViewObjectContact& ViewContactOfGrid::CreateObjectSpecificViewObjectContact(Obje
     return *pRetval;
 }
 
-drawinglayer::primitive2d::Primitive2DSequence ViewContactOfGrid::createViewIndependentPrimitive2DSequence() const
+drawinglayer::primitive2d::Primitive2DContainer ViewContactOfGrid::createViewIndependentPrimitive2DSequence() const
 {
     // We have only the page information, not the view information and thus no grid settings. Create empty
     // default. For the view-dependent implementation, see ViewObjectContactOfPageGrid::createPrimitive2DSequence
-    return drawinglayer::primitive2d::Primitive2DSequence();
+    return drawinglayer::primitive2d::Primitive2DContainer();
 }
 
 ViewContactOfGrid::ViewContactOfGrid(ViewContactOfSdrPage& rParentViewContactOfSdrPage, bool bFront)
@@ -459,11 +459,11 @@ ViewObjectContact& ViewContactOfHelplines::CreateObjectSpecificViewObjectContact
     return *pRetval;
 }
 
-drawinglayer::primitive2d::Primitive2DSequence ViewContactOfHelplines::createViewIndependentPrimitive2DSequence() const
+drawinglayer::primitive2d::Primitive2DContainer ViewContactOfHelplines::createViewIndependentPrimitive2DSequence() const
 {
     // We have only the page information, not the view information and thus no helplines. Create empty
     // default. For the view-dependent implementation, see ViewObjectContactOfPageHelplines::createPrimitive2DSequence
-    return drawinglayer::primitive2d::Primitive2DSequence();
+    return drawinglayer::primitive2d::Primitive2DContainer();
 }
 
 ViewContactOfHelplines::ViewContactOfHelplines(ViewContactOfSdrPage& rParentViewContactOfSdrPage, bool bFront)
@@ -522,9 +522,9 @@ ViewContact& ViewContactOfSdrPage::GetViewContact(sal_uInt32 nIndex) const
 {
     switch(nIndex)
     {
-        case 0: return (ViewContact&)maViewContactOfPageBackground;
-        case 1: return (ViewContact&)maViewContactOfPageShadow;
-        case 2: return (ViewContact&)maViewContactOfPageFill;
+        case 0: return const_cast<ViewContactOfPageBackground&>(maViewContactOfPageBackground);
+        case 1: return const_cast<ViewContactOfPageShadow&>(maViewContactOfPageShadow);
+        case 2: return const_cast<ViewContactOfPageFill&>(maViewContactOfPageFill);
         case 3:
         {
             const SdrPage& rPage = GetSdrPage();
@@ -535,17 +535,17 @@ ViewContact& ViewContactOfSdrPage::GetViewContact(sal_uInt32 nIndex) const
             }
             else
             {
-                return (ViewContact&)maViewContactOfMasterPage;
+                return const_cast<ViewContactOfMasterPage&>(maViewContactOfMasterPage);
             }
         }
-        case 4: return (ViewContact&)maViewContactOfOuterPageBorder;
-        case 5: return (ViewContact&)maViewContactOfInnerPageBorder;
-        case 6: return (ViewContact&)maViewContactOfGridBack;
-        case 7: return (ViewContact&)maViewContactOfHelplinesBack;
-        case 8: return (ViewContact&)maViewContactOfPageHierarchy;
-        case 9: return (ViewContact&)maViewContactOfGridFront;
-        case 10: case 11: return (ViewContact&)maViewContactOfHelplinesFront;
-        default: assert(false);return (ViewContact&)maViewContactOfHelplinesFront;
+        case 4: return const_cast<ViewContactOfOuterPageBorder&>(maViewContactOfOuterPageBorder);
+        case 5: return const_cast<ViewContactOfInnerPageBorder&>(maViewContactOfInnerPageBorder);
+        case 6: return const_cast<ViewContactOfGrid&>(maViewContactOfGridBack);
+        case 7: return const_cast<ViewContactOfHelplines&>(maViewContactOfHelplinesBack);
+        case 8: return const_cast<ViewContactOfPageHierarchy&>(maViewContactOfPageHierarchy);
+        case 9: return const_cast<ViewContactOfGrid&>(maViewContactOfGridFront);
+        case 10: case 11: return const_cast<ViewContactOfHelplines&>(maViewContactOfHelplinesFront);
+        default: assert(false);return const_cast<ViewContactOfHelplines&>(maViewContactOfHelplinesFront);
     }
 }
 
@@ -580,31 +580,31 @@ void ViewContactOfSdrPage::ActionChanged()
     maViewContactOfHelplinesFront.ActionChanged();
 }
 
-drawinglayer::primitive2d::Primitive2DSequence ViewContactOfSdrPage::createViewIndependentPrimitive2DSequence() const
+drawinglayer::primitive2d::Primitive2DContainer ViewContactOfSdrPage::createViewIndependentPrimitive2DSequence() const
 {
-    drawinglayer::primitive2d::Primitive2DSequence xRetval;
+    drawinglayer::primitive2d::Primitive2DContainer xRetval;
 
     // collect all sub-sequences including sub hierarchy.
-    drawinglayer::primitive2d::appendPrimitive2DSequenceToPrimitive2DSequence(xRetval, maViewContactOfPageBackground.getViewIndependentPrimitive2DSequence());
-    drawinglayer::primitive2d::appendPrimitive2DSequenceToPrimitive2DSequence(xRetval, maViewContactOfPageShadow.getViewIndependentPrimitive2DSequence());
-    drawinglayer::primitive2d::appendPrimitive2DSequenceToPrimitive2DSequence(xRetval, maViewContactOfPageFill.getViewIndependentPrimitive2DSequence());
+    xRetval.append(maViewContactOfPageBackground.getViewIndependentPrimitive2DContainer());
+    xRetval.append(maViewContactOfPageShadow.getViewIndependentPrimitive2DContainer());
+    xRetval.append(maViewContactOfPageFill.getViewIndependentPrimitive2DContainer());
 
     const SdrPage& rPage = GetSdrPage();
 
     if(rPage.TRG_HasMasterPage())
     {
-        drawinglayer::primitive2d::appendPrimitive2DSequenceToPrimitive2DSequence(xRetval,
-            rPage.TRG_GetMasterPageDescriptorViewContact().getViewIndependentPrimitive2DSequence());
+        xRetval.append(
+            rPage.TRG_GetMasterPageDescriptorViewContact().getViewIndependentPrimitive2DContainer());
     }
     else if(rPage.IsMasterPage())
     {
-        drawinglayer::primitive2d::appendPrimitive2DSequenceToPrimitive2DSequence(xRetval,
-            maViewContactOfMasterPage.getViewIndependentPrimitive2DSequence());
+        xRetval.append(
+            maViewContactOfMasterPage.getViewIndependentPrimitive2DContainer());
     }
 
-    drawinglayer::primitive2d::appendPrimitive2DSequenceToPrimitive2DSequence(xRetval, maViewContactOfOuterPageBorder.getViewIndependentPrimitive2DSequence());
-    drawinglayer::primitive2d::appendPrimitive2DSequenceToPrimitive2DSequence(xRetval, maViewContactOfInnerPageBorder.getViewIndependentPrimitive2DSequence());
-    drawinglayer::primitive2d::appendPrimitive2DSequenceToPrimitive2DSequence(xRetval, maViewContactOfPageHierarchy.getViewIndependentPrimitive2DSequence());
+    xRetval.append(maViewContactOfOuterPageBorder.getViewIndependentPrimitive2DContainer());
+    xRetval.append(maViewContactOfInnerPageBorder.getViewIndependentPrimitive2DContainer());
+    xRetval.append(maViewContactOfPageHierarchy.getViewIndependentPrimitive2DContainer());
 
     // Only add front versions of grid and helplines since no visibility test is done,
     // so adding the back incarnations is not necessary. This makes the Front
@@ -615,8 +615,8 @@ drawinglayer::primitive2d::Primitive2DSequence ViewContactOfSdrPage::createViewI
     // do not need to be called ATM. This may change later if grid or helpline info gets
     // model data (it should not). Keeping the lines commented to hold this hint.
 
-    // drawinglayer::primitive2d::appendPrimitive2DSequenceToPrimitive2DSequence(xRetval, maViewContactOfGridFront.getViewIndependentPrimitive2DSequence());
-    // drawinglayer::primitive2d::appendPrimitive2DSequenceToPrimitive2DSequence(xRetval, maViewContactOfHelplinesFront.getViewIndependentPrimitive2DSequence());
+    // drawinglayer::primitive2d::appendPrimitive2DSequenceToPrimitive2DSequence(xRetval, maViewContactOfGridFront.getViewIndependentPrimitive2DContainer());
+    // drawinglayer::primitive2d::appendPrimitive2DSequenceToPrimitive2DSequence(xRetval, maViewContactOfHelplinesFront.getViewIndependentPrimitive2DContainer());
 
     return xRetval;
 }
