@@ -17,6 +17,11 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
+#include <sal/config.h>
+
+#include <utility>
+
+#include <o3tl/make_unique.hxx>
 #include <sdr/properties/attributeproperties.hxx>
 #include <sdr/properties/itemsettools.hxx>
 #include <tools/debug.hxx>
@@ -108,17 +113,14 @@ namespace sdr
         }
 
         // create a new itemset
-        SfxItemSet* AttributeProperties::CreateObjectSpecificItemSet(SfxItemPool& rPool)
+        std::unique_ptr<SfxItemSet> AttributeProperties::CreateObjectSpecificItemSet(SfxItemPool& rPool)
         {
-            return new SfxItemSet(rPool,
+            return o3tl::make_unique<SfxItemSet>(rPool,
 
                 // ranges from SdrAttrObj
-                SDRATTR_START, SDRATTR_SHADOW_LAST,
+                svl::Items<SDRATTR_START, SDRATTR_SHADOW_LAST,
                 SDRATTR_MISC_FIRST, SDRATTR_MISC_LAST,
-                SDRATTR_TEXTDIRECTION, SDRATTR_TEXTDIRECTION,
-
-                // end
-                0, 0);
+                SDRATTR_TEXTDIRECTION, SDRATTR_TEXTDIRECTION>{});
         }
 
         AttributeProperties::AttributeProperties(SdrObject& rObj)
@@ -253,7 +255,6 @@ namespace sdr
                     // because this functionality is used by UNDO only. Thus
                     // objects and ItemSets would be moved back to their original
                     // pool before usage.
-                    SfxItemSet* pOldSet = mpItemSet;
                     SfxStyleSheet* pStySheet = GetStyleSheet();
 
                     if(pStySheet)
@@ -261,8 +262,9 @@ namespace sdr
                         ImpRemoveStyleSheet();
                     }
 
-                    mpItemSet = mpItemSet->Clone(false, pDestPool);
-                    SdrModel::MigrateItemSet(pOldSet, mpItemSet, pNewModel);
+                    auto pOldSet = std::move(mpItemSet);
+                    mpItemSet.reset(pOldSet->Clone(false, pDestPool));
+                    SdrModel::MigrateItemSet(pOldSet.get(), mpItemSet.get(), pNewModel);
 
                     // set stylesheet (if used)
                     if(pStySheet)
@@ -297,8 +299,6 @@ namespace sdr
                             ImpAddStyleSheet(pNewStyleSheet, true);
                         }
                     }
-
-                    delete pOldSet;
                 }
             }
         }
@@ -417,7 +417,7 @@ namespace sdr
                                 pItemSet = pItemSet->GetParent();
                             }
 
-                            SfxItemSet* pNewSet = CreateObjectSpecificItemSet(pNewModel->GetItemPool());
+                            auto pNewSet = CreateObjectSpecificItemSet(pNewModel->GetItemPool());
 
                             std::vector<const SfxItemSet*>::reverse_iterator riter;
                             for (riter = aSetList.rbegin(); riter != aSetList.rend(); ++riter)
@@ -451,12 +451,9 @@ namespace sdr
                                 {
                                     ImpRemoveStyleSheet();
                                 }
-
-                                delete mpItemSet;
-                                mpItemSet = nullptr;
                             }
 
-                            mpItemSet = pNewSet;
+                            mpItemSet = std::move(pNewSet);
                         }
                     }
                 }
@@ -472,46 +469,45 @@ namespace sdr
 
         void AttributeProperties::ForceStyleToHardAttributes()
         {
-            if(GetStyleSheet() && dynamic_cast<const SfxStyleSheet *>(mpStyleSheet) != nullptr)
+            if(!GetStyleSheet() || dynamic_cast<const SfxStyleSheet *>(mpStyleSheet) == nullptr)
+                return;
+
+            // prepare copied, new itemset, but WITHOUT parent
+            GetObjectItemSet();
+            SfxItemSet* pDestItemSet = new SfxItemSet(*mpItemSet);
+            pDestItemSet->SetParent(nullptr);
+
+            // prepare forgetting the current stylesheet like in RemoveStyleSheet()
+            EndListening(*mpStyleSheet);
+            EndListening(mpStyleSheet->GetPool());
+
+            // prepare the iter; use the mpObjectItemSet which may have less
+            // WhichIDs than the style.
+            SfxWhichIter aIter(*pDestItemSet);
+            sal_uInt16 nWhich(aIter.FirstWhich());
+            const SfxPoolItem *pItem = nullptr;
+
+            // now set all hard attributes of the current at the new itemset
+            while(nWhich)
             {
-                // prepare copied, new itemset, but WITHOUT parent
-                GetObjectItemSet();
-                SfxItemSet* pDestItemSet = new SfxItemSet(*mpItemSet);
-                pDestItemSet->SetParent(nullptr);
-
-                // prepare forgetting the current stylesheet like in RemoveStyleSheet()
-                EndListening(*mpStyleSheet);
-                EndListening(mpStyleSheet->GetPool());
-
-                // prepare the iter; use the mpObjectItemSet which may have less
-                // WhichIDs than the style.
-                SfxWhichIter aIter(*pDestItemSet);
-                sal_uInt16 nWhich(aIter.FirstWhich());
-                const SfxPoolItem *pItem = nullptr;
-
-                // now set all hard attributes of the current at the new itemset
-                while(nWhich)
+                // #i61284# use mpItemSet with parents, makes things easier and reduces to
+                // one loop
+                if(SfxItemState::SET == mpItemSet->GetItemState(nWhich, true, &pItem))
                 {
-                    // #i61284# use mpItemSet with parents, makes things easier and reduces to
-                    // one loop
-                    if(SfxItemState::SET == mpItemSet->GetItemState(nWhich, true, &pItem))
-                    {
-                        pDestItemSet->Put(*pItem);
-                    }
-
-                    nWhich = aIter.NextWhich();
+                    pDestItemSet->Put(*pItem);
                 }
 
-                // replace itemsets
-                delete mpItemSet;
-                mpItemSet = pDestItemSet;
-
-                // set necessary changes like in RemoveStyleSheet()
-                GetSdrObject().SetBoundRectDirty();
-                GetSdrObject().SetRectsDirty(true);
-
-                mpStyleSheet = nullptr;
+                nWhich = aIter.NextWhich();
             }
+
+            // replace itemsets
+            mpItemSet.reset(pDestItemSet);
+
+            // set necessary changes like in RemoveStyleSheet()
+            GetSdrObject().SetBoundRectDirty();
+            GetSdrObject().SetRectsDirty(true);
+
+            mpStyleSheet = nullptr;
         }
 
         void AttributeProperties::Notify(SfxBroadcaster& rBC, const SfxHint& rHint)
