@@ -16,11 +16,10 @@
  *   except in compliance with the License. You may obtain a copy of
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
-#include <sfx2/sidebar/ResourceDefinitions.hrc>
-#include <sfx2/sidebar/Theme.hxx>
 #include <sfx2/sidebar/ControlFactory.hxx>
-#include <GraphicPropertyPanel.hxx>
-#include <svx/dialogs.hrc>
+#include "GraphicPropertyPanel.hxx"
+#include <svx/strings.hrc>
+#include <svx/svxids.hrc>
 #include <svx/dialmgr.hxx>
 #include <vcl/field.hxx>
 #include <vcl/lstbox.hxx>
@@ -30,7 +29,6 @@
 
 using namespace css;
 using namespace css::uno;
-using ::sfx2::sidebar::Theme;
 
 
 // namespace open
@@ -38,7 +36,6 @@ using ::sfx2::sidebar::Theme;
 namespace svx { namespace sidebar {
 
 
-
 GraphicPropertyPanel::GraphicPropertyPanel(
     vcl::Window* pParent,
     const css::uno::Reference<css::frame::XFrame>& rxFrame,
@@ -52,12 +49,12 @@ GraphicPropertyPanel::GraphicPropertyPanel(
     maBlueControl(SID_ATTR_GRAF_BLUE, *pBindings, *this),
     maGammaControl(SID_ATTR_GRAF_GAMMA, *pBindings, *this),
     maModeControl(SID_ATTR_GRAF_MODE, *pBindings, *this),
-    mxFrame(rxFrame),
     mpBindings(pBindings)
 {
     get(mpMtrBrightness, "setbrightness");
     get(mpMtrContrast, "setcontrast");
     get(mpLBColorMode, "setcolormode");
+    mpLBColorMode->set_width_request(mpLBColorMode->get_preferred_size().Width());
     get(mpMtrTrans, "settransparency");
     get(mpMtrRed, "setred");
     get(mpMtrGreen, "setgreen");
@@ -66,43 +63,51 @@ GraphicPropertyPanel::GraphicPropertyPanel(
     Initialize();
 }
 
-
-
 GraphicPropertyPanel::~GraphicPropertyPanel()
 {
+    disposeOnce();
 }
 
+void GraphicPropertyPanel::dispose()
+{
+    mpMtrBrightness.clear();
+    mpMtrContrast.clear();
+    mpLBColorMode.clear();
+    mpMtrTrans.clear();
+    mpMtrRed.clear();
+    mpMtrGreen.clear();
+    mpMtrBlue.clear();
+    mpMtrGamma.clear();
+
+    maBrightControl.dispose();
+    maContrastControl.dispose();
+    maTransparenceControl.dispose();
+    maRedControl.dispose();
+    maGreenControl.dispose();
+    maBlueControl.dispose();
+    maGammaControl.dispose();
+    maModeControl.dispose();
+
+    PanelLayout::dispose();
+}
 
 
 void GraphicPropertyPanel::Initialize()
 {
     mpMtrBrightness->SetModifyHdl( LINK( this, GraphicPropertyPanel, ModifyBrightnessHdl ) );
-    mpMtrBrightness->SetAccessibleName(::rtl::OUString( "Brightness"));
     mpMtrContrast->SetModifyHdl( LINK( this, GraphicPropertyPanel, ModifyContrastHdl ) );
-    mpMtrContrast->SetAccessibleName(::rtl::OUString( "Contrast"));
     mpMtrTrans->SetModifyHdl( LINK( this, GraphicPropertyPanel, ModifyTransHdl ) );
-    mpMtrTrans->SetAccessibleName(::rtl::OUString( "Transparency"));
 
-    mpLBColorMode->InsertEntry(SVX_RESSTR(RID_SVXSTR_GRAFMODE_STANDARD));
-    mpLBColorMode->InsertEntry(SVX_RESSTR(RID_SVXSTR_GRAFMODE_GREYS));
-    mpLBColorMode->InsertEntry(SVX_RESSTR(RID_SVXSTR_GRAFMODE_MONO));
-    mpLBColorMode->InsertEntry(SVX_RESSTR(RID_SVXSTR_GRAFMODE_WATERMARK));
+    mpLBColorMode->InsertEntry(SvxResId(RID_SVXSTR_GRAFMODE_STANDARD));
+    mpLBColorMode->InsertEntry(SvxResId(RID_SVXSTR_GRAFMODE_GREYS));
+    mpLBColorMode->InsertEntry(SvxResId(RID_SVXSTR_GRAFMODE_MONO));
+    mpLBColorMode->InsertEntry(SvxResId(RID_SVXSTR_GRAFMODE_WATERMARK));
     mpLBColorMode->SetSelectHdl( LINK( this, GraphicPropertyPanel, ClickColorModeHdl ));
-    mpLBColorMode->SetAccessibleName(::rtl::OUString( "Color mode"));
 
     mpMtrRed->SetModifyHdl( LINK( this, GraphicPropertyPanel, RedHdl ) );
     mpMtrGreen->SetModifyHdl( LINK( this, GraphicPropertyPanel, GreenHdl ) );
     mpMtrBlue->SetModifyHdl( LINK( this, GraphicPropertyPanel, BlueHdl ) );
     mpMtrGamma->SetModifyHdl( LINK( this, GraphicPropertyPanel, GammaHdl ) );
-    mpMtrRed->SetAccessibleName(mpMtrRed->GetQuickHelpText());
-    mpMtrGreen->SetAccessibleName(mpMtrGreen->GetQuickHelpText());
-    mpMtrBlue->SetAccessibleName(mpMtrBlue->GetQuickHelpText());
-    mpMtrGamma->SetAccessibleName(::rtl::OUString( "Gamma value"));
-
-    mpMtrRed->SetAccessibleRelationLabeledBy(mpMtrRed);
-    mpMtrGreen->SetAccessibleRelationLabeledBy(mpMtrGreen);
-    mpMtrBlue->SetAccessibleRelationLabeledBy(mpMtrBlue);
-    mpMtrGamma->SetAccessibleRelationLabeledBy(mpMtrGamma);
 
     // Fix left position of some controls that may be wrong due to
     // rounding errors.
@@ -123,142 +128,109 @@ void GraphicPropertyPanel::Initialize()
 }
 
 
-
-
-
-
-IMPL_LINK( GraphicPropertyPanel, ModifyBrightnessHdl, void *, EMPTYARG )
+IMPL_LINK_NOARG( GraphicPropertyPanel, ModifyBrightnessHdl, Edit&, void )
 {
     const sal_Int16 nBright = mpMtrBrightness->GetValue();
     const SfxInt16Item aBrightItem( SID_ATTR_GRAF_LUMINANCE, nBright );
-    GetBindings()->GetDispatcher()->Execute(SID_ATTR_GRAF_LUMINANCE, SfxCallMode::RECORD, &aBrightItem, 0L);
-    return 0L;
+    GetBindings()->GetDispatcher()->ExecuteList(SID_ATTR_GRAF_LUMINANCE,
+            SfxCallMode::RECORD, { &aBrightItem });
 }
 
 
-
-IMPL_LINK( GraphicPropertyPanel, ModifyContrastHdl, void *, EMPTYARG )
+IMPL_LINK_NOARG( GraphicPropertyPanel, ModifyContrastHdl, Edit&, void )
 {
     const sal_Int16 nContrast = mpMtrContrast->GetValue();
     const SfxInt16Item aContrastItem( SID_ATTR_GRAF_CONTRAST, nContrast );
-    GetBindings()->GetDispatcher()->Execute(SID_ATTR_GRAF_CONTRAST, SfxCallMode::RECORD, &aContrastItem, 0L);
-    return 0L;
+    GetBindings()->GetDispatcher()->ExecuteList(SID_ATTR_GRAF_CONTRAST,
+            SfxCallMode::RECORD, { &aContrastItem });
 }
 
 
-
-IMPL_LINK( GraphicPropertyPanel, ModifyTransHdl, void *, EMPTYARG )
+IMPL_LINK_NOARG( GraphicPropertyPanel, ModifyTransHdl, Edit&, void )
 {
     const sal_Int16 nTrans = mpMtrTrans->GetValue();
     const SfxInt16Item aTransItem( SID_ATTR_GRAF_TRANSPARENCE, nTrans );
-    GetBindings()->GetDispatcher()->Execute(SID_ATTR_GRAF_TRANSPARENCE, SfxCallMode::RECORD, &aTransItem, 0L);
-    return 0L;
+    GetBindings()->GetDispatcher()->ExecuteList(SID_ATTR_GRAF_TRANSPARENCE,
+            SfxCallMode::RECORD, { &aTransItem });
 }
 
 
-
-IMPL_LINK_NOARG( GraphicPropertyPanel, ClickColorModeHdl )
+IMPL_LINK_NOARG( GraphicPropertyPanel, ClickColorModeHdl, ListBox&, void )
 {
-    const sal_Int16 nTrans = mpLBColorMode->GetSelectEntryPos();
+    const sal_Int16 nTrans = mpLBColorMode->GetSelectedEntryPos();
     const SfxInt16Item aTransItem( SID_ATTR_GRAF_MODE, nTrans );
-    GetBindings()->GetDispatcher()->Execute(SID_ATTR_GRAF_MODE, SfxCallMode::RECORD, &aTransItem, 0L);
-    return 0L;
+    GetBindings()->GetDispatcher()->ExecuteList(SID_ATTR_GRAF_MODE,
+            SfxCallMode::RECORD, { &aTransItem });
 }
 
 
-
-IMPL_LINK( GraphicPropertyPanel, RedHdl, void*, EMPTYARG )
+IMPL_LINK_NOARG( GraphicPropertyPanel, RedHdl, Edit&, void )
 {
     const sal_Int16 nRed = mpMtrRed->GetValue();
     const SfxInt16Item aRedItem( SID_ATTR_GRAF_RED, nRed );
-    GetBindings()->GetDispatcher()->Execute(SID_ATTR_GRAF_RED, SfxCallMode::RECORD, &aRedItem, 0L);
-    return 0L;
+    GetBindings()->GetDispatcher()->ExecuteList(SID_ATTR_GRAF_RED,
+            SfxCallMode::RECORD, { &aRedItem });
 }
 
 
-
-IMPL_LINK( GraphicPropertyPanel, GreenHdl, void*, EMPTYARG )
+IMPL_LINK_NOARG( GraphicPropertyPanel, GreenHdl, Edit&, void )
 {
     const sal_Int16 nGreen = mpMtrGreen->GetValue();
     const SfxInt16Item aGreenItem( SID_ATTR_GRAF_GREEN, nGreen );
-    GetBindings()->GetDispatcher()->Execute(SID_ATTR_GRAF_GREEN, SfxCallMode::RECORD, &aGreenItem, 0L);
-    return 0L;
+    GetBindings()->GetDispatcher()->ExecuteList(SID_ATTR_GRAF_GREEN,
+            SfxCallMode::RECORD, { &aGreenItem });
 }
 
 
-
-IMPL_LINK(GraphicPropertyPanel, BlueHdl, void *, EMPTYARG)
+IMPL_LINK_NOARG(GraphicPropertyPanel, BlueHdl, Edit&, void)
 {
     const sal_Int16 nBlue = mpMtrBlue->GetValue();
     const SfxInt16Item aBlueItem( SID_ATTR_GRAF_BLUE, nBlue );
-    GetBindings()->GetDispatcher()->Execute(SID_ATTR_GRAF_BLUE, SfxCallMode::RECORD, &aBlueItem, 0L);
-    return 0L;
+    GetBindings()->GetDispatcher()->ExecuteList(SID_ATTR_GRAF_BLUE,
+            SfxCallMode::RECORD, { &aBlueItem });
 }
 
 
-
-IMPL_LINK(GraphicPropertyPanel, GammaHdl, void *, EMPTYARG)
+IMPL_LINK_NOARG(GraphicPropertyPanel, GammaHdl, Edit&, void)
 {
     const sal_Int32 nGamma = mpMtrGamma->GetValue();
     const SfxInt32Item nGammaItem( SID_ATTR_GRAF_GAMMA, nGamma );
-    GetBindings()->GetDispatcher()->Execute(SID_ATTR_GRAF_GAMMA, SfxCallMode::RECORD, &nGammaItem, 0L);
-    return 0L;
+    GetBindings()->GetDispatcher()->ExecuteList(SID_ATTR_GRAF_GAMMA,
+            SfxCallMode::RECORD, { &nGammaItem });
 }
 
 
-
-void GraphicPropertyPanel::SetupIcons(void)
-{
-    if(Theme::GetBoolean(Theme::Bool_UseSymphonyIcons))
-    {
-        // todo
-    }
-    else
-    {
-        // todo
-    }
-}
-
-
-
-GraphicPropertyPanel* GraphicPropertyPanel::Create (
+VclPtr<vcl::Window> GraphicPropertyPanel::Create (
     vcl::Window* pParent,
     const css::uno::Reference<css::frame::XFrame>& rxFrame,
     SfxBindings* pBindings)
 {
-    if (pParent == NULL)
-        throw lang::IllegalArgumentException("no parent Window given to GraphicPropertyPanel::Create", NULL, 0);
+    if (pParent == nullptr)
+        throw lang::IllegalArgumentException("no parent Window given to GraphicPropertyPanel::Create", nullptr, 0);
     if ( ! rxFrame.is())
-        throw lang::IllegalArgumentException("no XFrame given to GraphicPropertyPanel::Create", NULL, 1);
-    if (pBindings == NULL)
-        throw lang::IllegalArgumentException("no SfxBindings given to GraphicPropertyPanel::Create", NULL, 2);
+        throw lang::IllegalArgumentException("no XFrame given to GraphicPropertyPanel::Create", nullptr, 1);
+    if (pBindings == nullptr)
+        throw lang::IllegalArgumentException("no SfxBindings given to GraphicPropertyPanel::Create", nullptr, 2);
 
-    return new GraphicPropertyPanel(
-        pParent,
-        rxFrame,
-        pBindings);
+    return VclPtr<GraphicPropertyPanel>::Create(
+                pParent,
+                rxFrame,
+                pBindings);
 }
 
 
-
 void GraphicPropertyPanel::DataChanged(
-    const DataChangedEvent& rEvent)
+    const DataChangedEvent& /*rEvent*/)
 {
-    (void)rEvent;
-
-    SetupIcons();
 }
 
 
-
 void GraphicPropertyPanel::NotifyItemUpdate(
     sal_uInt16 nSID,
     SfxItemState eState,
     const SfxPoolItem* pState,
-    const bool bIsEnabled)
+    const bool)
 {
-    (void)bIsEnabled;
-
     switch( nSID )
     {
         case SID_ATTR_GRAF_LUMINANCE:
@@ -457,14 +429,8 @@ void GraphicPropertyPanel::NotifyItemUpdate(
 }
 
 
-
-
-
-
-
-
 // namespace close
 
-}} // end of namespace ::svx::sidebar
+}} // end of namespace svx::sidebar
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
