@@ -7,7 +7,9 @@
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 */
 
+#include <memory>
 #include <svdobjuserdatalist.hxx>
+#include <vcl/outdev.hxx>
 
 SdrObjUserDataList::SdrObjUserDataList() {}
 SdrObjUserDataList::~SdrObjUserDataList() {}
@@ -17,14 +19,14 @@ size_t SdrObjUserDataList::GetUserDataCount() const
     return maList.size();
 }
 
-SdrObjUserData* SdrObjUserDataList::GetUserData(size_t nNum)
+SdrObjUserData& SdrObjUserDataList::GetUserData(size_t nNum)
 {
-    return &maList.at(nNum);
+    return *maList.at(nNum).get();
 }
 
 void SdrObjUserDataList::AppendUserData(SdrObjUserData* pData)
 {
-    maList.push_back(pData);
+    maList.push_back(std::unique_ptr<SdrObjUserData>(pData));
 }
 
 void SdrObjUserDataList::DeleteUserData(size_t nNum)
