@@ -195,7 +195,7 @@ namespace
 
     IMPL_LINK(impTextBreakupHandler, decompositionPathTextPrimitive, DrawPortionInfo*, pInfo, void)
     {
-        maPathTextPortions.push_back(impPathTextPortion(*pInfo));
+        maPathTextPortions.emplace_back(*pInfo);
     }
 } // end of anonymous namespace
 
@@ -234,7 +234,7 @@ namespace
 
             if(mxBreak.is())
             {
-                sal_Int32 nDone(0L);
+                sal_Int32 nDone(0);
                 nNextGlyphLen = mxBreak->nextCharacters(pCandidate->getText(), nPosition,
                     rFontLocale, CharacterIteratorMode::SKIPCELL, 1, nDone) - nPosition;
             }
@@ -260,7 +260,7 @@ namespace
         {
             // prepare polygon geometry, take into account as many parameters as possible
             basegfx::B2DPolygon aPolygonCandidate(rPolygonCandidate);
-            const double fPolyLength(basegfx::tools::getLength(aPolygonCandidate));
+            const double fPolyLength(basegfx::utils::getLength(aPolygonCandidate));
             double fPolyEnd(fPolyLength);
             double fPolyStart(0.0);
             double fAutosizeScaleFactor(1.0);
@@ -332,9 +332,9 @@ namespace
             }
 
             // handle text portions for this paragraph
-            for(sal_uInt32 a(0L); a < rTextPortions.size() && fPolyStart < fPolyEnd; a++)
+            for(auto a = rTextPortions.begin(); a != rTextPortions.end() && fPolyStart < fPolyEnd; ++a)
             {
-                const impPathTextPortion* pCandidate = rTextPortions[a];
+                const impPathTextPortion* pCandidate = *a;
                 basegfx::B2DVector aFontScaling;
 
                 if(pCandidate && pCandidate->getTextLength())
@@ -365,7 +365,7 @@ namespace
 
                         // create transformation
                         basegfx::B2DHomMatrix aNewTransformA, aNewTransformB, aNewShadowTransform;
-                        basegfx::B2DPoint aStartPos(basegfx::tools::getPositionAbsolute(aPolygonCandidate, fPolyStart, fPolyLength));
+                        basegfx::B2DPoint aStartPos(basegfx::utils::getPositionAbsolute(aPolygonCandidate, fPolyStart, fPolyLength));
                         basegfx::B2DPoint aEndPos(aStartPos);
 
                         // add font scaling
@@ -404,7 +404,7 @@ namespace
                         {
                             case XFormTextStyle::Rotate :
                             {
-                                aEndPos = basegfx::tools::getPositionAbsolute(aPolygonCandidate, fPolyStart + fPortionLength, fPolyLength);
+                                aEndPos = basegfx::utils::getPositionAbsolute(aPolygonCandidate, fPolyStart + fPortionLength, fPolyLength);
                                 const basegfx::B2DVector aDirection(aEndPos - aStartPos);
                                 aNewTransformB.rotate(atan2(aDirection.getY(), aDirection.getX()));
                                 aNewTransformB.translate(aStartPos.getX(), aStartPos.getY());
@@ -419,7 +419,7 @@ namespace
                             }
                             case XFormTextStyle::SlantX :
                             {
-                                aEndPos = basegfx::tools::getPositionAbsolute(aPolygonCandidate, fPolyStart + fPortionLength, fPolyLength);
+                                aEndPos = basegfx::utils::getPositionAbsolute(aPolygonCandidate, fPolyStart + fPortionLength, fPolyLength);
                                 const basegfx::B2DVector aDirection(aEndPos - aStartPos);
                                 const double fShearValue(atan2(aDirection.getY(), aDirection.getX()));
                                 const double fSin(sin(fShearValue));
@@ -437,7 +437,7 @@ namespace
                             }
                             case XFormTextStyle::SlantY :
                             {
-                                aEndPos = basegfx::tools::getPositionAbsolute(aPolygonCandidate, fPolyStart + fPortionLength, fPolyLength);
+                                aEndPos = basegfx::utils::getPositionAbsolute(aPolygonCandidate, fPolyStart + fPortionLength, fPolyLength);
                                 const basegfx::B2DVector aDirection(aEndPos - aStartPos);
                                 const double fShearValue(atan2(aDirection.getY(), aDirection.getX()));
                                 const double fCos(cos(fShearValue));
@@ -462,7 +462,7 @@ namespace
                         {
                             if(aEndPos.equal(aStartPos))
                             {
-                                aEndPos = basegfx::tools::getPositionAbsolute(aPolygonCandidate, fPolyStart + fPortionLength, fPolyLength);
+                                aEndPos = basegfx::utils::getPositionAbsolute(aPolygonCandidate, fPolyStart + fPortionLength, fPolyLength);
                             }
 
                             // use back vector (aStartPos - aEndPos) here to get mirrored perpendicular as in old stuff
@@ -573,7 +573,7 @@ namespace
             basegfx::B2DPolyPolygon aB2DPolyPolygon = *aPolygon;
             aB2DPolyPolygon.transform(rTransform);
 
-            for(sal_uInt32 a(0L); a < aB2DPolyPolygon.count(); a++)
+            for(sal_uInt32 a(0); a < aB2DPolyPolygon.count(); a++)
             {
                 // create one primitive per polygon
                 drawinglayer::primitive2d::PolygonStrokePrimitive2D* pNew =
@@ -621,7 +621,7 @@ namespace
                             // create UnifiedTransparencePrimitive2D
                             drawinglayer::primitive2d::Primitive2DContainer aStrokePrimitiveSequence(nStrokeCount);
 
-                            for(sal_uInt32 b(0L); b < nStrokeCount; b++)
+                            for(sal_uInt32 b(0); b < nStrokeCount; b++)
                             {
                                 aStrokePrimitiveSequence[b] = drawinglayer::primitive2d::Primitive2DReference(aStrokePrimitives[b]);
                             }
@@ -648,7 +648,7 @@ namespace
         {
             drawinglayer::primitive2d::Primitive2DContainer aRetval(nNewCount);
 
-            for(sal_uInt32 a(0L); a < nNewCount; a++)
+            for(sal_uInt32 a(0); a < nNewCount; a++)
             {
                 aRetval[a] = drawinglayer::primitive2d::Primitive2DReference(aNewPrimitives[a]);
             }
@@ -712,7 +712,7 @@ void SdrTextObj::impDecomposePathTextPrimitive(
                 aShadowDecomposition);
             sal_uInt32 a;
 
-            for(a = 0L; a < nLoopCount; a++)
+            for(a = 0; a < nLoopCount; a++)
             {
                 // filter text portions for this paragraph
                 ::std::vector< const impPathTextPortion* > aParagraphTextPortions;
@@ -740,7 +740,7 @@ void SdrTextObj::impDecomposePathTextPrimitive(
                 // add shadow primitives to decomposition
                 aRetvalA.resize(nShadowCount);
 
-                for(a = 0L; a < nShadowCount; a++)
+                for(a = 0; a < nShadowCount; a++)
                 {
                     aRetvalA[a] = drawinglayer::primitive2d::Primitive2DReference(aShadowDecomposition[a]);
                 }
@@ -763,7 +763,7 @@ void SdrTextObj::impDecomposePathTextPrimitive(
                 // add normal primitives to decomposition
                 aRetvalB.resize(nRegularCount);
 
-                for(a = 0L; a < nRegularCount; a++)
+                for(a = 0; a < nRegularCount; a++)
                 {
                     aRetvalB[a] = drawinglayer::primitive2d::Primitive2DReference(aRegularDecomposition[a]);
                 }
