@@ -18,7 +18,8 @@
  */
 
 
-#include "svx/XPropertyTable.hxx"
+#include <memory>
+#include <svx/XPropertyTable.hxx>
 #include <com/sun/star/drawing/PolyPolygonBezierCoords.hpp>
 #include <com/sun/star/drawing/LineDash.hpp>
 #include <com/sun/star/awt/Gradient.hpp>
@@ -27,17 +28,16 @@
 #include <com/sun/star/container/XNameContainer.hpp>
 #include <o3tl/any.hxx>
 #include <o3tl/make_unique.hxx>
-#include <osl/mutex.hxx>
 #include <vcl/svapp.hxx>
 
 #include <cppuhelper/implbase.hxx>
 #include <cppuhelper/supportsservice.hxx>
 #include <svx/xdef.hxx>
 
-#include "svx/unoapi.hxx"
+#include <svx/unoapi.hxx>
 #include <editeng/unoprnms.hxx>
 #include <basegfx/polygon/b2dpolygon.hxx>
-#include <basegfx/tools/unotools.hxx>
+#include <basegfx/utils/unotools.hxx>
 
 using namespace com::sun::star;
 using namespace ::cppu;
@@ -53,28 +53,29 @@ private:
 public:
     SvxUnoXPropertyTable( sal_Int16 nWhich, XPropertyList* pList ) throw();
 
-    virtual ~SvxUnoXPropertyTable() throw() override;
-
-    virtual uno::Any getAny( const XPropertyEntry* pEntry ) const throw(uno::RuntimeException) = 0;
-    virtual std::unique_ptr<XPropertyEntry> createEntry(const OUString& rName, const uno::Any& rAny) const throw(uno::RuntimeException, lang::IllegalArgumentException) = 0;
+    /// @throws uno::RuntimeException
+    virtual uno::Any getAny( const XPropertyEntry* pEntry ) const = 0;
+    /// @throws uno::RuntimeException
+    /// @throws lang::IllegalArgumentException
+    virtual std::unique_ptr<XPropertyEntry> createEntry(const OUString& rName, const uno::Any& rAny) const = 0;
 
     // XServiceInfo
-    virtual sal_Bool SAL_CALL supportsService( const  OUString& ServiceName ) throw( uno::RuntimeException, std::exception) override;
+    virtual sal_Bool SAL_CALL supportsService( const  OUString& ServiceName ) override;
 
     // XNameContainer
-    virtual void SAL_CALL insertByName( const  OUString& aName, const  uno::Any& aElement ) throw( lang::IllegalArgumentException, container::ElementExistException, lang::WrappedTargetException, uno::RuntimeException, std::exception) override;
-    virtual void SAL_CALL removeByName( const  OUString& Name ) throw( container::NoSuchElementException, lang::WrappedTargetException, uno::RuntimeException, std::exception) override;
+    virtual void SAL_CALL insertByName( const  OUString& aName, const  uno::Any& aElement ) override;
+    virtual void SAL_CALL removeByName( const  OUString& Name ) override;
 
     // XNameReplace
-    virtual void SAL_CALL replaceByName( const  OUString& aName, const  uno::Any& aElement ) throw( lang::IllegalArgumentException, container::NoSuchElementException, lang::WrappedTargetException, uno::RuntimeException, std::exception) override;
+    virtual void SAL_CALL replaceByName( const  OUString& aName, const  uno::Any& aElement ) override;
 
     // XNameAccess
-    virtual uno::Any SAL_CALL getByName( const  OUString& aName ) throw( container::NoSuchElementException, lang::WrappedTargetException, uno::RuntimeException, std::exception) override;
-    virtual uno::Sequence<  OUString > SAL_CALL getElementNames(  ) throw( uno::RuntimeException, std::exception) override;
-    virtual sal_Bool SAL_CALL hasByName( const  OUString& aName ) throw( uno::RuntimeException, std::exception) override;
+    virtual uno::Any SAL_CALL getByName( const  OUString& aName ) override;
+    virtual uno::Sequence<  OUString > SAL_CALL getElementNames(  ) override;
+    virtual sal_Bool SAL_CALL hasByName( const  OUString& aName ) override;
 
     // XElementAccess
-    virtual sal_Bool SAL_CALL hasElements(  ) throw( uno::RuntimeException, std::exception) override;
+    virtual sal_Bool SAL_CALL hasElements(  ) override;
 };
 
 SvxUnoXPropertyTable::SvxUnoXPropertyTable( sal_Int16 nWhich, XPropertyList* pList ) throw()
@@ -82,10 +83,6 @@ SvxUnoXPropertyTable::SvxUnoXPropertyTable( sal_Int16 nWhich, XPropertyList* pLi
 {
 }
 
-SvxUnoXPropertyTable::~SvxUnoXPropertyTable() throw()
-{
-}
-
 const XPropertyEntry* SvxUnoXPropertyTable::get(long index) const
 {
     if( mpList )
@@ -96,14 +93,12 @@ const XPropertyEntry* SvxUnoXPropertyTable::get(long index) const
 
 // XServiceInfo
 sal_Bool SAL_CALL SvxUnoXPropertyTable::supportsService( const  OUString& ServiceName )
-    throw( uno::RuntimeException, std::exception)
 {
     return cppu::supportsService(this, ServiceName);
 }
 
 // XNameContainer
 void SAL_CALL SvxUnoXPropertyTable::insertByName( const  OUString& aName, const  uno::Any& aElement )
-    throw( lang::IllegalArgumentException, container::ElementExistException, lang::WrappedTargetException, uno::RuntimeException, std::exception)
 {
     SolarMutexGuard aGuard;
 
@@ -123,7 +118,6 @@ void SAL_CALL SvxUnoXPropertyTable::insertByName( const  OUString& aName, const
 }
 
 void SAL_CALL SvxUnoXPropertyTable::removeByName( const  OUString& Name )
-    throw( container::NoSuchElementException, lang::WrappedTargetException, uno::RuntimeException, std::exception)
 {
     SolarMutexGuard aGuard;
 
@@ -134,7 +128,7 @@ void SAL_CALL SvxUnoXPropertyTable::removeByName( const  OUString& Name )
     for( i = 0; i < nCount; i++ )
     {
         const XPropertyEntry* pEntry = get(i);
-        if (pEntry && aInternalName.equals(pEntry->GetName()))
+        if (pEntry && aInternalName == pEntry->GetName())
         {
             mpList->Remove(i);
             return;
@@ -146,7 +140,6 @@ void SAL_CALL SvxUnoXPropertyTable::removeByName( const  OUString& Name )
 
 // XNameReplace
 void SAL_CALL SvxUnoXPropertyTable::replaceByName( const  OUString& aName, const  uno::Any& aElement )
-    throw( lang::IllegalArgumentException, container::NoSuchElementException, lang::WrappedTargetException, uno::RuntimeException, std::exception)
 {
     SolarMutexGuard aGuard;
 
@@ -157,7 +150,7 @@ void SAL_CALL SvxUnoXPropertyTable::replaceByName( const  OUString& aName, const
     for( i = 0; i < nCount; i++ )
     {
         const XPropertyEntry* pEntry = get(i);
-        if (pEntry && aInternalName.equals(pEntry->GetName()))
+        if (pEntry && aInternalName == pEntry->GetName())
         {
             std::unique_ptr<XPropertyEntry> pNewEntry(createEntry(aInternalName, aElement));
             if (!pNewEntry)
@@ -173,7 +166,6 @@ void SAL_CALL SvxUnoXPropertyTable::replaceByName( const  OUString& aName, const
 
 // XNameAccess
 uno::Any SAL_CALL SvxUnoXPropertyTable::getByName( const  OUString& aName )
-    throw( container::NoSuchElementException, lang::WrappedTargetException, uno::RuntimeException, std::exception)
 {
     SolarMutexGuard aGuard;
 
@@ -185,7 +177,7 @@ uno::Any SAL_CALL SvxUnoXPropertyTable::getByName( const  OUString& aName )
     {
         const XPropertyEntry* pEntry = get(i);
 
-        if (pEntry && aInternalName.equals(pEntry->GetName()))
+        if (pEntry && aInternalName == pEntry->GetName())
             return getAny( pEntry );
     }
 
@@ -193,7 +185,6 @@ uno::Any SAL_CALL SvxUnoXPropertyTable::getByName( const  OUString& aName )
 }
 
 uno::Sequence<  OUString > SAL_CALL SvxUnoXPropertyTable::getElementNames()
-    throw( uno::RuntimeException, std::exception)
 {
     SolarMutexGuard aGuard;
 
@@ -213,7 +204,6 @@ uno::Sequence<  OUString > SAL_CALL SvxUnoXPropertyTable::getElementNames()
 }
 
 sal_Bool SAL_CALL SvxUnoXPropertyTable::hasByName( const  OUString& aName )
-    throw( uno::RuntimeException, std::exception)
 {
     SolarMutexGuard aGuard;
 
@@ -224,7 +214,7 @@ sal_Bool SAL_CALL SvxUnoXPropertyTable::hasByName( const  OUString& aName )
     for( i = 0; i < nCount; i++ )
     {
         const XPropertyEntry* pEntry = get(i);
-        if (pEntry && aInternalName.equals(pEntry->GetName()))
+        if (pEntry && aInternalName == pEntry->GetName())
             return true;
     }
 
@@ -233,7 +223,6 @@ sal_Bool SAL_CALL SvxUnoXPropertyTable::hasByName( const  OUString& aName )
 
 // XElementAccess
 sal_Bool SAL_CALL SvxUnoXPropertyTable::hasElements(  )
-    throw( uno::RuntimeException, std::exception)
 {
     SolarMutexGuard aGuard;
 
@@ -248,14 +237,14 @@ public:
 
     // SvxUnoXPropertyTable
     virtual uno::Any getAny( const XPropertyEntry* pEntry ) const throw() override;
-    virtual std::unique_ptr<XPropertyEntry> createEntry(const OUString& rName, const uno::Any& rAny) const throw() override;
+    virtual std::unique_ptr<XPropertyEntry> createEntry(const OUString& rName, const uno::Any& rAny) const override;
 
     // XElementAccess
-    virtual uno::Type SAL_CALL getElementType() throw( uno::RuntimeException, std::exception ) override;
+    virtual uno::Type SAL_CALL getElementType() override;
 
     // XServiceInfo
-    virtual OUString SAL_CALL getImplementationName(  ) throw( uno::RuntimeException, std::exception ) override;
-    virtual uno::Sequence<  OUString > SAL_CALL getSupportedServiceNames(  ) throw( uno::RuntimeException, std::exception) override;
+    virtual OUString SAL_CALL getImplementationName(  ) override;
+    virtual uno::Sequence<  OUString > SAL_CALL getSupportedServiceNames(  ) override;
 };
 
 uno::Reference< uno::XInterface > SAL_CALL SvxUnoXColorTable_createInstance( XPropertyList* pList ) throw()
@@ -269,7 +258,7 @@ uno::Any SvxUnoXColorTable::getAny( const XPropertyEntry* pEntry ) const throw()
     return uno::Any( (sal_Int32)static_cast<const XColorEntry*>(pEntry)->GetColor().GetColor() );
 }
 
-std::unique_ptr<XPropertyEntry> SvxUnoXColorTable::createEntry(const OUString& rName, const uno::Any& rAny) const throw()
+std::unique_ptr<XPropertyEntry> SvxUnoXColorTable::createEntry(const OUString& rName, const uno::Any& rAny) const
 {
     sal_Int32 nColor = 0;
     if( !(rAny >>= nColor) )
@@ -281,18 +270,17 @@ std::unique_ptr<XPropertyEntry> SvxUnoXColorTable::createEntry(const OUString& r
 
 // XElementAccess
 uno::Type SAL_CALL SvxUnoXColorTable::getElementType()
-    throw( uno::RuntimeException, std::exception )
 {
     return ::cppu::UnoType<sal_Int32>::get();
 }
 
 // XServiceInfo
-OUString SAL_CALL SvxUnoXColorTable::getImplementationName(  ) throw( uno::RuntimeException, std::exception )
+OUString SAL_CALL SvxUnoXColorTable::getImplementationName(  )
 {
     return OUString( "SvxUnoXColorTable" );
 }
 
-uno::Sequence<  OUString > SAL_CALL SvxUnoXColorTable::getSupportedServiceNames(  ) throw( uno::RuntimeException, std::exception)
+uno::Sequence<  OUString > SAL_CALL SvxUnoXColorTable::getSupportedServiceNames(  )
 {
     const OUString aServiceName( "com.sun.star.drawing.ColorTable" );
     uno::Sequence< OUString > aServices( &aServiceName, 1 );
@@ -307,14 +295,14 @@ public:
 
     // SvxUnoXPropertyTable
     virtual uno::Any getAny( const XPropertyEntry* pEntry ) const throw() override;
-    virtual std::unique_ptr<XPropertyEntry> createEntry(const OUString& rName, const uno::Any& rAny) const throw(lang::IllegalArgumentException) override;
+    virtual std::unique_ptr<XPropertyEntry> createEntry(const OUString& rName, const uno::Any& rAny) const override;
 
     // XElementAccess
-    virtual uno::Type SAL_CALL getElementType() throw( uno::RuntimeException, std::exception ) override;
+    virtual uno::Type SAL_CALL getElementType() override;
 
     // XServiceInfo
-    virtual OUString SAL_CALL getImplementationName(  ) throw( uno::RuntimeException, std::exception ) override;
-    virtual uno::Sequence<  OUString > SAL_CALL getSupportedServiceNames(  ) throw( uno::RuntimeException, std::exception) override;
+    virtual OUString SAL_CALL getImplementationName(  ) override;
+    virtual uno::Sequence<  OUString > SAL_CALL getSupportedServiceNames(  ) override;
 };
 
 uno::Reference< uno::XInterface > SAL_CALL SvxUnoXLineEndTable_createInstance( XPropertyList* pTable ) throw()
@@ -331,7 +319,7 @@ uno::Any SvxUnoXLineEndTable::getAny( const XPropertyEntry* pEntry ) const throw
     return uno::Any(aBezier);
 }
 
-std::unique_ptr<XPropertyEntry> SvxUnoXLineEndTable::createEntry(const OUString& rName, const uno::Any& rAny) const throw(lang::IllegalArgumentException)
+std::unique_ptr<XPropertyEntry> SvxUnoXLineEndTable::createEntry(const OUString& rName, const uno::Any& rAny) const
 {
     auto pCoords = o3tl::tryAccess<drawing::PolyPolygonBezierCoords>(rAny);
     if( !pCoords )
@@ -349,18 +337,17 @@ std::unique_ptr<XPropertyEntry> SvxUnoXLineEndTable::createEntry(const OUString&
 
 // XElementAccess
 uno::Type SAL_CALL SvxUnoXLineEndTable::getElementType()
-    throw( uno::RuntimeException, std::exception )
 {
     return cppu::UnoType<drawing::PolyPolygonBezierCoords>::get();
 }
 
 // XServiceInfo
-OUString SAL_CALL SvxUnoXLineEndTable::getImplementationName(  ) throw( uno::RuntimeException, std::exception )
+OUString SAL_CALL SvxUnoXLineEndTable::getImplementationName(  )
 {
     return OUString( "SvxUnoXLineEndTable" );
 }
 
-uno::Sequence<  OUString > SAL_CALL SvxUnoXLineEndTable::getSupportedServiceNames(  ) throw( uno::RuntimeException, std::exception)
+uno::Sequence<  OUString > SAL_CALL SvxUnoXLineEndTable::getSupportedServiceNames(  )
 {
     const OUString aServiceName( "com.sun.star.drawing.LineEndTable" );
     uno::Sequence< OUString > aServices( &aServiceName, 1 );
@@ -375,14 +362,14 @@ public:
 
     // SvxUnoXPropertyTable
     virtual uno::Any getAny( const XPropertyEntry* pEntry ) const throw() override;
-    virtual std::unique_ptr<XPropertyEntry> createEntry(const OUString& rName, const uno::Any& rAny) const throw() override;
+    virtual std::unique_ptr<XPropertyEntry> createEntry(const OUString& rName, const uno::Any& rAny) const override;
 
     // XElementAccess
-    virtual uno::Type SAL_CALL getElementType() throw( uno::RuntimeException, std::exception ) override;
+    virtual uno::Type SAL_CALL getElementType() override;
 
     // XServiceInfo
-    virtual OUString SAL_CALL getImplementationName(  ) throw( uno::RuntimeException, std::exception ) override;
-    virtual uno::Sequence<  OUString > SAL_CALL getSupportedServiceNames(  ) throw( uno::RuntimeException, std::exception) override;
+    virtual OUString SAL_CALL getImplementationName(  ) override;
+    virtual uno::Sequence<  OUString > SAL_CALL getSupportedServiceNames(  ) override;
 };
 
 uno::Reference< uno::XInterface > SAL_CALL SvxUnoXDashTable_createInstance( XPropertyList* pTable ) throw()
@@ -407,7 +394,7 @@ uno::Any SvxUnoXDashTable::getAny( const XPropertyEntry* pEntry ) const throw()
     return uno::Any(aLineDash);
 }
 
-std::unique_ptr<XPropertyEntry> SvxUnoXDashTable::createEntry(const OUString& rName, const uno::Any& rAny) const throw()
+std::unique_ptr<XPropertyEntry> SvxUnoXDashTable::createEntry(const OUString& rName, const uno::Any& rAny) const
 {
     drawing::LineDash aLineDash;
     if(!(rAny >>= aLineDash))
@@ -427,18 +414,17 @@ std::unique_ptr<XPropertyEntry> SvxUnoXDashTable::createEntry(const OUString& rN
 
 // XElementAccess
 uno::Type SAL_CALL SvxUnoXDashTable::getElementType()
-    throw( uno::RuntimeException, std::exception )
 {
     return cppu::UnoType<drawing::LineDash>::get();
 }
 
 // XServiceInfo
-OUString SAL_CALL SvxUnoXDashTable::getImplementationName(  ) throw( uno::RuntimeException, std::exception )
+OUString SAL_CALL SvxUnoXDashTable::getImplementationName(  )
 {
     return OUString( "SvxUnoXDashTable" );
 }
 
-uno::Sequence<  OUString > SAL_CALL SvxUnoXDashTable::getSupportedServiceNames(  ) throw( uno::RuntimeException, std::exception)
+uno::Sequence<  OUString > SAL_CALL SvxUnoXDashTable::getSupportedServiceNames(  )
 {
     const OUString aServiceName( "com.sun.star.drawing.DashTable" );
     uno::Sequence< OUString > aServices( &aServiceName, 1 );
@@ -453,14 +439,14 @@ public:
 
     // SvxUnoXPropertyTable
     virtual uno::Any getAny( const XPropertyEntry* pEntry ) const throw() override;
-    virtual std::unique_ptr<XPropertyEntry> createEntry(const OUString& rName, const uno::Any& rAny) const throw() override;
+    virtual std::unique_ptr<XPropertyEntry> createEntry(const OUString& rName, const uno::Any& rAny) const override;
 
     // XElementAccess
-    virtual uno::Type SAL_CALL getElementType() throw( uno::RuntimeException, std::exception ) override;
+    virtual uno::Type SAL_CALL getElementType() override;
 
     // XServiceInfo
-    virtual OUString SAL_CALL getImplementationName(  ) throw( uno::RuntimeException, std::exception ) override;
-    virtual uno::Sequence<  OUString > SAL_CALL getSupportedServiceNames(  ) throw( uno::RuntimeException, std::exception) override;
+    virtual OUString SAL_CALL getImplementationName(  ) override;
+    virtual uno::Sequence<  OUString > SAL_CALL getSupportedServiceNames(  ) override;
 };
 
 uno::Reference< uno::XInterface > SAL_CALL SvxUnoXHatchTable_createInstance( XPropertyList* pTable ) throw()
@@ -483,7 +469,7 @@ uno::Any SvxUnoXHatchTable::getAny( const XPropertyEntry* pEntry ) const throw()
     return uno::Any(aUnoHatch);
 }
 
-std::unique_ptr<XPropertyEntry> SvxUnoXHatchTable::createEntry(const OUString& rName, const uno::Any& rAny) const throw()
+std::unique_ptr<XPropertyEntry> SvxUnoXHatchTable::createEntry(const OUString& rName, const uno::Any& rAny) const
 {
     drawing::Hatch aUnoHatch;
     if(!(rAny >>= aUnoHatch))
@@ -500,18 +486,17 @@ std::unique_ptr<XPropertyEntry> SvxUnoXHatchTable::createEntry(const OUString& r
 
 // XElementAccess
 uno::Type SAL_CALL SvxUnoXHatchTable::getElementType()
-    throw( uno::RuntimeException, std::exception )
 {
     return cppu::UnoType<drawing::Hatch>::get();
 }
 
 // XServiceInfo
-OUString SAL_CALL SvxUnoXHatchTable::getImplementationName(  ) throw( uno::RuntimeException, std::exception )
+OUString SAL_CALL SvxUnoXHatchTable::getImplementationName(  )
 {
     return OUString( "SvxUnoXHatchTable" );
 }
 
-uno::Sequence<  OUString > SAL_CALL SvxUnoXHatchTable::getSupportedServiceNames(  ) throw( uno::RuntimeException, std::exception)
+uno::Sequence<  OUString > SAL_CALL SvxUnoXHatchTable::getSupportedServiceNames(  )
 {
     const OUString aServiceName( "com.sun.star.drawing.HatchTable" );
     uno::Sequence< OUString > aServices( &aServiceName, 1 );
@@ -526,14 +511,14 @@ public:
 
     // SvxUnoXPropertyTable
     virtual uno::Any getAny( const XPropertyEntry* pEntry ) const throw() override;
-    virtual std::unique_ptr<XPropertyEntry> createEntry(const OUString& rName, const uno::Any& rAny) const throw() override;
+    virtual std::unique_ptr<XPropertyEntry> createEntry(const OUString& rName, const uno::Any& rAny) const override;
 
     // XElementAccess
-    virtual uno::Type SAL_CALL getElementType() throw( uno::RuntimeException, std::exception ) override;
+    virtual uno::Type SAL_CALL getElementType() override;
 
     // XServiceInfo
-    virtual OUString SAL_CALL getImplementationName(  ) throw( uno::RuntimeException, std::exception ) override;
-    virtual uno::Sequence<  OUString > SAL_CALL getSupportedServiceNames(  ) throw( uno::RuntimeException, std::exception) override;
+    virtual OUString SAL_CALL getImplementationName(  ) override;
+    virtual uno::Sequence<  OUString > SAL_CALL getSupportedServiceNames(  ) override;
 };
 
 uno::Reference< uno::XInterface > SAL_CALL SvxUnoXGradientTable_createInstance( XPropertyList* pTable ) throw()
@@ -561,7 +546,7 @@ uno::Any SvxUnoXGradientTable::getAny( const XPropertyEntry* pEntry ) const thro
     return uno::Any(aGradient);
 }
 
-std::unique_ptr<XPropertyEntry> SvxUnoXGradientTable::createEntry(const OUString& rName, const uno::Any& rAny) const throw()
+std::unique_ptr<XPropertyEntry> SvxUnoXGradientTable::createEntry(const OUString& rName, const uno::Any& rAny) const
 {
     awt::Gradient aGradient;
     if(!(rAny >>= aGradient))
@@ -585,18 +570,17 @@ std::unique_ptr<XPropertyEntry> SvxUnoXGradientTable::createEntry(const OUString
 
 // XElementAccess
 uno::Type SAL_CALL SvxUnoXGradientTable::getElementType()
-    throw( uno::RuntimeException, std::exception )
 {
     return cppu::UnoType<awt::Gradient>::get();
 }
 
 // XServiceInfo
-OUString SAL_CALL SvxUnoXGradientTable::getImplementationName(  ) throw( uno::RuntimeException, std::exception )
+OUString SAL_CALL SvxUnoXGradientTable::getImplementationName(  )
 {
     return OUString( "SvxUnoXGradientTable" );
 }
 
-uno::Sequence<  OUString > SAL_CALL SvxUnoXGradientTable::getSupportedServiceNames(  ) throw( uno::RuntimeException, std::exception)
+uno::Sequence<  OUString > SAL_CALL SvxUnoXGradientTable::getSupportedServiceNames(  )
 {
     const OUString aServiceName( "com.sun.star.drawing.GradientTable" );
     uno::Sequence< OUString > aServices( &aServiceName, 1 );
@@ -610,15 +594,15 @@ public:
     explicit SvxUnoXBitmapTable( XPropertyList* pTable ) throw() : SvxUnoXPropertyTable( XATTR_FILLBITMAP, pTable ) {};
 
     // SvxUnoXPropertyTable
-    virtual uno::Any getAny( const XPropertyEntry* pEntry ) const throw(uno::RuntimeException) override;
-    virtual std::unique_ptr<XPropertyEntry> createEntry(const OUString& rName, const uno::Any& rAny) const throw(uno::RuntimeException) override;
+    virtual uno::Any getAny( const XPropertyEntry* pEntry ) const override;
+    virtual std::unique_ptr<XPropertyEntry> createEntry(const OUString& rName, const uno::Any& rAny) const override;
 
     // XElementAccess
-    virtual uno::Type SAL_CALL getElementType() throw( uno::RuntimeException, std::exception ) override;
+    virtual uno::Type SAL_CALL getElementType() override;
 
     // XServiceInfo
-    virtual OUString SAL_CALL getImplementationName(  ) throw( uno::RuntimeException, std::exception ) override;
-    virtual uno::Sequence<  OUString > SAL_CALL getSupportedServiceNames(  ) throw( uno::RuntimeException, std::exception) override;
+    virtual OUString SAL_CALL getImplementationName(  ) override;
+    virtual uno::Sequence<  OUString > SAL_CALL getSupportedServiceNames(  ) override;
 };
 
 uno::Reference< uno::XInterface > SAL_CALL SvxUnoXBitmapTable_createInstance( XPropertyList* pTable ) throw()
@@ -627,7 +611,7 @@ uno::Reference< uno::XInterface > SAL_CALL SvxUnoXBitmapTable_createInstance( XP
 }
 
 // SvxUnoXPropertyTable
-uno::Any SvxUnoXBitmapTable::getAny( const XPropertyEntry* pEntry ) const throw(uno::RuntimeException)
+uno::Any SvxUnoXBitmapTable::getAny( const XPropertyEntry* pEntry ) const
 {
     OUString aURL( UNO_NAME_GRAPHOBJ_URLPREFIX);
     const GraphicObject& rGraphicObject(static_cast<const XBitmapEntry*>(pEntry)->GetGraphicObject());
@@ -636,7 +620,7 @@ uno::Any SvxUnoXBitmapTable::getAny( const XPropertyEntry* pEntry ) const throw(
     return uno::Any(aURL);
 }
 
-std::unique_ptr<XPropertyEntry> SvxUnoXBitmapTable::createEntry(const OUString& rName, const uno::Any& rAny) const throw(uno::RuntimeException)
+std::unique_ptr<XPropertyEntry> SvxUnoXBitmapTable::createEntry(const OUString& rName, const uno::Any& rAny) const
 {
     OUString aURL;
     if(!(rAny >>= aURL))
@@ -649,18 +633,17 @@ std::unique_ptr<XPropertyEntry> SvxUnoXBitmapTable::createEntry(const OUString&
 
 // XElementAccess
 uno::Type SAL_CALL SvxUnoXBitmapTable::getElementType()
-    throw( uno::RuntimeException, std::exception )
 {
     return ::cppu::UnoType<OUString>::get();
 }
 
 // XServiceInfo
-OUString SAL_CALL SvxUnoXBitmapTable::getImplementationName(  ) throw( uno::RuntimeException, std::exception )
+OUString SAL_CALL SvxUnoXBitmapTable::getImplementationName(  )
 {
     return OUString( "SvxUnoXBitmapTable" );
 }
 
-uno::Sequence<  OUString > SAL_CALL SvxUnoXBitmapTable::getSupportedServiceNames(  ) throw( uno::RuntimeException, std::exception)
+uno::Sequence<  OUString > SAL_CALL SvxUnoXBitmapTable::getSupportedServiceNames(  )
 {
     const OUString aServiceName( "com.sun.star.drawing.BitmapTable" );
     uno::Sequence< OUString > aServices( &aServiceName, 1 );
