@@ -20,8 +20,7 @@
 #include <sal/config.h>
 
 #include "unogaltheme.hxx"
-#include "svx/gallery1.hxx"
-#include <osl/mutex.hxx>
+#include <svx/gallery1.hxx>
 #include <rtl/ref.hxx>
 #include <vcl/svapp.hxx>
 #include <unotools/pathoptions.hxx>
@@ -167,10 +166,8 @@ uno::Any SAL_CALL GalleryThemeProvider::getByName( const OUString& rName )
     {
         throw container::NoSuchElementException();
     }
-    else
-    {
-        aRet <<= uno::Reference< gallery::XGalleryTheme >( new ::unogallery::GalleryTheme( rName ) );
-    }
+
+    aRet <<= uno::Reference< gallery::XGalleryTheme >( new ::unogallery::GalleryTheme( rName ) );
 
     return aRet;
 }
@@ -240,10 +237,8 @@ void SAL_CALL GalleryThemeProvider::removeByName( const OUString& rName )
     {
         throw container::NoSuchElementException();
     }
-    else
-    {
-        mpGallery->RemoveTheme( rName );
-    }
+
+    mpGallery->RemoveTheme( rName );
 }
 
 }
