@@ -17,7 +17,11 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
+#include <sal/config.h>
+
+#include <o3tl/make_unique.hxx>
 #include <sot/formats.hxx>
+#include <tools/stream.hxx>
 #include <tools/vcompat.hxx>
 #include <svx/xflasit.hxx>
 #include <svx/xfillit0.hxx>
@@ -25,20 +29,11 @@
 #include <svl/whiter.hxx>
 #include <svl/itemset.hxx>
 #include <svx/xdef.hxx>
-#include "svx/xexch.hxx"
-#include <boost/scoped_ptr.hpp>
+#include <svx/xexch.hxx>
+#include <memory>
+#include <utility>
 
-
-TYPEINIT1_AUTOFACTORY( XFillExchangeData, SvDataCopyStream );
-
-/// default CTOR, for Assign()
-XFillExchangeData::XFillExchangeData() :
-    pXFillAttrSetItem( NULL ),
-    pPool( NULL )
-{
-}
-
-XFillExchangeData::XFillExchangeData( const XFillAttrSetItem rXFillAttrSetItem ) :
+XFillExchangeData::XFillExchangeData( const XFillAttrSetItem& rXFillAttrSetItem ) :
     pXFillAttrSetItem( static_cast<XFillAttrSetItem*>( rXFillAttrSetItem.Clone( rXFillAttrSetItem.GetItemSet().GetPool() ) ) ),
     pPool( rXFillAttrSetItem.GetItemSet().GetPool() )
 {
@@ -46,7 +41,6 @@ XFillExchangeData::XFillExchangeData( const XFillAttrSetItem rXFillAttrSetItem )
 
 XFillExchangeData::~XFillExchangeData()
 {
-    delete pXFillAttrSetItem;
 }
 
 /// binary export (currently w/o version control because it is not persistent)
@@ -58,7 +52,7 @@ SvStream& WriteXFillExchangeData( SvStream& rOStm, const XFillExchangeData& rDat
         sal_uInt16              nWhich = aIter.FirstWhich();
         const SfxPoolItem*  pItem;
         sal_uInt32          nItemCount = 0;
-        sal_Size            nFirstPos = rOStm.Tell();
+        sal_uInt64 const    nFirstPos = rOStm.Tell();
 
         rOStm.WriteUInt32( nItemCount );
 
@@ -66,7 +60,7 @@ SvStream& WriteXFillExchangeData( SvStream& rOStm, const XFillExchangeData& rDat
         {
             if( SfxItemState::SET == rData.pXFillAttrSetItem->GetItemSet().GetItemState( nWhich, false, &pItem ) )
             {
-                VersionCompat   aCompat( rOStm, STREAM_WRITE );
+                VersionCompat   aCompat( rOStm, StreamMode::WRITE );
                 const sal_uInt16    nItemVersion2 = pItem->GetVersion( (sal_uInt16) rOStm.GetVersion() );
 
                 rOStm.WriteUInt16( nWhich ).WriteUInt16( nItemVersion2 );
@@ -92,24 +86,24 @@ SvStream& ReadXFillExchangeData( SvStream& rIStm, XFillExchangeData& rData )
 {
     DBG_ASSERT( rData.pPool, "XFillExchangeData has no pool" );
 
-    SfxItemSet*     pSet = new SfxItemSet ( *rData.pPool, XATTR_FILL_FIRST, XATTR_FILL_LAST );
+    auto pSet = o3tl::make_unique<SfxItemSet>( *rData.pPool, svl::Items<XATTR_FILL_FIRST, XATTR_FILL_LAST>{} );
     sal_uInt32      nItemCount = 0;
     sal_uInt16          nWhich, nItemVersion;
 
     rIStm.ReadUInt32( nItemCount );
 
-    if( nItemCount > ( XATTR_FILL_LAST - XATTR_FILL_FIRST + 1 ) )
+    if( nItemCount > sal_uInt16( XATTR_FILL_LAST - XATTR_FILL_FIRST + 1 ) )
         nItemCount = ( XATTR_FILL_LAST - XATTR_FILL_FIRST + 1 );
 
     for( sal_uInt32 i = 0; i < nItemCount; i++ )
     {
-        VersionCompat aCompat( rIStm, STREAM_READ );
+        VersionCompat aCompat( rIStm, StreamMode::READ );
 
         rIStm.ReadUInt16( nWhich ).ReadUInt16( nItemVersion );
 
         if( nWhich )
         {
-            boost::scoped_ptr<SfxPoolItem> pNewItem(rData.pPool->GetDefaultItem( nWhich ).Create( rIStm, nItemVersion ));
+            std::unique_ptr<SfxPoolItem> pNewItem(rData.pPool->GetDefaultItem( nWhich ).Create( rIStm, nItemVersion ));
 
             if( pNewItem )
             {
@@ -118,8 +112,7 @@ SvStream& ReadXFillExchangeData( SvStream& rIStm, XFillExchangeData& rData )
         }
     }
 
-    delete rData.pXFillAttrSetItem;
-    rData.pXFillAttrSetItem = new XFillAttrSetItem( pSet );
+    rData.pXFillAttrSetItem.reset( new XFillAttrSetItem( std::move(pSet) ) );
     rData.pPool = rData.pXFillAttrSetItem->GetItemSet().GetPool();
 
     return rIStm;
@@ -127,17 +120,15 @@ SvStream& ReadXFillExchangeData( SvStream& rIStm, XFillExchangeData& rData )
 
 XFillExchangeData& XFillExchangeData::operator=( const XFillExchangeData& rData )
 {
-    delete pXFillAttrSetItem;
-
     if( rData.pXFillAttrSetItem )
-        pXFillAttrSetItem = static_cast<XFillAttrSetItem*>( rData.pXFillAttrSetItem->Clone( pPool = rData.pXFillAttrSetItem->GetItemSet().GetPool() ) );
+        pXFillAttrSetItem.reset( static_cast<XFillAttrSetItem*>( rData.pXFillAttrSetItem->Clone( pPool = rData.pXFillAttrSetItem->GetItemSet().GetPool() ) ) );
     else
     {
-        pPool = NULL;
-        pXFillAttrSetItem = NULL;
+        pPool = nullptr;
+        pXFillAttrSetItem.reset();
     }
 
-    return( *this );
+    return *this;
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
