@@ -21,6 +21,9 @@
 #include <functional>
 #include <SwNumberTree.hxx>
 #include <osl/diagnose.h>
+#include <sal/log.hxx>
+
+#include <cassert>
 
 using std::vector;
 using std::find;
@@ -72,7 +75,7 @@ SwNumberTreeNode * SwNumberTreeNode::CreatePhantom()
     else
     {
         pNew = Create();
-        pNew->SetPhantom();
+        pNew->mbPhantom = true;
         pNew->mpParent = this;
 
         std::pair<tSwNumberTreeChildren::iterator, bool> aInsert =
@@ -383,9 +386,9 @@ void SwNumberTreeNode::MoveGreaterChildren( SwNumberTreeNode& _rCompareNode,
         }
     }
 
-#ifdef __SW_NUMBER_TREE_SANITY_CHECK
-    if (! IsSane(false) || ! IsSane(&_rDestNode))
-        clog << __FUNCTION__ << "insanity!" << endl;
+#ifdef DBG_UTIL
+    IsSane(false);
+    _rDestNode.IsSane(true);
 #endif
 }
 
@@ -432,8 +435,9 @@ void SwNumberTreeNode::MoveChildren(SwNumberTreeNode * pDest)
 
    OSL_ENSURE(mChildren.empty(), "MoveChildren failed!");
 
-#ifdef __SW_NUMBER_TREE_SANITY_CHECK
-    OSL_ENSURE(IsSane(false) && pDest->IsSane(false), "insanity!");
+#ifdef DBG_UTIL
+    IsSane(false);
+    pDest->IsSane(false);
 #endif
 }
 
@@ -584,9 +588,8 @@ void SwNumberTreeNode::AddChild( SwNumberTreeNode * pChild,
         }
     }
 
-#ifdef __SW_NUMBER_TREE_SANITY_CHECK
-    if (! IsSane(false))
-        clog << __FUNCTION__ << ": insanity!" << endl;
+#ifdef DBG_UTIL
+    IsSane(false);
 #endif
 }
 
@@ -678,9 +681,8 @@ void SwNumberTreeNode::RemoveMe()
         if (pSavedParent)
             pSavedParent->ClearObsoletePhantoms();
 
-#ifdef __SW_NUMBER_TREE_SANITY_CHECK
-        if (! IsSane(false))
-            clog << __FUNCTION__ << ": insanity!" << endl;
+#ifdef DBG_UTIL
+        IsSane(false);
 #endif
     }
 }
@@ -725,11 +727,6 @@ bool SwNumberTreeNode::IsValid(const SwNumberTreeNode * pChild) const
 }
 
 
-void SwNumberTreeNode::SetPhantom()
-{
-    mbPhantom = true;
-}
-
 bool SwNumberTreeNode::HasOnlyPhantoms() const
 {
     bool bResult = false;
@@ -863,35 +860,23 @@ SwNumberTreeNode::GetChildCount() const
     return mChildren.size();
 }
 
-#ifdef __SW_NUMBER_TREE_SANITY_CHECK
-bool SwNumberTreeNode::IsSane(bool bRecursive) const
+#ifdef DBG_UTIL
+void SwNumberTreeNode::IsSane(bool bRecursive) const
 {
     vector<const SwNumberTreeNode*> aParents;
 
     return IsSane(bRecursive, aParents);
 }
 
-bool SwNumberTreeNode::IsSane(bool bRecursive,
+void SwNumberTreeNode::IsSane(bool bRecursive,
                               vector<const SwNumberTreeNode *> rParents)
     const
 {
-    bool bResult = true;
-
     tSwNumberTreeChildren::const_iterator aIt;
 
-    if (find(rParents.begin(), rParents.end(), this) != rParents.end())
-    {
-        OSL_FAIL(" I'm my own ancestor!");
+    assert(find(rParents.begin(), rParents.end(), this) == rParents.end());
 
-        bResult = false;
-    }
-
-    if (! rParents.empty() && rParents.back() != mpParent)
-    {
-        OSL_FAIL(" I'm a bastard!");
-
-        bResult = false;
-    }
+    assert(rParents.empty() || rParents.back() == mpParent);
 
     rParents.push_back(this);
 
@@ -902,51 +887,35 @@ bool SwNumberTreeNode::IsSane(bool bRecursive,
         {
             if ((*aIt)->IsPhantom())
             {
-                if ((*aIt)->HasOnlyPhantoms())
-                {
-                    bResult = false;
-                }
+                SAL_WARN_IF((*aIt)->HasOnlyPhantoms(), "sw.core",
+                        "HasOnlyPhantoms: is this an error?");
 
-                if (! bFirst)
-                {
-                    OSL_FAIL(" found phantom not at first position.");
-
-                    bResult = false;
-                }
+                assert(bFirst && "found phantom not at first position.");
             }
 
-            if ((*aIt)->mpParent != (SwNumberTreeNode *) this)
-            {
-                OSL_FAIL("found a bastard");
-
-                bResult = false;
-            }
+            assert((*aIt)->mpParent == this);
 
             if (mpParent)
             {
-                if  (!(*aIt)->IsPhantom() && (*aIt)->LessThan(*this))
-                {
-                    OSL_FAIL(" found child less than me");
-
-                    bResult = false;
-                }
+                assert((*aIt)->IsPhantom() || !(*aIt)->LessThan(*this));
             }
         }
         else
         {
-            OSL_FAIL("found child that is NULL");
-            bResult = false;
+            assert(!"found child that is NULL");
         }
 
-    if (bRecursive)
-      bResult = (*aIt)->IsSane(bRecursive, rParents) && bResult;
+        if (bRecursive)
+        {
+            (*aIt)->IsSane(bRecursive, rParents);
+        }
+
+        bFirst = false;
     }
 
     rParents.pop_back();
-
-    return bResult;
 }
-#endif // __SW_NUMBER_TREE_SANITY_CHECK
+#endif // DBG_UTIL
 
 SwNumberTreeNode::tSwNumberTreeChildren::const_iterator
 SwNumberTreeNode::GetIterator(const SwNumberTreeNode * pChild) const
@@ -1075,21 +1044,14 @@ void SwNumberTreeNode::SetLastValid
                 ++aIt;
             }
 
-            SetLastValid(bValidating);
+            if (mpParent)
+            {
+                mpParent->SetLastValid(mpParent->GetIterator(this), bValidating);
+            }
         }
     }
 }
 
-void SwNumberTreeNode::SetLastValid(bool bValidating) const
-{
-    if (mpParent)
-    {
-        tSwNumberTreeChildren::const_iterator aIt = mpParent->GetIterator(this);
-
-        mpParent->SetLastValid(aIt, bValidating);
-    }
-}
-
 void SwNumberTreeNode::InvalidateTree() const
 {
     // do not call SetInvalid, would cause loop !!!
@@ -1101,7 +1063,7 @@ void SwNumberTreeNode::InvalidateTree() const
         (*aIt)->InvalidateTree();
 }
 
-void SwNumberTreeNode::Invalidate(SwNumberTreeNode * pChild)
+void SwNumberTreeNode::Invalidate(SwNumberTreeNode const * pChild)
 {
     if (pChild->IsValid())
     {
