@@ -20,7 +20,6 @@
 #include <hintids.hxx>
 #include <editeng/protitem.hxx>
 #include <com/sun/star/i18n/WordType.hpp>
-#include <com/sun/star/i18n/CharType.hpp>
 #include <unotools/charclass.hxx>
 #include <svl/ctloptions.hxx>
 #include <swmodule.hxx>
@@ -45,25 +44,25 @@
 #include <viewsh.hxx>
 #include <frmatr.hxx>
 #include <breakit.hxx>
-#include <crsskip.hxx>
 #include <vcl/msgbox.hxx>
 #include <mdiexp.hxx>
-#include <statstr.hrc>
+#include <strings.hrc>
 #include <redline.hxx>
 #include <txatbase.hxx>
 #include <memory>
+#include <comphelper/lok.hxx>
 
 using namespace ::com::sun::star::i18n;
 
 static const sal_uInt16 coSrchRplcThreshold = 60000;
 
-struct _PercentHdl
+struct PercentHdl
 {
     SwDocShell* pDSh;
     sal_uLong nActPos;
     bool bBack, bNodeIdx;
 
-    _PercentHdl( sal_uLong nStt, sal_uLong nEnd, SwDocShell* pSh )
+    PercentHdl( sal_uLong nStt, sal_uLong nEnd, SwDocShell* pSh )
         : pDSh(pSh), bBack(false), bNodeIdx(false)
     {
         nActPos = nStt;
@@ -74,7 +73,7 @@ struct _PercentHdl
         ::StartProgress( STR_STATSTR_SEARCH, nStt, nEnd );
     }
 
-    explicit _PercentHdl( const SwPaM& rPam )
+    explicit PercentHdl( const SwPaM& rPam )
         : pDSh( rPam.GetDoc()->GetDocShell() )
     {
         sal_uLong nStt, nEnd;
@@ -98,12 +97,12 @@ struct _PercentHdl
         ::StartProgress( STR_STATSTR_SEARCH, nStt, nEnd, pDSh );
     }
 
-    ~_PercentHdl()                      { ::EndProgress( pDSh ); }
+    ~PercentHdl()                      { ::EndProgress( pDSh ); }
 
     void NextPos( sal_uLong nPos ) const
         { ::SetProgressState( bBack ? nActPos - nPos : nPos, pDSh ); }
 
-    void NextPos( SwPosition& rPos ) const
+    void NextPos( SwPosition const & rPos ) const
         {
             sal_uLong nPos;
             if( bNodeIdx )
@@ -114,12 +113,12 @@ struct _PercentHdl
         }
 };
 
-SwCursor::SwCursor( const SwPosition &rPos, SwPaM* pRing, bool bColumnSel )
+SwCursor::SwCursor( const SwPosition &rPos, SwPaM* pRing )
     : SwPaM( rPos, pRing )
     , m_pSavePos(nullptr)
     , m_nRowSpanOffset(0)
     , m_nCursorBidiLevel(0)
-    , m_bColumnSelection(bColumnSel)
+    , m_bColumnSelection(false)
 {
 }
 
@@ -137,7 +136,7 @@ SwCursor::~SwCursor()
 {
     while( m_pSavePos )
     {
-        _SwCursor_SavePos* pNxt = m_pSavePos->pNext;
+        SwCursor_SavePos* pNxt = m_pSavePos->pNext;
         delete m_pSavePos;
         m_pSavePos = pNxt;
     }
@@ -145,7 +144,7 @@ SwCursor::~SwCursor()
 
 SwCursor* SwCursor::Create( SwPaM* pRing ) const
 {
-    return new SwCursor( *GetPoint(), pRing, false );
+    return new SwCursor( *GetPoint(), pRing );
 }
 
 bool SwCursor::IsReadOnlyAvailable() const
@@ -167,7 +166,7 @@ bool SwCursor::IsSkipOverProtectSections() const
 // own SaveObjects if needed and validate them in the virtual check routines.
 void SwCursor::SaveState()
 {
-    _SwCursor_SavePos* pNew = CreateNewSavePos();
+    SwCursor_SavePos* pNew = new SwCursor_SavePos( *this );
     pNew->pNext = m_pSavePos;
     m_pSavePos = pNew;
 }
@@ -176,17 +175,12 @@ void SwCursor::RestoreState()
 {
     if (m_pSavePos) // Robust
     {
-        _SwCursor_SavePos* pDel = m_pSavePos;
+        SwCursor_SavePos* pDel = m_pSavePos;
         m_pSavePos = m_pSavePos->pNext;
         delete pDel;
     }
 }
 
-_SwCursor_SavePos* SwCursor::CreateNewSavePos() const
-{
-    return new _SwCursor_SavePos( *this );
-}
-
 /// determine if point is outside of the node-array's content area
 bool SwCursor::IsNoContent() const
 {
@@ -194,17 +188,17 @@ bool SwCursor::IsNoContent() const
             GetDoc()->GetNodes().GetEndOfExtras().GetIndex();
 }
 
-bool SwCursor::IsSelOvrCheck(int)
+bool SwCursor::IsSelOvrCheck(SwCursorSelOverFlags)
 {
     return false;
 }
 
 // extracted from IsSelOvr()
-bool SwTableCursor::IsSelOvrCheck(int eFlags)
+bool SwTableCursor::IsSelOvrCheck(SwCursorSelOverFlags eFlags)
 {
     SwNodes& rNds = GetDoc()->GetNodes();
     // check sections of nodes array
-    if( (nsSwCursorSelOverFlags::SELOVER_CHECKNODESSECTION & eFlags)
+    if( (SwCursorSelOverFlags::CheckNodeSection & eFlags)
         && HasMark() )
     {
         SwNodeIndex aOldPos( rNds, GetSavePos()->nNode );
@@ -220,7 +214,7 @@ bool SwTableCursor::IsSelOvrCheck(int eFlags)
 
 namespace
 {
-    const SwTextAttr* InputFieldAtPos(SwPosition *pPos)
+    const SwTextAttr* InputFieldAtPos(SwPosition const *pPos)
     {
         SwTextNode* pTextNd = pPos->nNode.GetNode().GetTextNode();
         if (!pTextNd)
@@ -229,7 +223,7 @@ namespace
     }
 }
 
-bool SwCursor::IsSelOvr( int eFlags )
+bool SwCursor::IsSelOvr( SwCursorSelOverFlags eFlags )
 {
     SwDoc* pDoc = GetDoc();
     SwNodes& rNds = pDoc->GetNodes();
@@ -253,7 +247,7 @@ bool SwCursor::IsSelOvr( int eFlags )
             ((bSkipOverHiddenSections && pSectNd->GetSection().IsHiddenFlag() ) ||
             (bSkipOverProtectSections && pSectNd->GetSection().IsProtectFlag() )))
         {
-            if( 0 == ( nsSwCursorSelOverFlags::SELOVER_CHANGEPOS & eFlags ) )
+            if( !( SwCursorSelOverFlags::ChangePos & eFlags ) )
             {
                 // then we're already done
                 RestoreSavePos();
@@ -267,7 +261,7 @@ bool SwCursor::IsSelOvr( int eFlags )
             SwContentNode* pCNd = bGoNxt
                 ? rNds.GoNextSection( &rPtIdx, bSkipOverHiddenSections, bSkipOverProtectSections)
                 : SwNodes::GoPrevSection( &rPtIdx, bSkipOverHiddenSections, bSkipOverProtectSections);
-            if( !pCNd && ( nsSwCursorSelOverFlags::SELOVER_ENABLEREVDIREKTION & eFlags ))
+            if( !pCNd && ( SwCursorSelOverFlags::EnableRevDirection & eFlags ))
             {
                 bGoNxt = !bGoNxt;
                 pCNd = bGoNxt ? rNds.GoNextSection( &rPtIdx, bSkipOverHiddenSections, bSkipOverProtectSections)
@@ -343,15 +337,16 @@ bool SwCursor::IsSelOvr( int eFlags )
     if( pNd->IsContentNode() && !dynamic_cast<SwUnoCursor*>(this) )
     {
         const SwContentFrame* pFrame = static_cast<const SwContentNode*>(pNd)->getLayoutFrame( pDoc->getIDocumentLayoutAccess().GetCurrentLayout() );
-        if ( (nsSwCursorSelOverFlags::SELOVER_CHANGEPOS & eFlags)   //allowed to change position if it's a bad one
-            && pFrame && pFrame->IsValid() && !pFrame->Frame().Height()     //a bad zero height position
+        if ( (SwCursorSelOverFlags::ChangePos & eFlags)   //allowed to change position if it's a bad one
+            && pFrame && pFrame->isFrameAreaDefinitionValid()
+            && !pFrame->getFrameArea().Height()     //a bad zero height position
             && !InputFieldAtPos(GetPoint()) )                       //unless it's a (vertical) input field
         {
             // skip to the next/prev valid paragraph with a layout
             SwNodeIndex& rPtIdx = GetPoint()->nNode;
             bool bGoNxt = m_pSavePos->nNode < rPtIdx.GetIndex();
             while( nullptr != ( pFrame = ( bGoNxt ? pFrame->GetNextContentFrame() : pFrame->GetPrevContentFrame() ))
-                   && 0 == pFrame->Frame().Height() )
+                   && 0 == pFrame->getFrameArea().Height() )
                 ;
 
             // #i72394# skip to prev/next valid paragraph with a layout in case
@@ -360,7 +355,7 @@ bool SwCursor::IsSelOvr( int eFlags )
             {
                 bGoNxt = !bGoNxt;
                 pFrame = static_cast<const SwContentNode*>(pNd)->getLayoutFrame( pDoc->getIDocumentLayoutAccess().GetCurrentLayout() );
-                while ( pFrame && 0 == pFrame->Frame().Height() )
+                while ( pFrame && 0 == pFrame->getFrameArea().Height() )
                 {
                     pFrame = bGoNxt ? pFrame->GetNextContentFrame()
                         :   pFrame->GetPrevContentFrame();
@@ -403,7 +398,7 @@ bool SwCursor::IsSelOvr( int eFlags )
     }
 
     // is the cursor allowed to be in a protected node?
-    if( 0 == ( nsSwCursorSelOverFlags::SELOVER_CHANGEPOS & eFlags ) && !IsAtValidPos() )
+    if( !( SwCursorSelOverFlags::ChangePos & eFlags ) && !IsAtValidPos() )
     {
         DeleteMark();
         RestoreSavePos();
@@ -438,11 +433,11 @@ bool SwCursor::IsSelOvr( int eFlags )
         if ( pInputFieldTextAttrAtPoint != pInputFieldTextAttrAtMark )
         {
             const sal_uLong nRefNodeIdx =
-                ( nsSwCursorSelOverFlags::SELOVER_TOGGLE & eFlags )
+                ( SwCursorSelOverFlags::Toggle & eFlags )
                 ? m_pSavePos->nNode
                 : GetMark()->nNode.GetIndex();
             const sal_Int32 nRefContentIdx =
-                ( nsSwCursorSelOverFlags::SELOVER_TOGGLE & eFlags )
+                ( SwCursorSelOverFlags::Toggle & eFlags )
                 ? m_pSavePos->nContent
                 : GetMark()->nContent.GetIndex();
             const bool bIsForwardSelection =
@@ -485,10 +480,10 @@ bool SwCursor::IsSelOvr( int eFlags )
 
     // Note: this cannot happen in TableMode
     // Only Point in Table then go behind/in front of table
-    if (nsSwCursorSelOverFlags::SELOVER_CHANGEPOS & eFlags)
+    if (SwCursorSelOverFlags::ChangePos & eFlags)
     {
         bool bSelTop = GetPoint()->nNode.GetIndex() <
-            ((nsSwCursorSelOverFlags::SELOVER_TOGGLE & eFlags)
+            ((SwCursorSelOverFlags::Toggle & eFlags)
                  ? m_pSavePos->nNode : GetMark()->nNode.GetIndex());
 
         do { // loop for table after table
@@ -599,16 +594,17 @@ bool SwCursor::IsInProtectTable( bool bMove, bool bChgCursor )
         SwNodeIndex aCellStt( *GetNode().FindTableBoxStartNode()->EndOfSectionNode(), 1 );
         bool bProt = true;
 GoNextCell:
-        do {
+        for (;;) {
             if( !aCellStt.GetNode().IsStartNode() )
                 break;
             ++aCellStt;
             if( nullptr == ( pCNd = aCellStt.GetNode().GetContentNode() ))
                 pCNd = aCellStt.GetNodes().GoNext( &aCellStt );
-            if( !( bProt = pCNd->IsProtect() ))
+            bProt = pCNd->IsProtect();
+            if( !bProt )
                 break;
             aCellStt.Assign( *pCNd->FindTableBoxStartNode()->EndOfSectionNode(), 1 );
-        } while( bProt );
+        }
 
 SetNextCursor:
         if( !bProt ) // found free cell
@@ -620,8 +616,8 @@ SetNextCursor:
                 GetPoint()->nContent.Assign( pTmpCNd, 0 );
                 return false;
             }
-            return IsSelOvr( nsSwCursorSelOverFlags::SELOVER_TOGGLE |
-                             nsSwCursorSelOverFlags::SELOVER_CHANGEPOS );
+            return IsSelOvr( SwCursorSelOverFlags::Toggle |
+                             SwCursorSelOverFlags::ChangePos );
         }
         // end of table, so go to next node
         ++aCellStt;
@@ -648,16 +644,17 @@ SetNextCursor:
         SwNode* pNd;
         bool bProt = true;
 GoPrevCell:
-        do {
+        for (;;) {
             if( !( pNd = &aCellStt.GetNode())->IsEndNode() )
                 break;
             aCellStt.Assign( *pNd->StartOfSectionNode(), +1 );
             if( nullptr == ( pCNd = aCellStt.GetNode().GetContentNode() ))
                 pCNd = pNd->GetNodes().GoNext( &aCellStt );
-            if( !( bProt = pCNd->IsProtect() ))
+            bProt = pCNd->IsProtect();
+            if( !bProt )
                 break;
             aCellStt.Assign( *pNd->FindTableBoxStartNode(), -1 );
-        } while( bProt );
+        }
 
 SetPrevCursor:
         if( !bProt ) // found free cell
@@ -669,8 +666,8 @@ SetPrevCursor:
                 GetPoint()->nContent.Assign( pTmpCNd, 0 );
                 return false;
             }
-            return IsSelOvr( nsSwCursorSelOverFlags::SELOVER_TOGGLE |
-                             nsSwCursorSelOverFlags::SELOVER_CHANGEPOS );
+            return IsSelOvr( SwCursorSelOverFlags::Toggle |
+                             SwCursorSelOverFlags::ChangePos );
         }
         // at the beginning of a table, so go to next node
         --aCellStt;
@@ -711,17 +708,15 @@ bool SwCursor::IsAtValidPos( bool bPoint ) const
         return false;
 
     const SwSectionNode* pSectNd = pNd->FindSectionNode();
-    if( pSectNd && (pSectNd->GetSection().IsHiddenFlag() ||
-                    ( !bCursorInReadOnly && pSectNd->GetSection().IsProtectFlag() )))
-        return false;
-
-    return true;
+    return !pSectNd
+           || !(pSectNd->GetSection().IsHiddenFlag() ||
+                ( !bCursorInReadOnly && pSectNd->GetSection().IsProtectFlag() ));
 }
 
 void SwCursor::SaveTableBoxContent( const SwPosition* ) {}
 
 /// set range for search in document
-SwMoveFnCollection* SwCursor::MakeFindRange( SwDocPositions nStart,
+SwMoveFnCollection const & SwCursor::MakeFindRange( SwDocPositions nStart,
                                 SwDocPositions nEnd, SwPaM* pRange ) const
 {
     pRange->SetMark();
@@ -729,14 +724,14 @@ SwMoveFnCollection* SwCursor::MakeFindRange( SwDocPositions nStart,
     FillFindPos( nEnd, *pRange->GetPoint() );
 
     // determine direction of search
-    return ( DOCPOS_START == nStart || DOCPOS_OTHERSTART == nStart ||
-              (DOCPOS_CURR == nStart &&
-                (DOCPOS_END == nEnd || DOCPOS_OTHEREND == nEnd ) ))
+    return ( SwDocPositions::Start == nStart || SwDocPositions::OtherStart == nStart ||
+              (SwDocPositions::Curr == nStart &&
+                (SwDocPositions::End == nEnd || SwDocPositions::OtherEnd == nEnd ) ))
                 ? fnMoveForward : fnMoveBackward;
 }
 
 static sal_uLong lcl_FindSelection( SwFindParas& rParas, SwCursor* pCurrentCursor,
-                        SwMoveFn fnMove, SwCursor*& pFndRing,
+                        SwMoveFnCollection const & fnMove, SwCursor*& pFndRing,
                         SwPaM& aRegion, FindRanges eFndRngs,
                         bool bInReadOnly, bool& bCancel )
 {
@@ -744,22 +739,22 @@ static sal_uLong lcl_FindSelection( SwFindParas& rParas, SwCursor* pCurrentCurso
     bool const bDoesUndo = pDoc->GetIDocumentUndoRedo().DoesUndo();
     int nFndRet = 0;
     sal_uLong nFound = 0;
-    const bool bSrchBkwrd = fnMove == fnMoveBackward;
+    const bool bSrchBkwrd = &fnMove == &fnMoveBackward;
     SwPaM *pTmpCursor = pCurrentCursor, *pSaveCursor = pCurrentCursor;
 
     // only create progress bar for ShellCursor
     bool bIsUnoCursor = dynamic_cast<SwUnoCursor*>(pCurrentCursor) !=  nullptr;
-    std::unique_ptr<_PercentHdl> pPHdl;
+    std::unique_ptr<PercentHdl> pPHdl;
     sal_uInt16 nCursorCnt = 0;
-    if( FND_IN_SEL & eFndRngs )
+    if( FindRanges::InSel & eFndRngs )
     {
         while( pCurrentCursor != ( pTmpCursor = pTmpCursor->GetNext() ))
             ++nCursorCnt;
         if( nCursorCnt && !bIsUnoCursor )
-            pPHdl.reset(new _PercentHdl( 0, nCursorCnt, pDoc->GetDocShell() ));
+            pPHdl.reset(new PercentHdl( 0, nCursorCnt, pDoc->GetDocShell() ));
     }
     else
-        pSaveCursor = static_cast<SwPaM*>(pSaveCursor->GetPrev());
+        pSaveCursor = pSaveCursor->GetPrev();
 
     bool bEnd = false;
     do {
@@ -774,7 +769,7 @@ static sal_uLong lcl_FindSelection( SwFindParas& rParas, SwCursor* pCurrentCurso
             aRegion.Exchange();
 
         if( !nCursorCnt && !pPHdl && !bIsUnoCursor )
-            pPHdl.reset(new _PercentHdl( aRegion ));
+            pPHdl.reset(new PercentHdl( aRegion ));
 
         // as long as found and not at same position
         while(  *pSttPos <= *pEndPos &&
@@ -797,7 +792,7 @@ static sal_uLong lcl_FindSelection( SwFindParas& rParas, SwCursor* pCurrentCurso
 
             ++nFound;
 
-            if( !( eFndRngs & FND_IN_SELALL) )
+            if( !( eFndRngs & FindRanges::InSelAll) )
             {
                 bEnd = true;
                 break;
@@ -841,7 +836,7 @@ static sal_uLong lcl_FindSelection( SwFindParas& rParas, SwCursor* pCurrentCurso
             }
         }
 
-        if( bEnd || !( eFndRngs & ( FND_IN_SELALL | FND_IN_SEL )) )
+        if( bEnd || !( eFndRngs & ( FindRanges::InSelAll | FindRanges::InSel )) )
             break;
 
         pTmpCursor = pTmpCursor->GetNext();
@@ -933,17 +928,17 @@ sal_uLong SwCursor::FindAll( SwFindParas& rParas,
 
     // create region without adding it to the ring
     SwPaM aRegion( *GetPoint() );
-    SwMoveFn fnMove = MakeFindRange( nStart, nEnde, &aRegion );
+    SwMoveFnCollection const & fnMove = MakeFindRange( nStart, nEnde, &aRegion );
 
     sal_uLong nFound = 0;
-    const bool bMvBkwrd = fnMove == fnMoveBackward;
+    const bool bMvBkwrd = &fnMove == &fnMoveBackward;
     bool bInReadOnly = IsReadOnlyAvailable();
 
     SwCursor* pFndRing = nullptr;
     SwNodes& rNds = GetDoc()->GetNodes();
 
     // search in sections?
-    if( FND_IN_SEL & eFndRngs )
+    if( FindRanges::InSel & eFndRngs )
     {
         // if string was not found in region then get all sections (cursors
         // stays unchanged)
@@ -962,7 +957,7 @@ sal_uLong SwCursor::FindAll( SwFindParas& rParas,
         pFndRing->GetRingContainer().merge( GetRingContainer() );
         delete pFndRing;
     }
-    else if( FND_IN_OTHER & eFndRngs )
+    else if( FindRanges::InOther & eFndRngs )
     {
         // put cursor as copy of current into ring
         // chaining points always to first created, so forward
@@ -999,7 +994,7 @@ sal_uLong SwCursor::FindAll( SwFindParas& rParas,
         }
         pSav.release();
 
-        if( !( FND_IN_SELALL & eFndRngs ))
+        if( !( FindRanges::InSelAll & eFndRngs ))
         {
             // there should only be a single one, thus add it
             // independent from search direction: SPoint is always bigger than
@@ -1021,11 +1016,11 @@ sal_uLong SwCursor::FindAll( SwFindParas& rParas,
         }
         delete pFndRing;
     }
-    else if( FND_IN_SELALL & eFndRngs )
+    else if( FindRanges::InSelAll & eFndRngs )
     {
-        ::std::unique_ptr< SwCursor> pSav( Create( this ) );  // save the current cursor
+        std::unique_ptr< SwCursor> pSav( Create( this ) );    // save the current cursor
 
-        const SwNode* pSttNd = ( FND_IN_BODYONLY & eFndRngs )
+        const SwNode* pSttNd = ( FindRanges::InBodyOnly & eFndRngs )
                             ? rNds.GetEndOfContent().StartOfSectionNode()
                             : rNds.GetEndOfPostIts().StartOfSectionNode();
 
@@ -1065,7 +1060,7 @@ sal_uLong SwCursor::FindAll( SwFindParas& rParas,
         // if a GetMark is set then keep the GetMark of the found object
         // This allows spanning an area with this search.
         SwPosition aMarkPos( *GetMark() );
-        const bool bMarkPos = HasMark() && !eFndRngs;
+        const bool bMarkPos = HasMark() && (eFndRngs == FindRanges::InBody);
 
         if( 0 != (nFound = rParas.Find( this, fnMove,
                                         &aRegion, bInReadOnly ) ? 1 : 0)
@@ -1073,7 +1068,7 @@ sal_uLong SwCursor::FindAll( SwFindParas& rParas,
             *GetMark() = aMarkPos;
     }
 
-    if( nFound && SwCursor::IsSelOvr( nsSwCursorSelOverFlags::SELOVER_TOGGLE ) )
+    if( nFound && SwCursor::IsSelOvr( SwCursorSelOverFlags::Toggle ) )
         nFound = 0;
     return nFound;
 }
@@ -1086,20 +1081,20 @@ void SwCursor::FillFindPos( SwDocPositions ePos, SwPosition& rPos ) const
 
     switch( ePos )
     {
-    case DOCPOS_START:
+    case SwDocPositions::Start:
         rPos.nNode = *rNds.GetEndOfContent().StartOfSectionNode();
         pCNd = rNds.GoNext( &rPos.nNode );
         break;
-    case DOCPOS_END:
+    case SwDocPositions::End:
         rPos.nNode = rNds.GetEndOfContent();
         pCNd = SwNodes::GoPrevious( &rPos.nNode );
         bIsStart = false;
         break;
-    case DOCPOS_OTHERSTART:
+    case SwDocPositions::OtherStart:
         rPos.nNode = *rNds[ sal_uLong(0) ];
         pCNd = rNds.GoNext( &rPos.nNode );
         break;
-    case DOCPOS_OTHEREND:
+    case SwDocPositions::OtherEnd:
         rPos.nNode = *rNds.GetEndOfContent().StartOfSectionNode();
         pCNd = SwNodes::GoPrevious( &rPos.nNode );
         bIsStart = false;
@@ -1154,7 +1149,7 @@ bool SwCursor::GoPrevWord()
     return GoPrevWordWT( WordType::ANYWORD_IGNOREWHITESPACES );
 }
 
-bool SwCursor::SelectWord( SwViewShell* pViewShell, const Point* pPt )
+bool SwCursor::SelectWord( SwViewShell const * pViewShell, const Point* pPt )
 {
     return SelectWordWT( pViewShell, WordType::ANYWORD_IGNOREWHITESPACES, pPt );
 }
@@ -1163,7 +1158,7 @@ bool SwCursor::IsStartWordWT( sal_Int16 nWordType ) const
 {
     bool bRet = false;
     const SwTextNode* pTextNd = GetNode().GetTextNode();
-    if( pTextNd && g_pBreakIt->GetBreakIter().is() )
+    if (pTextNd)
     {
         const sal_Int32 nPtPos = GetPoint()->nContent.GetIndex();
         bRet = g_pBreakIt->GetBreakIter()->isBeginWord(
@@ -1178,7 +1173,7 @@ bool SwCursor::IsEndWordWT( sal_Int16 nWordType ) const
 {
     bool bRet = false;
     const SwTextNode* pTextNd = GetNode().GetTextNode();
-    if( pTextNd && g_pBreakIt->GetBreakIter().is() )
+    if (pTextNd)
     {
         const sal_Int32 nPtPos = GetPoint()->nContent.GetIndex();
         bRet = g_pBreakIt->GetBreakIter()->isEndWord(
@@ -1194,7 +1189,7 @@ bool SwCursor::IsInWordWT( sal_Int16 nWordType ) const
 {
     bool bRet = false;
     const SwTextNode* pTextNd = GetNode().GetTextNode();
-    if( pTextNd && g_pBreakIt->GetBreakIter().is() )
+    if (pTextNd)
     {
         const sal_Int32 nPtPos = GetPoint()->nContent.GetIndex();
         Boundary aBoundary = g_pBreakIt->GetBreakIter()->getWordBoundary(
@@ -1223,7 +1218,7 @@ bool SwCursor::IsStartEndSentence( bool bEnd ) const
 
     if( !bRet )
     {
-        SwCursor aCursor(*GetPoint(), nullptr, false);
+        SwCursor aCursor(*GetPoint(), nullptr);
         SwPosition aOrigPos = *aCursor.GetPoint();
         aCursor.GoSentence( bEnd ? SwCursor::END_SENT : SwCursor::START_SENT );
         bRet = aOrigPos == *aCursor.GetPoint();
@@ -1235,7 +1230,7 @@ bool SwCursor::GoStartWordWT( sal_Int16 nWordType )
 {
     bool bRet = false;
     const SwTextNode* pTextNd = GetNode().GetTextNode();
-    if( pTextNd && g_pBreakIt->GetBreakIter().is() )
+    if (pTextNd)
     {
         SwCursorSaveState aSave( *this );
         sal_Int32 nPtPos = GetPoint()->nContent.GetIndex();
@@ -1259,7 +1254,7 @@ bool SwCursor::GoEndWordWT( sal_Int16 nWordType )
 {
     bool bRet = false;
     const SwTextNode* pTextNd = GetNode().GetTextNode();
-    if( pTextNd && g_pBreakIt->GetBreakIter().is() )
+    if (pTextNd)
     {
         SwCursorSaveState aSave( *this );
         sal_Int32 nPtPos = GetPoint()->nContent.GetIndex();
@@ -1284,7 +1279,7 @@ bool SwCursor::GoNextWordWT( sal_Int16 nWordType )
 {
     bool bRet = false;
     const SwTextNode* pTextNd = GetNode().GetTextNode();
-    if( pTextNd && g_pBreakIt->GetBreakIter().is() )
+    if (pTextNd)
     {
         SwCursorSaveState aSave( *this );
         sal_Int32 nPtPos = GetPoint()->nContent.GetIndex();
@@ -1308,7 +1303,7 @@ bool SwCursor::GoPrevWordWT( sal_Int16 nWordType )
 {
     bool bRet = false;
     const SwTextNode* pTextNd = GetNode().GetTextNode();
-    if( pTextNd && g_pBreakIt->GetBreakIter().is() )
+    if (pTextNd)
     {
         SwCursorSaveState aSave( *this );
         sal_Int32 nPtPos = GetPoint()->nContent.GetIndex();
@@ -1331,7 +1326,7 @@ bool SwCursor::GoPrevWordWT( sal_Int16 nWordType )
     return bRet;
 }
 
-bool SwCursor::SelectWordWT( SwViewShell* pViewShell, sal_Int16 nWordType, const Point* pPt )
+bool SwCursor::SelectWordWT( SwViewShell const * pViewShell, sal_Int16 nWordType, const Point* pPt )
 {
     SwCursorSaveState aSave( *this );
 
@@ -1346,7 +1341,7 @@ bool SwCursor::SelectWordWT( SwViewShell* pViewShell, sal_Int16 nWordType, const
     }
 
     const SwTextNode* pTextNd = GetNode().GetTextNode();
-    if( pTextNd && g_pBreakIt->GetBreakIter().is() )
+    if (pTextNd)
     {
         // Should we select the whole fieldmark?
         const IDocumentMarkAccess* pMarksAccess = GetDoc()->getIDocumentMarkAccess( );
@@ -1379,7 +1374,7 @@ bool SwCursor::SelectWordWT( SwViewShell* pViewShell, sal_Int16 nWordType, const
                                 nWordType,
                                 bForward ));
 
-            if (pViewShell->isTiledRendering() && aBndry.startPos == aBndry.endPos && nPtPos > 0)
+            if (comphelper::LibreOfficeKit::isActive() && aBndry.startPos == aBndry.endPos && nPtPos > 0)
             {
                 // nPtPos is the end of the paragraph, select the last word then.
                 --nPtPos;
@@ -1432,10 +1427,10 @@ static OUString lcl_MaskDeletedRedlines( const SwTextNode* pTextNd )
         //mask deleted redlines
         OUString sNodeText(pTextNd->GetText());
         const SwDoc& rDoc = *pTextNd->GetDoc();
-        const bool bShowChg = IDocumentRedlineAccess::IsShowChanges( rDoc.getIDocumentRedlineAccess().GetRedlineMode() );
+        const bool bShowChg = IDocumentRedlineAccess::IsShowChanges( rDoc.getIDocumentRedlineAccess().GetRedlineFlags() );
         if ( bShowChg )
         {
-            sal_uInt16 nAct = rDoc.getIDocumentRedlineAccess().GetRedlinePos( *pTextNd, USHRT_MAX );
+            SwRedlineTable::size_type nAct = rDoc.getIDocumentRedlineAccess().GetRedlinePos( *pTextNd, USHRT_MAX );
             for ( ; nAct < rDoc.getIDocumentRedlineAccess().GetRedlineTable().size(); nAct++ )
             {
                 const SwRangeRedline* pRed = rDoc.getIDocumentRedlineAccess().GetRedlineTable()[ nAct ];
@@ -1461,7 +1456,7 @@ bool SwCursor::GoSentence( SentenceMoveType eMoveType )
 {
     bool bRet = false;
     const SwTextNode* pTextNd = GetNode().GetTextNode();
-    if( pTextNd && g_pBreakIt->GetBreakIter().is() )
+    if (pTextNd)
     {
         OUString sNodeText( lcl_MaskDeletedRedlines( pTextNd ) );
 
@@ -1524,7 +1519,7 @@ bool SwCursor::ExpandToSentenceBorders()
     bool bRes = false;
     const SwTextNode* pStartNd = Start()->nNode.GetNode().GetTextNode();
     const SwTextNode* pEndNd   = End()->nNode.GetNode().GetTextNode();
-    if (pStartNd && pEndNd && g_pBreakIt->GetBreakIter().is())
+    if (pStartNd && pEndNd)
     {
         if (!HasMark())
             SetMark();
@@ -1629,13 +1624,13 @@ bool SwCursor::LeftRight( bool bLeft, sal_uInt16 nCnt, sal_uInt16 nMode,
 
     // can the cursor be moved n times?
     SwCursorSaveState aSave( *this );
-    SwMoveFn fnMove = bLeft ? fnMoveBackward : fnMoveForward;
+    SwMoveFnCollection const & fnMove = bLeft ? fnMoveBackward : fnMoveForward;
 
     SwGoInDoc fnGo;
     if ( bSkipHidden )
-        fnGo = CRSR_SKIP_CELLS == nMode ? fnGoContentCellsSkipHidden : fnGoContentSkipHidden;
+        fnGo = CRSR_SKIP_CELLS == nMode ? GoInContentCellsSkipHidden : GoInContentSkipHidden;
     else
-        fnGo = CRSR_SKIP_CELLS == nMode ? fnGoContentCells : fnGoContent;
+        fnGo = CRSR_SKIP_CELLS == nMode ? GoInContentCells : GoInContent;
 
     while( nCnt )
     {
@@ -1739,8 +1734,8 @@ bool SwCursor::LeftRight( bool bLeft, sal_uInt16 nCnt, sal_uInt16 nMode,
     }
 
     return 0 == nCnt && !IsInProtectTable( true ) &&
-            !IsSelOvr( nsSwCursorSelOverFlags::SELOVER_TOGGLE |
-                       nsSwCursorSelOverFlags::SELOVER_CHANGEPOS );
+            !IsSelOvr( SwCursorSelOverFlags::Toggle |
+                       SwCursorSelOverFlags::ChangePos );
 }
 
 // calculate cursor bidi level: extracted from UpDown()
@@ -1774,7 +1769,7 @@ void SwCursor::DoSetBidiLevelUpDown()
 }
 
 bool SwCursor::UpDown( bool bUp, sal_uInt16 nCnt,
-                            Point* pPt, long nUpDownX )
+                       Point const * pPt, long nUpDownX )
 {
     SwTableCursor* pTableCursor = dynamic_cast<SwTableCursor*>(this);
     bool bAdjustTableCursor = false;
@@ -1806,8 +1801,8 @@ bool SwCursor::UpDown( bool bUp, sal_uInt16 nCnt,
             aPt = aTmpRect.Pos();
 
             nUpDownX = pFrame->IsVertical() ?
-                aPt.getY() - pFrame->Frame().Top() :
-                aPt.getX() - pFrame->Frame().Left();
+                aPt.getY() - pFrame->getFrameArea().Top() :
+                aPt.getX() - pFrame->getFrameArea().Left();
         }
 
         // It is allowed to move footnotes in other footnotes but not sections
@@ -1828,7 +1823,7 @@ bool SwCursor::UpDown( bool bUp, sal_uInt16 nCnt,
             {
                 const SwNode* pEndNd = pTableNd->EndOfSectionNode();
                 GetPoint()->nNode = *pEndNd;
-                pTableCursor->Move( fnMoveBackward, fnGoNode );
+                pTableCursor->Move( fnMoveBackward, GoInNode );
                    pFrame = GetContentNode()->getLayoutFrame( GetDoc()->getIDocumentLayoutAccess().GetCurrentLayout(), &aPt, GetPoint() );
             }
         }
@@ -1843,12 +1838,13 @@ bool SwCursor::UpDown( bool bUp, sal_uInt16 nCnt,
         }
 
         // iterate over whole number of items?
-        if( !nCnt && !IsSelOvr( nsSwCursorSelOverFlags::SELOVER_TOGGLE |
-                                nsSwCursorSelOverFlags::SELOVER_CHANGEPOS ) )
+        if( !nCnt && !IsSelOvr( SwCursorSelOverFlags::Toggle |
+                                SwCursorSelOverFlags::ChangePos ) )
         {
             if( !pTableCursor )
             {
                 // try to position the cursor at half of the char-rect's height
+                DisableCallbackAction a(*GetDoc()->getIDocumentLayoutAccess().GetCurrentLayout());
                 pFrame = GetContentNode()->getLayoutFrame( GetDoc()->getIDocumentLayoutAccess().GetCurrentLayout(), &aPt, GetPoint() );
                 SwCursorMoveState eTmpState( MV_UPDOWN );
                 eTmpState.m_bSetInReadOnly = bInReadOnly;
@@ -1858,17 +1854,17 @@ bool SwCursor::UpDown( bool bUp, sal_uInt16 nCnt,
                 {
                     aPt.setX(aTmpRect.Center().getX());
                     pFrame->Calc(pFrame->getRootFrame()->GetCurrShell()->GetOut());
-                    aPt.setY(pFrame->Frame().Top() + nUpDownX);
+                    aPt.setY(pFrame->getFrameArea().Top() + nUpDownX);
                 }
                 else
                 {
                     aPt.setY(aTmpRect.Center().getY());
                     pFrame->Calc(pFrame->getRootFrame()->GetCurrShell()->GetOut());
-                    aPt.setX(pFrame->Frame().Left() + nUpDownX);
+                    aPt.setX(pFrame->getFrameArea().Left() + nUpDownX);
                 }
                 pFrame->GetCursorOfst( GetPoint(), aPt, &eTmpState );
             }
-            bRet = !IsSelOvr( nsSwCursorSelOverFlags::SELOVER_TOGGLE | nsSwCursorSelOverFlags::SELOVER_CHANGEPOS );
+            bRet = !IsSelOvr( SwCursorSelOverFlags::Toggle | SwCursorSelOverFlags::ChangePos );
         }
         else
             *GetPoint() = aOldPos;
@@ -1890,7 +1886,7 @@ bool SwCursor::LeftRightMargin( bool bLeft, bool bAPI )
     SwCursorSaveState aSave( *this );
     return pFrame
            && (bLeft ? pFrame->LeftMargin( this ) : pFrame->RightMargin( this, bAPI ) )
-           && !IsSelOvr( nsSwCursorSelOverFlags::SELOVER_TOGGLE | nsSwCursorSelOverFlags::SELOVER_CHANGEPOS );
+           && !IsSelOvr( SwCursorSelOverFlags::Toggle | SwCursorSelOverFlags::ChangePos );
 }
 
 bool SwCursor::IsAtLeftRightMargin( bool bLeft, bool bAPI ) const
@@ -1915,13 +1911,13 @@ bool SwCursor::SttEndDoc( bool bStt )
     SwCursorSaveState aSave( *this );
     // Never jump over section boundaries during selection!
     // Can the cursor still moved on?
-    SwMoveFn fnMove = bStt ? fnMoveBackward : fnMoveForward;
+    SwMoveFnCollection const & fnMove = bStt ? fnMoveBackward : fnMoveForward;
     bool bRet = (!HasMark() || !IsNoContent() ) &&
-                    Move( fnMove, fnGoDoc ) &&
+                    Move( fnMove, GoInDoc ) &&
                     !IsInProtectTable( true ) &&
-                    !IsSelOvr( nsSwCursorSelOverFlags::SELOVER_TOGGLE |
-                               nsSwCursorSelOverFlags::SELOVER_CHANGEPOS |
-                               nsSwCursorSelOverFlags::SELOVER_ENABLEREVDIREKTION );
+                    !IsSelOvr( SwCursorSelOverFlags::Toggle |
+                               SwCursorSelOverFlags::ChangePos |
+                               SwCursorSelOverFlags::EnableRevDirection );
     return bRet;
 }
 
@@ -1965,7 +1961,10 @@ bool SwCursor::GoPrevNextCell( bool bNext, sal_uInt16 nCnt )
             (!bNext && !aCellIdx.GetNode().IsEndNode()) )
             return false;
 
-        rPtIdx = bNext ? aCellIdx : SwNodeIndex(*aCellIdx.GetNode().StartOfSectionNode());
+        if (bNext)
+            rPtIdx = aCellIdx;
+        else
+            rPtIdx.Assign(*aCellIdx.GetNode().StartOfSectionNode());
 
         pTableBoxStartNode = rPtIdx.GetNode().FindTableBoxStartNode();
         pTableBox = pTableBoxStartNode->GetTableBox();
@@ -2004,7 +2003,7 @@ bool SwCursor::GotoTable( const OUString& rName )
             SwCursorSaveState aSave( *this );
             GetPoint()->nNode = *pTmpTable->GetTabSortBoxes()[ 0 ]->
                                 GetSttNd()->FindTableNode();
-            Move( fnMoveForward, fnGoContent );
+            Move( fnMoveForward, GoInContent );
             bRet = !IsSelOvr();
         }
     }
@@ -2025,28 +2024,28 @@ bool SwCursor::GotoTableBox( const OUString& rName )
         {
             SwCursorSaveState aSave( *this );
             GetPoint()->nNode = *pTableBox->GetSttNd();
-            Move( fnMoveForward, fnGoContent );
+            Move( fnMoveForward, GoInContent );
             bRet = !IsSelOvr();
         }
     }
     return bRet;
 }
 
-bool SwCursor::MovePara(SwWhichPara fnWhichPara, SwPosPara fnPosPara )
+bool SwCursor::MovePara(SwWhichPara fnWhichPara, SwMoveFnCollection const & fnPosPara )
 {
     // for optimization test something before
     const SwNode* pNd = &GetPoint()->nNode.GetNode();
     bool bShortCut = false;
-    if ( fnWhichPara == fnParaCurr )
+    if ( fnWhichPara == GoCurrPara )
     {
         // #i41048#
-        // If fnWhichPara == fnParaCurr then (*fnWhichPara)( *this, fnPosPara )
+        // If fnWhichPara == GoCurrPara then (*fnWhichPara)( *this, fnPosPara )
         // can already move the cursor to a different text node. In this case
         // we better check if IsSelOvr().
         const SwContentNode* pContentNd = pNd->GetContentNode();
         if ( pContentNd )
         {
-            const sal_Int32 nSttEnd = fnPosPara == fnMoveForward ? 0 : pContentNd->Len();
+            const sal_Int32 nSttEnd = &fnPosPara == &fnMoveForward ? 0 : pContentNd->Len();
             if ( GetPoint()->nContent.GetIndex() != nSttEnd )
                 bShortCut = true;
         }
@@ -2055,7 +2054,7 @@ bool SwCursor::MovePara(SwWhichPara fnWhichPara, SwPosPara fnPosPara )
     {
         if ( pNd->IsTextNode() &&
              pNd->GetNodes()[ pNd->GetIndex() +
-                    (fnWhichPara == fnParaNext ? 1 : -1 ) ]->IsTextNode() )
+                    (fnWhichPara == GoNextPara ? 1 : -1 ) ]->IsTextNode() )
             bShortCut = true;
     }
 
@@ -2067,18 +2066,18 @@ bool SwCursor::MovePara(SwWhichPara fnWhichPara, SwPosPara fnPosPara )
     SwCursorSaveState aSave( *this );
     return (*fnWhichPara)( *this, fnPosPara ) &&
             !IsInProtectTable( true ) &&
-            !IsSelOvr( nsSwCursorSelOverFlags::SELOVER_TOGGLE |
-                       nsSwCursorSelOverFlags::SELOVER_CHANGEPOS );
+            !IsSelOvr( SwCursorSelOverFlags::Toggle |
+                       SwCursorSelOverFlags::ChangePos );
 }
 
 bool SwCursor::MoveSection( SwWhichSection fnWhichSect,
-                                SwPosSection fnPosSect)
+                                SwMoveFnCollection const & fnPosSect)
 {
     SwCursorSaveState aSave( *this );
     return (*fnWhichSect)( *this, fnPosSect ) &&
             !IsInProtectTable( true ) &&
-            !IsSelOvr( nsSwCursorSelOverFlags::SELOVER_TOGGLE |
-                       nsSwCursorSelOverFlags::SELOVER_CHANGEPOS );
+            !IsSelOvr( SwCursorSelOverFlags::Toggle |
+                       SwCursorSelOverFlags::ChangePos );
 }
 
 void SwCursor::RestoreSavePos()
@@ -2108,13 +2107,15 @@ void SwCursor::RestoreSavePos()
     }
 }
 
-SwTableCursor::SwTableCursor( const SwPosition &rPos, SwPaM* pRing )
-    : SwCursor( rPos, pRing, false )
+SwTableCursor::SwTableCursor( const SwPosition &rPos )
+    : SwCursor( rPos, nullptr )
 {
     m_bParked = false;
     m_bChanged = false;
-    m_nTablePtNd = 0, m_nTableMkNd = 0;
-    m_nTablePtCnt = 0, m_nTableMkCnt = 0;
+    m_nTablePtNd = 0;
+    m_nTableMkNd = 0;
+    m_nTablePtCnt = 0;
+    m_nTableMkCnt = 0;
 }
 
 SwTableCursor::~SwTableCursor() {}
@@ -2264,8 +2265,8 @@ void SwTableCursor::DeleteBox(size_t const nPos)
 bool SwTableCursor::NewTableSelection()
 {
     bool bRet = false;
-    const SwNode *pStart = GetContentNode()->FindTableBoxStartNode();
-    const SwNode *pEnd = GetContentNode(false)->FindTableBoxStartNode();
+    const SwNode *pStart = GetNode().FindTableBoxStartNode();
+    const SwNode *pEnd = GetNode(false).FindTableBoxStartNode();
     if( pStart && pEnd )
     {
         const SwTableNode *pTableNode = pStart->FindTableNode();
