@@ -31,6 +31,7 @@
 #include <pagedesc.hxx>
 #include <poolfmt.hxx>
 #include <calbck.hxx>
+#include <IDocumentStylePoolAccess.hxx>
 #include <editeng/svxacorr.hxx>
 
 #include <editeng/acorrcfg.hxx>
@@ -49,7 +50,7 @@ class SwAutoCompleteClient : public SwClient
 public:
     SwAutoCompleteClient(SwAutoCompleteWord& rToTell, SwDoc& rSwDoc);
     SwAutoCompleteClient(const SwAutoCompleteClient& rClient);
-    ~SwAutoCompleteClient();
+    virtual ~SwAutoCompleteClient() override;
 
     SwAutoCompleteClient& operator=(const SwAutoCompleteClient& rClient);
 
@@ -58,7 +59,7 @@ public:
     static sal_uLong GetElementCount() {return nSwAutoCompleteClientCount;}
 #endif
 protected:
-    virtual void Modify( const SfxPoolItem* pOld, const SfxPoolItem *pNew);
+    virtual void Modify( const SfxPoolItem* pOld, const SfxPoolItem *pNew) override;
 };
 
 typedef std::vector<SwAutoCompleteClient> SwAutoCompleteClientVector;
@@ -68,14 +69,13 @@ class SwAutoCompleteWord_Impl
     SwAutoCompleteClientVector  aClientVector;
     SwAutoCompleteWord&         rAutoCompleteWord;
 public:
-    SwAutoCompleteWord_Impl(SwAutoCompleteWord& rParent) :
+    explicit SwAutoCompleteWord_Impl(SwAutoCompleteWord& rParent) :
         rAutoCompleteWord(rParent){}
     void AddDocument(SwDoc& rDoc);
     void RemoveDocument(const SwDoc& rDoc);
 };
 
-typedef const SwDoc* SwDocPtr;
-typedef std::vector<SwDocPtr> SwDocPtrVector;
+typedef std::vector<const SwDoc*> SwDocPtrVector;
 class SwAutoCompleteString
     : public editeng::IAutoCompleteString
 {
@@ -84,9 +84,9 @@ class SwAutoCompleteString
 #endif
     SwDocPtrVector aSourceDocs;
     public:
-        SwAutoCompleteString(const OUString& rStr, xub_StrLen nPos, xub_StrLen nLen);
+        SwAutoCompleteString(const OUString& rStr, sal_Int32 nLen);
 
-        ~SwAutoCompleteString();
+        virtual ~SwAutoCompleteString() override;
         void        AddDocument(const SwDoc& rDoc);
         //returns true if last document reference has been removed
         bool        RemoveDocument(const SwDoc& rDoc);
@@ -103,7 +103,7 @@ SwAutoCompleteClient::SwAutoCompleteClient(SwAutoCompleteWord& rToTell, SwDoc& r
         pAutoCompleteWord(&rToTell),
         pDoc(&rSwDoc)
 {
-    pDoc->GetPageDescFromPool(RES_POOLPAGE_STANDARD)->Add(this);
+    pDoc->getIDocumentStylePoolAccess().GetPageDescFromPool(RES_POOLPAGE_STANDARD)->Add(this);
 #if OSL_DEBUG_LEVEL > 0
     ++nSwAutoCompleteClientCount;
 #endif
@@ -114,7 +114,7 @@ SwAutoCompleteClient::SwAutoCompleteClient(const SwAutoCompleteClient& rClient)
     pAutoCompleteWord(rClient.pAutoCompleteWord),
     pDoc(rClient.pDoc)
 {
-    pDoc->GetPageDescFromPool(RES_POOLPAGE_STANDARD)->Add(this);
+    pDoc->getIDocumentStylePoolAccess().GetPageDescFromPool(RES_POOLPAGE_STANDARD)->Add(this);
 #if OSL_DEBUG_LEVEL > 0
     ++nSwAutoCompleteClientCount;
 #endif
@@ -124,6 +124,8 @@ SwAutoCompleteClient::~SwAutoCompleteClient()
 {
 #if OSL_DEBUG_LEVEL > 0
     --nSwAutoCompleteClientCount;
+#else
+    (void) this;
 #endif
 }
 
@@ -132,7 +134,7 @@ SwAutoCompleteClient& SwAutoCompleteClient::operator=(const SwAutoCompleteClient
     pAutoCompleteWord = rClient.pAutoCompleteWord;
     pDoc = rClient.pDoc;
     if(rClient.GetRegisteredIn())
-        ((SwModify*)rClient.GetRegisteredIn())->Add(this);
+        const_cast<SwModify*>(rClient.GetRegisteredIn())->Add(this);
     else if(GetRegisteredIn())
         GetRegisteredInNonConst()->Remove(this);
     return *this;
@@ -144,8 +146,8 @@ void SwAutoCompleteClient::Modify( const SfxPoolItem* pOld, const SfxPoolItem *)
     {
     case RES_REMOVE_UNO_OBJECT:
     case RES_OBJECTDYING:
-        if( (void*)GetRegisteredIn() == ((SwPtrMsgPoolItem *)pOld)->pObject )
-            ((SwModify*)GetRegisteredIn())->Remove(this);
+        if( static_cast<void*>(GetRegisteredIn()) == static_cast<const SwPtrMsgPoolItem *>(pOld)->pObject )
+            GetRegisteredIn()->Remove(this);
         pAutoCompleteWord->DocumentDying(*pDoc);
         break;
     }
@@ -159,7 +161,7 @@ void SwAutoCompleteWord_Impl::AddDocument(SwDoc& rDoc)
         if(&aIt->GetDoc() == &rDoc)
             return;
     }
-    aClientVector.push_back(SwAutoCompleteClient(rAutoCompleteWord, rDoc));
+    aClientVector.emplace_back(rAutoCompleteWord, rDoc);
 }
 
 void SwAutoCompleteWord_Impl::RemoveDocument(const SwDoc& rDoc)
@@ -176,8 +178,8 @@ void SwAutoCompleteWord_Impl::RemoveDocument(const SwDoc& rDoc)
 }
 
 SwAutoCompleteString::SwAutoCompleteString(
-            const OUString& rStr, xub_StrLen const nPos, xub_StrLen const nLen)
-    : editeng::IAutoCompleteString(rStr.copy(nPos, nLen))
+            const OUString& rStr, sal_Int32 const nLen)
+    : editeng::IAutoCompleteString(rStr.copy(0, nLen))
 {
 #if OSL_DEBUG_LEVEL > 0
     ++nSwAutoCompleteStringCount;
@@ -188,6 +190,8 @@ SwAutoCompleteString::~SwAutoCompleteString()
 {
 #if OSL_DEBUG_LEVEL > 0
     --nSwAutoCompleteStringCount;
+#else
+    (void) this;
 #endif
 }
 
@@ -214,18 +218,18 @@ bool SwAutoCompleteString::RemoveDocument(const SwDoc& rDoc)
     return false;
 }
 
-SwAutoCompleteWord::SwAutoCompleteWord( sal_uInt16 nWords, sal_uInt16 nMWrdLen ) :
+SwAutoCompleteWord::SwAutoCompleteWord(
+    editeng::SortedAutoCompleteStrings::size_type nWords, sal_uInt16 nMWrdLen ):
     pImpl(new SwAutoCompleteWord_Impl(*this)),
     nMaxCount( nWords ),
     nMinWrdLen( nMWrdLen ),
-    bLockWordLst( sal_False )
+    bLockWordLst( false )
 {
 }
 
 SwAutoCompleteWord::~SwAutoCompleteWord()
 {
     m_WordList.DeleteAndDestroyAll(); // so the assertion below works
-    delete pImpl;
 #if OSL_DEBUG_LEVEL > 0
     sal_uLong nStrings = SwAutoCompleteString::GetElementCount();
     sal_uLong nClients = SwAutoCompleteClient::GetElementCount();
@@ -236,18 +240,17 @@ SwAutoCompleteWord::~SwAutoCompleteWord()
 bool SwAutoCompleteWord::InsertWord( const OUString& rWord, SwDoc& rDoc )
 {
     SwDocShell* pDocShell = rDoc.GetDocShell();
-    SfxMedium* pMedium = pDocShell ? pDocShell->GetMedium() : 0;
+    SfxMedium* pMedium = pDocShell ? pDocShell->GetMedium() : nullptr;
     // strings from help module should not be added
     if( pMedium )
     {
         const INetURLObject& rURL = pMedium->GetURLObject();
-        if ( rURL.GetProtocol() == INET_PROT_VND_SUN_STAR_HELP )
-            return sal_False;
+        if ( rURL.GetProtocol() == INetProtocol::VndSunStarHelp )
+            return false;
     }
 
-    OUString aNewWord(rWord);
-    aNewWord = comphelper::string::remove(aNewWord, CH_TXTATR_INWORD);
-    aNewWord = comphelper::string::remove(aNewWord, CH_TXTATR_BREAKWORD);
+    OUString aNewWord = rWord.replaceAll(OUStringLiteral1(CH_TXTATR_INWORD), "")
+                             .replaceAll(OUStringLiteral1(CH_TXTATR_BREAKWORD), "");
 
     pImpl->AddDocument(rDoc);
     bool bRet = false;
@@ -257,12 +260,12 @@ bool SwAutoCompleteWord::InsertWord( const OUString& rWord, SwDoc& rDoc )
 
     if( !bLockWordLst && nWrdLen >= nMinWrdLen )
     {
-        SwAutoCompleteString* pNew = new SwAutoCompleteString( aNewWord, 0, nWrdLen );
+        SwAutoCompleteString* pNew = new SwAutoCompleteString( aNewWord, nWrdLen );
         pNew->AddDocument(rDoc);
         std::pair<editeng::SortedAutoCompleteStrings::const_iterator, bool>
             aInsPair = m_WordList.insert(pNew);
 
-        m_LookupTree.insert( OUString(aNewWord).copy(0, nWrdLen) );
+        m_LookupTree.insert( aNewWord.copy(0, nWrdLen) );
 
         if (aInsPair.second)
         {
@@ -282,7 +285,7 @@ bool SwAutoCompleteWord::InsertWord( const OUString& rWord, SwDoc& rDoc )
         {
             delete pNew;
             // then move "up"
-            pNew = (SwAutoCompleteString*)(*aInsPair.first);
+            pNew = static_cast<SwAutoCompleteString*>(*aInsPair.first);
 
             // add the document to the already inserted string
             pNew->AddDocument(rDoc);
@@ -300,12 +303,13 @@ bool SwAutoCompleteWord::InsertWord( const OUString& rWord, SwDoc& rDoc )
     return bRet;
 }
 
-void SwAutoCompleteWord::SetMaxCount( sal_uInt16 nNewMax )
+void SwAutoCompleteWord::SetMaxCount(
+    editeng::SortedAutoCompleteStrings::size_type nNewMax )
 {
     if( nNewMax < nMaxCount && aLRULst.size() > nNewMax )
     {
         // remove the trailing ones
-        sal_uInt16 nLRUIndex = nNewMax-1;
+        SwAutoCompleteStringPtrDeque::size_type nLRUIndex = nNewMax-1;
         while (nNewMax < m_WordList.size() && nLRUIndex < aLRULst.size())
         {
             editeng::SortedAutoCompleteStrings::const_iterator it =
@@ -348,21 +352,19 @@ void SwAutoCompleteWord::SetMinWordLen( sal_uInt16 n )
  *  @param aMatch the prefix to search for
  *  @param aWords the words to search in
  */
-bool SwAutoCompleteWord::GetWordsMatching(OUString aMatch, std::vector<OUString>& aWords) const
+bool SwAutoCompleteWord::GetWordsMatching(const OUString& aMatch, std::vector<OUString>& aWords) const
 {
-    OUString aStringRoot = aMatch;
-
     std::vector<OUString> suggestions;
-    m_LookupTree.findSuggestions(aStringRoot, suggestions);
+    m_LookupTree.findSuggestions(aMatch, suggestions);
 
     if (suggestions.empty())
     {
         return false;
     }
 
-    for (size_t i = 0; i < suggestions.size(); i++)
+    for (const OUString & suggestion : suggestions)
     {
-        aWords.push_back( suggestions[i] );
+        aWords.push_back( suggestion );
     }
 
     return true;
@@ -414,12 +416,11 @@ void SwAutoCompleteWord::DocumentDying(const SwDoc& rDoc)
     pImpl->RemoveDocument(rDoc);
 
     SvxAutoCorrect* pACorr = SvxAutoCorrCfg::Get().GetAutoCorrect();
-    const sal_Bool bDelete = !pACorr->GetSwFlags().bAutoCmpltKeepList;
+    const bool bDelete = !pACorr->GetSwFlags().bAutoCmpltKeepList;
     for (size_t nPos = m_WordList.size(); nPos; nPos--)
     {
-        SwAutoCompleteString *const pCurrent =
-            dynamic_cast<SwAutoCompleteString*>(m_WordList[nPos - 1]);
-        if(pCurrent->RemoveDocument(rDoc) && bDelete)
+        SwAutoCompleteString *const pCurrent = dynamic_cast<SwAutoCompleteString*>(m_WordList[nPos - 1]);
+        if(pCurrent && pCurrent->RemoveDocument(rDoc) && bDelete)
         {
             m_WordList.erase(nPos - 1);
             SwAutoCompleteStringPtrDeque::iterator it = std::find( aLRULst.begin(), aLRULst.end(), pCurrent );
