@@ -19,9 +19,7 @@
 
 #include <unotools/linguprops.hxx>
 #include <unotools/lingucfg.hxx>
-#include <com/sun/star/embed/EmbedStates.hpp>
 #include <hintids.hxx>
-#include <com/sun/star/util/XCloseable.hpp>
 #include <sfx2/progress.hxx>
 #include <svx/svdmodel.hxx>
 #include <svx/svdpage.hxx>
@@ -93,7 +91,7 @@
 #include <ftninfo.hxx>
 #include <pagedesc.hxx>
 #include <PostItMgr.hxx>
-#include <comcore.hrc>
+#include <strings.hrc>
 #include <tools/datetimeutils.hxx>
 
 #include <unoframe.hxx>
@@ -128,7 +126,7 @@ SdrObject* SwDoc::CloneSdrObj( const SdrObject& rObj, bool bMoveWithinDoc,
     }
 
     SdrObject *pObj = rObj.Clone();
-    if( bMoveWithinDoc && FmFormInventor == pObj->GetObjInventor() )
+    if( bMoveWithinDoc && SdrInventor::FmForm == pObj->GetObjInventor() )
     {
         // We need to preserve the Name for Controls
         uno::Reference< awt::XControlModel >  xModel = static_cast<SdrUnoObj*>(pObj)->GetUnoControlModel();
@@ -161,7 +159,7 @@ SdrObject* SwDoc::CloneSdrObj( const SdrObject& rObj, bool bMoveWithinDoc,
     return pObj;
 }
 
-SwFlyFrameFormat* SwDoc::_MakeFlySection( const SwPosition& rAnchPos,
+SwFlyFrameFormat* SwDoc::MakeFlySection_( const SwPosition& rAnchPos,
                                     const SwContentNode& rNode,
                                     RndStdIds eRequestId,
                                     const SfxItemSet* pFlySet,
@@ -174,8 +172,8 @@ SwFlyFrameFormat* SwDoc::_MakeFlySection( const SwPosition& rAnchPos,
     if( !mbInReading )
         switch( rNode.GetNodeType() )
         {
-        case ND_GRFNODE:        sName = GetUniqueGrfName();     break;
-        case ND_OLENODE:        sName = GetUniqueOLEName();     break;
+        case SwNodeType::Grf:        sName = GetUniqueGrfName();     break;
+        case SwNodeType::Ole:        sName = GetUniqueOLEName();     break;
         default:                sName = GetUniqueFrameName();   break;
         }
     SwFlyFrameFormat* pFormat = MakeFlyFrameFormat( sName, pFrameFormat );
@@ -208,19 +206,19 @@ SwFlyFrameFormat* SwDoc::_MakeFlySection( const SwPosition& rAnchPos,
     // #i107811# Assure that at-page anchored fly frames have a page num or a
     // content anchor set.
     if ( !pAnchor ||
-         ( FLY_AT_PAGE != pAnchor->GetAnchorId() &&
+         ( RndStdIds::FLY_AT_PAGE != pAnchor->GetAnchorId() &&
            !pAnchor->GetContentAnchor() ) ||
-         ( FLY_AT_PAGE == pAnchor->GetAnchorId() &&
+         ( RndStdIds::FLY_AT_PAGE == pAnchor->GetAnchorId() &&
            !pAnchor->GetContentAnchor() &&
            pAnchor->GetPageNum() == 0 ) )
     {
         // set it again, needed for Undo
         SwFormatAnchor aAnch( pFormat->GetAnchor() );
-        if (pAnchor && (FLY_AT_FLY == pAnchor->GetAnchorId()))
+        if (pAnchor && (RndStdIds::FLY_AT_FLY == pAnchor->GetAnchorId()))
         {
             SwPosition aPos( *rAnchPos.nNode.GetNode().FindFlyStartNode() );
             aAnch.SetAnchor( &aPos );
-            eAnchorId = FLY_AT_FLY;
+            eAnchorId = RndStdIds::FLY_AT_FLY;
         }
         else
         {
@@ -231,7 +229,7 @@ SwFlyFrameFormat* SwDoc::_MakeFlySection( const SwPosition& rAnchPos,
             }
 
             eAnchorId = aAnch.GetAnchorId();
-            if ( FLY_AT_PAGE != eAnchorId || !pAnchor || aAnch.GetPageNum() == 0)
+            if ( RndStdIds::FLY_AT_PAGE != eAnchorId || !pAnchor || aAnch.GetPageNum() == 0)
             {
                 aAnch.SetAnchor( &rAnchPos );
             }
@@ -241,7 +239,7 @@ SwFlyFrameFormat* SwDoc::_MakeFlySection( const SwPosition& rAnchPos,
     else
         eAnchorId = pFormat->GetAnchor().GetAnchorId();
 
-    if ( FLY_AS_CHAR == eAnchorId )
+    if ( RndStdIds::FLY_AS_CHAR == eAnchorId )
     {
         const sal_Int32 nStt = rAnchPos.nContent.GetIndex();
         SwTextNode * pTextNode = rAnchPos.nNode.GetNode().GetTextNode();
@@ -301,7 +299,7 @@ SwFlyFrameFormat* SwDoc::MakeFlySection( RndStdIds eAnchorType,
                                     SwFrameFormat* pFrameFormat, bool bCalledFromShell )
 {
     SwFlyFrameFormat* pFormat = nullptr;
-    if ( !pAnchorPos && (FLY_AT_PAGE != eAnchorType) )
+    if ( !pAnchorPos && (RndStdIds::FLY_AT_PAGE != eAnchorType) )
     {
         const SwFormatAnchor* pAnch;
         if( (pFlySet && SfxItemState::SET == pFlySet->GetItemState(
@@ -309,7 +307,7 @@ SwFlyFrameFormat* SwDoc::MakeFlySection( RndStdIds eAnchorType,
             ( pFrameFormat && SfxItemState::SET == pFrameFormat->GetItemState(
                 RES_ANCHOR, true, reinterpret_cast<const SfxPoolItem**>(&pAnch) )) )
         {
-            if ( (FLY_AT_PAGE != pAnch->GetAnchorId()) )
+            if ( RndStdIds::FLY_AT_PAGE != pAnch->GetAnchorId() )
             {
                 pAnchorPos = pAnch->GetContentAnchor();
             }
@@ -338,10 +336,10 @@ SwFlyFrameFormat* SwDoc::MakeFlySection( RndStdIds eAnchorType,
             SfxItemState::SET == pAnchorNode->GetSwAttrSet().
             GetItemState(RES_PARATR_ADJUST, true, &pItem))
         {
-            static_cast<SwContentNode *>(pNewTextNd)->SetAttr(*pItem);
+            pNewTextNd->SetAttr(*pItem);
         }
 
-         pFormat = _MakeFlySection( *pAnchorPos, *pNewTextNd,
+         pFormat = MakeFlySection_( *pAnchorPos, *pNewTextNd,
                                 eAnchorType, pFlySet, pFrameFormat );
     }
     return pFormat;
@@ -353,7 +351,7 @@ SwFlyFrameFormat* SwDoc::MakeFlyAndMove( const SwPaM& rPam, const SfxItemSet& rS
 {
     const SwFormatAnchor& rAnch = static_cast<const SwFormatAnchor&>(rSet.Get( RES_ANCHOR ));
 
-    GetIDocumentUndoRedo().StartUndo( UNDO_INSLAYFMT, nullptr );
+    GetIDocumentUndoRedo().StartUndo( SwUndoId::INSLAYFMT, nullptr );
 
     SwFlyFrameFormat* pFormat = MakeFlySection( rAnch.GetAnchorId(), rPam.GetPoint(),
                                         &rSet, pParent );
@@ -460,7 +458,7 @@ SwFlyFrameFormat* SwDoc::MakeFlyAndMove( const SwPaM& rPam, const SfxItemSet& rS
 
     getIDocumentState().SetModified();
 
-    GetIDocumentUndoRedo().EndUndo( UNDO_INSLAYFMT, nullptr );
+    GetIDocumentUndoRedo().EndUndo( SwUndoId::INSLAYFMT, nullptr );
 
     return pFormat;
 }
@@ -483,7 +481,7 @@ static bool lcl_TstFlyRange( const SwPaM* pPam, const SwPosition* pFlyPos,
         const SwPosition* pPaMEnd = pTmp->End();
         const sal_uInt32 nPamStartIndex = pPaMStart->nNode.GetIndex();
         const sal_uInt32 nPamEndIndex = pPaMEnd->nNode.GetIndex();
-        if (FLY_AT_PARA == nAnchorId)
+        if (RndStdIds::FLY_AT_PARA == nAnchorId)
             bOk = (nPamStartIndex < nFlyIndex && nPamEndIndex > nFlyIndex) ||
                (((nPamStartIndex == nFlyIndex) && (pPaMStart->nContent.GetIndex() == 0)) &&
                (nPamEndIndex > nFlyIndex));
@@ -502,7 +500,7 @@ static bool lcl_TstFlyRange( const SwPaM* pPam, const SwPosition* pFlyPos,
                      (nPamEndContentIndex > nFlyContentIndex )));
         }
 
-    } while( !bOk && pPam != ( pTmp = static_cast<const SwPaM*>(pTmp->GetNext()) ));
+    } while( !bOk && pPam != ( pTmp = pTmp->GetNext() ));
     return bOk;
 }
 
@@ -521,15 +519,15 @@ SwPosFlyFrames SwDoc::GetAllFlyFormats( const SwPaM* pCmpRange, bool bDrawAlso,
             const SwFormatAnchor& rAnchor = pFly->GetAnchor();
             SwPosition const*const pAPos = rAnchor.GetContentAnchor();
             if (pAPos &&
-                ((FLY_AT_PARA == rAnchor.GetAnchorId()) ||
-                 (FLY_AT_FLY  == rAnchor.GetAnchorId()) ||
-                 (FLY_AT_CHAR == rAnchor.GetAnchorId()) ||
-                 ((FLY_AS_CHAR == rAnchor.GetAnchorId()) && bAsCharAlso)))
+                ((RndStdIds::FLY_AT_PARA == rAnchor.GetAnchorId()) ||
+                 (RndStdIds::FLY_AT_FLY  == rAnchor.GetAnchorId()) ||
+                 (RndStdIds::FLY_AT_CHAR == rAnchor.GetAnchorId()) ||
+                 ((RndStdIds::FLY_AS_CHAR == rAnchor.GetAnchorId()) && bAsCharAlso)))
             {
                 if( pCmpRange &&
                     !lcl_TstFlyRange( pCmpRange, pAPos, rAnchor.GetAnchorId() ))
                         continue;       // not a valid FlyFrame
-                aRetval.insert(SwPosFlyFramePtr(new SwPosFlyFrame(pAPos->nNode, pFly, aRetval.size())));
+                aRetval.insert(std::make_shared<SwPosFlyFrame>(pAPos->nNode, pFly, aRetval.size()));
             }
         }
     }
@@ -547,9 +545,8 @@ SwPosFlyFrames SwDoc::GetAllFlyFormats( const SwPaM* pCmpRange, bool bDrawAlso,
         if( pPage->GetSortedObjs() )
         {
             const SwSortedObjs &rObjs = *pPage->GetSortedObjs();
-            for( size_t i = 0; i < rObjs.size(); ++i)
+            for(SwAnchoredObject* pAnchoredObj : rObjs)
             {
-                SwAnchoredObject* pAnchoredObj = rObjs[i];
                 SwFrameFormat *pFly;
                 if ( dynamic_cast<const SwFlyFrame*>( pAnchoredObj) !=  nullptr )
                     pFly = &(pAnchoredObj->GetFrameFormat());
@@ -559,9 +556,9 @@ SwPosFlyFrames SwDoc::GetAllFlyFormats( const SwPaM* pCmpRange, bool bDrawAlso,
                     continue;
 
                 const SwFormatAnchor& rAnchor = pFly->GetAnchor();
-                if ((FLY_AT_PARA != rAnchor.GetAnchorId()) &&
-                    (FLY_AT_FLY  != rAnchor.GetAnchorId()) &&
-                    (FLY_AT_CHAR != rAnchor.GetAnchorId()))
+                if ((RndStdIds::FLY_AT_PARA != rAnchor.GetAnchorId()) &&
+                    (RndStdIds::FLY_AT_FLY  != rAnchor.GetAnchorId()) &&
+                    (RndStdIds::FLY_AT_CHAR != rAnchor.GetAnchorId()))
                 {
                     const SwContentFrame * pContentFrame = pPage->FindFirstBodyContent();
                     if ( !pContentFrame )
@@ -579,7 +576,7 @@ SwPosFlyFrames SwDoc::GetAllFlyFormats( const SwPaM* pCmpRange, bool bDrawAlso,
                     if ( pContentFrame )
                     {
                         SwNodeIndex aIdx( *pContentFrame->GetNode() );
-                        aRetval.insert(SwPosFlyFramePtr(new SwPosFlyFrame(aIdx, pFly, aRetval.size())));
+                        aRetval.insert(std::make_shared<SwPosFlyFrame>(aIdx, pFly, aRetval.size()));
                     }
                 }
             }
@@ -647,7 +644,7 @@ lcl_InsertLabel(SwDoc & rDoc, SwTextFormatColls *const pTextFormatCollTable,
     OSL_ENSURE( nId == USHRT_MAX  || nId < rDoc.getIDocumentFieldsAccess().GetFieldTypes()->size(),
             "FieldType index out of bounds." );
     SwFieldType *pType = (nId != USHRT_MAX) ? (*rDoc.getIDocumentFieldsAccess().GetFieldTypes())[nId] : nullptr;
-    OSL_ENSURE(!pType || pType->Which() == RES_SETEXPFLD, "wrong Id for Label");
+    OSL_ENSURE(!pType || pType->Which() == SwFieldIds::SetExp, "wrong Id for Label");
 
     SwTextFormatColl * pColl = nullptr;
     if( pType )
@@ -675,9 +672,9 @@ lcl_InsertLabel(SwDoc & rDoc, SwTextFormatColls *const pTextFormatCollTable,
     {
         case LTYPE_TABLE:
             bTable = true;
-            // no break here
+            SAL_FALLTHROUGH;
         case LTYPE_FLY:
-            // At the FlySection's Beginning/End insert the corresponding Node with it's Field.
+            // At the FlySection's Beginning/End insert the corresponding Node with its Field.
             // The Frame is created automatically.
             {
                 SwStartNode *pSttNd = rDoc.GetNodes()[nNdIdx]->GetStartNode();
@@ -794,7 +791,7 @@ lcl_InsertLabel(SwDoc & rDoc, SwTextFormatColls *const pTextFormatCollTable,
                 // To avoid this, we disconnect the attribute from the Format.
 
                 const SwFormatAnchor& rAnchor = pNewFormat->GetAnchor();
-                if ( FLY_AS_CHAR == rAnchor.GetAnchorId() )
+                if ( RndStdIds::FLY_AS_CHAR == rAnchor.GetAnchorId() )
                 {
                     const SwPosition *pPos = rAnchor.GetContentAnchor();
                     SwTextNode *pTextNode = pPos->nNode.GetNode().GetTextNode();
@@ -803,9 +800,11 @@ lcl_InsertLabel(SwDoc & rDoc, SwTextFormatColls *const pTextFormatCollTable,
                     SwTextAttr * const pHint =
                         pTextNode->GetTextAttrForCharAt(nIdx, RES_TXTATR_FLYCNT);
 
-                    OSL_ENSURE( pHint && pHint->Which() == RES_TXTATR_FLYCNT,
+                    assert(pHint && "Missing Hint.");
+
+                    OSL_ENSURE( pHint->Which() == RES_TXTATR_FLYCNT,
                                 "Missing FlyInCnt-Hint." );
-                    OSL_ENSURE( pHint && pHint->GetFlyCnt().GetFrameFormat() == pOldFormat,
+                    OSL_ENSURE( pHint->GetFlyCnt().GetFrameFormat() == pOldFormat,
                                 "Wrong TextFlyCnt-Hint." );
 
                     const_cast<SwFormatFlyCnt&>(pHint->GetFlyCnt()).SetFlyFormat(
@@ -814,10 +813,10 @@ lcl_InsertLabel(SwDoc & rDoc, SwTextFormatColls *const pTextFormatCollTable,
 
                 // The old one should not have a flow and it should be adjusted to above and
                 // middle.
-                // Also, the width should be 100% and it should also adjust the hight, if changed.
+                // Also, the width should be 100% and it should also adjust the height, if changed.
                 pNewSet->ClearItem();
 
-                pNewSet->Put( SwFormatSurround( SURROUND_NONE ) );
+                pNewSet->Put( SwFormatSurround( css::text::WrapTextMode_NONE ) );
                 pNewSet->Put( SvxOpaqueItem( RES_OPAQUE, true ) );
 
                 sal_Int16 eVert = bBefore ? text::VertOrientation::BOTTOM : text::VertOrientation::TOP;
@@ -852,7 +851,7 @@ lcl_InsertLabel(SwDoc & rDoc, SwTextFormatColls *const pTextFormatCollTable,
                 pNewSet->Put( SvxULSpaceItem(RES_UL_SPACE) );
 
                 // The old one is paragraph-bound to the paragraph in the new one.
-                SwFormatAnchor aAnch( FLY_AT_PARA );
+                SwFormatAnchor aAnch( RndStdIds::FLY_AT_PARA );
                 SwNodeIndex aAnchIdx( *pNewFormat->GetContent().GetContentIdx(), 1 );
                 pNew = aAnchIdx.GetNode().GetTextNode();
                 SwPosition aPos( aAnchIdx );
@@ -923,7 +922,7 @@ lcl_InsertLabel(SwDoc & rDoc, SwTextFormatColls *const pTextFormatCollTable,
                 SwCharFormat* pCharFormat = rDoc.FindCharFormatByName(rCharacterStyle);
                 if( !pCharFormat )
                 {
-                    const sal_uInt16 nMyId = SwStyleNameMapper::GetPoolIdFromUIName(rCharacterStyle, nsSwGetPoolIdFromName::GET_POOLID_CHRFMT);
+                    const sal_uInt16 nMyId = SwStyleNameMapper::GetPoolIdFromUIName(rCharacterStyle, SwGetPoolIdFromName::ChrFmt);
                     pCharFormat = rDoc.getIDocumentStylePoolAccess().GetCharFormatFromPool( nMyId );
                 }
                 if (pCharFormat)
@@ -972,7 +971,7 @@ SwDoc::InsertLabel(
     {
         pUndo = new SwUndoInsertLabel(
                         eType, rText, rSeparator, rNumberingSeparator,
-                        bBefore, nId, rCharacterStyle, bCpyBrd );
+                        bBefore, nId, rCharacterStyle, bCpyBrd, this );
     }
 
     SwFlyFrameFormat *const pNewFormat = lcl_InsertLabel(*this, mpTextFormatCollTable, pUndo,
@@ -1008,7 +1007,7 @@ lcl_InsertDrawLabel( SwDoc & rDoc, SwTextFormatColls *const pTextFormatCollTable
     OSL_ENSURE( nId == USHRT_MAX  || nId < rDoc.getIDocumentFieldsAccess().GetFieldTypes()->size(),
             "FieldType index out of bounds" );
     SwFieldType *pType = nId != USHRT_MAX ? (*rDoc.getIDocumentFieldsAccess().GetFieldTypes())[nId] : nullptr;
-    OSL_ENSURE( !pType || pType->Which() == RES_SETEXPFLD, "Wrong label id" );
+    OSL_ENSURE( !pType || pType->Which() == SwFieldIds::SetExp, "Wrong label id" );
 
     SwTextFormatColl *pColl = nullptr;
     if( pType )
@@ -1111,7 +1110,7 @@ lcl_InsertDrawLabel( SwDoc & rDoc, SwTextFormatColls *const pTextFormatCollTable
     pNewFormat->SetFormatAttr( *pNewSet );
 
     const SwFormatAnchor& rAnchor = pNewFormat->GetAnchor();
-    if ( FLY_AS_CHAR == rAnchor.GetAnchorId() )
+    if ( RndStdIds::FLY_AS_CHAR == rAnchor.GetAnchorId() )
     {
         const SwPosition *pPos = rAnchor.GetContentAnchor();
         SwTextNode *pTextNode = pPos->nNode.GetNode().GetTextNode();
@@ -1120,10 +1119,12 @@ lcl_InsertDrawLabel( SwDoc & rDoc, SwTextFormatColls *const pTextFormatCollTable
         SwTextAttr * const pHint =
             pTextNode->GetTextAttrForCharAt( nIdx, RES_TXTATR_FLYCNT );
 
+        assert(pHint && "Missing Hint.");
+
 #if OSL_DEBUG_LEVEL > 0
-        OSL_ENSURE( pHint && pHint->Which() == RES_TXTATR_FLYCNT,
+        OSL_ENSURE( pHint->Which() == RES_TXTATR_FLYCNT,
                     "Missing FlyInCnt-Hint." );
-        OSL_ENSURE( pHint && pHint->GetFlyCnt().
+        OSL_ENSURE( pHint->GetFlyCnt().
                     GetFrameFormat() == static_cast<SwFrameFormat*>(pOldFormat),
                     "Wrong TextFlyCnt-Hint." );
 #endif
@@ -1134,7 +1135,7 @@ lcl_InsertDrawLabel( SwDoc & rDoc, SwTextFormatColls *const pTextFormatCollTable
     // and it should be adjusted to above and middle.
     pNewSet->ClearItem();
 
-    pNewSet->Put( SwFormatSurround( SURROUND_NONE ) );
+    pNewSet->Put( SwFormatSurround( css::text::WrapTextMode_NONE ) );
     if (nLayerId == rDoc.getIDocumentDrawModelAccess().GetHellId())
     {
     // Consider drawing objects in the 'invisible' hell layer
@@ -1152,7 +1153,7 @@ lcl_InsertDrawLabel( SwDoc & rDoc, SwTextFormatColls *const pTextFormatCollTable
     pNewSet->Put( SwFormatHoriOrient( 0, text::HoriOrientation::CENTER, text::RelOrientation::FRAME ) );
 
     // The old one is paragraph-bound to the new one's paragraph.
-    SwFormatAnchor aAnch( FLY_AT_PARA );
+    SwFormatAnchor aAnch( RndStdIds::FLY_AT_PARA );
     SwNodeIndex aAnchIdx( *pNewFormat->GetContent().GetContentIdx(), 1 );
     pNew = aAnchIdx.GetNode().GetTextNode();
     SwPosition aPos( aAnchIdx );
@@ -1215,7 +1216,7 @@ lcl_InsertDrawLabel( SwDoc & rDoc, SwTextFormatColls *const pTextFormatCollTable
                 SwCharFormat * pCharFormat = rDoc.FindCharFormatByName(rCharacterStyle);
                 if ( !pCharFormat )
                 {
-                    const sal_uInt16 nMyId = SwStyleNameMapper::GetPoolIdFromUIName( rCharacterStyle, nsSwGetPoolIdFromName::GET_POOLID_CHRFMT );
+                    const sal_uInt16 nMyId = SwStyleNameMapper::GetPoolIdFromUIName( rCharacterStyle, SwGetPoolIdFromName::ChrFmt );
                     pCharFormat = rDoc.getIDocumentStylePoolAccess().GetCharFormatFromPool( nMyId );
                 }
                 if ( pCharFormat )
@@ -1256,7 +1257,7 @@ SwFlyFrameFormat* SwDoc::InsertDrawLabel(
         GetIDocumentUndoRedo().ClearRedo();
         pUndo = new SwUndoInsertLabel(
             LTYPE_DRAW, rText, rSeparator, rNumberSeparator, false,
-            nId, rCharacterStyle, false );
+            nId, rCharacterStyle, false, this );
     }
 
     SwFlyFrameFormat *const pNewFormat = lcl_InsertDrawLabel(
@@ -1275,7 +1276,7 @@ SwFlyFrameFormat* SwDoc::InsertDrawLabel(
     return pNewFormat;
 }
 
-static OUString lcl_GetUniqueFlyName(const SwDoc* pDoc, sal_uInt16 nDefStrId, RES_FMT eType)
+static OUString lcl_GetUniqueFlyName(const SwDoc* pDoc, const char* pDefStrId, RES_FMT eType)
 {
     if( pDoc->IsInMailMerge())
     {
@@ -1285,8 +1286,7 @@ static OUString lcl_GetUniqueFlyName(const SwDoc* pDoc, sal_uInt16 nDefStrId, RE
         return newName;
     }
 
-    ResId aId( nDefStrId, *pSwResMgr );
-    OUString aName( aId );
+    OUString aName(SwResId(pDefStrId));
     sal_Int32 nNmLen = aName.getLength();
 
     const SwFrameFormats& rFormats = *pDoc->GetSpzFrameFormats();
@@ -1328,7 +1328,10 @@ static OUString lcl_GetUniqueFlyName(const SwDoc* pDoc, sal_uInt16 nDefStrId, RE
             // so determine the number
             nNum = n * 8;
             while( nTmp & 1 )
-                ++nNum, nTmp >>= 1;
+            {
+                ++nNum;
+                nTmp >>= 1;
+            }
             break;
         }
     }
@@ -1356,22 +1359,22 @@ OUString SwDoc::GetUniqueShapeName() const
     return lcl_GetUniqueFlyName(this, STR_SHAPE_DEFNAME, RES_DRAWFRMFMT);
 }
 
-const SwFlyFrameFormat* SwDoc::FindFlyByName( const OUString& rName, sal_Int8 nNdTyp ) const
+const SwFlyFrameFormat* SwDoc::FindFlyByName( const OUString& rName, SwNodeType nNdTyp ) const
 {
-    const SwFrameFormats& rFormats = *GetSpzFrameFormats();
-    for( auto n = rFormats.size(); n; )
+    auto range = GetSpzFrameFormats()->rangeFind( RES_FLYFRMFMT, rName );
+    for( auto it = range.first; it != range.second; it++ )
     {
-        const SwFrameFormat* pFlyFormat = rFormats[ --n ];
+        const SwFrameFormat* pFlyFormat = *it;
         const SwNodeIndex* pIdx = nullptr;
         if( RES_FLYFRMFMT == pFlyFormat->Which() && pFlyFormat->GetName() == rName &&
             nullptr != ( pIdx = pFlyFormat->GetContent().GetContentIdx() ) &&
             pIdx->GetNode().GetNodes().IsDocNodes() )
         {
-            if( nNdTyp )
+            if( nNdTyp != SwNodeType::NONE )
             {
                 // query for the right NodeType
                 const SwNode* pNd = GetNodes()[ pIdx->GetIndex()+1 ];
-                if( nNdTyp == ND_TEXTNODE
+                if( nNdTyp == SwNodeType::Text
                         ? !pNd->IsNoTextNode()
                         : nNdTyp == pNd->GetNodeType() )
                     return static_cast<const SwFlyFrameFormat*>(pFlyFormat);
@@ -1388,21 +1391,22 @@ void SwDoc::SetFlyName( SwFlyFrameFormat& rFormat, const OUString& rName )
     OUString sName( rName );
     if( sName.isEmpty() || FindFlyByName( sName ) )
     {
-        sal_uInt16 nTyp = STR_FRAME_DEFNAME;
+        const char* pTyp = STR_FRAME_DEFNAME;
         const SwNodeIndex* pIdx = rFormat.GetContent().GetContentIdx();
         if( pIdx && pIdx->GetNode().GetNodes().IsDocNodes() )
         {
             switch( GetNodes()[ pIdx->GetIndex() + 1 ]->GetNodeType() )
             {
-                case ND_GRFNODE:
-                    nTyp = STR_GRAPHIC_DEFNAME;
+                case SwNodeType::Grf:
+                    pTyp = STR_GRAPHIC_DEFNAME;
                     break;
-                case ND_OLENODE:
-                    nTyp = STR_OBJECT_DEFNAME;
+                case SwNodeType::Ole:
+                    pTyp = STR_OBJECT_DEFNAME;
                     break;
+                default: break;
             }
         }
-        sName = lcl_GetUniqueFlyName(this, nTyp, RES_FLYFRMFMT);
+        sName = lcl_GetUniqueFlyName(this, pTyp, RES_FLYFRMFMT);
     }
     rFormat.SetName( sName, true );
     getIDocumentState().SetModified();
@@ -1412,16 +1416,13 @@ void SwDoc::SetAllUniqueFlyNames()
 {
     sal_Int32 n, nFlyNum = 0, nGrfNum = 0, nOLENum = 0;
 
-    ResId nFrameId( STR_FRAME_DEFNAME, *pSwResMgr ),
-          nGrfId( STR_GRAPHIC_DEFNAME, *pSwResMgr ),
-          nOLEId( STR_OBJECT_DEFNAME, *pSwResMgr );
-    const OUString sFlyNm( nFrameId );
-    const OUString sGrfNm( nGrfId );
-    const OUString sOLENm( nOLEId );
+    const OUString sFlyNm(SwResId(STR_FRAME_DEFNAME));
+    const OUString sGrfNm(SwResId(STR_GRAPHIC_DEFNAME));
+    const OUString sOLENm(SwResId(STR_OBJECT_DEFNAME));
 
     if( 255 < ( n = GetSpzFrameFormats()->size() ))
         n = 255;
-    SwFrameFormats aArr;
+    SwFrameFormatsV aArr;
     aArr.reserve( n );
     SwFrameFormat* pFlyFormat;
     bool bContainsAtPageObjWithContentAnchor = false;
@@ -1466,7 +1467,7 @@ void SwDoc::SetAllUniqueFlyNames()
         if ( !bContainsAtPageObjWithContentAnchor )
         {
             const SwFormatAnchor& rAnchor = pFlyFormat->GetAnchor();
-            if ( (FLY_AT_PAGE == rAnchor.GetAnchorId()) &&
+            if ( (RndStdIds::FLY_AT_PAGE == rAnchor.GetAnchorId()) &&
                  rAnchor.GetContentAnchor() )
             {
                 bContainsAtPageObjWithContentAnchor = true;
@@ -1484,10 +1485,10 @@ void SwDoc::SetAllUniqueFlyNames()
         {
             switch( GetNodes()[ pIdx->GetIndex() + 1 ]->GetNodeType() )
             {
-            case ND_GRFNODE:
+            case SwNodeType::Grf:
                 pFlyFormat->SetName( sGrfNm + OUString::number( ++nGrfNum ));
                 break;
-            case ND_OLENODE:
+            case SwNodeType::Ole:
                 pFlyFormat->SetName( sOLENm + OUString::number( ++nOLENum ));
                 break;
             default:
@@ -1552,7 +1553,7 @@ bool SwDoc::IsInHeaderFooter( const SwNodeIndex& rIdx ) const
                 checkFormats.erase( checkPos );
 #endif
                 const SwFormatAnchor& rAnchor = pFormat->GetAnchor();
-                if ((FLY_AT_PAGE == rAnchor.GetAnchorId()) ||
+                if ((RndStdIds::FLY_AT_PAGE == rAnchor.GetAnchorId()) ||
                     !rAnchor.GetContentAnchor() )
                 {
                     return false;
@@ -1575,10 +1576,10 @@ bool SwDoc::IsInHeaderFooter( const SwNodeIndex& rIdx ) const
             nullptr != pNd->FindFooterStartNode();
 }
 
-short SwDoc::GetTextDirection( const SwPosition& rPos,
+SvxFrameDirection SwDoc::GetTextDirection( const SwPosition& rPos,
                                const Point* pPt ) const
 {
-    short nRet = -1;
+    SvxFrameDirection nRet = SvxFrameDirection::Unknown;
 
     SwContentNode *pNd = rPos.nNode.GetNode().GetContentNode();
 
@@ -1587,7 +1588,7 @@ short SwDoc::GetTextDirection( const SwPosition& rPos,
     {
         nRet = pNd->GetTextDirection( rPos, pPt );
     }
-    if ( nRet == -1 )
+    if ( nRet == SvxFrameDirection::Unknown )
     {
         const SvxFrameDirectionItem* pItem = nullptr;
         if( pNd )
@@ -1597,11 +1598,11 @@ short SwDoc::GetTextDirection( const SwPosition& rPos,
             while( pFlyFormat )
             {
                 pItem = &pFlyFormat->GetFrameDir();
-                if( FRMDIR_ENVIRONMENT == pItem->GetValue() )
+                if( SvxFrameDirection::Environment == pItem->GetValue() )
                 {
                     pItem = nullptr;
                     const SwFormatAnchor* pAnchor = &pFlyFormat->GetAnchor();
-                    if ((FLY_AT_PAGE != pAnchor->GetAnchorId()) &&
+                    if ((RndStdIds::FLY_AT_PAGE != pAnchor->GetAnchorId()) &&
                         pAnchor->GetContentAnchor())
                     {
                         pFlyFormat = pAnchor->GetContentAnchor()->nNode.
@@ -1616,7 +1617,7 @@ short SwDoc::GetTextDirection( const SwPosition& rPos,
 
             if( !pItem )
             {
-                const SwPageDesc* pPgDsc = pNd->FindPageDesc( false );
+                const SwPageDesc* pPgDsc = pNd->FindPageDesc();
                 if( pPgDsc )
                     pItem = &pPgDsc->GetMaster().GetFrameDir();
             }
@@ -1629,10 +1630,10 @@ short SwDoc::GetTextDirection( const SwPosition& rPos,
     return nRet;
 }
 
-bool SwDoc::IsInVerticalText( const SwPosition& rPos, const Point* pPt ) const
+bool SwDoc::IsInVerticalText( const SwPosition& rPos ) const
 {
-    const short nDir = GetTextDirection( rPos, pPt );
-    return FRMDIR_VERT_TOP_RIGHT == nDir || FRMDIR_VERT_TOP_LEFT == nDir;
+    const SvxFrameDirection nDir = GetTextDirection( rPos );
+    return SvxFrameDirection::Vertical_RL_TB == nDir || SvxFrameDirection::Vertical_LR_TB == nDir;
 }
 
 std::set<SwRootFrame*> SwDoc::GetAllLayouts()
