@@ -54,11 +54,11 @@
 #include <viewsh.hxx>
 #include <viscrs.hxx>
 #include <rootfrm.hxx>
-#include <comcore.hrc>
+#include <strings.hrc>
 #include <unoport.hxx>
 #include <wrtsh.hxx>
 
-#include "flowfrm.hxx"
+#include <flowfrm.hxx>
 
 using namespace com::sun::star;
 
@@ -558,7 +558,7 @@ SwRedlineTable::~SwRedlineTable()
 
 SwRedlineTable::size_type SwRedlineTable::GetPos(const SwRangeRedline* p) const
 {
-    vector_type::const_iterator it = maVector.find(const_cast<SwRangeRedline* const>(p));
+    vector_type::const_iterator it = maVector.find(const_cast<SwRangeRedline*>(p));
     if( it == maVector.end() )
         return npos;
     return it - maVector.begin();
@@ -974,9 +974,23 @@ void SwRedlineData::SetExtraData( const SwRedlineExtraData* pData )
         pExtraData = nullptr;
 }
 
+static const char* STR_REDLINE_ARY[] =
+{
+    STR_UNDO_REDLINE_INSERT,
+    STR_UNDO_REDLINE_DELETE,
+    STR_UNDO_REDLINE_FORMAT,
+    STR_UNDO_REDLINE_TABLE,
+    STR_UNDO_REDLINE_FMTCOLL,
+    STR_UNDO_REDLINE_PARAGRAPH_FORMAT,
+    STR_UNDO_REDLINE_TABLE_ROW_INSERT,
+    STR_UNDO_REDLINE_TABLE_ROW_DELETE,
+    STR_UNDO_REDLINE_TABLE_CELL_INSERT,
+    STR_UNDO_REDLINE_TABLE_CELL_DELETE
+};
+
 OUString SwRedlineData::GetDescr() const
 {
-    return SwResId(STR_UNDO_REDLINE_INSERT + GetType());
+    return SwResId(STR_REDLINE_ARY[GetType()]);
 }
 
 sal_uInt32 SwRangeRedline::m_nLastId = 1;
@@ -1191,7 +1205,7 @@ void SwRangeRedline::ShowOriginal(sal_uInt16 nLoop, size_t nMyPos)
         }
         break;
 
-    case nsRedlineType_t::REDLINE_DELETE:           // Inhalt wurde eingefuegt
+    case nsRedlineType_t::REDLINE_DELETE:           // Content has been deleted
         bIsVisible = true;
         if( 1 <= nLoop )
             MoveFromSection(nMyPos);
@@ -1350,78 +1364,79 @@ void SwRangeRedline::MoveToSection()
 
 void SwRangeRedline::CopyToSection()
 {
-    if( !pContentSect )
+    if( pContentSect )
+        return;
+
+    const SwPosition* pStt = Start(),
+                    * pEnd = pStt == GetPoint() ? GetMark() : GetPoint();
+
+    SwContentNode* pCSttNd = pStt->nNode.GetNode().GetContentNode();
+    SwContentNode* pCEndNd = pEnd->nNode.GetNode().GetContentNode();
+
+    SwStartNode* pSttNd;
+    SwDoc* pDoc = GetDoc();
+    SwNodes& rNds = pDoc->GetNodes();
+
+    bool bSaveCopyFlag = pDoc->IsCopyIsMove(),
+         bSaveRdlMoveFlg = pDoc->getIDocumentRedlineAccess().IsRedlineMove();
+    pDoc->SetCopyIsMove( true );
+
+    // The IsRedlineMove() flag causes the behaviour of the
+    // SwDoc::_CopyFlyInFly method to change, which will eventually be
+    // called by the pDoc->Copy line below (through SwDoc::Copy_,
+    // SwDoc::CopyWithFlyInFly). This rather obscure bugfix
+    // apparently never really worked.
+    pDoc->getIDocumentRedlineAccess().SetRedlineMove( pStt->nContent == 0 );
+
+    if( pCSttNd )
     {
-        const SwPosition* pStt = Start(),
-                        * pEnd = pStt == GetPoint() ? GetMark() : GetPoint();
+        SwTextFormatColl* pColl = (pCSttNd && pCSttNd->IsTextNode() )
+                                ? pCSttNd->GetTextNode()->GetTextColl()
+                                : pDoc->getIDocumentStylePoolAccess().GetTextCollFromPool(RES_POOLCOLL_STANDARD);
 
-        SwContentNode* pCSttNd = pStt->nNode.GetNode().GetContentNode();
-        SwContentNode* pCEndNd = pEnd->nNode.GetNode().GetContentNode();
+        pSttNd = rNds.MakeTextSection( SwNodeIndex( rNds.GetEndOfRedlines() ),
+                                        SwNormalStartNode, pColl );
 
-        SwStartNode* pSttNd;
-        SwDoc* pDoc = GetDoc();
-        SwNodes& rNds = pDoc->GetNodes();
+        SwNodeIndex aNdIdx( *pSttNd, 1 );
+        SwTextNode* pTextNd = aNdIdx.GetNode().GetTextNode();
+        SwPosition aPos( aNdIdx, SwIndex( pTextNd ));
+        pDoc->getIDocumentContentOperations().CopyRange( *this, aPos, /*bCopyAll=*/false, /*bCheckPos=*/true );
 
-        bool bSaveCopyFlag = pDoc->IsCopyIsMove(),
-             bSaveRdlMoveFlg = pDoc->getIDocumentRedlineAccess().IsRedlineMove();
-        pDoc->SetCopyIsMove( true );
-
-        // The IsRedlineMove() flag causes the behaviour of the
-        // SwDoc::_CopyFlyInFly method to change, which will eventually be
-        // called by the pDoc->Copy line below (through SwDoc::Copy_,
-        // SwDoc::CopyWithFlyInFly). This rather obscure bugfix
-        // apparently never really worked.
-        pDoc->getIDocumentRedlineAccess().SetRedlineMove( pStt->nContent == 0 );
-
-        if( pCSttNd )
+        // Take over the style from the EndNode if needed
+        // We don't want this in Doc::Copy
+        if( pCEndNd && pCEndNd != pCSttNd )
         {
-            SwTextFormatColl* pColl = (pCSttNd && pCSttNd->IsTextNode() )
-                                    ? pCSttNd->GetTextNode()->GetTextColl()
-                                    : pDoc->getIDocumentStylePoolAccess().GetTextCollFromPool(RES_POOLCOLL_STANDARD);
-
-            pSttNd = rNds.MakeTextSection( SwNodeIndex( rNds.GetEndOfRedlines() ),
-                                            SwNormalStartNode, pColl );
-
-            SwNodeIndex aNdIdx( *pSttNd, 1 );
-            SwTextNode* pTextNd = aNdIdx.GetNode().GetTextNode();
-            SwPosition aPos( aNdIdx, SwIndex( pTextNd ));
-            pDoc->getIDocumentContentOperations().CopyRange( *this, aPos, /*bCopyAll=*/false, /*bCheckPos=*/true );
-
-            // Take over the style from the EndNode if needed
-            // We don't want this in Doc::Copy
-            if( pCEndNd && pCEndNd != pCSttNd )
+            SwContentNode* pDestNd = aPos.nNode.GetNode().GetContentNode();
+            if( pDestNd )
             {
-                SwContentNode* pDestNd = aPos.nNode.GetNode().GetContentNode();
-                if( pDestNd )
-                {
-                    if( pDestNd->IsTextNode() && pCEndNd->IsTextNode() )
-                        pCEndNd->GetTextNode()->CopyCollFormat(*pDestNd->GetTextNode());
-                    else
-                        pDestNd->ChgFormatColl( pCEndNd->GetFormatColl() );
-                }
+                if( pDestNd->IsTextNode() && pCEndNd->IsTextNode() )
+                    pCEndNd->GetTextNode()->CopyCollFormat(*pDestNd->GetTextNode());
+                else
+                    pDestNd->ChgFormatColl( pCEndNd->GetFormatColl() );
             }
         }
+    }
+    else
+    {
+        pSttNd = SwNodes::MakeEmptySection( SwNodeIndex( rNds.GetEndOfRedlines() ) );
+
+        if( pCEndNd )
+        {
+            SwPosition aPos( *pSttNd->EndOfSectionNode() );
+            pDoc->getIDocumentContentOperations().CopyRange( *this, aPos, /*bCopyAll=*/false, /*bCheckPos=*/true );
+        }
         else
         {
-            pSttNd = SwNodes::MakeEmptySection( SwNodeIndex( rNds.GetEndOfRedlines() ) );
-
-            if( pCEndNd )
-            {
-                SwPosition aPos( *pSttNd->EndOfSectionNode() );
-                pDoc->getIDocumentContentOperations().CopyRange( *this, aPos, /*bCopyAll=*/false, /*bCheckPos=*/true );
-            }
-            else
-            {
-                SwNodeIndex aInsPos( *pSttNd->EndOfSectionNode() );
-                SwNodeRange aRg( pStt->nNode, 0, pEnd->nNode, 1 );
-                pDoc->GetDocumentContentOperationsManager().CopyWithFlyInFly( aRg, 0, aInsPos );
-            }
+            SwNodeIndex aInsPos( *pSttNd->EndOfSectionNode() );
+            SwNodeRange aRg( pStt->nNode, 0, pEnd->nNode, 1 );
+            pDoc->GetDocumentContentOperationsManager().CopyWithFlyInFly( aRg, 0, aInsPos );
         }
-        pContentSect = new SwNodeIndex( *pSttNd );
-
-        pDoc->SetCopyIsMove( bSaveCopyFlag );
-        pDoc->getIDocumentRedlineAccess().SetRedlineMove( bSaveRdlMoveFlg );
     }
+    pContentSect = new SwNodeIndex( *pSttNd );
+
+    pDoc->SetCopyIsMove( bSaveCopyFlag );
+    pDoc->getIDocumentRedlineAccess().SetRedlineMove( bSaveRdlMoveFlg );
+
 }
 
 void SwRangeRedline::DelCopyOfSection(size_t nMyPos)
