@@ -83,7 +83,7 @@
 #include <docsh.hxx>
 #include <unofldmid.h>
 #include <swunohelper.hxx>
-#include <comcore.hrc>
+#include <strings.hrc>
 
 #include <editeng/outliner.hxx>
 #include <editeng/outlobj.hxx>
@@ -272,7 +272,7 @@ bool SwPageNumberField::PutValue( const uno::Any& rAny, sal_uInt16 nWhichId )
     case FIELD_PROP_FORMAT:
         rAny >>= nSet;
 
-        // TODO: woher kommen die defines?
+        // TODO: where do the defines come from?
         if(nSet <= SVX_NUM_PAGEDESC )
             SetFormat(nSet);
         else {
@@ -734,7 +734,7 @@ OUString SwDocStatFieldType::Expand(sal_uInt16 nSubType, SvxNumType nFormat) con
         case DS_CHAR: nVal = rDStat.nChar;  break;
         case DS_PAGE:
             if( pDoc->getIDocumentLayoutAccess().GetCurrentLayout() )
-                ((SwDocStat &)rDStat).nPage = pDoc->getIDocumentLayoutAccess().GetCurrentLayout()->GetPageNum();
+                const_cast<SwDocStat &>(rDStat).nPage = pDoc->getIDocumentLayoutAccess().GetCurrentLayout()->GetPageNum();
             nVal = rDStat.nPage;
             if( SVX_NUM_PAGEDESC == nFormat )
                 nFormat = nNumberingType;
@@ -1070,15 +1070,15 @@ OUString SwDocInfoField::Expand() const
                     if( aAny >>= aDate)
                     {
                         SvNumberFormatter* pFormatter = pDocShell->GetDoc()->GetNumberFormatter();
-                        Date* pNullDate = pFormatter->GetNullDate();
-                        sVal = ExpandValue( lcl_DateToDouble<util::Date>( aDate, *pNullDate ), GetFormat(), GetLanguage());
+                        const Date& rNullDate = pFormatter->GetNullDate();
+                        sVal = ExpandValue( lcl_DateToDouble<util::Date>( aDate, rNullDate ), GetFormat(), GetLanguage());
                     }
                     else if( aAny >>= aDateTime )
                     {
                         double fDateTime = lcl_TimeToDouble<util::DateTime>( aDateTime );
                         SvNumberFormatter* pFormatter = pDocShell->GetDoc()->GetNumberFormatter();
-                        Date* pNullDate = pFormatter->GetNullDate();
-                        fDateTime += lcl_DateToDouble<util::DateTime>( aDateTime, *pNullDate );
+                        const Date& rNullDate = pFormatter->GetNullDate();
+                        fDateTime += lcl_DateToDouble<util::DateTime>( aDateTime, rNullDate );
                         sVal = ExpandValue( fDateTime, GetFormat(), GetLanguage());
                     }
                     else if( aAny >>= aDuration )
@@ -1128,7 +1128,7 @@ OUString SwDocInfoField::GetFieldName() const
     }
     if (IsFixed())
     {
-        aStr += " " + OUString(SwViewShell::GetShellRes()->aFixedStr);
+        aStr += " " + SwViewShell::GetShellRes()->aFixedStr;
     }
     return aStr;
 }
@@ -1855,7 +1855,7 @@ SwFieldType* SwExtUserFieldType::Copy() const
     return pTyp;
 }
 
-OUString SwExtUserFieldType::Expand(sal_uInt16 nSub, sal_uInt32 )
+OUString SwExtUserFieldType::Expand(sal_uInt16 nSub )
 {
     UserOptToken nRet = static_cast<UserOptToken>(USHRT_MAX);
     switch(nSub)
@@ -1893,13 +1893,13 @@ OUString SwExtUserFieldType::Expand(sal_uInt16 nSub, sal_uInt32 )
 SwExtUserField::SwExtUserField(SwExtUserFieldType* pTyp, sal_uInt16 nSubTyp, sal_uInt32 nFormat) :
     SwField(pTyp, nFormat), nType(nSubTyp)
 {
-    aContent = SwExtUserFieldType::Expand(nType, GetFormat());
+    aContent = SwExtUserFieldType::Expand(nType);
 }
 
 OUString SwExtUserField::Expand() const
 {
     if (!IsFixed())
-        const_cast<SwExtUserField*>(this)->aContent = SwExtUserFieldType::Expand(nType, GetFormat());
+        const_cast<SwExtUserField*>(this)->aContent = SwExtUserFieldType::Expand(nType);
 
     return aContent;
 }
@@ -2117,7 +2117,6 @@ bool SwRefPageGetFieldType::MakeSetList( SetGetExpFields& rTmpLst )
                     SwPosition aPos( pDoc->GetNodes().GetEndOfPostIts() );
                     bool const bResult = GetBodyTextNode( *pDoc, aPos, *pFrame );
                     OSL_ENSURE(bResult, "where is the Field?");
-                    (void) bResult; // unused in non-debug
                     pNew = new SetGetExpField( aPos.nNode, pTField,
                                                 &aPos.nContent );
                 }
@@ -2130,8 +2129,8 @@ bool SwRefPageGetFieldType::MakeSetList( SetGetExpFields& rTmpLst )
     return !rTmpLst.empty();
 }
 
-void SwRefPageGetFieldType::UpdateField( SwTextField* pTextField,
-                                        SetGetExpFields& rSetList )
+void SwRefPageGetFieldType::UpdateField( SwTextField const * pTextField,
+                                        SetGetExpFields const & rSetList )
 {
     SwRefPageGetField* pGetField = const_cast<SwRefPageGetField*>(static_cast<const SwRefPageGetField*>(pTextField->GetFormatField().GetField()));
     pGetField->SetText( OUString() );
