@@ -17,7 +17,6 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include <com/sun/star/embed/EmbedStates.hpp>
 
 #include <sfx2/ipclient.hxx>
 #include <sfx2/viewsh.hxx>
@@ -41,17 +40,17 @@
 
 using namespace com::sun::star;
 
-SwFlyFrm *SwFEShell::FindFlyFrm( const uno::Reference < embed::XEmbeddedObject >& xObj ) const
+SwFlyFrame *SwFEShell::FindFlyFrame( const uno::Reference < embed::XEmbeddedObject >& xObj ) const
 {
-    SwFlyFrm *pFly = FindFlyFrm();
-    if ( pFly && pFly->Lower() && pFly->Lower()->IsNoTxtFrm() )
+    SwFlyFrame *pFly = GetSelectedFlyFrame();
+    if ( pFly && pFly->Lower() && pFly->Lower()->IsNoTextFrame() )
     {
-        SwOLENode *pNd = ((SwNoTxtFrm*)pFly->Lower())->GetNode()->GetOLENode();
+        SwOLENode *pNd = static_cast<SwNoTextFrame*>(pFly->Lower())->GetNode()->GetOLENode();
         if ( !pNd || pNd->GetOLEObj().GetOleRef() != xObj )
-            pFly = 0;
+            pFly = nullptr;
     }
     else
-        pFly = 0;
+        pFly = nullptr;
 
     if ( !pFly )
     {
@@ -61,70 +60,54 @@ SwFlyFrm *SwFEShell::FindFlyFrm( const uno::Reference < embed::XEmbeddedObject >
         sal_uLong nSttIdx = GetNodes().GetEndOfAutotext().StartOfSectionIndex() + 1,
               nEndIdx = GetNodes().GetEndOfAutotext().GetIndex();
         while( nSttIdx < nEndIdx &&
-                0 != (pStNd = GetNodes()[ nSttIdx ]->GetStartNode()) )
+                nullptr != (pStNd = GetNodes()[ nSttIdx ]->GetStartNode()) )
         {
             SwNode *pNd = GetNodes()[ nSttIdx+1 ];
             if ( pNd->IsOLENode() &&
-                 ((SwOLENode*)pNd)->GetOLEObj().GetOleRef() == xObj )
+                 static_cast<SwOLENode*>(pNd)->GetOLEObj().GetOleRef() == xObj )
             {
                 bExist = true;
-                SwFrm *pFrm = ((SwOLENode*)pNd)->getLayoutFrm( GetLayout() );
-                if ( pFrm )
-                    pFly = pFrm->FindFlyFrm();
+                SwFrame *pFrame = static_cast<SwOLENode*>(pNd)->getLayoutFrame( GetLayout() );
+                if ( pFrame )
+                    pFly = pFrame->FindFlyFrame();
                 break;
             }
             nSttIdx = pStNd->EndOfSectionIndex() + 1;
         }
 
-        OSL_ENSURE( bExist, "OLE-Object unknown and FlyFrm not found." );
-        (void)bExist;
+        OSL_ENSURE( bExist, "OLE-Object unknown and FlyFrame not found." );
     }
     return pFly;
 }
 
-
 OUString SwFEShell::GetUniqueOLEName() const
 {
     return GetDoc()->GetUniqueOLEName();
 }
 
-
 OUString SwFEShell::GetUniqueFrameName() const
 {
     return GetDoc()->GetUniqueFrameName();
 }
 
-
-void SwFEShell::MakeObjVisible( const uno::Reference < embed::XEmbeddedObject >& xObj ) const
+OUString SwFEShell::GetUniqueShapeName() const
 {
-    SwFlyFrm *pFly = FindFlyFrm( xObj );
-    if ( pFly )
-    {
-        SwRect aTmp( pFly->Prt() );
-        aTmp += pFly->Frm().Pos();
-        if ( !aTmp.IsOver( VisArea() ) )
-        {
-            ((SwFEShell*)this)->StartAction();
-            ((SwFEShell*)this)->MakeVisible( aTmp );
-            ((SwFEShell*)this)->EndAction();
-        }
-    }
+    return GetDoc()->GetUniqueShapeName();
 }
 
-sal_Bool SwFEShell::FinishOLEObj()                      // Server is terminated
+bool SwFEShell::FinishOLEObj()                      // Server is terminated
 {
     SfxInPlaceClient* pIPClient = GetSfxViewShell()->GetIPClient();
     if ( !pIPClient )
-        return sal_False;
+        return false;
 
-    sal_Bool bRet = pIPClient->IsObjectInPlaceActive();
+    bool bRet = pIPClient->IsObjectInPlaceActive();
     if( bRet )
     {
-        uno::Reference < embed::XEmbeddedObject > xObj = pIPClient->GetObject();
         if( CNT_OLE == GetCntType() )
             ClearAutomaticContour();
 
-        if( ((SwOleClient*)pIPClient)->IsCheckForOLEInCaption() !=
+        if( static_cast<SwOleClient*>(pIPClient)->IsCheckForOLEInCaption() !=
             IsCheckForOLEInCaption() )
             SetCheckForOLEInCaption( !IsCheckForOLEInCaption() );
 
@@ -134,7 +117,4 @@ sal_Bool SwFEShell::FinishOLEObj()                      // Server is terminated
     return bRet;
 }
 
-
-
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
