@@ -28,14 +28,14 @@
  *
  * The PROTOCOL macros accept the following parameters:
  * 1.   A pointer to an SwFrame (usually "this" or "rThis")
- * 2.   The function group i.e. PROT_MAKEALL. This is used to decide (inline)
+ * 2.   The function group i.e. PROT::MakeAll. This is used to decide (inline)
  *      whether this event shall be logged at the current time.
- * 3.   The action, usually 0. For example ACT_START indents output in the log
- *      file and ACT_END stops the indentation. This allows for example
+ * 3.   The action, usually 0. For example DbgAction::Start indents output in the log
+ *      file and DbgAction::End stops the indentation. This allows for example
  *      PROTOCOL_ENTER to indent at the beginning of a method and stop indenting
  *      when leaving the method.
  * 4.   The fourth parameter is a void pointer which allows to pass anything
- *      which can be used in the log. A good example is PROT_GROW: this requires
+ *      which can be used in the log. A good example is PROT::Grow: this requires
  *      a pointer to the value which defines how much to grow.
  *
  * The log file is called "dbg_lay.out", which is saved in the current (BIN-)
@@ -45,13 +45,13 @@
  * What exactly is going to be logged, can be defined as follows:
  * 1.   The static variable SwProtocol::nRecord contains the function groups
  *      which shall be logged.
- *      A value of i.e. PROT_GROW causes calls to SwFrame::Grow to be
- *      logged; PROT_MAKEALL logs the calls to xxx::MakeAll.
+ *      A value of i.e. PROT::Grow causes calls to SwFrame::Grow to be
+ *      logged; PROT::MakeAll logs the calls to xxx::MakeAll.
  *      The PROT_XY values can be combined using binary OR, the default value
  *      is null - no method calls are logged.
  * 2.   The SwImplProtocol class contains a filter for frame types, only method
  *      call of frame types which are defined there are logged.
- *      The member nTypes can be set to values like FRM_PAGE or FRM_SECTION and
+ *      The member nTypes can be set to values like SwFrameType::Page or SwFrameType::Section and
  *      may be combined using binary OR. The default values is 0xFFFF - meaning
  *      all frame types.
  * 3.   The SwImplProtocol class contains an ArrayPointer to FrameIds which need to be
@@ -64,7 +64,7 @@
  * 1.   Set a breakpoint in SwProtocol::Init() and manipulate nRecord there, set
  *      FrameIds accordingly then start logging during program start.
  * 2.   Set a breakpoint before any PROTOCOL or PROTOCOL_ENTER macro during
- *      program execution, then set the lowest bit (PROT_INIT) of
+ *      program execution, then set the lowest bit (PROT::Init) of
  *      SwProtocol::nRecord. This activates the function group of the following
  *      macro and causes it to be logged in the future.
  * 3.   There's a special case for 2: If one uses 2. in SwRootFrame::Paint(..),
@@ -82,8 +82,8 @@
  *      listed; default is 0 which means that none are logged. It's also
  *      possible to remove functions using '!'.
  *      An example INI file:
- *           #Functions: all, except PRTARE
- *           [record] 0xFFFFFFFE !0x200
+ *           #Functions: all(0x0007ffff), except PrintArea (0x200)
+ *           [record] 524287 !512
  *           [frmid]
  *           #the following FrameIds:
  *           1 2 12 13 14 15
@@ -91,19 +91,19 @@
  *           [frmtype] !0x3FFF 0x4
  *
  * As soon as the logging is in process, one can manipulate many things in
- * SwImplProtocol::_Record(...) using a debugger, especially concerning
+ * SwImplProtocol::Record_(...) using a debugger, especially concerning
  * frame types and FrameIds.
  */
 
-#include "dbg_lay.hxx"
+#include <dbg_lay.hxx>
 
-#include "flyfrm.hxx"
-#include "txtfrm.hxx"
+#include <flyfrm.hxx>
+#include <txtfrm.hxx>
 #include <fntcache.hxx>
 
 #include <comphelper/string.hxx>
 
-sal_uLong SwProtocol::nRecord = 0;
+PROT SwProtocol::nRecord = PROT::FileInit;
 SwImplProtocol* SwProtocol::pImpl = nullptr;
 
 static sal_uLong lcl_GetFrameId( const SwFrame* pFrame )
@@ -113,8 +113,8 @@ static sal_uLong lcl_GetFrameId( const SwFrame* pFrame )
     if( bFrameId )
         return pFrame->GetFrameId();
 #endif
-    if( pFrame && pFrame->IsTextFrame() )
-        return static_cast<const SwTextFrame*>(pFrame)->GetTextNode()->GetIndex();
+    if( pFrame )
+        return pFrame->GetFrameId();
     return 0;
 }
 
@@ -124,21 +124,21 @@ class SwImplProtocol
     std::set<sal_uInt16> *pFrameIds;  // which FrameIds shall be logged ( NULL == all)
     std::vector<long> aVars;        // variables
     OStringBuffer aLayer;      // indentation of output ("  " per start/end)
-    sal_uInt16 nTypes;              // which types shall be logged
+    SwFrameType nTypes;              // which types shall be logged
     sal_uInt16 nLineCount;          // printed lines
     sal_uInt16 nMaxLines;           // max lines to be printed
     sal_uInt8 nInitFile;            // range (FrameId,FrameType,Record) during reading of the INI file
     sal_uInt8 nTestMode;            // special for test formatting, logging may only be done in test formatting.
-    void _Record( const SwFrame* pFrame, sal_uLong nFunction, sal_uLong nAct, void* pParam );
+    void Record_( const SwFrame* pFrame, PROT nFunction, DbgAction nAct, void* pParam );
     bool NewStream();
     void CheckLine( OString& rLine );
-    static void SectFunc( OStringBuffer& rOut, const SwFrame* pFrame, sal_uLong nAct, void* pParam );
+    static void SectFunc( OStringBuffer& rOut, DbgAction nAct, void const * pParam );
 public:
     SwImplProtocol();
     ~SwImplProtocol();
     // logging
-    void Record( const SwFrame* pFrame, sal_uLong nFunction, sal_uLong nAct, void* pParam )
-        { if( pStream ) _Record( pFrame, nFunction, nAct, pParam ); }
+    void Record( const SwFrame* pFrame, PROT nFunction, DbgAction nAct, void* pParam )
+        { if( pStream ) Record_( pFrame, nFunction, nAct, pParam ); }
     bool InsertFrame( sal_uInt16 nFrameId );    // take FrameId for logging
     bool DeleteFrame( sal_uInt16 nFrameId );    // remove FrameId; don't log him anymore
     void FileInit();                    // read the INI file
@@ -150,7 +150,7 @@ public:
  * The funny thing here is, that the Ctor of the Impl object is automatically
  * called at the beginning of the function and the Dtor is automatically called
  * when leaving the function. In the base implementation the Ctor calls only
- * PROTOCOL(..) with ACT_START and in the Dtor a PROTOCOL(..) with ACT_END.
+ * PROTOCOL(..) with DbgAction::Start and in the Dtor a PROTOCOL(..) with DbgAction::End.
  * It's possible to derive from this class, for example to be able to document
  * frame resize while leaving a function. To do this, one only needs to add the
  * desired SwImplEnterLeave class in SwEnterLeave::Ctor().
@@ -159,11 +159,12 @@ public:
 class SwImplEnterLeave
 {
 protected:
-    const SwFrame* pFrame;              // the frame
-    sal_uLong nFunction, nAction;   // the function, the action if needed
-    void* pParam;                   // further parameter
+    const SwFrame* pFrame;    // the frame
+    PROT           nFunction; // the function
+    DbgAction      nAction;   // the action if needed
+    void*          pParam;    // further parameter
 public:
-    SwImplEnterLeave( const SwFrame* pF, sal_uLong nFunct, sal_uLong nAct, void* pPar )
+    SwImplEnterLeave( const SwFrame* pF, PROT nFunct, DbgAction nAct, void* pPar )
         : pFrame( pF ), nFunction( nFunct ), nAction( nAct ), pParam( pPar ) {}
     virtual ~SwImplEnterLeave() {}
     virtual void Enter();           // message when entering
@@ -174,9 +175,9 @@ class SwSizeEnterLeave : public SwImplEnterLeave
 {
     long nFrameHeight;
 public:
-    SwSizeEnterLeave( const SwFrame* pF, sal_uLong nFunct, sal_uLong nAct, void* pPar )
-        : SwImplEnterLeave( pF, nFunct, nAct, pPar ), nFrameHeight( pF->Frame().Height() ) {}
-    virtual ~SwSizeEnterLeave() {}
+    SwSizeEnterLeave( const SwFrame* pF, PROT nFunct, DbgAction nAct, void* pPar )
+        : SwImplEnterLeave( pF, nFunct, nAct, pPar ), nFrameHeight( pF->getFrameArea().Height() ) {}
+
     virtual void Leave() override;           // resize message
 };
 
@@ -184,9 +185,9 @@ class SwUpperEnterLeave : public SwImplEnterLeave
 {
     sal_uInt16 nFrameId;
 public:
-    SwUpperEnterLeave( const SwFrame* pF, sal_uLong nFunct, sal_uLong nAct, void* pPar )
+    SwUpperEnterLeave( const SwFrame* pF, PROT nFunct, DbgAction nAct, void* pPar )
         : SwImplEnterLeave( pF, nFunct, nAct, pPar ), nFrameId( 0 ) {}
-    virtual ~SwUpperEnterLeave() {}
+
     virtual void Enter() override;           // message
     virtual void Leave() override;           // message of FrameId from upper
 };
@@ -195,26 +196,26 @@ class SwFrameChangesLeave : public SwImplEnterLeave
 {
     SwRect aFrame;
 public:
-    SwFrameChangesLeave( const SwFrame* pF, sal_uLong nFunct, sal_uLong nAct, void* pPar )
-        : SwImplEnterLeave( pF, nFunct, nAct, pPar ), aFrame( pF->Frame() ) {}
-    virtual ~SwFrameChangesLeave() {}
+    SwFrameChangesLeave( const SwFrame* pF, PROT nFunct, DbgAction nAct, void* pPar )
+        : SwImplEnterLeave( pF, nFunct, nAct, pPar ), aFrame( pF->getFrameArea() ) {}
+
     virtual void Enter() override;           // no message
     virtual void Leave() override;           // message when resizing the Frame area
 };
 
-void SwProtocol::Record( const SwFrame* pFrame, sal_uLong nFunction, sal_uLong nAct, void* pParam )
+void SwProtocol::Record( const SwFrame* pFrame, PROT nFunction, DbgAction nAct, void* pParam )
 {
     if( Start() )
-    {   // We reach this point if SwProtocol::nRecord is binary OR'd with PROT_INIT(0x1) using the debugger
+    {   // We reach this point if SwProtocol::nRecord is binary OR'd with PROT::Init(0x1) using the debugger
         bool bFinit = false; // This gives the possibility to stop logging of this action in the debugger
         if( bFinit )
         {
             nRecord &= ~nFunction;  // Don't log this function any longer
-            nRecord &= ~PROT_INIT;  // Always reset PROT_INIT
+            nRecord &= ~PROT::Init;  // Always reset PROT::Init
             return;
         }
         nRecord |= nFunction;       // Activate logging of this function
-        nRecord &= ~PROT_INIT;      // Always reset PROT_INIT
+        nRecord &= ~PROT::Init;      // Always reset PROT::Init
         if( pImpl )
             pImpl->ChkStream();
     }
@@ -229,7 +230,7 @@ void SwProtocol::Record( const SwFrame* pFrame, sal_uLong nFunction, sal_uLong n
 
 void SwProtocol::Init()
 {
-    nRecord = 0;
+    nRecord = PROT::FileInit;
     OUString aName("dbg_lay.go");
     SvFileStream aStream( aName, StreamMode::READ );
     if( aStream.IsOpen() )
@@ -251,11 +252,11 @@ void SwProtocol::Stop()
         if( pFntCache )
             pFntCache->Flush();
      }
-     nRecord = 0;
+     nRecord = PROT::FileInit;
 }
 
 SwImplProtocol::SwImplProtocol()
-    : pStream( nullptr ), pFrameIds( nullptr ), nTypes( 0xffff ),
+    : pStream( nullptr ), pFrameIds( nullptr ), nTypes( FRM_ALL ),
       nLineCount( 0 ), nMaxLines( USHRT_MAX ), nTestMode( 0 )
 {
     NewStream();
@@ -281,7 +282,8 @@ SwImplProtocol::~SwImplProtocol()
         pStream->Close();
         delete pStream;
     }
-    pFrameIds->clear();
+    if (pFrameIds)
+        pFrameIds->clear();
     delete pFrameIds;
     aVars.clear();
 }
@@ -293,7 +295,7 @@ void SwImplProtocol::CheckLine( OString& rLine )
     rLine = rLine.replace( '\t', ' ' );
     if( '#' == rLine[0] )   // comments start with '#'
         return;
-    if( '[' == rLine[0] )   // section: FrameIds, type or funciton
+    if( '[' == rLine[0] )   // section: FrameIds, type or function
     {
         OString aTmp = rLine.getToken(0, ']');
         if (aTmp == "[frmid")      // section FrameIds
@@ -306,12 +308,12 @@ void SwImplProtocol::CheckLine( OString& rLine )
         else if (aTmp == "[frmtype")// section types
         {
             nInitFile = 2;
-            nTypes = USHRT_MAX;     // default: log all frame types
+            nTypes = FRM_ALL;     // default: log all frame types
         }
         else if (aTmp == "[record")// section functions
         {
             nInitFile = 3;
-            SwProtocol::SetRecord( 0 );// default: don't log any function
+            SwProtocol::SetRecord( PROT::FileInit );// default: don't log any function
         }
         else if (aTmp == "[test")// section functions
         {
@@ -338,21 +340,20 @@ void SwImplProtocol::CheckLine( OString& rLine )
     {
         OString aTok = rLine.getToken( 0, ' ', nIndex );
         bool bNo = false;
-        if( '!' == aTok[0] )
+        if( !aTok.isEmpty() && '!' == aTok[0] )
         {
             bNo = true;                 // remove this function/type
             aTok = aTok.copy(1);
         }
         if( !aTok.isEmpty() )
         {
-            sal_uLong nVal;
-            sscanf( aTok.getStr(), "%li", &nVal );
+            sal_Int64 nVal = aTok.toInt64();
             switch ( nInitFile )
             {
                 case 1: InsertFrame( sal_uInt16( nVal ) );    // add FrameId
                         break;
                 case 2: {
-                            sal_uInt16 nNew = (sal_uInt16)nVal;
+                            SwFrameType nNew = static_cast<SwFrameType>(nVal);
                             if( bNo )
                                 nTypes &= ~nNew;    // remove type
                             else
@@ -360,11 +361,11 @@ void SwImplProtocol::CheckLine( OString& rLine )
                         }
                         break;
                 case 3: {
-                            sal_uLong nOld = SwProtocol::Record();
+                            PROT nOld = SwProtocol::Record();
                             if( bNo )
-                                nOld &= ~nVal;      // remove function
+                                nOld &= ~PROT(nVal); // remove function
                             else
-                                nOld |= nVal;       // remove function
+                                nOld |= PROT(nVal);  // remove function
                             SwProtocol::SetRecord( nOld );
                         }
                         break;
@@ -378,7 +379,7 @@ void SwImplProtocol::CheckLine( OString& rLine )
                         break;
                 case 5: nMaxLines = (sal_uInt16)nVal;
                         break;
-                case 6: aVars.push_back( (long)nVal );
+                case 6: aVars.push_back( nVal );
                         break;
             }
         }
@@ -407,7 +408,7 @@ void SwImplProtocol::FileInit()
                 aLine.clear();
             }
             else
-                aLine = OString(c);
+                aLine += OString(c);
         }
         if( !aLine.isEmpty() )
             CheckLine( aLine );     // evaluate last line
@@ -415,15 +416,15 @@ void SwImplProtocol::FileInit()
     aStream.Close();
 }
 
-/// enable indentation by two spaces during ACT_START and disable it again at ACT_END.
-static void lcl_Start(OStringBuffer& rOut, OStringBuffer& rLay, sal_uLong nAction)
+/// enable indentation by two spaces during DbgAction::Start and disable it again at DbgAction::End.
+static void lcl_Start(OStringBuffer& rOut, OStringBuffer& rLay, DbgAction nAction)
 {
-    if( nAction == ACT_START )
+    if( nAction == DbgAction::Start )
     {
         rLay.append("  ");
         rOut.append(" On");
     }
-    else if( nAction == ACT_END )
+    else if( nAction == DbgAction::End )
     {
         if( rLay.getLength() > 1 )
         {
@@ -438,56 +439,56 @@ static void lcl_Start(OStringBuffer& rOut, OStringBuffer& rLay, sal_uLong nActio
 /// of the frame; "+" stands for valid, "-" stands for invalid.
 static void lcl_Flags(OStringBuffer& rOut, const SwFrame* pFrame)
 {
-    rOut.append(" Sz");
-    rOut.append(pFrame->GetValidSizeFlag() ? '+' : '-');
-    rOut.append(" Ps");
-    rOut.append(pFrame->GetValidPosFlag() ? '+' : '-');
-    rOut.append(" PA");
-    rOut.append(pFrame->GetValidPrtAreaFlag() ? '+' : '-');
+    rOut.append(" ValidSize");
+    rOut.append(pFrame->isFrameAreaSizeValid() ? '+' : '-');
+    rOut.append(" ValidPos");
+    rOut.append(pFrame->isFrameAreaPositionValid() ? '+' : '-');
+    rOut.append(" ValidPrtArea");
+    rOut.append(pFrame->isFramePrintAreaValid() ? '+' : '-');
 }
 
 /// output the type of the frame as plain text.
 static void lcl_FrameType( OStringBuffer& rOut, const SwFrame* pFrame )
 {
     if( pFrame->IsTextFrame() )
-        rOut.append("Text ");
+        rOut.append("SwTextFrame ");
     else if( pFrame->IsLayoutFrame() )
     {
         if( pFrame->IsPageFrame() )
-            rOut.append("Page ");
+            rOut.append("SwPageFrame ");
         else if( pFrame->IsColumnFrame() )
-            rOut.append("Col ");
+            rOut.append("SwColumnFrame ");
         else if( pFrame->IsBodyFrame() )
         {
             if( pFrame->GetUpper() && pFrame->IsColBodyFrame() )
                 rOut.append("(Col)");
-            rOut.append("Body ");
+            rOut.append("SwBodyFrame ");
         }
         else if( pFrame->IsRootFrame() )
-            rOut.append("Root ");
+            rOut.append("SwRootFrame ");
         else if( pFrame->IsCellFrame() )
-            rOut.append("Cell ");
+            rOut.append("SwCellFrame ");
         else if( pFrame->IsTabFrame() )
-            rOut.append("Tab ");
+            rOut.append("SwTabFrame ");
         else if( pFrame->IsRowFrame() )
-            rOut.append("Row ");
+            rOut.append("SwRowFrame ");
         else if( pFrame->IsSctFrame() )
-            rOut.append("Sect ");
+            rOut.append("SwSectionFrame ");
         else if( pFrame->IsHeaderFrame() )
-            rOut.append("Header ");
+            rOut.append("SwHeaderFrame ");
         else if( pFrame->IsFooterFrame() )
-            rOut.append("Footer ");
+            rOut.append("SwFooterFrame ");
         else if( pFrame->IsFootnoteFrame() )
-            rOut.append("Footnote ");
+            rOut.append("SwFootnoteFrame ");
         else if( pFrame->IsFootnoteContFrame() )
-            rOut.append("FootnoteCont ");
+            rOut.append("SwFootnoteContFrame ");
         else if( pFrame->IsFlyFrame() )
-            rOut.append("Fly ");
+            rOut.append("SwFlyFrame ");
         else
-            rOut.append("Layout ");
+            rOut.append("SwLayoutFrame ");
     }
     else if( pFrame->IsNoTextFrame() )
-        rOut.append("NoText ");
+        rOut.append("SwNoTextFrame");
     else
         rOut.append("Not impl. ");
 }
@@ -498,7 +499,7 @@ static void lcl_FrameType( OStringBuffer& rOut, const SwFrame* pFrame )
  *
  * In this method we also check if FrameId and frame type should be logged.
  */
-void SwImplProtocol::_Record( const SwFrame* pFrame, sal_uLong nFunction, sal_uLong nAct, void* pParam )
+void SwImplProtocol::Record_( const SwFrame* pFrame, PROT nFunction, DbgAction nAct, void* pParam )
 {
     sal_uInt16 nSpecial = 0;
     if( nSpecial )  // the possible debugger manipulations
@@ -522,7 +523,7 @@ void SwImplProtocol::_Record( const SwFrame* pFrame, sal_uLong nFunction, sal_uL
     if( !(pFrame->GetType() & nTypes) )
         return; // the type is unwanted
 
-    if( 1 == nTestMode && nFunction != PROT_TESTFORMAT )
+    if( 1 == nTestMode && nFunction != PROT::TestFormat )
         return; // we may only log inside a test formatting
     bool bTmp = false;
     OStringBuffer aOut(aLayer);
@@ -531,19 +532,20 @@ void SwImplProtocol::_Record( const SwFrame* pFrame, sal_uLong nFunction, sal_uL
     lcl_FrameType( aOut, pFrame );    // then the frame type
     switch ( nFunction )            // and the function
     {
-        case PROT_SNAPSHOT: lcl_Flags( aOut, pFrame );
+        case PROT::Snapshot: lcl_Flags( aOut, pFrame );
                             break;
-        case PROT_MAKEALL:  aOut.append("MakeAll");
+        case PROT::MakeAll:  aOut.append("SwFrame::MakeAll");
                             lcl_Start( aOut, aLayer, nAct );
-                            if( nAct == ACT_START )
+                            if( nAct == DbgAction::Start )
                                 lcl_Flags( aOut, pFrame );
                             break;
-        case PROT_MOVE_FWD: bTmp = true; // NoBreak
-        case PROT_MOVE_BWD:
-                            if (nFunction == (bTmp ? 1U : 0U))
-                                aOut.append("Fwd");
+        case PROT::MoveFwd: bTmp = true;
+                            SAL_FALLTHROUGH;
+        case PROT::MoveBack:
+                            if (nFunction == (bTmp ? PROT::Init : PROT::FileInit))
+                                aOut.append("SwFlowFrame::MoveFwd");
                             else
-                                aOut.append("Bwd");
+                                aOut.append("SwFlowFrame::MoveBwd");
                             lcl_Start( aOut, aLayer, nAct );
                             if( pParam )
                             {
@@ -551,25 +553,26 @@ void SwImplProtocol::_Record( const SwFrame* pFrame, sal_uLong nFunction, sal_uL
                                 aOut.append(static_cast<sal_Int32>(*static_cast<sal_uInt16*>(pParam)));
                             }
                             break;
-        case PROT_GROW_TST: if( ACT_START != nAct )
-                                return;
-                            aOut.append("TestGrow");
+        case PROT::GrowTest:
+                            aOut.append("SwFrame::Grow (test)");
+                            lcl_Start( aOut, aLayer, nAct );
                             break;
-        case PROT_SHRINK_TST: if( ACT_START != nAct )
-                                return;
-                            aOut.append("TestShrink");
+        case PROT::ShrinkTest:
+                            aOut.append("SwFrame::Shrink (test)");
+                            lcl_Start( aOut, aLayer, nAct );
                             break;
-        case PROT_ADJUSTN :
-        case PROT_SHRINK:   bTmp = true; // NoBreak
-        case PROT_GROW:
+        case PROT::AdjustN :
+        case PROT::Shrink:   bTmp = true;
+                            SAL_FALLTHROUGH;
+        case PROT::Grow:
                             if (!bTmp)
-                                aOut.append("Grow");
+                                aOut.append("SwFrame::Grow");
                             else
                             {
-                                if (nFunction == PROT_SHRINK)
-                                    aOut.append("Shrink");
+                                if (nFunction == PROT::Shrink)
+                                    aOut.append("SwFrame::Shrink");
                                 else
-                                    aOut.append("AdjustNgbhd");
+                                    aOut.append("SwFrame::AdjustNeighbourhood");
                             }
                             lcl_Start( aOut, aLayer, nAct );
                             if( pParam )
@@ -578,16 +581,16 @@ void SwImplProtocol::_Record( const SwFrame* pFrame, sal_uLong nFunction, sal_uL
                                 aOut.append(static_cast<sal_Int64>(*static_cast<long*>(pParam)));
                             }
                             break;
-        case PROT_POS:      break;
-        case PROT_PRTAREA:  aOut.append("PrtArea");
+        case PROT::Pos:      break;
+        case PROT::PrintArea:  aOut.append("PROT::PrintArea");
                             lcl_Start( aOut, aLayer, nAct );
                             break;
-        case PROT_SIZE:     aOut.append("Size");
+        case PROT::Size:     aOut.append("PROT::Size");
                             lcl_Start( aOut, aLayer, nAct );
                             aOut.append(' ');
-                            aOut.append(static_cast<sal_Int64>(pFrame->Frame().Height()));
+                            aOut.append(static_cast<sal_Int64>(pFrame->getFrameArea().Height()));
                             break;
-        case PROT_LEAF:     aOut.append("Prev/NextLeaf");
+        case PROT::Leaf:     aOut.append("SwFrame::GetPrev/NextSctLeaf");
                             lcl_Start( aOut, aLayer, nAct );
                             aOut.append(' ');
                             if( pParam )
@@ -596,93 +599,102 @@ void SwImplProtocol::_Record( const SwFrame* pFrame, sal_uLong nFunction, sal_uL
                                 aOut.append(static_cast<sal_Int64>(lcl_GetFrameId(static_cast<SwFrame*>(pParam))));
                             }
                             break;
-        case PROT_FILE_INIT: FileInit();
+        case PROT::FileInit: FileInit();
                             aOut.append("Initialize");
                             break;
-        case PROT_SECTION:  SectFunc(aOut, pFrame, nAct, pParam);
+        case PROT::Section:  SectFunc(aOut, nAct, pParam);
                             break;
-        case PROT_CUT:      bTmp = true; // NoBreak
-        case PROT_PASTE:
+        case PROT::Cut:      bTmp = true;
+                            SAL_FALLTHROUGH;
+        case PROT::Paste:
                             if (bTmp)
-                                aOut.append("Cut from ");
+                                aOut.append("PROT::Cut from ");
                             else
-                                aOut.append("Paste to ");
+                                aOut.append("PROT::Paste to ");
                             aOut.append(static_cast<sal_Int64>(lcl_GetFrameId(static_cast<SwFrame*>(pParam))));
                             break;
-        case PROT_TESTFORMAT:
-                            aOut.append("Test");
+        case PROT::TestFormat:
+                            aOut.append("SwTextFrame::TestFormat");
                             lcl_Start( aOut, aLayer, nAct );
-                            if( ACT_START == nAct )
+                            if( DbgAction::Start == nAct )
                                 nTestMode |= 2;
                             else
                                 nTestMode &= ~2;
                             break;
-        case PROT_FRMCHANGES:
+        case PROT::FrmChanges:
                             {
                                 SwRect& rFrame = *static_cast<SwRect*>(pParam);
-                                if( pFrame->Frame().Pos() != rFrame.Pos() )
+                                if( pFrame->getFrameArea().Pos() != rFrame.Pos() )
                                 {
                                     aOut.append("PosChg: (");
                                     aOut.append(static_cast<sal_Int64>(rFrame.Left()));
                                     aOut.append(", ");
                                     aOut.append(static_cast<sal_Int64>(rFrame.Top()));
-                                    aOut.append(") (");
-                                    aOut.append(static_cast<sal_Int64>(pFrame->Frame().Left()));
+                                    aOut.append(") -> (");
+                                    aOut.append(static_cast<sal_Int64>(pFrame->getFrameArea().Left()));
                                     aOut.append(", ");
-                                    aOut.append(static_cast<sal_Int64>(pFrame->Frame().Top()));
+                                    aOut.append(static_cast<sal_Int64>(pFrame->getFrameArea().Top()));
                                     aOut.append(") ");
                                 }
-                                if( pFrame->Frame().Height() != rFrame.Height() )
+                                if( pFrame->getFrameArea().Height() != rFrame.Height() )
                                 {
                                     aOut.append("Height: ");
                                     aOut.append(static_cast<sal_Int64>(rFrame.Height()));
                                     aOut.append(" -> ");
-                                    aOut.append(static_cast<sal_Int64>(pFrame->Frame().Height()));
+                                    aOut.append(static_cast<sal_Int64>(pFrame->getFrameArea().Height()));
                                     aOut.append(" ");
                                 }
-                                if( pFrame->Frame().Width() != rFrame.Width() )
+                                if( pFrame->getFrameArea().Width() != rFrame.Width() )
                                 {
                                     aOut.append("Width: ");
                                     aOut.append(static_cast<sal_Int64>(rFrame.Width()));
                                     aOut.append(" -> ");
-                                    aOut.append(static_cast<sal_Int64>(pFrame->Frame().Width()));
+                                    aOut.append(static_cast<sal_Int64>(pFrame->getFrameArea().Width()));
                                     aOut.append(' ');
                                 }
                                 break;
                             }
+        default: break;
     }
     pStream->WriteCharPtr( aOut.getStr() );
     (*pStream) << endl;  // output
     pStream->Flush();   // to the disk, so we can read it immediately
+    SAL_INFO("sw.layout.debug", aOut.getStr());
     if( ++nLineCount >= nMaxLines )     // max number of lines reached?
-        SwProtocol::SetRecord( 0 );        // => end f logging
+    {
+        SAL_WARN("sw.layout.debug", "max number of lines reached");
+        SwProtocol::SetRecord( PROT::FileInit );        // => end f logging
+    }
 }
 
 /// Handle the output of the SectionFrames.
-void SwImplProtocol::SectFunc(OStringBuffer &rOut, const SwFrame* , sal_uLong nAct, void* pParam)
+void SwImplProtocol::SectFunc(OStringBuffer &rOut, DbgAction nAct, void const * pParam)
 {
     bool bTmp = false;
     switch( nAct )
     {
-        case ACT_MERGE:         rOut.append("Merge Section ");
-                                rOut.append(static_cast<sal_Int64>(lcl_GetFrameId(static_cast<SwFrame*>(pParam))));
+        case DbgAction::Merge:  rOut.append("Merge Section ");
+                                rOut.append(static_cast<sal_Int64>(lcl_GetFrameId(static_cast<SwFrame const *>(pParam))));
                                 break;
-        case ACT_CREATE_MASTER: bTmp = true; // NoBreak
-        case ACT_CREATE_FOLLOW: rOut.append("Create Section ");
+        case DbgAction::CreateMaster: bTmp = true;
+                                SAL_FALLTHROUGH;
+        case DbgAction::CreateFollow: rOut.append("Create Section ");
                                 if (bTmp)
                                     rOut.append("Master to ");
                                 else
                                     rOut.append("Follow from ");
-                                rOut.append(static_cast<sal_Int64>(lcl_GetFrameId(static_cast<SwFrame*>(pParam))));
+                                rOut.append(static_cast<sal_Int64>(lcl_GetFrameId(static_cast<SwFrame const *>(pParam))));
                                 break;
-        case ACT_DEL_MASTER:    bTmp = true; // NoBreak
-        case ACT_DEL_FOLLOW:    rOut.append("Delete Section ");
+        case DbgAction::DelMaster:    bTmp = true;
+                                SAL_FALLTHROUGH;
+        case DbgAction::DelFollow:    rOut.append("Delete Section ");
                                 if (bTmp)
                                     rOut.append("Master to ");
                                 else
                                     rOut.append("Follow from ");
-                                rOut.append(static_cast<sal_Int64>(lcl_GetFrameId(static_cast<SwFrame*>(pParam))));
+                                rOut.append(static_cast<sal_Int64>(lcl_GetFrameId(static_cast<SwFrame const *>(pParam))));
                                 break;
+        default: break;
     }
 }
 
@@ -708,9 +720,7 @@ bool SwImplProtocol::DeleteFrame( sal_uInt16 nId )
 {
     if( !pFrameIds )
         return false;
-    if ( pFrameIds->erase(nId) )
-        return true;
-    return false;
+    return pFrameIds->erase(nId) != 0;
 }
 
 /* SwEnterLeave::Ctor(..) is called from the (inline-)CTor if the function should
@@ -718,16 +728,16 @@ bool SwImplProtocol::DeleteFrame( sal_uInt16 nId )
  * The task here is to find the right SwImplEnterLeave object based on the
  * function; everything else is then done in his Ctor/Dtor.
  */
-void SwEnterLeave::Ctor( const SwFrame* pFrame, sal_uLong nFunc, sal_uLong nAct, void* pPar )
+void SwEnterLeave::Ctor( const SwFrame* pFrame, PROT nFunc, DbgAction nAct, void* pPar )
 {
     switch( nFunc )
     {
-        case PROT_ADJUSTN :
-        case PROT_GROW:
-        case PROT_SHRINK : pImpl = new SwSizeEnterLeave( pFrame, nFunc, nAct, pPar ); break;
-        case PROT_MOVE_FWD:
-        case PROT_MOVE_BWD : pImpl = new SwUpperEnterLeave( pFrame, nFunc, nAct, pPar ); break;
-        case PROT_FRMCHANGES : pImpl = new SwFrameChangesLeave( pFrame, nFunc, nAct, pPar ); break;
+        case PROT::AdjustN :
+        case PROT::Grow:
+        case PROT::Shrink : pImpl = new SwSizeEnterLeave( pFrame, nFunc, nAct, pPar ); break;
+        case PROT::MoveFwd:
+        case PROT::MoveBack : pImpl = new SwUpperEnterLeave( pFrame, nFunc, nAct, pPar ); break;
+        case PROT::FrmChanges : pImpl = new SwFrameChangesLeave( pFrame, nFunc, nAct, pPar ); break;
         default: pImpl = new SwImplEnterLeave( pFrame, nFunc, nAct, pPar ); break;
     }
     pImpl->Enter();
@@ -748,30 +758,30 @@ void SwEnterLeave::Dtor()
 
 void SwImplEnterLeave::Enter()
 {
-    SwProtocol::Record( pFrame, nFunction, ACT_START, pParam );
+    SwProtocol::Record( pFrame, nFunction, DbgAction::Start, pParam );
 }
 
 void SwImplEnterLeave::Leave()
 {
-    SwProtocol::Record( pFrame, nFunction, ACT_END, pParam );
+    SwProtocol::Record( pFrame, nFunction, DbgAction::End, pParam );
 }
 
 void SwSizeEnterLeave::Leave()
 {
-    nFrameHeight = pFrame->Frame().Height() - nFrameHeight;
-    SwProtocol::Record( pFrame, nFunction, ACT_END, &nFrameHeight );
+    nFrameHeight = pFrame->getFrameArea().Height() - nFrameHeight;
+    SwProtocol::Record( pFrame, nFunction, DbgAction::End, &nFrameHeight );
 }
 
 void SwUpperEnterLeave::Enter()
 {
     nFrameId = pFrame->GetUpper() ? sal_uInt16(lcl_GetFrameId( pFrame->GetUpper() )) : 0;
-    SwProtocol::Record( pFrame, nFunction, ACT_START, &nFrameId );
+    SwProtocol::Record( pFrame, nFunction, DbgAction::Start, &nFrameId );
 }
 
 void SwUpperEnterLeave::Leave()
 {
     nFrameId = pFrame->GetUpper() ? sal_uInt16(lcl_GetFrameId( pFrame->GetUpper() )) : 0;
-    SwProtocol::Record( pFrame, nFunction, ACT_END, &nFrameId );
+    SwProtocol::Record( pFrame, nFunction, DbgAction::End, &nFrameId );
 }
 
 void SwFrameChangesLeave::Enter()
@@ -780,8 +790,8 @@ void SwFrameChangesLeave::Enter()
 
 void SwFrameChangesLeave::Leave()
 {
-    if( pFrame->Frame() != aFrame )
-        SwProtocol::Record( pFrame, PROT_FRMCHANGES, 0, &aFrame );
+    if( pFrame->getFrameArea() != aFrame )
+        SwProtocol::Record( pFrame, PROT::FrmChanges, DbgAction::NONE, &aFrame );
 }
 
 #endif // DBG_UTIL
