@@ -20,18 +20,18 @@
 #include <config_features.h>
 
 #include <ctime>
-#include "rootfrm.hxx"
-#include "pagefrm.hxx"
-#include "viewimp.hxx"
-#include "crsrsh.hxx"
-#include "dflyobj.hxx"
-#include "frmtool.hxx"
-#include "dcontact.hxx"
-#include "viewopt.hxx"
-#include "dbg_lay.hxx"
-#include "layouter.hxx"
-#include "docstat.hxx"
-#include "swevent.hxx"
+#include <rootfrm.hxx>
+#include <pagefrm.hxx>
+#include <viewimp.hxx>
+#include <crsrsh.hxx>
+#include <dflyobj.hxx>
+#include <frmtool.hxx>
+#include <dcontact.hxx>
+#include <viewopt.hxx>
+#include <dbg_lay.hxx>
+#include <layouter.hxx>
+#include <docstat.hxx>
+#include <swevent.hxx>
 #include <IDocumentStatistics.hxx>
 #include <IDocumentLayoutAccess.hxx>
 
@@ -42,28 +42,23 @@
 #include <editeng/opaqitem.hxx>
 #include <SwSmartTagMgr.hxx>
 
-#include "layact.hxx"
+#include <layact.hxx>
 #include <swwait.hxx>
 #include <fmtsrnd.hxx>
 #include <docsh.hxx>
 
-#include "tabfrm.hxx"
-#include "ftnfrm.hxx"
-#include "txtfrm.hxx"
-#include "notxtfrm.hxx"
-#include "flyfrms.hxx"
-#include "mdiexp.hxx"
-#include "sectfrm.hxx"
+#include <tabfrm.hxx>
+#include <ftnfrm.hxx>
+#include <txtfrm.hxx>
+#include <notxtfrm.hxx>
+#include <flyfrms.hxx>
+#include <mdiexp.hxx>
+#include <sectfrm.hxx>
 #include <acmplwrd.hxx>
 #include <sortedobjs.hxx>
 #include <objectformatter.hxx>
 #include <vector>
 
-// SwLayAction static stuff
-
-#define IS_FLYS (pPage->GetSortedObjs())
-#define IS_INVAFLY (pPage->IsInvalidFly())
-
 // Save some typing work to avoid accessing destroyed pages.
 #define XCHECKPAGE \
             {   if ( IsAgain() ) \
@@ -74,17 +69,12 @@
                 } \
             }
 
-#define RESCHEDULE \
-    { \
-        if ( IsReschedule() )  \
-        { \
-            ::RescheduleProgress( m_pImp->GetShell()->GetDoc()->GetDocShell() ); \
-        } \
-    }
-
 void SwLayAction::CheckWaitCursor()
 {
-    RESCHEDULE
+    if (IsReschedule())
+    {
+        ::RescheduleProgress(m_pImp->GetShell()->GetDoc()->GetDocShell());
+    }
     if ( !m_pWait && IsWaitAllowed() && IsPaint() &&
          ((std::clock() - m_nStartTicks) * 1000 / CLOCKS_PER_SEC >= CLOCKS_PER_SEC/2) )
     {
@@ -132,7 +122,7 @@ bool SwLayAction::PaintWithoutFlys( const SwRect &rRect, const SwContentFrame *p
 
         SwFlyFrame *pFly = static_cast<SwVirtFlyDrawObj*>(pO)->GetFlyFrame();
 
-        if ( pFly == pSelfFly || !rRect.IsOver( pFly->Frame() ) )
+        if ( pFly == pSelfFly || !rRect.IsOver( pFly->getFrameArea() ) )
             continue;
 
         if ( pSelfFly && pSelfFly->IsLowerOf( pFly ) )
@@ -179,7 +169,7 @@ bool SwLayAction::PaintWithoutFlys( const SwRect &rRect, const SwContentFrame *p
             continue;
         }
 
-        aTmp -= pFly->Frame();
+        aTmp -= pFly->getFrameArea();
     }
 
     bool bRetPaint = false;
@@ -224,7 +214,7 @@ void SwLayAction::PaintContent( const SwContentFrame *pCnt,
         // paint the area between printing bottom and frame bottom and
         // the area left and right beside the frame, if its height changed.
         long nOldHeight = aRectFnSet.GetHeight(rOldRect);
-        long nNewHeight = aRectFnSet.GetHeight(pCnt->Frame());
+        long nNewHeight = aRectFnSet.GetHeight(pCnt->getFrameArea());
         const bool bHeightDiff = nOldHeight != nNewHeight;
         if( bHeightDiff )
         {
@@ -524,12 +514,12 @@ void SwLayAction::InternalAction(OutputDevice* pRenderContext)
             XCHECKPAGE;
 
             while ( !IsInterrupt() && !IsNextCycle() &&
-                    ((IS_FLYS && IS_INVAFLY) || pPage->IsInvalid()) )
+                    ((pPage->GetSortedObjs() && pPage->IsInvalidFly()) || pPage->IsInvalid()) )
             {
                 unlockPositionOfObjects( pPage );
 
                 SwObjectFormatter::FormatObjsAtFrame( *pPage, *pPage, this );
-                if ( !IS_FLYS )
+                if ( !pPage->GetSortedObjs() )
                 {
                     // If there are no (more) Flys, the flags are superfluous.
                     pPage->ValidateFlyLayout();
@@ -538,7 +528,7 @@ void SwLayAction::InternalAction(OutputDevice* pRenderContext)
                 // change condition
                 while ( !IsInterrupt() && !IsNextCycle() &&
                         ( pPage->IsInvalid() ||
-                          (IS_FLYS && IS_INVAFLY) ) )
+                          (pPage->GetSortedObjs() && pPage->IsInvalidFly()) ) )
                 {
                     PROTOCOL( pPage, PROT::FileInit, DbgAction::NONE, nullptr)
                     XCHECKPAGE;
@@ -563,7 +553,7 @@ void SwLayAction::InternalAction(OutputDevice* pRenderContext)
                     // change condition
                     if ( !IsNextCycle() &&
                          ( pPage->IsInvalidContent() ||
-                           (IS_FLYS && IS_INVAFLY) ) )
+                           (pPage->GetSortedObjs() && pPage->IsInvalidFly()) ) )
                     {
                         pPage->ValidateFlyInCnt();
                         pPage->ValidateContent();
@@ -589,7 +579,7 @@ void SwLayAction::InternalAction(OutputDevice* pRenderContext)
 
             // A previous page may be invalid again.
             XCHECKPAGE;
-            if ( !IS_FLYS )
+            if ( !pPage->GetSortedObjs() )
             {
                 // If there are no (more) Flys, the flags are superfluous.
                 pPage->ValidateFlyLayout();
@@ -629,7 +619,7 @@ void SwLayAction::InternalAction(OutputDevice* pRenderContext)
 
                 // Continue to the next invalid page
                 while ( pPage && !pPage->IsInvalid() &&
-                        (!IS_FLYS || !IS_INVAFLY) )
+                        (!pPage->GetSortedObjs() || !pPage->IsInvalidFly()) )
                 {
                     pPage = static_cast<SwPageFrame*>(pPage->GetNext());
                 }
@@ -685,7 +675,7 @@ void SwLayAction::InternalAction(OutputDevice* pRenderContext)
         XCHECKPAGE;
         const SwRect &rVis = m_pImp->GetShell()->VisArea();
 
-        while( pPg && pPg->Frame().Bottom() < rVis.Top() )
+        while( pPg && pPg->getFrameArea().Bottom() < rVis.Top() )
             pPg = static_cast<SwPageFrame*>(pPg->GetNext());
         if( pPg != pPage )
             pPg = pPg ? static_cast<SwPageFrame*>(pPg->GetPrev()) : pPage;
@@ -696,7 +686,7 @@ void SwLayAction::InternalAction(OutputDevice* pRenderContext)
         // #i42586# - format current page, if idle action is active
         // This is an optimization for the case that the interrupt is created by
         // the move of a form control object, which is represented by a window.
-        while ( pPg && ( pPg->Frame().Top() < nBottom ||
+        while ( pPg && ( pPg->getFrameArea().Top() < nBottom ||
                          ( IsIdle() && pPg == pPage ) ) )
         {
             unlockPositionOfObjects( pPg );
@@ -708,8 +698,7 @@ void SwLayAction::InternalAction(OutputDevice* pRenderContext)
             const int nLoopControlMax = 20;
 
             // special case: interrupt content formatting
-            // conditions are incorrect (macros IS_FLYS and IS_INVAFLY only
-            //            works for <pPage>) and are too strict.
+            // conditions are incorrect and are too strict.
             // adjust interrupt formatting to normal page formatting - see above.
             while ( ( mbFormatContentOnInterrupt &&
                       ( pPg->IsInvalid() ||
@@ -788,12 +777,12 @@ bool SwLayAction::TurboAction_( const SwContentFrame *pCnt )
 {
 
     const SwPageFrame *pPage = nullptr;
-    if ( !pCnt->IsValid() || pCnt->IsCompletePaint() || pCnt->IsRetouche() )
+    if ( !pCnt->isFrameAreaDefinitionValid() || pCnt->IsCompletePaint() || pCnt->IsRetouche() )
     {
         const SwRect aOldRect( pCnt->UnionFrame( true ) );
-        const long   nOldBottom = pCnt->Frame().Top() + pCnt->Prt().Bottom();
+        const long   nOldBottom = pCnt->getFrameArea().Top() + pCnt->getFramePrintArea().Bottom();
         pCnt->Calc(m_pImp->GetShell()->GetOut());
-        if ( pCnt->Frame().Bottom() < aOldRect.Bottom() )
+        if ( pCnt->getFrameArea().Bottom() < aOldRect.Bottom() )
             pCnt->SetRetouche();
 
         pPage = pCnt->FindPageFrame();
@@ -806,7 +795,7 @@ bool SwLayAction::TurboAction_( const SwContentFrame *pCnt )
             if ( nAllLines != static_cast<const SwTextFrame*>(pCnt)->GetAllLines() )
             {
                 if ( IsPaintExtraData() )
-                    m_pImp->GetShell()->AddPaintRect( pCnt->Frame() );
+                    m_pImp->GetShell()->AddPaintRect( pCnt->getFrameArea() );
                 // This is to calculate the remaining LineNums on the page,
                 // and we don't stop processing here. To perform this inside RecalcAllLines
                 // would be expensive, because we would have to notify the page even
@@ -821,7 +810,7 @@ bool SwLayAction::TurboAction_( const SwContentFrame *pCnt )
             return false;
         }
 
-        if ( pPage->IsInvalidLayout() || (IS_FLYS && IS_INVAFLY) )
+        if ( pPage->IsInvalidLayout() || (pPage->GetSortedObjs() && pPage->IsInvalidFly()) )
             return false;
     }
     if ( !pPage )
@@ -829,7 +818,7 @@ bool SwLayAction::TurboAction_( const SwContentFrame *pCnt )
 
     // format floating screen objects at content frame.
     if ( pCnt->IsTextFrame() &&
-         !SwObjectFormatter::FormatObjsAtFrame( *(const_cast<SwContentFrame*>(pCnt)),
+         !SwObjectFormatter::FormatObjsAtFrame( *const_cast<SwContentFrame*>(pCnt),
                                               *pPage, this ) )
     {
         return false;
@@ -860,8 +849,8 @@ bool SwLayAction::TurboAction()
 
 static bool lcl_IsInvaLay( const SwFrame *pFrame, long nBottom )
 {
-    return !pFrame->IsValid() ||
-         (pFrame->IsCompletePaint() && ( pFrame->Frame().Top() < nBottom ) );
+    return !pFrame->isFrameAreaDefinitionValid() ||
+         (pFrame->IsCompletePaint() && ( pFrame->getFrameArea().Top() < nBottom ) );
 }
 
 static const SwFrame *lcl_FindFirstInvaLay( const SwFrame *pFrame, long nBottom )
@@ -893,9 +882,9 @@ static const SwFrame *lcl_FindFirstInvaContent( const SwLayoutFrame *pLay, long
                                       pLay->ContainsContent();
     while ( pCnt )
     {
-        if ( !pCnt->IsValid() || pCnt->IsCompletePaint() )
+        if ( !pCnt->isFrameAreaDefinitionValid() || pCnt->IsCompletePaint() )
         {
-            if ( pCnt->Frame().Top() <= nBottom )
+            if ( pCnt->getFrameArea().Top() <= nBottom )
                 return pCnt;
         }
 
@@ -904,25 +893,24 @@ static const SwFrame *lcl_FindFirstInvaContent( const SwLayoutFrame *pLay, long
             const SwSortedObjs &rObjs = *pCnt->GetDrawObjs();
             for (SwAnchoredObject* pObj : rObjs)
             {
-                if ( dynamic_cast< const SwFlyFrame *>( pObj ) !=  nullptr )
+                if ( auto pFly = dynamic_cast< const SwFlyFrame *>( pObj ) )
                 {
-                    const SwFlyFrame* pFly = static_cast<const SwFlyFrame*>(pObj);
                     if ( pFly->IsFlyInContentFrame() )
                     {
                         if ( static_cast<const SwFlyInContentFrame*>(pFly)->IsInvalid() ||
                              pFly->IsCompletePaint() )
                         {
-                            if ( pFly->Frame().Top() <= nBottom )
+                            if ( pFly->getFrameArea().Top() <= nBottom )
                                 return pFly;
                         }
                         const SwFrame *pFrame = lcl_FindFirstInvaContent( pFly, nBottom, nullptr );
-                        if ( pFrame && pFrame->Frame().Bottom() <= nBottom )
+                        if ( pFrame && pFrame->getFrameArea().Bottom() <= nBottom )
                             return pFrame;
                     }
                 }
             }
         }
-        if ( pCnt->Frame().Top() > nBottom && !pCnt->IsInTab() )
+        if ( pCnt->getFrameArea().Top() > nBottom && !pCnt->IsInTab() )
             return nullptr;
         pCnt = pCnt->GetNextContentFrame();
         if ( !pLay->IsAnLower( pCnt ) )
@@ -939,23 +927,22 @@ static const SwAnchoredObject* lcl_FindFirstInvaObj( const SwPageFrame* _pPage,
 
     for (SwAnchoredObject* pObj : *_pPage->GetSortedObjs())
     {
-        if ( dynamic_cast< const SwFlyFrame *>( pObj ) !=  nullptr )
+        if ( auto pFly = dynamic_cast< const SwFlyFrame *>( pObj )  )
         {
-            const SwFlyFrame* pFly = static_cast<const SwFlyFrame*>(pObj);
-            if ( pFly->Frame().Top() <= _nBottom )
+            if ( pFly->getFrameArea().Top() <= _nBottom )
             {
                 if ( pFly->IsInvalid() || pFly->IsCompletePaint() )
                     return pFly;
 
                 const SwFrame* pTmp;
                 if ( nullptr != (pTmp = lcl_FindFirstInvaContent( pFly, _nBottom, nullptr )) &&
-                     pTmp->Frame().Top() <= _nBottom )
+                     pTmp->getFrameArea().Top() <= _nBottom )
                     return pFly;
             }
         }
-        else if ( dynamic_cast< const SwAnchoredDrawObject *>( pObj ) !=  nullptr )
+        else if ( auto pDrawObject = dynamic_cast< const SwAnchoredDrawObject *>( pObj ) )
         {
-            if ( !static_cast<const SwAnchoredDrawObject*>(pObj)->IsValidPos() )
+            if ( !pDrawObject->IsValidPos() )
             {
                 return pObj;
             }
@@ -981,7 +968,7 @@ bool SwLayAction::IsShortCut( SwPageFrame *&prPage )
 
     // If the page is not valid, we quickly format it, otherwise
     // there's gonna be no end of trouble
-    if ( !prPage->IsValid() )
+    if ( !prPage->isFrameAreaDefinitionValid() )
     {
         if ( bBrowse )
         {
@@ -1005,8 +992,8 @@ bool SwLayAction::IsShortCut( SwPageFrame *&prPage )
     }
 
     const SwRect &rVis = m_pImp->GetShell()->VisArea();
-    if ( (prPage->Frame().Top() >= rVis.Bottom()) ||
-         (prPage->Frame().Left()>= rVis.Right()) )
+    if ( (prPage->getFrameArea().Top() >= rVis.Bottom()) ||
+         (prPage->getFrameArea().Left()>= rVis.Right()) )
     {
         bRet = true;
 
@@ -1051,8 +1038,8 @@ bool SwLayAction::IsShortCut( SwPageFrame *&prPage )
                     pLst = pContent->FindSctFrame();
                 pLst = pLst->FindPrev();
                 if ( pLst &&
-                     (pLst->Frame().Top() >= rVis.Bottom() ||
-                      pLst->Frame().Left()>= rVis.Right()) )
+                     (pLst->getFrameArea().Top() >= rVis.Bottom() ||
+                      pLst->getFrameArea().Left()>= rVis.Right()) )
                 {
                     bTstCnt = false;
                 }
@@ -1068,7 +1055,7 @@ bool SwLayAction::IsShortCut( SwPageFrame *&prPage )
                 if ( pContent->IsInSct() )
                 {
                     const SwSectionFrame *pSct = const_cast<SwFrame*>(static_cast<SwFrame const *>(pContent))->ImplFindSctFrame();
-                    if ( !pSct->IsValid() )
+                    if ( !pSct->isFrameAreaDefinitionValid() )
                     {
                         pSct->Calc(pRenderContext);
                         pSct->SetCompletePaint();
@@ -1080,7 +1067,7 @@ bool SwLayAction::IsShortCut( SwPageFrame *&prPage )
                     }
                 }
 
-                if ( !bPageChg && !pContent->IsValid() )
+                if ( !bPageChg && !pContent->isFrameAreaDefinitionValid() )
                 {
                     pContent->Calc(pRenderContext);
                     pContent->SetCompletePaint();
@@ -1094,7 +1081,7 @@ bool SwLayAction::IsShortCut( SwPageFrame *&prPage )
                 if ( !bPageChg && pContent->IsInTab() )
                 {
                     const SwTabFrame *pTab = const_cast<SwFrame*>(static_cast<SwFrame const *>(pContent))->ImplFindTabFrame();
-                    if ( !pTab->IsValid() )
+                    if ( !pTab->isFrameAreaDefinitionValid() )
                     {
                         pTab->Calc(pRenderContext);
                         pTab->SetCompletePaint();
@@ -1109,7 +1096,7 @@ bool SwLayAction::IsShortCut( SwPageFrame *&prPage )
                 if ( !bPageChg && pContent->IsInSct() )
                 {
                     const SwSectionFrame *pSct = const_cast<SwFrame*>(static_cast<SwFrame const *>(pContent))->ImplFindSctFrame();
-                    if ( !pSct->IsValid() )
+                    if ( !pSct->isFrameAreaDefinitionValid() )
                     {
                         pSct->Calc(pRenderContext);
                         pSct->SetCompletePaint();
@@ -1171,13 +1158,13 @@ bool SwLayAction::IsShortCut( SwPageFrame *&prPage )
         const SwFrame* pFrame( nullptr );
         if ( prPage->IsInvalidLayout() &&
              nullptr != (pFrame = lcl_FindFirstInvaLay( prPage, nBottom )) &&
-             pFrame->Frame().Top() <= nBottom )
+             pFrame->getFrameArea().Top() <= nBottom )
         {
             return false;
         }
         if ( (prPage->IsInvalidContent() || prPage->IsInvalidFlyInCnt()) &&
              nullptr != (pFrame = lcl_FindFirstInvaContent( prPage, nBottom, nullptr )) &&
-             pFrame->Frame().Top() <= nBottom )
+             pFrame->getFrameArea().Top() <= nBottom )
         {
             return false;
         }
@@ -1198,12 +1185,12 @@ bool SwLayAction::FormatLayout( OutputDevice *pRenderContext, SwLayoutFrame *pLa
     // remember frame at complete paint
     SwRect aFrameAtCompletePaint;
 
-    if ( !pLay->IsValid() || pLay->IsCompletePaint() )
+    if ( !pLay->isFrameAreaDefinitionValid() || pLay->IsCompletePaint() )
     {
-        if ( pLay->GetPrev() && !pLay->GetPrev()->IsValid() )
+        if ( pLay->GetPrev() && !pLay->GetPrev()->isFrameAreaDefinitionValid() )
             pLay->GetPrev()->SetCompletePaint();
 
-        SwRect aOldFrame( pLay->Frame() );
+        SwRect aOldFrame( pLay->getFrameArea() );
         SwRect aOldRect( aOldFrame );
         if( pLay->IsPageFrame() )
         {
@@ -1215,12 +1202,12 @@ bool SwLayAction::FormatLayout( OutputDevice *pRenderContext, SwLayoutFrame *pLa
             pLay->Calc(pRenderContext);
         }
 
-        if ( aOldFrame != pLay->Frame() )
+        if ( aOldFrame != pLay->getFrameArea() )
             bChanged = true;
 
         bool bNoPaint = false;
         if ( pLay->IsPageBodyFrame() &&
-             pLay->Frame().Pos() == aOldRect.Pos() &&
+             pLay->getFrameArea().Pos() == aOldRect.Pos() &&
              pLay->Lower() )
         {
             const SwViewShell *pSh = pLay->getRootFrame()->GetCurrShell();
@@ -1232,7 +1219,7 @@ bool SwLayAction::FormatLayout( OutputDevice *pRenderContext, SwLayoutFrame *pLa
 
         if ( !bNoPaint && IsPaint() && bAddRect && (pLay->IsCompletePaint() || bChanged) )
         {
-            SwRect aPaint( pLay->Frame() );
+            SwRect aPaint( pLay->getFrameArea() );
             // consider border and shadow for
             // page frames -> enlarge paint rectangle correspondingly.
             if ( pLay->IsPageFrame() )
@@ -1276,7 +1263,7 @@ bool SwLayAction::FormatLayout( OutputDevice *pRenderContext, SwLayoutFrame *pLa
                 m_pImp->GetShell()->AddPaintRect( aPaint );
                 bAlreadyPainted = true;
                 // remember frame at complete paint
-                aFrameAtCompletePaint = pLay->Frame();
+                aFrameAtCompletePaint = pLay->getFrameArea();
             }
 
             // provide paint of spacing
@@ -1290,7 +1277,7 @@ bool SwLayAction::FormatLayout( OutputDevice *pRenderContext, SwLayoutFrame *pLa
                 const bool bPrev = bLeftToRightViewLayout ? pLay->GetPrev() : pLay->GetNext();
                 const bool bNext = bLeftToRightViewLayout ? pLay->GetNext() : pLay->GetPrev();
                 SwPageFrame* pPageFrame = static_cast<SwPageFrame*>(pLay);
-                SwRect aPageRect( pLay->Frame() );
+                SwRect aPageRect( pLay->getFrameArea() );
 
                 if(pSh)
                 {
@@ -1305,14 +1292,14 @@ bool SwLayAction::FormatLayout( OutputDevice *pRenderContext, SwLayoutFrame *pLa
                     // top
                     SwRect aSpaceToPrevPage( aPageRect );
                     aSpaceToPrevPage.Top( aSpaceToPrevPage.Top() - nHalfDocBorder );
-                    aSpaceToPrevPage.Bottom( pLay->Frame().Top() );
+                    aSpaceToPrevPage.Bottom( pLay->getFrameArea().Top() );
                     if(aSpaceToPrevPage.Height() > 0 && aSpaceToPrevPage.Width() > 0)
                         m_pImp->GetShell()->AddPaintRect( aSpaceToPrevPage );
 
                     // left
                     aSpaceToPrevPage = aPageRect;
                     aSpaceToPrevPage.Left( aSpaceToPrevPage.Left() - nHalfDocBorder );
-                    aSpaceToPrevPage.Right( pLay->Frame().Left() );
+                    aSpaceToPrevPage.Right( pLay->getFrameArea().Left() );
                     if(aSpaceToPrevPage.Height() > 0 && aSpaceToPrevPage.Width() > 0)
                         m_pImp->GetShell()->AddPaintRect( aSpaceToPrevPage );
                 }
@@ -1321,14 +1308,14 @@ bool SwLayAction::FormatLayout( OutputDevice *pRenderContext, SwLayoutFrame *pLa
                     // bottom
                     SwRect aSpaceToNextPage( aPageRect );
                     aSpaceToNextPage.Bottom( aSpaceToNextPage.Bottom() + nHalfDocBorder );
-                    aSpaceToNextPage.Top( pLay->Frame().Bottom() );
+                    aSpaceToNextPage.Top( pLay->getFrameArea().Bottom() );
                     if(aSpaceToNextPage.Height() > 0 && aSpaceToNextPage.Width() > 0)
                         m_pImp->GetShell()->AddPaintRect( aSpaceToNextPage );
 
                     // right
                     aSpaceToNextPage = aPageRect;
                     aSpaceToNextPage.Right( aSpaceToNextPage.Right() + nHalfDocBorder );
-                    aSpaceToNextPage.Left( pLay->Frame().Right() );
+                    aSpaceToNextPage.Left( pLay->getFrameArea().Right() );
                     if(aSpaceToNextPage.Height() > 0 && aSpaceToNextPage.Width() > 0)
                         m_pImp->GetShell()->AddPaintRect( aSpaceToNextPage );
                 }
@@ -1385,7 +1372,7 @@ bool SwLayAction::FormatLayout( OutputDevice *pRenderContext, SwLayoutFrame *pLa
     // add complete frame area as paint area, if frame
     // area has been already added and after formatting its lowers the frame area
     // is enlarged.
-    SwRect aBoundRect(pLay->IsPageFrame() ? static_cast<SwPageFrame*>(pLay)->GetBoundRect(pRenderContext) : pLay->Frame() );
+    SwRect aBoundRect(pLay->IsPageFrame() ? static_cast<SwPageFrame*>(pLay)->GetBoundRect(pRenderContext) : pLay->getFrameArea() );
 
     if ( bAlreadyPainted &&
          ( aBoundRect.Width() > aFrameAtCompletePaint.Width() ||
@@ -1407,16 +1394,16 @@ bool SwLayAction::FormatLayoutFly( SwFlyFrame* pFly )
     bool bChanged = false;
     bool bAddRect = true;
 
-    if ( !pFly->IsValid() || pFly->IsCompletePaint() || pFly->IsInvalid() )
+    if ( !pFly->isFrameAreaDefinitionValid() || pFly->IsCompletePaint() || pFly->IsInvalid() )
     {
         // The Frame has changed, now it's getting formatted.
-        const SwRect aOldRect( pFly->Frame() );
+        const SwRect aOldRect( pFly->getFrameArea() );
         pFly->Calc(pRenderContext);
-        bChanged = aOldRect != pFly->Frame();
+        bChanged = aOldRect != pFly->getFrameArea();
 
         if ( IsPaint() && (pFly->IsCompletePaint() || bChanged) &&
-                    pFly->Frame().Top() > 0 && pFly->Frame().Left() > 0 )
-            m_pImp->GetShell()->AddPaintRect( pFly->Frame() );
+                    pFly->getFrameArea().Top() > 0 && pFly->getFrameArea().Left() > 0 )
+            m_pImp->GetShell()->AddPaintRect( pFly->getFrameArea() );
 
         if ( bChanged )
             pFly->Invalidate();
@@ -1466,17 +1453,17 @@ bool SwLayAction::FormatLayoutTab( SwTabFrame *pTab, bool bAddRect )
     // vertical layout support
     SwRectFnSet aRectFnSet(pTab);
 
-    if ( !pTab->IsValid() || pTab->IsCompletePaint() || pTab->IsComplete() )
+    if ( !pTab->isFrameAreaDefinitionValid() || pTab->IsCompletePaint() || pTab->IsComplete() )
     {
-        if ( pTab->GetPrev() && !pTab->GetPrev()->IsValid() )
+        if ( pTab->GetPrev() && !pTab->GetPrev()->isFrameAreaDefinitionValid() )
         {
             pTab->GetPrev()->SetCompletePaint();
         }
 
-        const SwRect aOldRect( pTab->Frame() );
+        const SwRect aOldRect( pTab->getFrameArea() );
         pTab->SetLowersFormatted( false );
         pTab->Calc(pRenderContext);
-        if ( aOldRect != pTab->Frame() )
+        if ( aOldRect != pTab->getFrameArea() )
         {
             bChanged = true;
         }
@@ -1484,13 +1471,13 @@ bool SwLayAction::FormatLayoutTab( SwTabFrame *pTab, bool bAddRect )
 
         if ( IsPaint() && bAddRect )
         {
-            // add condition <pTab->Frame().HasArea()>
+            // add condition <pTab->getFrameArea().HasArea()>
             if ( !pTab->IsCompletePaint() &&
                  pTab->IsComplete() &&
-                 ( pTab->Frame().SSize() != pTab->Prt().SSize() ||
+                 ( pTab->getFrameArea().SSize() != pTab->getFramePrintArea().SSize() ||
                    // vertical layout support
                    aRectFnSet.GetLeftMargin(*pTab) ) &&
-                 pTab->Frame().HasArea()
+                 pTab->getFrameArea().HasArea()
                )
             {
                 // re-implement calculation of margin rectangles.
@@ -1499,14 +1486,14 @@ bool SwLayAction::FormatLayoutTab( SwTabFrame *pTab, bool bAddRect )
                 SwTwips nLeftMargin = aRectFnSet.GetLeftMargin(*pTab);
                 if ( nLeftMargin > 0)
                 {
-                    aMarginRect = pTab->Frame();
+                    aMarginRect = pTab->getFrameArea();
                     aRectFnSet.SetWidth( aMarginRect, nLeftMargin );
                     m_pImp->GetShell()->AddPaintRect( aMarginRect );
                 }
 
                 if ( aRectFnSet.GetRightMargin(*pTab) > 0)
                 {
-                    aMarginRect = pTab->Frame();
+                    aMarginRect = pTab->getFrameArea();
                     aRectFnSet.SetLeft( aMarginRect, aRectFnSet.GetPrtRight(*pTab) );
                     m_pImp->GetShell()->AddPaintRect( aMarginRect );
                 }
@@ -1514,14 +1501,14 @@ bool SwLayAction::FormatLayoutTab( SwTabFrame *pTab, bool bAddRect )
                 SwTwips nTopMargin = aRectFnSet.GetTopMargin(*pTab);
                 if ( nTopMargin > 0)
                 {
-                    aMarginRect = pTab->Frame();
+                    aMarginRect = pTab->getFrameArea();
                     aRectFnSet.SetHeight( aMarginRect, nTopMargin );
                     m_pImp->GetShell()->AddPaintRect( aMarginRect );
                 }
 
                 if ( aRectFnSet.GetBottomMargin(*pTab) > 0)
                 {
-                    aMarginRect = pTab->Frame();
+                    aMarginRect = pTab->getFrameArea();
                     aRectFnSet.SetTop( aMarginRect, aRectFnSet.GetPrtBottom(*pTab) );
                     m_pImp->GetShell()->AddPaintRect( aMarginRect );
                 }
@@ -1566,7 +1553,7 @@ bool SwLayAction::FormatLayoutTab( SwTabFrame *pTab, bool bAddRect )
 
     // Ugly shortcut!
     if ( pTab->IsLowersFormatted() &&
-         (bPainted || !m_pImp->GetShell()->VisArea().IsOver( pTab->Frame())) )
+         (bPainted || !m_pImp->GetShell()->VisArea().IsOver( pTab->getFrameArea())) )
         return false;
 
     // Now, deal with the lowers
@@ -1579,7 +1566,7 @@ bool SwLayAction::FormatLayoutTab( SwTabFrame *pTab, bool bAddRect )
         SetNextCycle( true );
 
     // format lowers, only if table frame is valid
-    if ( pTab->IsValid() )
+    if ( pTab->isFrameAreaDefinitionValid() )
     {
         SwLayoutFrame *pLow = static_cast<SwLayoutFrame*>(pTab->Lower());
         while ( pLow )
@@ -1603,7 +1590,7 @@ bool SwLayAction::FormatContent( const SwPageFrame *pPage )
     while ( pContent && pPage->IsAnLower( pContent ) )
     {
         // If the content didn't change, we can use a few shortcuts.
-        const bool bFull = !pContent->IsValid() || pContent->IsCompletePaint() ||
+        const bool bFull = !pContent->isFrameAreaDefinitionValid() || pContent->IsCompletePaint() ||
                            pContent->IsRetouche() || pContent->GetDrawObjs();
         if ( bFull )
         {
@@ -1614,7 +1601,7 @@ bool SwLayAction::FormatContent( const SwPageFrame *pPage )
 
             const SwLayoutFrame*pOldUpper  = pContent->GetUpper();
             const SwTabFrame *pTab = pContent->FindTabFrame();
-            const bool bInValid = !pContent->IsValid() || pContent->IsCompletePaint();
+            const bool bInValid = !pContent->isFrameAreaDefinitionValid() || pContent->IsCompletePaint();
             const bool bOldPaint = IsPaint();
             m_bPaint = bOldPaint && !(pTab && pTab == m_pOptTab);
             FormatContent_( pContent, pPage );
@@ -1630,7 +1617,7 @@ bool SwLayAction::FormatContent( const SwPageFrame *pPage )
             if ( !IsAgain() &&
                  ( !IsInterrupt() || mbFormatContentOnInterrupt ) &&
                  pContent->IsTextFrame() &&
-                 !SwObjectFormatter::FormatObjsAtFrame( *(const_cast<SwContentFrame*>(pContent)),
+                 !SwObjectFormatter::FormatObjsAtFrame( *const_cast<SwContentFrame*>(pContent),
                                                       *(pContent->FindPageFrame()), this ) )
             {
                 return false;
@@ -1642,7 +1629,7 @@ bool SwLayAction::FormatContent( const SwPageFrame *pPage )
                 const_cast<SwTextFrame*>(static_cast<const SwTextFrame*>(pContent))->RecalcAllLines();
                 if ( IsPaintExtraData() && IsPaint() &&
                      nAllLines != static_cast<const SwTextFrame*>(pContent)->GetAllLines() )
-                    m_pImp->GetShell()->AddPaintRect( pContent->Frame() );
+                    m_pImp->GetShell()->AddPaintRect( pContent->getFrameArea() );
             }
 
             if ( IsAgain() )
@@ -1660,7 +1647,7 @@ bool SwLayAction::FormatContent( const SwPageFrame *pPage )
                 if ( ( IsInterrupt() && !mbFormatContentOnInterrupt ) ||
                      ( !bBrowse && pPage->IsInvalidLayout() ) ||
                      // consider interrupt formatting
-                     ( IS_FLYS && IS_INVAFLY && !mbFormatContentOnInterrupt )
+                     ( pPage->GetSortedObjs() && pPage->IsInvalidFly() && !mbFormatContentOnInterrupt )
                    )
                     return false;
             }
@@ -1689,8 +1676,11 @@ bool SwLayAction::FormatContent( const SwPageFrame *pPage )
             bool bSetContent = true;
             if ( pContentPrev )
             {
-                if ( !pContentPrev->IsValid() && pPage->IsAnLower( pContentPrev ) )
+                if ( !pContentPrev->isFrameAreaDefinitionValid() && pPage->IsAnLower( pContentPrev ) )
+                {
                     pPage->InvalidateContent();
+                }
+
                 if ( pOldUpper != pContent->GetUpper() &&
                      pPage->GetPhyPageNum() < pContent->FindPageFrame()->GetPhyPageNum() )
                 {
@@ -1701,14 +1691,14 @@ bool SwLayAction::FormatContent( const SwPageFrame *pPage )
             if ( bSetContent )
             {
                 if ( bBrowse && !IsIdle() && !IsCalcLayout() && !IsComplete() &&
-                     pContent->Frame().Top() > m_pImp->GetShell()->VisArea().Bottom())
+                     pContent->getFrameArea().Top() > m_pImp->GetShell()->VisArea().Bottom())
                 {
                     const long nBottom = m_pImp->GetShell()->VisArea().Bottom();
                     const SwFrame *pTmp = lcl_FindFirstInvaContent( pPage,
                                                             nBottom, pContent );
                     if ( !pTmp )
                     {
-                        if ( (!(IS_FLYS && IS_INVAFLY) ||
+                        if ( (!(pPage->GetSortedObjs() && pPage->IsInvalidFly()) ||
                               !lcl_FindFirstInvaObj( pPage, nBottom )) &&
                               (!pPage->IsInvalidLayout() ||
                                !lcl_FindFirstInvaLay( pPage, nBottom )))
@@ -1723,7 +1713,10 @@ bool SwLayAction::FormatContent( const SwPageFrame *pPage )
                 pContent = bNxtCnt ? pContentNext : pContent->GetNextContentFrame();
             }
 
-            RESCHEDULE;
+            if (IsReschedule())
+            {
+                ::RescheduleProgress(m_pImp->GetShell()->GetDoc()->GetDocShell());
+            }
         }
         else
         {
@@ -1733,13 +1726,13 @@ bool SwLayAction::FormatContent( const SwPageFrame *pPage )
                 const_cast<SwTextFrame*>(static_cast<const SwTextFrame*>(pContent))->RecalcAllLines();
                 if ( IsPaintExtraData() && IsPaint() &&
                      nAllLines != static_cast<const SwTextFrame*>(pContent)->GetAllLines() )
-                    m_pImp->GetShell()->AddPaintRect( pContent->Frame() );
+                    m_pImp->GetShell()->AddPaintRect( pContent->getFrameArea() );
             }
 
             // Do this if the frame has been formatted before.
             if ( pContent->IsTextFrame() && static_cast<const SwTextFrame*>(pContent)->HasRepaint() &&
                   IsPaint() )
-                PaintContent( pContent, pPage, pContent->Frame(), pContent->Frame().Bottom());
+                PaintContent( pContent, pPage, pContent->getFrameArea(), pContent->getFrameArea().Bottom());
             if ( IsIdle() )
             {
                 CheckIdleEnd();
@@ -1748,14 +1741,14 @@ bool SwLayAction::FormatContent( const SwPageFrame *pPage )
                     return false;
             }
             if ( bBrowse && !IsIdle() && !IsCalcLayout() && !IsComplete() &&
-                 pContent->Frame().Top() > m_pImp->GetShell()->VisArea().Bottom())
+                 pContent->getFrameArea().Top() > m_pImp->GetShell()->VisArea().Bottom())
             {
                 const long nBottom = m_pImp->GetShell()->VisArea().Bottom();
                 const SwFrame *pTmp = lcl_FindFirstInvaContent( pPage,
                                                     nBottom, pContent );
                 if ( !pTmp )
                 {
-                    if ( (!(IS_FLYS && IS_INVAFLY) ||
+                    if ( (!(pPage->GetSortedObjs() && pPage->IsInvalidFly()) ||
                             !lcl_FindFirstInvaObj( pPage, nBottom )) &&
                             (!pPage->IsInvalidLayout() ||
                             !lcl_FindFirstInvaLay( pPage, nBottom )))
@@ -1775,12 +1768,10 @@ bool SwLayAction::FormatContent( const SwPageFrame *pPage )
     return !IsInterrupt() || mbFormatContentOnInterrupt;
 }
 
-void SwLayAction::FormatContent_( const SwContentFrame *pContent,
-                                const SwPageFrame  *pPage )
+void SwLayAction::FormatContent_( const SwContentFrame *pContent, const SwPageFrame  *pPage )
 {
     // We probably only ended up here because the Content holds DrawObjects.
-    const bool bDrawObjsOnly = pContent->IsValid() && !pContent->IsCompletePaint() &&
-                         !pContent->IsRetouche();
+    const bool bDrawObjsOnly = pContent->isFrameAreaDefinitionValid() && !pContent->IsCompletePaint() && !pContent->IsRetouche();
     SwRectFnSet aRectFnSet(pContent);
     if ( !bDrawObjsOnly && IsPaint() )
     {
@@ -1789,7 +1780,7 @@ void SwLayAction::FormatContent_( const SwContentFrame *pContent,
         pContent->OptCalc();
         if( IsAgain() )
             return;
-        if( aRectFnSet.YDiff( aRectFnSet.GetBottom(pContent->Frame()),
+        if( aRectFnSet.YDiff( aRectFnSet.GetBottom(pContent->getFrameArea()),
                                 aRectFnSet.GetBottom(aOldRect) ) < 0 )
         {
             pContent->SetRetouche();
@@ -1799,8 +1790,8 @@ void SwLayAction::FormatContent_( const SwContentFrame *pContent,
     else
     {
         if ( IsPaint() && pContent->IsTextFrame() && static_cast<const SwTextFrame*>(pContent)->HasRepaint() )
-            PaintContent( pContent, pPage, pContent->Frame(),
-                        aRectFnSet.GetBottom(pContent->Frame()) );
+            PaintContent( pContent, pPage, pContent->getFrameArea(),
+                        aRectFnSet.GetBottom(pContent->getFrameArea()) );
         pContent->OptCalc();
     }
 }
@@ -1819,7 +1810,7 @@ bool SwLayAction::FormatFlyContent( const SwFlyFrame *pFly )
         // pass correct page frame to the object formatter.
         if ( pContent->IsTextFrame() &&
              !SwObjectFormatter::FormatObjsAtFrame(
-                                            *(const_cast<SwContentFrame*>(pContent)),
+                                            *const_cast<SwContentFrame*>(pContent),
                                             *(pContent->FindPageFrame()), this ) )
         {
             // restart format with first content
@@ -1833,7 +1824,7 @@ bool SwLayAction::FormatFlyContent( const SwFlyFrame *pFly )
             const_cast<SwTextFrame*>(static_cast<const SwTextFrame*>(pContent))->RecalcAllLines();
             if ( IsPaintExtraData() && IsPaint() &&
                  nAllLines != static_cast<const SwTextFrame*>(pContent)->GetAllLines() )
-                m_pImp->GetShell()->AddPaintRect( pContent->Frame() );
+                m_pImp->GetShell()->AddPaintRect( pContent->getFrameArea() );
         }
 
         if ( IsAgain() )
@@ -1931,7 +1922,7 @@ bool SwLayIdle::DoIdleJob_( const SwContentFrame *pCnt, IdleJobType eJob )
                         pImp->GetShell()->InvalidateWindows( aRepaint );
                 } catch( const css::uno::RuntimeException& e) {
                     // handle smarttag problems gracefully and provide diagnostics
-                    SAL_WARN( "sw.core", "SMART_TAGS Exception:" << e.Message);
+                    SAL_WARN( "sw.core", "SMART_TAGS: " << e);
                 }
                 if (Application::AnyInput(VCL_INPUT_ANY & VclInputFlags(~VclInputFlags::TIMER)))
                     return true;
@@ -2025,9 +2016,8 @@ bool SwLayIdle::DoIdleJob( IdleJobType eJob, bool bVisAreaOnly )
                                 i < pPage->GetSortedObjs()->size(); ++i )
             {
                 const SwAnchoredObject* pObj = (*pPage->GetSortedObjs())[i];
-                if ( dynamic_cast< const SwFlyFrame *>( pObj ) !=  nullptr )
+                if ( auto pFly = dynamic_cast< const SwFlyFrame *>( pObj ) )
                 {
-                    const SwFlyFrame *pFly = static_cast<const SwFlyFrame*>(pObj);
                     const SwContentFrame *pC = pFly->ContainsContent();
                     while( pC )
                     {
@@ -2055,7 +2045,7 @@ bool SwLayIdle::DoIdleJob( IdleJobType eJob, bool bVisAreaOnly )
 
         pPage = static_cast<SwPageFrame*>(pPage->GetNext());
         if ( pPage && bVisAreaOnly &&
-             !pPage->Frame().IsOver( pImp->GetShell()->VisArea()))
+             !pPage->getFrameArea().IsOver( pImp->GetShell()->VisArea()))
              break;
     }
     return false;
