@@ -17,7 +17,7 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include <objectformattertxtfrm.hxx>
+#include "objectformattertxtfrm.hxx"
 #include <sortedobjs.hxx>
 #include <rootfrm.hxx>
 #include <flyfrms.hxx>
@@ -29,6 +29,7 @@
 #include <fmtwrapinfluenceonobjpos.hxx>
 #include <fmtfollowtextflow.hxx>
 #include <layact.hxx>
+#include <ftnfrm.hxx>
 
 using namespace ::com::sun::star;
 
@@ -110,14 +111,6 @@ SwFrame& SwObjectFormatterTextFrame::GetAnchorFrame()
 bool SwObjectFormatterTextFrame::DoFormatObj( SwAnchoredObject& _rAnchoredObj,
                                            const bool _bCheckForMovedFwd )
 {
-    // check, if only as-character anchored object have to be formatted, and
-    // check the anchor type
-    if ( FormatOnlyAsCharAnchored() &&
-         !(_rAnchoredObj.GetFrameFormat().GetAnchor().GetAnchorId() == FLY_AS_CHAR) )
-    {
-        return true;
-    }
-
     // consider, if the layout action has to be
     // restarted due to a delete of a page frame.
     if ( GetLayAction() && GetLayAction()->IsAgain() )
@@ -160,11 +153,11 @@ bool SwObjectFormatterTextFrame::DoFormatObj( SwAnchoredObject& _rAnchoredObj,
         // format anchor text frame, if wrapping style influence of the object
         // has to be considered and it's <NONE_SUCCESSIVE_POSITIONED>
         // #i3317# - consider also anchored objects, whose
-        // wrapping style influence is temporarly considered.
+        // wrapping style influence is temporarily considered.
         // #i40147# - consider also anchored objects, for
         // whose the check of a moved forward anchor frame is requested.
         // revise decision made for i3317:
-        // anchored objects, whose wrapping style influence is temporarly considered,
+        // anchored objects, whose wrapping style influence is temporarily considered,
         // have to be considered in method <SwObjectFormatterTextFrame::DoFormatObjs()>
         if ( bSuccess &&
              _rAnchoredObj.ConsiderObjWrapInfluenceOnObjPos() &&
@@ -194,7 +187,7 @@ bool SwObjectFormatterTextFrame::DoFormatObj( SwAnchoredObject& _rAnchoredObj,
                 if ( pAnchorPageFrame != _rAnchoredObj.GetPageFrame() )
                 {
                     bool bInsert( true );
-                    sal_uInt32 nToPageNum( 0L );
+                    sal_uInt32 nToPageNum( 0 );
                     const SwDoc& rDoc = *(GetPageFrame().GetFormat()->GetDoc());
                     if ( SwLayouter::FrameMovedFwdByObjPos(
                                             rDoc, mrAnchorTextFrame, nToPageNum ) )
@@ -228,7 +221,7 @@ bool SwObjectFormatterTextFrame::DoFormatObj( SwAnchoredObject& _rAnchoredObj,
                         "<SwObjectFormatterTextFrame::DoFormatObj(..)> - anchored object not collected!?" );
                 --nIdx;
 
-                sal_uInt32 nToPageNum( 0L );
+                sal_uInt32 nToPageNum( 0 );
                 // #i43913#
                 bool bDummy( false );
                 // #i58182# - consider new method signature
@@ -240,7 +233,7 @@ bool SwObjectFormatterTextFrame::DoFormatObj( SwAnchoredObject& _rAnchoredObj,
                     // #i49987# - consider, that anchor frame
                     // could already been marked to move forward.
                     bool bInsert( true );
-                    sal_uInt32 nMovedFwdToPageNum( 0L );
+                    sal_uInt32 nMovedFwdToPageNum( 0 );
                     const SwDoc& rDoc = *(GetPageFrame().GetFormat()->GetDoc());
                     if ( SwLayouter::FrameMovedFwdByObjPos(
                                             rDoc, mrAnchorTextFrame, nMovedFwdToPageNum ) )
@@ -293,7 +286,7 @@ bool SwObjectFormatterTextFrame::DoFormatObj( SwAnchoredObject& _rAnchoredObj,
 
 bool SwObjectFormatterTextFrame::DoFormatObjs()
 {
-    if ( !mrAnchorTextFrame.IsValid() )
+    if ( !mrAnchorTextFrame.isFrameAreaDefinitionValid() )
     {
         if ( GetLayAction() &&
              mrAnchorTextFrame.FindPageFrame() != &GetPageFrame() )
@@ -336,7 +329,7 @@ bool SwObjectFormatterTextFrame::DoFormatObjs()
         bSuccess = FormatObjsAtFrame_();
     }
 
-    // consider anchored objects, whose wrapping style influence are temporarly
+    // consider anchored objects, whose wrapping style influence are temporarily
     // considered.
     if ( bSuccess &&
          ( ConsiderWrapOnObjPos() ||
@@ -354,7 +347,7 @@ bool SwObjectFormatterTextFrame::DoFormatObjs()
         // section the anchor frame is in.
         FormatAnchorFrameForCheckMoveFwd();
 
-        sal_uInt32 nToPageNum( 0L );
+        sal_uInt32 nToPageNum( 0 );
         // #i43913#
         bool bInFollow( false );
         SwAnchoredObject* pObj = nullptr;
@@ -378,7 +371,7 @@ bool SwObjectFormatterTextFrame::DoFormatObjs()
                  bInFollow )
             {
                 bool bInsert( true );
-                sal_uInt32 nTmpToPageNum( 0L );
+                sal_uInt32 nTmpToPageNum( 0 );
                 const SwDoc& rDoc = *(GetPageFrame().GetFormat()->GetDoc());
                 if ( SwLayouter::FrameMovedFwdByObjPos(
                                         rDoc, mrAnchorTextFrame, nTmpToPageNum ) )
@@ -410,7 +403,7 @@ bool SwObjectFormatterTextFrame::DoFormatObjs()
             // #i49987# - consider, that anchor frame
             // could already been marked to move forward.
             bool bInsert( true );
-            sal_uInt32 nMovedFwdToPageNum( 0L );
+            sal_uInt32 nMovedFwdToPageNum( 0 );
             const SwDoc& rDoc = *(GetPageFrame().GetFormat()->GetDoc());
             if ( SwLayouter::FrameMovedFwdByObjPos(
                                     rDoc, mrAnchorTextFrame, nMovedFwdToPageNum ) )
@@ -519,7 +512,7 @@ SwAnchoredObject* SwObjectFormatterTextFrame::GetFirstObjWithMovedFwdAnchor(
 
     SwAnchoredObject* pRetAnchoredObj = nullptr;
 
-    sal_uInt32 i = 0L;
+    sal_uInt32 i = 0;
     for ( ; i < CountOfCollected(); ++i )
     {
         SwAnchoredObject* pAnchoredObj = GetCollectedObj(i);
@@ -588,8 +581,8 @@ bool SwObjectFormatterTextFrame::CheckMovedFwdCondition(
     // which will be on the next page.
     if ( !bAnchorIsMovedForward &&
          _bAnchoredAtMasterBeforeFormatAnchor &&
-        ((_rAnchoredObj.GetFrameFormat().GetAnchor().GetAnchorId() == FLY_AT_CHAR) ||
-         (_rAnchoredObj.GetFrameFormat().GetAnchor().GetAnchorId() == FLY_AT_PARA)))
+        ((_rAnchoredObj.GetFrameFormat().GetAnchor().GetAnchorId() == RndStdIds::FLY_AT_CHAR) ||
+         (_rAnchoredObj.GetFrameFormat().GetAnchor().GetAnchorId() == RndStdIds::FLY_AT_PARA)))
     {
         SwFrame* pAnchorFrame = _rAnchoredObj.GetAnchorFrameContainingAnchPos();
         OSL_ENSURE( pAnchorFrame->IsTextFrame(),
@@ -646,12 +639,36 @@ static void lcl_FormatContentOfLayoutFrame( SwLayoutFrame* pLayFrame,
             break;
         }
         if ( pLowerFrame->IsLayoutFrame() )
+        {
+            SwFrameDeleteGuard aCrudeHack(pLowerFrame); // ??? any issue setting this for non-footnote frames?
             lcl_FormatContentOfLayoutFrame( static_cast<SwLayoutFrame*>(pLowerFrame),
                                         pLastLowerFrame );
+        }
         else
             pLowerFrame->Calc(pLowerFrame->getRootFrame()->GetCurrShell()->GetOut());
 
-        pLowerFrame = pLowerFrame->GetNext();
+        // Calc on a SwTextFrame in a footnote can move it to the next page -
+        // deletion of the SwFootnoteFrame was disabled with SwFrameDeleteGuard
+        // but now we have to clean up empty footnote frames to prevent crashes.
+        // Note: check it at this level, not lower: both container and footnote
+        // can be deleted at the same time!
+        SwFrame *const pNext = pLowerFrame->GetNext();
+        if (pLowerFrame->IsFootnoteContFrame())
+        {
+            for (SwFrame * pFootnote = pLowerFrame->GetLower(); pFootnote; )
+            {
+                assert(pFootnote->IsFootnoteFrame());
+                SwFrame *const pNextNote = pFootnote->GetNext();
+                if (!pFootnote->GetLower() && !pFootnote->IsColLocked() &&
+                    !static_cast<SwFootnoteFrame*>(pFootnote)->IsBackMoveLocked())
+                {
+                    pFootnote->Cut();
+                    SwFrame::DestroyFrame(pFootnote);
+                }
+                pFootnote = pNextNote;
+            }
+        }
+        pLowerFrame = pNext;
     }
 }
 
@@ -760,7 +777,7 @@ void SwObjectFormatterTextFrame::FormatAnchorFrameForCheckMoveFwd()
 }
 
 /** method to determine if at least one anchored object has state
-    <temporarly consider wrapping style influence> set.
+    <temporarily consider wrapping style influence> set.
 */
 bool SwObjectFormatterTextFrame::AtLeastOneObjIsTmpConsiderWrapInfluence()
 {
