@@ -17,19 +17,18 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include <com/sun/star/i18n/ScriptType.hpp>
 #include <vcl/outdev.hxx>
 #include <IDocumentSettingAccess.hxx>
 
-#include "frame.hxx"
-#include "paratr.hxx"
+#include <frame.hxx>
+#include <paratr.hxx>
 #include "itrtxt.hxx"
 #include "porglue.hxx"
 #include "porlay.hxx"
 #include "porfly.hxx"
 #include "pordrop.hxx"
 #include "pormulti.hxx"
-#include <portab.hxx>
+#include "portab.hxx"
 #include <memory>
 
 #define MIN_TAB_WIDTH 60
@@ -113,6 +112,9 @@ void SwTextAdjuster::FormatBlock( )
 static bool lcl_CheckKashidaPositions( SwScriptInfo& rSI, SwTextSizeInfo& rInf, SwTextIter& rItr,
                                 sal_Int32& rKashidas, sal_Int32& nGluePortion )
 {
+    if ( rInf.GetOut()->GetMinKashida() <= 0 )
+        return false;
+
     // i60594 validate Kashida justification
     sal_Int32 nIdx = rItr.GetStart();
     sal_Int32 nEnd = rItr.GetEnd();
@@ -149,12 +151,6 @@ static bool lcl_CheckKashidaPositions( SwScriptInfo& rSI, SwTextSizeInfo& rInf,
         sal_Int32 nKashidasInAttr = rSI.KashidaJustify ( nullptr, nullptr, nIdx, nNext - nIdx );
         if (nKashidasInAttr > 0)
         {
-            // Kashida glyph looks suspicious, skip Kashida justification
-            if ( rInf.GetOut()->GetMinKashida() <= 0 )
-            {
-                return false;
-            }
-
             sal_Int32 nKashidasDropped = 0;
             if ( !SwScriptInfo::IsArabicText( rInf.GetText(), nIdx, nNext - nIdx ) )
             {
@@ -163,8 +159,8 @@ static bool lcl_CheckKashidaPositions( SwScriptInfo& rSI, SwTextSizeInfo& rInf,
             }
             else
             {
-                ComplexTextLayoutMode nOldLayout = rInf.GetOut()->GetLayoutMode();
-                rInf.GetOut()->SetLayoutMode ( nOldLayout | TEXT_LAYOUT_BIDI_RTL );
+                ComplexTextLayoutFlags nOldLayout = rInf.GetOut()->GetLayoutMode();
+                rInf.GetOut()->SetLayoutMode ( nOldLayout | ComplexTextLayoutFlags::BiDiRtl );
                 nKashidasDropped = rInf.GetOut()->ValidateKashidas ( rInf.GetText(), nIdx, nNext - nIdx,
                                                nKashidasInAttr, pKashidaPos.get() + nKashidaIdx,
                                                pKashidaPosDropped.get() );
@@ -212,7 +208,7 @@ static bool lcl_CheckKashidaWidth ( SwScriptInfo& rSI, SwTextSizeInfo& rInf, SwT
             sal_Int32 nKashidasInAttr = rSI.KashidaJustify ( nullptr, nullptr, nIdx, nNext - nIdx );
 
             long nFontMinKashida = rInf.GetOut()->GetMinKashida();
-            if ( nFontMinKashida && nKashidasInAttr > 0 && SwScriptInfo::IsArabicText( rInf.GetText(), nIdx, nNext - nIdx ) )
+            if ( nKashidasInAttr > 0 && SwScriptInfo::IsArabicText( rInf.GetText(), nIdx, nNext - nIdx ) )
             {
                 sal_Int32 nKashidasDropped = 0;
                 while ( rKashidas && nGluePortion && nKashidasInAttr > 0 &&
@@ -247,7 +243,7 @@ static bool lcl_CheckKashidaWidth ( SwScriptInfo& rSI, SwTextSizeInfo& rInf, SwT
 void SwTextAdjuster::CalcNewBlock( SwLineLayout *pCurrent,
                                   const SwLinePortion *pStopAt, SwTwips nReal, bool bSkipKashida )
 {
-    OSL_ENSURE( GetInfo().IsMulti() || SVX_ADJUST_BLOCK == GetAdjust(),
+    OSL_ENSURE( GetInfo().IsMulti() || SvxAdjust::Block == GetAdjust(),
             "CalcNewBlock: Why?" );
     OSL_ENSURE( pCurrent->Height(), "SwTextAdjuster::CalcBlockAdjust: missing CalcLine()" );
 
@@ -396,7 +392,7 @@ SwTwips SwTextAdjuster::CalcKanaAdj( SwLineLayout* pCurrent )
     OSL_ENSURE( pCurrent->Height(), "SwTextAdjuster::CalcBlockAdjust: missing CalcLine()" );
     OSL_ENSURE( !pCurrent->GetpKanaComp(), "pKanaComp already exists!!" );
 
-    std::deque<sal_uInt16> *pNewKana = new std::deque<sal_uInt16>();
+    std::deque<sal_uInt16> *pNewKana = new std::deque<sal_uInt16>;
     pCurrent->SetKanaComp( pNewKana );
 
     const sal_uInt16 nNull = 0;
@@ -549,8 +545,8 @@ SwMarginPortion *SwTextAdjuster::CalcRightMargin( SwLineLayout *pCurrent,
         {
             pLast->Append( pFly );
             pLast = pFly;
-            if( pFly->Fix() > nPrtWidth )
-                pFly->Width( ( pFly->Fix() - nPrtWidth) + pFly->Width() + 1);
+            if( pFly->GetFix() > nPrtWidth )
+                pFly->Width( ( pFly->GetFix() - nPrtWidth) + pFly->Width() + 1);
             nPrtWidth += pFly->Width() + 1;
             aCurrRect.Left( nLeftMar + nPrtWidth );
             pFly = CalcFlyPortion( nRealWidth, aCurrRect );
@@ -558,7 +554,7 @@ SwMarginPortion *SwTextAdjuster::CalcRightMargin( SwLineLayout *pCurrent,
         delete pFly;
     }
 
-    SwMarginPortion *pRight = new SwMarginPortion( 0 );
+    SwMarginPortion *pRight = new SwMarginPortion;
     pLast->Append( pRight );
 
     if( long( nPrtWidth )< nRealWidth )
@@ -603,7 +599,7 @@ void SwTextAdjuster::CalcFlyAdjust( SwLineLayout *pCurrent )
             // in tab compat mode we do not want to change tab portions
             // in non tab compat mode we do not want to change margins if we
             // found a multi portion with tabs
-            if( SVX_ADJUST_RIGHT == GetAdjust() )
+            if( SvxAdjust::Right == GetAdjust() )
                 static_cast<SwGluePortion*>(pPos)->MoveAllGlue( pGlue );
             else
             {
@@ -645,7 +641,7 @@ void SwTextAdjuster::CalcFlyAdjust( SwLineLayout *pCurrent )
         pPos = pPos->GetPortion();
      }
 
-     if( ! bTabCompat && ! bMultiTab && SVX_ADJUST_RIGHT == GetAdjust() )
+     if( ! bTabCompat && ! bMultiTab && SvxAdjust::Right == GetAdjust() )
         // portions are moved to the right if possible
         pLeft->AdjustRight( pCurrent );
 }
@@ -660,14 +656,14 @@ void SwTextAdjuster::CalcAdjLine( SwLineLayout *pCurrent )
 
     switch( GetAdjust() )
     {
-        case SVX_ADJUST_RIGHT:
-        case SVX_ADJUST_CENTER:
+        case SvxAdjust::Right:
+        case SvxAdjust::Center:
         {
             CalcFlyAdjust( pCurrent );
             pPara->GetRepaint().SetOfst( 0 );
             break;
         }
-        case SVX_ADJUST_BLOCK:
+        case SvxAdjust::Block:
         {
             FormatBlock();
             break;
@@ -727,7 +723,7 @@ SwFlyPortion *SwTextAdjuster::CalcFlyPortion( const long nRealWidth,
 // CalcDropAdjust is called at the end by Format() if needed
 void SwTextAdjuster::CalcDropAdjust()
 {
-    OSL_ENSURE( 1<GetDropLines() && SVX_ADJUST_LEFT!=GetAdjust() && SVX_ADJUST_BLOCK!=GetAdjust(),
+    OSL_ENSURE( 1<GetDropLines() && SvxAdjust::Left!=GetAdjust() && SvxAdjust::Block!=GetAdjust(),
             "CalcDropAdjust: No reason for DropAdjustment." );
 
     const sal_uInt16 nLineNumber = GetLineNr();
