@@ -20,25 +20,25 @@
 #include <hintids.hxx>
 
 #include <com/sun/star/i18n/ScriptType.hpp>
-#include <vcl/graphic.hxx>
+#include <vcl/graph.hxx>
 #include <editeng/brushitem.hxx>
 #include <vcl/metric.hxx>
 #include <vcl/outdev.hxx>
 #include <viewopt.hxx>
 #include <SwPortionHandler.hxx>
-#include <porlay.hxx>
-#include <porfld.hxx>
-#include <inftxt.hxx>
+#include "porlay.hxx"
+#include "porfld.hxx"
+#include "inftxt.hxx"
 #include <blink.hxx>
 #include <frmtool.hxx>
 #include <viewsh.hxx>
 #include <docsh.hxx>
 #include <doc.hxx>
 #include <IDocumentSettingAccess.hxx>
-#include "rootfrm.hxx"
+#include <rootfrm.hxx>
 #include <breakit.hxx>
-#include <porrst.hxx>
-#include <porftn.hxx>
+#include "porrst.hxx"
+#include "porftn.hxx"
 #include <accessibilityoptions.hxx>
 #include <editeng/lrspitem.hxx>
 #include <unicode/ubidi.h>
@@ -46,37 +46,37 @@
 using namespace ::com::sun::star;
 
 SwLinePortion *SwFieldPortion::Compress()
-{ return (GetLen() || !aExpand.isEmpty() || SwLinePortion::Compress()) ? this : nullptr; }
+{ return (GetLen() || !m_aExpand.isEmpty() || SwLinePortion::Compress()) ? this : nullptr; }
 
 SwFieldPortion *SwFieldPortion::Clone( const OUString &rExpand ) const
 {
     SwFont *pNewFnt;
-    if( nullptr != ( pNewFnt = pFnt ) )
+    if( nullptr != ( pNewFnt = m_pFont ) )
     {
-        pNewFnt = new SwFont( *pFnt );
+        pNewFnt = new SwFont( *m_pFont );
     }
     // #i107143#
     // pass placeholder property to created <SwFieldPortion> instance.
-    SwFieldPortion* pClone = new SwFieldPortion( rExpand, pNewFnt, bPlaceHolder );
-    pClone->SetNextOffset( nNextOffset );
-    pClone->m_bNoLength = this->m_bNoLength;
+    SwFieldPortion* pClone = new SwFieldPortion( rExpand, pNewFnt, m_bPlaceHolder );
+    pClone->SetNextOffset( m_nNextOffset );
+    pClone->m_bNoLength = m_bNoLength;
     return pClone;
 }
 
 void SwFieldPortion::TakeNextOffset( const SwFieldPortion* pField )
 {
     OSL_ENSURE( pField, "TakeNextOffset: Missing Source" );
-    nNextOffset = pField->GetNextOffset();
-    aExpand = aExpand.replaceAt( 0, nNextOffset, "" );
-    bFollow = true;
+    m_nNextOffset = pField->GetNextOffset();
+    m_aExpand = m_aExpand.replaceAt( 0, m_nNextOffset, "" );
+    m_bFollow = true;
 }
 
 SwFieldPortion::SwFieldPortion( const OUString &rExpand, SwFont *pFont, bool bPlaceHold )
-    : aExpand(rExpand), pFnt(pFont), nNextOffset(0), nNextScriptChg(COMPLETE_STRING), nViewWidth(0)
-    , bFollow( false ), bLeft( false), bHide( false)
-    , bCenter (false), bHasFollow( false )
-    , bAnimated( false), bNoPaint( false)
-    , bReplace( false), bPlaceHolder( bPlaceHold )
+    : m_aExpand(rExpand), m_pFont(pFont), m_nNextOffset(0), m_nNextScriptChg(COMPLETE_STRING), m_nViewWidth(0)
+    , m_bFollow( false ), m_bLeft( false), m_bHide( false)
+    , m_bCenter (false), m_bHasFollow( false )
+    , m_bAnimated( false), m_bNoPaint( false)
+    , m_bReplace( false), m_bPlaceHolder( bPlaceHold )
     , m_bNoLength( false )
     , m_nAttrFieldType(0)
 {
@@ -85,33 +85,33 @@ SwFieldPortion::SwFieldPortion( const OUString &rExpand, SwFont *pFont, bool bPl
 
 SwFieldPortion::SwFieldPortion( const SwFieldPortion& rField )
     : SwExpandPortion( rField )
-    , aExpand( rField.GetExp() )
-    , nNextOffset( rField.GetNextOffset() )
-    , nNextScriptChg( rField.GetNextScriptChg() )
-    , nViewWidth( rField.nViewWidth )
-    , bFollow( rField.IsFollow() )
-    , bLeft( rField.IsLeft() )
-    , bHide( rField.IsHide() )
-    , bCenter( rField.IsCenter() )
-    , bHasFollow( rField.HasFollow() )
-    , bAnimated ( rField.bAnimated )
-    , bNoPaint( rField.bNoPaint)
-    , bReplace( rField.bReplace )
-    , bPlaceHolder( rField.bPlaceHolder )
+    , m_aExpand( rField.GetExp() )
+    , m_nNextOffset( rField.GetNextOffset() )
+    , m_nNextScriptChg( rField.m_nNextScriptChg )
+    , m_nViewWidth( rField.m_nViewWidth )
+    , m_bFollow( rField.IsFollow() )
+    , m_bLeft( rField.IsLeft() )
+    , m_bHide( rField.IsHide() )
+    , m_bCenter( rField.IsCenter() )
+    , m_bHasFollow( rField.HasFollow() )
+    , m_bAnimated ( rField.m_bAnimated )
+    , m_bNoPaint( rField.m_bNoPaint)
+    , m_bReplace( rField.m_bReplace )
+    , m_bPlaceHolder( rField.m_bPlaceHolder )
     , m_bNoLength( rField.m_bNoLength )
     , m_nAttrFieldType( rField.m_nAttrFieldType)
 {
     if ( rField.HasFont() )
-        pFnt = new SwFont( *rField.GetFont() );
+        m_pFont = new SwFont( *rField.GetFont() );
     else
-        pFnt = nullptr;
+        m_pFont = nullptr;
 
     SetWhichPor( POR_FLD );
 }
 
 SwFieldPortion::~SwFieldPortion()
 {
-    delete pFnt;
+    delete m_pFont;
     if( pBlink )
         pBlink->Delete( this );
 }
@@ -123,12 +123,12 @@ sal_uInt16 SwFieldPortion::GetViewWidth( const SwTextSizeInfo &rInf ) const
     if( !Width() && rInf.OnWin() && !rInf.GetOpt().IsPagePreview() &&
             !rInf.GetOpt().IsReadonly() && SwViewOption::IsFieldShadings() )
     {
-        if( !nViewWidth )
-            pThis->nViewWidth = rInf.GetTextSize(OUString(' ')).Width();
+        if( !m_nViewWidth )
+            pThis->m_nViewWidth = rInf.GetTextSize(OUString(' ')).Width();
     }
     else
-        pThis->nViewWidth = 0;
-    return nViewWidth;
+        pThis->m_nViewWidth = 0;
+    return m_nViewWidth;
 }
 
 /**
@@ -194,97 +194,97 @@ SwFieldSlot::~SwFieldSlot()
 void SwFieldPortion::CheckScript( const SwTextSizeInfo &rInf )
 {
     OUString aText;
-    if( GetExpText( rInf, aText ) && !aText.isEmpty() && g_pBreakIt->GetBreakIter().is() )
+    if (!GetExpText(rInf, aText) || aText.isEmpty())
+        return;
+
+    SwFontScript nActual = m_pFont ? m_pFont->GetActual() : rInf.GetFont()->GetActual();
+    sal_uInt16 nScript = g_pBreakIt->GetBreakIter()->getScriptType( aText, 0 );
+    sal_Int32 nChg = 0;
+    if( i18n::ScriptType::WEAK == nScript )
     {
-        sal_uInt8 nActual = pFnt ? pFnt->GetActual() : rInf.GetFont()->GetActual();
-        sal_uInt16 nScript = g_pBreakIt->GetBreakIter()->getScriptType( aText, 0 );
-        sal_Int32 nChg = 0;
-        if( i18n::ScriptType::WEAK == nScript )
-        {
-            nChg = g_pBreakIt->GetBreakIter()->endOfScript(aText,0,nScript);
-            if (nChg < aText.getLength() && nChg >= 0)
-                nScript = g_pBreakIt->GetBreakIter()->getScriptType( aText, nChg );
-        }
-
-        // nNextScriptChg will be evaluated during SwFieldPortion::Format()
-
+        nChg = g_pBreakIt->GetBreakIter()->endOfScript(aText,0,nScript);
         if (nChg < aText.getLength() && nChg >= 0)
-            nNextScriptChg = g_pBreakIt->GetBreakIter()->endOfScript( aText, nChg, nScript );
-        else
-            nNextScriptChg = aText.getLength();
+            nScript = g_pBreakIt->GetBreakIter()->getScriptType( aText, nChg );
+    }
 
-        sal_uInt8 nTmp;
-        switch ( nScript ) {
-            case i18n::ScriptType::LATIN : nTmp = SW_LATIN; break;
-            case i18n::ScriptType::ASIAN : nTmp = SW_CJK; break;
-            case i18n::ScriptType::COMPLEX : nTmp = SW_CTL; break;
-            default: nTmp = nActual;
-        }
+    // nNextScriptChg will be evaluated during SwFieldPortion::Format()
 
-        // #i16354# Change script type for RTL text to CTL.
-        const SwScriptInfo& rSI = rInf.GetParaPortion()->GetScriptInfo();
-        // #i98418#
-        const sal_uInt8 nFieldDir = ( IsNumberPortion() || IsFootnoteNumPortion() ) ?
-                             rSI.GetDefaultDir() :
-                             rSI.DirType( IsFollow() ? rInf.GetIdx() - 1 : rInf.GetIdx() );
+    if (nChg < aText.getLength() && nChg >= 0)
+        m_nNextScriptChg = g_pBreakIt->GetBreakIter()->endOfScript( aText, nChg, nScript );
+    else
+        m_nNextScriptChg = aText.getLength();
 
-        bool bPerformUBA = UBIDI_LTR != nFieldDir || i18n::ScriptType::COMPLEX == nScript;
-        if (bPerformUBA)
+    SwFontScript nTmp;
+    switch ( nScript ) {
+        case i18n::ScriptType::LATIN : nTmp = SwFontScript::Latin; break;
+        case i18n::ScriptType::ASIAN : nTmp = SwFontScript::CJK; break;
+        case i18n::ScriptType::COMPLEX : nTmp = SwFontScript::CTL; break;
+        default: nTmp = nActual;
+    }
+
+    // #i16354# Change script type for RTL text to CTL.
+    const SwScriptInfo& rSI = rInf.GetParaPortion()->GetScriptInfo();
+    // #i98418#
+    const sal_uInt8 nFieldDir = ( IsNumberPortion() || IsFootnoteNumPortion() ) ?
+                         rSI.GetDefaultDir() :
+                         rSI.DirType( IsFollow() ? rInf.GetIdx() - 1 : rInf.GetIdx() );
+
+    {
+        UErrorCode nError = U_ZERO_ERROR;
+        UBiDi* pBidi = ubidi_openSized( aText.getLength(), 0, &nError );
+        ubidi_setPara( pBidi, reinterpret_cast<const UChar *>(aText.getStr()), aText.getLength(), nFieldDir, nullptr, &nError );
+        int32_t nEnd;
+        UBiDiLevel nCurrDir;
+        ubidi_getLogicalRun( pBidi, 0, &nEnd, &nCurrDir );
+        ubidi_close( pBidi );
+        const sal_Int32 nNextDirChg = nEnd;
+        m_nNextScriptChg = std::min( m_nNextScriptChg, nNextDirChg );
+
+        // #i89825# change the script type also to CTL
+        // if there is no strong LTR char in the LTR run (numbers)
+        if (nCurrDir != UBIDI_RTL &&
+            (UBIDI_LTR != nFieldDir || i18n::ScriptType::COMPLEX == nScript))
         {
-            UErrorCode nError = U_ZERO_ERROR;
-            UBiDi* pBidi = ubidi_openSized( aText.getLength(), 0, &nError );
-            ubidi_setPara( pBidi, reinterpret_cast<const UChar *>(aText.getStr()), aText.getLength(), nFieldDir, nullptr, &nError );
-            int32_t nEnd;
-            UBiDiLevel nCurrDir;
-            ubidi_getLogicalRun( pBidi, 0, &nEnd, &nCurrDir );
-            ubidi_close( pBidi );
-            const sal_Int32 nNextDirChg = nEnd;
-            nNextScriptChg = std::min( nNextScriptChg, nNextDirChg );
-
-            // #i89825# change the script type also to CTL
-            // if there is no strong LTR char in the LTR run (numbers)
-            if ( nCurrDir != UBIDI_RTL )
+            nCurrDir = UBIDI_RTL;
+            for( sal_Int32 nCharIdx = 0; nCharIdx < nEnd; ++nCharIdx )
             {
-                nCurrDir = UBIDI_RTL;
-                for( sal_Int32 nCharIdx = 0; nCharIdx < nEnd; ++nCharIdx )
+                UCharDirection nCharDir = u_charDirection ( aText[ nCharIdx ]);
+                if ( nCharDir == U_LEFT_TO_RIGHT ||
+                     nCharDir == U_LEFT_TO_RIGHT_EMBEDDING ||
+                     nCharDir == U_LEFT_TO_RIGHT_OVERRIDE )
                 {
-                    UCharDirection nCharDir = u_charDirection ( aText[ nCharIdx ]);
-                    if ( nCharDir == U_LEFT_TO_RIGHT ||
-                         nCharDir == U_LEFT_TO_RIGHT_EMBEDDING ||
-                         nCharDir == U_LEFT_TO_RIGHT_OVERRIDE )
-                    {
-                        nCurrDir = UBIDI_LTR;
-                        break;
-                    }
+                    nCurrDir = UBIDI_LTR;
+                    break;
                 }
             }
-
-            if (nCurrDir == UBIDI_RTL)
-            {
-                nTmp = SW_CTL;
-                // If we decided that this range was RTL after all and the
-                // previous range was complex but clipped to the start of this
-                // range, then extend it to be complex over the additional RTL range
-                if (nScript == i18n::ScriptType::COMPLEX)
-                    nNextScriptChg = nNextDirChg;
-            }
         }
 
-        // #i98418#
-        // keep determined script type for footnote portions as preferred script type.
-        // For footnote portions a font can not be created directly - see footnote
-        // portion format method.
-        if ( IsFootnotePortion() )
+        if (nCurrDir == UBIDI_RTL)
         {
-            static_cast<SwFootnotePortion*>(this)->SetPreferredScriptType( nTmp );
-        }
-        else if ( nTmp != nActual )
-        {
-            if( !pFnt )
-                pFnt = new SwFont( *rInf.GetFont() );
-            pFnt->SetActual( nTmp );
+            nTmp = SwFontScript::CTL;
+            // If we decided that this range was RTL after all and the
+            // previous range was complex but clipped to the start of this
+            // range, then extend it to be complex over the additional RTL range
+            if (nScript == i18n::ScriptType::COMPLEX)
+                m_nNextScriptChg = nNextDirChg;
         }
     }
+
+    // #i98418#
+    // keep determined script type for footnote portions as preferred script type.
+    // For footnote portions a font can not be created directly - see footnote
+    // portion format method.
+    if ( IsFootnotePortion() )
+    {
+        static_cast<SwFootnotePortion*>(this)->SetPreferredScriptType( nTmp );
+    }
+    else if ( nTmp != nActual )
+    {
+        if( !m_pFont )
+            m_pFont = new SwFont( *rInf.GetFont() );
+        m_pFont->SetActual( nTmp );
+    }
+
 }
 
 bool SwFieldPortion::Format( SwTextFormatInfo &rInf )
@@ -304,9 +304,9 @@ bool SwFieldPortion::Format( SwTextFormatInfo &rInf )
         // 2. There are portion breaks (tab, break) inside the field:
         const sal_Int32 nOldFullLen = rInf.GetLen();
         sal_Int32 nFullLen = rInf.ScanPortionEnd( rInf.GetIdx(), rInf.GetIdx() + nOldFullLen ) - rInf.GetIdx();
-        if ( nNextScriptChg < nFullLen )
+        if ( m_nNextScriptChg < nFullLen )
         {
-            nFullLen = nNextScriptChg;
+            nFullLen = m_nNextScriptChg;
             rInf.SetHookChar( 0 );
         }
         rInf.SetLen( nFullLen );
@@ -315,10 +315,10 @@ bool SwFieldPortion::Format( SwTextFormatInfo &rInf )
              rInf.GetUnderScorePos() > rInf.GetIdx() )
              rInf.SetUnderScorePos( rInf.GetIdx() );
 
-        if( pFnt )
-            pFnt->GoMagic( rInf.GetVsh(), pFnt->GetActual() );
+        if( m_pFont )
+            m_pFont->GoMagic( rInf.GetVsh(), m_pFont->GetActual() );
 
-        SwFontSave aSave( rInf, pFnt );
+        SwFontSave aSave( rInf, m_pFont );
 
         // Length must be 0: the length is set for bFull after format
         // and passed along in nRest. Or else the old length would be
@@ -365,20 +365,21 @@ bool SwFieldPortion::Format( SwTextFormatInfo &rInf )
         {
             // aExpand has not yet been shortened; the new Ofst is a
             // result of nRest
-            sal_Int32 nNextOfst = aExpand.getLength() - nRest;
+            sal_Int32 nNextOfst = m_aExpand.getLength() - nRest;
 
             if ( IsQuoVadisPortion() )
                 nNextOfst = nNextOfst + static_cast<SwQuoVadisPortion*>(this)->GetContText().getLength();
 
-            OUString aNew( aExpand.copy( nNextOfst ) );
-            aExpand = aExpand.copy( 0, nNextOfst );
+            OUString aNew( m_aExpand.copy( nNextOfst ) );
+            m_aExpand = m_aExpand.copy( 0, nNextOfst );
 
             // These characters should not be contained in the follow
             // field portion. They are handled via the HookChar mechanism.
-            switch( aNew[0] )
+            const sal_Unicode nNew = !aNew.isEmpty() ? aNew[0] : 0;
+            switch (nNew)
             {
                 case CH_BREAK  : bFull = true;
-                            // no break
+                    SAL_FALLTHROUGH;
                 case ' ' :
                 case CH_TAB    :
                 case CHAR_HARDHYPHEN:               // non-breaking hyphen
@@ -409,11 +410,11 @@ bool SwFieldPortion::Format( SwTextFormatInfo &rInf )
             SetHasFollow( true );
 
             // For a newly created field, nNextOffset contains the Offset
-            // of it's start of the original string
+            // of its start of the original string
             // If a FollowField is created when formatting, this FollowField's
             // Offset is being held in nNextOffset
-            nNextOffset = nNextOffset + nNextOfst;
-            pField->SetNextOffset( nNextOffset );
+            m_nNextOffset = m_nNextOffset + nNextOfst;
+            pField->SetNextOffset( m_nNextOffset );
             rInf.SetRest( pField );
         }
     }
@@ -425,10 +426,10 @@ bool SwFieldPortion::Format( SwTextFormatInfo &rInf )
 
 void SwFieldPortion::Paint( const SwTextPaintInfo &rInf ) const
 {
-    SwFontSave aSave( rInf, pFnt );
+    SwFontSave aSave( rInf, m_pFont );
 
     OSL_ENSURE( GetLen() <= 1, "SwFieldPortion::Paint: rest-portion pollution?" );
-    if( Width() && ( !bPlaceHolder || rInf.GetOpt().IsShowPlaceHolderFields() ) )
+    if( Width() && ( !m_bPlaceHolder || rInf.GetOpt().IsShowPlaceHolderFields() ) )
     {
         // A very liberal use of the background
         rInf.DrawViewOpt( *this, POR_FLD );
@@ -438,7 +439,7 @@ void SwFieldPortion::Paint( const SwTextPaintInfo &rInf ) const
 
 bool SwFieldPortion::GetExpText( const SwTextSizeInfo &rInf, OUString &rText ) const
 {
-    rText = aExpand;
+    rText = m_aExpand;
     if( rText.isEmpty() && rInf.OnWin() &&
         !rInf.GetOpt().IsPagePreview() && !rInf.GetOpt().IsReadonly() &&
             SwViewOption::IsFieldShadings() &&
@@ -451,12 +452,12 @@ void SwFieldPortion::HandlePortion( SwPortionHandler& rPH ) const
 {
     sal_Int32 nH = 0;
     sal_Int32 nW = 0;
-    if (pFnt)
+    if (m_pFont)
     {
-        nH = pFnt->GetSize(pFnt->GetActual()).Height();
-        nW = pFnt->GetSize(pFnt->GetActual()).Width();
+        nH = m_pFont->GetSize(m_pFont->GetActual()).Height();
+        nW = m_pFont->GetSize(m_pFont->GetActual()).Width();
     }
-    rPH.Special( GetLen(), aExpand, GetWhichPor(), nH, nW, pFnt );
+    rPH.Special( GetLen(), m_aExpand, GetWhichPor(), nH, nW, m_pFont );
     if( GetWhichPor() == POR_FLD )
     {
         rPH.SetAttrFieldType(m_nAttrFieldType);
@@ -465,7 +466,7 @@ void SwFieldPortion::HandlePortion( SwPortionHandler& rPH ) const
 
 SwPosSize SwFieldPortion::GetTextSize( const SwTextSizeInfo &rInf ) const
 {
-    SwFontSave aSave( rInf, pFnt );
+    SwFontSave aSave( rInf, m_pFont );
     SwPosSize aSize( SwExpandPortion::GetTextSize( rInf ) );
     return aSize;
 }
@@ -473,8 +474,8 @@ SwPosSize SwFieldPortion::GetTextSize( const SwTextSizeInfo &rInf ) const
 SwFieldPortion *SwHiddenPortion::Clone(const OUString &rExpand ) const
 {
     SwFont *pNewFnt;
-    if( nullptr != ( pNewFnt = pFnt ) )
-        pNewFnt = new SwFont( *pFnt );
+    if( nullptr != ( pNewFnt = m_pFont ) )
+        pNewFnt = new SwFont( *m_pFont );
     return new SwHiddenPortion( rExpand, pNewFnt );
 }
 
@@ -482,7 +483,7 @@ void SwHiddenPortion::Paint( const SwTextPaintInfo &rInf ) const
 {
     if( Width() )
     {
-        SwFontSave aSave( rInf, pFnt );
+        SwFontSave aSave( rInf, m_pFont );
         rInf.DrawViewOpt( *this, POR_HIDDEN );
         SwExpandPortion::Paint( rInf );
     }
@@ -519,8 +520,8 @@ sal_Int32 SwNumberPortion::GetCursorOfst( const sal_uInt16 ) const
 SwFieldPortion *SwNumberPortion::Clone( const OUString &rExpand ) const
 {
     SwFont *pNewFnt;
-    if( nullptr != ( pNewFnt = pFnt ) )
-        pNewFnt = new SwFont( *pFnt );
+    if( nullptr != ( pNewFnt = m_pFont ) )
+        pNewFnt = new SwFont( *m_pFont );
 
     return new SwNumberPortion( rExpand, pNewFnt, IsLeft(), IsCenter(),
                                 nMinDist, mbLabelAlignmentPosAndSpaceModeActive );
@@ -656,33 +657,33 @@ void SwNumberPortion::Paint( const SwTextPaintInfo &rInf ) const
     // follow field portions
     if ( ! IsFollow() )
     {
-        SwLinePortion *pThis = const_cast<SwLinePortion*>(static_cast<SwLinePortion const *>(this));
+        SwNumberPortion *pThis = const_cast<SwNumberPortion*>(this);
         pThis->Width( nSumWidth );
         rInf.DrawViewOpt( *this, POR_NUMBER );
         pThis->Width( nOldWidth );
     }
 
-    if( !aExpand.isEmpty() )
+    if( !m_aExpand.isEmpty() )
     {
         const SwFont *pTmpFnt = rInf.GetFont();
-        bool bPaintSpace = ( UNDERLINE_NONE != pTmpFnt->GetUnderline() ||
-                                 UNDERLINE_NONE != pTmpFnt->GetOverline()  ||
+        bool bPaintSpace = ( LINESTYLE_NONE != pTmpFnt->GetUnderline() ||
+                                 LINESTYLE_NONE != pTmpFnt->GetOverline()  ||
                                  STRIKEOUT_NONE != pTmpFnt->GetStrikeout() ) &&
                                  !pTmpFnt->IsWordLineMode();
-        if( bPaintSpace && pFnt )
-            bPaintSpace = ( UNDERLINE_NONE != pFnt->GetUnderline() ||
-                            UNDERLINE_NONE != pFnt->GetOverline()  ||
-                            STRIKEOUT_NONE != pFnt->GetStrikeout() ) &&
-                            !pFnt->IsWordLineMode();
+        if( bPaintSpace && m_pFont )
+            bPaintSpace = ( LINESTYLE_NONE != m_pFont->GetUnderline() ||
+                            LINESTYLE_NONE != m_pFont->GetOverline()  ||
+                            STRIKEOUT_NONE != m_pFont->GetStrikeout() ) &&
+                            !m_pFont->IsWordLineMode();
 
-        SwFontSave aSave( rInf, pFnt );
+        SwFontSave aSave( rInf, m_pFont );
 
         if( nFixWidth == Width() && ! HasFollow() )
             SwExpandPortion::Paint( rInf );
         else
         {
             // logical const: reset width
-            SwLinePortion *pThis = const_cast<SwLinePortion*>(static_cast<SwLinePortion const *>(this));
+            SwNumberPortion *pThis = const_cast<SwNumberPortion*>(this);
             bPaintSpace = bPaintSpace && nFixWidth < nOldWidth;
             sal_uInt16 nSpaceOffs = nFixWidth;
             pThis->Width( nFixWidth );
@@ -743,7 +744,7 @@ SwBulletPortion::SwBulletPortion( const sal_Unicode cBullet,
                                   const bool bCntr,
                                   const sal_uInt16 nMinDst,
                                   const bool bLabelAlignmentPosAndSpaceModeActive )
-    : SwNumberPortion( OUString(cBullet) + rBulletFollowedBy,
+    : SwNumberPortion( OUStringLiteral1(cBullet) + rBulletFollowedBy,
                        pFont, bLft, bCntr, nMinDst,
                        bLabelAlignmentPosAndSpaceModeActive )
 {
@@ -753,7 +754,6 @@ SwBulletPortion::SwBulletPortion( const sal_Unicode cBullet,
 #define GRFNUM_SECURE 10
 
 SwGrfNumPortion::SwGrfNumPortion(
-        SwFrame*,
         const OUString& rGraphicFollowedBy,
         const SvxBrushItem* pGrfBrush,
         const SwFormatVertOrient* pGrfOrient, const Size& rGrfSize,
@@ -765,7 +765,7 @@ SwGrfNumPortion::SwGrfNumPortion(
 {
     SetWhichPor( POR_GRFNUM );
     SetAnimated( false );
-    bReplace = false;
+    m_bReplace = false;
     if( pGrfBrush )
     {
         *pBrush = *pGrfBrush;
@@ -773,7 +773,7 @@ SwGrfNumPortion::SwGrfNumPortion(
         if( pGraph )
             SetAnimated( pGraph->IsAnimated() );
         else
-            bReplace = true;
+            m_bReplace = true;
     }
     if( pGrfOrient )
     {
@@ -789,7 +789,7 @@ SwGrfNumPortion::SwGrfNumPortion(
     nFixWidth = Width();
     nGrfHeight = rGrfSize.Height() + 2 * GRFNUM_SECURE;
     Height( sal_uInt16(nGrfHeight) );
-    bNoPaint = false;
+    m_bNoPaint = false;
 }
 
 SwGrfNumPortion::~SwGrfNumPortion()
@@ -838,7 +838,7 @@ bool SwGrfNumPortion::Format( SwTextFormatInfo &rInf )
         if( bFly )
         {
             SetLen( 0 );
-            SetNoPaint( true );
+            m_bNoPaint = true;
             rInf.SetNumDone( false );
             return true;
         }
@@ -880,7 +880,7 @@ bool SwGrfNumPortion::Format( SwTextFormatInfo &rInf )
  */
 void SwGrfNumPortion::Paint( const SwTextPaintInfo &rInf ) const
 {
-    if( DontPaint() )
+    if( m_bNoPaint )
         return;
     if ( IsHide() && rInf.GetParaPortion() && rInf.GetParaPortion()->GetNext() )
     {
@@ -917,7 +917,7 @@ void SwGrfNumPortion::Paint( const SwTextPaintInfo &rInf ) const
         aPos.X() += nOffset;
     }
 
-    if( bReplace )
+    if( m_bReplace )
     {
         const long nTmpH = GetPortion() ? GetPortion()->GetAscent() : 120;
         aSize = Size( nTmpH, nTmpH );
@@ -994,7 +994,7 @@ void SwGrfNumPortion::Paint( const SwTextPaintInfo &rInf ) const
     if( bDraw && aTmp.HasArea() )
     {
         DrawGraphic( pBrush, const_cast<OutputDevice*>(rInf.GetOut()),
-            aTmp, aRepaint, bReplace ? GRFNUM_REPLACE : GRFNUM_YES );
+            aTmp, aRepaint, m_bReplace ? GRFNUM_REPLACE : GRFNUM_YES );
     }
 }
 
@@ -1068,88 +1068,84 @@ SwCombinedPortion::SwCombinedPortion( const OUString &rText )
 {
     SetLen(1);
     SetWhichPor( POR_COMBINED );
-    if( aExpand.getLength() > 6 )
-        aExpand = aExpand.copy( 0, 6 );
+    if( m_aExpand.getLength() > 6 )
+        m_aExpand = m_aExpand.copy( 0, 6 );
 
     // Initialization of the scripttype array,
     // the arrays of width and position are filled by the format function
-    if( g_pBreakIt->GetBreakIter().is() )
+    assert(g_pBreakIt && g_pBreakIt->GetBreakIter().is());
+
+    SwFontScript nScr = SW_SCRIPTS;
+    for( sal_Int32 i = 0; i < rText.getLength(); ++i )
     {
-        sal_uInt8 nScr = SW_SCRIPTS;
-        for( sal_Int32 i = 0; i < rText.getLength(); ++i )
-        {
-            switch ( g_pBreakIt->GetBreakIter()->getScriptType( rText, i ) ) {
-                case i18n::ScriptType::LATIN : nScr = SW_LATIN; break;
-                case i18n::ScriptType::ASIAN : nScr = SW_CJK; break;
-                case i18n::ScriptType::COMPLEX : nScr = SW_CTL; break;
-            }
-            aScrType[i] = nScr;
+        switch ( g_pBreakIt->GetBreakIter()->getScriptType( rText, i ) ) {
+            case i18n::ScriptType::LATIN : nScr = SwFontScript::Latin; break;
+            case i18n::ScriptType::ASIAN : nScr = SwFontScript::CJK; break;
+            case i18n::ScriptType::COMPLEX : nScr = SwFontScript::CTL; break;
         }
+        aScrType[i] = nScr;
     }
-    else
-    {
-        for( int i = 0; i < 6; ++i )
-            aScrType[i] = 0;
-    }
+
     memset( &aWidth, 0, sizeof(aWidth) );
 }
 
 void SwCombinedPortion::Paint( const SwTextPaintInfo &rInf ) const
 {
     OSL_ENSURE( GetLen() <= 1, "SwFieldPortion::Paint: rest-portion pollution?" );
-    if( Width() )
+    if( !Width() )
+        return;
+
+    rInf.DrawBackBrush( *this );
+    rInf.DrawViewOpt( *this, POR_FLD );
+
+    // do we have to repaint a post it portion?
+    if( rInf.OnWin() && pPortion && !pPortion->Width() )
+        pPortion->PrePaint( rInf, this );
+
+    const sal_Int32 nCount = m_aExpand.getLength();
+    if( !nCount )
+        return;
+    OSL_ENSURE( nCount < 7, "Too much combined characters" );
+
+    // the first character of the second row
+    const sal_Int32 nTop = ( nCount + 1 ) / 2;
+
+    SwFont aTmpFont( *rInf.GetFont() );
+    aTmpFont.SetProportion( nProportion );  // a smaller font
+    SwFontSave aFontSave( rInf, &aTmpFont );
+
+    Point aOldPos = rInf.GetPos();
+    Point aOutPos( aOldPos.X(), aOldPos.Y() - nUpPos );// Y of the first row
+    for( sal_Int32 i = 0 ; i < nCount; ++i )
     {
-        rInf.DrawBackBrush( *this );
-        rInf.DrawViewOpt( *this, POR_FLD );
+        if( i == nTop ) // change the row
+            aOutPos.Y() = aOldPos.Y() + nLowPos;    // Y of the second row
+        aOutPos.X() = aOldPos.X() + aPos[i];        // X position
+        const SwFontScript nAct = aScrType[i];        // script type
+        aTmpFont.SetActual( nAct );
 
-        // do we have to repaint a post it portion?
-        if( rInf.OnWin() && pPortion && !pPortion->Width() )
-            pPortion->PrePaint( rInf, this );
-
-        const sal_Int32 nCount = aExpand.getLength();
-        if( !nCount )
-            return;
-        OSL_ENSURE( nCount < 7, "Too much combined characters" );
-
-        // the first character of the second row
-        const sal_Int32 nTop = ( nCount + 1 ) / 2;
-
-        SwFont aTmpFont( *rInf.GetFont() );
-        aTmpFont.SetProportion( nProportion );  // a smaller font
-        SwFontSave aFontSave( rInf, &aTmpFont );
-
-        Point aOldPos = rInf.GetPos();
-        Point aOutPos( aOldPos.X(), aOldPos.Y() - nUpPos );// Y of the first row
-        for( sal_Int32 i = 0 ; i < nCount; ++i )
+        // if there're more than 4 characters to display, we choose fonts
+        // with 2/3 of the original font width.
+        if( aWidth[ nAct ] )
         {
-            if( i == nTop ) // change the row
-                aOutPos.Y() = aOldPos.Y() + nLowPos;    // Y of the second row
-            aOutPos.X() = aOldPos.X() + aPos[i];        // X position
-            const sal_uInt8 nAct = aScrType[i];        // script type
-            aTmpFont.SetActual( nAct );
-
-            // if there're more than 4 characters to display, we choose fonts
-            // with 2/3 of the original font width.
-            if( aWidth[ nAct ] )
+            Size aTmpSz = aTmpFont.GetSize( nAct );
+            if( aTmpSz.Width() != aWidth[ nAct ] )
             {
-                Size aTmpSz = aTmpFont.GetSize( nAct );
-                if( aTmpSz.Width() != aWidth[ nAct ] )
-                {
-                    aTmpSz.Width() = aWidth[ nAct ];
-                    aTmpFont.SetSize( aTmpSz, nAct );
-                }
+                aTmpSz.Width() = aWidth[ nAct ];
+                aTmpFont.SetSize( aTmpSz, nAct );
             }
-            const_cast<SwTextPaintInfo&>(rInf).SetPos( aOutPos );
-            rInf.DrawText( aExpand, *this, i, 1 );
         }
-        // rInf is const, so we have to take back our manipulations
-        const_cast<SwTextPaintInfo&>(rInf).SetPos( aOldPos );
+        const_cast<SwTextPaintInfo&>(rInf).SetPos( aOutPos );
+        rInf.DrawText( m_aExpand, *this, i, 1 );
     }
+    // rInf is const, so we have to take back our manipulations
+    const_cast<SwTextPaintInfo&>(rInf).SetPos( aOldPos );
+
 }
 
 bool SwCombinedPortion::Format( SwTextFormatInfo &rInf )
 {
-    const sal_Int32 nCount = aExpand.getLength();
+    const sal_Int32 nCount = m_aExpand.getLength();
     if( !nCount )
     {
         Width( 0 );
@@ -1165,14 +1161,14 @@ bool SwCombinedPortion::Format( SwTextFormatInfo &rInf )
     if( nCount > 4 )
     {
         // more than four? Ok, then we need the 2/3 font width
-        for( sal_Int32 i = 0; i < aExpand.getLength(); ++i )
+        for( sal_Int32 i = 0; i < m_aExpand.getLength(); ++i )
         {
             OSL_ENSURE( aScrType[i] < SW_SCRIPTS, "Combined: Script fault" );
             if( !aWidth[ aScrType[i] ] )
             {
                 rInf.GetOut()->SetFont( rInf.GetFont()->GetFnt( aScrType[i] ) );
                 aWidth[ aScrType[i] ] =
-                        static_cast<sal_uInt16>(2 * rInf.GetOut()->GetFontMetric().GetSize().Width() / 3);
+                        static_cast<sal_uInt16>(2 * rInf.GetOut()->GetFontMetric().GetFontSize().Width() / 3);
             }
         }
     }
@@ -1207,7 +1203,7 @@ bool SwCombinedPortion::Format( SwTextFormatInfo &rInf )
         // local nMaxAscent, nMaxDescent and nMaxWidth variables.
         for( sal_Int32 i = 0; i < nCount; ++i )
         {
-            sal_uInt8 nScrp = aScrType[i];
+            SwFontScript nScrp = aScrType[i];
             aTmpFont.SetActual( nScrp );
             if( aWidth[ nScrp ] )
             {
@@ -1216,8 +1212,8 @@ bool SwCombinedPortion::Format( SwTextFormatInfo &rInf )
                 aTmpFont.SetSize( aFontSize, nScrp );
             }
 
-            SwDrawTextInfo aDrawInf( pSh, *rInf.GetOut(), nullptr, aExpand, i, 1 );
-            Size aSize = aTmpFont._GetTextSize( aDrawInf );
+            SwDrawTextInfo aDrawInf( pSh, *rInf.GetOut(), nullptr, m_aExpand, i, 1 );
+            Size aSize = aTmpFont.GetTextSize_( aDrawInf );
             const sal_uInt16 nAsc = aTmpFont.GetAscent( pSh, *rInf.GetOut() );
             aPos[ i ] = (sal_uInt16)aSize.Width();
             if( i == nTop ) // enter the second line
@@ -1274,16 +1270,20 @@ bool SwCombinedPortion::Format( SwTextFormatInfo &rInf )
         nBotDiff = ( Width() - nMaxWidth ) / 2;
     switch( nTop)
     {
-        case 3: aPos[1] = aPos[0] + nTopDiff;  // no break
+        case 3: aPos[1] = aPos[0] + nTopDiff;
+            SAL_FALLTHROUGH;
         case 2: aPos[nTop-1] = Width() - aPos[nTop-1];
     }
     aPos[0] = 0;
     switch( nCount )
     {
-        case 5: aPos[4] = aPos[3] + nBotDiff;   // no break
+        case 5: aPos[4] = aPos[3] + nBotDiff;
+            SAL_FALLTHROUGH;
         case 3: aPos[nTop] = nBotDiff;          break;
-        case 6: aPos[4] = aPos[3] + nBotDiff;   // no break
-        case 4: aPos[nTop] = 0;                 // no break
+        case 6: aPos[4] = aPos[3] + nBotDiff;
+            SAL_FALLTHROUGH;
+        case 4: aPos[nTop] = 0;
+            SAL_FALLTHROUGH;
         case 2: aPos[nCount-1] = Width() - aPos[nCount-1];
     }
 
