@@ -26,9 +26,9 @@
 #include <charfmt.hxx>
 #include <viewopt.hxx>
 #include <viewsh.hxx>
-#include <pordrop.hxx>
-#include <itrform2.hxx>
-#include <txtpaint.hxx>
+#include "pordrop.hxx"
+#include "itrform2.hxx"
+#include "txtpaint.hxx"
 #include <blink.hxx>
 #include <breakit.hxx>
 #include <com/sun/star/i18n/ScriptType.hpp>
@@ -52,8 +52,8 @@ static bool lcl_IsDropFlyInter( const SwTextFormatInfo &rInf,
     const SwTextFly& rTextFly = rInf.GetTextFly();
     if( rTextFly.IsOn() )
     {
-        SwRect aRect( rInf.GetTextFrame()->Frame().Pos(), Size( nWidth, nHeight) );
-        aRect.Pos() += rInf.GetTextFrame()->Prt().Pos();
+        SwRect aRect( rInf.GetTextFrame()->getFrameArea().Pos(), Size( nWidth, nHeight) );
+        aRect.Pos() += rInf.GetTextFrame()->getFramePrintArea().Pos();
         aRect.Pos().X() += rInf.X();
         aRect.Pos().Y() = rInf.Y();
         aRect = rTextFly.GetFrame( aRect );
@@ -108,7 +108,6 @@ SwDropPortion::SwDropPortion( const sal_uInt16 nLineCnt,
     nDropDescent(nDrpDescent),
     nDistance(nDist),
     nFix(0),
-    nX(0),
     nY(0)
 {
     SetWhichPor( POR_DROP );
@@ -128,7 +127,7 @@ sal_Int32 SwTextNode::GetDropLen( sal_Int32 nWishLen ) const
     if( nWishLen && nWishLen < nEnd )
         nEnd = nWishLen;
 
-    if ( ! nWishLen && g_pBreakIt->GetBreakIter().is() )
+    if (! nWishLen)
     {
         // find first word
         const SwAttrSet& rAttrSet = GetSwAttrSet();
@@ -162,7 +161,7 @@ sal_Int32 SwTextNode::GetDropLen( sal_Int32 nWishLen ) const
         sal_Unicode const cChar = GetText()[i];
         if( CH_TAB == cChar || CH_BREAK == cChar ||
             (( CH_TXTATR_BREAKWORD == cChar || CH_TXTATR_INWORD == cChar )
-                && SwTextSizeInfo::_HasHint( this, i ) ) )
+                && SwTextSizeInfo::HasHint_( this, i ) ) )
             break;
     }
     return i;
@@ -217,7 +216,7 @@ bool SwTextNode::GetDropSize(int& rFontHeight, int& rDropHeight, int& rDropDesce
                             rFontHeight = pFont->GetSize(pFont->GetActual()).Height();
                         else
                         {
-                            const SvxFontHeightItem& rItem = static_cast<const SvxFontHeightItem&>(rSet.Get(RES_CHRATR_FONTSIZE));
+                            const SvxFontHeightItem& rItem = rSet.Get(RES_CHRATR_FONTSIZE);
                             rFontHeight = rItem.GetHeight();
                         }
                     }
@@ -231,7 +230,7 @@ bool SwTextNode::GetDropSize(int& rFontHeight, int& rDropHeight, int& rDropDesce
     {
         const sal_uInt16 nLines = rDrop.GetLines();
 
-        const SvxFontHeightItem& rItem = static_cast<const SvxFontHeightItem&>(rSet.Get( RES_CHRATR_FONTSIZE ));
+        const SvxFontHeightItem& rItem = rSet.Get( RES_CHRATR_FONTSIZE );
         rFontHeight = rItem.GetHeight();
         rDropHeight = nLines * rFontHeight;
         rDropDescent = rFontHeight / 5;
@@ -303,7 +302,7 @@ void SwDropPortion::PaintDrop( const SwTextPaintInfo &rInf ) const
     const SwTwips nOldPosY  = rInf.Y();
     const SwTwips nOldPosX  = rInf.X();
     const SwParaPortion *pPara = rInf.GetParaPortion();
-    const Point aOutPos( nOldPosX + nX, nOldPosY - pPara->GetAscent()
+    const Point aOutPos( nOldPosX, nOldPosY - pPara->GetAscent()
                          - pPara->GetRealHeight() + pPara->Height() );
     // make good for retouching
 
@@ -312,7 +311,6 @@ void SwDropPortion::PaintDrop( const SwTextPaintInfo &rInf ) const
 
     // for background
     const_cast<SwDropPortion*>(this)->Height( nDropHeight + nDropDescent );
-    const_cast<SwDropPortion*>(this)->Width( Width() - nX );
     const_cast<SwDropPortion*>(this)->SetAscent( nDropHeight );
 
     // Always adapt Clipregion to us, never set it off using the existing ClipRect
@@ -474,7 +472,7 @@ void SwTextFormatter::CalcDropHeight( const sal_uInt16 nLines )
     SetDropDescent( nHeight - nAscent );
     SetDropHeight( nDropHght );
     SetDropLines( nDropLns );
-    // Alte Stelle wiederfinden!
+    // Find old position!
     while( pOldCurr != GetCurr() )
     {
         if( !Next() )
@@ -486,7 +484,7 @@ void SwTextFormatter::CalcDropHeight( const sal_uInt16 nLines )
 }
 
 /**
- * We assume hat the font height doesn't change and that at first there
+ * We assume that the font height doesn't change and that at first there
  * are at least as many lines, as the DropCap-setting claims
  */
 void SwTextFormatter::GuessDropHeight( const sal_uInt16 nLines )
@@ -513,7 +511,7 @@ SwDropPortion *SwTextFormatter::NewDropPortion( SwTextFormatInfo &rInf )
     nPorLen = m_pFrame->GetTextNode()->GetDropLen( nPorLen );
     if( !nPorLen )
     {
-        static_cast<SwTextFormatter*>(this)->ClearDropFormat();
+        ClearDropFormat();
         return nullptr;
     }
 
@@ -543,7 +541,7 @@ SwDropPortion *SwTextFormatter::NewDropPortion( SwTextFormatInfo &rInf )
     // font is used.
     if ( GetDropLines() < 2 )
     {
-        static_cast<SwTextFormatter*>(this)->SetPaintDrop( true );
+        SetPaintDrop( true );
         return pDropPor;
     }
 
@@ -571,8 +569,8 @@ SwDropPortion *SwTextFormatter::NewDropPortion( SwTextFormatInfo &rInf )
 
         // find next attribute change / script change
         const sal_Int32 nTmpIdx = nNextChg;
-        sal_Int32 nNextAttr = std::min( static_cast<sal_Int32>(GetNextAttr()), rInf.GetText().getLength() );
-        nNextChg = pScriptInfo->NextScriptChg( nTmpIdx );
+        sal_Int32 nNextAttr = std::min( GetNextAttr(), rInf.GetText().getLength() );
+        nNextChg = m_pScriptInfo->NextScriptChg( nTmpIdx );
         if( nNextChg > nNextAttr )
             nNextChg = nNextAttr;
         if ( nNextChg > nPorLen )
@@ -589,7 +587,7 @@ SwDropPortion *SwTextFormatter::NewDropPortion( SwTextFormatInfo &rInf )
         pCurrPart = pPart;
     }
 
-    static_cast<SwTextFormatter*>(this)->SetPaintDrop( true );
+    SetPaintDrop( true );
     return pDropPor;
 }
 
@@ -613,7 +611,7 @@ void SwTextPainter::PaintDropPortion()
     while( !m_pCurr->GetLen() && Next() )
         ;
 
-    // MarginPortion und Adjustment!
+    // MarginPortion and Adjustment!
     const SwLinePortion *pPor = m_pCurr->GetFirstPortion();
     long nX = 0;
     while( pPor && !pPor->IsDropPortion() )
@@ -650,7 +648,6 @@ class SwDropCapCache
     sal_uInt16 nIndex;
 public:
     SwDropCapCache();
-    ~SwDropCapCache(){}
     void CalcFontSize( SwDropPortion* pDrop, SwTextFormatInfo &rInf );
 };
 
@@ -743,7 +740,7 @@ void SwDropCapCache::CalcFontSize( SwDropPortion* pDrop, SwTextFormatInfo &rInf
 
         bool bWinUsed = false;
         vcl::Font aOldFnt;
-        MapMode aOldMap( MAP_TWIP );
+        MapMode aOldMap( MapUnit::MapTwip );
         OutputDevice* pOut = rInf.GetOut();
         OutputDevice* pWin;
         if( rInf.GetVsh() && rInf.GetVsh()->GetWin() )
@@ -756,7 +753,7 @@ void SwDropCapCache::CalcFontSize( SwDropPortion* pDrop, SwTextFormatInfo &rInf
             // reset pCurrPart to first part
             pCurrPart = pDrop->GetPart();
             bool bFirstGlyphRect = true;
-            Rectangle aCommonRect, aRect;
+            tools::Rectangle aCommonRect, aRect;
 
             while ( pCurrPart )
             {
@@ -792,7 +789,7 @@ void SwDropCapCache::CalcFontSize( SwDropPortion* pDrop, SwTextFormatInfo &rInf
                         {
                             bWinUsed = true;
                             aOldMap = pWin->GetMapMode( );
-                            pWin->SetMapMode( MapMode( MAP_TWIP ) );
+                            pWin->SetMapMode( MapMode( MapUnit::MapTwip ) );
                             aOldFnt = pWin->GetFont();
                         }
                         pWin->SetFont( rFnt.GetActualFont() );
@@ -805,7 +802,7 @@ void SwDropCapCache::CalcFontSize( SwDropPortion* pDrop, SwTextFormatInfo &rInf
                     {
                         // We do not have a window or our window could not
                         // give us glyph boundaries.
-                        aRect = Rectangle( Point( 0, 0 ), Size( 0, nAscent ) );
+                        aRect = tools::Rectangle( Point( 0, 0 ), Size( 0, nAscent ) );
                     }
                 }
 
@@ -936,7 +933,7 @@ void SwDropCapCache::CalcFontSize( SwDropPortion* pDrop, SwTextFormatInfo &rInf
 bool SwDropPortion::Format( SwTextFormatInfo &rInf )
 {
     bool bFull = false;
-    Fix( (sal_uInt16)rInf.X() );
+    nFix = (sal_uInt16)rInf.X();
 
     SwLayoutModeModifier aLayoutModeModifier( *rInf.GetOut() );
     aLayoutModeModifier.SetAuto();
