@@ -7,12 +7,11 @@
  * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  */
 
-#include "ToxWhitespaceStripper.hxx"
+#include <ToxWhitespaceStripper.hxx>
 
-#include "rtl/ustrbuf.hxx"
-#include "sal/log.hxx"
+#include <rtl/ustrbuf.hxx>
+#include <sal/log.hxx>
 
-#include <boost/numeric/conversion/cast.hpp>
 
 namespace sw {
 
@@ -51,13 +50,14 @@ ToxWhitespaceStripper::ToxWhitespaceStripper(const OUString& inputString)
 sal_Int32
 ToxWhitespaceStripper::GetPositionInStrippedString(sal_Int32 pos) const
 {
-    size_t upos = boost::numeric_cast<size_t>(pos);
-    if (upos >= mNewPositions.size()) {
+    assert(0 <= pos);
+    if (static_cast<size_t>(pos) >= mNewPositions.size()) {
+        // TODO probably this should assert, not just warn?
         SAL_WARN("sw.core", "Requested position of TOX entry text which does not exist. "
                             "Maybe the formatting hint is corrupt?");
         return mNewPositions.back();
     }
-    return mNewPositions.at(upos);
+    return mNewPositions.at(pos);
 }
 
 
