@@ -31,52 +31,42 @@
 #include <breakit.hxx>
 #include <txtfrm.hxx>
 #include <scriptinfo.hxx>
+#include <fntcap.hxx>
 
 using namespace ::com::sun::star::i18n;
 
-/*************************************************************************
- *                      class SwCapitalInfo
- *
- * The information encapsulated in SwCapitalInfo is required
- * by the ::Do functions. They contain the information about
- * the original string, whereas rDo.GetInf() contains information
- * about the display string.
- *************************************************************************/
-
+// The information encapsulated in SwCapitalInfo is required
+// by the ::Do functions. They contain the information about
+// the original string, whereas rDo.GetInf() contains information
+// about the display string.
 class SwCapitalInfo
 {
 public:
     explicit SwCapitalInfo( const OUString& rOrigText ) :
         rString( rOrigText ), nIdx( 0 ), nLen( 0 ) {};
     const OUString& rString;
-    xub_StrLen nIdx;
-    xub_StrLen nLen;
+    sal_Int32 nIdx;
+    sal_Int32 nLen;
 };
 
-/*************************************************************************
- *                      xub_StrLen sw_CalcCaseMap()
- *
- * rFnt: required for CalcCaseMap
- * rOrigString: The original string
- * nOfst: Position of the substring in rOrigString
- * nLen: Length if the substring in rOrigString
- * nIdx: Referes to a position in the display string and should be mapped
- *       to a position in rOrigString
- *************************************************************************/
-
-xub_StrLen sw_CalcCaseMap( const SwFont& rFnt,
+// rFnt: required for CalcCaseMap
+// rOrigString: The original string
+// nOfst: Position of the substring in rOrigString
+// nLen: Length if the substring in rOrigString
+// nIdx: Referes to a position in the display string and should be mapped
+//       to a position in rOrigString
+sal_Int32 sw_CalcCaseMap( const SwFont& rFnt,
                             const OUString& rOrigString,
-                            xub_StrLen nOfst,
-                            xub_StrLen nLen,
-                            xub_StrLen nIdx )
+                            sal_Int32 nOfst,
+                            sal_Int32 nLen,
+                            sal_Int32 nIdx )
 {
     int j = 0;
-    const xub_StrLen nEnd = nOfst + nLen;
+    const sal_Int32 nEnd = nOfst + nLen;
     OSL_ENSURE( nEnd <= rOrigString.getLength(), "sw_CalcCaseMap: Wrong parameters" );
 
     // special case for title case:
-    const bool bTitle = SVX_CASEMAP_TITEL == rFnt.GetCaseMap() &&
-                        g_pBreakIt->GetBreakIter().is();
+    const bool bTitle = SvxCaseMap::Capitalize == rFnt.GetCaseMap();
     for ( sal_Int32 i = nOfst; i < nEnd; ++i )
     {
         OUString aTmp(rOrigString.copy(i, 1));
@@ -97,60 +87,48 @@ xub_StrLen sw_CalcCaseMap( const SwFont& rFnt,
     return nOfst + nLen;
 }
 
-/*************************************************************************
- *                      class SwDoCapitals
- *************************************************************************/
-
 class SwDoCapitals
 {
 protected:
     SwDrawTextInfo &rInf;
     SwCapitalInfo* pCapInf; // referes to additional information
                            // required by the ::Do function
-    SwDoCapitals ( SwDrawTextInfo &rInfo ) : rInf( rInfo ), pCapInf( 0 ) { }
+    explicit SwDoCapitals ( SwDrawTextInfo &rInfo ) : rInf( rInfo ), pCapInf( nullptr ) { }
     ~SwDoCapitals() {}
 public:
     virtual void Init( SwFntObj *pUpperFont, SwFntObj *pLowerFont ) = 0;
     virtual void Do() = 0;
-    inline OutputDevice& GetOut() { return rInf.GetOut(); }
-    inline SwDrawTextInfo& GetInf() { return rInf; }
-    inline SwCapitalInfo* GetCapInf() const { return pCapInf; }
-    inline void SetCapInf( SwCapitalInfo& rNew ) { pCapInf = &rNew; }
+    OutputDevice& GetOut() { return rInf.GetOut(); }
+    SwDrawTextInfo& GetInf() { return rInf; }
+    SwCapitalInfo* GetCapInf() const { return pCapInf; }
+    void SetCapInf( SwCapitalInfo& rNew ) { pCapInf = &rNew; }
 };
 
-/*************************************************************************
- *                    class SwDoGetCapitalSize
- *************************************************************************/
-
 class SwDoGetCapitalSize : public SwDoCapitals
 {
 protected:
-    Size aTxtSize;
+    Size aTextSize;
 public:
-    SwDoGetCapitalSize( SwDrawTextInfo &rInfo ) : SwDoCapitals ( rInfo ) { }
+    explicit SwDoGetCapitalSize( SwDrawTextInfo &rInfo ) : SwDoCapitals ( rInfo ) { }
     virtual ~SwDoGetCapitalSize() {}
-    virtual void Init( SwFntObj *pUpperFont, SwFntObj *pLowerFont );
-    virtual void Do();
-    const Size &GetSize() const { return aTxtSize; }
+    virtual void Init( SwFntObj *pUpperFont, SwFntObj *pLowerFont ) override;
+    virtual void Do() override;
+    const Size &GetSize() const { return aTextSize; }
 };
 
 void SwDoGetCapitalSize::Init( SwFntObj *, SwFntObj * )
 {
-    aTxtSize.Height() = 0;
-    aTxtSize.Width() = 0;
+    aTextSize.Height() = 0;
+    aTextSize.Width() = 0;
 }
 
 void SwDoGetCapitalSize::Do()
 {
-    aTxtSize.Width() += rInf.GetSize().Width();
+    aTextSize.Width() += rInf.GetSize().Width();
     if( rInf.GetUpper() )
-        aTxtSize.Height() = rInf.GetSize().Height();
+        aTextSize.Height() = rInf.GetSize().Height();
 }
 
-/*************************************************************************
- *                    SwSubFont::GetCapitalSize()
- *************************************************************************/
-
 Size SwSubFont::GetCapitalSize( SwDrawTextInfo& rInf )
 {
     // Start:
@@ -159,40 +137,36 @@ Size SwSubFont::GetCapitalSize( SwDrawTextInfo& rInf )
     Point aPos;
     rInf.SetPos( aPos );
     rInf.SetSpace( 0 );
-    rInf.SetDrawSpace( sal_False );
+    rInf.SetDrawSpace( false );
     SwDoGetCapitalSize aDo( rInf );
     DoOnCapitals( aDo );
-    Size aTxtSize( aDo.GetSize() );
+    Size aTextSize( aDo.GetSize() );
 
     // End:
-    if( !aTxtSize.Height() )
+    if( !aTextSize.Height() )
     {
         SV_STAT( nGetTextSize );
-        aTxtSize.Height() = short ( rInf.GetpOut()->GetTextHeight() );
+        aTextSize.Height() = short ( rInf.GetpOut()->GetTextHeight() );
     }
     rInf.SetKern( nOldKern );
-    return aTxtSize;
+    return aTextSize;
 }
 
-/*************************************************************************
- *                    class SwDoGetCapitalBreak
- *************************************************************************/
-
 class SwDoGetCapitalBreak : public SwDoCapitals
 {
 protected:
-    long nTxtWidth;
-    xub_StrLen nBreak;
+    long nTextWidth;
+    sal_Int32 m_nBreak;
 public:
     SwDoGetCapitalBreak( SwDrawTextInfo &rInfo, long const nWidth)
         :   SwDoCapitals ( rInfo )
-        ,   nTxtWidth( nWidth )
-        ,   nBreak( STRING_LEN )
+        ,   nTextWidth( nWidth )
+        ,   m_nBreak( -1 )
         { }
     virtual ~SwDoGetCapitalBreak() {}
-    virtual void Init( SwFntObj *pUpperFont, SwFntObj *pLowerFont );
-    virtual void Do();
-    xub_StrLen GetBreak() const { return nBreak; }
+    virtual void Init( SwFntObj *pUpperFont, SwFntObj *pLowerFont ) override;
+    virtual void Do() override;
+    sal_Int32 getBreak() const { return m_nBreak; }
 };
 
 void SwDoGetCapitalBreak::Init( SwFntObj *, SwFntObj * )
@@ -201,87 +175,72 @@ void SwDoGetCapitalBreak::Init( SwFntObj *, SwFntObj * )
 
 void SwDoGetCapitalBreak::Do()
 {
-    if ( nTxtWidth )
+    if ( nTextWidth )
     {
-        if ( rInf.GetSize().Width() < nTxtWidth )
-            nTxtWidth -= rInf.GetSize().Width();
+        if ( rInf.GetSize().Width() < nTextWidth )
+            nTextWidth -= rInf.GetSize().Width();
         else
         {
-            xub_StrLen nEnd = rInf.GetEnd();
-            OUString sText(rInf.GetText()); // only needed until rInf.GetText() returns OUString
-            sal_Int32 nIdx2 = rInf.GetIdx(); // ditto
-            sal_Int32 nLen2 = rInf.GetLen(); // ditto
-            nBreak = GetOut().GetTextBreak( sText, nTxtWidth,
-                               nIdx2, nLen2, rInf.GetKern() );
+            sal_Int32 nEnd = rInf.GetEnd();
+            m_nBreak = GetOut().GetTextBreak( rInf.GetText(), nTextWidth,
+                               rInf.GetIdx(), rInf.GetLen(), rInf.GetKern() );
 
-            rInf.SetText(sText); // ditto
-            rInf.SetIdx(nIdx2);  // ditto
-            rInf.SetLen(nLen2);  // ditto
+            if (m_nBreak > nEnd || m_nBreak < 0)
+                m_nBreak = nEnd;
 
-            if( nBreak > nEnd )
-                nBreak = nEnd;
-
-            // nBreak may be relative to the display string. It has to be
+            // m_nBreak may be relative to the display string. It has to be
             // calculated relative to the original string:
             if ( GetCapInf()  )
             {
                 if ( GetCapInf()->nLen != rInf.GetLen() )
-                    nBreak = sw_CalcCaseMap( *rInf.GetFont(),
+                    m_nBreak = sw_CalcCaseMap( *rInf.GetFont(),
                                               GetCapInf()->rString,
                                               GetCapInf()->nIdx,
-                                              GetCapInf()->nLen, nBreak );
+                                              GetCapInf()->nLen, m_nBreak );
                 else
-                    nBreak = nBreak + GetCapInf()->nIdx;
+                    m_nBreak = m_nBreak + GetCapInf()->nIdx;
             }
 
-            nTxtWidth = 0;
+            nTextWidth = 0;
         }
     }
 }
 
-/*************************************************************************
- *                    SwFont::GetCapitalBreak()
- *************************************************************************/
-
-xub_StrLen SwFont::GetCapitalBreak( SwViewShell* pSh, const OutputDevice* pOut,
-    const SwScriptInfo* pScript, const OUString& rTxt, long const nTextWidth,
-    const xub_StrLen nIdx, const xub_StrLen nLen )
+sal_Int32 SwFont::GetCapitalBreak( SwViewShell const * pSh, const OutputDevice* pOut,
+    const SwScriptInfo* pScript, const OUString& rText, long const nTextWidth,
+    const sal_Int32 nIdx, const sal_Int32 nLen )
 {
     // Start:
     Point aPos( 0, 0 );
-    SwDrawTextInfo aInfo(pSh, *(OutputDevice*)pOut, pScript, rTxt, nIdx, nLen,
-        0, sal_False);
+    SwDrawTextInfo aInfo(pSh, *const_cast<OutputDevice*>(pOut), pScript, rText, nIdx, nLen,
+        0, false);
     aInfo.SetPos( aPos );
     aInfo.SetSpace( 0 );
-    aInfo.SetWrong( NULL );
-    aInfo.SetGrammarCheck( NULL );
-    aInfo.SetSmartTags( NULL ); // SMARTTAGS
-    aInfo.SetDrawSpace( sal_False );
+    aInfo.SetWrong( nullptr );
+    aInfo.SetGrammarCheck( nullptr );
+    aInfo.SetSmartTags( nullptr );
+    aInfo.SetDrawSpace( false );
     aInfo.SetKern( CheckKerning() );
     aInfo.SetKanaComp( pScript ? 0 : 100 );
     aInfo.SetFont( this );
 
     SwDoGetCapitalBreak aDo(aInfo, nTextWidth);
     DoOnCapitals( aDo );
-    return aDo.GetBreak();
+    return aDo.getBreak();
 }
 
-/*************************************************************************
- *                     class SwDoDrawCapital
- *************************************************************************/
-
 class SwDoDrawCapital : public SwDoCapitals
 {
 protected:
     SwFntObj *pUpperFnt;
     SwFntObj *pLowerFnt;
 public:
-    SwDoDrawCapital( SwDrawTextInfo &rInfo ) :
-        SwDoCapitals( rInfo ), pUpperFnt(0), pLowerFnt(0)
+    explicit SwDoDrawCapital( SwDrawTextInfo &rInfo ) :
+        SwDoCapitals( rInfo ), pUpperFnt(nullptr), pLowerFnt(nullptr)
         { }
     virtual ~SwDoDrawCapital() {}
-    virtual void Init( SwFntObj *pUpperFont, SwFntObj *pLowerFont );
-    virtual void Do();
+    virtual void Init( SwFntObj *pUpperFont, SwFntObj *pLowerFont ) override;
+    virtual void Do() override;
     void DrawSpace( Point &rPos );
 };
 
@@ -294,110 +253,96 @@ void SwDoDrawCapital::Init( SwFntObj *pUpperFont, SwFntObj *pLowerFont )
 void SwDoDrawCapital::Do()
 {
     SV_STAT( nDrawText );
-    sal_uInt16 nOrgWidth = rInf.GetWidth();
+    const sal_uInt16 nOrgWidth = rInf.GetWidth();
     rInf.SetWidth( sal_uInt16(rInf.GetSize().Width()) );
     if ( rInf.GetUpper() )
         pUpperFnt->DrawText( rInf );
     else
     {
-        sal_Bool bOldBullet = rInf.GetBullet();
-        rInf.SetBullet( sal_False );
+        bool bOldBullet = rInf.GetBullet();
+        rInf.SetBullet( false );
         pLowerFnt->DrawText( rInf );
         rInf.SetBullet( bOldBullet );
     }
 
     OSL_ENSURE( pUpperFnt, "No upper font, dying soon!");
-    rInf.Shift( pUpperFnt->GetFont()->GetOrientation() );
+    rInf.Shift( pUpperFnt->GetFont().GetOrientation() );
     rInf.SetWidth( nOrgWidth );
 }
 
-/*************************************************************************
- *                    SwDoDrawCapital::DrawSpace()
- *************************************************************************/
-
 void SwDoDrawCapital::DrawSpace( Point &rPos )
 {
     long nDiff = rInf.GetPos().X() - rPos.X();
 
     Point aPos( rPos );
-    const sal_Bool bSwitchL2R = rInf.GetFrm()->IsRightToLeft() &&
-                          ! rInf.IsIgnoreFrmRTL();
-
+    const bool bSwitchL2R = rInf.GetFrame()->IsRightToLeft() &&
+                          ! rInf.IsIgnoreFrameRTL();
 
     if ( bSwitchL2R )
-       rInf.GetFrm()->SwitchLTRtoRTL( aPos );
+       rInf.GetFrame()->SwitchLTRtoRTL( aPos );
 
-    const sal_uLong nMode = rInf.GetpOut()->GetLayoutMode();
-    const sal_Bool bBidiPor = ( bSwitchL2R !=
-                            ( 0 != ( TEXT_LAYOUT_BIDI_RTL & nMode ) ) );
+    const ComplexTextLayoutFlags nMode = rInf.GetpOut()->GetLayoutMode();
+    const bool bBidiPor = ( bSwitchL2R !=
+                            ( ComplexTextLayoutFlags::Default != ( ComplexTextLayoutFlags::BiDiRtl & nMode ) ) );
 
     if ( bBidiPor )
         nDiff = -nDiff;
 
-    if ( rInf.GetFrm()->IsVertical() )
-        rInf.GetFrm()->SwitchHorizontalToVertical( aPos );
+    if ( rInf.GetFrame()->IsVertical() )
+        rInf.GetFrame()->SwitchHorizontalToVertical( aPos );
 
     if ( nDiff )
     {
         rInf.ApplyAutoColor();
         GetOut().DrawStretchText( aPos, nDiff,
-            OUString("  "), 0, 2 );
+            "  ", 0, 2 );
     }
     rPos.X() = rInf.GetPos().X() + rInf.GetWidth();
 }
 
-/*************************************************************************
- *                    SwSubFont::DrawCapital()
- *************************************************************************/
-
 void SwSubFont::DrawCapital( SwDrawTextInfo &rInf )
 {
-    // Es wird vorausgesetzt, dass rPos bereits kalkuliert ist!
-    // hochgezogen in SwFont: const Point aPos( CalcPos(rPos) );
-    rInf.SetDrawSpace( GetUnderline() != UNDERLINE_NONE ||
-                       GetOverline()  != UNDERLINE_NONE ||
+    // Precondition: rInf.GetPos() has already been calculated
+
+    rInf.SetDrawSpace( GetUnderline() != LINESTYLE_NONE ||
+                       GetOverline()  != LINESTYLE_NONE ||
                        GetStrikeout() != STRIKEOUT_NONE );
     SwDoDrawCapital aDo( rInf );
     DoOnCapitals( aDo );
 }
 
-/*************************************************************************
- *                     class SwDoDrawCapital
- *************************************************************************/
-
-class SwDoCapitalCrsrOfst : public SwDoCapitals
+class SwDoCapitalCursorOfst : public SwDoCapitals
 {
 protected:
     SwFntObj *pUpperFnt;
     SwFntObj *pLowerFnt;
-    xub_StrLen nCrsr;
+    sal_Int32 nCursor;
     sal_uInt16 nOfst;
 public:
-    SwDoCapitalCrsrOfst( SwDrawTextInfo &rInfo, const sal_uInt16 nOfs ) :
-        SwDoCapitals( rInfo ), pUpperFnt(0), pLowerFnt(0), nCrsr( 0 ), nOfst( nOfs )
+    SwDoCapitalCursorOfst( SwDrawTextInfo &rInfo, const sal_uInt16 nOfs ) :
+        SwDoCapitals( rInfo ), pUpperFnt(nullptr), pLowerFnt(nullptr), nCursor( 0 ), nOfst( nOfs )
         { }
-    virtual ~SwDoCapitalCrsrOfst() {}
-    virtual void Init( SwFntObj *pUpperFont, SwFntObj *pLowerFont );
-    virtual void Do();
+    virtual ~SwDoCapitalCursorOfst() {}
+    virtual void Init( SwFntObj *pUpperFont, SwFntObj *pLowerFont ) override;
+    virtual void Do() override;
 
-    void DrawSpace( const Point &rPos );
-    inline xub_StrLen GetCrsr(){ return nCrsr; }
+    sal_Int32 GetCursor(){ return nCursor; }
 };
 
-void SwDoCapitalCrsrOfst::Init( SwFntObj *pUpperFont, SwFntObj *pLowerFont )
+void SwDoCapitalCursorOfst::Init( SwFntObj *pUpperFont, SwFntObj *pLowerFont )
 {
     pUpperFnt = pUpperFont;
     pLowerFnt = pLowerFont;
 }
 
-void SwDoCapitalCrsrOfst::Do()
+void SwDoCapitalCursorOfst::Do()
 {
     if ( nOfst )
     {
-        if ( nOfst > rInf.GetSize().Width() )
+        if ( static_cast<long>(nOfst) > rInf.GetSize().Width() )
         {
-            nOfst = nOfst - sal_uInt16(rInf.GetSize().Width());
-            nCrsr = nCrsr + rInf.GetLen();
+            nOfst -= rInf.GetSize().Width();
+            nCursor = nCursor + rInf.GetLen();
         }
         else
         {
@@ -405,56 +350,48 @@ void SwDoCapitalCrsrOfst::Do()
                                      rInf.GetScriptInfo(),
                                      rInf.GetText(),
                                      rInf.GetIdx(),
-                                     rInf.GetLen(), 0, sal_False );
+                                     rInf.GetLen(), 0, false );
             aDrawInf.SetOfst( nOfst );
             aDrawInf.SetKern( rInf.GetKern() );
             aDrawInf.SetKanaComp( rInf.GetKanaComp() );
-            aDrawInf.SetFrm( rInf.GetFrm() );
+            aDrawInf.SetFrame( rInf.GetFrame() );
             aDrawInf.SetFont( rInf.GetFont() );
 
             if ( rInf.GetUpper() )
             {
                 aDrawInf.SetSpace( 0 );
-                nCrsr = nCrsr + pUpperFnt->GetCrsrOfst( aDrawInf );
+                nCursor = nCursor + pUpperFnt->GetCursorOfst( aDrawInf );
             }
             else
             {
                 aDrawInf.SetSpace( rInf.GetSpace() );
-                nCrsr = nCrsr + pLowerFnt->GetCrsrOfst( aDrawInf );
+                nCursor = nCursor + pLowerFnt->GetCursorOfst( aDrawInf );
             }
             nOfst = 0;
         }
     }
 }
 
-/*************************************************************************
- *                    SwSubFont::GetCapitalCrsrOfst()
- *************************************************************************/
-
-xub_StrLen SwSubFont::GetCapitalCrsrOfst( SwDrawTextInfo& rInf )
+sal_Int32 SwSubFont::GetCapitalCursorOfst( SwDrawTextInfo& rInf )
 {
     const long nOldKern = rInf.GetKern();
     rInf.SetKern( CheckKerning() );
-    SwDoCapitalCrsrOfst aDo( rInf, rInf.GetOfst() );
+    SwDoCapitalCursorOfst aDo( rInf, rInf.GetOfst() );
     Point aPos;
     rInf.SetPos( aPos );
-    rInf.SetDrawSpace( sal_False );
+    rInf.SetDrawSpace( false );
     DoOnCapitals( aDo );
     rInf.SetKern( nOldKern );
-    return aDo.GetCrsr();
+    return aDo.GetCursor();
 }
 
-/*************************************************************************
- *                    class SwDoDrawStretchCapital
- *************************************************************************/
-
 class SwDoDrawStretchCapital : public SwDoDrawCapital
 {
-    const xub_StrLen nStrLen;
+    const sal_Int32 nStrLen;
     const sal_uInt16 nCapWidth;
     const sal_uInt16 nOrgWidth;
 public:
-    virtual void Do();
+    virtual void Do() override;
 
     SwDoDrawStretchCapital( SwDrawTextInfo &rInfo, const sal_uInt16 nCapitalWidth )
             : SwDoDrawCapital( rInfo ),
@@ -462,45 +399,39 @@ public:
               nCapWidth( nCapitalWidth ),
               nOrgWidth( rInfo.GetWidth() )
         { }
-
-    virtual ~SwDoDrawStretchCapital() {}
 };
 
-/*************************************************************************
- *                    SwDoDrawStretchCapital
- *************************************************************************/
-
 void SwDoDrawStretchCapital::Do()
 {
     SV_STAT( nDrawStretchText );
-    sal_uInt16 nPartWidth = sal_uInt16(rInf.GetSize().Width());
+    long nPartWidth = rInf.GetSize().Width();
 
     if( rInf.GetLen() )
     {
-        // 4023: Kapitaelchen und Kerning.
+        // small caps and kerning
         long nDiff = long(nOrgWidth) - long(nCapWidth);
         if( nDiff )
         {
             nDiff *= rInf.GetLen();
-            nDiff /= (long) nStrLen;
+            nDiff /= nStrLen;
             nDiff += nPartWidth;
             if( 0 < nDiff )
-                nPartWidth = sal_uInt16(nDiff);
+                nPartWidth = nDiff;
         }
 
         rInf.ApplyAutoColor();
 
         Point aPos( rInf.GetPos() );
-        const sal_Bool bSwitchL2R = rInf.GetFrm()->IsRightToLeft() &&
-                              ! rInf.IsIgnoreFrmRTL();
+        const bool bSwitchL2R = rInf.GetFrame()->IsRightToLeft() &&
+                              ! rInf.IsIgnoreFrameRTL();
 
         if ( bSwitchL2R )
-            rInf.GetFrm()->SwitchLTRtoRTL( aPos );
+            rInf.GetFrame()->SwitchLTRtoRTL( aPos );
 
-        if ( rInf.GetFrm()->IsVertical() )
-            rInf.GetFrm()->SwitchHorizontalToVertical( aPos );
+        if ( rInf.GetFrame()->IsVertical() )
+            rInf.GetFrame()->SwitchHorizontalToVertical( aPos );
 
-        // Optimierung:
+        // Optimise:
         if( 1 >= rInf.GetLen() )
             GetOut().DrawText( aPos, rInf.GetText(), rInf.GetIdx(),
                 rInf.GetLen() );
@@ -508,76 +439,65 @@ void SwDoDrawStretchCapital::Do()
             GetOut().DrawStretchText( aPos, nPartWidth,
                                 rInf.GetText(), rInf.GetIdx(), rInf.GetLen() );
     }
-    ((Point&)rInf.GetPos()).X() += nPartWidth;
+    const_cast<Point&>(rInf.GetPos()).X() += nPartWidth;
 }
 
-/*************************************************************************
- *                    SwSubFont::DrawStretchCapital()
- *************************************************************************/
-
 void SwSubFont::DrawStretchCapital( SwDrawTextInfo &rInf )
 {
-    // Es wird vorausgesetzt, dass rPos bereits kalkuliert ist!
-    // hochgezogen in SwFont: const Point aPos( CalcPos(rPos) );
+    // Precondition: rInf.GetPos() has already been calculated
 
-    if( rInf.GetLen() == STRING_LEN )
+    if( rInf.GetLen() == COMPLETE_STRING )
         rInf.SetLen( rInf.GetText().getLength() );
 
     const Point aOldPos = rInf.GetPos();
     const sal_uInt16 nCapWidth = (sal_uInt16)( GetCapitalSize( rInf ).Width() );
     rInf.SetPos(aOldPos);
 
-    rInf.SetDrawSpace( GetUnderline() != UNDERLINE_NONE ||
-                       GetOverline()  != UNDERLINE_NONE ||
+    rInf.SetDrawSpace( GetUnderline() != LINESTYLE_NONE ||
+                       GetOverline()  != LINESTYLE_NONE ||
                        GetStrikeout() != STRIKEOUT_NONE );
     SwDoDrawStretchCapital aDo( rInf, nCapWidth );
     DoOnCapitals( aDo );
 }
 
-/*************************************************************************
- *                  SwSubFont::DoOnCapitals() const
- *************************************************************************/
-
 void SwSubFont::DoOnCapitals( SwDoCapitals &rDo )
 {
     OSL_ENSURE( pLastFont, "SwFont::DoOnCapitals: No LastFont?!" );
 
     long nKana = 0;
-    const OUString aTxt( CalcCaseMap( rDo.GetInf().GetText() ) );
-    xub_StrLen nMaxPos = std::min( sal_uInt16(rDo.GetInf().GetText().getLength() - rDo.GetInf().GetIdx()),
+    const OUString aText( CalcCaseMap( rDo.GetInf().GetText() ) );
+    sal_Int32 nMaxPos = std::min( rDo.GetInf().GetText().getLength() - rDo.GetInf().GetIdx(),
                              rDo.GetInf().GetLen() );
     rDo.GetInf().SetLen( nMaxPos );
 
     const OUString oldText = rDo.GetInf().GetText();
-    rDo.GetInf().SetText( aTxt );
-    xub_StrLen nPos = rDo.GetInf().GetIdx();
-    xub_StrLen nOldPos = nPos;
+    rDo.GetInf().SetText( aText );
+    sal_Int32 nPos = rDo.GetInf().GetIdx();
+    sal_Int32 nOldPos = nPos;
     nMaxPos = nMaxPos + nPos;
 
-    // #107816#
     // Look if the length of the original text and the ToUpper-converted
     // text is different. If yes, do special handling.
-    OUString aNewText;
     SwCapitalInfo aCapInf(oldText);
-    sal_Bool bCaseMapLengthDiffers(aTxt.getLength() != oldText.getLength());
+    bool bCaseMapLengthDiffers(aText.getLength() != oldText.getLength());
     if ( bCaseMapLengthDiffers )
         rDo.SetCapInf( aCapInf );
 
     SwFntObj *pOldLast = pLastFont;
-    SwFntAccess *pBigFontAccess = NULL;
+    SwFntAccess *pBigFontAccess = nullptr;
     SwFntObj *pBigFont;
-    SwFntAccess *pSpaceFontAccess = NULL;
-    SwFntObj *pSpaceFont = NULL;
+    SwFntAccess *pSpaceFontAccess = nullptr;
+    SwFntObj *pSpaceFont = nullptr;
 
-    const void *pMagic2 = NULL;
+    const void *pMagic2 = nullptr;
     sal_uInt16 nIndex2 = 0;
     SwSubFont aFont( *this );
     Point aStartPos( rDo.GetInf().GetPos() );
 
-    const sal_Bool bTextLines = aFont.GetUnderline() != UNDERLINE_NONE
-                         || aFont.GetOverline()  != UNDERLINE_NONE
+    const bool bTextLines = aFont.GetUnderline() != LINESTYLE_NONE
+                         || aFont.GetOverline()  != LINESTYLE_NONE
                          || aFont.GetStrikeout() != STRIKEOUT_NONE;
-    const sal_Bool bWordWise = bTextLines && aFont.IsWordLineMode() &&
+    const bool bWordWise = bTextLines && aFont.IsWordLineMode() &&
                            rDo.GetInf().GetDrawSpace();
     const long nTmpKern = rDo.GetInf().GetKern();
 
@@ -585,7 +505,7 @@ void SwSubFont::DoOnCapitals( SwDoCapitals &rDo )
     {
         if ( bWordWise )
         {
-            aFont.SetWordLineMode( sal_False );
+            aFont.SetWordLineMode( false );
             pSpaceFontAccess = new SwFntAccess( pMagic2, nIndex2, &aFont,
                                                 rDo.GetInf().GetShell() );
             pSpaceFont = pSpaceFontAccess->Get();
@@ -593,11 +513,11 @@ void SwSubFont::DoOnCapitals( SwDoCapitals &rDo )
         else
             pSpaceFont = pLastFont;
 
-        // Wir basteln uns einen Font fuer die Grossbuchstaben:
-        aFont.SetUnderline( UNDERLINE_NONE );
-        aFont.SetOverline( UNDERLINE_NONE );
+        // Construct a font for the capitals:
+        aFont.SetUnderline( LINESTYLE_NONE );
+        aFont.SetOverline( LINESTYLE_NONE );
         aFont.SetStrikeout( STRIKEOUT_NONE );
-        pMagic2 = NULL;
+        pMagic2 = nullptr;
         nIndex2 = 0;
         pBigFontAccess = new SwFntAccess( pMagic2, nIndex2, &aFont,
                                           rDo.GetInf().GetShell() );
@@ -611,9 +531,9 @@ void SwSubFont::DoOnCapitals( SwDoCapitals &rDo )
     // NOTE: There are more uses of SMALL_CAPS_PERCENTAGE in editeng, but it seems they
     // do not matter for Writer (and if they did it'd be pretty ugly to propagate
     // the option there).
-    int smallCapsPercentage = smallCapsPercentage66 ? 66 : SMALL_CAPS_PERCENTAGE;
-    aFont.SetProportion( (aFont.GetPropr() * smallCapsPercentage ) / 100L );
-    pMagic2 = NULL;
+    int smallCapsPercentage = m_bSmallCapsPercentage66 ? 66 : SMALL_CAPS_PERCENTAGE;
+    aFont.SetProportion( (aFont.GetPropr() * smallCapsPercentage ) / 100 );
+    pMagic2 = nullptr;
     nIndex2 = 0;
     SwFntAccess *pSmallFontAccess = new SwFntAccess( pMagic2, nIndex2, &aFont,
                                                      rDo.GetInf().GetShell() );
@@ -630,10 +550,10 @@ void SwSubFont::DoOnCapitals( SwDoCapitals &rDo )
 
     if( nPos < nMaxPos )
     {
-        nPos = (xub_StrLen)g_pBreakIt->GetBreakIter()->endOfCharBlock(
+        nPos = g_pBreakIt->GetBreakIter()->endOfCharBlock(
                         oldText, nPos,
             g_pBreakIt->GetLocale( eLng ), CharType::LOWERCASE_LETTER);
-        if( nPos == STRING_LEN )
+        if (nPos < 0)
             nPos = nOldPos;
         else if( nPos > nMaxPos )
             nPos = nMaxPos;
@@ -655,8 +575,7 @@ void SwSubFont::DoOnCapitals( SwDoCapitals &rDo )
                 // Build an own 'changed' string for the given part of the
                 // source string and use it. That new string may differ in length
                 // from the source string.
-                const OUString aSnippet(oldText.copy(nOldPos, nPos - nOldPos));
-                aNewText = CalcCaseMap( aSnippet );
+                const OUString aNewText = CalcCaseMap( oldText.copy(nOldPos, nPos-nOldPos) );
                 aCapInf.nIdx = nOldPos;
                 aCapInf.nLen = nPos - nOldPos;
                 rDo.GetInf().SetIdx( 0 );
@@ -669,7 +588,7 @@ void SwSubFont::DoOnCapitals( SwDoCapitals &rDo )
                 rDo.GetInf().SetLen( nPos - nOldPos );
             }
 
-            rDo.GetInf().SetUpper( sal_False );
+            rDo.GetInf().SetUpper( false );
             rDo.GetInf().SetOut( *pOutSize );
             Size aPartSize = pSmallFont->GetTextSize( rDo.GetInf() );
             nKana += rDo.GetInf().GetKanaDiff();
@@ -680,10 +599,10 @@ void SwSubFont::DoOnCapitals( SwDoCapitals &rDo )
             rDo.Do();
             nOldPos = nPos;
         }
-        nPos = (xub_StrLen)g_pBreakIt->GetBreakIter()->nextCharBlock(
+        nPos = g_pBreakIt->GetBreakIter()->nextCharBlock(
                             oldText, nPos,
                g_pBreakIt->GetLocale( eLng ), CharType::LOWERCASE_LETTER);
-        if( nPos == STRING_LEN || nPos > nMaxPos )
+        if (nPos < 0 || nPos > nMaxPos)
             nPos = nMaxPos;
         OSL_ENSURE( nPos, "nextCharBlock not implemented?" );
 #if OSL_DEBUG_LEVEL > 1
@@ -697,10 +616,10 @@ void SwSubFont::DoOnCapitals( SwDoCapitals &rDo )
 
             do
             {
-                rDo.GetInf().SetUpper( sal_True );
+                rDo.GetInf().SetUpper( true );
                 pLastFont = pBigFont;
                 pLastFont->SetDevFont( rDo.GetInf().GetShell(), rDo.GetOut() );
-                xub_StrLen nTmp;
+                sal_Int32 nTmp;
                 if( bWordWise )
                 {
                     nTmp = nOldPos;
@@ -711,7 +630,7 @@ void SwSubFont::DoOnCapitals( SwDoCapitals &rDo )
                         pLastFont = pSpaceFont;
                         pLastFont->SetDevFont( rDo.GetInf().GetShell(),
                                                rDo.GetOut() );
-                        ((SwDoDrawCapital&)rDo).DrawSpace( aStartPos );
+                        static_cast<SwDoDrawCapital&>(rDo).DrawSpace( aStartPos );
                         pLastFont = pBigFont;
                         pLastFont->SetDevFont( rDo.GetInf().GetShell(),
                                                rDo.GetOut() );
@@ -722,8 +641,7 @@ void SwSubFont::DoOnCapitals( SwDoCapitals &rDo )
                             // Build an own 'changed' string for the given part of the
                             // source string and use it. That new string may differ in length
                             // from the source string.
-                            const OUString aSnippet(oldText.copy(nOldPos, nTmp - nOldPos));
-                            aNewText = CalcCaseMap( aSnippet );
+                            const OUString aNewText = CalcCaseMap( oldText.copy(nOldPos, nTmp-nOldPos) );
                             aCapInf.nIdx = nOldPos;
                             aCapInf.nLen = nTmp - nOldPos;
                             rDo.GetInf().SetIdx( 0 );
@@ -763,8 +681,7 @@ void SwSubFont::DoOnCapitals( SwDoCapitals &rDo )
                         // Build an own 'changed' string for the given part of the
                         // source string and use it. That new string may differ in length
                         // from the source string.
-                        const OUString aSnippet(oldText.copy(nOldPos, nTmp - nOldPos));
-                        aNewText = CalcCaseMap( aSnippet );
+                        const OUString aNewText = CalcCaseMap( oldText.copy(nOldPos, nTmp-nOldPos) );
                         aCapInf.nIdx = nOldPos;
                         aCapInf.nLen = nTmp - nOldPos;
                         rDo.GetInf().SetIdx( 0 );
@@ -797,10 +714,10 @@ void SwSubFont::DoOnCapitals( SwDoCapitals &rDo )
                 }
             } while( nOldPos != nPos );
         }
-        nPos = (xub_StrLen)g_pBreakIt->GetBreakIter()->endOfCharBlock(
+        nPos = g_pBreakIt->GetBreakIter()->endOfCharBlock(
                             oldText, nPos,
                g_pBreakIt->GetLocale( eLng ), CharType::LOWERCASE_LETTER);
-        if( nPos == STRING_LEN || nPos > nMaxPos )
+        if (nPos < 0 || nPos > nMaxPos)
             nPos = nMaxPos;
         OSL_ENSURE( nPos, "endOfCharBlock not implemented?" );
 #if OSL_DEBUG_LEVEL > 1
@@ -809,7 +726,7 @@ void SwSubFont::DoOnCapitals( SwDoCapitals &rDo )
 #endif
     }
 
-    // Aufraeumen:
+    // clean up:
     if( pBigFont != pOldLast )
         delete pBigFontAccess;
 
@@ -819,7 +736,7 @@ void SwSubFont::DoOnCapitals( SwDoCapitals &rDo )
         {
             pLastFont = pSpaceFont;
             pLastFont->SetDevFont( rDo.GetInf().GetShell(), rDo.GetOut() );
-            ( (SwDoDrawCapital&) rDo ).DrawSpace( aStartPos );
+            static_cast<SwDoDrawCapital&>( rDo ).DrawSpace( aStartPos );
         }
         if ( bWordWise )
             delete pSpaceFontAccess;
