@@ -17,7 +17,6 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include <tools/resid.hxx>
 #include <doc.hxx>
 #include <IDocumentUndoRedo.hxx>
 #include <swundo.hxx>
@@ -25,7 +24,7 @@
 #include <SwUndoPageDesc.hxx>
 #include <SwRewriter.hxx>
 #include <undobj.hxx>
-#include <comcore.hrc>
+#include <strings.hrc>
 #include <fmtcntnt.hxx>
 #include <fmthdft.hxx>
 
@@ -100,8 +99,9 @@ SwUndoPageDesc::SwUndoPageDesc(const SwPageDesc & _aOld,
                                const SwPageDesc & _aNew,
                                SwDoc * _pDoc)
     : SwUndo( _aOld.GetName() != _aNew.GetName() ?
-              UNDO_RENAME_PAGEDESC :
-              UNDO_CHANGE_PAGEDESC ),
+              SwUndoId::RENAME_PAGEDESC :
+              SwUndoId::CHANGE_PAGEDESC,
+              _pDoc ),
       aOld(_aOld, _pDoc), aNew(_aNew, _pDoc), pDoc(_pDoc), bExchange( false )
 {
     OSL_ENSURE(nullptr != pDoc, "no document?");
@@ -147,17 +147,20 @@ SwUndoPageDesc::SwUndoPageDesc(const SwPageDesc & _aOld,
             SwFrameFormat* pFormat = new SwFrameFormat( *rNewHead.GetHeaderFormat() );
             // The Ctor of this object will remove the duplicate!
             SwFormatHeader aFormatHeader(pFormat);
+            (void)aFormatHeader;
             if (!rNewDesc.IsHeaderShared())
             {
                 pFormat = new SwFrameFormat( *rNewDesc.GetLeft().GetHeader().GetHeaderFormat() );
                 // The Ctor of this object will remove the duplicate!
                 SwFormatHeader aLeftHeader(pFormat);
+                (void)aLeftHeader;
             }
             if (!rNewDesc.IsFirstShared())
             {
                 pFormat = new SwFrameFormat( *rNewDesc.GetFirstMaster().GetHeader().GetHeaderFormat() );
                 // The Ctor of this object will remove the duplicate!
                 SwFormatHeader aFirstHeader(pFormat);
+                (void)aFirstHeader;
             }
         }
         // Same procedure for footers...
@@ -166,17 +169,20 @@ SwUndoPageDesc::SwUndoPageDesc(const SwPageDesc & _aOld,
             SwFrameFormat* pFormat = new SwFrameFormat( *rNewFoot.GetFooterFormat() );
             // The Ctor of this object will remove the duplicate!
             SwFormatFooter aFormatFooter(pFormat);
+            (void)aFormatFooter;
             if (!rNewDesc.IsFooterShared())
             {
                 pFormat = new SwFrameFormat( *rNewDesc.GetLeft().GetFooter().GetFooterFormat() );
                 // The Ctor of this object will remove the duplicate!
                 SwFormatFooter aLeftFooter(pFormat);
+                (void)aLeftFooter;
             }
             if (!rNewDesc.IsFirstShared())
             {
                 pFormat = new SwFrameFormat( *rNewDesc.GetFirstMaster().GetFooter().GetFooterFormat() );
                 // The Ctor of this object will remove the duplicate!
                 SwFormatFooter aFirstFooter(pFormat);
+                (void)aFirstFooter;
             }
         }
 
@@ -270,70 +276,72 @@ void SwUndoPageDesc::ExchangeContentNodes( SwPageDesc& rSource, SwPageDesc &rDes
     // Same procedure for footers...
     const SwFormatFooter& rDestFoot = rDest.GetMaster().GetFooter();
     const SwFormatFooter& rSourceFoot = rSource.GetMaster().GetFooter();
-    if( rDestFoot.IsActive() )
-    {
-        const SfxPoolItem* pItem;
-        rDest.GetMaster().GetAttrSet().GetItemState( RES_FOOTER, false, &pItem );
-        SfxPoolItem *pNewItem = pItem->Clone();
-        SwFrameFormat *pNewFormat = static_cast<SwFormatFooter*>(pNewItem)->GetFooterFormat();
-        pNewFormat->SetFormatAttr( rSourceFoot.GetFooterFormat()->GetContent() );
-        delete pNewItem;
+    if( !rDestFoot.IsActive() )
+        return;
+
+    const SfxPoolItem* pItem;
+    rDest.GetMaster().GetAttrSet().GetItemState( RES_FOOTER, false, &pItem );
+    SfxPoolItem *pNewItem = pItem->Clone();
+    SwFrameFormat *pNewFormat = static_cast<SwFormatFooter*>(pNewItem)->GetFooterFormat();
+    pNewFormat->SetFormatAttr( rSourceFoot.GetFooterFormat()->GetContent() );
+    delete pNewItem;
 
 #if OSL_DEBUG_LEVEL > 1
-        const SwFormatContent& rFooterSourceContent = rSourceFoot.GetFooterFormat()->GetContent();
-        (void)rFooterSourceContent;
-        const SwFormatContent& rFooterDestContent = rDestFoot.GetFooterFormat()->GetContent();
-        (void)rFooterDestContent;
+    const SwFormatContent& rFooterSourceContent = rSourceFoot.GetFooterFormat()->GetContent();
+    (void)rFooterSourceContent;
+    const SwFormatContent& rFooterDestContent = rDestFoot.GetFooterFormat()->GetContent();
+    (void)rFooterDestContent;
 #endif
-        rSource.GetMaster().GetAttrSet().GetItemState( RES_FOOTER, false, &pItem );
+    rSource.GetMaster().GetAttrSet().GetItemState( RES_FOOTER, false, &pItem );
+    pNewItem = pItem->Clone();
+    pNewFormat = static_cast<SwFormatFooter*>(pNewItem)->GetFooterFormat();
+    pNewFormat->SetFormatAttr( SwFormatContent() );
+    delete pNewItem;
+
+    if( !rDest.IsFooterShared() )
+    {
+        const SwFormatFooter& rSourceLeftFoot = rSource.GetLeft().GetFooter();
+#if OSL_DEBUG_LEVEL > 1
+        const SwFormatContent& rFooterSourceContent2 = rSourceLeftFoot.GetFooterFormat()->GetContent();
+        const SwFormatContent& rFooterDestContent2 =
+            rDest.GetLeft().GetFooter().GetFooterFormat()->GetContent();
+        (void)rFooterSourceContent2;
+        (void)rFooterDestContent2;
+#endif
+        rDest.GetLeft().GetAttrSet().GetItemState( RES_FOOTER, false, &pItem );
+        pNewItem = pItem->Clone();
+        pNewFormat = static_cast<SwFormatFooter*>(pNewItem)->GetFooterFormat();
+        pNewFormat->SetFormatAttr( rSourceLeftFoot.GetFooterFormat()->GetContent() );
+        delete pNewItem;
+        rSource.GetLeft().GetAttrSet().GetItemState( RES_FOOTER, false, &pItem );
         pNewItem = pItem->Clone();
         pNewFormat = static_cast<SwFormatFooter*>(pNewItem)->GetFooterFormat();
         pNewFormat->SetFormatAttr( SwFormatContent() );
         delete pNewItem;
-
-        if( !rDest.IsFooterShared() )
-        {
-            const SwFormatFooter& rSourceLeftFoot = rSource.GetLeft().GetFooter();
-#if OSL_DEBUG_LEVEL > 1
-            const SwFormatContent& rFooterSourceContent2 = rSourceLeftFoot.GetFooterFormat()->GetContent();
-            const SwFormatContent& rFooterDestContent2 =
-                rDest.GetLeft().GetFooter().GetFooterFormat()->GetContent();
-            (void)rFooterSourceContent2;
-            (void)rFooterDestContent2;
-#endif
-            rDest.GetLeft().GetAttrSet().GetItemState( RES_FOOTER, false, &pItem );
-            pNewItem = pItem->Clone();
-            pNewFormat = static_cast<SwFormatFooter*>(pNewItem)->GetFooterFormat();
-            pNewFormat->SetFormatAttr( rSourceLeftFoot.GetFooterFormat()->GetContent() );
-            delete pNewItem;
-            rSource.GetLeft().GetAttrSet().GetItemState( RES_FOOTER, false, &pItem );
-            pNewItem = pItem->Clone();
-            pNewFormat = static_cast<SwFormatFooter*>(pNewItem)->GetFooterFormat();
-            pNewFormat->SetFormatAttr( SwFormatContent() );
-            delete pNewItem;
-        }
-        if (!rDest.IsFirstShared())
-        {
-            const SwFormatFooter& rSourceFirstMasterFoot = rSource.GetFirstMaster().GetFooter();
-#if OSL_DEBUG_LEVEL > 1
-            const SwFormatContent& rFooterSourceContent2 = rSourceFirstMasterFoot.GetFooterFormat()->GetContent();
-            const SwFormatContent& rFooterDestContent2 =
-                rDest.GetFirstMaster().GetFooter().GetFooterFormat()->GetContent();
-            (void)rFooterSourceContent2;
-            (void)rFooterDestContent2;
-#endif
-            rDest.GetFirstMaster().GetAttrSet().GetItemState( RES_FOOTER, false, &pItem );
-            pNewItem = pItem->Clone();
-            pNewFormat = static_cast<SwFormatFooter*>(pNewItem)->GetFooterFormat();
-            pNewFormat->SetFormatAttr( rSourceFirstMasterFoot.GetFooterFormat()->GetContent() );
-            delete pNewItem;
-            rSource.GetFirstMaster().GetAttrSet().GetItemState( RES_FOOTER, false, &pItem );
-            pNewItem = pItem->Clone();
-            pNewFormat = static_cast<SwFormatFooter*>(pNewItem)->GetFooterFormat();
-            pNewFormat->SetFormatAttr( SwFormatContent() );
-            delete pNewItem;
-        }
     }
+    if (rDest.IsFirstShared())
+        return;
+
+    const SwFormatFooter& rSourceFirstMasterFoot = rSource.GetFirstMaster().GetFooter();
+#if OSL_DEBUG_LEVEL > 1
+    const SwFormatContent& rFooterSourceContent2 = rSourceFirstMasterFoot.GetFooterFormat()->GetContent();
+    const SwFormatContent& rFooterDestContent2 =
+        rDest.GetFirstMaster().GetFooter().GetFooterFormat()->GetContent();
+    (void)rFooterSourceContent2;
+    (void)rFooterDestContent2;
+#endif
+    rDest.GetFirstMaster().GetAttrSet().GetItemState( RES_FOOTER, false, &pItem );
+    pNewItem = pItem->Clone();
+    pNewFormat = static_cast<SwFormatFooter*>(pNewItem)->GetFooterFormat();
+    pNewFormat->SetFormatAttr( rSourceFirstMasterFoot.GetFooterFormat()->GetContent() );
+    delete pNewItem;
+    rSource.GetFirstMaster().GetAttrSet().GetItemState( RES_FOOTER, false, &pItem );
+    pNewItem = pItem->Clone();
+    pNewFormat = static_cast<SwFormatFooter*>(pNewItem)->GetFooterFormat();
+    pNewFormat->SetFormatAttr( SwFormatContent() );
+    delete pNewItem;
+
+
 }
 
 void SwUndoPageDesc::UndoImpl(::sw::UndoRedoContext &)
@@ -357,7 +365,7 @@ SwRewriter SwUndoPageDesc::GetRewriter() const
     SwRewriter aResult;
 
     aResult.AddRule(UndoArg1, aOld.GetName());
-    aResult.AddRule(UndoArg2, SW_RESSTR(STR_YIELDS));
+    aResult.AddRule(UndoArg2, SwResId(STR_YIELDS));
     aResult.AddRule(UndoArg3, aNew.GetName());
 
     return aResult;
@@ -365,7 +373,7 @@ SwRewriter SwUndoPageDesc::GetRewriter() const
 
 SwUndoPageDescCreate::SwUndoPageDescCreate(const SwPageDesc * pNew,
                                            SwDoc * _pDoc)
-    : SwUndo(UNDO_CREATE_PAGEDESC), pDesc(pNew), aNew(*pNew, _pDoc),
+    : SwUndo(SwUndoId::CREATE_PAGEDESC, _pDoc), pDesc(pNew), aNew(*pNew, _pDoc),
       pDoc(_pDoc)
 {
     OSL_ENSURE(nullptr != pDoc, "no document?");
@@ -417,7 +425,7 @@ SwRewriter SwUndoPageDescCreate::GetRewriter() const
 
 SwUndoPageDescDelete::SwUndoPageDescDelete(const SwPageDesc & _aOld,
                                            SwDoc * _pDoc)
-    : SwUndo(UNDO_DELETE_PAGEDESC), aOld(_aOld, _pDoc), pDoc(_pDoc)
+    : SwUndo(SwUndoId::DELETE_PAGEDESC, _pDoc), aOld(_aOld, _pDoc), pDoc(_pDoc)
 {
     OSL_ENSURE(nullptr != pDoc, "no document?");
 }
