@@ -54,7 +54,7 @@
 #include <fmtfld.hxx>
 #include <fmtpdsc.hxx>
 #include <pagedesc.hxx>
-#include <poolfmt.hrc>
+#include <strings.hrc>
 #include <poolfmt.hxx>
 #include <edimp.hxx>
 #include <fchrfmt.hxx>
@@ -96,7 +96,6 @@
 #include <com/sun/star/drawing/XDrawPageSupplier.hpp>
 #include <unoframe.hxx>
 #include <fmthdft.hxx>
-#include <osl/mutex.hxx>
 #include <vcl/svapp.hxx>
 #include <fmtflcnt.hxx>
 #include <editeng/brushitem.hxx>
@@ -167,7 +166,7 @@ namespace
 {
     void lcl_CollectFrameAtNodeWithLayout(const SwContentFrame* pCFrame,
             FrameClientSortList_t& rFrames,
-            const sal_uInt16 nAnchorType)
+            const RndStdIds nAnchorType)
     {
         auto pObjs = pCFrame->GetDrawObjs();
         if(!pObjs)
@@ -202,8 +201,7 @@ void CollectFrameAtNode( const SwNodeIndex& rIdx,
     // search all borders, images, and OLEs that are connected to the paragraph
     SwDoc* pDoc = rIdx.GetNode().GetDoc();
 
-    const auto nChkType = static_cast< sal_uInt16 >((bAtCharAnchoredObjs)
-            ? FLY_AT_CHAR : FLY_AT_PARA);
+    const auto nChkType = bAtCharAnchoredObjs ? RndStdIds::FLY_AT_CHAR : RndStdIds::FLY_AT_PARA;
     const SwContentFrame* pCFrame;
     const SwContentNode* pCNd;
     if( pDoc->getIDocumentLayoutAccess().GetCurrentViewShell() &&
@@ -249,7 +247,7 @@ UnoActionContext::UnoActionContext(SwDoc *const pDoc)
     }
 }
 
-UnoActionContext::~UnoActionContext()
+UnoActionContext::~UnoActionContext() COVERITY_NOEXCEPT_FALSE
 {
     // Doc may already have been removed here
     if (m_pDoc)
@@ -338,19 +336,19 @@ void SwUnoCursorHelper::SetCursorAttr(SwPaM & rPam,
     UnoActionContext aAction(pDoc);
     if (rPam.GetNext() != &rPam)    // Ring of Cursors
     {
-        pDoc->GetIDocumentUndoRedo().StartUndo(UNDO_INSATTR, nullptr);
+        pDoc->GetIDocumentUndoRedo().StartUndo(SwUndoId::INSATTR, nullptr);
 
         for(SwPaM& rCurrent : rPam.GetRingContainer())
         {
             if (rCurrent.HasMark() &&
-                ( (bTableMode) ||
+                ( bTableMode ||
                   (*rCurrent.GetPoint() != *rCurrent.GetMark()) ))
             {
                 pDoc->getIDocumentContentOperations().InsertItemSet(rCurrent, rSet, nFlags);
             }
         }
 
-        pDoc->GetIDocumentUndoRedo().EndUndo(UNDO_INSATTR, nullptr);
+        pDoc->GetIDocumentUndoRedo().EndUndo(SwUndoId::INSATTR, nullptr);
     }
     else
     {
@@ -397,7 +395,7 @@ void SwUnoCursorHelper::GetCursorAttr(SwPaM & rPam,
             SwNode *const pNd = rPam.GetDoc()->GetNodes()[ n ];
             switch (pNd->GetNodeType())
             {
-                case ND_TEXTNODE:
+                case SwNodeType::Text:
                 {
                     const sal_Int32 nStart = (n == nSttNd)
                         ? rStart.nContent.GetIndex() : 0;
@@ -408,8 +406,8 @@ void SwUnoCursorHelper::GetCursorAttr(SwPaM & rPam,
                 }
                 break;
 
-                case ND_GRFNODE:
-                case ND_OLENODE:
+                case SwNodeType::Grf:
+                case SwNodeType::Ole:
                     static_cast<SwContentNode*>(pNd)->GetAttr( *pSet );
                 break;
 
@@ -470,13 +468,13 @@ struct SwXParagraphEnumerationImpl final : public SwXParagraphEnumeration
         , m_pCursor(pCursor)
     {
         OSL_ENSURE(m_xParentText.is(), "SwXParagraphEnumeration: no parent?");
-        OSL_ENSURE(   !((CURSOR_SELECTION_IN_TABLE == eType) ||
-                        (CURSOR_TBLTEXT == eType))
+        OSL_ENSURE(   !((CursorType::SelectionInTable == eType) ||
+                        (CursorType::TableText == eType))
                    || (m_pOwnTable && m_pOwnStartNode),
             "SwXParagraphEnumeration: table type but no start node or table?");
 
-        if ((CURSOR_SELECTION == m_eCursorType) ||
-            (CURSOR_SELECTION_IN_TABLE == m_eCursorType))
+        if ((CursorType::Selection == m_eCursorType) ||
+            (CursorType::SelectionInTable == m_eCursorType))
         {
             SwUnoCursor & rCursor = GetCursor();
             rCursor.Normalize();
@@ -495,21 +493,23 @@ struct SwXParagraphEnumerationImpl final : public SwXParagraphEnumeration
     }
 
     // XServiceInfo
-    virtual OUString SAL_CALL getImplementationName() throw (css::uno::RuntimeException, std::exception) override
+    virtual OUString SAL_CALL getImplementationName() override
         { return OUString("SwXParagraphEnumeration"); }
-    virtual sal_Bool SAL_CALL supportsService( const OUString& rServiceName) throw (css::uno::RuntimeException, std::exception) override
+    virtual sal_Bool SAL_CALL supportsService( const OUString& rServiceName) override
         { return cppu::supportsService(this, rServiceName); };
-    virtual css::uno::Sequence< OUString > SAL_CALL getSupportedServiceNames() throw (css::uno::RuntimeException, std::exception) override
+    virtual css::uno::Sequence< OUString > SAL_CALL getSupportedServiceNames() override
         { return {"com.sun.star.text.ParagraphEnumeration"}; };
 
     // XEnumeration
-    virtual sal_Bool SAL_CALL hasMoreElements() throw (css::uno::RuntimeException, std::exception) override;
-    virtual css::uno::Any SAL_CALL nextElement() throw (css::container::NoSuchElementException, css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception) override;
+    virtual sal_Bool SAL_CALL hasMoreElements() override;
+    virtual css::uno::Any SAL_CALL nextElement() override;
 
     SwUnoCursor& GetCursor()
         { return *m_pCursor; }
-    uno::Reference< text::XTextContent > NextElement_Impl()
-        throw (container::NoSuchElementException, lang::WrappedTargetException, uno::RuntimeException);
+    /// @throws container::NoSuchElementException
+    /// @throws lang::WrappedTargetException
+    /// @throws uno::RuntimeException
+    uno::Reference< text::XTextContent > NextElement_Impl();
 };
 
 SwXParagraphEnumeration* SwXParagraphEnumeration::Create(
@@ -523,7 +523,7 @@ SwXParagraphEnumeration* SwXParagraphEnumeration::Create(
 }
 
 sal_Bool SAL_CALL
-SwXParagraphEnumerationImpl::hasMoreElements() throw (uno::RuntimeException, std::exception)
+SwXParagraphEnumerationImpl::hasMoreElements()
 {
     SolarMutexGuard aGuard;
     return m_bFirstParagraph || m_xNextPara.is();
@@ -564,20 +564,20 @@ lcl_CursorIsInSection(
 }
 
 uno::Reference< text::XTextContent >
-SwXParagraphEnumerationImpl::NextElement_Impl() throw (container::NoSuchElementException, lang::WrappedTargetException, uno::RuntimeException)
+SwXParagraphEnumerationImpl::NextElement_Impl()
 {
     SwUnoCursor& rUnoCursor = GetCursor();
 
     // check for exceeding selections
     if (!m_bFirstParagraph &&
-        ((CURSOR_SELECTION == m_eCursorType) ||
-         (CURSOR_SELECTION_IN_TABLE == m_eCursorType)))
+        ((CursorType::Selection == m_eCursorType) ||
+         (CursorType::SelectionInTable == m_eCursorType)))
     {
         SwPosition* pStart = rUnoCursor.Start();
         auto aNewCursor(rUnoCursor.GetDoc()->CreateUnoCursor(*pStart));
         // one may also go into tables here
-        if ((CURSOR_TBLTEXT != m_eCursorType) &&
-            (CURSOR_SELECTION_IN_TABLE != m_eCursorType))
+        if ((CursorType::TableText != m_eCursorType) &&
+            (CursorType::SelectionInTable != m_eCursorType))
         {
             aNewCursor->SetRemainInSection( false );
         }
@@ -585,8 +585,8 @@ SwXParagraphEnumerationImpl::NextElement_Impl() throw (container::NoSuchElementE
         // os 2005-01-14: This part is only necessary to detect movements out
         // of a selection; if there is no selection we don't have to care
         SwTableNode *const pTableNode = aNewCursor->GetNode().FindTableNode();
-        if (((CURSOR_TBLTEXT != m_eCursorType) &&
-            (CURSOR_SELECTION_IN_TABLE != m_eCursorType)) && pTableNode)
+        if (((CursorType::TableText != m_eCursorType) &&
+            (CursorType::SelectionInTable != m_eCursorType)) && pTableNode)
         {
             aNewCursor->GetPoint()->nNode = pTableNode->EndOfSectionIndex();
             aNewCursor->Move(fnMoveForward, GoInNode);
@@ -637,7 +637,7 @@ SwXParagraphEnumerationImpl::NextElement_Impl() throw (container::NoSuchElementE
         // position in a table, or in a simple paragraph?
         SwTableNode * pTableNode = rUnoCursor.GetNode().FindTableNode();
         pTableNode = lcl_FindTopLevelTable( pTableNode, m_pOwnTable );
-        if (/*CURSOR_TBLTEXT != eCursorType && CURSOR_SELECTION_IN_TABLE != eCursorType && */
+        if (/*CursorType::TableText != eCursorType && CursorType::SelectionInTable != eCursorType && */
             pTableNode && (&pTableNode->GetTable() != m_pOwnTable))
         {
             // this is a foreign table
@@ -657,7 +657,7 @@ SwXParagraphEnumerationImpl::NextElement_Impl() throw (container::NoSuchElementE
     return xRef;
 }
 
-uno::Any SAL_CALL SwXParagraphEnumerationImpl::nextElement() throw (container::NoSuchElementException, lang::WrappedTargetException, uno::RuntimeException, std::exception)
+uno::Any SAL_CALL SwXParagraphEnumerationImpl::nextElement()
 {
     SolarMutexGuard aGuard;
     if (m_bFirstParagraph)
@@ -750,7 +750,7 @@ void SwXTextRange::Impl::Modify(const SfxPoolItem *pOld, const SfxPoolItem *pNew
     }
 }
 
-SwXTextRange::SwXTextRange(SwPaM& rPam,
+SwXTextRange::SwXTextRange(SwPaM const & rPam,
         const uno::Reference< text::XText > & xParent,
         const enum RangePosition eRange)
     : m_pImpl( new SwXTextRange::Impl(*rPam.GetDoc(), eRange, nullptr, xParent) )
@@ -794,13 +794,12 @@ void SwXTextRange::SetPositions(const SwPaM& rPam)
     m_pImpl->Invalidate();
     IDocumentMarkAccess* const pMA = m_pImpl->m_rDoc.getIDocumentMarkAccess();
     m_pImpl->m_pMark = pMA->makeMark(rPam, OUString(),
-                IDocumentMarkAccess::MarkType::UNO_BOOKMARK);
+        IDocumentMarkAccess::MarkType::UNO_BOOKMARK, sw::mark::InsertMode::New);
     m_pImpl->m_pMark->Add(m_pImpl.get());
 }
 
 void SwXTextRange::DeleteAndInsert(
         const OUString& rText, const bool bForceExpandHints)
-throw (uno::RuntimeException)
 {
     if (RANGE_IS_TABLE == m_pImpl->m_eRangePosition)
     {
@@ -813,7 +812,7 @@ throw (uno::RuntimeException)
     if (GetPositions(aCursor))
     {
         UnoActionContext aAction(& m_pImpl->m_rDoc);
-        m_pImpl->m_rDoc.GetIDocumentUndoRedo().StartUndo(UNDO_INSERT, nullptr);
+        m_pImpl->m_rDoc.GetIDocumentUndoRedo().StartUndo(SwUndoId::INSERT, nullptr);
         if (aCursor.HasMark())
         {
             m_pImpl->m_rDoc.getIDocumentContentOperations().DeleteAndJoin(aCursor);
@@ -828,7 +827,7 @@ throw (uno::RuntimeException)
             aCursor.Left(rText.getLength());
         }
         SetPositions(aCursor);
-        m_pImpl->m_rDoc.GetIDocumentUndoRedo().EndUndo(UNDO_INSERT, nullptr);
+        m_pImpl->m_rDoc.GetIDocumentUndoRedo().EndUndo(SwUndoId::INSERT, nullptr);
     }
 }
 
@@ -845,13 +844,12 @@ const uno::Sequence< sal_Int8 > & SwXTextRange::getUnoTunnelId()
 // XUnoTunnel
 sal_Int64 SAL_CALL
 SwXTextRange::getSomething(const uno::Sequence< sal_Int8 >& rId)
-throw (uno::RuntimeException, std::exception)
 {
     return ::sw::UnoTunnelImpl<SwXTextRange>(rId, this);
 }
 
 OUString SAL_CALL
-SwXTextRange::getImplementationName() throw (uno::RuntimeException, std::exception)
+SwXTextRange::getImplementationName()
 {
     return OUString("SwXTextRange");
 }
@@ -870,20 +868,19 @@ static char const*const g_ServicesTextRange[] =
 static const size_t g_nServicesTextRange(SAL_N_ELEMENTS(g_ServicesTextRange));
 
 sal_Bool SAL_CALL SwXTextRange::supportsService(const OUString& rServiceName)
-throw (uno::RuntimeException, std::exception)
 {
     return cppu::supportsService(this, rServiceName);
 }
 
 uno::Sequence< OUString > SAL_CALL
-SwXTextRange::getSupportedServiceNames() throw (uno::RuntimeException, std::exception)
+SwXTextRange::getSupportedServiceNames()
 {
     return ::sw::GetSupportedServiceNamesImpl(
             g_nServicesTextRange, g_ServicesTextRange);
 }
 
 uno::Reference< text::XText > SAL_CALL
-SwXTextRange::getText() throw (uno::RuntimeException, std::exception)
+SwXTextRange::getText()
 {
     SolarMutexGuard aGuard;
 
@@ -906,7 +903,7 @@ SwXTextRange::getText() throw (uno::RuntimeException, std::exception)
 }
 
 uno::Reference< text::XTextRange > SAL_CALL
-SwXTextRange::getStart() throw (uno::RuntimeException, std::exception)
+SwXTextRange::getStart()
 {
     SolarMutexGuard aGuard;
 
@@ -934,7 +931,7 @@ SwXTextRange::getStart() throw (uno::RuntimeException, std::exception)
 }
 
 uno::Reference< text::XTextRange > SAL_CALL
-SwXTextRange::getEnd() throw (uno::RuntimeException, std::exception)
+SwXTextRange::getEnd()
 {
     SolarMutexGuard aGuard;
 
@@ -961,7 +958,7 @@ SwXTextRange::getEnd() throw (uno::RuntimeException, std::exception)
     return xRet;
 }
 
-OUString SAL_CALL SwXTextRange::getString() throw (uno::RuntimeException, std::exception)
+OUString SAL_CALL SwXTextRange::getString()
 {
     SolarMutexGuard aGuard;
 
@@ -977,7 +974,6 @@ OUString SAL_CALL SwXTextRange::getString() throw (uno::RuntimeException, std::e
 }
 
 void SAL_CALL SwXTextRange::setString(const OUString& rString)
-throw (uno::RuntimeException, std::exception)
 {
     SolarMutexGuard aGuard;
 
@@ -1053,10 +1049,10 @@ bool XTextRangeToSwPaM( SwUnoInternalPaM & rToFill,
         }
         else
         {
-            SwDoc* const pDoc = (pCursor) ? pCursor->GetDoc()
-                : ((pPortion) ? pPortion->GetCursor().GetDoc() : nullptr);
-            const SwPaM* const pUnoCursor = (pCursor) ? pCursor->GetPaM()
-                : ((pPortion) ? &pPortion->GetCursor() : nullptr);
+            SwDoc* const pDoc = pCursor ? pCursor->GetDoc()
+                : (pPortion ? pPortion->GetCursor().GetDoc() : nullptr);
+            const SwPaM* const pUnoCursor = pCursor ? pCursor->GetPaM()
+                : (pPortion ? &pPortion->GetCursor() : nullptr);
             if (pUnoCursor && pDoc == rToFill.GetDoc())
             {
                 OSL_ENSURE(!pUnoCursor->IsMultiSelection(),
@@ -1077,7 +1073,7 @@ bool XTextRangeToSwPaM( SwUnoInternalPaM & rToFill,
 }
 
 static bool
-lcl_IsStartNodeInFormat(const bool bHeader, SwStartNode *const pSttNode,
+lcl_IsStartNodeInFormat(const bool bHeader, SwStartNode const *const pSttNode,
     SwFrameFormat const*const pFrameFormat, SwFrameFormat*& rpFormat)
 {
     bool bRet = false;
@@ -1088,7 +1084,7 @@ lcl_IsStartNodeInFormat(const bool bHeader, SwStartNode *const pSttNode,
             true, &pItem))
     {
         SfxPoolItem *const pItemNonConst(const_cast<SfxPoolItem *>(pItem));
-        SwFrameFormat *const pHeadFootFormat = (bHeader) ?
+        SwFrameFormat *const pHeadFootFormat = bHeader ?
             static_cast<SwFormatHeader*>(pItemNonConst)->GetHeaderFormat() :
             static_cast<SwFormatFooter*>(pItemNonConst)->GetFooterFormat();
         if (pHeadFootFormat)
@@ -1096,7 +1092,7 @@ lcl_IsStartNodeInFormat(const bool bHeader, SwStartNode *const pSttNode,
             const SwFormatContent& rFlyContent = pHeadFootFormat->GetContent();
             const SwNode& rNode = rFlyContent.GetContentIdx()->GetNode();
             SwStartNode const*const pCurSttNode = rNode.FindSttNodeByType(
-                (bHeader) ? SwHeaderStartNode : SwFooterStartNode);
+                bHeader ? SwHeaderStartNode : SwFooterStartNode);
             if (pCurSttNode && (pCurSttNode == pSttNode))
             {
                 rpFormat = pHeadFootFormat;
@@ -1149,7 +1145,7 @@ CreateParentXText(SwDoc & rDoc, const SwPosition& rPos)
                 static_cast<SwFrameFormat*>(pTableNode->GetTable().GetFrameFormat());
             SwTableBox *const  pBox = pSttNode->GetTableBox();
 
-            xParentText = (pBox)
+            xParentText = pBox
                 ? SwXCell::CreateXCell( pTableFormat, pBox )
                 : new SwXCell( pTableFormat, *pSttNode );
         }
@@ -1194,7 +1190,6 @@ CreateParentXText(SwDoc & rDoc, const SwPosition& rPos)
         case SwFootnoteStartNode:
         {
             const size_t nFootnoteCnt = rDoc.GetFootnoteIdxs().size();
-            uno::Reference< text::XFootnote >  xRef;
             for (size_t n = 0; n < nFootnoteCnt; ++n )
             {
                 const SwTextFootnote* pTextFootnote = rDoc.GetFootnoteIdxs()[ n ];
@@ -1235,7 +1230,6 @@ CreateParentXText(SwDoc & rDoc, const SwPosition& rPos)
 
 uno::Reference< container::XEnumeration > SAL_CALL
 SwXTextRange::createContentEnumeration(const OUString& rServiceName)
-throw (uno::RuntimeException, std::exception)
 {
     SolarMutexGuard g;
 
@@ -1259,7 +1253,7 @@ throw (uno::RuntimeException, std::exception)
 }
 
 uno::Reference< container::XEnumeration > SAL_CALL
-SwXTextRange::createEnumeration() throw (uno::RuntimeException, std::exception)
+SwXTextRange::createEnumeration()
 {
     SolarMutexGuard g;
 
@@ -1279,29 +1273,29 @@ SwXTextRange::createEnumeration() throw (uno::RuntimeException, std::exception)
     }
 
     const CursorType eSetType = (RANGE_IN_CELL == m_pImpl->m_eRangePosition)
-            ? CURSOR_SELECTION_IN_TABLE : CURSOR_SELECTION;
+            ? CursorType::SelectionInTable : CursorType::Selection;
     return SwXParagraphEnumeration::Create(m_pImpl->m_xParentText, pNewCursor, eSetType);
 }
 
-uno::Type SAL_CALL SwXTextRange::getElementType() throw (uno::RuntimeException, std::exception)
+uno::Type SAL_CALL SwXTextRange::getElementType()
 {
     return cppu::UnoType<text::XTextRange>::get();
 }
 
-sal_Bool SAL_CALL SwXTextRange::hasElements() throw (uno::RuntimeException, std::exception)
+sal_Bool SAL_CALL SwXTextRange::hasElements()
 {
     return true;
 }
 
 uno::Sequence< OUString > SAL_CALL
-SwXTextRange::getAvailableServiceNames() throw (uno::RuntimeException, std::exception)
+SwXTextRange::getAvailableServiceNames()
 {
     uno::Sequence<OUString> aRet { "com.sun.star.text.TextContent" };
     return aRet;
 }
 
 uno::Reference< beans::XPropertySetInfo > SAL_CALL
-SwXTextRange::getPropertySetInfo() throw (uno::RuntimeException, std::exception)
+SwXTextRange::getPropertySetInfo()
 {
     SolarMutexGuard aGuard;
 
@@ -1313,9 +1307,6 @@ SwXTextRange::getPropertySetInfo() throw (uno::RuntimeException, std::exception)
 void SAL_CALL
 SwXTextRange::setPropertyValue(
         const OUString& rPropertyName, const uno::Any& rValue)
-throw (beans::UnknownPropertyException, beans::PropertyVetoException,
-        lang::IllegalArgumentException, lang::WrappedTargetException,
-        uno::RuntimeException, std::exception)
 {
     SolarMutexGuard aGuard;
 
@@ -1331,8 +1322,6 @@ throw (beans::UnknownPropertyException, beans::PropertyVetoException,
 
 uno::Any SAL_CALL
 SwXTextRange::getPropertyValue(const OUString& rPropertyName)
-throw (beans::UnknownPropertyException, lang::WrappedTargetException,
-        uno::RuntimeException, std::exception)
 {
     SolarMutexGuard aGuard;
 
@@ -1350,8 +1339,6 @@ void SAL_CALL
 SwXTextRange::addPropertyChangeListener(
         const OUString& /*rPropertyName*/,
         const uno::Reference< beans::XPropertyChangeListener >& /*xListener*/)
-throw (beans::UnknownPropertyException, lang::WrappedTargetException,
-    uno::RuntimeException, std::exception)
 {
     OSL_FAIL("SwXTextRange::addPropertyChangeListener(): not implemented");
 }
@@ -1360,8 +1347,6 @@ void SAL_CALL
 SwXTextRange::removePropertyChangeListener(
         const OUString& /*rPropertyName*/,
         const uno::Reference< beans::XPropertyChangeListener >& /*xListener*/)
-throw (beans::UnknownPropertyException, lang::WrappedTargetException,
-    uno::RuntimeException, std::exception)
 {
     OSL_FAIL("SwXTextRange::removePropertyChangeListener(): not implemented");
 }
@@ -1370,8 +1355,6 @@ void SAL_CALL
 SwXTextRange::addVetoableChangeListener(
         const OUString& /*rPropertyName*/,
         const uno::Reference< beans::XVetoableChangeListener >& /*xListener*/)
-throw (beans::UnknownPropertyException, lang::WrappedTargetException,
-    uno::RuntimeException, std::exception)
 {
     OSL_FAIL("SwXTextRange::addVetoableChangeListener(): not implemented");
 }
@@ -1380,15 +1363,12 @@ void SAL_CALL
 SwXTextRange::removeVetoableChangeListener(
         const OUString& /*rPropertyName*/,
         const uno::Reference< beans::XVetoableChangeListener >& /*xListener*/)
-throw (beans::UnknownPropertyException, lang::WrappedTargetException,
-        uno::RuntimeException, std::exception)
 {
     OSL_FAIL("SwXTextRange::removeVetoableChangeListener(): not implemented");
 }
 
 beans::PropertyState SAL_CALL
 SwXTextRange::getPropertyState(const OUString& rPropertyName)
-throw (beans::UnknownPropertyException, uno::RuntimeException, std::exception)
 {
     SolarMutexGuard aGuard;
 
@@ -1404,7 +1384,6 @@ throw (beans::UnknownPropertyException, uno::RuntimeException, std::exception)
 
 uno::Sequence< beans::PropertyState > SAL_CALL
 SwXTextRange::getPropertyStates(const uno::Sequence< OUString >& rPropertyName)
-throw (beans::UnknownPropertyException, uno::RuntimeException, std::exception)
 {
     SolarMutexGuard g;
 
@@ -1419,7 +1398,6 @@ throw (beans::UnknownPropertyException, uno::RuntimeException, std::exception)
 }
 
 void SAL_CALL SwXTextRange::setPropertyToDefault(const OUString& rPropertyName)
-throw (beans::UnknownPropertyException, uno::RuntimeException, std::exception)
 {
     SolarMutexGuard aGuard;
 
@@ -1435,8 +1413,6 @@ throw (beans::UnknownPropertyException, uno::RuntimeException, std::exception)
 
 uno::Any SAL_CALL
 SwXTextRange::getPropertyDefault(const OUString& rPropertyName)
-throw (beans::UnknownPropertyException, lang::WrappedTargetException,
-        uno::RuntimeException, std::exception)
 {
     SolarMutexGuard aGuard;
 
@@ -1454,7 +1430,6 @@ void SAL_CALL
 SwXTextRange::makeRedline(
     const OUString& rRedlineType,
     const uno::Sequence< beans::PropertyValue >& rRedlineProperties )
-throw (lang::IllegalArgumentException, uno::RuntimeException, std::exception)
 {
     SolarMutexGuard aGuard;
 
@@ -1471,24 +1446,24 @@ struct SwXTextRangesImpl final : public SwXTextRanges
 {
 
     // XUnoTunnel
-    virtual sal_Int64 SAL_CALL getSomething( const css::uno::Sequence< sal_Int8 >& rIdentifier) throw (css::uno::RuntimeException, std::exception) override;
+    virtual sal_Int64 SAL_CALL getSomething( const css::uno::Sequence< sal_Int8 >& rIdentifier) override;
 
     // XServiceInfo
-    virtual OUString SAL_CALL getImplementationName() throw (css::uno::RuntimeException, std::exception) override
+    virtual OUString SAL_CALL getImplementationName() override
         { return OUString("SwXTextRanges"); };
-    virtual sal_Bool SAL_CALL supportsService( const OUString& rServiceName) throw (css::uno::RuntimeException, std::exception) override
+    virtual sal_Bool SAL_CALL supportsService( const OUString& rServiceName) override
         { return cppu::supportsService(this, rServiceName); };
-    virtual css::uno::Sequence< OUString > SAL_CALL getSupportedServiceNames() throw (css::uno::RuntimeException, std::exception) override
+    virtual css::uno::Sequence< OUString > SAL_CALL getSupportedServiceNames() override
         { return { "com.sun.star.text.TextRanges" }; };
 
     // XElementAccess
-    virtual css::uno::Type SAL_CALL getElementType() throw (css::uno::RuntimeException, std::exception) override
+    virtual css::uno::Type SAL_CALL getElementType() override
         { return cppu::UnoType<text::XTextRange>::get(); };
-    virtual sal_Bool SAL_CALL hasElements() throw (css::uno::RuntimeException, std::exception) override
+    virtual sal_Bool SAL_CALL hasElements() override
         { return getCount() > 0; };
     // XIndexAccess
-    virtual sal_Int32 SAL_CALL getCount() throw (css::uno::RuntimeException, std::exception) override;
-    virtual css::uno::Any SAL_CALL getByIndex(sal_Int32 nIndex) throw (css::lang::IndexOutOfBoundsException, css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception) override;
+    virtual sal_Int32 SAL_CALL getCount() override;
+    virtual css::uno::Any SAL_CALL getByIndex(sal_Int32 nIndex) override;
 
     explicit SwXTextRangesImpl(SwPaM *const pPaM)
     {
@@ -1542,7 +1517,6 @@ const uno::Sequence< sal_Int8 > & SwXTextRanges::getUnoTunnelId()
 
 sal_Int64 SAL_CALL
 SwXTextRangesImpl::getSomething(const uno::Sequence< sal_Int8 >& rId)
-    throw (uno::RuntimeException, std::exception)
 {
     return ::sw::UnoTunnelImpl<SwXTextRanges>(rId, this);
 }
@@ -1554,19 +1528,18 @@ SwXTextRangesImpl::getSomething(const uno::Sequence< sal_Int8 >& rId)
  */
 
 sal_Int32 SAL_CALL SwXTextRangesImpl::getCount()
-    throw (uno::RuntimeException, std::exception)
 {
     SolarMutexGuard aGuard;
     return static_cast<sal_Int32>(m_Ranges.size());
 }
 
-uno::Any SAL_CALL SwXTextRangesImpl::getByIndex(sal_Int32 nIndex) throw (lang::IndexOutOfBoundsException, lang::WrappedTargetException, uno::RuntimeException, std::exception)
+uno::Any SAL_CALL SwXTextRangesImpl::getByIndex(sal_Int32 nIndex)
 {
     SolarMutexGuard aGuard;
     if ((nIndex < 0) || (static_cast<size_t>(nIndex) >= m_Ranges.size()))
         throw lang::IndexOutOfBoundsException();
     uno::Any ret;
-    ret <<= (m_Ranges.at(nIndex));
+    ret <<= m_Ranges.at(nIndex);
     return ret;
 }
 
@@ -1575,7 +1548,7 @@ void SwUnoCursorHelper::SetString(SwCursor & rCursor, const OUString& rString)
     // Start/EndAction
     SwDoc *const pDoc = rCursor.GetDoc();
     UnoActionContext aAction(pDoc);
-    pDoc->GetIDocumentUndoRedo().StartUndo(UNDO_INSERT, nullptr);
+    pDoc->GetIDocumentUndoRedo().StartUndo(SwUndoId::INSERT, nullptr);
     if (rCursor.HasMark())
     {
         pDoc->getIDocumentContentOperations().DeleteAndJoin(rCursor);
@@ -1585,26 +1558,25 @@ void SwUnoCursorHelper::SetString(SwCursor & rCursor, const OUString& rString)
         const bool bSuccess( SwUnoCursorHelper::DocInsertStringSplitCR(
                     *pDoc, rCursor, rString, false ) );
         OSL_ENSURE( bSuccess, "DocInsertStringSplitCR" );
-        (void) bSuccess;
         SwUnoCursorHelper::SelectPam(rCursor, true);
         rCursor.Left(rString.getLength());
     }
-    pDoc->GetIDocumentUndoRedo().EndUndo(UNDO_INSERT, nullptr);
+    pDoc->GetIDocumentUndoRedo().EndUndo(SwUndoId::INSERT, nullptr);
 }
 
 struct SwXParaFrameEnumerationImpl final : public SwXParaFrameEnumeration
 {
     // XServiceInfo
-    virtual OUString SAL_CALL getImplementationName() throw (css::uno::RuntimeException, std::exception) override
+    virtual OUString SAL_CALL getImplementationName() override
         { return OUString("SwXParaFrameEnumeration"); };
-    virtual sal_Bool SAL_CALL supportsService(const OUString& rServiceName) throw (css::uno::RuntimeException, std::exception) override
+    virtual sal_Bool SAL_CALL supportsService(const OUString& rServiceName) override
         { return cppu::supportsService(this, rServiceName); };
-    virtual css::uno::Sequence< OUString > SAL_CALL getSupportedServiceNames() throw (css::uno::RuntimeException, std::exception) override
+    virtual css::uno::Sequence< OUString > SAL_CALL getSupportedServiceNames() override
         { return {"com.sun.star.util.ContentEnumeration"}; };
 
     // XEnumeration
-    virtual sal_Bool SAL_CALL hasMoreElements() throw (css::uno::RuntimeException, std::exception) override;
-    virtual css::uno::Any SAL_CALL nextElement() throw (css::container::NoSuchElementException, css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception) override;
+    virtual sal_Bool SAL_CALL hasMoreElements() override;
+    virtual css::uno::Any SAL_CALL nextElement() override;
 
     SwXParaFrameEnumerationImpl(const SwPaM& rPaM, const enum ParaFrameMode eParaFrameMode, SwFrameFormat* const pFormat);
     virtual void SAL_CALL release() throw () override
@@ -1705,12 +1677,12 @@ bool SwXParaFrameEnumerationImpl::CreateNextObject()
     // the format should be valid here, otherwise the client
     // would have been removed by PurgeFrameClients
     // check for a shape first
-    SwDrawContact* const pContact = SwIterator<SwDrawContact,SwFormat>( *pFormat ).First();
-    if (pContact)
+    if(pFormat->Which() == RES_DRAWFRMFMT)
     {
-        SdrObject* const pSdr = pContact->GetMaster();
-        if (pSdr)
-            m_xNextObject.set(pSdr->getUnoShape(), uno::UNO_QUERY);
+        SdrObject* pObject(nullptr);
+        pFormat->CallSwClientNotify(sw::FindSdrObjectHint(pObject));
+        if(pObject)
+            m_xNextObject.set(pObject->getUnoShape(), uno::UNO_QUERY);
     }
     else
     {
@@ -1740,7 +1712,7 @@ bool SwXParaFrameEnumerationImpl::CreateNextObject()
 }
 
 sal_Bool SAL_CALL
-SwXParaFrameEnumerationImpl::hasMoreElements() throw (uno::RuntimeException, std::exception)
+SwXParaFrameEnumerationImpl::hasMoreElements()
 {
     SolarMutexGuard aGuard;
     PurgeFrameClients();
@@ -1748,8 +1720,6 @@ SwXParaFrameEnumerationImpl::hasMoreElements() throw (uno::RuntimeException, std
 }
 
 uno::Any SAL_CALL SwXParaFrameEnumerationImpl::nextElement()
-throw (container::NoSuchElementException,
-        lang::WrappedTargetException, uno::RuntimeException, std::exception)
 {
     SolarMutexGuard aGuard;
     PurgeFrameClients();
