@@ -33,7 +33,7 @@
 #include <viewimp.hxx>
 #include <viewopt.hxx>
 #include <swregion.hxx>
-#include <comcore.hrc>
+#include <strings.hrc>
 #include <frmtool.hxx>
 #include <sfx2/zoomitem.hxx>
 #include <printdata.hxx>
@@ -50,16 +50,15 @@ SwPagePreviewLayout::SwPagePreviewLayout( SwViewShell& _rParentViewShell,
       mrParentViewShell( _rParentViewShell ),
       mrLayoutRootFrame ( _rLayoutRootFrame )
 {
-    _Clear();
+    Clear_();
 
-    // OD 2004-03-05 #i18143#
     mbBookPreview = false;
     mbBookPreviewModeToggled = false;
 
     mbPrintEmptyPages = mrParentViewShell.getIDocumentDeviceAccess().getPrintData().IsPrintEmptyPages();
 }
 
-void SwPagePreviewLayout::_Clear()
+void SwPagePreviewLayout::Clear_()
 {
     mbLayoutInfoValid = mbLayoutSizesValid = mbPaintInfoValid = false;
 
@@ -67,7 +66,7 @@ void SwPagePreviewLayout::_Clear()
     maWinSize.Height() = 0;
     mnCols = mnRows = 0;
 
-    _ClearPreviewLayoutSizes();
+    ClearPreviewLayoutSizes();
 
     mbDoesLayoutRowsFitIntoWindow = false;
     mbDoesLayoutColsFitIntoWindow = false;
@@ -86,14 +85,13 @@ void SwPagePreviewLayout::_Clear()
     maPaintedPreviewDocRect.Right() = 0;
     maPaintedPreviewDocRect.Bottom() = 0;
     mnSelectedPageNum = 0;
-    _ClearPreviewPageData();
+    ClearPreviewPageData();
 
-    // OD 07.11.2003 #i22014#
     mbInPaint = false;
     mbNewLayoutDuringPaint = false;
 }
 
-void SwPagePreviewLayout::_ClearPreviewLayoutSizes()
+void SwPagePreviewLayout::ClearPreviewLayoutSizes()
 {
     mnPages = 0;
 
@@ -105,7 +103,7 @@ void SwPagePreviewLayout::_ClearPreviewLayoutSizes()
     mnPreviewLayoutWidth = mnPreviewLayoutHeight = 0;
 }
 
-void SwPagePreviewLayout::_ClearPreviewPageData()
+void SwPagePreviewLayout::ClearPreviewPageData()
 {
     for ( std::vector<PreviewPage*>::iterator aPageDelIter = maPreviewPages.begin();
           aPageDelIter != maPreviewPages.end();
@@ -118,9 +116,8 @@ void SwPagePreviewLayout::_ClearPreviewPageData()
 
 /** calculate page preview layout sizes
 
-    OD 18.12.2002 #103492#
 */
-void SwPagePreviewLayout::_CalcPreviewLayoutSizes()
+void SwPagePreviewLayout::CalcPreviewLayoutSizes()
 {
     vcl::RenderContext* pRenderContext = mrParentViewShell.GetOut();
     // calculate maximal page size; calculate also number of pages
@@ -136,7 +133,7 @@ void SwPagePreviewLayout::_CalcPreviewLayoutSizes()
 
         ++mnPages;
         pPage->Calc(pRenderContext);
-        const Size& rPageSize = pPage->Frame().SSize();
+        const Size& rPageSize = pPage->getFrameArea().SSize();
         if ( rPageSize.Width() > maMaxPageSize.Width() )
             maMaxPageSize.Width() = rPageSize.Width();
         if ( rPageSize.Height() > maMaxPageSize.Height() )
@@ -159,7 +156,7 @@ void SwPagePreviewLayout::_CalcPreviewLayoutSizes()
 
         // document height
         // determine number of rows needed for <nPages> in preview layout
-        // OD 19.02.2003 #107369# - use method <GetRowOfPage(..)>.
+        // use method <GetRowOfPage(..)>.
         const sal_uInt16 nDocRows = GetRowOfPage( mnPages );
         aDocSize.Height() = nDocRows * maMaxPageSize.Height() +
                             (nDocRows+1) * mnYFree;
@@ -170,7 +167,6 @@ void SwPagePreviewLayout::_CalcPreviewLayoutSizes()
 
 /** init page preview layout
 
-    OD 11.12.2002 #103492#
     initialize the page preview settings for a given layout.
 
     side effects:
@@ -180,8 +176,7 @@ void SwPagePreviewLayout::_CalcPreviewLayoutSizes()
 */
 bool SwPagePreviewLayout::Init( const sal_uInt16 _nCols,
                                 const sal_uInt16 _nRows,
-                                const Size&      _rPxWinSize,
-                                const bool       _bCalcScale
+                                const Size&      _rPxWinSize
                               )
 {
     // check environment and parameters
@@ -201,41 +196,39 @@ bool SwPagePreviewLayout::Init( const sal_uInt16 _nCols,
     // environment and parameters ok
 
     // clear existing preview settings
-    _Clear();
+    Clear_();
 
     // set layout information columns and rows
     mnCols = _nCols;
     mnRows = _nRows;
 
-    _CalcPreviewLayoutSizes();
+    CalcPreviewLayoutSizes();
 
     // validate layout information
     mbLayoutInfoValid = true;
 
-    if ( _bCalcScale )
+    // calculate scaling
+    MapMode aMapMode( MapUnit::MapTwip );
+    Size aWinSize = mrParentViewShell.GetOut()->PixelToLogic( _rPxWinSize, aMapMode );
+    Fraction aXScale( aWinSize.Width(), mnPreviewLayoutWidth );
+    Fraction aYScale( aWinSize.Height(), mnPreviewLayoutHeight );
+    if( aXScale < aYScale )
+        aYScale = aXScale;
     {
-        // calculate scaling
-        MapMode aMapMode( MAP_TWIP );
-        Size aWinSize = mrParentViewShell.GetOut()->PixelToLogic( _rPxWinSize, aMapMode );
-        Fraction aXScale( aWinSize.Width(), mnPreviewLayoutWidth );
-        Fraction aYScale( aWinSize.Height(), mnPreviewLayoutHeight );
-        if( aXScale < aYScale )
-            aYScale = aXScale;
-        {
-            // adjust scaling for Drawing layer.
-            aYScale *= Fraction( 1000, 1 );
-            long nNewNuminator = aYScale.operator long();
-            if( nNewNuminator < 1 )
-                nNewNuminator = 1;
-            aYScale = Fraction( nNewNuminator, 1000 );
-            // propagate scaling as zoom percentage to view options for font cache
-            _ApplyNewZoomAtViewShell( static_cast<sal_uInt8>(nNewNuminator/10) );
-        }
+        // adjust scaling for Drawing layer.
+        aYScale *= Fraction( 1000, 1 );
+        long nNewNuminator = aYScale.operator long();
+        if( nNewNuminator < 1 )
+            nNewNuminator = 1;
+        aYScale = Fraction( nNewNuminator, 1000 );
+        // propagate scaling as zoom percentage to view options for font cache
+        ApplyNewZoomAtViewShell( static_cast<sal_uInt8>(nNewNuminator/10) );
+
         aMapMode.SetScaleY( aYScale );
         aMapMode.SetScaleX( aYScale );
         // set created mapping mode with calculated scaling at output device.
         mrParentViewShell.GetOut()->SetMapMode( aMapMode );
-        // OD 20.02.2003 #107369# - update statics for paint.
+        // update statics for paint.
         ::SwCalcPixStatics( mrParentViewShell.GetOut() );
     }
 
@@ -248,22 +241,20 @@ bool SwPagePreviewLayout::Init( const sal_uInt16 _nCols,
 }
 
 /** apply new zoom at given view shell */
-void SwPagePreviewLayout::_ApplyNewZoomAtViewShell( sal_uInt8 _aNewZoom )
+void SwPagePreviewLayout::ApplyNewZoomAtViewShell( sal_uInt8 _aNewZoom )
 {
     SwViewOption aNewViewOptions = *(mrParentViewShell.GetViewOptions());
     if ( aNewViewOptions.GetZoom() != _aNewZoom )
     {
         aNewViewOptions.SetZoom( _aNewZoom );
         //#i19975# - consider zoom type.
-        SvxZoomType eZoomType = SvxZoomType::PERCENT;
-        aNewViewOptions.SetZoomType( eZoomType );
+        aNewViewOptions.SetZoomType( SvxZoomType::PERCENT );
         mrParentViewShell.ApplyViewOptions( aNewViewOptions );
     }
 }
 
 /** method to adjust page preview layout to document changes
 
-    OD 18.12.2002 #103492#
 */
 bool SwPagePreviewLayout::ReInit()
 {
@@ -276,8 +267,8 @@ bool SwPagePreviewLayout::ReInit()
             return false;
     }
 
-    _ClearPreviewLayoutSizes();
-    _CalcPreviewLayoutSizes();
+    ClearPreviewLayoutSizes();
+    CalcPreviewLayoutSizes();
 
     return true;
 }
@@ -286,8 +277,7 @@ bool SwPagePreviewLayout::ReInit()
 
 /** prepare paint of page preview
 
-    OD 12.12.2002 #103492#
-    OD 21.03.2003 #108282# - delete parameter _onStartPageVirtNum
+    delete parameter _onStartPageVirtNum
 
     @note _nProposedStartPageNum, _onStartPageNum are absolute
 */
@@ -295,7 +285,7 @@ bool SwPagePreviewLayout::Prepare( const sal_uInt16 _nProposedStartPageNum,
                                    const Point&      rProposedStartPos,
                                    const Size&      _rPxWinSize,
                                    sal_uInt16&      _onStartPageNum,
-                                   Rectangle&       _orDocPreviewPaintRect,
+                                   tools::Rectangle&       _orDocPreviewPaintRect,
                                    const bool       _bStartWithPageAtFirstCol
                                  )
 {
@@ -348,7 +338,7 @@ bool SwPagePreviewLayout::Prepare( const sal_uInt16 _nProposedStartPageNum,
         // determine start page
         if ( _bStartWithPageAtFirstCol )
         {
-            // OD 19.02.2003 #107369# - leaving left-top-corner blank is
+            // leaving left-top-corner blank is
             // controlled by <mbBookPreview>.
             if ( mbBookPreview &&
                  ( nProposedStartPageNum == 1 || nRowOfProposed == 1 )
@@ -388,7 +378,7 @@ bool SwPagePreviewLayout::Prepare( const sal_uInt16 _nProposedStartPageNum,
         const sal_uInt16 nRowOfProposed =
                 static_cast<sal_uInt16>(rProposedStartPos.Y() / mnRowHeight) + 1;
         // determine start page == page at proposed start position
-        // OD 19.02.2003 #107369# - leaving left-top-corner blank is
+        // leaving left-top-corner blank is
         // controlled by <mbBookPreview>.
         if ( mbBookPreview &&
              ( nRowOfProposed == 1 && nColOfProposed == 1 )
@@ -396,7 +386,7 @@ bool SwPagePreviewLayout::Prepare( const sal_uInt16 _nProposedStartPageNum,
             mnPaintPhyStartPageNum = 1;
         else
         {
-            // OD 19.02.2003 #107369# - leaving left-top-corner blank is
+            // leaving left-top-corner blank is
             // controlled by <mbBookPreview>.
             mnPaintPhyStartPageNum = (nRowOfProposed-1) * mnCols + nColOfProposed;
             if ( mbBookPreview )
@@ -422,13 +412,13 @@ bool SwPagePreviewLayout::Prepare( const sal_uInt16 _nProposedStartPageNum,
     }
 
     // determine additional paint offset, if preview layout fits into window.
-    _CalcAdditionalPaintOffset();
+    CalcAdditionalPaintOffset();
 
     // determine rectangle to be painted from document preview
-    _CalcDocPreviewPaintRect();
+    CalcDocPreviewPaintRect();
     _orDocPreviewPaintRect = maPaintedPreviewDocRect;
 
-    // OD 20.01.2003 #103492# - shift visible preview document area to the left,
+    // shift visible preview document area to the left,
     // if on the right is an area left blank.
     if ( !mbDoesLayoutColsFitIntoWindow &&
          maPaintedPreviewDocRect.GetWidth() < maWinSize.Width() )
@@ -440,8 +430,8 @@ bool SwPagePreviewLayout::Prepare( const sal_uInt16 _nProposedStartPageNum,
                  _orDocPreviewPaintRect, _bStartWithPageAtFirstCol );
     }
 
-    // OD 20.01.2003 #103492# - shift visible preview document area to the top,
-    // if on the botton is an area left blank.
+    // shift visible preview document area to the top,
+    // if on the bottom is an area left blank.
     if ( mbBookPreviewModeToggled &&
          maPaintedPreviewDocRect.Bottom() == maPreviewDocRect.Bottom() &&
          maPaintedPreviewDocRect.GetHeight() < maWinSize.Height() )
@@ -469,7 +459,7 @@ bool SwPagePreviewLayout::Prepare( const sal_uInt16 _nProposedStartPageNum,
 
     // determine preview pages - visible pages with needed data for paint and
     // accessible pages with needed data.
-    _CalcPreviewPages();
+    CalcPreviewPages();
 
     // OD 07.11.2003 #i22014# - indicate new layout, if print preview is in paint
     if ( mbInPaint )
@@ -488,9 +478,8 @@ bool SwPagePreviewLayout::Prepare( const sal_uInt16 _nProposedStartPageNum,
 
 /** calculate additional paint offset
 
-    OD 12.12.2002 #103492#
 */
-void SwPagePreviewLayout::_CalcAdditionalPaintOffset()
+void SwPagePreviewLayout::CalcAdditionalPaintOffset()
 {
     if ( mnPreviewLayoutWidth <= maWinSize.Width() &&
          maPaintStartPageOffset.X() <= 0 )
@@ -519,9 +508,8 @@ void SwPagePreviewLayout::_CalcAdditionalPaintOffset()
 
 /** calculate painted preview document rectangle
 
-    OD 12.12.2002 #103492#
 */
-void SwPagePreviewLayout::_CalcDocPreviewPaintRect()
+void SwPagePreviewLayout::CalcDocPreviewPaintRect()
 {
     Point aTopLeftPos = maPaintPreviewDocOffset;
     maPaintedPreviewDocRect.SetPos( aTopLeftPos );
@@ -544,12 +532,11 @@ void SwPagePreviewLayout::_CalcDocPreviewPaintRect()
 
 /** calculate preview pages
 
-    OD 12.12.2002 #103492#
 */
-void SwPagePreviewLayout::_CalcPreviewPages()
+void SwPagePreviewLayout::CalcPreviewPages()
 {
     vcl::RenderContext* pRenderContext = mrParentViewShell.GetOut();
-    _ClearPreviewPageData();
+    ClearPreviewPageData();
 
     if ( mbNoPageVisible )
         return;
@@ -579,7 +566,7 @@ void SwPagePreviewLayout::_CalcPreviewPages()
     sal_uInt16 nCurrCol = mnPaintStartCol;
     sal_uInt16 nConsideredRows = 0;
     Point aCurrPaintOffset = aInitialPaintOffset;
-    // loop on pages to determine preview background retangles
+    // loop on pages to determine preview background rectangles
     while ( pPage &&
             (!mbDoesLayoutRowsFitIntoWindow || nConsideredRows < mnRows) &&
             aCurrPaintOffset.Y() < maWinSize.Height()
@@ -600,7 +587,7 @@ void SwPagePreviewLayout::_CalcPreviewPages()
             PreviewPage* pPreviewPage = new PreviewPage;
             Point aCurrAccOffset = aCurrPaintOffset -
                            Point( (mnPaintStartCol-nCurrCol) * mnColWidth, 0 );
-            _CalcPreviewDataForPage( *(pPage), aCurrAccOffset, pPreviewPage );
+            CalcPreviewDataForPage( *pPage, aCurrAccOffset, pPreviewPage );
             pPreviewPage->bVisible = false;
             maPreviewPages.push_back( pPreviewPage );
             // continue with next page and next column
@@ -610,7 +597,7 @@ void SwPagePreviewLayout::_CalcPreviewPages()
         }
         if ( aCurrPaintOffset.X() < maWinSize.Width() )
         {
-            // OD 19.02.2003 #107369# - leaving left-top-corner blank is
+            // leaving left-top-corner blank is
             // controlled by <mbBookPreview>.
             if ( mbBookPreview && pPage->GetPhyPageNum() == 1 && mnCols != 1 && nCurrCol == 1
                )
@@ -627,7 +614,7 @@ void SwPagePreviewLayout::_CalcPreviewPages()
 
             // calculate data of visible page
             PreviewPage* pPreviewPage = new PreviewPage;
-            _CalcPreviewDataForPage( *(pPage), aCurrPaintOffset, pPreviewPage );
+            CalcPreviewDataForPage( *pPage, aCurrPaintOffset, pPreviewPage );
             pPreviewPage->bVisible = true;
             maPreviewPages.push_back( pPreviewPage );
         }
@@ -635,7 +622,7 @@ void SwPagePreviewLayout::_CalcPreviewPages()
         {
             // calculate data of unvisible page needed for accessibility
             PreviewPage* pPreviewPage = new PreviewPage;
-            _CalcPreviewDataForPage( *(pPage), aCurrPaintOffset, pPreviewPage );
+            CalcPreviewDataForPage( *pPage, aCurrPaintOffset, pPreviewPage );
             pPreviewPage->bVisible = false;
             maPreviewPages.push_back( pPreviewPage );
         }
@@ -662,7 +649,7 @@ void SwPagePreviewLayout::_CalcPreviewPages()
 
     OD 13.12.2002 #103492#
 */
-bool SwPagePreviewLayout::_CalcPreviewDataForPage( const SwPageFrame& _rPage,
+bool SwPagePreviewLayout::CalcPreviewDataForPage( const SwPageFrame& _rPage,
                                                    const Point& _rPreviewOffset,
                                                    PreviewPage* _opPreviewPage )
 {
@@ -672,12 +659,12 @@ bool SwPagePreviewLayout::_CalcPreviewDataForPage( const SwPageFrame& _rPage,
     if ( _rPage.IsEmptyPage() )
     {
         if ( _rPage.GetPhyPageNum() % 2 == 0 )
-            _opPreviewPage->aPageSize = _rPage.GetPrev()->Frame().SSize();
+            _opPreviewPage->aPageSize = _rPage.GetPrev()->getFrameArea().SSize();
         else
-            _opPreviewPage->aPageSize = _rPage.GetNext()->Frame().SSize();
+            _opPreviewPage->aPageSize = _rPage.GetNext()->getFrameArea().SSize();
     }
     else
-        _opPreviewPage->aPageSize = _rPage.Frame().SSize();
+        _opPreviewPage->aPageSize = _rPage.getFrameArea().SSize();
     // position of page in preview window
     Point aPreviewWinOffset( _rPreviewOffset );
     if ( _opPreviewPage->aPageSize.Width() < maMaxPageSize.Width() )
@@ -693,7 +680,7 @@ bool SwPagePreviewLayout::_CalcPreviewDataForPage( const SwPageFrame& _rPage,
     }
     else
     {
-        _opPreviewPage->aLogicPos = _rPage.Frame().Pos();
+        _opPreviewPage->aLogicPos = _rPage.getFrameArea().Pos();
         _opPreviewPage->aMapOffset = _opPreviewPage->aPreviewWinPos - _opPreviewPage->aLogicPos;
     }
 
@@ -706,7 +693,7 @@ bool SwPagePreviewLayout::_CalcPreviewDataForPage( const SwPageFrame& _rPage,
 */
 bool SwPagePreviewLayout::SetBookPreviewMode( const bool _bEnableBookPreview,
                                               sal_uInt16& _onStartPageNum,
-                                              Rectangle&  _orDocPreviewPaintRect )
+                                              tools::Rectangle&  _orDocPreviewPaintRect )
 {
     if ( mbBookPreview != _bEnableBookPreview)
     {
@@ -740,7 +727,6 @@ bool SwPagePreviewLayout::SetBookPreviewMode( const bool _bEnableBookPreview,
 
 /** calculate start position for new scale
 
-    OD 12.12.2002 #103492#
 */
 Point SwPagePreviewLayout::GetPreviewStartPosForNewScale(
                           const Fraction& _aNewScale,
@@ -801,11 +787,11 @@ Point SwPagePreviewLayout::GetPreviewStartPosForNewScale(
 
 /** determines, if page with given page number is visible in preview
 
-    @note _nPageNum is absolut!
+    @note _nPageNum is absolute
 */
 bool SwPagePreviewLayout::IsPageVisible( const sal_uInt16 _nPageNum ) const
 {
-    const PreviewPage* pPreviewPage = _GetPreviewPageByPageNum( _nPageNum );
+    const PreviewPage* pPreviewPage = GetPreviewPageByPageNum( _nPageNum );
     return pPreviewPage && pPreviewPage->bVisible;
 }
 
@@ -906,7 +892,7 @@ struct PreviewPosInsidePagePred
     {
         if ( _pPreviewPage->bVisible )
         {
-            Rectangle aPreviewPageRect( _pPreviewPage->aPreviewWinPos, _pPreviewPage->aPageSize );
+            tools::Rectangle aPreviewPageRect( _pPreviewPage->aPreviewWinPos, _pPreviewPage->aPageSize );
             return aPreviewPageRect.IsInside( mnPreviewPos );
         }
         return false;
@@ -1011,9 +997,8 @@ public:
 
 /** paint prepared preview
 
-    OD 12.12.2002 #103492#
 */
-bool SwPagePreviewLayout::Paint(vcl::RenderContext& rRenderContext, const Rectangle& rOutRect) const
+bool SwPagePreviewLayout::Paint(vcl::RenderContext& rRenderContext, const tools::Rectangle& rOutRect) const
 {
     PreviewRenderContextGuard aGuard(mrParentViewShell, &rRenderContext);
     // check environment and parameters
@@ -1036,7 +1021,6 @@ bool SwPagePreviewLayout::Paint(vcl::RenderContext& rRenderContext, const Rectan
 
     // environment and parameter ok
 
-    // OD 07.11.2003 #i22014#
     if (mbInPaint)
     {
         return false;
@@ -1068,11 +1052,11 @@ bool SwPagePreviewLayout::Paint(vcl::RenderContext& rRenderContext, const Rectan
             }
         }
         // paint preview background rectangles
-        mrParentViewShell._PaintDesktop(rRenderContext, aPreviewBackgrdRegion);
+        mrParentViewShell.PaintDesktop_(aPreviewBackgrdRegion);
     }
 
     // prepare data for paint of pages
-    const Rectangle aPxOutRect( pOutputDev->LogicToPixel(rOutRect) );
+    const tools::Rectangle aPxOutRect( pOutputDev->LogicToPixel(rOutRect) );
 
     MapMode aMapMode( pOutputDev->GetMapMode() );
     MapMode aSavedMapMode = aMapMode;
@@ -1086,10 +1070,10 @@ bool SwPagePreviewLayout::Paint(vcl::RenderContext& rRenderContext, const Rectan
         if ( !(*aPageIter)->bVisible )
             continue;
 
-        Rectangle aPageRect( (*aPageIter)->aLogicPos, (*aPageIter)->aPageSize );
+        tools::Rectangle aPageRect( (*aPageIter)->aLogicPos, (*aPageIter)->aPageSize );
         aMapMode.SetOrigin( (*aPageIter)->aMapOffset );
         pOutputDev->SetMapMode( aMapMode );
-        Rectangle aPxPaintRect = pOutputDev->LogicToPixel( aPageRect );
+        tools::Rectangle aPxPaintRect = pOutputDev->LogicToPixel( aPageRect );
         if ( aPxOutRect.IsOver( aPxPaintRect) )
         {
             const SwPageFrame* pPage = (*aPageIter)->pPage;
@@ -1099,8 +1083,8 @@ bool SwPagePreviewLayout::Paint(vcl::RenderContext& rRenderContext, const Rectan
                 const Color aRetouche( mrParentViewShell.Imp()->GetRetoucheColor() );
                 if( pOutputDev->GetFillColor() != aRetouche )
                     pOutputDev->SetFillColor( aRetouche );
-                pOutputDev->SetLineColor(); // OD 20.02.2003 #107369# - no line color
-                // OD 20.02.2003 #107369# - use aligned page rectangle
+                pOutputDev->SetLineColor(); // no line color
+                // use aligned page rectangle
                 {
                     SwRect aTmpPageRect( aPageRect );
                     ::SwAlignRect( aTmpPageRect, &mrParentViewShell, &rRenderContext );
@@ -1111,13 +1095,13 @@ bool SwPagePreviewLayout::Paint(vcl::RenderContext& rRenderContext, const Rectan
                 // paint empty page text
                 vcl::Font aOldFont( pOutputDev->GetFont() );
                 pOutputDev->SetFont( rEmptyPgFont );
-                pOutputDev->DrawText( aPageRect, SW_RESSTR( STR_EMPTYPAGE ),
+                pOutputDev->DrawText( aPageRect, SwResId( STR_EMPTYPAGE ),
                                     DrawTextFlags::VCenter |
                                     DrawTextFlags::Center |
                                     DrawTextFlags::Clip );
                 pOutputDev->SetFont( aOldFont );
                 // paint shadow and border for empty page
-                // OD 19.02.2003 #107369# - use new method to paint page border and shadow
+                // use new method to paint page border and shadow
                 SwPageFrame::PaintBorderAndShadow( aPageRect, &mrParentViewShell, true, false, true );
             }
             else
@@ -1127,7 +1111,7 @@ bool SwPagePreviewLayout::Paint(vcl::RenderContext& rRenderContext, const Rectan
 
                 mrParentViewShell.maVisArea = aPageRect;
                 aPxPaintRect.Intersection( aPxOutRect );
-                Rectangle aPaintRect = pOutputDev->PixelToLogic( aPxPaintRect );
+                tools::Rectangle aPaintRect = pOutputDev->PixelToLogic( aPxPaintRect );
                 mrParentViewShell.Paint(rRenderContext, aPaintRect);
 
                 // --> OD 2007-08-15 #i80691#
@@ -1152,7 +1136,7 @@ bool SwPagePreviewLayout::Paint(vcl::RenderContext& rRenderContext, const Rectan
 
             if (pPage->GetPhyPageNum() == mnSelectedPageNum)
             {
-                _PaintSelectMarkAtPage(rRenderContext, *aPageIter);
+                PaintSelectMarkAtPage(rRenderContext, *aPageIter);
             }
         }
     }
@@ -1183,7 +1167,7 @@ bool SwPagePreviewLayout::Paint(vcl::RenderContext& rRenderContext, const Rectan
 
     OD 18.12.2002 #103492#
 */
-void SwPagePreviewLayout::Repaint( const Rectangle& rInvalidCoreRect ) const
+void SwPagePreviewLayout::Repaint( const tools::Rectangle& rInvalidCoreRect ) const
 {
     // check environment and parameters
     {
@@ -1215,11 +1199,11 @@ void SwPagePreviewLayout::Repaint( const Rectangle& rInvalidCoreRect ) const
         if ( !(*aPageIter)->bVisible )
             continue;
 
-        Rectangle aPageRect( (*aPageIter)->aLogicPos, (*aPageIter)->aPageSize );
+        tools::Rectangle aPageRect( (*aPageIter)->aLogicPos, (*aPageIter)->aPageSize );
         if ( rInvalidCoreRect.IsOver( aPageRect ) )
         {
             aPageRect.Intersection(rInvalidCoreRect);
-            Rectangle aInvalidPreviewRect = aPageRect;
+            tools::Rectangle aInvalidPreviewRect = aPageRect;
             aInvalidPreviewRect.SetPos( aInvalidPreviewRect.TopLeft() -
                                       (*aPageIter)->aLogicPos +
                                       (*aPageIter)->aPreviewWinPos );
@@ -1232,7 +1216,7 @@ void SwPagePreviewLayout::Repaint( const Rectangle& rInvalidCoreRect ) const
 
     OD 17.12.2002 #103492#
 */
-void SwPagePreviewLayout::_PaintSelectMarkAtPage(vcl::RenderContext& rRenderContext,
+void SwPagePreviewLayout::PaintSelectMarkAtPage(vcl::RenderContext& rRenderContext,
                                     const PreviewPage* _aSelectedPreviewPage ) const
 {
     OutputDevice* pOutputDev = &rRenderContext;
@@ -1260,18 +1244,18 @@ void SwPagePreviewLayout::_PaintSelectMarkAtPage(vcl::RenderContext& rRenderCont
     // OD 19.02.2003 #107369# - use aligned page rectangle, as it is used for
     // page border and shadow paint - see <SwPageFrame::PaintBorderAndShadow(..)>
     ::SwAlignRect( aPageRect, &mrParentViewShell, pOutputDev );
-    Rectangle aPxPageRect = pOutputDev->LogicToPixel( aPageRect.SVRect() );
+    tools::Rectangle aPxPageRect = pOutputDev->LogicToPixel( aPageRect.SVRect() );
 
     // draw two rectangle
     // OD 19.02.2003 #107369# - adjust position of select mark rectangle
-    Rectangle aRect( aPxPageRect.Left(), aPxPageRect.Top(),
+    tools::Rectangle aRect( aPxPageRect.Left(), aPxPageRect.Top(),
                        aPxPageRect.Right(), aPxPageRect.Bottom() );
     aRect = pOutputDev->PixelToLogic( aRect );
     pOutputDev->SetFillColor(); // OD 20.02.2003 #107369# - no fill color
     pOutputDev->SetLineColor( aSelPgLineColor );
     pOutputDev->DrawRect( aRect );
     // OD 19.02.2003 #107369# - adjust position of select mark rectangle
-    aRect = Rectangle( aPxPageRect.Left()+1, aPxPageRect.Top()+1,
+    aRect = tools::Rectangle( aPxPageRect.Left()+1, aPxPageRect.Top()+1,
                        aPxPageRect.Right()-1, aPxPageRect.Bottom()-1 );
     aRect = pOutputDev->PixelToLogic( aRect );
     pOutputDev->DrawRect( aRect );
@@ -1290,7 +1274,7 @@ void SwPagePreviewLayout::_PaintSelectMarkAtPage(vcl::RenderContext& rRenderCont
     Perform paint for current selected page in order to unmark it.
     Set new selected page and perform paint to mark this page.
 
-    @note _nSelectedPage, mnSelectedPage are absolut
+    @note _nSelectedPage, mnSelectedPage are absolute
 */
 void SwPagePreviewLayout::MarkNewSelectedPage( const sal_uInt16 _nSelectedPage )
 {
@@ -1298,7 +1282,7 @@ void SwPagePreviewLayout::MarkNewSelectedPage( const sal_uInt16 _nSelectedPage )
     mnSelectedPageNum = _nSelectedPage;
 
     // re-paint for current selected page in order to unmark it.
-    const PreviewPage* pOldSelectedPreviewPage = _GetPreviewPageByPageNum( nOldSelectedPageNum );
+    const PreviewPage* pOldSelectedPreviewPage = GetPreviewPageByPageNum( nOldSelectedPageNum );
     OutputDevice* pOutputDev = mrParentViewShell.GetOut();
     if ( pOldSelectedPreviewPage && pOldSelectedPreviewPage->bVisible )
     {
@@ -1306,30 +1290,30 @@ void SwPagePreviewLayout::MarkNewSelectedPage( const sal_uInt16 _nSelectedPage )
         SwRect aPageRect( pOldSelectedPreviewPage->aPreviewWinPos,
                               pOldSelectedPreviewPage->aPageSize );
         ::SwAlignRect( aPageRect, &mrParentViewShell, pOutputDev );
-        Rectangle aPxPageRect = pOutputDev->LogicToPixel( aPageRect.SVRect() );
+        tools::Rectangle aPxPageRect = pOutputDev->LogicToPixel( aPageRect.SVRect() );
         // invalidate top mark line
-        Rectangle aInvalPxRect( aPxPageRect.Left(), aPxPageRect.Top(),
+        tools::Rectangle aInvalPxRect( aPxPageRect.Left(), aPxPageRect.Top(),
                                 aPxPageRect.Right(), aPxPageRect.Top()+1 );
         mrParentViewShell.GetWin()->Invalidate( pOutputDev->PixelToLogic( aInvalPxRect ) );
         // invalidate right mark line
-        aInvalPxRect = Rectangle( aPxPageRect.Right()-1, aPxPageRect.Top(),
+        aInvalPxRect = tools::Rectangle( aPxPageRect.Right()-1, aPxPageRect.Top(),
                                   aPxPageRect.Right(), aPxPageRect.Bottom() );
         mrParentViewShell.GetWin()->Invalidate( pOutputDev->PixelToLogic( aInvalPxRect ) );
         // invalidate bottom mark line
-        aInvalPxRect = Rectangle( aPxPageRect.Left(), aPxPageRect.Bottom()-1,
+        aInvalPxRect = tools::Rectangle( aPxPageRect.Left(), aPxPageRect.Bottom()-1,
                                   aPxPageRect.Right(), aPxPageRect.Bottom() );
         mrParentViewShell.GetWin()->Invalidate( pOutputDev->PixelToLogic( aInvalPxRect ) );
         // invalidate left mark line
-        aInvalPxRect = Rectangle( aPxPageRect.Left(), aPxPageRect.Top(),
+        aInvalPxRect = tools::Rectangle( aPxPageRect.Left(), aPxPageRect.Top(),
                                   aPxPageRect.Left()+1, aPxPageRect.Bottom() );
         mrParentViewShell.GetWin()->Invalidate( pOutputDev->PixelToLogic( aInvalPxRect ) );
     }
 
     // re-paint for new selected page in order to mark it.
-    const PreviewPage* pNewSelectedPreviewPage = _GetPreviewPageByPageNum( _nSelectedPage );
+    const PreviewPage* pNewSelectedPreviewPage = GetPreviewPageByPageNum( _nSelectedPage );
     if ( pNewSelectedPreviewPage && pNewSelectedPreviewPage->bVisible )
     {
-        const PreviewPage* pSelectedPreviewPage = _GetPreviewPageByPageNum(mnSelectedPageNum);
+        const PreviewPage* pSelectedPreviewPage = GetPreviewPageByPageNum(mnSelectedPageNum);
         SwRect aPageRect(pSelectedPreviewPage->aPreviewWinPos, pSelectedPreviewPage->aPageSize);
         ::SwAlignRect(aPageRect, &mrParentViewShell, pOutputDev);
         mrParentViewShell.GetWin()->Invalidate(aPageRect.SVRect());
@@ -1354,7 +1338,7 @@ struct EqualsPageNumPred
     }
 };
 
-const PreviewPage* SwPagePreviewLayout::_GetPreviewPageByPageNum( const sal_uInt16 _nPageNum ) const
+const PreviewPage* SwPagePreviewLayout::GetPreviewPageByPageNum( const sal_uInt16 _nPageNum ) const
 {
     std::vector<PreviewPage*>::const_iterator aFoundPreviewPageIter =
             std::find_if( maPreviewPages.begin(), maPreviewPages.end(),
@@ -1419,7 +1403,7 @@ Size SwPagePreviewLayout::GetPreviewDocSize() const
 */
 Size SwPagePreviewLayout::GetPreviewPageSizeByPageNum( sal_uInt16 _nPageNum ) const
 {
-    const PreviewPage* pPreviewPage = _GetPreviewPageByPageNum( _nPageNum );
+    const PreviewPage* pPreviewPage = GetPreviewPageByPageNum( _nPageNum );
     if ( pPreviewPage )
     {
         return pPreviewPage->aPageSize;
@@ -1433,7 +1417,7 @@ Size SwPagePreviewLayout::GetPreviewPageSizeByPageNum( sal_uInt16 _nPageNum ) co
 */
 sal_uInt16 SwPagePreviewLayout::GetVirtPageNumByPageNum( sal_uInt16 _nPageNum ) const
 {
-    const PreviewPage* pPreviewPage = _GetPreviewPageByPageNum( _nPageNum );
+    const PreviewPage* pPreviewPage = GetPreviewPageByPageNum( _nPageNum );
     if ( pPreviewPage )
     {
         return pPreviewPage->pPage->GetVirtPageNum();
