@@ -45,7 +45,7 @@ void SwViewShell::Init( const SwViewOption *pNewOpt )
 {
     mbDocSizeChgd = false;
 
-    // We play it save: Remove old font information whenever the printer
+    // We play it safe: Remove old font information whenever the printer
     // resolution or the zoom factor changes. For that, Init() and Reformat()
     // are the most secure places.
      pFntCache->Flush( );
@@ -73,36 +73,31 @@ void SwViewShell::Init( const SwViewOption *pNewOpt )
         }
     }
 
-    SwDocShell* pDShell = mpDoc->GetDocShell();
-    mpDoc->GetDocumentSettingManager().set(DocumentSettingId::HTML_MODE, 0 != ::GetHtmlMode( pDShell ) );
-    // JP 02.02.99: Bug 61335 - set readonly flag at ViewOptions before creating layout. Otherwise,
-    //                          one would have to reformat again.
+    SwDocShell* pDShell = mxDoc->GetDocShell();
+    mxDoc->GetDocumentSettingManager().set(DocumentSettingId::HTML_MODE, 0 != ::GetHtmlMode( pDShell ) );
+    // set readonly flag at ViewOptions before creating layout. Otherwise,
+    // one would have to reformat again.
 
     if( pDShell && pDShell->IsReadOnly() )
         mpOpt->SetReadonly( true );
 
     SAL_INFO( "sw.core", "View::Init - before InitPrt" );
-    // --> FME 2007-11-06 #i82967#
     OutputDevice* pPDFOut = nullptr;
 
     if ( mpOut && mpOut->GetPDFWriter() )
         pPDFOut = mpOut;
-    // <--
 
-    // --> FME 2005-01-21 #i41075#
     // Only setup the printer if we need one:
     const bool bBrowseMode = mpOpt->getBrowseMode();
     if( pPDFOut )
         InitPrt( pPDFOut );
-    // <--
 
-    // --> FME 2005-03-16 #i44963# Good occasion to check if page sizes in
+    // i#44963 Good occasion to check if page sizes in
     // page descriptions are still set to (LONG_MAX, LONG_MAX) (html import)
     if ( !bBrowseMode )
     {
-        mpDoc->CheckDefaultPageFormat();
+        mxDoc->CheckDefaultPageFormat();
     }
-    // <--
 
     SAL_INFO( "sw.core", "View::Init - after InitPrt" );
     if( GetWin() )
@@ -126,14 +121,13 @@ void SwViewShell::Init( const SwViewOption *pNewOpt )
         if( !mpLayout )
         {
             // switched to two step construction because creating the layout in SwRootFrame needs a valid pLayout set
-            mpLayout = SwRootFramePtr(new SwRootFrame(mpDoc->GetDfltFrameFormat(), this),
+            mpLayout = SwRootFramePtr(new SwRootFrame(mxDoc->GetDfltFrameFormat(), this),
                                     &SwFrame::DestroyFrame);
-            mpLayout->Init( mpDoc->GetDfltFrameFormat() );
+            mpLayout->Init( mxDoc->GetDfltFrameFormat() );
         }
     }
     SizeChgNotify();
 
-    // --> #i31958#
     // XForms mode: initialize XForms mode, based on design mode (draw view)
     //   MakeDrawView() requires layout
     if( GetDoc()->isXForms() )
@@ -142,16 +136,13 @@ void SwViewShell::Init( const SwViewOption *pNewOpt )
             MakeDrawView();
         mpOpt->SetFormView( ! GetDrawView()->IsDesignMode() );
     }
-    // <-- #i31958#
 }
 
 /// CTor for the first Shell.
 SwViewShell::SwViewShell( SwDoc& rDocument, vcl::Window *pWindow,
                         const SwViewOption *pNewOpt, OutputDevice *pOutput,
                         long nFlags )
-    : m_pReplaceBmp(nullptr)
-    , m_pErrorBmp(nullptr)
-    ,
+    :
     maBrowseBorder(),
     mpSfxViewShell( nullptr ),
     mpImp( new SwViewShellImp( this ) ),
@@ -165,18 +156,17 @@ SwViewShell::SwViewShell( SwDoc& rDocument, vcl::Window *pWindow,
     mbShowHeaderSeparator( false ),
     mbShowFooterSeparator( false ),
     mbHeaderFooterEdit( false ),
-    mpTargetPaintWindow(nullptr), // #i74769#
-    mpBufferedOut(nullptr), // #i74769#
-    mpDoc( &rDocument ),
+    mpTargetPaintWindow(nullptr),
+    mpBufferedOut(nullptr),
+    mxDoc( &rDocument ),
     mnStartAction( 0 ),
     mnLockPaint( 0 ),
     mbSelectAll(false),
-    mbInLibreOfficeKitCallback(false),
     mbOutputToWindow(false),
-    mpPrePostOutDev(nullptr), // #i72754#
+    mpPrePostOutDev(nullptr),
     maPrePostMapMode()
 {
-    // OD 2004-06-01 #i26791# - in order to suppress event handling in
+    // in order to suppress event handling in
     // <SwDrawContact::Changed> during construction of <SwViewShell> instance
     mbInConstructor = true;
 
@@ -185,34 +175,31 @@ SwViewShell::SwViewShell( SwDoc& rDocument, vcl::Window *pWindow,
     mbPaintWorks = mbEnableSmooth = true;
     mbPreview = 0 !=( VSHELLFLAG_ISPREVIEW & nFlags );
 
-    // --> OD 2005-02-11 #i38810# - Do not reset modified state of document,
+    // i#38810 Do not reset modified state of document,
     // if it's already been modified.
-    const bool bIsDocModified( mpDoc->getIDocumentState().IsModified() );
-    mpDoc->acquire();
+    const bool bIsDocModified( mxDoc->getIDocumentState().IsModified() );
     pOutput = mpOut;
     Init( pNewOpt );    // may change the Outdev (InitPrt())
     mpOut = pOutput;
 
-    // OD 28.03.2003 #108470# - initialize print preview layout after layout
+    // initialize print preview layout after layout
     // is created in <SwViewShell::Init(..)> - called above.
     if ( mbPreview )
     {
-        // OD 12.12.2002 #103492# - init page preview layout
+        // init page preview layout
         mpImp->InitPagePreviewLayout();
     }
 
     SET_CURR_SHELL( this );
 
-    static_cast<SwHiddenTextFieldType*>(mpDoc->getIDocumentFieldsAccess().GetSysFieldType( RES_HIDDENTXTFLD ))->
+    static_cast<SwHiddenTextFieldType*>(mxDoc->getIDocumentFieldsAccess().GetSysFieldType( SwFieldIds::HiddenText ))->
         SetHiddenFlag( !mpOpt->IsShowHiddenField() );
 
     // In Init a standard FrameFormat is created.
-    // --> OD 2005-02-11 #i38810#
-    if (   !mpDoc->GetIDocumentUndoRedo().IsUndoNoResetModified()
+    if (   !mxDoc->GetIDocumentUndoRedo().IsUndoNoResetModified()
         && !bIsDocModified )
-    // <--
     {
-        mpDoc->getIDocumentState().ResetModified();
+        mxDoc->getIDocumentState().ResetModified();
     }
 
     // extend format cache.
@@ -221,17 +208,13 @@ SwViewShell::SwViewShell( SwDoc& rDocument, vcl::Window *pWindow,
     if( mpOpt->IsGridVisible() || getIDocumentDrawModelAccess().GetDrawModel() )
         Imp()->MakeDrawView();
 
-    // OD 2004-06-01 #i26791#
     mbInConstructor = false;
 }
 
 /// CTor for further Shells on a document.
 SwViewShell::SwViewShell( SwViewShell& rShell, vcl::Window *pWindow,
                         OutputDevice * pOutput, long const nFlags)
-    : Ring( &rShell )
-    , m_pReplaceBmp(nullptr)
-    , m_pErrorBmp(nullptr)
-    ,
+    : Ring( &rShell ) ,
     maBrowseBorder( rShell.maBrowseBorder ),
     mpSfxViewShell( nullptr ),
     mpImp( new SwViewShellImp( this ) ),
@@ -245,18 +228,17 @@ SwViewShell::SwViewShell( SwViewShell& rShell, vcl::Window *pWindow,
     mbShowHeaderSeparator( false ),
     mbShowFooterSeparator( false ),
     mbHeaderFooterEdit( false ),
-    mpTargetPaintWindow(nullptr), // #i74769#
-    mpBufferedOut(nullptr), // #i74769#
-    mpDoc( rShell.GetDoc() ),
+    mpTargetPaintWindow(nullptr),
+    mpBufferedOut(nullptr),
+    mxDoc( rShell.GetDoc() ),
     mnStartAction( 0 ),
     mnLockPaint( 0 ),
     mbSelectAll(false),
-    mbInLibreOfficeKitCallback(false),
     mbOutputToWindow(false),
-    mpPrePostOutDev(nullptr), // #i72754#
+    mpPrePostOutDev(nullptr),
     maPrePostMapMode()
 {
-    // OD 2004-06-01 #i26791# - in order to suppress event handling in
+    // in order to suppress event handling in
     // <SwDrawContact::Changed> during construction of <SwViewShell> instance
     mbInConstructor = true;
 
@@ -264,30 +246,28 @@ SwViewShell::SwViewShell( SwViewShell& rShell, vcl::Window *pWindow,
     mbPaintInProgress = mbViewLocked = mbInEndAction = mbFrameView =
     mbEndActionByVirDev = false;
     mbPreview = 0 !=( VSHELLFLAG_ISPREVIEW & nFlags );
-    // OD 12.12.2002 #103492#
+
     if( nFlags & VSHELLFLAG_SHARELAYOUT )
         mpLayout = rShell.mpLayout;
 
     SET_CURR_SHELL( this );
 
-    mpDoc->acquire();
-    bool bModified = mpDoc->getIDocumentState().IsModified();
+    bool bModified = mxDoc->getIDocumentState().IsModified();
 
     pOutput = mpOut;
     Init( rShell.GetViewOptions() ); // might change Outdev (InitPrt())
     mpOut = pOutput;
 
-    // OD 12.12.2002 #103492#
     if ( mbPreview )
         mpImp->InitPagePreviewLayout();
 
-    static_cast<SwHiddenTextFieldType*>(mpDoc->getIDocumentFieldsAccess().GetSysFieldType( RES_HIDDENTXTFLD ))->
+    static_cast<SwHiddenTextFieldType*>(mxDoc->getIDocumentFieldsAccess().GetSysFieldType( SwFieldIds::HiddenText ))->
             SetHiddenFlag( !mpOpt->IsShowHiddenField() );
 
     // In Init a standard FrameFormat is created.
-    if( !bModified && !mpDoc->GetIDocumentUndoRedo().IsUndoNoResetModified() )
+    if( !bModified && !mxDoc->GetIDocumentUndoRedo().IsUndoNoResetModified() )
     {
-        mpDoc->getIDocumentState().ResetModified();
+        mxDoc->getIDocumentState().ResetModified();
     }
 
     // extend format cache.
@@ -296,23 +276,24 @@ SwViewShell::SwViewShell( SwViewShell& rShell, vcl::Window *pWindow,
     if( mpOpt->IsGridVisible() || getIDocumentDrawModelAccess().GetDrawModel() )
         Imp()->MakeDrawView();
 
-    // OD 2004-06-01 #i26791#
     mbInConstructor = false;
 
 }
 
 SwViewShell::~SwViewShell()
 {
+    IDocumentLayoutAccess * const pLayoutAccess = mxDoc.get() ? &mxDoc->getIDocumentLayoutAccess() : nullptr;
+
     {
         SET_CURR_SHELL( this );
         mbPaintWorks = false;
 
-        // FME 2004-06-21 #i9684# Stopping the animated graphics is not
+        // i#9684 Stopping the animated graphics is not
         // necessary during printing or pdf export, because the animation
         // has not been started in this case.
-        if( mpDoc && GetWin() )
+        if( mxDoc.get() && GetWin() )
         {
-            SwNodes& rNds = mpDoc->GetNodes();
+            SwNodes& rNds = mxDoc->GetNodes();
 
             SwStartNode *pStNd;
             SwNodeIndex aIdx( *rNds.GetEndOfAutotext().StartOfSectionNode(), 1 );
@@ -341,11 +322,9 @@ SwViewShell::~SwViewShell()
         delete mpImp; // Delete first, so that the LayoutViews are destroyed.
         mpImp = nullptr;   // Set to zero, because ~SwFrame relies on it.
 
-        if ( mpDoc )
+        if ( mxDoc.get() )
         {
-            if( !mpDoc->release() )
-                delete mpDoc, mpDoc = nullptr;
-            else
+            if( mxDoc->getReferenceCount() > 1 )
                 GetLayout()->ResetNewLayout();
         }
 
@@ -361,18 +340,17 @@ SwViewShell::~SwViewShell()
         OSL_ENSURE( !mnStartAction, "EndAction() pending." );
     }
 
-    if ( mpDoc )
+    if ( pLayoutAccess )
     {
         GetLayout()->DeRegisterShell( this );
-        auto& rLayoutAccess(mpDoc->getIDocumentLayoutAccess());
-        if(rLayoutAccess.GetCurrentViewShell()==this)
+        if(pLayoutAccess->GetCurrentViewShell()==this)
         {
-            rLayoutAccess.SetCurrentViewShell(nullptr);
+            pLayoutAccess->SetCurrentViewShell(nullptr);
             for(SwViewShell& rShell : GetRingContainer())
             {
                 if(&rShell != this)
                 {
-                    rLayoutAccess.SetCurrentViewShell(&rShell);
+                    pLayoutAccess->SetCurrentViewShell(&rShell);
                     break;
                 }
             }
