@@ -20,10 +20,13 @@
 #include <svl/itemiter.hxx>
 #include <svl/whiter.hxx>
 
-#include "shellio.hxx"
-#include "wrt_fn.hxx"
-#include "node.hxx"
-#include "format.hxx"
+// tdf#94088 SdrAllFillAttributesHelper needed
+#include <svx/unobrushitemhelper.hxx>
+
+#include <shellio.hxx>
+#include <wrt_fn.hxx>
+#include <node.hxx>
+#include <format.hxx>
 
 Writer& Out( const SwAttrFnTab pTab, const SfxPoolItem& rHt, Writer & rWrt )
 {
@@ -37,8 +40,7 @@ Writer& Out( const SwAttrFnTab pTab, const SfxPoolItem& rHt, Writer & rWrt )
 }
 
 Writer& Out_SfxItemSet( const SwAttrFnTab pTab, Writer& rWrt,
-                        const SfxItemSet& rSet, bool bDeep,
-                        bool bTstForDefault )
+                        const SfxItemSet& rSet, bool bDeep )
 {
     // at first give the own attributes out
     const SfxItemPool& rPool = *rSet.GetPool();
@@ -54,6 +56,11 @@ Writer& Out_SfxItemSet( const SwAttrFnTab pTab, Writer& rWrt,
     }
     const SfxPoolItem* pItem(nullptr);
     FnAttrOut pOut;
+
+    // tdf#94088 check if any FillAttribute is used [XATTR_FILL_FIRST .. XATTR_FILL_LAST]
+    // while processing the items
+    bool bFillItemUsed = false;
+
     if( !bDeep || !pSet->GetParent() )
     {
         OSL_ENSURE( rSet.Count(), "It has been handled already, right?" );
@@ -61,8 +68,17 @@ Writer& Out_SfxItemSet( const SwAttrFnTab pTab, Writer& rWrt,
         pItem = aIter.GetCurItem();
         do {
             // pTab only covers POOLATTR_BEGIN..POOLATTR_END.
-            if( pItem->Which() <= POOLATTR_END && nullptr != ( pOut = pTab[ pItem->Which() - RES_CHRATR_BEGIN] ))
+            if( pItem->Which() <= POOLATTR_END )
+            {
+                if( nullptr != ( pOut = pTab[ pItem->Which() - RES_CHRATR_BEGIN]) )
+                {
                     (*pOut)( rWrt, *pItem );
+                }
+            }
+            else if(XATTR_FILLSTYLE == pItem->Which())
+            {
+                bFillItemUsed = true;
+            }
         } while( !aIter.IsAtEnd() && nullptr != ( pItem = aIter.NextItem() ) );
     }
     else
@@ -72,15 +88,38 @@ Writer& Out_SfxItemSet( const SwAttrFnTab pTab, Writer& rWrt,
         while( nWhich )
         {
             if( SfxItemState::SET == pSet->GetItemState( nWhich, bDeep, &pItem ) &&
-                ( !bTstForDefault || (
-                    *pItem != rPool.GetDefaultItem( nWhich )
+                (   *pItem != rPool.GetDefaultItem( nWhich )
                     || ( pSet->GetParent() &&
                         *pItem != pSet->GetParent()->Get( nWhich ))
-                )) && nullptr != ( pOut = pTab[ nWhich - RES_CHRATR_BEGIN] ))
+                ))
+            {
+                if( nullptr != ( pOut = pTab[ nWhich - RES_CHRATR_BEGIN] ))
+                {
                     (*pOut)( rWrt, *pItem );
+                }
+                else if(XATTR_FILLSTYLE == pItem->Which())
+                {
+                    bFillItemUsed = true;
+                }
+            }
             nWhich = aIter.NextWhich();
         }
     }
+
+    if(bFillItemUsed)
+    {
+        // tdf#94088 if used, construct a SvxBrushItem and export it using the
+        // existing mechanisms.
+        // This is the right place in the future if the adapted fill attributes
+        // may be handled more directly in HTML export to handle them.
+        const SvxBrushItem aSvxBrushItem = getSvxBrushItemFromSourceSet(*pSet, RES_BACKGROUND, bDeep);
+
+        if( nullptr != ( pOut = pTab[RES_BACKGROUND - RES_CHRATR_BEGIN] ))
+        {
+            (*pOut)( rWrt, aSvxBrushItem );
+        }
+    }
+
     return rWrt;
 }
 
@@ -94,13 +133,13 @@ Writer& Out( const SwNodeFnTab pTab, SwNode& rNode, Writer & rWrt )
     sal_uInt16 nId = RES_TXTNODE;
     switch (pCNd->GetNodeType())
     {
-        case ND_TEXTNODE:
+        case SwNodeType::Text:
             nId = RES_TXTNODE;
              break;
-        case ND_GRFNODE:
+        case SwNodeType::Grf:
             nId = RES_GRFNODE;
             break;
-        case ND_OLENODE:
+        case SwNodeType::Ole:
             nId = RES_OLENODE;
             break;
         default:
