@@ -21,14 +21,18 @@
 
 #include <cassert>
 
-#include <com/sun/star/container/XIndexAccess.hpp>
 #include <com/sun/star/document/PrinterIndependentLayout.hpp>
 #include <com/sun/star/drawing/XDrawPage.hpp>
 #include <com/sun/star/drawing/XDrawPageSupplier.hpp>
-#include <com/sun/star/i18n/XForbiddenCharacters.hpp>
+#include <com/sun/star/frame/Desktop.hpp>
+#include <com/sun/star/frame/XSynchronousFrameLoader.hpp>
+#include <com/sun/star/io/IOException.hpp>
+#include <com/sun/star/lang/WrappedTargetRuntimeException.hpp>
 #include <com/sun/star/text/XTextDocument.hpp>
 #include <com/sun/star/text/XTextRange.hpp>
 
+#include <o3tl/any.hxx>
+#include <o3tl/safeint.hxx>
 #include <xmloff/xmlnmspe.hxx>
 #include <xmloff/xmltkmap.hxx>
 #include <xmloff/xmlictxt.hxx>
@@ -47,31 +51,38 @@
 #include <TextCursorHelper.hxx>
 #include <unotext.hxx>
 #include <unotextrange.hxx>
-#include "unocrsr.hxx"
+#include <unocrsr.hxx>
 #include <poolfmt.hxx>
 #include <ndtxt.hxx>
 #include <editsh.hxx>
+#include <strings.hrc>
 #include "xmlimp.hxx"
 #include "xmltexti.hxx"
+#include <swdll.hxx>
 #include <xmloff/DocumentSettingsContext.hxx>
 #include <docsh.hxx>
 #include <editeng/unolingu.hxx>
 #include <svx/svdmodel.hxx>
 #include <svx/xmlgrhlp.hxx>
 #include <svx/xmleohlp.hxx>
+#include <sfx2/docfile.hxx>
+#include <sfx2/docfilt.hxx>
+#include <sfx2/frame.hxx>
 #include <sfx2/printer.hxx>
 #include <xmloff/xmluconv.hxx>
 #include <unotools/saveopt.hxx>
+#include <unotools/streamwrap.hxx>
+#include <tools/helpers.hxx>
 #include <tools/diagnose_ex.h>
 
 #include <vcl/svapp.hxx>
-#include <osl/mutex.hxx>
 #include <unotxdoc.hxx>
 
 #include <xmloff/xmlmetai.hxx>
 #include <xmloff/xformsimport.hxx>
 #include <comphelper/servicehelper.hxx>
 #include <comphelper/processfactory.hxx>
+#include <comphelper/propertysequence.hxx>
 
 #include <unordered_set>
 
@@ -98,10 +109,9 @@ enum SwXMLDocTokens
     XML_TOK_DOC_SCRIPT,
     XML_TOK_DOC_SETTINGS,
     XML_TOK_DOC_XFORMS,
-    XML_TOK_OFFICE_END=XML_TOK_UNKNOWN
 };
 
-static SvXMLTokenMapEntry aDocTokenMap[] =
+static const SvXMLTokenMapEntry aDocTokenMap[] =
 {
     { XML_NAMESPACE_OFFICE, XML_FONT_FACE_DECLS,     XML_TOK_DOC_FONTDECLS  },
     { XML_NAMESPACE_OFFICE, XML_STYLES,         XML_TOK_DOC_STYLES      },
@@ -122,29 +132,44 @@ class SwXMLBodyContext_Impl : public SvXMLImportContext
 public:
 
     SwXMLBodyContext_Impl( SwXMLImport& rImport, sal_uInt16 nPrfx,
-                const OUString& rLName,
-                const Reference< xml::sax::XAttributeList > & xAttrList );
-    virtual ~SwXMLBodyContext_Impl();
+                const OUString& rLName );
 
-
-    virtual SvXMLImportContext *CreateChildContext( sal_uInt16 nPrefix,
+    virtual SvXMLImportContextRef CreateChildContext( sal_uInt16 nPrefix,
                 const OUString& rLocalName,
                 const Reference< xml::sax::XAttributeList > & xAttrList ) override;
 };
 
 SwXMLBodyContext_Impl::SwXMLBodyContext_Impl( SwXMLImport& rImport,
-                sal_uInt16 nPrfx, const OUString& rLName,
-                const Reference< xml::sax::XAttributeList > & /*xAttrList*/ ) :
+                sal_uInt16 nPrfx, const OUString& rLName) :
     SvXMLImportContext( rImport, nPrfx, rLName )
 {
+    // tdf#107211: if at this point we don't have a defined char style "Default"
+    // or "Default Style", add a mapping for it as it is not written
+    // into the file since it's not really a style but "no style"
+    // (hence referencing it actually makes no sense except for hyperlinks
+    // which default to something other than "Default")
+    OUString const sDefault(SwResId(STR_POOLCOLL_STANDARD));
+    uno::Reference<container::XNameContainer> const& xStyles(
+            rImport.GetTextImport()->GetTextStyles());
+    if (!xStyles->hasByName("Default"))
+    {   // this old name was used before LO 4.0
+        rImport.AddStyleDisplayName(XML_STYLE_FAMILY_TEXT_TEXT, "Default", sDefault);
+    }
+    if (!xStyles->hasByName("Default_20_Style"))
+    {   // this new name contains a space which is converted to _20_ on export
+        rImport.AddStyleDisplayName(XML_STYLE_FAMILY_TEXT_TEXT, "Default_20_Style", sDefault);
+    }
+    bool isEncoded(false);
+    OUString const defaultEncoded(
+        rImport.GetMM100UnitConverter().encodeStyleName(sDefault, &isEncoded));
+    if (isEncoded && defaultEncoded != "Default_20_Style"
+        && !xStyles->hasByName(defaultEncoded))
+    {   // new name may contain a space which is converted to _20_ on export
+        rImport.AddStyleDisplayName(XML_STYLE_FAMILY_TEXT_TEXT, defaultEncoded, sDefault);
+    }
 }
 
-SwXMLBodyContext_Impl::~SwXMLBodyContext_Impl()
-{
-}
-
-
-SvXMLImportContext *SwXMLBodyContext_Impl::CreateChildContext(
+SvXMLImportContextRef SwXMLBodyContext_Impl::CreateChildContext(
         sal_uInt16 /*nPrefix*/,
         const OUString& rLocalName,
         const Reference< xml::sax::XAttributeList > & /*xAttrList*/ )
@@ -165,29 +190,20 @@ protected: // #i69629#
 public:
 
     SwXMLDocContext_Impl( SwXMLImport& rImport, sal_uInt16 nPrfx,
-                const OUString& rLName,
-                const Reference< xml::sax::XAttributeList > & xAttrList );
-    virtual ~SwXMLDocContext_Impl();
+                const OUString& rLName );
 
-
-    virtual SvXMLImportContext *CreateChildContext( sal_uInt16 nPrefix,
+    virtual SvXMLImportContextRef CreateChildContext( sal_uInt16 nPrefix,
                 const OUString& rLocalName,
                 const Reference< xml::sax::XAttributeList > & xAttrList ) override;
 };
 
 SwXMLDocContext_Impl::SwXMLDocContext_Impl( SwXMLImport& rImport,
-                sal_uInt16 nPrfx, const OUString& rLName,
-                const Reference< xml::sax::XAttributeList > & /*xAttrList*/ ) :
+                sal_uInt16 nPrfx, const OUString& rLName ) :
     SvXMLImportContext( rImport, nPrfx, rLName )
 {
 }
 
-SwXMLDocContext_Impl::~SwXMLDocContext_Impl()
-{
-}
-
-
-SvXMLImportContext *SwXMLDocContext_Impl::CreateChildContext(
+SvXMLImportContextRef SwXMLDocContext_Impl::CreateChildContext(
         sal_uInt16 nPrefix,
         const OUString& rLocalName,
         const Reference< xml::sax::XAttributeList > & xAttrList )
@@ -228,7 +244,7 @@ SvXMLImportContext *SwXMLDocContext_Impl::CreateChildContext(
     case XML_TOK_DOC_BODY:
         GetSwImport().GetProgressBarHelper()->Increment( PROGRESS_BAR_STEP );
         pContext = new SwXMLBodyContext_Impl( GetSwImport(), nPrefix,
-                                              rLocalName, xAttrList );
+                                              rLocalName );
         break;
     case XML_TOK_DOC_SETTINGS:
         pContext = new XMLDocumentSettingsContext( GetImport(), nPrefix, rLocalName, xAttrList );
@@ -253,12 +269,9 @@ public:
     SwXMLOfficeDocContext_Impl( SwXMLImport& rImport,
                 sal_uInt16 nPrfx,
                 const OUString& rLName,
-                const Reference< xml::sax::XAttributeList > & xAttrList,
                 const Reference< document::XDocumentProperties >& xDocProps);
-    virtual ~SwXMLOfficeDocContext_Impl();
 
-
-    virtual SvXMLImportContext *CreateChildContext(
+    virtual SvXMLImportContextRef CreateChildContext(
                 sal_uInt16 nPrefix,
                 const OUString& rLocalName,
                 const Reference< xml::sax::XAttributeList > & xAttrList ) override;
@@ -268,20 +281,14 @@ SwXMLOfficeDocContext_Impl::SwXMLOfficeDocContext_Impl(
                 SwXMLImport& rImport,
                 sal_uInt16 nPrfx,
                 const OUString& rLName,
-                const Reference< xml::sax::XAttributeList > & xAttrList,
                 const Reference< document::XDocumentProperties >& xDocProps) :
     SvXMLImportContext( rImport, nPrfx, rLName ),
-    SwXMLDocContext_Impl( rImport, nPrfx, rLName, xAttrList ),
+    SwXMLDocContext_Impl( rImport, nPrfx, rLName ),
     SvXMLMetaDocumentContext( rImport, nPrfx, rLName, xDocProps)
 {
 }
 
-SwXMLOfficeDocContext_Impl::~SwXMLOfficeDocContext_Impl()
-{
-}
-
-
-SvXMLImportContext* SwXMLOfficeDocContext_Impl::CreateChildContext(
+SvXMLImportContextRef SwXMLOfficeDocContext_Impl::CreateChildContext(
                 sal_uInt16 nPrefix,
                 const OUString& rLocalName,
                 const Reference< xml::sax::XAttributeList > & xAttrList )
@@ -315,10 +322,7 @@ public:
 
     SwXMLDocStylesContext_Impl( SwXMLImport& rImport,
                                 sal_uInt16 nPrfx,
-                                const OUString& rLName,
-                                const Reference< xml::sax::XAttributeList > & xAttrList );
-    virtual ~SwXMLDocStylesContext_Impl();
-
+                                const OUString& rLName );
 
     virtual void EndElement() override;
 };
@@ -326,18 +330,12 @@ public:
 SwXMLDocStylesContext_Impl::SwXMLDocStylesContext_Impl(
                     SwXMLImport& rImport,
                     sal_uInt16 nPrfx,
-                    const OUString& rLName,
-                    const Reference< xml::sax::XAttributeList > & xAttrList ) :
+                    const OUString& rLName ) :
     SvXMLImportContext( rImport, nPrfx, rLName ),
-    SwXMLDocContext_Impl( rImport, nPrfx, rLName, xAttrList )
+    SwXMLDocContext_Impl( rImport, nPrfx, rLName )
 {
 }
 
-SwXMLDocStylesContext_Impl::~SwXMLDocStylesContext_Impl()
-{
-}
-
-
 void SwXMLDocStylesContext_Impl::EndElement()
 {
     // assign paragraph styles to list levels of outline style after all styles
@@ -366,8 +364,7 @@ SvXMLImportContext *SwXMLImport::CreateContext(
     if( XML_NAMESPACE_OFFICE==nPrefix &&
         ( IsXMLToken( rLocalName, XML_DOCUMENT_SETTINGS ) ||
           IsXMLToken( rLocalName, XML_DOCUMENT_CONTENT ) ))
-        pContext = new SwXMLDocContext_Impl( *this, nPrefix, rLocalName,
-                                             xAttrList );
+        pContext = new SwXMLDocContext_Impl( *this, nPrefix, rLocalName );
     else if ( XML_NAMESPACE_OFFICE==nPrefix &&
               IsXMLToken( rLocalName, XML_DOCUMENT_META ) )
     {
@@ -376,8 +373,7 @@ SvXMLImportContext *SwXMLImport::CreateContext(
     else if ( XML_NAMESPACE_OFFICE==nPrefix &&
               IsXMLToken( rLocalName, XML_DOCUMENT_STYLES ) )
     {
-        pContext = new SwXMLDocStylesContext_Impl( *this, nPrefix, rLocalName,
-                                                   xAttrList );
+        pContext = new SwXMLDocStylesContext_Impl( *this, nPrefix, rLocalName );
     }
     else if ( XML_NAMESPACE_OFFICE==nPrefix &&
               IsXMLToken( rLocalName, XML_DOCUMENT ) )
@@ -386,7 +382,7 @@ SvXMLImportContext *SwXMLImport::CreateContext(
             GetDocumentProperties());
         // flat OpenDocument file format
         pContext = new SwXMLOfficeDocContext_Impl( *this, nPrefix, rLocalName,
-                        xAttrList, xDocProps);
+                        xDocProps);
     }
     else
         pContext = SvXMLImport::CreateContext( nPrefix, rLocalName, xAttrList );
@@ -402,20 +398,15 @@ SwXMLImport::SwXMLImport(
     m_pDocElemTokenMap( nullptr ),
     m_pTableElemTokenMap( nullptr ),
     m_pTableCellAttrTokenMap( nullptr ),
-    m_pGraphicResolver( nullptr ),
-    m_pEmbeddedResolver( nullptr ),
     m_nStyleFamilyMask( SfxStyleFamily::All ),
     m_bLoadDoc( true ),
     m_bInsert( false ),
     m_bBlock( false ),
-    m_bShowProgress( true ),
     m_bOrganizerMode( false ),
     m_bInititedXForms( false ),
-    m_bPreserveRedlineMode( true ),
     m_pDoc( nullptr )
 {
     InitItemImport();
-
 }
 
 SwXMLImport::~SwXMLImport() throw ()
@@ -445,16 +436,6 @@ void SwXMLImport::setStyleInsertMode( SfxStyleFamily nFamilies,
     m_bLoadDoc = false;
 }
 
-void SwXMLImport::setBlockMode( )
-{
-    m_bBlock = true;
-}
-
-void SwXMLImport::setOrganizerMode( )
-{
-    m_bOrganizerMode = true;
-}
-
 namespace
 {
     class theSwXMLImportUnoTunnelId : public rtl::Static< UnoTunnelIdInit, theSwXMLImportUnoTunnelId > {};
@@ -466,7 +447,6 @@ const Sequence< sal_Int8 > & SwXMLImport::getUnoTunnelId() throw()
 }
 
 sal_Int64 SAL_CALL SwXMLImport::getSomething( const Sequence< sal_Int8 >& rId )
-    throw(RuntimeException, std::exception)
 {
     if( rId.getLength() == 16
         && 0 == memcmp( getUnoTunnelId().getConstArray(),
@@ -490,9 +470,6 @@ static OTextCursorHelper *lcl_xml_GetSwXTextCursor( const Reference < XTextCurso
 }
 
 void SwXMLImport::startDocument()
-    throw (xml::sax::SAXException,
-           uno::RuntimeException,
-           std::exception)
 {
     // delegate to parent
     SvXMLImport::startDocument();
@@ -542,9 +519,11 @@ void SwXMLImport::startDocument()
                 if( xPropertySetInfo->hasPropertyByName(sStyleInsertModeOverwrite) )
                 {
                     aAny = xImportInfo->getPropertyValue(sStyleInsertModeOverwrite);
-                    if( aAny.getValueType() == cppu::UnoType<bool>::get() &&
-                        *static_cast<const sal_Bool*>(aAny.getValue()) )
-                        bOverwrite = true;
+                    if( auto b = o3tl::tryAccess<bool>(aAny) )
+                    {
+                        if( *b )
+                            bOverwrite = true;
+                    }
                 }
 
                 setStyleInsertMode( nFamilyMask, bOverwrite );
@@ -566,9 +545,11 @@ void SwXMLImport::startDocument()
         if( xPropertySetInfo->hasPropertyByName(sAutoTextMode) )
         {
             aAny = xImportInfo->getPropertyValue(sAutoTextMode);
-            if( aAny.getValueType() == cppu::UnoType<bool>::get() &&
-                *static_cast<const sal_Bool*>(aAny.getValue()) )
-                    setBlockMode();
+            if( auto b = o3tl::tryAccess<bool>(aAny) )
+            {
+                if( *b )
+                    m_bBlock = true;
+            }
         }
 
         // organizer mode
@@ -576,9 +557,11 @@ void SwXMLImport::startDocument()
         if( xPropertySetInfo->hasPropertyByName(sOrganizerMode) )
         {
             aAny = xImportInfo->getPropertyValue(sOrganizerMode);
-            if( aAny.getValueType() == cppu::UnoType<bool>::get() &&
-                *static_cast<const sal_Bool*>(aAny.getValue()) )
-                    setOrganizerMode();
+            if( auto b = o3tl::tryAccess<bool>(aAny) )
+            {
+                if( *b )
+                    m_bOrganizerMode = true;
+            }
         }
     }
 
@@ -629,7 +612,7 @@ void SwXMLImport::startDocument()
             GetTextImport()->SetCursor( xTextCursor );
     }
 
-    if( (!(getImportFlags() & (SvXMLImportFlags::CONTENT|SvXMLImportFlags::MASTERSTYLES))))
+    if( !(getImportFlags() & (SvXMLImportFlags::CONTENT|SvXMLImportFlags::MASTERSTYLES)) )
         return;
 
     if( !pTextCursor  )
@@ -675,16 +658,15 @@ void SwXMLImport::startDocument()
     // We need a draw model to be able to set the z order
     pDoc->getIDocumentDrawModelAccess().GetOrCreateDrawModel(); // #i52858# - method name changed
 
-    // SJ: #i49801# locking the modell to disable repaints
+    // SJ: #i49801# locking the model to disable repaints
     SwDrawModel* pDrawModel = pDoc->getIDocumentDrawModelAccess().GetDrawModel();
     if ( pDrawModel )
         pDrawModel->setLock(true);
 
     if( !GetGraphicResolver().is() )
     {
-        m_pGraphicResolver = SvXMLGraphicHelper::Create( GRAPHICHELPER_MODE_READ );
-        Reference< document::XGraphicObjectResolver > xGraphicResolver( m_pGraphicResolver );
-        SetGraphicResolver( xGraphicResolver );
+        m_xGraphicResolver = SvXMLGraphicHelper::Create( SvXMLGraphicHelperMode::Read );
+        SetGraphicResolver( m_xGraphicResolver.get() );
     }
 
     if( !GetEmbeddedResolver().is() )
@@ -692,17 +674,16 @@ void SwXMLImport::startDocument()
         SfxObjectShell *pPersist = pDoc->GetPersist();
         if( pPersist )
         {
-            m_pEmbeddedResolver = SvXMLEmbeddedObjectHelper::Create(
+            m_xEmbeddedResolver = SvXMLEmbeddedObjectHelper::Create(
                                             *pPersist,
-                                            EMBEDDEDOBJECTHELPER_MODE_READ );
-            Reference< document::XEmbeddedObjectResolver > xEmbeddedResolver( m_pEmbeddedResolver );
+                                            SvXMLEmbeddedObjectHelperMode::Read );
+            Reference< document::XEmbeddedObjectResolver > xEmbeddedResolver( m_xEmbeddedResolver.get() );
             SetEmbeddedResolver( xEmbeddedResolver );
         }
     }
 }
 
 void SwXMLImport::endDocument()
-    throw( xml::sax::SAXException, uno::RuntimeException, std::exception )
 {
     OSL_ENSURE( GetModel().is(), "model missing; maybe startDocument wasn't called?" );
     if( !GetModel().is() )
@@ -711,10 +692,12 @@ void SwXMLImport::endDocument()
     // this method will modify the document directly -> lock SolarMutex
     SolarMutexGuard aGuard;
 
-    if( m_pGraphicResolver )
-        SvXMLGraphicHelper::Destroy( m_pGraphicResolver );
-    if( m_pEmbeddedResolver )
-        SvXMLEmbeddedObjectHelper::Destroy( m_pEmbeddedResolver );
+    if( m_xGraphicResolver )
+        m_xGraphicResolver->dispose();
+    m_xGraphicResolver.clear();
+    if( m_xEmbeddedResolver )
+        m_xEmbeddedResolver->dispose();
+    m_xEmbeddedResolver.clear();
     // Clear the shape import to sort the shapes  (and not in the
     // destructor that might be called after the import has finished
     // for Java filters.
@@ -865,7 +848,7 @@ void SwXMLImport::endDocument()
     // SJ: #i49801# -> now permitting repaints
     if ( pDoc )
     {
-        if( (getImportFlags() == SvXMLImportFlags::ALL ) )
+        if( getImportFlags() == SvXMLImportFlags::ALL )
         {
             // Notify math objects. If we are in the package filter this will
             // be done by the filter object itself
@@ -935,7 +918,7 @@ class SvTextShapeImportHelper : public XMLTextShapeImportHelper
 
 public:
     explicit SvTextShapeImportHelper(SvXMLImport& rImp);
-    virtual ~SvTextShapeImportHelper();
+    virtual ~SvTextShapeImportHelper() override;
 };
 
 SvTextShapeImportHelper::SvTextShapeImportHelper(SvXMLImport& rImp) :
@@ -971,9 +954,8 @@ XMLTextImportHelper* SwXMLImport::CreateTextImport()
 {
     return new SwXMLTextImportHelper( GetModel(), *this, getImportInfo(),
                                       IsInsertMode(),
-                                      IsStylesOnlyMode(), m_bShowProgress,
-                                      IsBlockMode(), IsOrganizerMode(),
-                                      m_bPreserveRedlineMode );
+                                      IsStylesOnlyMode(),
+                                      IsBlockMode(), m_bOrganizerMode );
 }
 
 XMLShapeImportHelper* SwXMLImport::CreateShapeImport()
@@ -992,16 +974,17 @@ SvXMLImportContext *SwXMLImport::CreateFontDeclsContext(
     SetFontDecls( pFSContext );
     return pFSContext;
 }
+
 void SwXMLImport::SetViewSettings(const Sequence < PropertyValue > & aViewProps)
 {
-    if (IsInsertMode() || IsStylesOnlyMode() || IsBlockMode() || IsOrganizerMode() || !GetModel().is() )
+    if (IsInsertMode() || IsStylesOnlyMode() || IsBlockMode() || m_bOrganizerMode || !GetModel().is() )
         return;
 
     // this method will modify the document directly -> lock SolarMutex
     SolarMutexGuard aGuard;
 
     SwDoc *pDoc = getDoc();
-    Rectangle aRect;
+    tools::Rectangle aRect;
     if( pDoc->GetDocShell() )
         aRect = pDoc->GetDocShell()->GetVisArea( ASPECT_CONTENT );
         //TODO/LATER: why that cast?!
@@ -1015,44 +998,44 @@ void SwXMLImport::SetViewSettings(const Sequence < PropertyValue > & aViewProps)
     bool bChangeShowRedline = false, bChangeBrowseMode = false;
 
     //TODO/LATER: why that cast?!
-    bool bTwip = pDoc->GetDocShell()->GetMapUnit ( ) == MAP_TWIP;
-    //sal_Bool bTwip = pDoc->GetDocShell()->SfxInPlaceObject::GetMapUnit ( ) == MAP_TWIP;
+    bool bTwip = pDoc->GetDocShell()->GetMapUnit ( ) == MapUnit::MapTwip;
+    //sal_Bool bTwip = pDoc->GetDocShell()->SfxInPlaceObject::GetMapUnit ( ) == MapUnit::MapTwip;
 
     for (sal_Int32 i = 0; i < nCount ; i++)
     {
         if ( pValue->Name == "ViewAreaTop" )
         {
             pValue->Value >>= nTmp;
-            aRect.setY( static_cast< long >(bTwip ? convertMm100ToTwip ( nTmp ) : nTmp) );
+            aRect.setY( static_cast< long >(bTwip ? sanitiseMm100ToTwip(nTmp) : nTmp) );
         }
         else if ( pValue->Name == "ViewAreaLeft" )
         {
             pValue->Value >>= nTmp;
-            aRect.setX( static_cast< long >(bTwip ? convertMm100ToTwip ( nTmp ) : nTmp) );
+            aRect.setX( static_cast< long >(bTwip ? sanitiseMm100ToTwip(nTmp) : nTmp) );
         }
         else if ( pValue->Name == "ViewAreaWidth" )
         {
             pValue->Value >>= nTmp;
             Size aSize( aRect.GetSize() );
-            aSize.Width() = static_cast< long >(bTwip ? convertMm100ToTwip ( nTmp ) : nTmp);
+            aSize.Width() = static_cast< long >(bTwip ? sanitiseMm100ToTwip(nTmp) : nTmp);
             aRect.SetSize( aSize );
         }
         else if ( pValue->Name == "ViewAreaHeight" )
         {
             pValue->Value >>= nTmp;
             Size aSize( aRect.GetSize() );
-            aSize.Height() = static_cast< long >(bTwip ? convertMm100ToTwip ( nTmp ) : nTmp);
+            aSize.Height() = static_cast< long >(bTwip ? sanitiseMm100ToTwip(nTmp) : nTmp);
             aRect.SetSize( aSize );
         }
         else if ( pValue->Name == "ShowRedlineChanges" )
         {
-            bShowRedlineChanges = *static_cast<sal_Bool const *>(pValue->Value.getValue());
+            bShowRedlineChanges = *o3tl::doAccess<bool>(pValue->Value);
             bChangeShowRedline = true;
         }
 // Headers and footers are not displayed in BrowseView anymore
         else if ( pValue->Name == "InBrowseMode" )
         {
-            bBrowseMode = *static_cast<sal_Bool const *>(pValue->Value.getValue());
+            bBrowseMode = *o3tl::doAccess<bool>(pValue->Value);
             bChangeBrowseMode = true;
         }
         pValue++;
@@ -1087,9 +1070,9 @@ void SwXMLImport::SetConfigurationSettings(const Sequence < PropertyValue > & aC
     if( !xInfo.is() )
         return;
 
-    std::unordered_set< OUString, OUStringHash > aExcludeAlways;
+    std::unordered_set< OUString > aExcludeAlways;
     aExcludeAlways.insert("LinkUpdateMode");
-    std::unordered_set< OUString, OUStringHash > aExcludeWhenNotLoadingUserSettings;
+    std::unordered_set< OUString > aExcludeWhenNotLoadingUserSettings;
     aExcludeWhenNotLoadingUserSettings.insert("ForbiddenCharacters");
     aExcludeWhenNotLoadingUserSettings.insert("IsKernAsianPunctuation");
     aExcludeWhenNotLoadingUserSettings.insert("CharacterCompressionType");
@@ -1122,6 +1105,7 @@ void SwXMLImport::SetConfigurationSettings(const Sequence < PropertyValue > & aC
     aExcludeWhenNotLoadingUserSettings.insert("TabOverMargin");
     aExcludeWhenNotLoadingUserSettings.insert("PropLineSpacingShrinksFirstLine");
     aExcludeWhenNotLoadingUserSettings.insert("SubtractFlysAnchoredAtFlys");
+    aExcludeWhenNotLoadingUserSettings.insert("DisableOffPagePositioning");
 
     sal_Int32 nCount = aConfigProps.getLength();
     const PropertyValue* pValues = aConfigProps.getConstArray();
@@ -1134,7 +1118,6 @@ void SwXMLImport::SetConfigurationSettings(const Sequence < PropertyValue > & aC
     // below, and set them if not found
     bool bPrinterIndependentLayout = false;
     bool bUseOldNumbering = false;
-    bool bOutlineLevelYieldsOutlineRule = false;
     bool bAddExternalLeading = false;
     bool bAddParaSpacingToTableCells = false;
     bool bUseFormerLineSpacing = false;
@@ -1148,7 +1131,6 @@ void SwXMLImport::SetConfigurationSettings(const Sequence < PropertyValue > & aC
     bool bDoNotCaptureDrawObjsOnPage( false );
     bool bClipAsCharacterAnchoredWriterFlyFrames( false );
     bool bUnixForceZeroExtLeading = false;
-    bool bUseOldPrinterMetrics = false;
     bool bSmallCapsPercentage66 = false;
     bool bTabOverflow = false;
     bool bUnbreakableNumberings = false;
@@ -1157,6 +1139,7 @@ void SwXMLImport::SetConfigurationSettings(const Sequence < PropertyValue > & aC
     bool bTabOverMargin = false;
     bool bPropLineSpacingShrinksFirstLine = false;
     bool bSubtractFlysAnchoredAtFlys = false;
+    bool bDisableOffPagePositioning = false;
 
     const PropertyValue* currentDatabaseDataSource = nullptr;
     const PropertyValue* currentDatabaseCommand = nullptr;
@@ -1217,8 +1200,6 @@ void SwXMLImport::SetConfigurationSettings(const Sequence < PropertyValue > & aC
                     bUseFormerTextWrapping = true;
                 else if ( pValues->Name == "UseOldNumbering" )
                     bUseOldNumbering = true;
-                else if ( pValues->Name == "OutlineLevelYieldsNumbering" )
-                    bOutlineLevelYieldsOutlineRule = true;
                 else if ( pValues->Name == "ConsiderTextWrapOnObjPos" )
                     bConsiderWrapOnObjPos = true;
                 else if ( pValues->Name == "IgnoreFirstLineIndentInNumbering" )
@@ -1235,8 +1216,6 @@ void SwXMLImport::SetConfigurationSettings(const Sequence < PropertyValue > & aC
                     bClipAsCharacterAnchoredWriterFlyFrames = true;
                 else if ( pValues->Name == "UnxForceZeroExtLeading" )
                     bUnixForceZeroExtLeading = true;
-                else if ( pValues->Name == "UseOldPrinterMetrics" )
-                    bUseOldPrinterMetrics = true;
                 else if ( pValues->Name == "SmallCapsPercentage66" )
                     bSmallCapsPercentage66 = true;
                 else if ( pValues->Name == "TabOverflow" )
@@ -1253,6 +1232,8 @@ void SwXMLImport::SetConfigurationSettings(const Sequence < PropertyValue > & aC
                     bPropLineSpacingShrinksFirstLine = true;
                 else if (pValues->Name == "SubtractFlysAnchoredAtFlys")
                     bSubtractFlysAnchoredAtFlys = true;
+                else if (pValues->Name == "DisableOffPagePositioning")
+                    bDisableOffPagePositioning = true;
             }
             catch( Exception& )
             {
@@ -1283,8 +1264,7 @@ void SwXMLImport::SetConfigurationSettings(const Sequence < PropertyValue > & aC
 
     if( ! bPrinterIndependentLayout )
     {
-        sal_Int16 nTmp = document::PrinterIndependentLayout::DISABLED;
-        xProps->setPropertyValue( "PrinterIndependentLayout", Any(nTmp) );
+        xProps->setPropertyValue( "PrinterIndependentLayout", Any(sal_Int16(document::PrinterIndependentLayout::DISABLED)) );
     }
 
     if( ! bAddExternalLeading )
@@ -1307,11 +1287,6 @@ void SwXMLImport::SetConfigurationSettings(const Sequence < PropertyValue > & aC
         xProps->setPropertyValue( "UseOldNumbering", makeAny(true) );
     }
 
-    if( !bOutlineLevelYieldsOutlineRule )
-    {
-        xProps->setPropertyValue( "OutlineLevelYieldsNumbering", makeAny(true) );
-    }
-
     if( !bAddParaSpacingToTableCells )
     {
         xProps->setPropertyValue( "AddParaSpacingToTableCells",
@@ -1383,11 +1358,6 @@ void SwXMLImport::SetConfigurationSettings(const Sequence < PropertyValue > & aC
         xProps->setPropertyValue( "UnxForceZeroExtLeading", makeAny( true ) );
     }
 
-    if ( !bUseOldPrinterMetrics )
-    {
-        xProps->setPropertyValue( "UseOldPrinterMetrics", makeAny( true ) );
-    }
-
     // Old LO versions had 66 as the value for small caps percentage, later changed to 80.
     // In order to keep backwards compatibility, SmallCapsPercentage66 option is written to .odt
     // files, and the default for new documents is 'false'. Files without this option
@@ -1424,6 +1394,9 @@ void SwXMLImport::SetConfigurationSettings(const Sequence < PropertyValue > & aC
     if (!bSubtractFlysAnchoredAtFlys)
         xProps->setPropertyValue("SubtractFlysAnchoredAtFlys", makeAny(true));
 
+    if ( !bDisableOffPagePositioning )
+        xProps->setPropertyValue("DisableOffPagePositioning", makeAny(true));
+
     SwDoc *pDoc = getDoc();
     SfxPrinter *pPrinter = pDoc->getIDocumentDeviceAccess().getPrinter( false );
     if( pPrinter )
@@ -1468,25 +1441,14 @@ void SwXMLImport::SetDocumentSpecificSettings(
 
 void SwXMLImport::initialize(
     const Sequence<Any>& aArguments )
-    throw( uno::Exception, uno::RuntimeException, std::exception)
 {
     // delegate to super class
     SvXMLImport::initialize(aArguments);
 
-    // we are only looking for a PropertyValue "PreserveRedlineMode"
+    // we are only looking for a NamedValue "LateInitSettings"
     sal_Int32 nLength = aArguments.getLength();
     for(sal_Int32 i = 0; i < nLength; i++)
     {
-        beans::PropertyValue aValue;
-        if ( aArguments[i] >>= aValue )
-        {
-            if (aValue.Name == "PreserveRedlineMode")
-            {
-                OSL_VERIFY( aValue.Value >>= m_bPreserveRedlineMode );
-            }
-            continue;
-        }
-
         beans::NamedValue aNamedValue;
         if ( aArguments[i] >>= aNamedValue )
         {
@@ -1498,7 +1460,7 @@ void SwXMLImport::initialize(
     }
 }
 
-SwDoc* SwImport::GetDocFromXMLImport( SvXMLImport& rImport )
+SwDoc* SwImport::GetDocFromXMLImport( SvXMLImport const & rImport )
 {
     uno::Reference<lang::XUnoTunnel> xModelTunnel( rImport.GetModel(), uno::UNO_QUERY );
     SwXTextDocument *pTextDoc = reinterpret_cast< SwXTextDocument *>(
@@ -1556,7 +1518,7 @@ extern "C" SAL_DLLPUBLIC_EXPORT css::uno::XInterface* SAL_CALL
 com_sun_star_comp_Writer_XMLOasisImporter_get_implementation(css::uno::XComponentContext* context,
         css::uno::Sequence<css::uno::Any> const &)
 {
-    return cppu::acquire(new SwXMLImport(context, OUString("com.sun.star.comp.Writer.XMLOasisImporter"),
+    return cppu::acquire(new SwXMLImport(context, "com.sun.star.comp.Writer.XMLOasisImporter",
                 SvXMLImportFlags::ALL));
 }
 
@@ -1565,7 +1527,7 @@ extern "C" SAL_DLLPUBLIC_EXPORT css::uno::XInterface* SAL_CALL
 com_sun_star_comp_Writer_XMLOasisStylesImporter_get_implementation(css::uno::XComponentContext* context,
         css::uno::Sequence<css::uno::Any> const &)
 {
-    return cppu::acquire(new SwXMLImport(context, OUString("com.sun.star.comp.Writer.XMLOasisStylesImporter"),
+    return cppu::acquire(new SwXMLImport(context, "com.sun.star.comp.Writer.XMLOasisStylesImporter",
                 SvXMLImportFlags::STYLES | SvXMLImportFlags::MASTERSTYLES | SvXMLImportFlags::AUTOSTYLES |
                 SvXMLImportFlags::FONTDECLS));
 }
@@ -1575,7 +1537,7 @@ extern "C" SAL_DLLPUBLIC_EXPORT css::uno::XInterface* SAL_CALL
 com_sun_star_comp_Writer_XMLOasisContentImporter_get_implementation(css::uno::XComponentContext* context,
         css::uno::Sequence<css::uno::Any> const &)
 {
-    return cppu::acquire(new SwXMLImport(context, OUString("com.sun.star.comp.Writer.XMLOasisContentImporter"),
+    return cppu::acquire(new SwXMLImport(context, "com.sun.star.comp.Writer.XMLOasisContentImporter",
                 SvXMLImportFlags::CONTENT | SvXMLImportFlags::SCRIPTS | SvXMLImportFlags::AUTOSTYLES |
                 SvXMLImportFlags::FONTDECLS));
 }
@@ -1584,7 +1546,7 @@ extern "C" SAL_DLLPUBLIC_EXPORT css::uno::XInterface* SAL_CALL
 com_sun_star_comp_Writer_XMLOasisMetaImporter_get_implementation(css::uno::XComponentContext* context,
         css::uno::Sequence<css::uno::Any> const &)
 {
-    return cppu::acquire(new SwXMLImport(context, OUString("com.sun.star.comp.Writer.XMLOasisMetaImporter"),
+    return cppu::acquire(new SwXMLImport(context, "com.sun.star.comp.Writer.XMLOasisMetaImporter",
                 SvXMLImportFlags::META));
 }
 
@@ -1593,7 +1555,101 @@ extern "C" SAL_DLLPUBLIC_EXPORT css::uno::XInterface* SAL_CALL
 com_sun_star_comp_Writer_XMLOasisSettingsImporter_get_implementation(css::uno::XComponentContext* context,
         css::uno::Sequence<css::uno::Any> const &)
 {
-    return cppu::acquire(new SwXMLImport(context, OUString("com.sun.star.comp.Writer.XMLOasisSettingsImporter"),
+    return cppu::acquire(new SwXMLImport(context, "com.sun.star.comp.Writer.XMLOasisSettingsImporter",
                 SvXMLImportFlags::SETTINGS));
 }
+
+extern "C" SAL_DLLPUBLIC_EXPORT bool SAL_CALL TestImportFODT(SvStream &rStream)
+{
+    SwGlobals::ensure();
+
+    SfxObjectShellLock xDocSh(new SwDocShell(SfxObjectCreateMode::INTERNAL));
+    xDocSh->DoInitNew();
+    uno::Reference<frame::XModel> xModel(xDocSh->GetModel());
+
+    uno::Reference<lang::XMultiServiceFactory> xMultiServiceFactory(comphelper::getProcessServiceFactory());
+    uno::Reference<io::XInputStream> xStream(new utl::OSeekableInputStreamWrapper(rStream));
+    uno::Reference<uno::XInterface> xInterface(xMultiServiceFactory->createInstance("com.sun.star.comp.Writer.XmlFilterAdaptor"), uno::UNO_QUERY_THROW);
+
+    css::uno::Sequence<OUString> aUserData(7);
+    aUserData[0] = "com.sun.star.comp.filter.OdfFlatXml";
+    aUserData[2] = "com.sun.star.comp.Writer.XMLOasisImporter";
+    aUserData[3] = "com.sun.star.comp.Writer.XMLOasisExporter";
+    aUserData[6] = "true";
+    uno::Sequence<beans::PropertyValue> aAdaptorArgs(comphelper::InitPropertySequence(
+    {
+        { "UserData", uno::Any(aUserData) },
+    }));
+    css::uno::Sequence<uno::Any> aOuterArgs(1);
+    aOuterArgs[0] <<= aAdaptorArgs;
+
+    uno::Reference<lang::XInitialization> xInit(xInterface, uno::UNO_QUERY_THROW);
+    xInit->initialize(aOuterArgs);
+
+    uno::Reference<document::XImporter> xImporter(xInterface, uno::UNO_QUERY_THROW);
+    uno::Sequence<beans::PropertyValue> aArgs(comphelper::InitPropertySequence(
+    {
+        { "InputStream", uno::Any(xStream) },
+        { "URL", uno::Any(OUString("private:stream")) },
+    }));
+    xImporter->setTargetDocument(xModel);
+
+    uno::Reference<document::XFilter> xFilter(xInterface, uno::UNO_QUERY_THROW);
+    //SetLoading hack because the document properties will be re-initted
+    //by the xml filter and during the init, while its considered uninitialized,
+    //setting a property will inform the document its modified, which attempts
+    //to update the properties, which throws cause the properties are uninitialized
+    xDocSh->SetLoading(SfxLoadedFlags::NONE);
+    bool ret = xFilter->filter(aArgs);
+    xDocSh->SetLoading(SfxLoadedFlags::ALL);
+
+    xDocSh->DoClose();
+
+    return ret;
+}
+
+extern "C" SAL_DLLPUBLIC_EXPORT bool SAL_CALL TestImportDOCX(SvStream &rStream)
+{
+    SwGlobals::ensure();
+
+    SfxObjectShellLock xDocSh(new SwDocShell(SfxObjectCreateMode::INTERNAL));
+    xDocSh->DoInitNew();
+    uno::Reference<frame::XModel> xModel(xDocSh->GetModel());
+
+    uno::Reference<lang::XMultiServiceFactory> xMultiServiceFactory(comphelper::getProcessServiceFactory());
+    uno::Reference<io::XInputStream> xStream(new utl::OSeekableInputStreamWrapper(rStream));
+
+    uno::Reference<document::XFilter> xFilter(xMultiServiceFactory->createInstance("com.sun.star.comp.Writer.WriterFilter"), uno::UNO_QUERY_THROW);
+
+    uno::Reference<document::XImporter> xImporter(xFilter, uno::UNO_QUERY_THROW);
+    uno::Sequence<beans::PropertyValue> aArgs(comphelper::InitPropertySequence(
+    {
+        { "InputStream", uno::makeAny(xStream) },
+        { "InputMode", uno::makeAny(true) },
+    }));
+    xImporter->setTargetDocument(xModel);
+
+    //SetLoading hack because the document properties will be re-initted
+    //by the xml filter and during the init, while its considered uninitialized,
+    //setting a property will inform the document its modified, which attempts
+    //to update the properties, which throws cause the properties are uninitialized
+    xDocSh->SetLoading(SfxLoadedFlags::NONE);
+    bool ret = false;
+    try
+    {
+        ret = xFilter->filter(aArgs);
+    }
+    catch (const css::io::IOException&)
+    {
+    }
+    catch (const css::lang::WrappedTargetRuntimeException&)
+    {
+    }
+    xDocSh->SetLoading(SfxLoadedFlags::ALL);
+
+    xDocSh->DoClose();
+
+    return ret;
+}
+
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
