@@ -17,16 +17,17 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include <mmaddressblockpage.hxx>
+#include "mmaddressblockpage.hxx"
 #include <mailmergewizard.hxx>
 #include <swtypes.hxx>
-#include <addresslistdialog.hxx>
+#include "addresslistdialog.hxx"
 #include <vcl/layout.hxx>
 #include <vcl/txtattr.hxx>
 #include <vcl/xtextedt.hxx>
 #include <vcl/builderfactory.hxx>
 #include <mmconfigitem.hxx>
 #include <com/sun/star/container/XNameAccess.hpp>
+#include <com/sun/star/sdbc/SQLException.hpp>
 #include <com/sun/star/sdbcx/XColumnsSupplier.hpp>
 #include <com/sun/star/sdb/XColumn.hpp>
 #include <comphelper/string.hxx>
@@ -34,8 +35,10 @@
 
 #include <vector>
 #include <globals.hrc>
+#include <strings.hrc>
 #include <dbui.hrc>
-#include <helpid.h>
+#include <mmaddressblockpage.hrc>
+#include <helpids.h>
 
 using namespace svt;
 using namespace ::com::sun::star;
@@ -64,14 +67,14 @@ SwMailMergeAddressBlockPage::SwMailMergeAddressBlockPage( SwMailMergeWizard* _pP
     get(m_pSettingsFI, "settingsft");
     get(m_pAddressCB, "address");
     get(m_pSettingsWIN, "settingspreview");
-    Size aSize(LogicToPixel(Size(164 , 45), MAP_APPFONT));
+    Size aSize(LogicToPixel(Size(164 , 45), MapMode(MapUnit::MapAppFont)));
     m_pSettingsWIN->set_width_request(aSize.Width());
     m_pSettingsWIN->set_height_request(aSize.Height());
     get(m_pSettingsPB, "settings");
     get(m_pHideEmptyParagraphsCB, "hideempty");
     get(m_pAssignPB, "assign");
     get(m_pPreviewWIN, "addresspreview");
-    aSize = LogicToPixel(Size(176, 46), MAP_APPFONT);
+    aSize = LogicToPixel(Size(176, 46), MapMode(MapUnit::MapAppFont));
     m_pPreviewWIN->set_width_request(aSize.Width());
     m_pPreviewWIN->set_height_request(aSize.Height());
     get(m_pDocumentIndexFI, "documentindex");
@@ -154,16 +157,14 @@ void SwMailMergeAddressBlockPage::ActivatePage()
 
 bool SwMailMergeAddressBlockPage::commitPage( ::svt::WizardTypes::CommitPageReason _eReason )
 {
-    if ( ::svt::WizardTypes::eTravelForward == _eReason && !m_pWizard->GetConfigItem().GetResultSet().is() )
-        return false;
-    return true;
+    return ::svt::WizardTypes::eTravelForward != _eReason || m_pWizard->GetConfigItem().GetResultSet().is();
 }
 
-IMPL_LINK_NOARG_TYPED(SwMailMergeAddressBlockPage, AddressListHdl_Impl, Button*, void)
+IMPL_LINK_NOARG(SwMailMergeAddressBlockPage, AddressListHdl_Impl, Button*, void)
 {
     try
     {
-        VclPtrInstance< SwAddressListDialog > xAddrDialog(this);
+        ScopedVclPtrInstance< SwAddressListDialog > xAddrDialog(this);
         if(RET_OK == xAddrDialog->Execute())
         {
             SwMailMergeConfigItem& rConfigItem = m_pWizard->GetConfigItem();
@@ -181,14 +182,14 @@ IMPL_LINK_NOARG_TYPED(SwMailMergeAddressBlockPage, AddressListHdl_Impl, Button*,
     }
     catch (const uno::Exception& e)
     {
-        OSL_FAIL(OUStringToOString(e.Message, osl_getThreadTextEncoding()).getStr());
-        ScopedVclPtrInstance<MessageDialog>::Create(this, e.Message)->Execute();
+        SAL_WARN("sw", e);
+        ScopedVclPtrInstance<MessageDialog>(this, e.Message)->Execute();
     }
 }
 
-IMPL_LINK_TYPED(SwMailMergeAddressBlockPage, SettingsHdl_Impl, Button*, pButton, void)
+IMPL_LINK(SwMailMergeAddressBlockPage, SettingsHdl_Impl, Button*, pButton, void)
 {
-    VclPtr<SwSelectAddressBlockDialog> pDlg(
+    ScopedVclPtr<SwSelectAddressBlockDialog> pDlg(
                 VclPtr<SwSelectAddressBlockDialog>::Create(pButton, m_pWizard->GetConfigItem()));
     SwMailMergeConfigItem& rConfig = m_pWizard->GetConfigItem();
     pDlg->SetAddressBlocks(rConfig.GetAddressBlocks(), m_pSettingsWIN->GetSelectedAddress());
@@ -207,12 +208,12 @@ IMPL_LINK_TYPED(SwMailMergeAddressBlockPage, SettingsHdl_Impl, Button*, pButton,
         rConfig.SetCountrySettings(pDlg->IsIncludeCountry(), pDlg->GetCountry());
         InsertDataHdl_Impl(nullptr);
     }
-    pDlg.reset();
+    pDlg.disposeAndClear();
     GetWizard()->UpdateRoadmap();
     GetWizard()->enableButtons(WizardButtonFlags::NEXT, GetWizard()->isStateEnabled(MM_GREETINGSPAGE));
 }
 
-IMPL_LINK_TYPED(SwMailMergeAddressBlockPage, AssignHdl_Impl, Button*, pButton, void)
+IMPL_LINK(SwMailMergeAddressBlockPage, AssignHdl_Impl, Button*, pButton, void)
 {
     SwMailMergeConfigItem& rConfigItem = m_pWizard->GetConfigItem();
     const sal_uInt16 nSel = m_pSettingsWIN->GetSelectedAddress();
@@ -240,15 +241,16 @@ void SwMailMergeAddressBlockPage::EnableAddressBlock(bool bAll, bool bSelective)
     m_pStep4->Enable(bSelective);
 }
 
-IMPL_LINK_TYPED(SwMailMergeAddressBlockPage, AddressBlockHdl_Impl, Button*, pBox, void)
+IMPL_LINK(SwMailMergeAddressBlockPage, AddressBlockHdl_Impl, Button*, pBox, void)
 {
     EnableAddressBlock(pBox->IsEnabled(), static_cast<CheckBox*>(pBox)->IsChecked());
     SwMailMergeConfigItem& rConfigItem = m_pWizard->GetConfigItem();
     rConfigItem.SetAddressBlock(m_pAddressCB->IsChecked());
     m_pWizard->UpdateRoadmap();
+    GetWizard()->enableButtons(WizardButtonFlags::NEXT, GetWizard()->isStateEnabled(MM_GREETINGSPAGE));
 }
 
-IMPL_LINK_NOARG_TYPED(SwMailMergeAddressBlockPage, AddressBlockSelectHdl_Impl, LinkParamNone*, void)
+IMPL_LINK_NOARG(SwMailMergeAddressBlockPage, AddressBlockSelectHdl_Impl, LinkParamNone*, void)
 {
     const sal_uInt16 nSel = m_pSettingsWIN->GetSelectedAddress();
     const uno::Sequence< OUString> aBlocks =
@@ -260,13 +262,13 @@ IMPL_LINK_NOARG_TYPED(SwMailMergeAddressBlockPage, AddressBlockSelectHdl_Impl, L
     GetWizard()->enableButtons(WizardButtonFlags::NEXT, GetWizard()->isStateEnabled(MM_GREETINGSPAGE));
 }
 
-IMPL_LINK_TYPED(SwMailMergeAddressBlockPage, HideParagraphsHdl_Impl, Button*, pBox, void)
+IMPL_LINK(SwMailMergeAddressBlockPage, HideParagraphsHdl_Impl, Button*, pBox, void)
 {
     SwMailMergeConfigItem& rConfigItem = m_pWizard->GetConfigItem();
     rConfigItem.SetHideEmptyParagraphs( static_cast<CheckBox*>(pBox)->IsChecked() );
 }
 
-IMPL_LINK_TYPED(SwMailMergeAddressBlockPage, InsertDataHdl_Impl, Button*, pButton, void)
+IMPL_LINK(SwMailMergeAddressBlockPage, InsertDataHdl_Impl, Button*, pButton, void)
 {
     //if no pButton is given, the first set has to be pre-set
     SwMailMergeConfigItem& rConfig = m_pWizard->GetConfigItem();
@@ -322,7 +324,7 @@ SwSelectAddressBlockDialog::SwSelectAddressBlockDialog(
     , m_rConfig(rConfig)
 {
     get(m_pPreview, "preview");
-    Size aSize(m_pPreview->LogicToPixel(Size(192, 100), MAP_APPFONT));
+    Size aSize(m_pPreview->LogicToPixel(Size(192, 100), MapMode(MapUnit::MapAppFont)));
     m_pPreview->set_width_request(aSize.Width());
     m_pPreview->set_height_request(aSize.Height());
     get(m_pNewPB, "new");
@@ -404,7 +406,7 @@ void SwSelectAddressBlockDialog::SetSettings(
     RadioButton *pActive = m_pNeverRB;
     if(bIsCountry)
     {
-        pActive = !rCountry.isEmpty() ? m_pDependentRB : m_pAlwaysRB;
+        pActive = !rCountry.isEmpty() ? m_pDependentRB.get() : m_pAlwaysRB.get();
         m_pCountryED->SetText(rCountry);
     }
     pActive->Check();
@@ -419,7 +421,7 @@ OUString     SwSelectAddressBlockDialog::GetCountry() const
     return OUString();
 }
 
-IMPL_LINK_TYPED(SwSelectAddressBlockDialog, DeleteHdl_Impl, Button*, pButton, void)
+IMPL_LINK(SwSelectAddressBlockDialog, DeleteHdl_Impl, Button*, pButton, void)
 {
     if(m_aAddressBlocks.getLength())
     {
@@ -439,7 +441,7 @@ IMPL_LINK_TYPED(SwSelectAddressBlockDialog, DeleteHdl_Impl, Button*, pButton, vo
     }
 }
 
-IMPL_LINK_TYPED(SwSelectAddressBlockDialog, NewCustomizeHdl_Impl, Button*, pButton, void)
+IMPL_LINK(SwSelectAddressBlockDialog, NewCustomizeHdl_Impl, Button*, pButton, void)
 {
     bool bCustomize = pButton == m_pCustomizePB;
     SwCustomizeAddressBlockDialog::DialogType nType = bCustomize ?
@@ -471,7 +473,7 @@ IMPL_LINK_TYPED(SwSelectAddressBlockDialog, NewCustomizeHdl_Impl, Button*, pButt
     }
 }
 
-IMPL_LINK_TYPED(SwSelectAddressBlockDialog, IncludeHdl_Impl, Button*, pButton, void)
+IMPL_LINK(SwSelectAddressBlockDialog, IncludeHdl_Impl, Button*, pButton, void)
 {
     m_pCountryED->Enable(m_pDependentRB == pButton);
 }
@@ -512,36 +514,44 @@ SwCustomizeAddressBlockDialog::SwCustomizeAddressBlockDialog(
     {
         m_pFieldFT->Show();
         m_pFieldCB->Show();
-        SvTreeListEntry* pEntry = m_pAddressElementsLB->InsertEntry(SW_RESSTR(ST_SALUTATION));
+        SvTreeListEntry* pEntry = m_pAddressElementsLB->InsertEntry(SwResId(ST_SALUTATION));
         pEntry->SetUserData(reinterpret_cast<void*>((sal_Int32)USER_DATA_SALUTATION) );
-        pEntry = m_pAddressElementsLB->InsertEntry(SW_RESSTR(ST_PUNCTUATION));
+        pEntry = m_pAddressElementsLB->InsertEntry(SwResId(ST_PUNCTUATION));
         pEntry->SetUserData(reinterpret_cast<void*>((sal_Int32)USER_DATA_PUNCTUATION) );
-        pEntry = m_pAddressElementsLB->InsertEntry(SW_RESSTR(ST_TEXT));
+        pEntry = m_pAddressElementsLB->InsertEntry(SwResId(ST_TEXT));
         pEntry->SetUserData(reinterpret_cast<void*>((sal_Int32)USER_DATA_TEXT)       );
-        ResStringArray aSalutArr(SW_RES(RA_SALUTATION));
-        for(sal_uInt32 i = 0; i < aSalutArr.Count(); ++i)
-            m_aSalutations.push_back(aSalutArr.GetString(i));
-        ResStringArray aPunctArr(SW_RES(RA_PUNCTUATION));
-        for(sal_uInt32 i = 0; i < aPunctArr.Count(); ++i)
-            m_aPunctuations.push_back(aPunctArr.GetString(i));
+        for (size_t i = 0; i < SAL_N_ELEMENTS(RA_SALUTATION); ++i)
+            m_aSalutations.push_back(SwResId(RA_SALUTATION[i]));
+        for (size_t i = 0; i < SAL_N_ELEMENTS(RA_PUNCTUATION); ++i)
+            m_aPunctuations.push_back(SwResId(RA_PUNCTUATION[i]));
         m_pDragED->SetText("            ");
-        SetText(SW_RESSTR(eType == GREETING_MALE ? ST_TITLE_MALE : ST_TITLE_FEMALE));
-        m_pAddressElementsFT->SetText(SW_RESSTR(ST_SALUTATIONELEMENTS));
-        m_pInsertFieldIB->SetQuickHelpText(SW_RESSTR(ST_INSERTSALUTATIONFIELD));
-        m_pRemoveFieldIB->SetQuickHelpText(SW_RESSTR(ST_REMOVESALUTATIONFIELD));
-        m_pDragFT->SetText(SW_RESSTR(ST_DRAGSALUTATION));
+        SetText(SwResId(eType == GREETING_MALE ? ST_TITLE_MALE : ST_TITLE_FEMALE));
+        m_pAddressElementsFT->SetText(SwResId(ST_SALUTATIONELEMENTS));
+        m_pInsertFieldIB->SetQuickHelpText(SwResId(ST_INSERTSALUTATIONFIELD));
+        m_pRemoveFieldIB->SetQuickHelpText(SwResId(ST_REMOVESALUTATIONFIELD));
+        m_pDragFT->SetText(SwResId(ST_DRAGSALUTATION));
     }
     else
     {
         if(eType == ADDRESSBLOCK_EDIT)
-            SetText(SW_RESSTR(ST_TITLE_EDIT));
+            SetText(SwResId(ST_TITLE_EDIT));
         m_pDragED->SetText("\n\n\n\n\n");
+        /* Set custom HIDs for swriter/01/mm_newaddblo.xhp */
+        m_pAddressElementsLB->SetHelpId( HID_MM_ADDBLOCK_ELEMENTS );
+        m_pInsertFieldIB->SetHelpId( HID_MM_ADDBLOCK_INSERT );
+        m_pRemoveFieldIB->SetHelpId( HID_MM_ADDBLOCK_REMOVE );
+        m_pDragED->SetHelpId( HID_MM_ADDBLOCK_DRAG );
+        m_pPreviewWIN->SetHelpId( HID_MM_ADDBLOCK_PREVIEW );
+        m_pRightIB->SetHelpId( HID_MM_ADDBLOCK_MOVEBUTTONS );
+        m_pLeftIB->SetHelpId( HID_MM_ADDBLOCK_MOVEBUTTONS );
+        m_pDownIB->SetHelpId( HID_MM_ADDBLOCK_MOVEBUTTONS );
+        m_pUpIB->SetHelpId( HID_MM_ADDBLOCK_MOVEBUTTONS );
     }
 
-    const ResStringArray& rHeaders = m_rConfigItem.GetDefaultAddressHeaders();
-    for(sal_uInt32 i = 0; i < rHeaders.Count(); ++i)
+    const std::vector<std::pair<OUString, int>>& rHeaders = m_rConfigItem.GetDefaultAddressHeaders();
+    for (size_t i = 0; i < rHeaders.size(); ++i)
     {
-        SvTreeListEntry* pEntry = m_pAddressElementsLB->InsertEntry(rHeaders.GetString( i ));
+        SvTreeListEntry* pEntry = m_pAddressElementsLB->InsertEntry(rHeaders[i].first);
         pEntry->SetUserData(reinterpret_cast<void*>((sal_IntPtr)i));
     }
     m_pOK->SetClickHdl(LINK(this, SwCustomizeAddressBlockDialog, OKHdl_Impl));
@@ -585,25 +595,25 @@ void SwCustomizeAddressBlockDialog::dispose()
     SfxModalDialog::dispose();
 }
 
-IMPL_LINK_NOARG_TYPED(SwCustomizeAddressBlockDialog, OKHdl_Impl, Button*, void)
+IMPL_LINK_NOARG(SwCustomizeAddressBlockDialog, OKHdl_Impl, Button*, void)
 {
     EndDialog(RET_OK);
 }
 
-IMPL_LINK_TYPED(SwCustomizeAddressBlockDialog, ListBoxSelectHdl_Impl, SvTreeListBox*, pBox, void)
+IMPL_LINK(SwCustomizeAddressBlockDialog, ListBoxSelectHdl_Impl, SvTreeListBox*, pBox, void)
 {
     sal_Int32 nUserData = (sal_Int32)reinterpret_cast<sal_IntPtr>(pBox->FirstSelected()->GetUserData());
     // Check if the selected entry is already in the address and then forbid inserting
     m_pInsertFieldIB->Enable(nUserData >= 0 || !HasItem_Impl(nUserData));
 }
 
-IMPL_LINK_NOARG_TYPED(SwCustomizeAddressBlockDialog, EditModifyHdl_Impl, Edit&, void)
+IMPL_LINK_NOARG(SwCustomizeAddressBlockDialog, EditModifyHdl_Impl, Edit&, void)
 {
     m_pPreviewWIN->SetAddress(SwAddressPreview::FillData(GetAddress(), m_rConfigItem));
     UpdateImageButtons_Impl();
 }
 
-IMPL_LINK_TYPED(SwCustomizeAddressBlockDialog, ImageButtonHdl_Impl, Button*, pButton, void)
+IMPL_LINK(SwCustomizeAddressBlockDialog, ImageButtonHdl_Impl, Button*, pButton, void)
 {
     if (m_pInsertFieldIB == pButton)
     {
@@ -619,13 +629,13 @@ IMPL_LINK_TYPED(SwCustomizeAddressBlockDialog, ImageButtonHdl_Impl, Button*, pBu
     }
     else
     {
-        sal_uInt16 nMove = MOVE_ITEM_DOWN;
+        MoveItemFlags nMove = MoveItemFlags::Down;
         if (m_pUpIB == pButton)
-            nMove = MOVE_ITEM_UP;
+            nMove = MoveItemFlags::Up;
         else if (m_pLeftIB == pButton)
-            nMove = MOVE_ITEM_LEFT;
+            nMove = MoveItemFlags::Left;
         else if (m_pRightIB == pButton)
-            nMove = MOVE_ITEM_RIGHT;
+            nMove = MoveItemFlags::Right;
         m_pDragED->MoveCurrentItem(nMove);
     }
     UpdateImageButtons_Impl();
@@ -666,7 +676,7 @@ bool   SwCustomizeAddressBlockDialog::HasItem_Impl(sal_Int32 nUserData)
     return m_pDragED->GetText().indexOf("<" + sEntry + ">") >= 0;
 }
 
-IMPL_LINK_TYPED(SwCustomizeAddressBlockDialog, SelectionChangedHdl_Impl, AddressMultiLineEdit&, rEdit, void)
+IMPL_LINK(SwCustomizeAddressBlockDialog, SelectionChangedHdl_Impl, AddressMultiLineEdit&, rEdit, void)
 {
     // called in case the selection of the edit field changes.
     // determine selection - if it's one of the editable fields then
@@ -684,7 +694,7 @@ IMPL_LINK_TYPED(SwCustomizeAddressBlockDialog, SelectionChangedHdl_Impl, Address
     {
         //search in ListBox if it's one of the first entries
         OUString sSelect;
-        ::std::vector<OUString>* pVector = nullptr;
+        std::vector<OUString>* pVector = nullptr;
         switch(nSelected) {
             case USER_DATA_SALUTATION:
                 sSelect =  m_sCurrentSalutation;
@@ -700,7 +710,7 @@ IMPL_LINK_TYPED(SwCustomizeAddressBlockDialog, SelectionChangedHdl_Impl, Address
         }
         m_pFieldCB->Clear();
         if(pVector) {
-            ::std::vector<OUString>::iterator  aIterator;
+            std::vector<OUString>::iterator    aIterator;
             for( aIterator = pVector->begin(); aIterator != pVector->end(); ++aIterator)
                 m_pFieldCB->InsertEntry(*aIterator);
         }
@@ -718,11 +728,11 @@ IMPL_LINK_TYPED(SwCustomizeAddressBlockDialog, SelectionChangedHdl_Impl, Address
     bOnEntry = false;
 }
 
-IMPL_LINK_NOARG_TYPED(SwCustomizeAddressBlockDialog, FieldChangeComboBoxHdl_Impl, ComboBox&, void)
+IMPL_LINK_NOARG(SwCustomizeAddressBlockDialog, FieldChangeComboBoxHdl_Impl, ComboBox&, void)
 {
     FieldChangeHdl_Impl(*m_pFieldCB);
 }
-IMPL_LINK_NOARG_TYPED(SwCustomizeAddressBlockDialog, FieldChangeHdl_Impl, Edit&, void)
+IMPL_LINK_NOARG(SwCustomizeAddressBlockDialog, FieldChangeHdl_Impl, Edit&, void)
 {
     //changing the field content changes the related members, too
     sal_Int32 nSelected = GetSelectedItem_Impl();
@@ -745,11 +755,11 @@ IMPL_LINK_NOARG_TYPED(SwCustomizeAddressBlockDialog, FieldChangeHdl_Impl, Edit&,
 
 void SwCustomizeAddressBlockDialog::UpdateImageButtons_Impl()
 {
-    sal_uInt16 nMove = m_pDragED->IsCurrentItemMoveable();
-    m_pUpIB->Enable(nMove & MOVE_ITEM_UP );
-    m_pLeftIB->Enable(nMove & MOVE_ITEM_LEFT );
-    m_pRightIB->Enable(nMove & MOVE_ITEM_RIGHT );
-    m_pDownIB->Enable(nMove & MOVE_ITEM_DOWN);
+    MoveItemFlags nMove = m_pDragED->IsCurrentItemMoveable();
+    m_pUpIB->Enable( bool(nMove & MoveItemFlags::Up) );
+    m_pLeftIB->Enable( bool(nMove & MoveItemFlags::Left) );
+    m_pRightIB->Enable( bool(nMove & MoveItemFlags::Right) );
+    m_pDownIB->Enable( bool(nMove & MoveItemFlags::Down) );
     m_pRemoveFieldIB->Enable(m_pDragED->HasCurrentItem());
     SvTreeListEntry* pEntry = m_pAddressElementsLB->GetCurEntry();
     m_pInsertFieldIB->Enable( pEntry &&
@@ -798,9 +808,9 @@ class SwAssignFieldsControl : public Control
     VclPtr<HeaderBar>           m_aHeaderHB;
     VclPtr<Window>              m_aWindow;
 
-    ::std::vector<VclPtr<FixedText> >   m_aFieldNames;
-    ::std::vector<VclPtr<ListBox> >     m_aMatches;
-    ::std::vector<VclPtr<FixedText> >   m_aPreviews;
+    std::vector<VclPtr<FixedText> >     m_aFieldNames;
+    std::vector<VclPtr<ListBox> >       m_aMatches;
+    std::vector<VclPtr<FixedText> >     m_aPreviews;
 
     SwMailMergeConfigItem*              m_rConfigItem;
 
@@ -810,9 +820,9 @@ class SwAssignFieldsControl : public Control
     long                        m_nYOffset;
     long                        m_nFirstYPos;
 
-    DECL_LINK_TYPED(ScrollHdl_Impl, ScrollBar*, void);
-    DECL_LINK_TYPED(MatchHdl_Impl, ListBox&, void);
-    DECL_LINK_TYPED(GotFocusHdl_Impl, Control&, void);
+    DECL_LINK(ScrollHdl_Impl, ScrollBar*, void);
+    DECL_LINK(MatchHdl_Impl, ListBox&, void);
+    DECL_LINK(GotFocusHdl_Impl, Control&, void);
 
     virtual bool        PreNotify( NotifyEvent& rNEvt ) override;
     virtual void        Command( const CommandEvent& rCEvt ) override;
@@ -820,7 +830,7 @@ class SwAssignFieldsControl : public Control
     void                MakeVisible( sal_Int32 nIndex );
 public:
     SwAssignFieldsControl(vcl::Window* pParent, WinBits nBits);
-    virtual ~SwAssignFieldsControl();
+    virtual ~SwAssignFieldsControl() override;
     virtual void dispose() override;
 
     void        Init(SwMailMergeConfigItem& rConfigItem);
@@ -836,7 +846,7 @@ public:
 VCL_BUILDER_FACTORY_ARGS(SwAssignFieldsControl, WB_BORDER)
 
 SwAssignFieldsControl::SwAssignFieldsControl(vcl::Window* pParent, WinBits nBits) :
-    Control(pParent, nBits | WB_DIALOGCONTROL | WB_TABSTOP | WB_DIALOGCONTROL),
+    Control(pParent, nBits | WB_DIALOGCONTROL | WB_TABSTOP),
     m_aVScroll(VclPtr<ScrollBar>::Create(this)),
     m_aHeaderHB(VclPtr<HeaderBar>::Create(this, WB_BUTTONSTYLE | WB_BOTTOMBORDER)),
     m_aWindow(VclPtr<vcl::Window>::Create(this, WB_BORDER | WB_DIALOGCONTROL)),
@@ -858,7 +868,7 @@ SwAssignFieldsControl::SwAssignFieldsControl(vcl::Window* pParent, WinBits nBits
 
 Size SwAssignFieldsControl::GetOptimalSize() const
 {
-    return LogicToPixel(Size(248 , 120), MAP_APPFONT);
+    return LogicToPixel(Size(248, 120), MapMode(MapUnit::MapAppFont));
 }
 
 void SwAssignFieldsControl::Init(SwMailMergeConfigItem& rConfigItem)
@@ -868,7 +878,7 @@ void SwAssignFieldsControl::Init(SwMailMergeConfigItem& rConfigItem)
     long nHBHeight = m_aHeaderHB->CalcWindowSizePixel().Height();
 
     //get the name of the default headers
-    const ResStringArray& rHeaders = rConfigItem.GetDefaultAddressHeaders();
+    const std::vector<std::pair<OUString, int>>& rHeaders = rConfigItem.GetDefaultAddressHeaders();
     //get the actual data
     uno::Reference< XColumnsSupplier > xColsSupp( rConfigItem.GetResultSet(), uno::UNO_QUERY);
     //get the name of the actual columns
@@ -888,14 +898,14 @@ void SwAssignFieldsControl::Init(SwMailMergeConfigItem& rConfigItem)
     //fill the controls
     long nControlWidth = aOutputSize.Width() / 3;
     long nControlHeight = -1;
-    for(sal_uInt32 i = 0; i < rHeaders.Count(); ++i)
+    for (size_t i = 0; i < rHeaders.size(); ++i)
     {
-        const OUString rHeader = rHeaders.GetString( i );
+        const OUString rHeader = rHeaders[i].first;
         VclPtr<FixedText> pNewText = VclPtr<FixedText>::Create(m_aWindow.get(), WB_VCENTER);
         pNewText->SetText("<" + rHeader + ">");
         VclPtr<ListBox> pNewLB = VclPtr<ListBox>::Create(m_aWindow.get(), WB_DROPDOWN | WB_VCENTER | WB_TABSTOP);
         pNewText->set_mnemonic_widget(pNewLB);
-        pNewLB->InsertEntry(SW_RESSTR(SW_STR_NONE));
+        pNewLB->InsertEntry(SwResId(SW_STR_NONE));
         pNewLB->SelectEntryPos(0);
         pNewLB->SetDropDownLineCount(5);
 
@@ -918,10 +928,10 @@ void SwAssignFieldsControl::Init(SwMailMergeConfigItem& rConfigItem)
         else //otherwise the current column name may match one of the db columns
             pNewLB->SelectEntry(rHeader);
         //then the preview can be filled accordingly
-        if(xColAccess.is() && pNewLB->GetSelectEntryPos() > 0 &&
-                xColAccess->hasByName(pNewLB->GetSelectEntry()))
+        if(xColAccess.is() && pNewLB->GetSelectedEntryPos() > 0 &&
+                xColAccess->hasByName(pNewLB->GetSelectedEntry()))
         {
-            uno::Any aCol = xColAccess->getByName(pNewLB->GetSelectEntry());
+            uno::Any aCol = xColAccess->getByName(pNewLB->GetSelectedEntry());
             uno::Reference< XColumn > xColumn;
             aCol >>= xColumn;
             if(xColumn.is())
@@ -957,7 +967,7 @@ void SwAssignFieldsControl::Init(SwMailMergeConfigItem& rConfigItem)
         pNewPreview->Show();
         pNewPreview->SetPosPixel(Point(2 * nControlWidth + 6, nMove));
     }
-    m_aVScroll->SetRange(Range(0, rHeaders.Count()));
+    m_aVScroll->SetRange(Range(0, rHeaders.size()));
     m_aVScroll->SetPageSize((aOutputSize.Height() - nHBHeight - m_nLBStartTopPos)/ m_nYOffset);
     m_aVScroll->EnableDrag();
     m_aVScroll->SetVisibleSize(m_aVScroll->GetPageSize());
@@ -1080,7 +1090,7 @@ void SwAssignFieldsControl::MakeVisible( sal_Int32 nIndex )
     ScrollHdl_Impl( m_aVScroll.get() );
 }
 
-IMPL_LINK_TYPED(SwAssignFieldsControl, ScrollHdl_Impl, ScrollBar*, pScroll, void)
+IMPL_LINK(SwAssignFieldsControl, ScrollHdl_Impl, ScrollBar*, pScroll, void)
 {
     long nThumb = pScroll->GetThumbPos();
     // the scrollbar moves on a per line basis
@@ -1099,9 +1109,9 @@ IMPL_LINK_TYPED(SwAssignFieldsControl, ScrollHdl_Impl, ScrollBar*, pScroll, void
     SetUpdateMode(true);
 }
 
-IMPL_LINK_TYPED(SwAssignFieldsControl, MatchHdl_Impl, ListBox&, rBox, void)
+IMPL_LINK(SwAssignFieldsControl, MatchHdl_Impl, ListBox&, rBox, void)
 {
-    const OUString sColumn = rBox.GetSelectEntry();
+    const OUString sColumn = rBox.GetSelectedEntry();
     uno::Reference< XColumnsSupplier > xColsSupp( m_rConfigItem->GetResultSet(), uno::UNO_QUERY);
     uno::Reference <XNameAccess> xColAccess = xColsSupp.is() ? xColsSupp->getColumns() : nullptr;
     OUString sPreview;
@@ -1133,7 +1143,7 @@ IMPL_LINK_TYPED(SwAssignFieldsControl, MatchHdl_Impl, ListBox&, rBox, void)
     m_aModifyHdl.Call(nullptr);
 }
 
-IMPL_LINK_TYPED(SwAssignFieldsControl, GotFocusHdl_Impl, Control&, rControl, void)
+IMPL_LINK(SwAssignFieldsControl, GotFocusHdl_Impl, Control&, rControl, void)
 {
     ListBox* pBox = static_cast<ListBox*>(&rControl);
     if(GetFocusFlags::Tab & pBox->GetGetFocusFlags())
@@ -1155,7 +1165,7 @@ SwAssignFieldsDialog::SwAssignFieldsDialog(
         const OUString& rPreview,
         bool bIsAddressBlock) :
     SfxModalDialog(pParent, "AssignFieldsDialog", "modules/swriter/ui/assignfieldsdialog.ui"),
-    m_sNone(SW_RESSTR(SW_STR_NONE)),
+    m_sNone(SwResId(SW_STR_NONE)),
     m_rPreviewString(rPreview),
     m_rConfigItem(rConfigItem)
 {
@@ -1163,20 +1173,20 @@ SwAssignFieldsDialog::SwAssignFieldsDialog(
     get(m_pPreviewFI, "PREVIEW_LABEL");
     get(m_pOK, "ok");
     get(m_pPreviewWIN, "PREVIEW");
-    Size aSize(LogicToPixel(Size(248 , 45), MAP_APPFONT));
+    Size aSize(LogicToPixel(Size(248, 45), MapMode(MapUnit::MapAppFont)));
     m_pPreviewWIN->set_width_request(aSize.Width());
     m_pPreviewWIN->set_height_request(aSize.Height());
     get(m_pFieldsControl, "FIELDS");
     m_pFieldsControl->Init(rConfigItem);
     //resize the HeaderBar
-    OUString sAddressElement( SW_RESSTR(ST_ADDRESSELEMENT) );
-    const OUString sMatchesTo( SW_RESSTR(ST_MATCHESTO) );
-    const OUString sPreview( SW_RESSTR(ST_PREVIEW) );
+    OUString sAddressElement( SwResId(ST_ADDRESSELEMENT) );
+    const OUString sMatchesTo( SwResId(ST_MATCHESTO) );
+    const OUString sPreview( SwResId(ST_PREVIEW) );
     if(!bIsAddressBlock)
     {
-        m_pPreviewFI->SetText(SW_RESSTR(ST_SALUTATIONPREVIEW));
-        m_pMatchingFI->SetText(SW_RESSTR(ST_SALUTATIONMATCHING));
-        sAddressElement = SW_RESSTR(ST_SALUTATIONELEMENT);
+        m_pPreviewFI->SetText(SwResId(ST_SALUTATIONPREVIEW));
+        m_pMatchingFI->SetText(SwResId(ST_SALUTATIONMATCHING));
+        sAddressElement = SwResId(ST_SALUTATIONELEMENT);
     }
 
     Size aOutputSize(m_pFieldsControl->m_aHeaderHB->GetSizePixel());
@@ -1213,20 +1223,20 @@ void SwAssignFieldsDialog::dispose()
 uno::Sequence< OUString > SwAssignFieldsDialog::CreateAssignments()
 {
     uno::Sequence< OUString > aAssignments(
-            m_rConfigItem.GetDefaultAddressHeaders().Count());
+            m_rConfigItem.GetDefaultAddressHeaders().size());
     OUString* pAssignments = aAssignments.getArray();
     sal_Int32 nIndex = 0;
     for(auto aLBIter = m_pFieldsControl->m_aMatches.begin();
                 aLBIter != m_pFieldsControl->m_aMatches.end();
                     ++aLBIter, ++nIndex)
     {
-        const OUString sSelect = (*aLBIter)->GetSelectEntry();
+        const OUString sSelect = (*aLBIter)->GetSelectedEntry();
         pAssignments[nIndex] = (m_sNone != sSelect) ? sSelect : OUString();
     }
     return aAssignments;
 }
 
-IMPL_LINK_NOARG_TYPED(SwAssignFieldsDialog, OkHdl_Impl, Button*, void)
+IMPL_LINK_NOARG(SwAssignFieldsDialog, OkHdl_Impl, Button*, void)
 {
     m_rConfigItem.SetColumnAssignment(
                             m_rConfigItem.GetCurrentDBData(),
@@ -1234,7 +1244,7 @@ IMPL_LINK_NOARG_TYPED(SwAssignFieldsDialog, OkHdl_Impl, Button*, void)
     EndDialog(RET_OK);
 }
 
-IMPL_LINK_NOARG_TYPED(SwAssignFieldsDialog, AssignmentModifyHdl_Impl, LinkParamNone*, void)
+IMPL_LINK_NOARG(SwAssignFieldsDialog, AssignmentModifyHdl_Impl, LinkParamNone*, void)
 {
     uno::Sequence< OUString > aAssignments = CreateAssignments();
     const OUString sPreview = SwAddressPreview::FillData(
@@ -1248,7 +1258,7 @@ DDListBox::DDListBox(vcl::Window* pParent, WinBits nStyle)
 {
     SetStyle( GetStyle() | /*WB_HASBUTTONS|WB_HASBUTTONSATROOT|*/
                             WB_CLIPCHILDREN );
-    SetSelectionMode( SINGLE_SELECTION );
+    SetSelectionMode( SelectionMode::Single );
     SetDragDropMode( DragDropMode::CTRL_COPY );
     EnableAsyncDrag(true);
     // expand selection to the complete width of the ListBox
@@ -1268,14 +1278,7 @@ void DDListBox::dispose()
     SvTreeListBox::dispose();
 }
 
-VCL_BUILDER_DECL_FACTORY(DDListBox)
-{
-    WinBits nWinStyle = WB_TABSTOP;
-    OString sBorder = VclBuilder::extractCustomProperty(rMap);
-    if (!sBorder.isEmpty())
-        nWinStyle |= WB_BORDER;
-    rRet = VclPtr<DDListBox>::Create(pParent, nWinStyle);
-}
+VCL_BUILDER_FACTORY_CONSTRUCTOR(DDListBox, WB_TABSTOP)
 
 void DDListBox::SetAddressDialog(SwCustomizeAddressBlockDialog *pParent)
 {
@@ -1289,9 +1292,7 @@ void  DDListBox::StartDrag( sal_Int8 /*nAction*/, const Point& /*rPosPixel*/ )
     {
         ReleaseMouse();
 
-        TransferDataContainer* pContainer = new TransferDataContainer;
-        uno::Reference<
-             datatransfer::XTransferable > xRef( pContainer );
+        rtl::Reference<TransferDataContainer> pContainer = new TransferDataContainer;
 
         sal_Int32 nUserData = (sal_Int32)reinterpret_cast<sal_IntPtr>(pEntry->GetUserData());
         //special entries can only be once in the address / greeting
@@ -1327,17 +1328,11 @@ void AddressMultiLineEdit::dispose()
 
 Size AddressMultiLineEdit::GetOptimalSize() const
 {
-    return LogicToPixel(Size(160, 60), MAP_APPFONT);
+    return LogicToPixel(Size(160, 60), MapMode(MapUnit::MapAppFont));
 }
 
-VCL_BUILDER_DECL_FACTORY(AddressMultiLineEdit)
-{
-    WinBits nWinStyle = WB_LEFT|WB_TABSTOP;
-    OString sBorder = VclBuilder::extractCustomProperty(rMap);
-    if (!sBorder.isEmpty())
-        nWinStyle |= WB_BORDER;
-    rRet = VclPtr<AddressMultiLineEdit>::Create(pParent, nWinStyle);
-}
+
+VCL_BUILDER_FACTORY_CONSTRUCTOR(AddressMultiLineEdit, WB_LEFT|WB_TABSTOP)
 
 void AddressMultiLineEdit::SetAddressDialog(SwCustomizeAddressBlockDialog *pParent)
 {
@@ -1349,8 +1344,8 @@ void AddressMultiLineEdit::Notify(SfxBroadcaster& /*rBC*/, const SfxHint& rHint)
     if (m_aSelectionLink.IsSet() && dynamic_cast<const TextHint*>(&rHint))
     {
         const TextHint& rTextHint = static_cast<const TextHint&>(rHint);
-        if (rTextHint.GetId() == TEXT_HINT_VIEWSELECTIONCHANGED ||
-            rTextHint.GetId() == TEXT_HINT_VIEWCARETCHANGED)
+        if (rTextHint.GetId() == SfxHintId::TextViewSelectionChanged ||
+            rTextHint.GetId() == SfxHintId::TextViewCaretChanged)
         {
             m_aSelectionLink.Call(*this);
         }
@@ -1423,7 +1418,7 @@ void AddressMultiLineEdit::SetText( const OUString& rStr )
 void AddressMultiLineEdit::InsertNewEntry( const OUString& rStr )
 {
     // insert new entry after current selected one.
-    ExtTextView* pTextView = GetTextView();
+    TextView* pTextView = GetTextView();
     const TextSelection& rSelection = pTextView->GetSelection();
     const sal_uInt32 nPara = rSelection.GetStart().GetPara();
     sal_Int32 nIndex = rSelection.GetEnd().GetIndex();
@@ -1453,7 +1448,7 @@ void AddressMultiLineEdit::InsertNewEntryAtPosition( const OUString& rStr, sal_u
     SetText( GetAddress() );
     //select the newly inserted/moved element
     TextSelection aEntrySel(aInsertPos);
-    ExtTextView* pTextView = GetTextView();
+    TextView* pTextView = GetTextView();
     pTextView->SetSelection(aEntrySel);
     m_aSelectionLink.Call(*this);
 }
@@ -1461,7 +1456,7 @@ void AddressMultiLineEdit::InsertNewEntryAtPosition( const OUString& rStr, sal_u
 void AddressMultiLineEdit::RemoveCurrentEntry()
 {
     ExtTextEngine* pTextEngine = GetTextEngine();
-    ExtTextView* pTextView = GetTextView();
+    TextView* pTextView = GetTextView();
     const TextSelection& rSelection = pTextView->GetSelection();
     const TextCharAttrib* pBeginAttrib = pTextEngine->FindCharAttrib( rSelection.GetStart(), TEXTATTR_PROTECTED );
     if(pBeginAttrib &&
@@ -1477,84 +1472,86 @@ void AddressMultiLineEdit::RemoveCurrentEntry()
     }
 }
 
-void AddressMultiLineEdit::MoveCurrentItem(sal_uInt16 nMove)
+void AddressMultiLineEdit::MoveCurrentItem(MoveItemFlags nMove)
 {
     ExtTextEngine* pTextEngine = GetTextEngine();
-    ExtTextView* pTextView = GetTextView();
+    TextView* pTextView = GetTextView();
     const TextSelection& rSelection = pTextView->GetSelection();
     const TextCharAttrib* pBeginAttrib = pTextEngine->FindCharAttrib( rSelection.GetStart(), TEXTATTR_PROTECTED );
-    if(pBeginAttrib &&
-            (pBeginAttrib->GetStart() <= rSelection.GetStart().GetIndex()
-                            && pBeginAttrib->GetEnd() >= rSelection.GetEnd().GetIndex()))
+    if(!pBeginAttrib ||
+       !(pBeginAttrib->GetStart() <= rSelection.GetStart().GetIndex() &&
+         pBeginAttrib->GetEnd() >= rSelection.GetEnd().GetIndex()))
+        return;
+
+    //current item has been found
+    sal_uInt32 nPara = rSelection.GetStart().GetPara();
+    sal_Int32 nIndex = pBeginAttrib->GetStart();
+    TextSelection aEntrySel(TextPaM( nPara, pBeginAttrib->GetStart()), TextPaM(nPara, pBeginAttrib->GetEnd()));
+    const OUString sCurrentItem = pTextEngine->GetText(aEntrySel);
+    pTextEngine->RemoveAttrib( nPara, *pBeginAttrib );
+    pTextEngine->ReplaceText(aEntrySel, OUString());
+    switch(nMove)
     {
-        //current item has been found
-        sal_uInt32 nPara = rSelection.GetStart().GetPara();
-        sal_Int32 nIndex = pBeginAttrib->GetStart();
-        TextSelection aEntrySel(TextPaM( nPara, pBeginAttrib->GetStart()), TextPaM(nPara, pBeginAttrib->GetEnd()));
-        const OUString sCurrentItem = pTextEngine->GetText(aEntrySel);
-        pTextEngine->RemoveAttrib( nPara, *pBeginAttrib );
-        pTextEngine->ReplaceText(aEntrySel, OUString());
-        switch(nMove)
-        {
-            case MOVE_ITEM_LEFT :
-                if(nIndex)
-                {
-                    //go left to find a predecessor or simple text
-                    --nIndex;
-                    const OUString sPara = pTextEngine->GetText( nPara );
-                    sal_Int32 nSearchIndex = sPara.lastIndexOf( '>', nIndex+1 );
-                    if( nSearchIndex != -1 && nSearchIndex == nIndex )
-                    {
-                        nSearchIndex = sPara.lastIndexOf( '<', nIndex );
-                        if( nSearchIndex != -1 )
-                            nIndex = nSearchIndex;
-                    }
-                }
-            break;
-            case MOVE_ITEM_RIGHT:
+        case MoveItemFlags::Left :
+            if(nIndex)
             {
-                //go right to find a successor or simple text
-                ++nIndex;
-                const TextCharAttrib* pEndAttrib = pTextEngine->FindCharAttrib( rSelection.GetStart(), TEXTATTR_PROTECTED );
-                if(pEndAttrib && pEndAttrib->GetEnd() >= nIndex)
+                //go left to find a predecessor or simple text
+                --nIndex;
+                const OUString sPara = pTextEngine->GetText( nPara );
+                sal_Int32 nSearchIndex = sPara.lastIndexOf( '>', nIndex+1 );
+                if( nSearchIndex != -1 && nSearchIndex == nIndex )
                 {
-                    nIndex = pEndAttrib->GetEnd();
+                    nSearchIndex = sPara.lastIndexOf( '<', nIndex );
+                    if( nSearchIndex != -1 )
+                        nIndex = nSearchIndex;
                 }
             }
-            break;
-            case MOVE_ITEM_UP   :
-                --nPara;
-                nIndex = 0;
-            break;
-            case MOVE_ITEM_DOWN :
-                ++nPara;
-                nIndex = 0;
-            break;
-        }
-        //add a new paragraph if there is none yet
-        if(nPara >= pTextEngine->GetParagraphCount())
+        break;
+        case MoveItemFlags::Right:
         {
-
-            TextPaM aTemp(nPara - 1, pTextEngine->GetTextLen( nPara - 1 ));
-            pTextEngine->ReplaceText(aTemp, "\n");
+            //go right to find a successor or simple text
+            ++nIndex;
+            const TextCharAttrib* pEndAttrib = pTextEngine->FindCharAttrib( rSelection.GetStart(), TEXTATTR_PROTECTED );
+            if(pEndAttrib && pEndAttrib->GetEnd() >= nIndex)
+            {
+                nIndex = pEndAttrib->GetEnd();
+            }
         }
-        InsertNewEntryAtPosition( sCurrentItem, nPara, nIndex );
-
-        // select the new entry [#i40817]
-        const TextCharAttrib *pAttrib = pTextEngine->FindCharAttrib(TextPaM(nPara, nIndex),TEXTATTR_PROTECTED);
-        if (pAttrib)
-            aEntrySel = TextSelection(TextPaM(nPara, nIndex), TextPaM(nPara, pAttrib->GetEnd()));
-        pTextView->SetSelection(aEntrySel);
-        Invalidate();
-        Modify();
+        break;
+        case MoveItemFlags::Up   :
+            --nPara;
+            nIndex = 0;
+        break;
+        case MoveItemFlags::Down :
+            ++nPara;
+            nIndex = 0;
+        break;
+        default: break;
     }
+    //add a new paragraph if there is none yet
+    if(nPara >= pTextEngine->GetParagraphCount())
+    {
+
+        TextPaM aTemp(nPara - 1, pTextEngine->GetTextLen( nPara - 1 ));
+        pTextEngine->ReplaceText(aTemp, "\n");
+    }
+    InsertNewEntryAtPosition( sCurrentItem, nPara, nIndex );
+
+    // select the new entry [#i40817]
+    const TextCharAttrib *pAttrib = pTextEngine->FindCharAttrib(TextPaM(nPara, nIndex),TEXTATTR_PROTECTED);
+    if (pAttrib)
+        aEntrySel = TextSelection(TextPaM(nPara, nIndex), TextPaM(nPara, pAttrib->GetEnd()));
+    pTextView->SetSelection(aEntrySel);
+    Invalidate();
+    Modify();
+
 }
 
-sal_uInt16  AddressMultiLineEdit::IsCurrentItemMoveable()
+MoveItemFlags  AddressMultiLineEdit::IsCurrentItemMoveable()
 {
-    sal_uInt16 nRet = 0;
+    MoveItemFlags nRet = MoveItemFlags::NONE;
     ExtTextEngine* pTextEngine = GetTextEngine();
-    ExtTextView* pTextView = GetTextView();
+    TextView* pTextView = GetTextView();
     const TextSelection& rSelection = pTextView->GetSelection();
     const TextCharAttrib* pBeginAttrib = pTextEngine->FindCharAttrib( rSelection.GetStart(), TEXTATTR_PROTECTED );
     if(pBeginAttrib &&
@@ -1562,11 +1559,11 @@ sal_uInt16  AddressMultiLineEdit::IsCurrentItemMoveable()
                             && pBeginAttrib->GetEnd() >= rSelection.GetEnd().GetIndex()))
     {
         if(pBeginAttrib->GetStart())
-            nRet |= MOVE_ITEM_LEFT;
+            nRet |= MoveItemFlags::Left;
         //if there is an entry it can always be move to the right and down
-        nRet |= MOVE_ITEM_RIGHT|MOVE_ITEM_DOWN;
+        nRet |= MoveItemFlags::Right | MoveItemFlags::Down;
         if(rSelection.GetStart().GetPara() > 0)
-            nRet |= MOVE_ITEM_UP;
+            nRet |= MoveItemFlags::Up;
     }
     return nRet;
 }
@@ -1574,7 +1571,7 @@ sal_uInt16  AddressMultiLineEdit::IsCurrentItemMoveable()
 bool AddressMultiLineEdit::HasCurrentItem()
 {
     ExtTextEngine* pTextEngine = GetTextEngine();
-    ExtTextView* pTextView = GetTextView();
+    TextView* pTextView = GetTextView();
     const TextSelection& rSelection = pTextView->GetSelection();
     const TextCharAttrib* pBeginAttrib = pTextEngine->FindCharAttrib( rSelection.GetStart(), TEXTATTR_PROTECTED );
     return (pBeginAttrib &&
@@ -1585,7 +1582,7 @@ bool AddressMultiLineEdit::HasCurrentItem()
 OUString AddressMultiLineEdit::GetCurrentItem()
 {
     ExtTextEngine* pTextEngine = GetTextEngine();
-    ExtTextView* pTextView = GetTextView();
+    TextView* pTextView = GetTextView();
     const TextSelection& rSelection = pTextView->GetSelection();
     const TextCharAttrib* pBeginAttrib = pTextEngine->FindCharAttrib( rSelection.GetStart(), TEXTATTR_PROTECTED );
     if(pBeginAttrib &&
@@ -1602,7 +1599,7 @@ OUString AddressMultiLineEdit::GetCurrentItem()
 void AddressMultiLineEdit::SelectCurrentItem()
 {
     ExtTextEngine* pTextEngine = GetTextEngine();
-    ExtTextView* pTextView = GetTextView();
+    TextView* pTextView = GetTextView();
     const TextSelection& rSelection = pTextView->GetSelection();
     const TextCharAttrib* pBeginAttrib = pTextEngine->FindCharAttrib( rSelection.GetStart(), TEXTATTR_PROTECTED );
     if(pBeginAttrib &&
