@@ -17,12 +17,10 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "swtypes.hxx"
+#include <swtypes.hxx>
 
-#include "multmrk.hxx"
-#include "toxmgr.hxx"
-
-#include "index.hrc"
+#include <multmrk.hxx>
+#include <toxmgr.hxx>
 
 SwMultiTOXMarkDlg::SwMultiTOXMarkDlg(vcl::Window* pParent, SwTOXMgr& rTOXMgr)
     : SvxStandardDialog(pParent, "SelectIndexDialog",
@@ -45,22 +43,31 @@ SwMultiTOXMarkDlg::SwMultiTOXMarkDlg(vcl::Window* pParent, SwTOXMgr& rTOXMgr)
     m_pTextFT->SetText(rMgr.GetTOXMark(0)->GetTOXType()->GetTypeName());
 }
 
-IMPL_LINK_INLINE_START( SwMultiTOXMarkDlg, SelectHdl, ListBox *, pBox )
+IMPL_LINK( SwMultiTOXMarkDlg, SelectHdl, ListBox&, rBox, void )
 {
-    if(pBox->GetSelectEntryPos() != LISTBOX_ENTRY_NOTFOUND)
-    {   SwTOXMark* pMark = rMgr.GetTOXMark(pBox->GetSelectEntryPos());
+    if(rBox.GetSelectedEntryPos() != LISTBOX_ENTRY_NOTFOUND)
+    {   SwTOXMark* pMark = rMgr.GetTOXMark(rBox.GetSelectedEntryPos());
         m_pTextFT->SetText(pMark->GetTOXType()->GetTypeName());
-        nPos = pBox->GetSelectEntryPos();
+        nPos = rBox.GetSelectedEntryPos();
     }
-    return 0;
 }
-IMPL_LINK_INLINE_END( SwMultiTOXMarkDlg, SelectHdl, ListBox *, pBox )
 
 void SwMultiTOXMarkDlg::Apply()
 {
     rMgr.SetCurTOXMark(nPos);
 }
 
-SwMultiTOXMarkDlg::~SwMultiTOXMarkDlg() {}
+SwMultiTOXMarkDlg::~SwMultiTOXMarkDlg()
+{
+    disposeOnce();
+}
+
+void SwMultiTOXMarkDlg::dispose()
+{
+    m_pTextFT.clear();
+    m_pTOXLB.clear();
+    SvxStandardDialog::dispose();
+}
+
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
