@@ -35,12 +35,12 @@
 #include <glosdoc.hxx>
 #include <swunohelper.hxx>
 
-#include <misc.hrc>
+#include <strings.hrc>
 
 #define PATH_CASE_SENSITIVE 0x01
 #define PATH_READONLY       0x02
 
-#define RENAME_TOKEN_DELIM      (sal_Unicode)1
+#define RENAME_TOKEN_DELIM      u'\x0001'
 
 SwGlossaryGroupDlg::SwGlossaryGroupDlg(vcl::Window * pParent,
     std::vector<OUString> const& rPathArr, SwGlossaryHdl *pHdl)
@@ -56,7 +56,7 @@ SwGlossaryGroupDlg::SwGlossaryGroupDlg(vcl::Window * pParent,
     get(m_pGroupTLB, "group");
 
     const int nAppFontUnits = 130;
-    long nWidth = LogicToPixel(Size(nAppFontUnits, 0), MAP_APPFONT).Width();
+    long nWidth = LogicToPixel(Size(nAppFontUnits, 0), MapMode(MapUnit::MapAppFont)).Width();
     m_pPathLB->set_width_request(nWidth);
     //just has to be something small, real size will be available space
     m_pGroupTLB->set_width_request(nWidth);
@@ -79,7 +79,7 @@ SwGlossaryGroupDlg::SwGlossaryGroupDlg(vcl::Window * pParent,
     for (size_t i = 0; i < rPathArr.size(); ++i)
     {
         INetURLObject aTempURL(rPathArr[i]);
-        const OUString sPath = aTempURL.GetMainURL(INetURLObject::DECODE_WITH_CHARSET );
+        const OUString sPath = aTempURL.GetMainURL(INetURLObject::DecodeMechanism::WithCharset );
         m_pPathLB->InsertEntry(sPath);
         sal_uLong nCaseReadonly = 0;
         utl::TempFile aTempFile(&sPath);
@@ -94,6 +94,9 @@ SwGlossaryGroupDlg::SwGlossaryGroupDlg(vcl::Window * pParent,
     m_pPathLB->Enable();
 
     const size_t nCount = pHdl->GetGroupCnt();
+    /* tdf#111870 "My AutoText" comes from mytexts.bau but should be translated
+       here as well, see also SwGlossaryDlg::Init */
+    const OUString sMyAutoTextEnglish("My AutoText");
     for( size_t i = 0; i < nCount; ++i)
     {
         OUString sTitle;
@@ -102,9 +105,12 @@ SwGlossaryGroupDlg::SwGlossaryGroupDlg(vcl::Window * pParent,
             continue;
         GlosBibUserData* pData = new GlosBibUserData;
         pData->sGroupName = sGroup;
-        pData->sGroupTitle = sTitle;
+        if ( sTitle == sMyAutoTextEnglish )
+            pData->sGroupTitle = SwResId(STR_MY_AUTOTEXT);
+        else
+            pData->sGroupTitle = sTitle;
         pData->sPath = m_pPathLB->GetEntry(sGroup.getToken(1, GLOS_DELIM).toInt32());
-        SvTreeListEntry* pEntry = m_pGroupTLB->InsertEntry(sTitle + "\t" + pData->sPath);
+        SvTreeListEntry* pEntry = m_pGroupTLB->InsertEntry(pData->sGroupTitle + "\t" + pData->sPath);
         pEntry->SetUserData(pData);
 
     }
@@ -149,10 +155,10 @@ void SwGlossaryGroupDlg::Apply()
             }
         }
         OUString sTitle( it->getToken(1, '\t') );
-        const OUString sMsg(SW_RESSTR(STR_QUERY_DELETE_GROUP1)
+        const OUString sMsg(SwResId(STR_QUERY_DELETE_GROUP1)
                             + sTitle
-                            + SW_RESSTR(STR_QUERY_DELETE_GROUP2));
-        ScopedVclPtrInstance< QueryBox > aQuery(this->GetParent(), WB_YES_NO|WB_DEF_NO, sMsg );
+                            + SwResId(STR_QUERY_DELETE_GROUP2));
+        ScopedVclPtrInstance< QueryBox > aQuery(GetParent(), MessBoxStyle::YesNo|MessBoxStyle::DefaultNo, sMsg );
         if(RET_YES == aQuery->Execute())
             pGlosHdl->DelGroup( sDelGroup );
     }
@@ -184,7 +190,7 @@ void SwGlossaryGroupDlg::Apply()
     }
 }
 
-IMPL_LINK_NOARG_TYPED( SwGlossaryGroupDlg, SelectHdl, SvTreeListBox*, void )
+IMPL_LINK_NOARG( SwGlossaryGroupDlg, SelectHdl, SvTreeListBox*, void )
 {
     m_pNewPB->Enable(false);
     SvTreeListEntry* pFirstEntry = m_pGroupTLB->FirstSelected();
@@ -207,17 +213,17 @@ IMPL_LINK_NOARG_TYPED( SwGlossaryGroupDlg, SelectHdl, SvTreeListBox*, void )
     }
 }
 
-IMPL_LINK_NOARG_TYPED(SwGlossaryGroupDlg, NewHdl, Button*, void)
+IMPL_LINK_NOARG(SwGlossaryGroupDlg, NewHdl, Button*, void)
 {
     OUString sGroup = m_pNameED->GetText()
-        + OUStringLiteral1<GLOS_DELIM>()
-        + OUString::number(m_pPathLB->GetSelectEntryPos());
+        + OUStringLiteral1(GLOS_DELIM)
+        + OUString::number(m_pPathLB->GetSelectedEntryPos());
     OSL_ENSURE(!pGlosHdl->FindGroupName(sGroup), "group already available!");
     m_InsertedArr.push_back(sGroup);
-    const OUString sTemp(m_pNameED->GetText() + "\t" + m_pPathLB->GetSelectEntry());
+    const OUString sTemp(m_pNameED->GetText() + "\t" + m_pPathLB->GetSelectedEntry());
     SvTreeListEntry* pEntry = m_pGroupTLB->InsertEntry(sTemp);
     GlosBibUserData* pData = new GlosBibUserData;
-    pData->sPath = m_pPathLB->GetSelectEntry();
+    pData->sPath = m_pPathLB->GetSelectedEntry();
     pData->sGroupName = sGroup;
     pData->sGroupTitle = m_pNameED->GetText();
     pEntry->SetUserData(pData);
@@ -226,7 +232,7 @@ IMPL_LINK_NOARG_TYPED(SwGlossaryGroupDlg, NewHdl, Button*, void)
     m_pGroupTLB->GetModel()->Resort();
 }
 
-IMPL_LINK_TYPED( SwGlossaryGroupDlg, DeleteHdl, Button*, pButton, void )
+IMPL_LINK( SwGlossaryGroupDlg, DeleteHdl, Button*, pButton, void )
 {
     SvTreeListEntry* pEntry = m_pGroupTLB->FirstSelected();
     if(!pEntry)
@@ -265,7 +271,7 @@ IMPL_LINK_TYPED( SwGlossaryGroupDlg, DeleteHdl, Button*, pButton, void )
     }
     if(bDelete)
     {
-        m_RemovedArr.push_back(pUserData->sGroupName + "\t" + pUserData->sGroupTitle);
+        m_RemovedArr.emplace_back(pUserData->sGroupName + "\t" + pUserData->sGroupTitle);
     }
     delete pUserData;
     m_pGroupTLB->GetModel()->Remove(pEntry);
@@ -275,7 +281,7 @@ IMPL_LINK_TYPED( SwGlossaryGroupDlg, DeleteHdl, Button*, pButton, void )
     m_pNameED->SetText(aEmptyOUStr);
 }
 
-IMPL_LINK_NOARG_TYPED(SwGlossaryGroupDlg, RenameHdl, Button*, void)
+IMPL_LINK_NOARG(SwGlossaryGroupDlg, RenameHdl, Button*, void)
 {
     SvTreeListEntry* pEntry = m_pGroupTLB->FirstSelected();
     GlosBibUserData* pUserData = static_cast<GlosBibUserData*>(pEntry->GetUserData());
@@ -283,8 +289,8 @@ IMPL_LINK_NOARG_TYPED(SwGlossaryGroupDlg, RenameHdl, Button*, void)
 
     const OUString sNewTitle(m_pNameED->GetText());
     OUString sNewName = sNewTitle
-        + OUStringLiteral1<GLOS_DELIM>()
-        + OUString::number(m_pPathLB->GetSelectEntryPos());
+        + OUStringLiteral1(GLOS_DELIM)
+        + OUString::number(m_pPathLB->GetSelectedEntryPos());
     OSL_ENSURE(!pGlosHdl->FindGroupName(sNewName), "group already available!");
 
     // if the name to be renamed is among the new ones - replace
@@ -302,16 +308,16 @@ IMPL_LINK_NOARG_TYPED(SwGlossaryGroupDlg, RenameHdl, Button*, void)
     }
     if(!bDone)
     {
-        sEntry += OUStringLiteral1<RENAME_TOKEN_DELIM>() + sNewName
-                + OUStringLiteral1<RENAME_TOKEN_DELIM>() + sNewTitle;
+        sEntry += OUStringLiteral1(RENAME_TOKEN_DELIM) + sNewName
+                + OUStringLiteral1(RENAME_TOKEN_DELIM) + sNewTitle;
         m_RenamedArr.push_back(sEntry);
     }
     delete static_cast<GlosBibUserData*>(pEntry->GetUserData());
     m_pGroupTLB->GetModel()->Remove(pEntry);
     pEntry = m_pGroupTLB->InsertEntry(m_pNameED->GetText() + "\t"
-                                      + m_pPathLB->GetSelectEntry());
+                                      + m_pPathLB->GetSelectedEntry());
     GlosBibUserData* pData = new GlosBibUserData;
-    pData->sPath = m_pPathLB->GetSelectEntry();
+    pData->sPath = m_pPathLB->GetSelectedEntry();
     pData->sGroupName = sNewName;
     pData->sGroupTitle = sNewTitle;
     pEntry->SetUserData(pData);
@@ -320,17 +326,17 @@ IMPL_LINK_NOARG_TYPED(SwGlossaryGroupDlg, RenameHdl, Button*, void)
     m_pGroupTLB->GetModel()->Resort();
 }
 
-IMPL_LINK_NOARG_TYPED(SwGlossaryGroupDlg, ModifyListBoxHdl, ListBox&, void)
+IMPL_LINK_NOARG(SwGlossaryGroupDlg, ModifyListBoxHdl, ListBox&, void)
 {
     ModifyHdl(*m_pNameED);
 }
-IMPL_LINK_NOARG_TYPED(SwGlossaryGroupDlg, ModifyHdl, Edit&, void)
+IMPL_LINK_NOARG(SwGlossaryGroupDlg, ModifyHdl, Edit&, void)
 {
     OUString sEntry(m_pNameED->GetText());
     bool bEnableNew = true;
     bool bEnableDel = false;
     sal_uLong nCaseReadonly =
-            reinterpret_cast<sal_uLong>(m_pPathLB->GetSelectEntryData());
+            reinterpret_cast<sal_uLong>(m_pPathLB->GetSelectedEntryData());
     bool bDirReadonly = 0 != (nCaseReadonly&PATH_READONLY);
 
     if(sEntry.isEmpty() || bDirReadonly)
@@ -377,7 +383,7 @@ IMPL_LINK_NOARG_TYPED(SwGlossaryGroupDlg, ModifyHdl, Edit&, void)
 
 bool SwGlossaryGroupDlg::IsDeleteAllowed(const OUString &rGroup)
 {
-    bool bDel = (!pGlosHdl->IsReadOnly(&rGroup));
+    bool bDel = !pGlosHdl->IsReadOnly(&rGroup);
 
     // OM: if the name is among the new region name, it is deletable
     // as well! Because for non existing region names ReadOnly issues
@@ -425,7 +431,7 @@ void SwGlossaryGroupTLB::RequestHelp( const HelpEvent& rHEvt )
             if((aPos.X() + aSize.Width()) > GetSizePixel().Width())
                 aSize.Width() = GetSizePixel().Width() - aPos.X();
             aPos = OutputToScreenPixel(aPos);
-            Rectangle aItemRect( aPos, aSize );
+            tools::Rectangle aItemRect( aPos, aSize );
             GlosBibUserData* pData = static_cast<GlosBibUserData*>(pEntry->GetUserData());
             const OUString sMsg = pData->sPath + "/"
                                 + pData->sGroupName.getToken(0, GLOS_DELIM)
