@@ -20,7 +20,6 @@
 #include <hintids.hxx>
 #include <vcl/msgbox.hxx>
 #include <sfx2/app.hxx>
-#include <sfx2/imgmgr.hxx>
 #include <svx/gallery.hxx>
 #include <editeng/brushitem.hxx>
 #include <editeng/lrspitem.hxx>
@@ -42,10 +41,8 @@
 #include <viewopt.hxx>
 #include <frmmgr.hxx>
 
-#include <misc.hrc>
-#include <frmui.hrc>
 #include <globals.hrc>
-#include <helpid.h>
+#include <helpids.h>
 #include <SwStyleNameMapper.hxx>
 #include <svx/svxids.hrc>
 #include <svx/dialogs.hrc>
@@ -103,8 +100,6 @@ SwNumPositionTabPage::SwNumPositionTabPage(vcl::Window* pParent,
     SetExchangeSupport();
     m_pPreviewWIN->SetBackground(Wallpaper(Color(COL_TRANSPARENT)));
 
-    m_pStandardPB->SetAccessibleRelationMemberOf(m_pPositionFrame->get_label_widget());
-
     m_pRelativeCB->Check();
     m_pAlignLB->SetSelectHdl(LINK(this, SwNumPositionTabPage, EditModifyHdl));
     m_pAlign2LB->SetSelectHdl(LINK(this, SwNumPositionTabPage, EditModifyHdl));
@@ -131,16 +126,19 @@ SwNumPositionTabPage::SwNumPositionTabPage(vcl::Window* pParent,
     m_pLabelFollowedByLB->SetSelectHdl( LINK(this, SwNumPositionTabPage, LabelFollowedByHdl_Impl) );
 
     aLk = LINK(this, SwNumPositionTabPage, ListtabPosHdl_Impl);
+    aLk2 = LINK(this, SwNumPositionTabPage, ListtabPosFocusHdl_Impl);
     m_pListtabMF->SetUpHdl(aLk);
     m_pListtabMF->SetDownHdl(aLk);
     m_pListtabMF->SetLoseFocusHdl(aLk2);
 
     aLk = LINK(this, SwNumPositionTabPage, AlignAtHdl_Impl);
+    aLk2 = LINK(this, SwNumPositionTabPage, AlignAtFocusHdl_Impl);
     m_pAlignedAtMF->SetUpHdl(aLk);
     m_pAlignedAtMF->SetDownHdl(aLk);
     m_pAlignedAtMF->SetLoseFocusHdl(aLk2);
 
     aLk = LINK(this, SwNumPositionTabPage, IndentAtHdl_Impl);
+    aLk2 = LINK(this, SwNumPositionTabPage, IndentAtFocusHdl_Impl);
     m_pIndentAtMF->SetUpHdl(aLk);
     m_pIndentAtMF->SetDownHdl(aLk);
     m_pIndentAtMF->SetLoseFocusHdl(aLk2);
@@ -201,7 +199,7 @@ void SwNumPositionTabPage::InitControls()
     bInInintControl = true;
     const bool bRelative = !bLabelAlignmentPosAndSpaceModeActive &&
                            m_pRelativeCB->IsEnabled() && m_pRelativeCB->IsChecked();
-    const bool bSingleSelection = m_pLevelLB->GetSelectEntryCount() == 1 &&
+    const bool bSingleSelection = m_pLevelLB->GetSelectedEntryCount() == 1 &&
                                   USHRT_MAX != nActNumLvl;
 
     m_pDistBorderMF->Enable( !bLabelAlignmentPosAndSpaceModeActive &&
@@ -311,9 +309,9 @@ void SwNumPositionTabPage::InitControls()
     if(bSameAdjust)
     {
         sal_Int32 nPos = 1; // centered
-        if(aNumFormatArr[nLvl]->GetNumAdjust() == SVX_ADJUST_LEFT)
+        if(aNumFormatArr[nLvl]->GetNumAdjust() == SvxAdjust::Left)
             nPos = 0;
-        else if(aNumFormatArr[nLvl]->GetNumAdjust() == SVX_ADJUST_RIGHT)
+        else if(aNumFormatArr[nLvl]->GetNumAdjust() == SvxAdjust::Right)
             nPos = 2;
         m_pAlignLB->SelectEntryPos(nPos);
         m_pAlign2LB->SelectEntryPos( nPos );
@@ -428,12 +426,12 @@ void SwNumPositionTabPage::ActivatePage(const SfxItemSet& )
     m_pPreviewWIN->Invalidate();
 }
 
-SfxTabPage::sfxpg SwNumPositionTabPage::DeactivatePage(SfxItemSet *_pSet)
+DeactivateRC SwNumPositionTabPage::DeactivatePage(SfxItemSet *_pSet)
 {
     SwOutlineTabDialog::SetActNumLevel(nActNumLvl);
     if(_pSet)
         FillItemSet(_pSet);
-    return LEAVE_PAGE;
+    return DeactivateRC::LeavePage;
 
 }
 
@@ -552,7 +550,7 @@ void SwNumPositionTabPage::SetWrtShell(SwWrtShell* pSh)
 {
     pWrtSh = pSh;
 
-    const SwTwips nWidth = pWrtSh->GetAnyCurRect(RECT_FRM).Width();
+    const SwTwips nWidth = pWrtSh->GetAnyCurRect(CurRectType::Frame).Width();
 
     m_pDistBorderMF->SetMax(m_pDistBorderMF->Normalize( nWidth ), FUNIT_TWIP );
     m_pDistNumMF->SetMax(m_pDistNumMF->Normalize( nWidth ), FUNIT_TWIP);
@@ -568,7 +566,7 @@ void SwNumPositionTabPage::SetWrtShell(SwWrtShell* pSh)
     m_pAlignedAtMF->SetLast(m_pAlignedAtMF->Normalize( nLast2 ), FUNIT_TWIP );
     m_pIndentAtMF->SetLast(m_pIndentAtMF->Normalize( nLast2 ), FUNIT_TWIP );
 
-    const SwRect& rPrtRect = pWrtSh->GetAnyCurRect(RECT_PAGE);
+    const SwRect& rPrtRect = pWrtSh->GetAnyCurRect(CurRectType::Page);
     m_pPreviewWIN->SetPageWidth(rPrtRect.Width());
     FieldUnit eMetric = ::GetDfltMetric( dynamic_cast<SwWebView*>( &pWrtSh->GetView()) != nullptr  );
     if(eMetric == FUNIT_MM)
@@ -588,7 +586,7 @@ void SwNumPositionTabPage::SetWrtShell(SwWrtShell* pSh)
     m_pIndentAtMF->SetUnit( eMetric );
 }
 
-IMPL_LINK_NOARG_TYPED(SwNumPositionTabPage, EditModifyHdl, ListBox&, void)
+IMPL_LINK_NOARG(SwNumPositionTabPage, EditModifyHdl, ListBox&, void)
 {
     sal_uInt16 nMask = 1;
     for(sal_uInt16 i = 0; i < MAXLEVEL; i++)
@@ -598,13 +596,13 @@ IMPL_LINK_NOARG_TYPED(SwNumPositionTabPage, EditModifyHdl, ListBox&, void)
             SwNumFormat aNumFormat(pActNum->Get(i));
 
             const sal_Int32 nPos = m_pAlignLB->IsVisible()
-                                ? m_pAlignLB->GetSelectEntryPos()
-                                : m_pAlign2LB->GetSelectEntryPos();
-            SvxAdjust eAdjust = SVX_ADJUST_CENTER;
+                                ? m_pAlignLB->GetSelectedEntryPos()
+                                : m_pAlign2LB->GetSelectedEntryPos();
+            SvxAdjust eAdjust = SvxAdjust::Center;
             if(nPos == 0)
-                eAdjust = SVX_ADJUST_LEFT;
+                eAdjust = SvxAdjust::Left;
             else if(nPos == 2)
-                eAdjust = SVX_ADJUST_RIGHT;
+                eAdjust = SvxAdjust::Right;
             aNumFormat.SetNumAdjust( eAdjust );
             pActNum->Set(i, aNumFormat);
         }
@@ -613,12 +611,12 @@ IMPL_LINK_NOARG_TYPED(SwNumPositionTabPage, EditModifyHdl, ListBox&, void)
     SetModified();
 }
 
-IMPL_LINK_TYPED( SwNumPositionTabPage, LevelHdl, ListBox&, rBox, void )
+IMPL_LINK( SwNumPositionTabPage, LevelHdl, ListBox&, rBox, void )
 {
     sal_uInt16 nSaveNumLvl = nActNumLvl;
     nActNumLvl = 0;
     if(rBox.IsEntryPosSelected( MAXLEVEL ) &&
-            (rBox.GetSelectEntryCount() == 1 || nSaveNumLvl != 0xffff))
+            (rBox.GetSelectedEntryCount() == 1 || nSaveNumLvl != 0xffff))
     {
         nActNumLvl = 0xFFFF;
         rBox.SetUpdateMode(false);
@@ -626,7 +624,7 @@ IMPL_LINK_TYPED( SwNumPositionTabPage, LevelHdl, ListBox&, rBox, void )
             rBox.SelectEntryPos( i, false );
         rBox.SetUpdateMode(true);
     }
-    else if(rBox.GetSelectEntryCount())
+    else if(rBox.GetSelectedEntryCount())
     {
         sal_uInt16 nMask = 1;
         for( sal_uInt16 i = 0; i < MAXLEVEL; i++ )
@@ -658,11 +656,11 @@ IMPL_LINK_TYPED( SwNumPositionTabPage, LevelHdl, ListBox&, rBox, void )
     InitControls();
 }
 
-IMPL_LINK_TYPED( SwNumPositionTabPage, DistanceLoseFocusHdl, Control&, rControl, void )
+IMPL_LINK( SwNumPositionTabPage, DistanceLoseFocusHdl, Control&, rControl, void )
 {
     DistanceHdl(static_cast<SpinField&>(rControl));
 }
-IMPL_LINK_TYPED( SwNumPositionTabPage, DistanceHdl, SpinField&, rSpin, void )
+IMPL_LINK( SwNumPositionTabPage, DistanceHdl, SpinField&, rSpin, void )
 {
     if(bInInintControl)
         return;
@@ -721,10 +719,10 @@ IMPL_LINK_TYPED( SwNumPositionTabPage, DistanceHdl, SpinField&, rSpin, void )
         m_pDistBorderMF->SetText(aEmptyOUStr);
 }
 
-IMPL_LINK_TYPED( SwNumPositionTabPage, RelativeHdl, Button *, pBox, void )
+IMPL_LINK( SwNumPositionTabPage, RelativeHdl, Button *, pBox, void )
 {
     bool bOn = static_cast<CheckBox*>(pBox)->IsChecked();
-    bool bSingleSelection = m_pLevelLB->GetSelectEntryCount() == 1 && USHRT_MAX != nActNumLvl;
+    bool bSingleSelection = m_pLevelLB->GetSelectedEntryCount() == 1 && USHRT_MAX != nActNumLvl;
     bool bSetValue = false;
     long nValue = 0;
     if(bOn || bSingleSelection)
@@ -759,12 +757,12 @@ IMPL_LINK_TYPED( SwNumPositionTabPage, RelativeHdl, Button *, pBox, void )
     bLastRelative = bOn;
 }
 
-IMPL_LINK_NOARG_TYPED(SwNumPositionTabPage, LabelFollowedByHdl_Impl, ListBox&, void)
+IMPL_LINK_NOARG(SwNumPositionTabPage, LabelFollowedByHdl_Impl, ListBox&, void)
 {
     // determine value to be set at the chosen list levels
     SvxNumberFormat::LabelFollowedBy eLabelFollowedBy = SvxNumberFormat::LISTTAB;
     {
-        const sal_Int32 nPos = m_pLabelFollowedByLB->GetSelectEntryPos();
+        const sal_Int32 nPos = m_pLabelFollowedByLB->GetSelectedEntryPos();
         if ( nPos == 1 )
         {
             eLabelFollowedBy = SvxNumberFormat::SPACE;
@@ -818,7 +816,11 @@ IMPL_LINK_NOARG_TYPED(SwNumPositionTabPage, LabelFollowedByHdl_Impl, ListBox&, v
     SetModified();
 }
 
-IMPL_LINK_TYPED( SwNumPositionTabPage, ListtabPosHdl_Impl, SpinField&, rSpin, void )
+IMPL_LINK( SwNumPositionTabPage, ListtabPosFocusHdl_Impl, Control&, rControl, void )
+{
+    ListtabPosHdl_Impl(static_cast<SpinField&>(rControl));
+}
+IMPL_LINK( SwNumPositionTabPage, ListtabPosHdl_Impl, SpinField&, rSpin, void )
 {
     MetricField& rField = static_cast<MetricField&>(rSpin);
     // determine value to be set at the chosen list levels
@@ -840,7 +842,11 @@ IMPL_LINK_TYPED( SwNumPositionTabPage, ListtabPosHdl_Impl, SpinField&, rSpin, vo
     SetModified();
 }
 
-IMPL_LINK_TYPED( SwNumPositionTabPage, AlignAtHdl_Impl, SpinField&, rSpin, void )
+IMPL_LINK( SwNumPositionTabPage, AlignAtFocusHdl_Impl, Control&, rControl, void )
+{
+    AlignAtHdl_Impl(static_cast<SpinField&>(rControl));
+}
+IMPL_LINK( SwNumPositionTabPage, AlignAtHdl_Impl, SpinField&, rSpin, void )
 {
     MetricField& rField = static_cast<MetricField&>(rSpin);
     // determine value to be set at the chosen list levels
@@ -863,7 +869,11 @@ IMPL_LINK_TYPED( SwNumPositionTabPage, AlignAtHdl_Impl, SpinField&, rSpin, void
     SetModified();
 }
 
-IMPL_LINK_TYPED( SwNumPositionTabPage, IndentAtHdl_Impl, SpinField&, rSpin, void )
+IMPL_LINK( SwNumPositionTabPage, IndentAtFocusHdl_Impl, Control&, rControl, void )
+{
+    IndentAtHdl_Impl(static_cast<SpinField&>(rControl));
+}
+IMPL_LINK( SwNumPositionTabPage, IndentAtHdl_Impl, SpinField&, rSpin, void )
 {
     MetricField& rField = static_cast<MetricField&>(rSpin);
     // determine value to be set at the chosen list levels
@@ -889,7 +899,7 @@ IMPL_LINK_TYPED( SwNumPositionTabPage, IndentAtHdl_Impl, SpinField&, rSpin, void
     SetModified();
 }
 
-IMPL_LINK_NOARG_TYPED(SwNumPositionTabPage, StandardHdl, Button*, void)
+IMPL_LINK_NOARG(SwNumPositionTabPage, StandardHdl, Button*, void)
 {
     sal_uInt16 nMask = 1;
     for(sal_uInt16 i = 0; i < MAXLEVEL; i++)
@@ -926,14 +936,11 @@ IMPL_LINK_NOARG_TYPED(SwNumPositionTabPage, StandardHdl, Button*, void)
 }
 
 #ifdef DBG_UTIL
-void SwNumPositionTabPage::SetModified(bool bRepaint)
+void SwNumPositionTabPage::SetModified()
 {
     bModified = true;
-    if(bRepaint)
-    {
-        m_pPreviewWIN->SetLevel(nActNumLvl);
-        m_pPreviewWIN->Invalidate();
-    }
+    m_pPreviewWIN->SetLevel(nActNumLvl);
+    m_pPreviewWIN->Invalidate();
 }
 #endif
 
@@ -950,7 +957,7 @@ SwSvxNumBulletTabDialog::SwSvxNumBulletTabDialog(vcl::Window* pParent,
     m_nBulletPageId = AddTabPage("bullets", RID_SVXPAGE_PICK_BULLET );
     AddTabPage("outlinenum", RID_SVXPAGE_PICK_NUM );
     AddTabPage("graphics", RID_SVXPAGE_PICK_BMP );
-    m_nOptionsPageId = AddTabPage("options", RID_SVXPAGE_NUM_OPTIONS );
+    m_nOptionsPageId = AddTabPage("customize", RID_SVXPAGE_NUM_OPTIONS );
     m_nPositionPageId = AddTabPage("position", RID_SVXPAGE_NUM_POSITION );
 }
 
@@ -1013,11 +1020,11 @@ void SwSvxNumBulletTabDialog::PageCreated(sal_uInt16 nPageId, SfxTabPage& rPage)
 short  SwSvxNumBulletTabDialog::Ok()
 {
     short nRet = SfxTabDialog::Ok();
-    pExampleSet->ClearItem(SID_PARAM_NUM_PRESET);
+    m_pExampleSet->ClearItem(SID_PARAM_NUM_PRESET);
     return nRet;
 }
 
-IMPL_LINK_NOARG_TYPED(SwSvxNumBulletTabDialog, RemoveNumberingHdl, Button*, void)
+IMPL_LINK_NOARG(SwSvxNumBulletTabDialog, RemoveNumberingHdl, Button*, void)
 {
     EndDialog(RET_USER);
 }
