@@ -17,13 +17,13 @@
 #include <charfmt.hxx>
 #include <docstyle.hxx>
 
-#include "fldbas.hxx"
-#include "lineinfo.hxx"
-#include "globals.hrc"
-#include "titlepage.hxx"
-#include "uitool.hxx"
-#include "fmtpdsc.hxx"
-#include "pagedesc.hxx"
+#include <fldbas.hxx>
+#include <lineinfo.hxx>
+#include <globals.hrc>
+#include <titlepage.hxx>
+#include <uitool.hxx>
+#include <fmtpdsc.hxx>
+#include <pagedesc.hxx>
 
 #include <IDocumentStylePoolAccess.hxx>
 
@@ -32,10 +32,10 @@ namespace
     bool lcl_GetPageDesc(SwWrtShell *pSh, sal_uInt16 &rPageNo, const SwFormatPageDesc **ppPageFormatDesc)
     {
         bool bRet = false;
-        SfxItemSet aSet( pSh->GetAttrPool(), RES_PAGEDESC, RES_PAGEDESC );
+        SfxItemSet aSet( pSh->GetAttrPool(), svl::Items<RES_PAGEDESC, RES_PAGEDESC>{} );
         if (pSh->GetCurAttr( aSet ))
         {
-            const SfxPoolItem* pItem(0);
+            const SfxPoolItem* pItem(nullptr);
             if (SfxItemState::SET == aSet.GetItemState( RES_PAGEDESC, true, &pItem ) && pItem)
             {
                 ::boost::optional<sal_uInt16> oNumOffset = static_cast<const SwFormatPageDesc *>(pItem)->GetNumOffset();
@@ -55,7 +55,7 @@ namespace
         const size_t nCurIdx = pSh->GetCurPageDesc();
         const SwPageDesc &rCurrentDesc = pSh->GetPageDesc( nCurIdx );
 
-        const SwFormatPageDesc *pPageFormatDesc(0);
+        const SwFormatPageDesc *pPageFormatDesc(nullptr);
         sal_uInt16 nDontCare;
         lcl_GetPageDesc(pSh, nDontCare, &pPageFormatDesc);
 
@@ -85,7 +85,7 @@ namespace
             }
         }
 
-        // If we want a new descriptior then set it, otherwise reuse the existing one
+        // If we want a new descriptor then set it, otherwise reuse the existing one
         if (!pNewDesc)
         {
             SwFormatPageDesc aPageFormatDesc(pPageFormatDesc ? *pPageFormatDesc : &rCurrentDesc);
@@ -106,17 +106,17 @@ namespace
     {
         pSh->LockView( true );
         pSh->StartAllAction();
-        pSh->SwCrsrShell::Push();
+        pSh->SwCursorShell::Push();
     }
 
     void lcl_PopCursor(SwWrtShell *pSh)
     {
-        pSh->SwCrsrShell::Pop( false );
+        pSh->SwCursorShell::Pop(SwCursorShell::PopMode::DeleteCurrent);
         pSh->EndAllAction();
         pSh->LockView( false );
     }
 
-    sal_uInt16 lcl_GetCurrentPage(SwWrtShell *pSh)
+    sal_uInt16 lcl_GetCurrentPage(SwWrtShell const *pSh)
     {
         OUString sDummy;
         sal_uInt16 nPhyNum=1, nVirtNum=1;
@@ -152,7 +152,7 @@ sal_uInt16 SwTitlePageDlg::GetInsertPosition() const
 
 SwTitlePageDlg::SwTitlePageDlg( vcl::Window *pParent ) :
     SfxModalDialog( pParent, "DLG_TITLEPAGE", "modules/swriter/ui/titlepage.ui"),
-    mpPageFormatDesc(0)
+    mpPageFormatDesc(nullptr)
 {
     get(m_pUseExistingPagesRB, "RB_USE_EXISTING_PAGES");
     get(m_pPageCountNF, "NF_PAGE_COUNT");
@@ -199,7 +199,7 @@ SwTitlePageDlg::SwTitlePageDlg( vcl::Window *pParent ) :
                 if (mpIndexDesc != &rPageDesc)
                 {
                     mpNormalDesc = &rPageDesc;
-                    bMaybeResetNumbering = lcl_GetPageDesc(mpSh, nResetPage, NULL);
+                    bMaybeResetNumbering = lcl_GetPageDesc(mpSh, nResetPage, nullptr);
                     break;
                 }
                 ++nTitlePages;
@@ -216,7 +216,7 @@ SwTitlePageDlg::SwTitlePageDlg( vcl::Window *pParent ) :
     m_pDocumentStartRB->Check();
     m_pPageStartNF->Enable(false);
     m_pPageStartNF->SetValue(lcl_GetCurrentPage(mpSh));
-    Link<> aStartPageHdl = LINK(this, SwTitlePageDlg, StartPageHdl);
+    Link<Button*,void> aStartPageHdl = LINK(this, SwTitlePageDlg, StartPageHdl);
     m_pDocumentStartRB->SetClickHdl(aStartPageHdl);
     m_pPageStartRB->SetClickHdl(aStartPageHdl);
 
@@ -236,36 +236,31 @@ SwTitlePageDlg::SwTitlePageDlg( vcl::Window *pParent ) :
     m_pPagePropertiesPB->SetClickHdl(LINK(this, SwTitlePageDlg, EditHdl));
 }
 
-IMPL_LINK_NOARG(SwTitlePageDlg, UpHdl)
+IMPL_LINK_NOARG(SwTitlePageDlg, UpHdl, SpinField&, void)
 {
     if (m_pPageCountNF->GetValue() == 2)
         FillList();
-    return 0;
 }
 
-IMPL_LINK_NOARG(SwTitlePageDlg, DownHdl)
+IMPL_LINK_NOARG(SwTitlePageDlg, DownHdl, SpinField&, void)
 {
     if (m_pPageCountNF->GetValue() == 1)
         FillList();
-    return 0;
 }
 
-IMPL_LINK_NOARG(SwTitlePageDlg, RestartNumberingHdl)
+IMPL_LINK_NOARG(SwTitlePageDlg, RestartNumberingHdl, Button*, void)
 {
     m_pRestartNumberingNF->Enable(m_pRestartNumberingCB->IsChecked());
-    return 0;
 }
 
-IMPL_LINK_NOARG(SwTitlePageDlg, SetPageNumberHdl)
+IMPL_LINK_NOARG(SwTitlePageDlg, SetPageNumberHdl, Button*, void)
 {
     m_pSetPageNumberNF->Enable(m_pSetPageNumberCB->IsChecked());
-    return 0;
 }
 
-IMPL_LINK_NOARG(SwTitlePageDlg, StartPageHdl)
+IMPL_LINK_NOARG(SwTitlePageDlg, StartPageHdl, Button*, void)
 {
     m_pPageStartNF->Enable(m_pPageStartRB->IsChecked());
-    return 0;
 }
 
 SwTitlePageDlg::~SwTitlePageDlg()
@@ -291,16 +286,14 @@ void SwTitlePageDlg::dispose()
     SfxModalDialog::dispose();
 }
 
-IMPL_LINK_NOARG(SwTitlePageDlg, EditHdl)
+IMPL_LINK_NOARG(SwTitlePageDlg, EditHdl, Button*, void)
 {
     SwView& rView = mpSh->GetView();
-    rView.GetDocShell()->FormatPage(m_pPagePropertiesLB->GetSelectEntry(), "page", *mpSh);
+    rView.GetDocShell()->FormatPage(m_pPagePropertiesLB->GetSelectedEntry(), "page", *mpSh);
     rView.InvalidateRulerPos();
-
-    return 0;
 }
 
-IMPL_LINK_NOARG(SwTitlePageDlg, OKHdl)
+IMPL_LINK_NOARG(SwTitlePageDlg, OKHdl, Button*, void)
 {
     lcl_PushCursor(mpSh);
 
@@ -340,7 +333,7 @@ IMPL_LINK_NOARG(SwTitlePageDlg, OKHdl)
     if (m_pRestartNumberingCB->IsChecked() || nNoPages > 1)
     {
         sal_uInt16 nPgNo = m_pRestartNumberingCB->IsChecked() ? m_pRestartNumberingNF->GetValue() : 0;
-        const SwPageDesc *pNewDesc = nNoPages > 1 ? mpNormalDesc : 0;
+        const SwPageDesc *pNewDesc = nNoPages > 1 ? mpNormalDesc : nullptr;
         mpSh->GotoPage(GetInsertPosition() + nNoPages, false);
         lcl_ChangePage(mpSh, nPgNo, pNewDesc);
     }
@@ -350,7 +343,6 @@ IMPL_LINK_NOARG(SwTitlePageDlg, OKHdl)
     if (!m_pUseExistingPagesRB->IsChecked())
         mpSh->GotoPage(GetInsertPosition(), false);
     EndDialog( RET_OK );
-    return 0;
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
