@@ -19,12 +19,12 @@
 
 #include <hintids.hxx>
 
-#include <svx/dialogs.hrc>
 #include <i18nlangtag/mslangid.hxx>
 #include <sot/storinfo.hxx>
 #include <sot/storage.hxx>
 #include <svl/zforlist.hxx>
 #include <svtools/ctrltool.hxx>
+#include <unotools/configmgr.hxx>
 #include <unotools/lingucfg.hxx>
 #include <sfx2/docfile.hxx>
 #include <sfx2/sfxmodelfactory.hxx>
@@ -48,6 +48,8 @@
 #include <editeng/tstpitem.hxx>
 #include <editeng/langitem.hxx>
 #include <editeng/colritem.hxx>
+#include <editeng/orphitem.hxx>
+#include <editeng/widwitem.hxx>
 #include <editeng/hyphenzoneitem.hxx>
 #include <editeng/svxacorr.hxx>
 #include <vcl/svapp.hxx>
@@ -85,12 +87,13 @@
 #include <swerror.h>
 #include <globals.hrc>
 #include <unochart.hxx>
+#include <drawdoc.hxx>
 
 #include <svx/CommonStyleManager.hxx>
 
 // text grid
 #include <tgrditem.hxx>
-#include <boost/scoped_ptr.hpp>
+#include <memory>
 
 using namespace ::com::sun::star::i18n;
 using namespace ::com::sun::star::lang;
@@ -101,46 +104,49 @@ using namespace ::com::sun::star;
 bool SwDocShell::InitNew( const uno::Reference < embed::XStorage >& xStor )
 {
     bool bRet = SfxObjectShell::InitNew( xStor );
-    OSL_ENSURE( GetMapUnit() == MAP_TWIP, "map unit is not twip!" );
+    OSL_ENSURE( GetMapUnit() == MapUnit::MapTwip, "map unit is not twip!" );
     bool bHTMLTemplSet = false;
     if( bRet )
     {
-        AddLink();      // create m_pDoc / pIo if applicable
+        AddLink();      // create m_xDoc / pIo if applicable
 
-        bool bWeb = ISA( SwWebDocShell );
+        bool bWeb = dynamic_cast< const SwWebDocShell *>( this ) !=  nullptr;
         if ( bWeb )
             bHTMLTemplSet = SetHTMLTemplate( *GetDoc() );// Styles from HTML.vor
-        else if( ISA( SwGlobalDocShell ) )
+        else if( dynamic_cast< const SwGlobalDocShell *>( this ) !=  nullptr )
             GetDoc()->getIDocumentSettingAccess().set(DocumentSettingId::GLOBAL_DOCUMENT, true);       // Globaldokument
 
         if ( GetCreateMode() ==  SfxObjectCreateMode::EMBEDDED )
-            SwTransferable::InitOle( this, *m_pDoc );
+            SwTransferable::InitOle( this );
 
         // set forbidden characters if necessary
-        SvxAsianConfig aAsian;
-        Sequence<lang::Locale> aLocales =  aAsian.GetStartEndCharLocales();
-        if(aLocales.getLength())
+        if (!utl::ConfigManager::IsFuzzing())
         {
-            const lang::Locale* pLocales = aLocales.getConstArray();
-            for(sal_Int32 i = 0; i < aLocales.getLength(); i++)
+            SvxAsianConfig aAsian;
+            Sequence<lang::Locale> aLocales =  aAsian.GetStartEndCharLocales();
+            if (aLocales.getLength())
             {
-                ForbiddenCharacters aForbidden;
-                aAsian.GetStartEndChars( pLocales[i], aForbidden.beginLine, aForbidden.endLine);
-                LanguageType  eLang = LanguageTag::convertToLanguageType(pLocales[i]);
-                m_pDoc->getIDocumentSettingAccess().setForbiddenCharacters( eLang, aForbidden);
+                const lang::Locale* pLocales = aLocales.getConstArray();
+                for(sal_Int32 i = 0; i < aLocales.getLength(); i++)
+                {
+                    ForbiddenCharacters aForbidden;
+                    aAsian.GetStartEndChars( pLocales[i], aForbidden.beginLine, aForbidden.endLine);
+                    LanguageType  eLang = LanguageTag::convertToLanguageType(pLocales[i]);
+                    m_xDoc->getIDocumentSettingAccess().setForbiddenCharacters( eLang, aForbidden);
+                }
             }
-        }
-        m_pDoc->getIDocumentSettingAccess().set(DocumentSettingId::KERN_ASIAN_PUNCTUATION,
+            m_xDoc->getIDocumentSettingAccess().set(DocumentSettingId::KERN_ASIAN_PUNCTUATION,
                   !aAsian.IsKerningWesternTextOnly());
-        m_pDoc->getIDocumentSettingAccess().setCharacterCompressionType(static_cast<SwCharCompressType>(aAsian.GetCharDistanceCompression()));
-        m_pDoc->getIDocumentDeviceAccess().setPrintData(*SW_MOD()->GetPrtOptions(bWeb));
+            m_xDoc->getIDocumentSettingAccess().setCharacterCompressionType(aAsian.GetCharDistanceCompression());
+            m_xDoc->getIDocumentDeviceAccess().setPrintData(*SW_MOD()->GetPrtOptions(bWeb));
+        }
 
         SubInitNew();
 
         // for all
 
         SwStdFontConfig* pStdFont = SW_MOD()->GetStdFontConfig();
-        SfxPrinter* pPrt = m_pDoc->getIDocumentDeviceAccess().getPrinter( false );
+        SfxPrinter* pPrt = m_xDoc->getIDocumentDeviceAccess().getPrinter( false );
 
         OUString sEntry;
         static const sal_uInt16 aFontWhich[] =
@@ -177,8 +183,8 @@ bool SwDocShell::InitNew( const uno::Reference < embed::XStorage >& xStor )
         {
             sal_uInt16 nFontWhich = aFontWhich[i];
             sal_uInt16 nFontId = aFontIds[i];
-            boost::scoped_ptr<SvxFontItem> pFontItem;
-            const SvxLanguageItem& rLang = static_cast<const SvxLanguageItem&>(m_pDoc->GetDefault( aLangTypes[i] ));
+            std::unique_ptr<SvxFontItem> pFontItem;
+            const SvxLanguageItem& rLang = static_cast<const SvxLanguageItem&>(m_xDoc->GetDefault( aLangTypes[i] ));
             LanguageType eLanguage = rLang.GetLanguage();
             if(!pStdFont->IsFontDefault(nFontId))
             {
@@ -190,7 +196,7 @@ bool SwDocShell::InitNew( const uno::Reference < embed::XStorage >& xStor )
                     aFont = pPrt->GetFontMetric( aFont );
                 }
 
-                pFontItem.reset(new SvxFontItem(aFont.GetFamily(), aFont.GetName(),
+                pFontItem.reset(new SvxFontItem(aFont.GetFamilyType(), aFont.GetFamilyName(),
                                                 aEmptyOUStr, aFont.GetPitch(), aFont.GetCharSet(), nFontWhich));
             }
             else
@@ -207,23 +213,23 @@ bool SwDocShell::InitNew( const uno::Reference < embed::XStorage >& xStor )
                     nFontTypes[i],
                     eLanguage,
                     GetDefaultFontFlags::OnlyOne );
-                pFontItem.reset(new SvxFontItem(aLangDefFont.GetFamily(), aLangDefFont.GetName(),
+                pFontItem.reset(new SvxFontItem(aLangDefFont.GetFamilyType(), aLangDefFont.GetFamilyName(),
                                                 aEmptyOUStr, aLangDefFont.GetPitch(), aLangDefFont.GetCharSet(), nFontWhich));
             }
-            m_pDoc->SetDefault(*pFontItem);
+            m_xDoc->SetDefault(*pFontItem);
             if( !bHTMLTemplSet )
             {
-                SwTextFormatColl *pColl = m_pDoc->getIDocumentStylePoolAccess().GetTextCollFromPool(RES_POOLCOLL_STANDARD);
+                SwTextFormatColl *pColl = m_xDoc->getIDocumentStylePoolAccess().GetTextCollFromPool(RES_POOLCOLL_STANDARD);
                 pColl->ResetFormatAttr(nFontWhich);
             }
             pFontItem.reset();
             sal_Int32 nFontHeight = pStdFont->GetFontHeight( FONT_STANDARD, i, eLanguage );
             if(nFontHeight <= 0)
                 nFontHeight = SwStdFontConfig::GetDefaultHeightFor( nFontId, eLanguage );
-            m_pDoc->SetDefault(SvxFontHeightItem( nFontHeight, 100, aFontHeightWhich[i] ));
+            m_xDoc->SetDefault(SvxFontHeightItem( nFontHeight, 100, aFontHeightWhich[i] ));
             if( !bHTMLTemplSet )
             {
-                SwTextFormatColl *pColl = m_pDoc->getIDocumentStylePoolAccess().GetTextCollFromPool(RES_POOLCOLL_STANDARD);
+                SwTextFormatColl *pColl = m_xDoc->getIDocumentStylePoolAccess().GetTextCollFromPool(RES_POOLCOLL_STANDARD);
                 pColl->ResetFormatAttr(aFontHeightWhich[i]);
             }
 
@@ -246,22 +252,22 @@ bool SwDocShell::InitNew( const uno::Reference < embed::XStorage >& xStor )
 
         sal_uInt16 nFontWhich = RES_CHRATR_FONT;
         sal_uInt16 nFontHeightWhich = RES_CHRATR_FONTSIZE;
-        LanguageType eLanguage = static_cast<const SvxLanguageItem&>(m_pDoc->GetDefault( RES_CHRATR_LANGUAGE )).GetLanguage();
+        LanguageType eLanguage = static_cast<const SvxLanguageItem&>(m_xDoc->GetDefault( RES_CHRATR_LANGUAGE )).GetLanguage();
         for(sal_uInt8 nIdx = 0; nIdx < 24; nIdx += 2)
         {
             if(nIdx == 8)
             {
                 nFontWhich = RES_CHRATR_CJK_FONT;
                 nFontHeightWhich = RES_CHRATR_CJK_FONTSIZE;
-                eLanguage = static_cast<const SvxLanguageItem&>(m_pDoc->GetDefault( RES_CHRATR_CJK_LANGUAGE )).GetLanguage();
+                eLanguage = static_cast<const SvxLanguageItem&>(m_xDoc->GetDefault( RES_CHRATR_CJK_LANGUAGE )).GetLanguage();
             }
             else if(nIdx == 16)
             {
                 nFontWhich = RES_CHRATR_CTL_FONT;
                 nFontHeightWhich = RES_CHRATR_CTL_FONTSIZE;
-                eLanguage = static_cast<const SvxLanguageItem&>(m_pDoc->GetDefault( RES_CHRATR_CTL_LANGUAGE )).GetLanguage();
+                eLanguage = static_cast<const SvxLanguageItem&>(m_xDoc->GetDefault( RES_CHRATR_CTL_LANGUAGE )).GetLanguage();
             }
-            SwTextFormatColl *pColl = 0;
+            SwTextFormatColl *pColl = nullptr;
             if(!pStdFont->IsFontDefault(aFontIdPoolId[nIdx]))
             {
                 sEntry = pStdFont->GetFontFor(aFontIdPoolId[nIdx]);
@@ -270,12 +276,12 @@ bool SwDocShell::InitNew( const uno::Reference < embed::XStorage >& xStor )
                 if( pPrt )
                     aFont = pPrt->GetFontMetric( aFont );
 
-                pColl = m_pDoc->getIDocumentStylePoolAccess().GetTextCollFromPool(aFontIdPoolId[nIdx + 1]);
+                pColl = m_xDoc->getIDocumentStylePoolAccess().GetTextCollFromPool(aFontIdPoolId[nIdx + 1]);
                 if( !bHTMLTemplSet ||
                     SfxItemState::SET != pColl->GetAttrSet().GetItemState(
                                                     nFontWhich, false ) )
                 {
-                    pColl->SetFormatAttr(SvxFontItem(aFont.GetFamily(), aFont.GetName(),
+                    pColl->SetFormatAttr(SvxFontItem(aFont.GetFamilyType(), aFont.GetFamilyName(),
                                                   aEmptyOUStr, aFont.GetPitch(), aFont.GetCharSet(), nFontWhich));
                 }
             }
@@ -283,8 +289,8 @@ bool SwDocShell::InitNew( const uno::Reference < embed::XStorage >& xStor )
             if(nFontHeight <= 0)
                 nFontHeight = SwStdFontConfig::GetDefaultHeightFor( aFontIdPoolId[nIdx], eLanguage );
             if(!pColl)
-                pColl = m_pDoc->getIDocumentStylePoolAccess().GetTextCollFromPool(aFontIdPoolId[nIdx + 1]);
-            SvxFontHeightItem aFontHeight( static_cast<const SvxFontHeightItem&>(pColl->GetFormatAttr( nFontHeightWhich, true )));
+                pColl = m_xDoc->getIDocumentStylePoolAccess().GetTextCollFromPool(aFontIdPoolId[nIdx + 1]);
+            SvxFontHeightItem aFontHeight( static_cast<const SvxFontHeightItem&>(pColl->GetFormatAttr( nFontHeightWhich )));
             if(aFontHeight.GetHeight() != sal::static_int_cast<sal_uInt32, sal_Int32>(nFontHeight))
             {
                 aFontHeight.SetHeight(nFontHeight);
@@ -295,29 +301,29 @@ bool SwDocShell::InitNew( const uno::Reference < embed::XStorage >& xStor )
         // the default for documents created via 'File/New' should be 'on'
         // (old documents, where this property was not yet implemented, will get the
         // value 'false' in the SwDoc c-tor)
-        m_pDoc->getIDocumentSettingAccess().set( DocumentSettingId::MATH_BASELINE_ALIGNMENT,
+        m_xDoc->getIDocumentSettingAccess().set( DocumentSettingId::MATH_BASELINE_ALIGNMENT,
                 SW_MOD()->GetUsrPref( bWeb )->IsAlignMathObjectsToBaseline() );
     }
 
     /* #106748# If the default frame direction of a document is RTL
-        the default adjusment is to the right. */
+        the default adjustment is to the right. */
     if( !bHTMLTemplSet &&
-        FRMDIR_HORI_RIGHT_TOP == GetDefaultFrameDirection(GetAppLanguage()) )
+        SvxFrameDirection::Horizontal_RL_TB == GetDefaultFrameDirection(GetAppLanguage()) )
     {
-        m_pDoc->SetDefault( SvxAdjustItem(SVX_ADJUST_RIGHT, RES_PARATR_ADJUST ) );
+        m_xDoc->SetDefault( SvxAdjustItem(SvxAdjust::Right, RES_PARATR_ADJUST ) );
     }
 
 // #i29550#
-    m_pDoc->SetDefault( SfxBoolItem( RES_COLLAPSING_BORDERS, true ) );
+    m_xDoc->SetDefault( SfxBoolItem( RES_COLLAPSING_BORDERS, true ) );
 // <-- collapsing
 
     //#i16874# AutoKerning as default for new documents
-    m_pDoc->SetDefault( SvxAutoKernItem( true, RES_CHRATR_AUTOKERN ) );
+    m_xDoc->SetDefault( SvxAutoKernItem( true, RES_CHRATR_AUTOKERN ) );
 
     // #i42080# - Due to the several calls of method <SetDefault(..)>
     // at the document instance, the document is modified. Thus, reset this
     // status here. Note: In method <SubInitNew()> this is also done.
-    m_pDoc->getIDocumentState().ResetModified();
+    m_xDoc->getIDocumentState().ResetModified();
 
     return bRet;
 }
@@ -325,7 +331,6 @@ bool SwDocShell::InitNew( const uno::Reference < embed::XStorage >& xStor )
 // Ctor with SfxCreateMode ?????
 SwDocShell::SwDocShell( SfxObjectCreateMode const eMode )
     : SfxObjectShell(eMode)
-    , m_pDoc(nullptr)
     , m_pFontList(nullptr)
     , m_IsInUpdateFontList(false)
     , m_pStyleManager(new svx::CommonStyleManager(*this))
@@ -342,7 +347,6 @@ SwDocShell::SwDocShell( SfxObjectCreateMode const eMode )
 // Ctor / Dtor
 SwDocShell::SwDocShell( const SfxModelFlags i_nSfxCreationFlags )
     : SfxObjectShell ( i_nSfxCreationFlags )
-    , m_pDoc(nullptr)
     , m_pFontList(nullptr)
     , m_IsInUpdateFontList(false)
     , m_pStyleManager(new svx::CommonStyleManager(*this))
@@ -359,7 +363,7 @@ SwDocShell::SwDocShell( const SfxModelFlags i_nSfxCreationFlags )
 // Ctor / Dtor
 SwDocShell::SwDocShell( SwDoc *const pD, SfxObjectCreateMode const eMode )
     : SfxObjectShell(eMode)
-    , m_pDoc(pD)
+    , m_xDoc(pD)
     , m_pFontList(nullptr)
     , m_IsInUpdateFontList(false)
     , m_pStyleManager(new svx::CommonStyleManager(*this))
@@ -377,10 +381,10 @@ SwDocShell::SwDocShell( SwDoc *const pD, SfxObjectCreateMode const eMode )
 SwDocShell::~SwDocShell()
 {
     // disable chart related objects now because in ~SwDoc it may be to late for this
-    if (m_pDoc)
+    if (m_xDoc.get())
     {
-        m_pDoc->getIDocumentChartDataProviderAccess().GetChartControllerHelper().Disconnect();
-        SwChartDataProvider *pPCD = m_pDoc->getIDocumentChartDataProviderAccess().GetChartDataProvider();
+        m_xDoc->getIDocumentChartDataProviderAccess().GetChartControllerHelper().Disconnect();
+        SwChartDataProvider *pPCD = m_xDoc->getIDocumentChartDataProviderAccess().GetChartDataProvider();
         if (pPCD)
             pPCD->dispose();
     }
@@ -406,28 +410,25 @@ void  SwDocShell::Init_Impl()
     SetAutoStyleFilterIndex(3);
 
     // set map unit to twip
-    SetMapUnit( MAP_TWIP );
+    SetMapUnit( MapUnit::MapTwip );
 }
 
 void SwDocShell::AddLink()
 {
-    if (!m_pDoc)
+    if (!m_xDoc.get())
     {
         SwDocFac aFactory;
-        m_pDoc = aFactory.GetDoc();
-        m_pDoc->acquire();
-        m_pDoc->getIDocumentSettingAccess().set(DocumentSettingId::HTML_MODE, ISA(SwWebDocShell) );
+        m_xDoc = aFactory.GetDoc();
+        m_xDoc->getIDocumentSettingAccess().set(DocumentSettingId::HTML_MODE, dynamic_cast< const SwWebDocShell *>( this ) !=  nullptr );
     }
-    else
-        m_pDoc->acquire();
-    m_pDoc->SetDocShell( this );      // set the DocShell-Pointer for Doc
+    m_xDoc->SetDocShell( this );      // set the DocShell-Pointer for Doc
     uno::Reference< text::XTextDocument >  xDoc(GetBaseModel(), uno::UNO_QUERY);
     static_cast<SwXTextDocument*>(xDoc.get())->Reactivate(this);
 
-    SetPool(&m_pDoc->GetAttrPool());
+    SetPool(&m_xDoc->GetAttrPool());
 
     // most suitably not until a sdbcx::View is created!!!
-    m_pDoc->SetOle2Link(LINK(this, SwDocShell, Ole2ModifiedHdl));
+    m_xDoc->SetOle2Link(LINK(this, SwDocShell, Ole2ModifiedHdl));
 }
 
 // create new FontList Change Printer
@@ -436,11 +437,11 @@ void SwDocShell::UpdateFontList()
     if (!m_IsInUpdateFontList)
     {
         m_IsInUpdateFontList = true;
-        OSL_ENSURE(m_pDoc, "No Doc no FontList");
-        if (m_pDoc)
+        OSL_ENSURE(m_xDoc.get(), "No Doc no FontList");
+        if (m_xDoc.get())
         {
             delete m_pFontList;
-            m_pFontList = new FontList( m_pDoc->getIDocumentDeviceAccess().getReferenceDevice(true) );
+            m_pFontList = new FontList( m_xDoc->getIDocumentDeviceAccess().getReferenceDevice(true) );
             PutItem( SvxFontListItem( m_pFontList, SID_ATTR_CHAR_FONTLIST ) );
         }
         m_IsInUpdateFontList = false;
@@ -452,19 +453,16 @@ void SwDocShell::RemoveLink()
     // disconnect Uno-Object
     uno::Reference< text::XTextDocument >  xDoc(GetBaseModel(), uno::UNO_QUERY);
     static_cast<SwXTextDocument*>(xDoc.get())->Invalidate();
-    if (m_pDoc)
+    if (m_xDoc.get())
     {
         if (m_xBasePool.is())
         {
             static_cast<SwDocStyleSheetPool*>(m_xBasePool.get())->dispose();
             m_xBasePool.clear();
         }
-        sal_Int8 nRefCt = static_cast< sal_Int8 >(m_pDoc->release());
-        m_pDoc->SetOle2Link(Link<>());
-        m_pDoc->SetDocShell( 0 );
-        if( !nRefCt )
-            delete m_pDoc;
-        m_pDoc = 0;       // we don't have the Doc anymore!!
+        m_xDoc->SetOle2Link(Link<bool,void>());
+        m_xDoc->SetDocShell( nullptr );
+        m_xDoc.clear();       // we don't have the Doc anymore!!
     }
 }
 void SwDocShell::InvalidateModel()
@@ -484,10 +482,22 @@ void SwDocShell::ReactivateModel()
 bool  SwDocShell::Load( SfxMedium& rMedium )
 {
     bool bRet = false;
-    if( SfxObjectShell::Load( rMedium ))
+
+    // If this is an ODF file being loaded, then by default, use legacy processing
+    // for tdf#99729 (if required, it will be overridden in *::ReadUserDataSequence())
+    if (IsOwnStorageFormat(rMedium))
     {
+        if (m_xDoc.get() && m_xDoc->getIDocumentDrawModelAccess().GetDrawModel())
+            m_xDoc->getIDocumentDrawModelAccess().GetDrawModel()->SetAnchoredTextOverflowLegacy(true);
+    }
+
+    if (SfxObjectShell::Load(rMedium))
+    {
+        comphelper::EmbeddedObjectContainer& rEmbeddedObjectContainer = getEmbeddedObjectContainer();
+        rEmbeddedObjectContainer.setUserAllowsLinkUpdate(false);
+
         SAL_INFO( "sw.ui", "after SfxInPlaceObject::Load" );
-        if (m_pDoc)              // for last version!!
+        if (m_xDoc.get())       // for last version!!
             RemoveLink();       // release the existing
 
         AddLink();      // set Link and update Data!!
@@ -495,15 +505,15 @@ bool  SwDocShell::Load( SfxMedium& rMedium )
         // Loading
         // for MD
         OSL_ENSURE( !m_xBasePool.is(), "who hasn't destroyed their Pool?" );
-        m_xBasePool = new SwDocStyleSheetPool( *m_pDoc, SfxObjectCreateMode::ORGANIZER == GetCreateMode() );
+        m_xBasePool = new SwDocStyleSheetPool( *m_xDoc, SfxObjectCreateMode::ORGANIZER == GetCreateMode() );
         if(GetCreateMode() != SfxObjectCreateMode::ORGANIZER)
         {
-            SFX_ITEMSET_ARG( rMedium.GetItemSet(), pUpdateDocItem, SfxUInt16Item, SID_UPDATEDOCMODE, false);
+            const SfxUInt16Item* pUpdateDocItem = SfxItemSet::GetItem<SfxUInt16Item>(rMedium.GetItemSet(), SID_UPDATEDOCMODE, false);
             m_nUpdateDocMode = pUpdateDocItem ? pUpdateDocItem->GetValue() : document::UpdateDocMode::NO_UPDATE;
         }
 
         SwWait aWait( *this, true );
-        sal_uInt32 nErr = ERR_SWG_READ_ERROR;
+        ErrCode nErr = ERR_SWG_READ_ERROR;
         switch( GetCreateMode() )
         {
             case SfxObjectCreateMode::ORGANIZER:
@@ -511,7 +521,7 @@ bool  SwDocShell::Load( SfxMedium& rMedium )
                     if( ReadXML )
                     {
                         ReadXML->SetOrganizerMode( true );
-                        SwReader aRdr( rMedium, aEmptyOUStr, m_pDoc );
+                        SwReader aRdr( rMedium, aEmptyOUStr, m_xDoc.get() );
                         nErr = aRdr.Read( *ReadXML );
                         ReadXML->SetOrganizerMode( false );
                     }
@@ -521,36 +531,35 @@ bool  SwDocShell::Load( SfxMedium& rMedium )
             case SfxObjectCreateMode::INTERNAL:
             case SfxObjectCreateMode::EMBEDDED:
                 {
-                    SwTransferable::InitOle( this, *m_pDoc );
+                    SwTransferable::InitOle( this );
                 }
                 // suppress SfxProgress, when we are Embedded
                 SW_MOD()->SetEmbeddedLoadSave( true );
-                // no break;
+                SAL_FALLTHROUGH;
 
             case SfxObjectCreateMode::STANDARD:
-            case SfxObjectCreateMode::PREVIEW:
                 {
                     Reader *pReader = ReadXML;
                     if( pReader )
                     {
                         // set Doc's DocInfo at DocShell-Medium
                         SAL_INFO( "sw.ui", "before ReadDocInfo" );
-                        SwReader aRdr( rMedium, aEmptyOUStr, m_pDoc );
+                        SwReader aRdr( rMedium, aEmptyOUStr, m_xDoc.get() );
                         SAL_INFO( "sw.ui", "before Read" );
                         nErr = aRdr.Read( *pReader );
                         SAL_INFO( "sw.ui", "after Read" );
                         // If a XML document is loaded, the global doc/web doc
                         // flags have to be set, because they aren't loaded
                         // by this formats.
-                        if( ISA( SwWebDocShell ) )
+                        if( dynamic_cast< const SwWebDocShell *>( this ) !=  nullptr )
                         {
-                            if (!m_pDoc->getIDocumentSettingAccess().get(DocumentSettingId::HTML_MODE))
-                                m_pDoc->getIDocumentSettingAccess().set(DocumentSettingId::HTML_MODE, true);
+                            if (!m_xDoc->getIDocumentSettingAccess().get(DocumentSettingId::HTML_MODE))
+                                m_xDoc->getIDocumentSettingAccess().set(DocumentSettingId::HTML_MODE, true);
                         }
-                        if( ISA( SwGlobalDocShell ) )
+                        if( dynamic_cast< const SwGlobalDocShell *>( this ) !=  nullptr )
                         {
-                            if (!m_pDoc->getIDocumentSettingAccess().get(DocumentSettingId::GLOBAL_DOCUMENT))
-                                m_pDoc->getIDocumentSettingAccess().set(DocumentSettingId::GLOBAL_DOCUMENT, true);
+                            if (!m_xDoc->getIDocumentSettingAccess().get(DocumentSettingId::GLOBAL_DOCUMENT))
+                                m_xDoc->getIDocumentSettingAccess().set(DocumentSettingId::GLOBAL_DOCUMENT, true);
                         }
                     }
                 }
@@ -561,12 +570,12 @@ bool  SwDocShell::Load( SfxMedium& rMedium )
         }
 
         UpdateFontList();
-        InitDrawModelAndDocShell(this, m_pDoc ? m_pDoc->getIDocumentDrawModelAccess().GetDrawModel() : 0);
+        InitDrawModelAndDocShell(this, m_xDoc.get() ? m_xDoc->getIDocumentDrawModelAccess().GetDrawModel() : nullptr);
 
-        SetError( nErr, OUString( OSL_LOG_PREFIX ) );
-        bRet = !IsError( nErr );
+        SetError(nErr);
+        bRet = !nErr.IsError();
 
-        if (bRet && !m_pDoc->IsInLoadAsynchron() &&
+        if (bRet && !m_xDoc->IsInLoadAsynchron() &&
             GetCreateMode() == SfxObjectCreateMode::STANDARD)
         {
             LoadingFinished();
@@ -582,13 +591,13 @@ bool  SwDocShell::Load( SfxMedium& rMedium )
 bool  SwDocShell::LoadFrom( SfxMedium& rMedium )
 {
     bool bRet = false;
-    if (m_pDoc)
+    if (m_xDoc.get())
         RemoveLink();
 
     AddLink();      // set Link and update Data!!
 
     do {        // middle check loop
-        sal_uInt32 nErr = ERR_SWG_READ_ERROR;
+        ErrCode nErr = ERR_SWG_READ_ERROR;
         OUString aStreamName = "styles.xml";
         uno::Reference < container::XNameAccess > xAccess( rMedium.GetStorage(), uno::UNO_QUERY );
         if ( xAccess->hasByName( aStreamName ) && rMedium.GetStorage()->isStreamElement( aStreamName ) )
@@ -597,11 +606,11 @@ bool  SwDocShell::LoadFrom( SfxMedium& rMedium )
             SwWait aWait( *this, true );
             {
                 OSL_ENSURE( !m_xBasePool.is(), "who hasn't destroyed their Pool?" );
-                m_xBasePool = new SwDocStyleSheetPool( *m_pDoc, SfxObjectCreateMode::ORGANIZER == GetCreateMode() );
+                m_xBasePool = new SwDocStyleSheetPool( *m_xDoc, SfxObjectCreateMode::ORGANIZER == GetCreateMode() );
                 if( ReadXML )
                 {
                     ReadXML->SetOrganizerMode( true );
-                    SwReader aRdr( rMedium, aEmptyOUStr, m_pDoc );
+                    SwReader aRdr( rMedium, aEmptyOUStr, m_xDoc.get() );
                     nErr = aRdr.Read( *ReadXML );
                     ReadXML->SetOrganizerMode( false );
                 }
@@ -612,27 +621,27 @@ bool  SwDocShell::LoadFrom( SfxMedium& rMedium )
             OSL_FAIL("Code removed!");
         }
 
-        SetError( nErr, OUString( OSL_LOG_PREFIX ) );
-        bRet = !IsError( nErr );
+        SetError(nErr);
+        bRet = !nErr.IsError();
 
     } while( false );
 
     SfxObjectShell::LoadFrom( rMedium );
-    m_pDoc->getIDocumentState().ResetModified();
+    m_xDoc->getIDocumentState().ResetModified();
     return bRet;
 }
 
 void SwDocShell::SubInitNew()
 {
     OSL_ENSURE( !m_xBasePool.is(), "who hasn't destroyed their Pool?" );
-    m_xBasePool = new SwDocStyleSheetPool( *m_pDoc, SfxObjectCreateMode::ORGANIZER == GetCreateMode() );
+    m_xBasePool = new SwDocStyleSheetPool( *m_xDoc, SfxObjectCreateMode::ORGANIZER == GetCreateMode() );
     UpdateFontList();
-    InitDrawModelAndDocShell(this, m_pDoc ? m_pDoc->getIDocumentDrawModelAccess().GetDrawModel() : 0);
+    InitDrawModelAndDocShell(this, m_xDoc ? m_xDoc->getIDocumentDrawModelAccess().GetDrawModel() : nullptr);
 
-    m_pDoc->getIDocumentSettingAccess().setLinkUpdateMode( GLOBALSETTING );
-    m_pDoc->getIDocumentSettingAccess().setFieldUpdateFlags( AUTOUPD_GLOBALSETTING );
+    m_xDoc->getIDocumentSettingAccess().setLinkUpdateMode( GLOBALSETTING );
+    m_xDoc->getIDocumentSettingAccess().setFieldUpdateFlags( AUTOUPD_GLOBALSETTING );
 
-    bool bWeb = ISA(SwWebDocShell);
+    bool bWeb = dynamic_cast< const SwWebDocShell *>( this ) !=  nullptr;
 
     sal_uInt16 nRange[] =   {
         RES_PARATR_ADJUST, RES_PARATR_ADJUST,
@@ -643,26 +652,27 @@ void SwDocShell::SubInitNew()
         0, 0, 0  };
     if(!bWeb)
     {
-        nRange[ (sizeof(nRange)/sizeof(nRange[0])) - 3 ] = RES_PARATR_TABSTOP;
-        nRange[ (sizeof(nRange)/sizeof(nRange[0])) - 2 ] = RES_PARATR_HYPHENZONE;
+        nRange[ SAL_N_ELEMENTS(nRange) - 3 ] = RES_PARATR_TABSTOP;
+        nRange[ SAL_N_ELEMENTS(nRange) - 2 ] = RES_PARATR_HYPHENZONE;
     }
-    SfxItemSet aDfltSet( m_pDoc->GetAttrPool(), nRange );
+    SfxItemSet aDfltSet( m_xDoc->GetAttrPool(), nRange );
 
     //! get lingu options without loading lingu DLL
     SvtLinguOptions aLinguOpt;
 
-    SvtLinguConfig().GetOptions( aLinguOpt );
+    if (!utl::ConfigManager::IsFuzzing())
+        SvtLinguConfig().GetOptions(aLinguOpt);
 
-    sal_Int16   nVal = MsLangId::resolveSystemLanguageByScriptType(aLinguOpt.nDefaultLanguage, ::com::sun::star::i18n::ScriptType::LATIN),
-                eCJK = MsLangId::resolveSystemLanguageByScriptType(aLinguOpt.nDefaultLanguage_CJK, ::com::sun::star::i18n::ScriptType::ASIAN),
-                eCTL = MsLangId::resolveSystemLanguageByScriptType(aLinguOpt.nDefaultLanguage_CTL, ::com::sun::star::i18n::ScriptType::COMPLEX);
+    LanguageType nVal = MsLangId::resolveSystemLanguageByScriptType(aLinguOpt.nDefaultLanguage, css::i18n::ScriptType::LATIN),
+                 eCJK = MsLangId::resolveSystemLanguageByScriptType(aLinguOpt.nDefaultLanguage_CJK, css::i18n::ScriptType::ASIAN),
+                 eCTL = MsLangId::resolveSystemLanguageByScriptType(aLinguOpt.nDefaultLanguage_CTL, css::i18n::ScriptType::COMPLEX);
     aDfltSet.Put( SvxLanguageItem( nVal, RES_CHRATR_LANGUAGE ) );
     aDfltSet.Put( SvxLanguageItem( eCJK, RES_CHRATR_CJK_LANGUAGE ) );
     aDfltSet.Put( SvxLanguageItem( eCTL, RES_CHRATR_CTL_LANGUAGE ) );
 
     if(!bWeb)
     {
-        SvxHyphenZoneItem aHyp( static_cast<const SvxHyphenZoneItem&>( m_pDoc->GetDefault(
+        SvxHyphenZoneItem aHyp( static_cast<const SvxHyphenZoneItem&>( m_xDoc->GetDefault(
                                                         RES_PARATR_HYPHENZONE)  ) );
         aHyp.GetMinLead()   = static_cast< sal_uInt8 >(aLinguOpt.nHyphMinLeading);
         aHyp.GetMinTrail()  = static_cast< sal_uInt8 >(aLinguOpt.nHyphMinTrailing);
@@ -672,27 +682,40 @@ void SwDocShell::SubInitNew()
         sal_uInt16 nNewPos = static_cast< sal_uInt16 >(SW_MOD()->GetUsrPref(false)->GetDefTab());
         if( nNewPos )
             aDfltSet.Put( SvxTabStopItem( 1, nNewPos,
-                                          SVX_TAB_ADJUST_DEFAULT, RES_PARATR_TABSTOP ) );
+                                          SvxTabAdjust::Default, RES_PARATR_TABSTOP ) );
     }
     aDfltSet.Put( SvxColorItem( Color( COL_AUTO ), RES_CHRATR_COLOR ) );
 
-    m_pDoc->SetDefault( aDfltSet );
+    m_xDoc->SetDefault( aDfltSet );
 
     //default page mode for text grid
     if(!bWeb)
     {
         bool bSquaredPageMode = SW_MOD()->GetUsrPref(false)->IsSquaredPageMode();
-        m_pDoc->SetDefaultPageMode( bSquaredPageMode );
+        m_xDoc->SetDefaultPageMode( bSquaredPageMode );
+
+        // only set Widow/Orphan defaults on a new, non-web document - not an opened one
+        if( GetMedium() && GetMedium()->GetOrigURL().isEmpty() )
+        {
+            m_xDoc->SetDefault( SvxWidowsItem(  (sal_uInt8) 2, RES_PARATR_WIDOWS)  );
+            m_xDoc->SetDefault( SvxOrphansItem( (sal_uInt8) 2, RES_PARATR_ORPHANS) );
+        }
     }
 
-    m_pDoc->getIDocumentState().ResetModified();
+    m_xDoc->getIDocumentState().ResetModified();
 }
 
 /*
  * Document Interface Access
  */
-IDocumentDeviceAccess* SwDocShell::getIDocumentDeviceAccess() { return &m_pDoc->getIDocumentDeviceAccess(); }
-const IDocumentSettingAccess* SwDocShell::getIDocumentSettingAccess() const { return &m_pDoc->getIDocumentSettingAccess(); }
-IDocumentChartDataProviderAccess* SwDocShell::getIDocumentChartDataProviderAccess() { return &m_pDoc->getIDocumentChartDataProviderAccess(); }
+IDocumentDeviceAccess& SwDocShell::getIDocumentDeviceAccess()
+{
+    return m_xDoc->getIDocumentDeviceAccess();
+}
+
+IDocumentChartDataProviderAccess& SwDocShell::getIDocumentChartDataProviderAccess()
+{
+     return m_xDoc->getIDocumentChartDataProviderAccess();
+}
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
