@@ -52,23 +52,20 @@
 #include <section.hxx>
 #include <navicont.hxx>
 #include <navipi.hxx>
-#include <crsskip.hxx>
 #include <txtinet.hxx>
 #include <cmdid.h>
-#include <wrtsh.hrc>
-#include "swabstdlg.hxx"
-#include "fldui.hrc"
+#include <swabstdlg.hxx>
 #include <SwRewriter.hxx>
 
 #include <com/sun/star/document/XDocumentProperties.hpp>
 #include <com/sun/star/document/XDocumentPropertiesSupplier.hpp>
 
-#include <xmloff/odffields.hxx>
 #include <memory>
 
 #include <LibreOfficeKit/LibreOfficeKitEnums.h>
+#include <comphelper/lok.hxx>
 
-void SwWrtShell::Insert(SwField &rField)
+void SwWrtShell::Insert(SwField const &rField)
 {
     ResetCursorStack();
     if(!CanInsert())
@@ -78,13 +75,13 @@ void SwWrtShell::Insert(SwField &rField)
     SwRewriter aRewriter;
     aRewriter.AddRule(UndoArg1, rField.GetDescription());
 
-    StartUndo(UNDO_INSERT, &aRewriter);
+    StartUndo(SwUndoId::INSERT, &aRewriter);
 
     bool bDeleted = false;
     std::unique_ptr<SwPaM> pAnnotationTextRange;
     if ( HasSelection() )
     {
-        if ( rField.GetTyp()->Which() == RES_POSTITFLD )
+        if ( rField.GetTyp()->Which() == SwFieldIds::Postit )
         {
             // for annotation fields:
             // - keep the current selection in order to create a corresponding annotation mark
@@ -147,21 +144,50 @@ void SwWrtShell::UpdateInputFields( SwInputFieldList* pLst )
 
         bool bCancel = false;
         OString aDlgPos;
-        for( size_t i = 0; i < nCnt && !bCancel; ++i )
+
+        size_t nIndex = 0;
+        FieldDialogPressedButton ePressedButton = BTN_NONE;
+
+        SwField* pField = GetCurField();
+        if (pField)
         {
-            pTmp->GotoFieldPos( i );
-            SwField* pField = pTmp->GetField( i );
-            if(pField->GetTyp()->Which() == RES_DROPDOWN)
-                bCancel = StartDropDownFieldDlg( pField, true, &aDlgPos );
+            for (size_t i = 0; i < nCnt; i++)
+            {
+                if (pField == pTmp->GetField(i))
+                {
+                    nIndex = i;
+                    break;
+                }
+            }
+        }
+
+        while (!bCancel)
+        {
+            bool bPrev = nIndex > 0;
+            bool bNext = nIndex < nCnt - 1;
+            pTmp->GotoFieldPos(nIndex);
+            pField = pTmp->GetField(nIndex);
+            if (pField->GetTyp()->Which() == SwFieldIds::Dropdown)
+            {
+                bCancel = StartDropDownFieldDlg(pField, bPrev, bNext, &aDlgPos, &ePressedButton);
+            }
             else
-                bCancel = StartInputFieldDlg( pField, true, nullptr, &aDlgPos);
+                bCancel = StartInputFieldDlg(pField, bPrev, bNext, nullptr, &aDlgPos, &ePressedButton);
 
             if (!bCancel)
             {
                 // Otherwise update error at multi-selection:
-                pTmp->GetField( i )->GetTyp()->UpdateFields();
+                pTmp->GetField(nIndex)->GetTyp()->UpdateFields();
+
+                if (ePressedButton == BTN_PREV && nIndex > 0)
+                    nIndex--;
+                else if (ePressedButton == BTN_NEXT && nIndex < nCnt - 1)
+                    nIndex++;
+                else
+                    bCancel = true;
             }
         }
+
         pTmp->PopCursor();
     }
 
@@ -198,7 +224,7 @@ class FieldDeletionModify : public SwModify
                 mpFormatField->Add(this);
         }
 
-        virtual ~FieldDeletionModify()
+        virtual ~FieldDeletionModify() override
         {
             if (mpFormatField)
             {
@@ -223,18 +249,18 @@ class FieldDeletionModify : public SwModify
             }
         }
     private:
-        AbstractFieldInputDlg* mpInputFieldDlg;
+        VclPtr<AbstractFieldInputDlg> mpInputFieldDlg;
         SwFormatField* mpFormatField;
 };
 
 // Start input dialog for a specific field
-bool SwWrtShell::StartInputFieldDlg( SwField* pField, bool bNextButton,
-                                   vcl::Window* pParentWin, OString* pWindowState )
+bool SwWrtShell::StartInputFieldDlg( SwField* pField, bool bPrevButton, bool bNextButton,
+                                   vcl::Window* pParentWin, OString* pWindowState, SwWrtShell::FieldDialogPressedButton* pPressedButton )
 {
 
     SwAbstractDialogFactory* pFact = SwAbstractDialogFactory::Create();
     OSL_ENSURE(pFact, "Dialog creation failed!");
-    std::unique_ptr<AbstractFieldInputDlg> pDlg(pFact->CreateFieldInputDlg(pParentWin, *this, pField, bNextButton));
+    ScopedVclPtr<AbstractFieldInputDlg> pDlg(pFact->CreateFieldInputDlg(pParentWin, *this, pField, bPrevButton, bNextButton));
     OSL_ENSURE(pDlg, "Dialog creation failed!");
     if(pWindowState && !pWindowState->isEmpty())
         pDlg->SetWindowState(*pWindowState);
@@ -249,24 +275,41 @@ bool SwWrtShell::StartInputFieldDlg( SwField* pField, bool bNextButton,
     if(pWindowState)
         *pWindowState = pDlg->GetWindowState();
 
-    pDlg.reset();
+    if (pPressedButton)
+    {
+        if (pDlg->PrevButtonPressed())
+            *pPressedButton = BTN_PREV;
+        else if (pDlg->NextButtonPressed())
+            *pPressedButton = BTN_NEXT;
+    }
+
+    pDlg.disposeAndClear();
     GetWin()->Update();
     return bRet;
 }
 
-bool SwWrtShell::StartDropDownFieldDlg(SwField* pField, bool bNextButton, OString* pWindowState)
+bool SwWrtShell::StartDropDownFieldDlg(SwField* pField, bool bPrevButton, bool bNextButton, OString* pWindowState, SwWrtShell::FieldDialogPressedButton* pPressedButton)
 {
     SwAbstractDialogFactory* pFact = SwAbstractDialogFactory::Create();
     OSL_ENSURE(pFact, "SwAbstractDialogFactory fail!");
 
-    std::unique_ptr<AbstractDropDownFieldDialog> pDlg(pFact->CreateDropDownFieldDialog(nullptr, *this, pField, bNextButton));
+    ScopedVclPtr<AbstractDropDownFieldDialog> pDlg(pFact->CreateDropDownFieldDialog(*this, pField, bPrevButton, bNextButton));
     OSL_ENSURE(pDlg, "Dialog creation failed!");
     if(pWindowState && !pWindowState->isEmpty())
         pDlg->SetWindowState(*pWindowState);
     const short nRet = pDlg->Execute();
     if(pWindowState)
         *pWindowState = pDlg->GetWindowState();
-    pDlg.reset();
+
+    if (pPressedButton)
+    {
+        if (pDlg->PrevButtonPressed())
+            *pPressedButton = BTN_PREV;
+        else if (pDlg->NextButtonPressed())
+            *pPressedButton = BTN_NEXT;
+    }
+
+    pDlg.disposeAndClear();
     bool bRet = RET_CANCEL == nRet;
     GetWin()->Update();
     if(RET_YES == nRet)
@@ -318,7 +361,7 @@ bool SwWrtShell::UpdateTableOf(const SwTOXBase& rTOX, const SfxItemSet* pSet)
 void SwWrtShell::ClickToField( const SwField& rField )
 {
     // cross reference field must not be selected because it moves the cursor
-    if (RES_GETREFFLD != rField.GetTyp()->Which())
+    if (SwFieldIds::GetRef != rField.GetTyp()->Which())
     {
         StartAllAction();
         Right( CRSR_SKIP_CHARS, true, 1, false ); // Select the field.
@@ -329,7 +372,7 @@ void SwWrtShell::ClickToField( const SwField& rField )
     m_bIsInClickToEdit = true;
     switch( rField.GetTyp()->Which() )
     {
-    case RES_JUMPEDITFLD:
+    case SwFieldIds::JumpEdit:
         {
             sal_uInt16 nSlotId = 0;
             switch( rField.GetFormat() )
@@ -349,17 +392,17 @@ void SwWrtShell::ClickToField( const SwField& rField )
 
             if( nSlotId )
             {
-                StartUndo( UNDO_START );
+                StartUndo( SwUndoId::START );
                 //#97295# immediately select the right shell
                 GetView().StopShellTimer();
                 GetView().GetViewFrame()->GetDispatcher()->Execute( nSlotId,
                             SfxCallMode::SYNCHRON|SfxCallMode::RECORD );
-                EndUndo( UNDO_END );
+                EndUndo( SwUndoId::END );
             }
         }
         break;
 
-    case RES_MACROFLD:
+    case SwFieldIds::Macro:
         {
             const SwMacroField *pField = static_cast<const SwMacroField*>(&rField);
             const OUString sText( rField.GetPar2() );
@@ -377,7 +420,7 @@ void SwWrtShell::ClickToField( const SwField& rField )
         }
         break;
 
-    case RES_GETREFFLD:
+    case SwFieldIds::GetRef:
         StartAllAction();
         SwCursorShell::GotoRefMark( static_cast<const SwGetRefField&>(rField).GetSetRefName(),
                                     static_cast<const SwGetRefField&>(rField).GetSubType(),
@@ -385,22 +428,22 @@ void SwWrtShell::ClickToField( const SwField& rField )
         EndAllAction();
         break;
 
-    case RES_INPUTFLD:
+    case SwFieldIds::Input:
         {
             const SwInputField* pInputField = dynamic_cast<const SwInputField*>(&rField);
             if ( pInputField == nullptr )
             {
-                StartInputFieldDlg( const_cast<SwField*>(&rField), false );
+                StartInputFieldDlg( const_cast<SwField*>(&rField), false, false );
             }
         }
         break;
 
-    case RES_SETEXPFLD:
+    case SwFieldIds::SetExp:
         if( static_cast<const SwSetExpField&>(rField).GetInputFlag() )
-            StartInputFieldDlg( const_cast<SwField*>(&rField), false );
+            StartInputFieldDlg( const_cast<SwField*>(&rField), false, false );
         break;
-    case RES_DROPDOWN :
-        StartDropDownFieldDlg( const_cast<SwField*>(&rField), false );
+    case SwFieldIds::Dropdown :
+        StartDropDownFieldDlg( const_cast<SwField*>(&rField), false, false );
     break;
     default:
         SAL_WARN_IF(rField.IsClickable(), "sw", "unhandled clickable field!");
@@ -409,7 +452,7 @@ void SwWrtShell::ClickToField( const SwField& rField )
     m_bIsInClickToEdit = false;
 }
 
-void SwWrtShell::ClickToINetAttr( const SwFormatINetFormat& rItem, sal_uInt16 nFilter )
+void SwWrtShell::ClickToINetAttr( const SwFormatINetFormat& rItem, LoadUrlFlags nFilter )
 {
     if( rItem.GetValue().isEmpty() )
         return ;
@@ -417,12 +460,12 @@ void SwWrtShell::ClickToINetAttr( const SwFormatINetFormat& rItem, sal_uInt16 nF
     m_bIsInClickToEdit = true;
 
     // At first run the possibly set ObjectSelect Macro
-    const SvxMacro* pMac = rItem.GetMacro( SFX_EVENT_MOUSECLICK_OBJECT );
+    const SvxMacro* pMac = rItem.GetMacro( SvMacroItemId::OnClick );
     if( pMac )
     {
         SwCallMouseEvent aCallEvent;
         aCallEvent.Set( &rItem );
-        GetDoc()->CallEvent( SFX_EVENT_MOUSECLICK_OBJECT, aCallEvent );
+        GetDoc()->CallEvent( SvMacroItemId::OnClick, aCallEvent );
     }
 
     // So that the implementation of templates is displayed immediately
@@ -437,7 +480,7 @@ void SwWrtShell::ClickToINetAttr( const SwFormatINetFormat& rItem, sal_uInt16 nF
     m_bIsInClickToEdit = false;
 }
 
-bool SwWrtShell::ClickToINetGrf( const Point& rDocPt, sal_uInt16 nFilter )
+bool SwWrtShell::ClickToINetGrf( const Point& rDocPt, LoadUrlFlags nFilter )
 {
     bool bRet = false;
     OUString sURL;
@@ -447,12 +490,12 @@ bool SwWrtShell::ClickToINetGrf( const Point& rDocPt, sal_uInt16 nFilter )
     {
         bRet = true;
         // At first run the possibly set ObjectSelect Macro
-        const SvxMacro* pMac = &pFnd->GetMacro().GetMacro( SFX_EVENT_MOUSECLICK_OBJECT );
+        const SvxMacro* pMac = &pFnd->GetMacro().GetMacro( SvMacroItemId::OnClick );
         if( pMac )
         {
             SwCallMouseEvent aCallEvent;
             aCallEvent.Set( EVENT_OBJECT_URLITEM, pFnd );
-            GetDoc()->CallEvent( SFX_EVENT_MOUSECLICK_OBJECT, aCallEvent );
+            GetDoc()->CallEvent( SvMacroItemId::OnClick, aCallEvent );
         }
 
         ::LoadURL(*this, sURL, nFilter, sTargetFrameName);
@@ -460,7 +503,7 @@ bool SwWrtShell::ClickToINetGrf( const Point& rDocPt, sal_uInt16 nFilter )
     return bRet;
 }
 
-void LoadURL( SwViewShell& rVSh, const OUString& rURL, sal_uInt16 nFilter,
+void LoadURL( SwViewShell& rVSh, const OUString& rURL, LoadUrlFlags nFilter,
               const OUString& rTargetFrameName )
 {
     OSL_ENSURE( !rURL.isEmpty(), "what should be loaded here?" );
@@ -471,10 +514,27 @@ void LoadURL( SwViewShell& rVSh, const OUString& rURL, sal_uInt16 nFilter,
     if ( dynamic_cast<const SwCursorShell*>( &rVSh) ==  nullptr )
         return;
 
-    // We are doing tiledRendering, let the client handles the URL loading.
-    if (rVSh.isTiledRendering())
+    OUString sFileURL = rURL;
+    INetURLObject aURL( sFileURL );
+    if( aURL.GetProtocol() == INetProtocol::NotValid && !sFileURL.startsWith("#") )
     {
-        rVSh.libreOfficeKitCallback(LOK_CALLBACK_HYPERLINK_CLICKED, rURL.toUtf8().getStr());
+        // May be the relative link -> try to convert to absolute path
+        OUString sParentPath =
+            rVSh.GetDoc()->GetDocShell()->GetMedium()->GetURLObject().GetPath();
+
+        bool bCorrectURL = true;
+        aURL = INetURLObject();
+        bCorrectURL &= aURL.setFSysPath( sParentPath, FSysStyle::Detect );
+        bCorrectURL &= aURL.insertName( sFileURL );
+
+        if( bCorrectURL )
+            sFileURL = aURL.GetMainURL( INetURLObject::DecodeMechanism::Unambiguous );
+    }
+
+    // We are doing tiledRendering, let the client handles the URL loading.
+    if (comphelper::LibreOfficeKit::isActive())
+    {
+        rVSh.GetSfxViewShell()->libreOfficeKitViewCallback(LOK_CALLBACK_HYPERLINK_CLICKED, sFileURL.toUtf8().getStr());
         return;
     }
 
@@ -499,7 +559,7 @@ void LoadURL( SwViewShell& rVSh, const OUString& rURL, sal_uInt16 nFilter,
         sReferer = pDShell->GetMedium()->GetName();
     SfxViewFrame* pViewFrame = rSh.GetView().GetViewFrame();
     SfxFrameItem aView( SID_DOCFRAME, pViewFrame );
-    SfxStringItem aName( SID_FILE_NAME, rURL );
+    SfxStringItem aName( SID_FILE_NAME, sFileURL );
     SfxStringItem aTargetFrameName( SID_TARGETNAME, sTargetFrame );
     SfxStringItem aReferer( SID_REFERER, sReferer );
 
@@ -507,7 +567,7 @@ void LoadURL( SwViewShell& rVSh, const OUString& rURL, sal_uInt16 nFilter,
     //#39076# Silent can be removed accordingly to SFX.
     SfxBoolItem aBrowse( SID_BROWSE, true );
 
-    if( nFilter & URLLOAD_NEWVIEW )
+    if( nFilter & LoadUrlFlags::NewView )
         aTargetFrameName.SetValue( "_blank" );
 
     const SfxPoolItem* aArr[] = {
@@ -519,7 +579,7 @@ void LoadURL( SwViewShell& rVSh, const OUString& rURL, sal_uInt16 nFilter,
                 nullptr
     };
 
-    pViewFrame->GetDispatcher()->GetBindings()->Execute( SID_OPENDOC, aArr, 0,
+    pViewFrame->GetDispatcher()->GetBindings()->Execute( SID_OPENDOC, aArr,
             SfxCallMode::ASYNCHRON|SfxCallMode::RECORD );
 }
 
@@ -554,10 +614,10 @@ void SwWrtShell::NavigatorPaste( const NaviContentBookmark& rBkmk,
     else
     {
         SwSectionData aSection( FILE_LINK_SECTION, GetUniqueSectionName() );
-        OUString aLinkFile( rBkmk.GetURL().getToken(0, '#') );
-        aLinkFile += OUString(sfx2::cTokenSeparator);
-        aLinkFile += OUString(sfx2::cTokenSeparator);
-        aLinkFile += rBkmk.GetURL().getToken(1, '#');
+        OUString aLinkFile = rBkmk.GetURL().getToken(0, '#')
+            + OUStringLiteral1(sfx2::cTokenSeparator)
+            + OUStringLiteral1(sfx2::cTokenSeparator)
+            + rBkmk.GetURL().getToken(1, '#');
         aSection.SetLinkFileName( aLinkFile );
         aSection.SetProtectFlag( true );
         const SwSection* pIns = InsertSection( aSection );
@@ -572,10 +632,10 @@ void SwWrtShell::NavigatorPaste( const NaviContentBookmark& rBkmk,
             // the undostack. Then the change of the section don't create
             // any undoobject. -  BUG 69145
             bool bDoesUndo = DoesUndo();
-            SwUndoId nLastUndoId(UNDO_EMPTY);
+            SwUndoId nLastUndoId(SwUndoId::EMPTY);
             if (GetLastUndoInfo(nullptr, & nLastUndoId))
             {
-                if (UNDO_INSSECTION != nLastUndoId)
+                if (SwUndoId::INSSECTION != nLastUndoId)
                 {
                     DoUndo(false);
                 }
