@@ -27,9 +27,9 @@
 #include <prewin.h>
 #include <postwin.h>
 #elif defined ( MACOSX )
-#include "premac.h"
+#include <premac.h>
 #include <Cocoa/Cocoa.h>
-#include "postmac.h"
+#include <postmac.h>
 #endif
 #include <vcl/sysdata.hxx>
 
