@@ -18,13 +18,16 @@
  */
 
 #include <com/sun/star/beans/XPropertySet.hpp>
+#include <com/sun/star/uno/XComponentContext.hpp>
 #include <com/sun/star/awt/XVclContainerPeer.hpp>
 
 #include <toolkit/controls/stdtabcontroller.hxx>
 #include <toolkit/controls/stdtabcontrollermodel.hxx>
 #include <toolkit/awt/vclxwindow.hxx>
 #include <toolkit/helper/macros.hxx>
+#include <cppuhelper/supportsservice.hxx>
 #include <cppuhelper/typeprovider.hxx>
+#include <cppuhelper/queryinterface.hxx>
 #include <rtl/uuid.h>
 
 #include <tools/debug.hxx>
@@ -38,9 +41,9 @@ using namespace ::com::sun::star::awt;
 using namespace ::com::sun::star::lang;
 using namespace ::com::sun::star::beans;
 
-//  ----------------------------------------------------
+
 //  class StdTabController
-//  ----------------------------------------------------
+
 StdTabController::StdTabController()
 {
 }
@@ -49,14 +52,14 @@ StdTabController::~StdTabController()
 {
 }
 
-sal_Bool StdTabController::ImplCreateComponentSequence(
+bool StdTabController::ImplCreateComponentSequence(
         Sequence< Reference< XControl > >&              rControls,
         const Sequence< Reference< XControlModel > >&   rModels,
         Sequence< Reference< XWindow > >&               rComponents,
         Sequence< Any>*                                 pTabStops,
-        sal_Bool bPeerComponent ) const
+        bool bPeerComponent )
 {
-    sal_Bool bOK = sal_True;
+    bool bOK = true;
 
     // Get only the requested controls
     sal_Int32 nModels = rModels.getLength();
@@ -86,7 +89,7 @@ sal_Bool StdTabController::ImplCreateComponentSequence(
     sal_uInt32 nCtrls = rControls.getLength();
     rComponents.realloc( nCtrls );
     Reference< XWindow > * pComps = rComponents.getArray();
-    Any* pTabs = NULL;
+    Any* pTabs = nullptr;
 
 
     if ( pTabStops )
@@ -102,15 +105,15 @@ sal_Bool StdTabController::ImplCreateComponentSequence(
         if ( xCtrl.is() )
         {
             if (bPeerComponent)
-                pComps[n] = Reference< XWindow > (xCtrl->getPeer(), UNO_QUERY);
+                pComps[n].set(xCtrl->getPeer(), UNO_QUERY);
             else
-                pComps[n] = Reference< XWindow > (xCtrl, UNO_QUERY);
+                pComps[n].set(xCtrl, UNO_QUERY);
 
             // TabStop-Property
             if ( pTabs )
             {
                 // opt: Constant String for TabStop name
-                static const OUString aTabStopName( "Tabstop" );
+                static const char aTabStopName[] = "Tabstop";
 
                 Reference< XPropertySet >  xPSet( xCtrl->getModel(), UNO_QUERY );
                 Reference< XPropertySetInfo >  xInfo = xPSet->getPropertySetInfo();
@@ -122,14 +125,14 @@ sal_Bool StdTabController::ImplCreateComponentSequence(
         }
         else
         {
-            OSL_TRACE( "ImplCreateComponentSequence: Control not found" );
-            bOK = sal_False;
+            SAL_WARN("toolkit", "Control not found" );
+            bOK = false;
         }
     }
     return bOK;
 }
 
-void StdTabController::ImplActivateControl( sal_Bool bFirst ) const
+void StdTabController::ImplActivateControl( bool bFirst ) const
 {
     // HACK due to bug #53688#, map controls onto an interface if remote controls may occur
     Reference< XTabController >  xTabController(const_cast< ::cppu::OWeakObject* >(static_cast< const ::cppu::OWeakObject* >(this)), UNO_QUERY);
@@ -137,10 +140,10 @@ void StdTabController::ImplActivateControl( sal_Bool bFirst ) const
     const Reference< XControl > * pControls = aCtrls.getConstArray();
     sal_uInt32 nCount = aCtrls.getLength();
 
-    for ( sal_uInt32 n = bFirst ? 0 : nCount; bFirst ? ( n < nCount ) : n; )
+    for ( sal_uInt32 n = bFirst ? 0 : nCount; bFirst ? n < nCount : n != 0; )
     {
         sal_uInt32 nCtrl = bFirst ? n++ : --n;
-        DBG_ASSERT( pControls[nCtrl].is(), "Control nicht im Container!" );
+        DBG_ASSERT( pControls[nCtrl].is(), "Control not in Container!" );
         if ( pControls[nCtrl].is() )
         {
             Reference< XWindowPeer >  xCP = pControls[nCtrl]->getPeer();
@@ -158,50 +161,50 @@ void StdTabController::ImplActivateControl( sal_Bool bFirst ) const
 }
 
 // XInterface
-Any StdTabController::queryAggregation( const Type & rType ) throw(RuntimeException)
+Any StdTabController::queryAggregation( const Type & rType )
 {
     Any aRet = ::cppu::queryInterface( rType,
-                                        (static_cast< XTabController* >(this)),
-                                        (static_cast< XServiceInfo* >(this)),
-                                        (static_cast< XTypeProvider* >(this)) );
+                                        static_cast< XTabController* >(this),
+                                        static_cast< XServiceInfo* >(this),
+                                        static_cast< XTypeProvider* >(this) );
     return (aRet.hasValue() ? aRet : OWeakAggObject::queryAggregation( rType ));
 }
 
 // XTypeProvider
 IMPL_XTYPEPROVIDER_START( StdTabController )
-    getCppuType( ( Reference< XTabController>* ) NULL ),
-    getCppuType( ( Reference< XServiceInfo>* ) NULL )
+    cppu::UnoType<XTabController>::get(),
+    cppu::UnoType<XServiceInfo>::get()
 IMPL_XTYPEPROVIDER_END
 
-void StdTabController::setModel( const Reference< XTabControllerModel >& Model ) throw(RuntimeException)
+void StdTabController::setModel( const Reference< XTabControllerModel >& Model )
 {
     ::osl::Guard< ::osl::Mutex > aGuard( GetMutex() );
 
     mxModel = Model;
 }
 
-Reference< XTabControllerModel > StdTabController::getModel(  ) throw(RuntimeException)
+Reference< XTabControllerModel > StdTabController::getModel(  )
 {
     ::osl::Guard< ::osl::Mutex > aGuard( GetMutex() );
 
     return mxModel;
 }
 
-void StdTabController::setContainer( const Reference< XControlContainer >& Container ) throw(RuntimeException)
+void StdTabController::setContainer( const Reference< XControlContainer >& Container )
 {
     ::osl::Guard< ::osl::Mutex > aGuard( GetMutex() );
 
     mxControlContainer = Container;
 }
 
-Reference< XControlContainer > StdTabController::getContainer(  ) throw(RuntimeException)
+Reference< XControlContainer > StdTabController::getContainer(  )
 {
     ::osl::Guard< ::osl::Mutex > aGuard( GetMutex() );
 
     return mxControlContainer;
 }
 
-Sequence< Reference< XControl > > StdTabController::getControls(  ) throw(RuntimeException)
+Sequence< Reference< XControl > > StdTabController::getControls(  )
 {
     ::osl::Guard< ::osl::Mutex > aGuard( GetMutex() );
 
@@ -227,7 +230,7 @@ Sequence< Reference< XControl > > StdTabController::getControls(  ) throw(Runtim
     return aSeq;
 }
 
-void StdTabController::autoTabOrder(  ) throw(RuntimeException)
+void StdTabController::autoTabOrder(  )
 {
     ::osl::Guard< ::osl::Mutex > aGuard( GetMutex() );
 
@@ -244,7 +247,7 @@ void StdTabController::autoTabOrder(  ) throw(RuntimeException)
 
     // #58317# Some Models may be missing from the Container. Plus there is a
     // autoTabOrder call later on.
-    if( !ImplCreateComponentSequence( aControls, aSeq, aCompSeq, NULL, sal_False ) )
+    if( !ImplCreateComponentSequence( aControls, aSeq, aCompSeq, nullptr, false ) )
         return;
 
     sal_uInt32 nCtrls = aCompSeq.getLength();
@@ -255,14 +258,14 @@ void StdTabController::autoTabOrder(  ) throw(RuntimeException)
     size_t n;
     for ( n = 0; n < nCtrls; n++ )
     {
-        XWindow* pC = (XWindow*)pComponents[n].get();
+        XWindow* pC = pComponents[n].get();
         ComponentEntry* pE = new ComponentEntry;
         pE->pComponent = pC;
         awt::Rectangle aPosSize = pC->getPosSize();
         pE->aPos.X() = aPosSize.X;
         pE->aPos.Y() = aPosSize.Y;
 
-        sal_uInt16 nPos;
+        ComponentEntryList::size_type nPos;
         for ( nPos = 0; nPos < aCtrls.size(); nPos++ )
         {
             ComponentEntry* pEntry = aCtrls[ nPos ];
@@ -292,7 +295,7 @@ void StdTabController::autoTabOrder(  ) throw(RuntimeException)
     mxModel->setControlModels( aNewSeq );
 }
 
-void StdTabController::activateTabOrder(  ) throw(RuntimeException)
+void StdTabController::activateTabOrder(  )
 {
     ::osl::Guard< ::osl::Mutex > aGuard( GetMutex() );
 
@@ -301,7 +304,7 @@ void StdTabController::activateTabOrder(  ) throw(RuntimeException)
     Reference< XControl >  xC( mxControlContainer, UNO_QUERY );
     Reference< XVclContainerPeer >  xVclContainerPeer;
     if ( xC.is() )
-        xVclContainerPeer = xVclContainerPeer.query( xC->getPeer() );
+        xVclContainerPeer.set(xC->getPeer(), css::uno::UNO_QUERY);
      if ( !xC.is() || !xVclContainerPeer.is() )
         return;
 
@@ -320,7 +323,7 @@ void StdTabController::activateTabOrder(  ) throw(RuntimeException)
 
     // #58317# Some Models may be missing from the Container. Plus there is a
     // autoTabOrder call later on.
-    if( !ImplCreateComponentSequence( aControls, aModels, aCompSeq, &aTabSeq, sal_True ) )
+    if( !ImplCreateComponentSequence( aControls, aModels, aCompSeq, &aTabSeq, true ) )
         return;
 
     xVclContainerPeer->setTabOrder( aCompSeq, aTabSeq, mxModel->getGroupControl() );
@@ -342,39 +345,55 @@ void StdTabController::activateTabOrder(  ) throw(RuntimeException)
 
         aControlComponents.realloc( 0 );
 
-        ImplCreateComponentSequence( aControls, aThisGroupModels, aControlComponents, NULL, sal_True );
+        ImplCreateComponentSequence( aControls, aThisGroupModels, aControlComponents, nullptr, true );
         xVclContainerPeer->setGroup( aControlComponents );
     }
 }
 
-void StdTabController::activateFirst(  ) throw(RuntimeException)
+void StdTabController::activateFirst(  )
 {
     SolarMutexGuard aSolarGuard;
     ::osl::Guard< ::osl::Mutex > aGuard( GetMutex() ); //TODO: necessary?
 
-    ImplActivateControl( sal_True );
+    ImplActivateControl( true );
 }
 
-void StdTabController::activateLast(  ) throw(RuntimeException)
+void StdTabController::activateLast(  )
 {
     SolarMutexGuard aSolarGuard;
     ::osl::Guard< ::osl::Mutex > aGuard( GetMutex() ); //TODO: necessary?
 
-    ImplActivateControl( sal_False );
+    ImplActivateControl( false );
 }
 
+OUString StdTabController::getImplementationName()
+{
+    return OUString("stardiv.Toolkit.StdTabController");
+}
+
+sal_Bool StdTabController::supportsService(OUString const & ServiceName)
+{
+    return cppu::supportsService(this, ServiceName);
+}
+
+css::uno::Sequence<OUString> StdTabController::getSupportedServiceNames()
+{
+    return css::uno::Sequence<OUString>{
+        OUString::createFromAscii(szServiceName2_TabController),
+        "stardiv.vcl.control.TabController"};
+}
 
 Reference< XControl >  StdTabController::FindControl( Sequence< Reference< XControl > >& rCtrls,
  const Reference< XControlModel > & rxCtrlModel )
 {
-    DBG_ASSERT( rxCtrlModel.is(), "ImplFindControl - welches ?!" );
+    DBG_ASSERT( rxCtrlModel.is(), "ImplFindControl - which one ?!" );
 
     const Reference< XControl > * pCtrls = rCtrls.getConstArray();
     sal_Int32 nCtrls = rCtrls.getLength();
     for ( sal_Int32 n = 0; n < nCtrls; n++ )
     {
         Reference< XControlModel >  xModel(pCtrls[n].is() ? pCtrls[n]->getModel() : Reference< XControlModel > ());
-        if ( (XControlModel*)xModel.get() == (XControlModel*)rxCtrlModel.get() )
+        if ( xModel.get() == rxCtrlModel.get() )
         {
             Reference< XControl >  xCtrl( pCtrls[n] );
             ::comphelper::removeElementAt( rCtrls, n );
@@ -384,4 +403,12 @@ Reference< XControl >  StdTabController::FindControl( Sequence< Reference< XCont
     return Reference< XControl > ();
 }
 
+extern "C" SAL_DLLPUBLIC_EXPORT css::uno::XInterface * SAL_CALL
+stardiv_Toolkit_StdTabController_get_implementation(
+    css::uno::XComponentContext *,
+    css::uno::Sequence<css::uno::Any> const &)
+{
+    return cppu::acquire(new StdTabController());
+}
+
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
