@@ -44,7 +44,7 @@
 #include <toolkit/controls/unocontrolcontainer.hxx>
 #include <cppuhelper/basemutex.hxx>
 
-#include "helper/unopropertyarrayhelper.hxx"
+#include <helper/unopropertyarrayhelper.hxx>
 
 using namespace ::com::sun::star;
 using namespace ::com::sun::star::uno;
@@ -59,12 +59,12 @@ UnoControlTabPageModel::UnoControlTabPageModel( Reference< XComponentContext > c
     ImplRegisterProperty( BASEPROPERTY_HELPURL );
 }
 
-OUString SAL_CALL UnoControlTabPageModel::getImplementationName() throw(css::uno::RuntimeException, std::exception)
+OUString SAL_CALL UnoControlTabPageModel::getImplementationName()
 {
     return OUString("stardiv.Toolkit.UnoControlTabPageModel");
 }
 
-css::uno::Sequence< OUString > SAL_CALL UnoControlTabPageModel::getSupportedServiceNames() throw(css::uno::RuntimeException, std::exception)
+css::uno::Sequence< OUString > SAL_CALL UnoControlTabPageModel::getSupportedServiceNames()
 {
     css::uno::Sequence< OUString > aNames = ControlModelContainerBase::getSupportedServiceNames( );
     aNames.realloc( aNames.getLength() + 1 );
@@ -72,7 +72,7 @@ css::uno::Sequence< OUString > SAL_CALL UnoControlTabPageModel::getSupportedServ
     return aNames;
 }
 
-OUString UnoControlTabPageModel::getServiceName( ) throw(RuntimeException, std::exception)
+OUString UnoControlTabPageModel::getServiceName( )
 {
     return OUString("com.sun.star.awt.tab.UnoControlTabPageModel");
 }
@@ -104,14 +104,13 @@ Any UnoControlTabPageModel::ImplGetDefaultValue( sal_uInt16 nPropId ) const
     return *pHelper;
 }
 // beans::XMultiPropertySet
-uno::Reference< beans::XPropertySetInfo > UnoControlTabPageModel::getPropertySetInfo(  ) throw(uno::RuntimeException, std::exception)
+uno::Reference< beans::XPropertySetInfo > UnoControlTabPageModel::getPropertySetInfo(  )
 {
     static uno::Reference< beans::XPropertySetInfo > xInfo( createPropertySetInfo( getInfoHelper() ) );
     return xInfo;
 }
 ////----- XInitialization -------------------------------------------------------------------
 void SAL_CALL UnoControlTabPageModel::initialize (const Sequence<Any>& rArguments)
-            throw (css::uno::Exception, css::uno::RuntimeException, std::exception)
 {
     sal_Int16 nPageId = -1;
     if ( rArguments.getLength() == 1 )
@@ -142,10 +141,7 @@ void SAL_CALL UnoControlTabPageModel::initialize (const Sequence<Any>& rArgument
                     xDialogModel->removeByName(*pIter);
                     insertByName(*pIter,aElement);
                 }
-                catch(const Exception& ex)
-                {
-                    (void)ex;
-                }
+                catch(const Exception&) {}
             }
             Reference<XPropertySet> xDialogProp(xDialogModel,UNO_QUERY);
             if ( xDialogProp.is() )
@@ -181,25 +177,22 @@ OUString UnoControlTabPage::GetComponentServiceName()
 }
 
 OUString SAL_CALL UnoControlTabPage::getImplementationName()
-    throw (css::uno::RuntimeException, std::exception)
 {
     return OUString("stardiv.Toolkit.UnoControlTabPage");
 }
 
 sal_Bool SAL_CALL UnoControlTabPage::supportsService(OUString const & ServiceName)
-    throw (css::uno::RuntimeException, std::exception)
 {
     return cppu::supportsService(this, ServiceName);
 }
 
 css::uno::Sequence<OUString> SAL_CALL UnoControlTabPage::getSupportedServiceNames()
-    throw (css::uno::RuntimeException, std::exception)
 {
     css::uno::Sequence< OUString > aSeq { "com.sun.star.awt.tab.UnoControlTabPage" };
     return aSeq;
 }
 
-void UnoControlTabPage::dispose() throw(RuntimeException, std::exception)
+void UnoControlTabPage::dispose()
 {
     SolarMutexGuard aSolarGuard;
 
@@ -208,12 +201,12 @@ void UnoControlTabPage::dispose() throw(RuntimeException, std::exception)
     ControlContainerBase::dispose();
 }
 
-void SAL_CALL UnoControlTabPage::disposing( const lang::EventObject& Source )throw(RuntimeException, std::exception)
+void SAL_CALL UnoControlTabPage::disposing( const lang::EventObject& Source )
 {
      ControlContainerBase::disposing( Source );
 }
 
-void UnoControlTabPage::createPeer( const Reference< XToolkit > & rxToolkit, const Reference< XWindowPeer >  & rParentPeer ) throw(RuntimeException, std::exception)
+void UnoControlTabPage::createPeer( const Reference< XToolkit > & rxToolkit, const Reference< XWindowPeer >  & rParentPeer )
 {
     SolarMutexGuard aSolarGuard;
     ImplUpdateResourceResolver();
@@ -232,87 +225,79 @@ void UnoControlTabPage::createPeer( const Reference< XToolkit > & rxToolkit, con
     }
 }
 
-static ::Size ImplMapPixelToAppFont( OutputDevice* pOutDev, const ::Size& aSize )
+static ::Size ImplMapPixelToAppFont( OutputDevice const * pOutDev, const ::Size& aSize )
 {
-    ::Size aTmp = pOutDev->PixelToLogic( aSize, MapUnit::MapAppFont );
+    ::Size aTmp = pOutDev->PixelToLogic(aSize, MapMode(MapUnit::MapAppFont));
     return aTmp;
 }
 // css::awt::XWindowListener
 void SAL_CALL UnoControlTabPage::windowResized( const css::awt::WindowEvent& e )
-throw (css::uno::RuntimeException, std::exception)
 {
     OutputDevice*pOutDev = Application::GetDefaultDevice();
     DBG_ASSERT( pOutDev, "Missing Default Device!" );
-    if ( pOutDev && !mbSizeModified )
+    if ( !pOutDev || mbSizeModified )
+        return;
+
+    // Currentley we are simply using MapUnit::MapAppFont
+    ::Size aAppFontSize( e.Width, e.Height );
+
+    Reference< XControl > xDialogControl( *this, UNO_QUERY_THROW );
+    Reference< XDevice > xDialogDevice( xDialogControl->getPeer(), UNO_QUERY );
+    OSL_ENSURE( xDialogDevice.is(), "UnoDialogControl::windowResized: no peer, but a windowResized event?" );
+    if ( xDialogDevice.is() )
     {
-        // Currentley we are simply using MapUnit::MapAppFont
-        ::Size aAppFontSize( e.Width, e.Height );
-
-        Reference< XControl > xDialogControl( *this, UNO_QUERY_THROW );
-        Reference< XDevice > xDialogDevice( xDialogControl->getPeer(), UNO_QUERY );
-        OSL_ENSURE( xDialogDevice.is(), "UnoDialogControl::windowResized: no peer, but a windowResized event?" );
-        if ( xDialogDevice.is() )
-        {
-            DeviceInfo aDeviceInfo( xDialogDevice->getInfo() );
-            aAppFontSize.Width() -= aDeviceInfo.LeftInset + aDeviceInfo.RightInset;
-            aAppFontSize.Height() -= aDeviceInfo.TopInset + aDeviceInfo.BottomInset;
-        }
-
-        aAppFontSize = ImplMapPixelToAppFont( pOutDev, aAppFontSize );
-
-        // Remember that changes have been done by listener. No need to
-        // update the position because of property change event.
-        mbSizeModified = true;
-        Sequence< OUString > aProps( 2 );
-        Sequence< Any > aValues( 2 );
-        // Properties in a sequence must be sorted!
-        aProps[0] = "Height";
-        aProps[1] = "Width";
-        aValues[0] <<= aAppFontSize.Height();
-        aValues[1] <<= aAppFontSize.Width();
-
-        ImplSetPropertyValues( aProps, aValues, true );
-        mbSizeModified = false;
+        DeviceInfo aDeviceInfo( xDialogDevice->getInfo() );
+        aAppFontSize.Width() -= aDeviceInfo.LeftInset + aDeviceInfo.RightInset;
+        aAppFontSize.Height() -= aDeviceInfo.TopInset + aDeviceInfo.BottomInset;
     }
+
+    aAppFontSize = ImplMapPixelToAppFont( pOutDev, aAppFontSize );
+
+    // Remember that changes have been done by listener. No need to
+    // update the position because of property change event.
+    mbSizeModified = true;
+    Sequence< OUString > aProps( 2 );
+    Sequence< Any > aValues( 2 );
+    // Properties in a sequence must be sorted!
+    aProps[0] = "Height";
+    aProps[1] = "Width";
+    aValues[0] <<= aAppFontSize.Height();
+    aValues[1] <<= aAppFontSize.Width();
+
+    ImplSetPropertyValues( aProps, aValues, true );
+    mbSizeModified = false;
+
 }
 
 void SAL_CALL UnoControlTabPage::windowMoved( const css::awt::WindowEvent& e )
-throw (css::uno::RuntimeException, std::exception)
 {
     OutputDevice*pOutDev = Application::GetDefaultDevice();
     DBG_ASSERT( pOutDev, "Missing Default Device!" );
-    if ( pOutDev && !mbPosModified )
-    {
-        // Currentley we are simply using MapUnit::MapAppFont
-        ::Size aTmp( e.X, e.Y );
-        aTmp = ImplMapPixelToAppFont( pOutDev, aTmp );
+    if ( !pOutDev || mbPosModified )
+        return;
 
-        // Remember that changes have been done by listener. No need to
-        // update the position because of property change event.
-        mbPosModified = true;
-        Sequence< OUString > aProps( 2 );
-        Sequence< Any > aValues( 2 );
-        aProps[0] = "PositionX";
-        aProps[1] = "PositionY";
-        aValues[0] <<= aTmp.Width();
-        aValues[1] <<= aTmp.Height();
+    // Currentley we are simply using MapUnit::MapAppFont
+    ::Size aTmp( e.X, e.Y );
+    aTmp = ImplMapPixelToAppFont( pOutDev, aTmp );
+
+    // Remember that changes have been done by listener. No need to
+    // update the position because of property change event.
+    mbPosModified = true;
+    Sequence< OUString > aProps( 2 );
+    Sequence< Any > aValues( 2 );
+    aProps[0] = "PositionX";
+    aProps[1] = "PositionY";
+    aValues[0] <<= aTmp.Width();
+    aValues[1] <<= aTmp.Height();
+
+    ImplSetPropertyValues( aProps, aValues, true );
+    mbPosModified = false;
 
-        ImplSetPropertyValues( aProps, aValues, true );
-        mbPosModified = false;
-    }
 }
 
-void SAL_CALL UnoControlTabPage::windowShown( const css::lang::EventObject& e )
-throw (css::uno::RuntimeException, std::exception)
-{
-    (void)e;
-}
+void SAL_CALL UnoControlTabPage::windowShown( const css::lang::EventObject& ) {}
 
-void SAL_CALL UnoControlTabPage::windowHidden( const css::lang::EventObject& e )
-throw (css::uno::RuntimeException, std::exception)
-{
-    (void)e;
-}
+void SAL_CALL UnoControlTabPage::windowHidden( const css::lang::EventObject& ) {}
 
 extern "C" SAL_DLLPUBLIC_EXPORT css::uno::XInterface * SAL_CALL
 stardiv_Toolkit_UnoControlTabPageModel_get_implementation(
