@@ -17,16 +17,16 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-
+#include <com/sun/star/uno/XComponentContext.hpp>
 #include <toolkit/controls/unocontrolcontainermodel.hxx>
 #include <toolkit/helper/property.hxx>
 #include <toolkit/helper/servicenames.hxx>
 
-#include "helper/unopropertyarrayhelper.hxx"
+#include <helper/unopropertyarrayhelper.hxx>
 
 //  class UnoControlContainerModel
 
-UnoControlContainerModel::UnoControlContainerModel( const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XComponentContext >& i_factory )
+UnoControlContainerModel::UnoControlContainerModel( const css::uno::Reference< css::uno::XComponentContext >& i_factory )
     :UnoControlModel( i_factory )
 {
     ImplRegisterProperty( BASEPROPERTY_BACKGROUNDCOLOR );
@@ -40,36 +40,51 @@ UnoControlContainerModel::UnoControlContainerModel( const ::com::sun::star::uno:
     ImplRegisterProperty( BASEPROPERTY_TEXT );
 }
 
-OUString UnoControlContainerModel::getServiceName() throw(::com::sun::star::uno::RuntimeException, std::exception)
+OUString UnoControlContainerModel::getServiceName()
 {
     return OUString::createFromAscii( szServiceName_UnoControlContainerModel );
 }
 
-::com::sun::star::uno::Any UnoControlContainerModel::ImplGetDefaultValue( sal_uInt16 nPropId ) const
+OUString UnoControlContainerModel::getImplementationName()
 {
-    ::com::sun::star::uno::Any aDefault;
+    return OUString("stardiv.Toolkit.UnoControlContainerModel");
+}
+
+css::uno::Sequence<OUString>
+UnoControlContainerModel::getSupportedServiceNames()
+{
+    auto s(UnoControlModel::getSupportedServiceNames());
+    s.realloc(s.getLength() + 2);
+    s[s.getLength() - 2] = "com.sun.star.awt.UnoControlContainerModel";
+    s[s.getLength() - 1] = "stardiv.vcl.controlmodel.ControlContainer";
+    return s;
+}
+
+css::uno::Any UnoControlContainerModel::ImplGetDefaultValue( sal_uInt16 nPropId ) const
+{
+    css::uno::Any aDefault;
     if ( nPropId == BASEPROPERTY_BORDER )
         aDefault <<= (sal_Int16) 0;
     else
-        aDefault <<= UnoControlModel::ImplGetDefaultValue( nPropId );
+        aDefault = UnoControlModel::ImplGetDefaultValue( nPropId );
     return aDefault;
 }
 
 
-::com::sun::star::uno::Reference< ::com::sun::star::beans::XPropertySetInfo > UnoControlContainerModel::getPropertySetInfo(  ) throw(::com::sun::star::uno::RuntimeException, std::exception)
+css::uno::Reference< css::beans::XPropertySetInfo > UnoControlContainerModel::getPropertySetInfo(  )
 {
-    static ::com::sun::star::uno::Reference< ::com::sun::star::beans::XPropertySetInfo > xInfo( createPropertySetInfo( getInfoHelper() ) );
+    static css::uno::Reference< css::beans::XPropertySetInfo > xInfo( createPropertySetInfo( getInfoHelper() ) );
     return xInfo;
 }
 
 ::cppu::IPropertyArrayHelper& UnoControlContainerModel::getInfoHelper()
 {
-    ::osl::Guard< ::osl::Mutex > aGuard( ((UnoControlContainerModel*)this)->GetMutex() );
+    ::osl::Guard< ::osl::Mutex > aGuard( GetMutex() );
 
-    static UnoPropertyArrayHelper* pHelper = NULL;
+    static UnoPropertyArrayHelper* pHelper = nullptr;
     if ( !pHelper )
     {
-        ::com::sun::star::uno::Sequence<sal_Int32>  aIDs = ImplGetPropertyIds();
+        css::uno::Sequence<sal_Int32>  aIDs = ImplGetPropertyIds();
         pHelper = new UnoPropertyArrayHelper( aIDs );
     }
     return *pHelper;
