@@ -47,6 +47,7 @@
 #include <comphelper/sequence.hxx>
 #include <comphelper/extract.hxx>
 #include <vcl/svapp.hxx>
+#include <vcl/unohelp.hxx>
 #include <uno/data.h>
 
 #include <memory>
@@ -307,6 +308,13 @@ css::uno::Any UnoControlModel::ImplGetDefaultValue( sal_uInt16 nPropId ) const
                 css::uno::Sequence< OUString> aStringSeq;
                 aDefault <<= aStringSeq;
 
+            }
+            break;
+            case BASEPROPERTY_TYPEDITEMLIST:
+            {
+                css::uno::Sequence< css::uno::Any > aAnySeq;
+                aDefault <<= aAnySeq;
+
             }
             break;
             case BASEPROPERTY_SELECTEDITEMS:
@@ -364,7 +372,6 @@ css::uno::Any UnoControlModel::ImplGetDefaultValue( sal_uInt16 nPropId ) const
                                 break;
                         }
                     DBG_ASSERT( bLegacy || pAllCurrencies != pAllCurrenciesEnd, "UnoControlModel::ImplGetDefaultValue: did not find the given bank symbol!" );
-                    (void)bLegacy;
                 }
 
                 aDefault <<= sCurrencySymbol;
@@ -400,9 +407,9 @@ void UnoControlModel::ImplRegisterProperty( sal_uInt16 nPropId )
     }
 }
 
-void UnoControlModel::ImplRegisterProperties( const std::list< sal_uInt16 > &rIds )
+void UnoControlModel::ImplRegisterProperties( const std::vector< sal_uInt16 > &rIds )
 {
-    std::list< sal_uInt16 >::const_iterator iter;
+    std::vector< sal_uInt16 >::const_iterator iter;
     for( iter = rIds.begin(); iter != rIds.end(); ++iter)
     {
         if( !ImplHasProperty( *iter ) )
@@ -411,7 +418,7 @@ void UnoControlModel::ImplRegisterProperties( const std::list< sal_uInt16 > &rId
 }
 
 // css::uno::XInterface
-css::uno::Any UnoControlModel::queryAggregation( const css::uno::Type & rType ) throw(css::uno::RuntimeException, std::exception)
+css::uno::Any UnoControlModel::queryAggregation( const css::uno::Type & rType )
 {
     Any aRet = UnoControlModel_Base::queryAggregation( rType );
     if ( !aRet.hasValue() )
@@ -429,7 +436,7 @@ IMPLEMENT_FORWARD_REFCOUNT( UnoControlModel, UnoControlModel_Base )
 IMPLEMENT_FORWARD_XTYPEPROVIDER2( UnoControlModel, UnoControlModel_Base, ::cppu::OPropertySetHelper )
 
 
-uno::Reference< util::XCloneable > UnoControlModel::createClone() throw(css::uno::RuntimeException, std::exception)
+uno::Reference< util::XCloneable > UnoControlModel::createClone()
 {
     UnoControlModel* pClone = Clone();
     uno::Reference< util::XCloneable > xClone( static_cast<cppu::OWeakObject*>(pClone), uno::UNO_QUERY );
@@ -437,7 +444,7 @@ uno::Reference< util::XCloneable > UnoControlModel::createClone() throw(css::uno
 }
 
 // css::lang::XComponent
-void UnoControlModel::dispose(  ) throw(css::uno::RuntimeException, std::exception)
+void UnoControlModel::dispose(  )
 {
     ::osl::Guard< ::osl::Mutex > aGuard( GetMutex() );
 
@@ -451,14 +458,14 @@ void UnoControlModel::dispose(  ) throw(css::uno::RuntimeException, std::excepti
     OPropertySetHelper::disposing();
 }
 
-void UnoControlModel::addEventListener( const css::uno::Reference< css::lang::XEventListener >& rxListener ) throw(css::uno::RuntimeException, std::exception)
+void UnoControlModel::addEventListener( const css::uno::Reference< css::lang::XEventListener >& rxListener )
 {
     ::osl::Guard< ::osl::Mutex > aGuard( GetMutex() );
 
     maDisposeListeners.addInterface( rxListener );
 }
 
-void UnoControlModel::removeEventListener( const css::uno::Reference< css::lang::XEventListener >& rxListener ) throw(css::uno::RuntimeException, std::exception)
+void UnoControlModel::removeEventListener( const css::uno::Reference< css::lang::XEventListener >& rxListener )
 {
     ::osl::Guard< ::osl::Mutex > aGuard( GetMutex() );
 
@@ -467,7 +474,7 @@ void UnoControlModel::removeEventListener( const css::uno::Reference< css::lang:
 
 
 // css::beans::XPropertyState
-css::beans::PropertyState UnoControlModel::getPropertyState( const OUString& PropertyName ) throw(css::beans::UnknownPropertyException, css::uno::RuntimeException, std::exception)
+css::beans::PropertyState UnoControlModel::getPropertyState( const OUString& PropertyName )
 {
     ::osl::Guard< ::osl::Mutex > aGuard( GetMutex() );
 
@@ -479,7 +486,7 @@ css::beans::PropertyState UnoControlModel::getPropertyState( const OUString& Pro
     return CompareProperties( aValue, aDefault ) ? css::beans::PropertyState_DEFAULT_VALUE : css::beans::PropertyState_DIRECT_VALUE;
 }
 
-css::uno::Sequence< css::beans::PropertyState > UnoControlModel::getPropertyStates( const css::uno::Sequence< OUString >& PropertyNames ) throw(css::beans::UnknownPropertyException, css::uno::RuntimeException, std::exception)
+css::uno::Sequence< css::beans::PropertyState > UnoControlModel::getPropertyStates( const css::uno::Sequence< OUString >& PropertyNames )
 {
     ::osl::Guard< ::osl::Mutex > aGuard( GetMutex() );
 
@@ -495,7 +502,7 @@ css::uno::Sequence< css::beans::PropertyState > UnoControlModel::getPropertyStat
     return aStates;
 }
 
-void UnoControlModel::setPropertyToDefault( const OUString& PropertyName ) throw(css::beans::UnknownPropertyException, css::uno::RuntimeException, std::exception)
+void UnoControlModel::setPropertyToDefault( const OUString& PropertyName )
 {
     Any aDefaultValue;
     {
@@ -505,7 +512,7 @@ void UnoControlModel::setPropertyToDefault( const OUString& PropertyName ) throw
     setPropertyValue( PropertyName, aDefaultValue );
 }
 
-css::uno::Any UnoControlModel::getPropertyDefault( const OUString& rPropertyName ) throw(css::beans::UnknownPropertyException, css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception)
+css::uno::Any UnoControlModel::getPropertyDefault( const OUString& rPropertyName )
 {
     ::osl::Guard< ::osl::Mutex > aGuard( GetMutex() );
 
@@ -514,15 +521,15 @@ css::uno::Any UnoControlModel::getPropertyDefault( const OUString& rPropertyName
 
 
 // css::io::XPersistObjec
-OUString UnoControlModel::getServiceName(  ) throw(css::uno::RuntimeException, std::exception)
+OUString UnoControlModel::getServiceName(  )
 {
     ::osl::Guard< ::osl::Mutex > aGuard( GetMutex() );
 
-    OSL_FAIL( "ServiceName von UnoControlModel ?!" );
+    OSL_FAIL( "ServiceName of UnoControlModel ?!" );
     return OUString();
 }
 
-void UnoControlModel::write( const css::uno::Reference< css::io::XObjectOutputStream >& OutStream ) throw(css::io::IOException, css::uno::RuntimeException, std::exception)
+void UnoControlModel::write( const css::uno::Reference< css::io::XObjectOutputStream >& OutStream )
 {
     ::osl::Guard< ::osl::Mutex > aGuard( GetMutex() );
 
@@ -550,7 +557,7 @@ void UnoControlModel::write( const css::uno::Reference< css::io::XObjectOutputSt
     for ( std::set<sal_uInt16>::const_iterator it = aProps.begin(); it != aProps.end(); ++it )
     {
         sal_Int32 nPropDataBeginMark = xMark->createMark();
-        OutStream->writeLong( 0L ); // DataLen
+        OutStream->writeLong( 0 ); // DataLen
 
         const css::uno::Any* pProp = &(maData[*it]);
         OutStream->writeShort( *it );
@@ -679,14 +686,11 @@ void UnoControlModel::write( const css::uno::Reference< css::io::XObjectOutputSt
 #if OSL_DEBUG_LEVEL > 0
             else
             {
-                OString sMessage( "UnoControlModel::write: don't know how to handle a property of type '" );
-                OUString sTypeName( rType.getTypeName() );
-                sMessage += OString( sTypeName.getStr(), sTypeName.getLength(), RTL_TEXTENCODING_ASCII_US );
-                sMessage += "'.\n(Currently handling property '";
-                OUString sPropertyName( GetPropertyName( *it ) );
-                sMessage += OString( sPropertyName.getStr(), sPropertyName.getLength(), osl_getThreadTextEncoding() );
-                sMessage += "'.)";
-                OSL_FAIL( sMessage.getStr() );
+                SAL_WARN( "toolkit", "UnoControlModel::write: don't know how to handle a property of type '"
+                          << rType.getTypeName()
+                          << "'.\n(Currently handling property '"
+                          << GetPropertyName( *it )
+                          << "'.)");
             }
 #endif
         }
@@ -708,9 +712,9 @@ void UnoControlModel::write( const css::uno::Reference< css::io::XObjectOutputSt
         for ( sal_uInt16 n = BASEPROPERTY_FONT_TYPE; n <= BASEPROPERTY_FONT_ATTRIBS; n++ )
         {
             sal_Int32 nPropDataBeginMark = xMark->createMark();
-            OutStream->writeLong( 0L ); // DataLen
+            OutStream->writeLong( 0 ); // DataLen
             OutStream->writeShort( n ); // PropId
-            OutStream->writeBoolean( sal_False );   // Void
+            OutStream->writeBoolean( false );   // Void
 
             if ( n == BASEPROPERTY_FONT_TYPE )
             {
@@ -726,13 +730,13 @@ void UnoControlModel::write( const css::uno::Reference< css::io::XObjectOutputSt
                 OutStream->writeLong( aFD.Height );
                 OutStream->writeShort(
                     sal::static_int_cast< sal_Int16 >(
-                        VCLUnoHelper::ConvertFontWidth( aFD.CharacterWidth )) );
+                        vcl::unohelper::ConvertFontWidth(aFD.CharacterWidth)) );
             }
             else if ( n == BASEPROPERTY_FONT_ATTRIBS )
             {
                 OutStream->writeShort(
                     sal::static_int_cast< sal_Int16 >(
-                        VCLUnoHelper::ConvertFontWeight( aFD.Weight )) );
+                        vcl::unohelper::ConvertFontWeight(aFD.Weight)) );
                 OutStream->writeShort(
                     sal::static_int_cast< sal_Int16 >(aFD.Slant) );
                 OutStream->writeShort( aFD.Underline );
@@ -755,7 +759,7 @@ void UnoControlModel::write( const css::uno::Reference< css::io::XObjectOutputSt
     }
 }
 
-void UnoControlModel::read( const css::uno::Reference< css::io::XObjectInputStream >& InStream ) throw(css::io::IOException, css::uno::RuntimeException, std::exception)
+void UnoControlModel::read( const css::uno::Reference< css::io::XObjectInputStream >& InStream )
 {
     ::osl::Guard< ::osl::Mutex > aGuard( GetMutex() );
 
@@ -840,8 +844,8 @@ void UnoControlModel::read( const css::uno::Reference< css::io::XObjectInputStre
                     aFD.Underline = InStream->readShort();
                     aFD.Strikeout = InStream->readShort();
                     aFD.Orientation = (float)InStream->readDouble();
-                    aFD.Kerning = InStream->readBoolean();
-                    aFD.WordLineMode = InStream->readBoolean();
+                    aFD.Kerning = InStream->readBoolean() != 0;
+                    aFD.WordLineMode = InStream->readBoolean() != 0;
                     aFD.Type = InStream->readShort();
                     aValue <<= aFD;
                 }
@@ -891,14 +895,11 @@ void UnoControlModel::read( const css::uno::Reference< css::io::XObjectInputStre
                 }
                 else
                 {
-                    OString sMessage( "UnoControlModel::read: don't know how to handle a property of type '" );
-                    OUString sTypeName( pType->getTypeName() );
-                    sMessage += OString( sTypeName.getStr(), sTypeName.getLength(), RTL_TEXTENCODING_ASCII_US );
-                    sMessage += "'.\n(Currently handling property '";
-                    OUString sPropertyName( GetPropertyName( nPropId ) );
-                    sMessage += OString( sPropertyName.getStr(), sPropertyName.getLength(), osl_getThreadTextEncoding() );
-                    sMessage += "'.)";
-                    OSL_FAIL( sMessage.getStr() );
+                    SAL_WARN( "toolkit", "UnoControlModel::read: don't know how to handle a property of type '"
+                                << pType->getTypeName()
+                                << "'.\n(Currently handling property '"
+                                << GetPropertyName( nPropId )
+                                << "'.)");
                 }
             }
             else
@@ -913,7 +914,7 @@ void UnoControlModel::read( const css::uno::Reference< css::io::XObjectInputStre
                         if ( !pFD )
                         {
                             pFD = new css::awt::FontDescriptor;
-                            if ( maData.find( BASEPROPERTY_FONTDESCRIPTOR ) != maData.end() ) // wegen den Defaults...
+                            if ( maData.find( BASEPROPERTY_FONTDESCRIPTOR ) != maData.end() ) // due to defaults...
                                 maData[ BASEPROPERTY_FONTDESCRIPTOR ] >>= *pFD;
                         }
                         pFD->Name = InStream->readUTF();
@@ -950,13 +951,13 @@ void UnoControlModel::read( const css::uno::Reference< css::io::XObjectInputStre
                             if ( maData.find(BASEPROPERTY_FONTDESCRIPTOR) != maData.end() ) // due to defaults...
                                 maData[BASEPROPERTY_FONTDESCRIPTOR] >>= *pFD;
                         }
-                        pFD->Weight = VCLUnoHelper::ConvertFontWeight( (FontWeight) InStream->readShort() );
+                        pFD->Weight = vcl::unohelper::ConvertFontWeight((FontWeight) InStream->readShort());
                         pFD->Slant =  (css::awt::FontSlant)InStream->readShort();
                         pFD->Underline = InStream->readShort();
                         pFD->Strikeout = InStream->readShort();
                         pFD->Orientation = ( (float)(double)InStream->readShort() ) / 10;
-                        pFD->Kerning = InStream->readBoolean();
-                        pFD->WordLineMode = InStream->readBoolean();
+                        pFD->Kerning = InStream->readBoolean() != 0;
+                        pFD->WordLineMode = InStream->readBoolean() != 0;
                     }
                 }
                 else
@@ -1022,25 +1023,25 @@ void UnoControlModel::read( const css::uno::Reference< css::io::XObjectInputStre
 
 
 // css::lang::XServiceInfo
-OUString UnoControlModel::getImplementationName(  ) throw(css::uno::RuntimeException, std::exception)
+OUString UnoControlModel::getImplementationName(  )
 {
     OSL_FAIL( "This method should be overridden!" );
     return OUString();
 
 }
 
-sal_Bool UnoControlModel::supportsService( const OUString& rServiceName ) throw(css::uno::RuntimeException, std::exception)
+sal_Bool UnoControlModel::supportsService( const OUString& rServiceName )
 {
     return cppu::supportsService(this, rServiceName);
 }
 
-css::uno::Sequence< OUString > UnoControlModel::getSupportedServiceNames(  ) throw(css::uno::RuntimeException, std::exception)
+css::uno::Sequence< OUString > UnoControlModel::getSupportedServiceNames(  )
 {
     OUString sName( "com.sun.star.awt.UnoControlModel" );
     return Sequence< OUString >( &sName, 1 );
 }
 
-sal_Bool UnoControlModel::convertFastPropertyValue( Any & rConvertedValue, Any & rOldValue, sal_Int32 nPropId, const Any& rValue ) throw (IllegalArgumentException, std::exception)
+sal_Bool UnoControlModel::convertFastPropertyValue( Any & rConvertedValue, Any & rOldValue, sal_Int32 nPropId, const Any& rValue )
 {
     ::osl::Guard< ::osl::Mutex > aGuard( GetMutex() );
 
@@ -1143,17 +1144,11 @@ sal_Bool UnoControlModel::convertFastPropertyValue( Any & rConvertedValue, Any &
 
                 if (!bConverted)
                 {
-                    OUStringBuffer aErrorMessage;
-                    aErrorMessage.append( "Unable to convert the given value for the property " );
-                    aErrorMessage.append     ( GetPropertyName( (sal_uInt16)nPropId ) );
-                    aErrorMessage.append( ".\n" );
-                    aErrorMessage.append( "Expected type: " );
-                    aErrorMessage.append     ( pDestType->getTypeName() );
-                    aErrorMessage.append( "\n" );
-                    aErrorMessage.append( "Found type: " );
-                    aErrorMessage.append     ( rValue.getValueType().getTypeName() );
                     throw css::lang::IllegalArgumentException(
-                        aErrorMessage.makeStringAndClear(),
+                        "Unable to convert the given value for the property "
+                        + GetPropertyName( (sal_uInt16)nPropId )
+                        + ".\nExpected type: " + pDestType->getTypeName()
+                        + "\nFound type: " + rValue.getValueType().getTypeName(),
                         static_cast< css::beans::XPropertySet* >(this),
                         1);
                 }
@@ -1166,7 +1161,7 @@ sal_Bool UnoControlModel::convertFastPropertyValue( Any & rConvertedValue, Any &
     return !CompareProperties( rConvertedValue, rOldValue );
 }
 
-void UnoControlModel::setFastPropertyValue_NoBroadcast( sal_Int32 nPropId, const css::uno::Any& rValue ) throw (css::uno::Exception, std::exception)
+void UnoControlModel::setFastPropertyValue_NoBroadcast( sal_Int32 nPropId, const css::uno::Any& rValue )
 {
     // Missing: the fake solo properties of the FontDescriptor
 
@@ -1174,7 +1169,7 @@ void UnoControlModel::setFastPropertyValue_NoBroadcast( sal_Int32 nPropId, const
     const css::uno::Any* pProp = it == maData.end() ? nullptr : &(it->second);
     ENSURE_OR_RETURN_VOID( pProp, "UnoControlModel::setFastPropertyValue_NoBroadcast: invalid property id!" );
 
-    DBG_ASSERT( ( rValue.getValueType().getTypeClass() != css::uno::TypeClass_VOID ) || ( GetPropertyAttribs( (sal_uInt16)nPropId ) & css::beans::PropertyAttribute::MAYBEVOID ), "Property darf nicht VOID sein!" );
+    DBG_ASSERT( ( rValue.getValueType().getTypeClass() != css::uno::TypeClass_VOID ) || ( GetPropertyAttribs( (sal_uInt16)nPropId ) & css::beans::PropertyAttribute::MAYBEVOID ), "Property should not be VOID!" );
     maData[ nPropId ] = rValue;
 }
 
@@ -1236,7 +1231,7 @@ void UnoControlModel::getFastPropertyValue( css::uno::Any& rValue, sal_Int32 nPr
 }
 
 // css::beans::XPropertySet
-void UnoControlModel::setPropertyValue( const OUString& rPropertyName, const css::uno::Any& rValue ) throw(css::beans::UnknownPropertyException, css::beans::PropertyVetoException, css::lang::IllegalArgumentException, css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception)
+void UnoControlModel::setPropertyValue( const OUString& rPropertyName, const css::uno::Any& rValue )
 {
     sal_Int32 nPropId = 0;
     {
@@ -1244,14 +1239,15 @@ void UnoControlModel::setPropertyValue( const OUString& rPropertyName, const css
         nPropId = (sal_Int32) GetPropertyId( rPropertyName );
         DBG_ASSERT( nPropId, "Invalid ID in UnoControlModel::setPropertyValue" );
     }
-    if( nPropId )
-        setFastPropertyValue( nPropId, rValue );
-    else
+    if( !nPropId )
         throw css::beans::UnknownPropertyException();
+
+    setFastPropertyValue( nPropId, rValue );
+
 }
 
 // css::beans::XFastPropertySet
-void UnoControlModel::setFastPropertyValue( sal_Int32 nPropId, const css::uno::Any& rValue ) throw(css::beans::UnknownPropertyException, css::beans::PropertyVetoException, css::lang::IllegalArgumentException, css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception)
+void UnoControlModel::setFastPropertyValue( sal_Int32 nPropId, const css::uno::Any& rValue )
 {
     if ( ( nPropId >= BASEPROPERTY_FONTDESCRIPTORPART_START ) && ( nPropId <= BASEPROPERTY_FONTDESCRIPTORPART_END ) )
     {
@@ -1279,20 +1275,20 @@ void UnoControlModel::setFastPropertyValue( sal_Int32 nPropId, const css::uno::A
 
         aGuard.clear();
         setFastPropertyValues( 1, &nDescriptorId, &aNewValue, 1 );
-        fire( &nPropId, &aNewSingleValue, &aOldSingleValue, 1, sal_False );
+        fire( &nPropId, &aNewSingleValue, &aOldSingleValue, 1, false );
        }
     else
         setFastPropertyValues( 1, &nPropId, &rValue, 1 );
 }
 
 // css::beans::XMultiPropertySet
-css::uno::Reference< css::beans::XPropertySetInfo > UnoControlModel::getPropertySetInfo(  ) throw(css::uno::RuntimeException, std::exception)
+css::uno::Reference< css::beans::XPropertySetInfo > UnoControlModel::getPropertySetInfo(  )
 {
     OSL_FAIL( "UnoControlModel::getPropertySetInfo() not possible!" );
     return css::uno::Reference< css::beans::XPropertySetInfo >();
 }
 
-void UnoControlModel::setPropertyValues( const css::uno::Sequence< OUString >& rPropertyNames, const css::uno::Sequence< css::uno::Any >& Values ) throw(css::beans::PropertyVetoException, css::lang::IllegalArgumentException, css::lang::WrappedTargetException, css::uno::RuntimeException, std::exception)
+void UnoControlModel::setPropertyValues( const css::uno::Sequence< OUString >& rPropertyNames, const css::uno::Sequence< css::uno::Any >& Values )
 {
     ::osl::ClearableMutexGuard aGuard( GetMutex() );
 
@@ -1356,7 +1352,6 @@ void UnoControlModel::setPropertyValues( const css::uno::Sequence< OUString >& r
 }
 
 
-
 void UnoControlModel::ImplNormalizePropertySequence( const sal_Int32, sal_Int32*,
     uno::Any*, sal_Int32* ) const
 {
