@@ -43,10 +43,7 @@
 #include <com/sun/star/util/Time.hpp>
 #include <com/sun/star/beans/PropertyAttribute.hpp>
 #include <com/sun/star/graphic/XGraphic.hpp>
-#include <com/sun/star/resource/XStringResourceResolver.hpp>
 #include <com/sun/star/container/XNameContainer.hpp>
-#include <comphelper/types.hxx>
-#include <functional>
 #include <algorithm>
 
 using ::com::sun::star::uno::Any;
@@ -62,20 +59,13 @@ using namespace com::sun::star;
 struct ImplPropertyInfo
 {
     OUString                 aName;
-    sal_uInt16                      nPropId;
-    ::com::sun::star::uno::Type     aType;
-    sal_Int16                       nAttribs;
-    sal_Bool                        bDependsOnOthers;   // eg. VALUE depends on MIN/MAX and must be set after MIN/MAX.
+    sal_uInt16               nPropId;
+    css::uno::Type           aType;
+    sal_Int16                nAttribs;
+    bool                     bDependsOnOthers;   // eg. VALUE depends on MIN/MAX and must be set after MIN/MAX.
 
-    ImplPropertyInfo()
-     {
-         nPropId = 0;
-        nAttribs = 0;
-           bDependsOnOthers = sal_False;
-     }
-
-    ImplPropertyInfo( OUString const & theName, sal_uInt16 nId, const ::com::sun::star::uno::Type& rType,
-                        sal_Int16 nAttrs, sal_Bool bDepends = sal_False )
+    ImplPropertyInfo( OUString const & theName, sal_uInt16 nId, const css::uno::Type& rType,
+                        sal_Int16 nAttrs, bool bDepends = false )
      : aName( theName )
      {
          nPropId = nId;
@@ -87,20 +77,20 @@ struct ImplPropertyInfo
 };
 
 #define DECL_PROP_1( asciiname, id, type, attrib1 ) \
-    ImplPropertyInfo( OUString::createFromAscii( asciiname ), BASEPROPERTY_##id, ::getCppuType( static_cast< const type* >( NULL ) ), ::com::sun::star::beans::PropertyAttribute::attrib1 )
+    ImplPropertyInfo( asciiname, BASEPROPERTY_##id, cppu::UnoType<type>::get(), css::beans::PropertyAttribute::attrib1 )
 #define DECL_PROP_2( asciiname, id, type, attrib1, attrib2 ) \
-    ImplPropertyInfo( OUString::createFromAscii( asciiname ), BASEPROPERTY_##id, ::getCppuType( static_cast< const type* >( NULL ) ), ::com::sun::star::beans::PropertyAttribute::attrib1 | ::com::sun::star::beans::PropertyAttribute::attrib2 )
+    ImplPropertyInfo( asciiname, BASEPROPERTY_##id, cppu::UnoType<type>::get(), css::beans::PropertyAttribute::attrib1 | css::beans::PropertyAttribute::attrib2 )
 #define DECL_PROP_3( asciiname, id, type, attrib1, attrib2, attrib3 ) \
-    ImplPropertyInfo( OUString::createFromAscii( asciiname ), BASEPROPERTY_##id, ::getCppuType( static_cast< const type* >( NULL ) ), ::com::sun::star::beans::PropertyAttribute::attrib1 | ::com::sun::star::beans::PropertyAttribute::attrib2 | ::com::sun::star::beans::PropertyAttribute::attrib3 )
+    ImplPropertyInfo( asciiname, BASEPROPERTY_##id, cppu::UnoType<type>::get(), css::beans::PropertyAttribute::attrib1 | css::beans::PropertyAttribute::attrib2 | css::beans::PropertyAttribute::attrib3 )
 
 #define DECL_DEP_PROP_2( asciiname, id, type, attrib1, attrib2 ) \
-    ImplPropertyInfo( OUString::createFromAscii( asciiname ), BASEPROPERTY_##id, ::getCppuType( static_cast< const type* >( NULL ) ), ::com::sun::star::beans::PropertyAttribute::attrib1 | ::com::sun::star::beans::PropertyAttribute::attrib2, sal_True )
+    ImplPropertyInfo( asciiname, BASEPROPERTY_##id, cppu::UnoType<type>::get(), css::beans::PropertyAttribute::attrib1 | css::beans::PropertyAttribute::attrib2, true )
 #define DECL_DEP_PROP_3( asciiname, id, type, attrib1, attrib2, attrib3 ) \
-    ImplPropertyInfo( OUString::createFromAscii( asciiname ), BASEPROPERTY_##id, ::getCppuType( static_cast< const type* >( NULL ) ), ::com::sun::star::beans::PropertyAttribute::attrib1 | ::com::sun::star::beans::PropertyAttribute::attrib2 | ::com::sun::star::beans::PropertyAttribute::attrib3, sal_True )
+    ImplPropertyInfo( asciiname, BASEPROPERTY_##id, cppu::UnoType<type>::get(), css::beans::PropertyAttribute::attrib1 | css::beans::PropertyAttribute::attrib2 | css::beans::PropertyAttribute::attrib3, true )
 
 ImplPropertyInfo* ImplGetPropertyInfos( sal_uInt16& rElementCount )
 {
-    static ImplPropertyInfo* pPropertyInfos = NULL;
+    static ImplPropertyInfo* pPropertyInfos = nullptr;
     static sal_uInt16 nElements = 0;
     if( !pPropertyInfos )
     {
@@ -148,7 +138,7 @@ ImplPropertyInfo* ImplGetPropertyInfos( sal_uInt16& rElementCount )
             DECL_PROP_2     ( "FontEmphasisMark",       FONTEMPHASISMARK,   sal_Int16,          BOUND, MAYBEDEFAULT ),
             DECL_PROP_2     ( "FontDescriptor",         FONTDESCRIPTOR,     FontDescriptor,     BOUND, MAYBEDEFAULT ),
 
-            // Teile des ::com::sun::star::awt::FontDescriptor
+            // parts of css::awt::FontDescriptor
             DECL_PROP_2     ( "FontName",               FONTDESCRIPTORPART_NAME,         OUString,BOUND, MAYBEDEFAULT ),
             DECL_PROP_2     ( "FontStyleName",          FONTDESCRIPTORPART_STYLENAME,    OUString,BOUND, MAYBEDEFAULT ),
             DECL_PROP_2     ( "FontFamily",             FONTDESCRIPTORPART_FAMILY,       sal_Int16,      BOUND, MAYBEDEFAULT ),
@@ -167,7 +157,7 @@ ImplPropertyInfo* ImplGetPropertyInfos( sal_uInt16& rElementCount )
             DECL_PROP_2     ( "FontType",               FONTDESCRIPTORPART_TYPE,         sal_Int16,      BOUND, MAYBEDEFAULT ),
 
             DECL_PROP_3     ( "FormatKey",              FORMATKEY,          sal_Int32,      BOUND, MAYBEVOID, TRANSIENT ),
-            DECL_PROP_3     ( "FormatsSupplier",        FORMATSSUPPLIER,    Reference< ::com::sun::star::util::XNumberFormatsSupplier >, BOUND, MAYBEVOID, TRANSIENT ),
+            DECL_PROP_3     ( "FormatsSupplier",        FORMATSSUPPLIER,    Reference< css::util::XNumberFormatsSupplier >, BOUND, MAYBEVOID, TRANSIENT ),
 
             DECL_PROP_2     ( "Graphic",                GRAPHIC,            Reference< XGraphic >, BOUND, TRANSIENT ),
             DECL_PROP_2     ( "GroupName",              GROUPNAME,          OUString,    BOUND, MAYBEDEFAULT ),
@@ -210,7 +200,7 @@ ImplPropertyInfo* ImplGetPropertyInfos( sal_uInt16& rElementCount )
             DECL_PROP_2     ( "AutoRepeat",             AUTO_REPEAT,        sal_Bool,           BOUND, MAYBEDEFAULT ),
             DECL_PROP_2     ( "RepeatDelay",            REPEAT_DELAY,       sal_Int32,          BOUND, MAYBEDEFAULT ),
             DECL_PROP_2     ( "ScaleImage",             SCALEIMAGE,         bool,               BOUND, MAYBEDEFAULT ),
-            DECL_PROP_2     ( "ScaleMode",              IMAGE_SCALE_MODE,   sal_Int16,          BOUND, MAYBEDEFAULT ),
+            DECL_DEP_PROP_2 ( "ScaleMode",              IMAGE_SCALE_MODE,   sal_Int16,          BOUND, MAYBEDEFAULT ),
             DECL_DEP_PROP_3 ( "ScrollValue",            SCROLLVALUE,        sal_Int32,          BOUND, MAYBEDEFAULT, MAYBEVOID ),
             DECL_PROP_2     ( "ScrollValueMax",         SCROLLVALUE_MAX,    sal_Int32,          BOUND, MAYBEDEFAULT ),
             DECL_PROP_2     ( "ScrollValueMin",         SCROLLVALUE_MIN,    sal_Int32,          BOUND, MAYBEDEFAULT ),
@@ -229,6 +219,7 @@ ImplPropertyInfo* ImplGetPropertyInfos( sal_uInt16& rElementCount )
             DECL_DEP_PROP_2 ( "State",                  STATE,                  sal_Int16,      BOUND, MAYBEDEFAULT ),
             DECL_PROP_2     ( "StrictFormat",           STRICTFORMAT,           bool,           BOUND, MAYBEDEFAULT ),
             DECL_PROP_2     ( "StringItemList",         STRINGITEMLIST,         Sequence< OUString >, BOUND, MAYBEDEFAULT ),
+            DECL_PROP_2     ( "TypedItemList",          TYPEDITEMLIST,          Sequence< Any >, BOUND, MAYBEDEFAULT ),
             DECL_PROP_2     ( "VisualEffect",           VISUALEFFECT,           sal_Int16,      BOUND, MAYBEDEFAULT ),
             DECL_PROP_3     ( "SymbolColor",            SYMBOL_COLOR,           sal_Int32,      BOUND, MAYBEDEFAULT, MAYBEVOID ),
             DECL_PROP_3     ( "Tabstop",                TABSTOP,                bool,           BOUND, MAYBEDEFAULT, MAYBEVOID ),
@@ -259,9 +250,9 @@ ImplPropertyInfo* ImplGetPropertyInfos( sal_uInt16& rElementCount )
             DECL_PROP_2     ( "StepTime",               STEP_TIME,              sal_Int32,      BOUND, MAYBEDEFAULT ),
             DECL_PROP_2     ( "Decoration",             DECORATION,             sal_Bool,       BOUND, MAYBEDEFAULT ),
 
-            DECL_PROP_2     ( "SelectionType",          TREE_SELECTIONTYPE,     ::com::sun::star::view::SelectionType,      BOUND, MAYBEDEFAULT ),
+            DECL_PROP_2     ( "SelectionType",          TREE_SELECTIONTYPE,     css::view::SelectionType,      BOUND, MAYBEDEFAULT ),
             DECL_PROP_2     ( "Editable",               TREE_EDITABLE,          sal_Bool,       BOUND, MAYBEDEFAULT ),
-            DECL_PROP_3     ( "DataModel",              TREE_DATAMODEL,         Reference< ::com::sun::star::awt::tree::XTreeDataModel >,       BOUND, MAYBEDEFAULT, MAYBEVOID ),
+            DECL_PROP_3     ( "DataModel",              TREE_DATAMODEL,         Reference< css::awt::tree::XTreeDataModel >,       BOUND, MAYBEDEFAULT, MAYBEVOID ),
             DECL_PROP_2     ( "RootDisplayed",          TREE_ROOTDISPLAYED,     sal_Bool,           BOUND, MAYBEDEFAULT ),
             DECL_PROP_2     ( "ShowsHandles",           TREE_SHOWSHANDLES,      sal_Bool,           BOUND, MAYBEDEFAULT ),
             DECL_PROP_2     ( "ShowsRootHandles",       TREE_SHOWSROOTHANDLES,  sal_Bool,           BOUND, MAYBEDEFAULT ),
@@ -275,9 +266,9 @@ ImplPropertyInfo* ImplGetPropertyInfos( sal_uInt16& rElementCount )
             DECL_PROP_2     ( "RowHeaderWidth",         ROW_HEADER_WIDTH,       sal_Int32,          BOUND, MAYBEDEFAULT ),
             DECL_PROP_2     ( "ShowColumnHeader",       GRID_SHOWCOLUMNHEADER,  sal_Bool,           BOUND, MAYBEDEFAULT ),
             DECL_PROP_3     ( "ColumnHeaderHeight",     COLUMN_HEADER_HEIGHT,   sal_Int32,          BOUND, MAYBEDEFAULT, MAYBEVOID ),
-            DECL_PROP_1     ( "GridDataModel",          GRID_DATAMODEL,         Reference< ::com::sun::star::awt::grid::XGridDataModel >,          BOUND ),
-            DECL_PROP_1     ( "ColumnModel",            GRID_COLUMNMODEL,       Reference< ::com::sun::star::awt::grid::XGridColumnModel >,          BOUND ),
-            DECL_PROP_3     ( "SelectionModel",         GRID_SELECTIONMODE,     ::com::sun::star::view::SelectionType,          BOUND, MAYBEDEFAULT, MAYBEVOID ),
+            DECL_PROP_1     ( "GridDataModel",          GRID_DATAMODEL,         Reference< css::awt::grid::XGridDataModel >,          BOUND ),
+            DECL_PROP_1     ( "ColumnModel",            GRID_COLUMNMODEL,       Reference< css::awt::grid::XGridColumnModel >,          BOUND ),
+            DECL_PROP_3     ( "SelectionModel",         GRID_SELECTIONMODE,     css::view::SelectionType,          BOUND, MAYBEDEFAULT, MAYBEVOID ),
             DECL_PROP_2     ( "EnableVisible",          ENABLEVISIBLE,          sal_Bool,           BOUND, MAYBEDEFAULT ),
             DECL_PROP_3     ( "ReferenceDevice",        REFERENCE_DEVICE,       Reference< XDevice >,BOUND, MAYBEDEFAULT, TRANSIENT ),
             DECL_PROP_3     ( "HeaderBackgroundColor",  GRID_HEADER_BACKGROUND,     sal_Int32,              BOUND, MAYBEDEFAULT, MAYBEVOID ),
@@ -286,14 +277,14 @@ ImplPropertyInfo* ImplGetPropertyInfos( sal_uInt16& rElementCount )
             DECL_PROP_3     ( "RowBackgroundColors",    GRID_ROW_BACKGROUND_COLORS, Sequence< sal_Int32 >,  BOUND, MAYBEDEFAULT, MAYBEVOID ),
             DECL_PROP_2     ( "UseGridLines",           USE_GRID_LINES,             sal_Bool,               BOUND, MAYBEDEFAULT ),
             DECL_DEP_PROP_3 ( "MultiPageValue",          MULTIPAGEVALUE,      sal_Int32,          BOUND, MAYBEDEFAULT, MAYBEVOID ),
-            DECL_PROP_3     ( "AllDialogChildren",                USERFORMCONTAINEES,                Reference< ::com::sun::star::container::XNameContainer >,           BOUND, MAYBEDEFAULT, MAYBEVOID ),
+            DECL_PROP_3     ( "AllDialogChildren",                USERFORMCONTAINEES,                Reference< css::container::XNameContainer >,           BOUND, MAYBEDEFAULT, MAYBEVOID ),
             DECL_PROP_3     ( "ActiveSelectionBackgroundColor",     ACTIVE_SEL_BACKGROUND_COLOR,    sal_Int32,  BOUND, MAYBEDEFAULT, MAYBEVOID ),
             DECL_PROP_3     ( "InactiveSelectionBackgroundColor",   INACTIVE_SEL_BACKGROUND_COLOR,  sal_Int32,  BOUND, MAYBEDEFAULT, MAYBEVOID ),
             DECL_PROP_3     ( "ActiveSelectionTextColor",           ACTIVE_SEL_TEXT_COLOR,          sal_Int32,  BOUND, MAYBEDEFAULT, MAYBEVOID ),
             DECL_PROP_3     ( "InactiveSelectionTextColor",         INACTIVE_SEL_TEXT_COLOR,        sal_Int32,  BOUND, MAYBEDEFAULT, MAYBEVOID ),
     };
             pPropertyInfos = aImplPropertyInfos;
-            nElements = sizeof( aImplPropertyInfos ) / sizeof( ImplPropertyInfo );
+            nElements = SAL_N_ELEMENTS( aImplPropertyInfos );
         }
     }
     rElementCount = nElements;
@@ -301,31 +292,27 @@ ImplPropertyInfo* ImplGetPropertyInfos( sal_uInt16& rElementCount )
 }
 
 
-struct ImplPropertyInfoCompareFunctor : ::std::binary_function<ImplPropertyInfo,OUString,bool>
+struct ImplPropertyInfoCompareFunctor
 {
-    inline bool operator()(const ImplPropertyInfo& lhs,const ImplPropertyInfo& rhs) const
+    bool operator()(const ImplPropertyInfo& lhs,const ImplPropertyInfo& rhs) const
     {
         return lhs.aName.compareTo(rhs.aName) < 0;
     }
-    inline bool operator()(const ImplPropertyInfo& lhs,const OUString& rhs)  const
+    bool operator()(const ImplPropertyInfo& lhs,const OUString& rhs)  const
     {
         return lhs.aName.compareTo(rhs) < 0;
     }
-    inline bool operator()(const OUString& lhs,const ImplPropertyInfo& rhs)  const
-    {
-        return lhs.compareTo(rhs.aName) < 0;
-    }
 };
 
 void ImplAssertValidPropertyArray()
 {
-    static sal_Bool bSorted = sal_False;
+    static bool bSorted = false;
     if( !bSorted )
     {
         sal_uInt16 nElements;
-        ImplPropertyInfo* pInfos = ImplGetPropertyInfos( nElements );
-        ::std::sort(pInfos, pInfos+nElements,ImplPropertyInfoCompareFunctor());
-        bSorted = sal_True;
+        ImplPropertyInfo* pInfo = ImplGetPropertyInfos( nElements );
+        ::std::sort(pInfo, pInfo+nElements,ImplPropertyInfoCompareFunctor());
+        bSorted = true;
     }
 }
 
@@ -334,14 +321,14 @@ sal_uInt16 GetPropertyId( const OUString& rPropertyName )
     ImplAssertValidPropertyArray();
 
     sal_uInt16 nElements;
-    ImplPropertyInfo* pInfos = ImplGetPropertyInfos( nElements );
-    ImplPropertyInfo* pInf = ::std::lower_bound(pInfos,pInfos+nElements,rPropertyName,ImplPropertyInfoCompareFunctor());
+    ImplPropertyInfo* pInfo = ImplGetPropertyInfos( nElements );
+    ImplPropertyInfo* pInf = ::std::lower_bound(pInfo,pInfo+nElements,rPropertyName,ImplPropertyInfoCompareFunctor());
 /*
         (ImplPropertyInfo*)
-                                bsearch( &aSearch, pInfos, nElements, sizeof( ImplPropertyInfo ), ImplPropertyInfoCompare );
+                                bsearch( &aSearch, pInfo, nElements, sizeof( ImplPropertyInfo ), ImplPropertyInfoCompare );
 */
 
-    return ( pInf && pInf != (pInfos+nElements) && pInf->aName == rPropertyName) ? pInf->nPropId: 0;
+    return ( pInf && pInf != (pInfo+nElements) && pInf->aName == rPropertyName) ? pInf->nPropId: 0;
 }
 
 const ImplPropertyInfo* ImplGetImplPropertyInfo( sal_uInt16 nPropertyId )
@@ -349,12 +336,12 @@ const ImplPropertyInfo* ImplGetImplPropertyInfo( sal_uInt16 nPropertyId )
     ImplAssertValidPropertyArray();
 
     sal_uInt16 nElements;
-    ImplPropertyInfo* pInfos = ImplGetPropertyInfos( nElements );
+    ImplPropertyInfo* pInfo = ImplGetPropertyInfos( nElements );
     sal_uInt16 n;
-    for ( n = 0; n < nElements && pInfos[n].nPropId != nPropertyId; ++n)
+    for ( n = 0; n < nElements && pInfo[n].nPropId != nPropertyId; ++n)
         ;
 
-    return (n < nElements) ? &pInfos[n] : NULL;
+    return (n < nElements) ? &pInfo[n] : nullptr;
 }
 
 sal_uInt16 GetPropertyOrderNr( sal_uInt16 nPropertyId )
@@ -362,10 +349,10 @@ sal_uInt16 GetPropertyOrderNr( sal_uInt16 nPropertyId )
     ImplAssertValidPropertyArray();
 
     sal_uInt16 nElements;
-    ImplPropertyInfo* pInfos = ImplGetPropertyInfos( nElements );
+    ImplPropertyInfo* pInfo = ImplGetPropertyInfos( nElements );
     for ( sal_uInt16 n = nElements; n; )
     {
-        if ( pInfos[--n].nPropId == nPropertyId )
+        if ( pInfo[--n].nPropId == nPropertyId )
             return n;
     }
     return 0xFFFF;
@@ -374,15 +361,15 @@ sal_uInt16 GetPropertyOrderNr( sal_uInt16 nPropertyId )
 const OUString& GetPropertyName( sal_uInt16 nPropertyId )
 {
     const ImplPropertyInfo* pImplPropertyInfo = ImplGetImplPropertyInfo( nPropertyId );
-    DBG_ASSERT( pImplPropertyInfo, "Invalid PropertyId!" );
+    assert(pImplPropertyInfo && "Invalid PropertyId!");
     return pImplPropertyInfo->aName;
 }
 
-const ::com::sun::star::uno::Type* GetPropertyType( sal_uInt16 nPropertyId )
+const css::uno::Type* GetPropertyType( sal_uInt16 nPropertyId )
 {
     const ImplPropertyInfo* pImplPropertyInfo = ImplGetImplPropertyInfo( nPropertyId );
     DBG_ASSERT( pImplPropertyInfo, "Invalid PropertyId!" );
-    return pImplPropertyInfo ? &pImplPropertyInfo->aType : NULL;
+    return pImplPropertyInfo ? &pImplPropertyInfo->aType : nullptr;
 }
 
 sal_Int16 GetPropertyAttribs( sal_uInt16 nPropertyId )
@@ -392,18 +379,17 @@ sal_Int16 GetPropertyAttribs( sal_uInt16 nPropertyId )
     return pImplPropertyInfo ? pImplPropertyInfo->nAttribs : 0;
 }
 
-sal_Bool DoesDependOnOthers( sal_uInt16 nPropertyId )
+bool DoesDependOnOthers( sal_uInt16 nPropertyId )
 {
     const ImplPropertyInfo* pImplPropertyInfo = ImplGetImplPropertyInfo( nPropertyId );
     DBG_ASSERT( pImplPropertyInfo, "Invalid PropertyId!" );
-    return pImplPropertyInfo ? pImplPropertyInfo->bDependsOnOthers : sal_False;
+    return pImplPropertyInfo && pImplPropertyInfo->bDependsOnOthers;
 }
 
-sal_Bool CompareProperties( const ::com::sun::star::uno::Any& r1, const ::com::sun::star::uno::Any& r2 )
+bool CompareProperties( const css::uno::Any& r1, const css::uno::Any& r2 )
 {
-    return ::comphelper::compare( r1, r2 );
+    return r1 == r2;
 }
 
 
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
