@@ -42,7 +42,7 @@ public class MessageArea
 
 
     /** Create a new message area.  This method is private because the class is
-        a singleton and may therefore not be instanciated from the outside.
+        a singleton and may therefore not be instantiated from the outside.
     */
     private MessageArea ()
     {
@@ -60,24 +60,14 @@ public class MessageArea
 
 
 
-    /** Show the given string at the end of the message area and scroll to make
-        it visible.
-    */
-    public static synchronized void print (String aMessage)
-    {
-        print (0, aMessage);
-    }
-
-
-
-
     /** Show the given string at the end of the message area and scroll to make
         it visible.  Indent the string as requested.
     */
-    public static synchronized void print (int nIndentation, String aMessage)
+    private static synchronized void print (int nIndentation, String aMessage)
     {
-        while (nIndentation-- > 0)
+        while (nIndentation-- > 0) {
             aMessage = " " + aMessage;
+        }
         Instance().printMessage(aMessage);
     }
 
@@ -98,7 +88,7 @@ public class MessageArea
     /** Show the given string at the end of the message area and scroll to make
         it visible.
     */
-    public static void println (int nIndentation, String aMessage)
+    private static void println (int nIndentation, String aMessage)
     {
         print (nIndentation, aMessage+"\n");
     }
@@ -106,6 +96,7 @@ public class MessageArea
 
 
 
+    @Override
     public void paintComponent (Graphics g)
     {
         synchronized (g)
@@ -136,5 +127,5 @@ public class MessageArea
 
 
     private static MessageArea saInstance = null;
-    private JTextArea maText;
+    private final JTextArea maText;
 }
