@@ -23,8 +23,8 @@
 #include <new>
 #include <string.h>
 
-#ifdef WNT
-#include "stdlib.h"
+#ifdef _WIN32
+#include <stdlib.h>
 #endif
 
 #include <osl/file.hxx>
@@ -57,7 +57,6 @@ struct ImplConfigData
     sal_uIntPtr     mnDataUpdateId;
     sal_uIntPtr     mnTimeStamp;
     LineEnd         meLineEnd;
-    sal_uInt16      mnRefCount;
     bool            mbModified;
     bool            mbRead;
     bool            mbIsUTF8BOM;
@@ -97,7 +96,7 @@ static sal_uIntPtr ImplSysGetConfigTimeStamp( const OUString& rFileName )
 static sal_uInt8* ImplSysReadConfig( const OUString& rFileName,
                                 sal_uInt64& rRead, bool& rbRead, bool& rbIsUTF8BOM, sal_uIntPtr& rTimeStamp )
 {
-    sal_uInt8*          pBuf = NULL;
+    sal_uInt8*          pBuf = nullptr;
     ::osl::File aFile( rFileName );
 
     if( aFile.open( osl_File_OpenFlag_Read ) == ::osl::FileBase::E_None )
@@ -107,18 +106,18 @@ static sal_uInt8* ImplSysReadConfig( const OUString& rFileName,
         {
             if (nPos > SAL_MAX_SIZE) {
                 aFile.close();
-                return 0;
+                return nullptr;
             }
             pBuf = new sal_uInt8[static_cast< std::size_t >(nPos)];
             sal_uInt64 nRead = 0;
             if( aFile.read( pBuf, nPos, nRead ) == ::osl::FileBase::E_None && nRead == nPos )
             {
                 //skip the byte-order-mark 0xEF 0xBB 0xBF, if it was UTF8 files
-                unsigned char BOM[3] = {0xEF, 0xBB, 0xBF};
+                unsigned char const BOM[3] = {0xEF, 0xBB, 0xBF};
                 if (nRead > 2 && memcmp(pBuf, BOM, 3) == 0)
                 {
                     nRead -= 3;
-                    memmove(pBuf, pBuf + 3, sal::static_int_cast<sal_Size>(nRead * sizeof(sal_uInt8)) );
+                    memmove(pBuf, pBuf + 3, sal::static_int_cast<std::size_t>(nRead * sizeof(sal_uInt8)) );
                     rbIsUTF8BOM = true;
                 }
 
@@ -129,7 +128,7 @@ static sal_uInt8* ImplSysReadConfig( const OUString& rFileName,
             else
             {
                 delete[] pBuf;
-                pBuf = NULL;
+                pBuf = nullptr;
             }
         }
         aFile.close();
@@ -157,7 +156,7 @@ static bool ImplSysWriteConfig( const OUString& rFileName,
         //write the byte-order-mark 0xEF 0xBB 0xBF first , if it was UTF8 files
         if ( rbIsUTF8BOM )
         {
-            unsigned char BOM[3] = {0xEF, 0xBB, 0xBF};
+            unsigned char const BOM[3] = {0xEF, 0xBB, 0xBF};
             sal_uInt64 nUTF8BOMWritten;
             if( aFile.write( BOM, 3, nUTF8BOMWritten ) == ::osl::FileBase::E_None && 3 == nUTF8BOMWritten )
             {
@@ -183,7 +182,7 @@ OString makeOString(const sal_uInt8* p, sal_uInt64 n)
 {
     if (n > SAL_MAX_INT32)
     {
-        #ifdef WNT
+        #ifdef _WIN32
         abort();
         #else
         ::std::abort(); //TODO: handle this gracefully
@@ -208,10 +207,10 @@ static void ImplMakeConfigList( ImplConfigData* pData,
     sal_uInt64 nKeyLen;
     sal_uInt64 i;
     const sal_uInt8*    pLine;
-    ImplKeyData*    pPrevKey = NULL;
+    ImplKeyData*    pPrevKey = nullptr;
     ImplKeyData*    pKey;
-    ImplGroupData*  pPrevGroup = NULL;
-    ImplGroupData*  pGroup = NULL;
+    ImplGroupData*  pPrevGroup = nullptr;
+    ImplGroupData*  pGroup = nullptr;
     i = 0;
     while ( i < nLen )
     {
@@ -245,16 +244,16 @@ static void ImplMakeConfigList( ImplConfigData* pData,
         if ( *pLine == '[' )
         {
             pGroup               = new ImplGroupData;
-            pGroup->mpNext       = NULL;
-            pGroup->mpFirstKey   = NULL;
+            pGroup->mpNext       = nullptr;
+            pGroup->mpFirstKey   = nullptr;
             pGroup->mnEmptyLines = 0;
             if ( pPrevGroup )
                 pPrevGroup->mpNext = pGroup;
             else
                 pData->mpFirstGroup = pGroup;
             pPrevGroup  = pGroup;
-            pPrevKey    = NULL;
-            pKey        = NULL;
+            pPrevKey    = nullptr;
+            pKey        = nullptr;
 
             // filter group names
             pLine++;
@@ -283,12 +282,12 @@ static void ImplMakeConfigList( ImplConfigData* pData,
                 if ( !pGroup )
                 {
                     pGroup              = new ImplGroupData;
-                    pGroup->mpNext      = NULL;
-                    pGroup->mpFirstKey  = NULL;
+                    pGroup->mpNext      = nullptr;
+                    pGroup->mpFirstKey  = nullptr;
                     pGroup->mnEmptyLines = 0;
                     pData->mpFirstGroup = pGroup;
                     pPrevGroup  = pGroup;
-                    pPrevKey    = NULL;
+                    pPrevKey    = nullptr;
                 }
 
                 // if empty line, append it
@@ -306,7 +305,7 @@ static void ImplMakeConfigList( ImplConfigData* pData,
 
                 // Generate new key
                 pKey        = new ImplKeyData;
-                pKey->mpNext = NULL;
+                pKey->mpNext = nullptr;
                 if ( pPrevKey )
                     pPrevKey->mpNext = pKey;
                 else
@@ -433,13 +432,13 @@ static sal_uInt8* ImplGetConfigBuffer( const ImplConfigData* pData, sal_uIntPtr&
             return pWriteBuf;
         }
         else
-            return 0;
+            return nullptr;
     }
 
     // Allocate new write buffer (caller frees it)
     pWriteBuf = new sal_uInt8[nBufLen];
     if ( !pWriteBuf )
-        return 0;
+        return nullptr;
 
     // fill buffer
     pBuf = pWriteBuf;
@@ -576,7 +575,7 @@ static void ImplDeleteConfigData( ImplConfigData* pData )
         pGroup = pTempGroup;
     }
 
-    pData->mpFirstGroup = NULL;
+    pData->mpFirstGroup = nullptr;
 }
 
 static ImplConfigData* ImplGetConfigData( const OUString& rFileName )
@@ -585,10 +584,9 @@ static ImplConfigData* ImplGetConfigData( const OUString& rFileName )
 
     pData                   = new ImplConfigData;
     pData->maFileName       = rFileName;
-    pData->mpFirstGroup     = NULL;
+    pData->mpFirstGroup     = nullptr;
     pData->mnDataUpdateId   = 0;
     pData->meLineEnd        = LINEEND_CRLF;
-    pData->mnRefCount       = 0;
     pData->mbRead           = false;
     pData->mbIsUTF8BOM      = false;
     ImplReadConfig( pData );
@@ -620,7 +618,7 @@ ImplGroupData* Config::ImplGetGroup() const
 {
     if ( !mpActGroup || (mnDataUpdateId != mpData->mnDataUpdateId) )
     {
-        ImplGroupData* pPrevGroup = NULL;
+        ImplGroupData* pPrevGroup = nullptr;
         ImplGroupData* pGroup = mpData->mpFirstGroup;
         while ( pGroup )
         {
@@ -635,8 +633,8 @@ ImplGroupData* Config::ImplGetGroup() const
         if ( !pGroup )
         {
             pGroup               = new ImplGroupData;
-            pGroup->mpNext       = NULL;
-            pGroup->mpFirstKey   = NULL;
+            pGroup->mpNext       = nullptr;
+            pGroup->mpFirstKey   = nullptr;
             pGroup->mnEmptyLines = 1;
             if ( pPrevGroup )
                 pPrevGroup->mpNext = pGroup;
@@ -644,7 +642,7 @@ ImplGroupData* Config::ImplGetGroup() const
                 mpData->mpFirstGroup = pGroup;
         }
 
-        // Always inherit group names and upate cache members
+        // Always inherit group names and update cache members
         pGroup->maGroupName             = maGroupName;
         const_cast<Config*>(this)->mnDataUpdateId = mpData->mnDataUpdateId;
         const_cast<Config*>(this)->mpActGroup     = pGroup;
@@ -658,24 +656,16 @@ Config::Config( const OUString& rFileName )
     // Initialize config data
     maFileName      = toUncPath( rFileName );
     mpData          = ImplGetConfigData( maFileName );
-    mpActGroup      = NULL;
+    mpActGroup      = nullptr;
     mnDataUpdateId  = 0;
     mnLockCount     = 1;
-    mbPersistence   = true;
 
-#ifdef DBG_UTIL
-    OStringBuffer aTraceStr("Config::Config( ");
-    aTraceStr.append(OUStringToOString(maFileName, RTL_TEXTENCODING_UTF8));
-    aTraceStr.append(" )");
-    OSL_TRACE("%s", aTraceStr.getStr());
-#endif
+    SAL_INFO("tools.generic", "Config::Config( " << maFileName << " )");
 }
 
 Config::~Config()
 {
-#ifdef DBG_UTIL
-    OSL_TRACE( "Config::~Config()" );
-#endif
+    SAL_INFO("tools.generic", "Config::~Config()" );
 
     Flush();
     ImplFreeConfigData( mpData );
@@ -700,7 +690,7 @@ void Config::DeleteGroup(const OString& rGroup)
         mpData->mbRead = true;
     }
 
-    ImplGroupData* pPrevGroup = NULL;
+    ImplGroupData* pPrevGroup = nullptr;
     ImplGroupData* pGroup = mpData->mpFirstGroup;
     while ( pGroup )
     {
@@ -731,7 +721,7 @@ void Config::DeleteGroup(const OString& rGroup)
         delete pGroup;
 
         // Rewrite config data
-        if ( !mnLockCount && mbPersistence )
+        if ( !mnLockCount )
             ImplWriteConfig( mpData );
         else
         {
@@ -814,15 +804,8 @@ OString Config::ReadKey(const OString& rKey) const
 
 OString Config::ReadKey(const OString& rKey, const OString& rDefault) const
 {
-#ifdef DBG_UTIL
-    OStringBuffer aTraceStr("Config::ReadKey( ");
-    aTraceStr.append(rKey);
-    aTraceStr.append(" ) from ");
-    aTraceStr.append(GetGroup());
-    aTraceStr.append(" in ");
-    aTraceStr.append(OUStringToOString(maFileName, RTL_TEXTENCODING_UTF8));
-    OSL_TRACE("%s", aTraceStr.getStr());
-#endif
+    SAL_INFO("tools.generic", "Config::ReadKey( " << rKey << " ) from " << GetGroup()
+                      << " in " << maFileName);
 
     // Update config data if necessary
     if ( !mnLockCount )
@@ -847,17 +830,8 @@ OString Config::ReadKey(const OString& rKey, const OString& rDefault) const
 
 void Config::WriteKey(const OString& rKey, const OString& rStr)
 {
-#ifdef DBG_UTIL
-    OStringBuffer aTraceStr("Config::WriteKey( ");
-    aTraceStr.append(rKey);
-    aTraceStr.append(", ");
-    aTraceStr.append(rStr);
-    aTraceStr.append(" ) to ");
-    aTraceStr.append(GetGroup());
-    aTraceStr.append(" in ");
-    aTraceStr.append(OUStringToOString(maFileName, RTL_TEXTENCODING_UTF8));
-    OSL_TRACE("%s", aTraceStr.getStr());
-#endif
+    SAL_INFO("tools.generic", "Config::WriteKey( " << rKey << ", " << rStr << " ) to "
+                       << GetGroup() << " in " << maFileName);
 
     // Update config data if necessary
     if ( !mnLockCount || !mpData->mbRead )
@@ -870,7 +844,7 @@ void Config::WriteKey(const OString& rKey, const OString& rStr)
     ImplGroupData* pGroup = ImplGetGroup();
     if ( pGroup )
     {
-        ImplKeyData* pPrevKey = NULL;
+        ImplKeyData* pPrevKey = nullptr;
         ImplKeyData* pKey = pGroup->mpFirstKey;
         while ( pKey )
         {
@@ -885,7 +859,7 @@ void Config::WriteKey(const OString& rKey, const OString& rStr)
         if ( !pKey )
         {
             pKey              = new ImplKeyData;
-            pKey->mpNext      = NULL;
+            pKey->mpNext      = nullptr;
             pKey->maKey       = rKey;
             pKey->mbIsComment = false;
             if ( pPrevKey )
@@ -901,7 +875,7 @@ void Config::WriteKey(const OString& rKey, const OString& rStr)
         {
             pKey->maValue = rStr;
 
-            if ( !mnLockCount && mbPersistence )
+            if ( !mnLockCount )
                 ImplWriteConfig( mpData );
             else
             {
@@ -924,7 +898,7 @@ void Config::DeleteKey(const OString& rKey)
     ImplGroupData* pGroup = ImplGetGroup();
     if ( pGroup )
     {
-        ImplKeyData* pPrevKey = NULL;
+        ImplKeyData* pPrevKey = nullptr;
         ImplKeyData* pKey = pGroup->mpFirstKey;
         while ( pKey )
         {
@@ -945,7 +919,7 @@ void Config::DeleteKey(const OString& rKey)
             delete pKey;
 
             // Rewrite config file
-            if ( !mnLockCount && mbPersistence )
+            if ( !mnLockCount )
                 ImplWriteConfig( mpData );
             else
             {
@@ -957,14 +931,7 @@ void Config::DeleteKey(const OString& rKey)
 
 sal_uInt16 Config::GetKeyCount() const
 {
-#ifdef DBG_UTIL
-    OStringBuffer aTraceStr("Config::GetKeyCount()");
-    aTraceStr.append(" from ");
-    aTraceStr.append(GetGroup());
-    aTraceStr.append(" in ");
-    aTraceStr.append(OUStringToOString(maFileName, RTL_TEXTENCODING_UTF8));
-    OSL_TRACE("%s", aTraceStr.getStr());
-#endif
+    SAL_INFO("tools.generic", "Config::GetKeyCount() from " << GetGroup() << " in " << maFileName);
 
     // Update config data if necessary
     if ( !mnLockCount )
@@ -990,16 +957,8 @@ sal_uInt16 Config::GetKeyCount() const
 
 OString Config::GetKeyName(sal_uInt16 nKey) const
 {
-#ifdef DBG_UTIL
-    OStringBuffer aTraceStr("Config::GetKeyName( ");
-    aTraceStr.append(static_cast<sal_Int32>(nKey));
-    aTraceStr.append(" ) from ");
-    aTraceStr.append(GetGroup());
-    aTraceStr.append(" in ");
-    aTraceStr.append(OUStringToOString(
-        maFileName, RTL_TEXTENCODING_UTF8));
-    OSL_TRACE("%s", aTraceStr.getStr());
-#endif
+    SAL_INFO("tools.generic", "Config::GetKeyName( " << OString::number(static_cast<sal_Int32>(nKey))
+                      << " ) from " << GetGroup() << " in " << maFileName);
 
     // search key and return name if found
     ImplGroupData* pGroup = ImplGetGroup();
@@ -1024,16 +983,8 @@ OString Config::GetKeyName(sal_uInt16 nKey) const
 
 OString Config::ReadKey(sal_uInt16 nKey) const
 {
-#ifdef DBG_UTIL
-    OStringBuffer aTraceStr("Config::ReadKey( ");
-    aTraceStr.append(static_cast<sal_Int32>(nKey));
-    aTraceStr.append(" ) from ");
-    aTraceStr.append(GetGroup());
-    aTraceStr.append(" in ");
-    aTraceStr.append(OUStringToOString(maFileName,
-        RTL_TEXTENCODING_UTF8));
-    OSL_TRACE("%s", aTraceStr.getStr());
-#endif
+    SAL_INFO("tools.generic", "Config::ReadKey( " << OString::number(static_cast<sal_Int32>(nKey))
+                       << " ) from " << GetGroup() << " in " << maFileName);
 
     // Search key and return value if found
     ImplGroupData* pGroup = ImplGetGroup();
@@ -1058,7 +1009,7 @@ OString Config::ReadKey(sal_uInt16 nKey) const
 
 void Config::Flush()
 {
-    if ( mpData->mbModified && mbPersistence )
+    if ( mpData->mbModified )
         ImplWriteConfig( mpData );
 }
 
