@@ -17,11 +17,6 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#define POLY_CLIP_INT   0
-#define POLY_CLIP_UNION 1
-#define POLY_CLIP_DIFF  2
-#define POLY_CLIP_XOR   3
-
 #include <rtl/math.hxx>
 #include <sal/log.hxx>
 #include <osl/diagnose.h>
@@ -41,7 +36,7 @@ ImplPolyPolygon::ImplPolyPolygon( sal_uInt16 nInitSize )
     mnCount     = nInitSize;
     mnSize      = nInitSize;
     mnResize    = 16;
-    mpPolyAry   = new SVPPOLYGON[ nInitSize ];
+    mpPolyAry   = new tools::Polygon*[ nInitSize ];
 }
 
 ImplPolyPolygon::ImplPolyPolygon( const ImplPolyPolygon& rImplPolyPoly )
@@ -53,12 +48,12 @@ ImplPolyPolygon::ImplPolyPolygon( const ImplPolyPolygon& rImplPolyPoly )
 
     if ( rImplPolyPoly.mpPolyAry )
     {
-        mpPolyAry = new SVPPOLYGON[mnSize];
+        mpPolyAry = new tools::Polygon*[mnSize];
         for ( sal_uInt16 i = 0; i < mnCount; i++ )
-            mpPolyAry[i] = new Polygon( *rImplPolyPoly.mpPolyAry[i] );
+            mpPolyAry[i] = new tools::Polygon( *rImplPolyPoly.mpPolyAry[i] );
     }
     else
-        mpPolyAry = NULL;
+        mpPolyAry = nullptr;
 }
 
 ImplPolyPolygon::~ImplPolyPolygon()
@@ -86,12 +81,12 @@ PolyPolygon::PolyPolygon( sal_uInt16 nInitSize, sal_uInt16 nResize )
     mpImplPolyPolygon = new ImplPolyPolygon( nInitSize, nResize );
 }
 
-PolyPolygon::PolyPolygon( const Polygon& rPoly )
+PolyPolygon::PolyPolygon( const tools::Polygon& rPoly )
 {
     if ( rPoly.GetSize() )
     {
         mpImplPolyPolygon = new ImplPolyPolygon( 1 );
-        mpImplPolyPolygon->mpPolyAry[0] = new Polygon( rPoly );
+        mpImplPolyPolygon->mpPolyAry[0] = new tools::Polygon( rPoly );
     }
     else
         mpImplPolyPolygon = new ImplPolyPolygon( 16, 16 );
@@ -99,7 +94,7 @@ PolyPolygon::PolyPolygon( const Polygon& rPoly )
 
 PolyPolygon::PolyPolygon( const tools::PolyPolygon& rPolyPoly )
 {
-    DBG_ASSERT( rPolyPoly.mpImplPolyPolygon->mnRefCount < 0xFFFFFFFE, "PolyPolygon: RefCount overflow" );
+    DBG_ASSERT( rPolyPoly.mpImplPolyPolygon->mnRefCount < (SAL_MAX_UINT32-1), "PolyPolygon: RefCount overflow" );
 
     mpImplPolyPolygon = rPolyPoly.mpImplPolyPolygon;
     mpImplPolyPolygon->mnRefCount++;
@@ -113,7 +108,7 @@ PolyPolygon::~PolyPolygon()
         delete mpImplPolyPolygon;
 }
 
-void PolyPolygon::Insert( const Polygon& rPoly, sal_uInt16 nPos )
+void PolyPolygon::Insert( const tools::Polygon& rPoly, sal_uInt16 nPos )
 {
     if ( mpImplPolyPolygon->mnCount >= MAX_POLYGONS )
         return;
@@ -128,19 +123,19 @@ void PolyPolygon::Insert( const Polygon& rPoly, sal_uInt16 nPos )
         nPos = mpImplPolyPolygon->mnCount;
 
     if ( !mpImplPolyPolygon->mpPolyAry )
-        mpImplPolyPolygon->mpPolyAry = new SVPPOLYGON[mpImplPolyPolygon->mnSize];
+        mpImplPolyPolygon->mpPolyAry = new tools::Polygon*[mpImplPolyPolygon->mnSize];
     else if ( mpImplPolyPolygon->mnCount == mpImplPolyPolygon->mnSize )
     {
         sal_uInt16      nOldSize = mpImplPolyPolygon->mnSize;
         sal_uInt16      nNewSize = nOldSize + mpImplPolyPolygon->mnResize;
-        SVPPOLYGON* pNewAry;
+        tools::Polygon** pNewAry;
 
         if ( nNewSize >= MAX_POLYGONS )
             nNewSize = MAX_POLYGONS;
-        pNewAry = new SVPPOLYGON[nNewSize];
-        memcpy( pNewAry, mpImplPolyPolygon->mpPolyAry, nPos*sizeof(SVPPOLYGON) );
+        pNewAry = new tools::Polygon*[nNewSize];
+        memcpy( pNewAry, mpImplPolyPolygon->mpPolyAry, nPos*sizeof(Polygon*) );
         memcpy( pNewAry+nPos+1, mpImplPolyPolygon->mpPolyAry+nPos,
-                (nOldSize-nPos)*sizeof(SVPPOLYGON) );
+                (nOldSize-nPos)*sizeof(Polygon*) );
         delete[] mpImplPolyPolygon->mpPolyAry;
         mpImplPolyPolygon->mpPolyAry = pNewAry;
         mpImplPolyPolygon->mnSize = nNewSize;
@@ -149,10 +144,10 @@ void PolyPolygon::Insert( const Polygon& rPoly, sal_uInt16 nPos )
     {
         memmove( mpImplPolyPolygon->mpPolyAry+nPos+1,
                  mpImplPolyPolygon->mpPolyAry+nPos,
-                 (mpImplPolyPolygon->mnCount-nPos)*sizeof(SVPPOLYGON) );
+                 (mpImplPolyPolygon->mnCount-nPos)*sizeof(Polygon*) );
     }
 
-    mpImplPolyPolygon->mpPolyAry[nPos] = new Polygon( rPoly );
+    mpImplPolyPolygon->mpPolyAry[nPos] = new tools::Polygon( rPoly );
     mpImplPolyPolygon->mnCount++;
 }
 
@@ -170,10 +165,10 @@ void PolyPolygon::Remove( sal_uInt16 nPos )
     mpImplPolyPolygon->mnCount--;
     memmove( mpImplPolyPolygon->mpPolyAry+nPos,
              mpImplPolyPolygon->mpPolyAry+nPos+1,
-             (mpImplPolyPolygon->mnCount-nPos)*sizeof(SVPPOLYGON) );
+             (mpImplPolyPolygon->mnCount-nPos)*sizeof(Polygon*) );
 }
 
-void PolyPolygon::Replace( const Polygon& rPoly, sal_uInt16 nPos )
+void PolyPolygon::Replace( const tools::Polygon& rPoly, sal_uInt16 nPos )
 {
     assert(nPos < Count() && "PolyPolygon::Replace(): nPos >= nSize");
 
@@ -184,10 +179,10 @@ void PolyPolygon::Replace( const Polygon& rPoly, sal_uInt16 nPos )
     }
 
     delete mpImplPolyPolygon->mpPolyAry[nPos];
-    mpImplPolyPolygon->mpPolyAry[nPos] = new Polygon( rPoly );
+    mpImplPolyPolygon->mpPolyAry[nPos] = new tools::Polygon( rPoly );
 }
 
-const Polygon& PolyPolygon::GetObject( sal_uInt16 nPos ) const
+const tools::Polygon& PolyPolygon::GetObject( sal_uInt16 nPos ) const
 {
     assert(nPos < Count() && "PolyPolygon::GetObject(): nPos >= nSize");
 
@@ -217,14 +212,14 @@ void PolyPolygon::Clear()
             for ( sal_uInt16 i = 0; i < mpImplPolyPolygon->mnCount; i++ )
                 delete mpImplPolyPolygon->mpPolyAry[i];
             delete[] mpImplPolyPolygon->mpPolyAry;
-            mpImplPolyPolygon->mpPolyAry = NULL;
+            mpImplPolyPolygon->mpPolyAry = nullptr;
             mpImplPolyPolygon->mnCount   = 0;
             mpImplPolyPolygon->mnSize    = mpImplPolyPolygon->mnResize;
         }
     }
 }
 
-void PolyPolygon::Optimize( PolyOptimizeFlags nOptimizeFlags, const PolyOptimizeData* pData )
+void PolyPolygon::Optimize( PolyOptimizeFlags nOptimizeFlags )
 {
     if(bool(nOptimizeFlags) && Count())
     {
@@ -245,7 +240,7 @@ void PolyPolygon::Optimize( PolyOptimizeFlags nOptimizeFlags, const PolyOptimize
             tools::PolyPolygon aPolyPoly;
 
             AdaptiveSubdivide(aPolyPoly);
-            aPolyPoly.Optimize(nOptimizeFlags, pData);
+            aPolyPoly.Optimize(nOptimizeFlags);
             *this = aPolyPoly;
         }
         else
@@ -256,10 +251,10 @@ void PolyPolygon::Optimize( PolyOptimizeFlags nOptimizeFlags, const PolyOptimize
 
             if( bEdges )
             {
-                const Rectangle aBound( GetBoundRect() );
+                const tools::Rectangle aBound( GetBoundRect() );
 
                 fArea = ( aBound.GetWidth() + aBound.GetHeight() ) * 0.5;
-                nPercent = pData ? pData->GetPercentValue() : 50;
+                nPercent = 50;
                 nOptimizeFlags &= ~PolyOptimizeFlags::EDGES;
             }
 
@@ -276,25 +271,25 @@ void PolyPolygon::Optimize( PolyOptimizeFlags nOptimizeFlags, const PolyOptimize
                 if( bEdges )
                 {
                     mpImplPolyPolygon->mpPolyAry[ i ]->Optimize( PolyOptimizeFlags::NO_SAME );
-                    Polygon::ImplReduceEdges( *( mpImplPolyPolygon->mpPolyAry[ i ] ), fArea, nPercent );
+                    tools::Polygon::ImplReduceEdges( *( mpImplPolyPolygon->mpPolyAry[ i ] ), fArea, nPercent );
                 }
 
                 if( bool(nOptimizeFlags) )
-                    mpImplPolyPolygon->mpPolyAry[ i ]->Optimize( nOptimizeFlags, pData );
+                    mpImplPolyPolygon->mpPolyAry[ i ]->Optimize( nOptimizeFlags );
             }
         }
     }
 }
 
-void PolyPolygon::AdaptiveSubdivide( tools::PolyPolygon& rResult, const double d ) const
+void PolyPolygon::AdaptiveSubdivide( tools::PolyPolygon& rResult ) const
 {
     rResult.Clear();
 
-    Polygon aPolygon;
+    tools::Polygon aPolygon;
 
     for( sal_uInt16 i = 0; i < mpImplPolyPolygon->mnCount; i++ )
     {
-        mpImplPolyPolygon->mpPolyAry[ i ]->AdaptiveSubdivide( aPolygon, d );
+        mpImplPolyPolygon->mpPolyAry[ i ]->AdaptiveSubdivide( aPolygon, 1.0 );
         rResult.Insert( aPolygon );
     }
 }
@@ -304,7 +299,7 @@ tools::PolyPolygon PolyPolygon::SubdivideBezier( const tools::PolyPolygon& rPoly
     sal_uInt16 i, nPolys = rPolyPoly.Count();
     tools::PolyPolygon aPolyPoly( nPolys );
     for( i=0; i<nPolys; ++i )
-        aPolyPoly.Insert( Polygon::SubdivideBezier( rPolyPoly.GetObject(i) ) );
+        aPolyPoly.Insert( tools::Polygon::SubdivideBezier( rPolyPoly.GetObject(i) ) );
 
     return aPolyPoly;
 }
@@ -312,15 +307,15 @@ tools::PolyPolygon PolyPolygon::SubdivideBezier( const tools::PolyPolygon& rPoly
 
 void PolyPolygon::GetIntersection( const tools::PolyPolygon& rPolyPoly, tools::PolyPolygon& rResult ) const
 {
-    ImplDoOperation( rPolyPoly, rResult, POLY_CLIP_INT );
+    ImplDoOperation( rPolyPoly, rResult, PolyClipOp::INTERSECT );
 }
 
 void PolyPolygon::GetUnion( const tools::PolyPolygon& rPolyPoly, tools::PolyPolygon& rResult ) const
 {
-    ImplDoOperation( rPolyPoly, rResult, POLY_CLIP_UNION );
+    ImplDoOperation( rPolyPoly, rResult, PolyClipOp::UNION );
 }
 
-void PolyPolygon::ImplDoOperation( const tools::PolyPolygon& rPolyPoly, tools::PolyPolygon& rResult, sal_uIntPtr nOperation ) const
+void PolyPolygon::ImplDoOperation( const tools::PolyPolygon& rPolyPoly, tools::PolyPolygon& rResult, PolyClipOp nOperation ) const
 {
     // Convert to B2DPolyPolygon, temporarily. It might be
     // advantageous in the future, to have a tools::PolyPolygon adaptor that
@@ -330,39 +325,25 @@ void PolyPolygon::ImplDoOperation( const tools::PolyPolygon& rPolyPoly, tools::P
 
     // normalize the two polypolygons before. Force properly oriented
     // polygons.
-    aMergePolyPolygonA = basegfx::tools::prepareForPolygonOperation( aMergePolyPolygonA );
-    aMergePolyPolygonB = basegfx::tools::prepareForPolygonOperation( aMergePolyPolygonB );
+    aMergePolyPolygonA = basegfx::utils::prepareForPolygonOperation( aMergePolyPolygonA );
+    aMergePolyPolygonB = basegfx::utils::prepareForPolygonOperation( aMergePolyPolygonB );
 
     switch( nOperation )
     {
         // All code extracted from svx/source/svdraw/svedtv2.cxx
 
-        case POLY_CLIP_UNION:
+        case PolyClipOp::UNION:
         {
             // merge A and B (OR)
-            aMergePolyPolygonA = basegfx::tools::solvePolygonOperationOr(aMergePolyPolygonA, aMergePolyPolygonB);
-            break;
-        }
-
-        case POLY_CLIP_DIFF:
-        {
-            // subtract B from A (DIFF)
-            aMergePolyPolygonA = basegfx::tools::solvePolygonOperationDiff(aMergePolyPolygonA, aMergePolyPolygonB);
-            break;
-        }
-
-        case POLY_CLIP_XOR:
-        {
-            // compute XOR between poly A and B
-            aMergePolyPolygonA = basegfx::tools::solvePolygonOperationXor(aMergePolyPolygonA, aMergePolyPolygonB);
+            aMergePolyPolygonA = basegfx::utils::solvePolygonOperationOr(aMergePolyPolygonA, aMergePolyPolygonB);
             break;
         }
 
         default:
-        case POLY_CLIP_INT:
+        case PolyClipOp::INTERSECT:
         {
             // cut poly 1 against polys 2..n (AND)
-            aMergePolyPolygonA = basegfx::tools::solvePolygonOperationAnd(aMergePolyPolygonA, aMergePolyPolygonB);
+            aMergePolyPolygonA = basegfx::utils::solvePolygonOperationAnd(aMergePolyPolygonA, aMergePolyPolygonB);
             break;
         }
     }
@@ -443,7 +424,7 @@ void PolyPolygon::Rotate( const Point& rCenter, double fSin, double fCos )
         mpImplPolyPolygon->mpPolyAry[ i ]->Rotate( rCenter, fSin, fCos );
 }
 
-void PolyPolygon::Clip( const Rectangle& rRect )
+void PolyPolygon::Clip( const tools::Rectangle& rRect )
 {
     sal_uInt16 nPolyCount = mpImplPolyPolygon->mnCount;
     sal_uInt16 i;
@@ -468,7 +449,7 @@ void PolyPolygon::Clip( const Rectangle& rRect )
     }
 }
 
-Rectangle PolyPolygon::GetBoundRect() const
+tools::Rectangle PolyPolygon::GetBoundRect() const
 {
     long    nXMin=0, nXMax=0, nYMin=0, nYMax=0;
     bool    bFirst = true;
@@ -476,7 +457,7 @@ Rectangle PolyPolygon::GetBoundRect() const
 
     for ( sal_uInt16 n = 0; n < nPolyCount; n++ )
     {
-        const Polygon*  pPoly = mpImplPolyPolygon->mpPolyAry[n];
+        const tools::Polygon*  pPoly = mpImplPolyPolygon->mpPolyAry[n];
         const Point*    pAry = pPoly->GetConstPointAry();
         sal_uInt16          nPointCount = pPoly->GetSize();
 
@@ -505,9 +486,9 @@ Rectangle PolyPolygon::GetBoundRect() const
     }
 
     if ( !bFirst )
-        return Rectangle( nXMin, nYMin, nXMax, nYMax );
+        return tools::Rectangle( nXMin, nYMin, nXMax, nYMax );
     else
-        return Rectangle();
+        return tools::Rectangle();
 }
 
 Polygon& PolyPolygon::operator[]( sal_uInt16 nPos )
@@ -528,7 +509,7 @@ PolyPolygon& PolyPolygon::operator=( const tools::PolyPolygon& rPolyPoly )
     if (this == &rPolyPoly)
         return *this;
 
-    DBG_ASSERT( rPolyPoly.mpImplPolyPolygon->mnRefCount < 0xFFFFFFFE, "PolyPolygon: RefCount overflow" );
+    DBG_ASSERT( rPolyPoly.mpImplPolyPolygon->mnRefCount < (SAL_MAX_UINT32-1), "PolyPolygon: RefCount overflow" );
 
     rPolyPoly.mpImplPolyPolygon->mnRefCount++;
 
@@ -541,6 +522,12 @@ PolyPolygon& PolyPolygon::operator=( const tools::PolyPolygon& rPolyPoly )
     return *this;
 }
 
+PolyPolygon& PolyPolygon::operator=( tools::PolyPolygon&& rPolyPoly )
+{
+    std::swap(mpImplPolyPolygon, rPolyPoly.mpImplPolyPolygon);
+    return *this;
+}
+
 bool PolyPolygon::operator==( const tools::PolyPolygon& rPolyPoly ) const
 {
     if ( rPolyPoly.mpImplPolyPolygon == mpImplPolyPolygon )
@@ -549,31 +536,9 @@ bool PolyPolygon::operator==( const tools::PolyPolygon& rPolyPoly ) const
         return false;
 }
 
-bool PolyPolygon::IsEqual( const tools::PolyPolygon& rPolyPoly ) const
-{
-    bool bIsEqual = true;
-    if ( Count() != rPolyPoly.Count() )
-        bIsEqual = false;
-    else
-    {
-        sal_uInt16 i;
-        for ( i = 0; i < Count(); i++ )
-        {
-            if (!GetObject( i ).IsEqual( rPolyPoly.GetObject( i ) ) )
-            {
-                bIsEqual = false;
-                break;
-            }
-        }
-    }
-    return bIsEqual;
-}
-
 SvStream& ReadPolyPolygon( SvStream& rIStream, tools::PolyPolygon& rPolyPoly )
 {
-    DBG_ASSERTWARNING( rIStream.GetVersion(), "PolyPolygon::>> - Solar-Version not set on rIStream" );
-
-    Polygon* pPoly;
+    tools::Polygon* pPoly;
     sal_uInt16 nPolyCount(0);
 
     // Read number of polygons
@@ -599,7 +564,7 @@ SvStream& ReadPolyPolygon( SvStream& rIStream, tools::PolyPolygon& rPolyPoly )
 
         for ( sal_uInt16 i = 0; i < nPolyCount; i++ )
         {
-            pPoly = new Polygon;
+            pPoly = new tools::Polygon;
             ReadPolygon( rIStream, *pPoly );
             rPolyPoly.mpImplPolyPolygon->mpPolyAry[i] = pPoly;
         }
@@ -612,8 +577,6 @@ SvStream& ReadPolyPolygon( SvStream& rIStream, tools::PolyPolygon& rPolyPoly )
 
 SvStream& WritePolyPolygon( SvStream& rOStream, const tools::PolyPolygon& rPolyPoly )
 {
-    DBG_ASSERTWARNING( rOStream.GetVersion(), "PolyPolygon::<< - Solar-Version not set on rOStream" );
-
     // Write number of polygons
     sal_uInt16 nPolyCount = rPolyPoly.mpImplPolyPolygon->mnCount;
     rOStream.WriteUInt16( nPolyCount );
@@ -629,9 +592,7 @@ void PolyPolygon::Read( SvStream& rIStream )
 {
     VersionCompat aCompat( rIStream, StreamMode::READ );
 
-    DBG_ASSERTWARNING( rIStream.GetVersion(), "PolyPolygon::>> - Solar-Version not set on rIStream" );
-
-    Polygon* pPoly;
+    tools::Polygon* pPoly;
     sal_uInt16 nPolyCount(0);
 
     // Read number of polygons
@@ -657,7 +618,7 @@ void PolyPolygon::Read( SvStream& rIStream )
 
         for ( sal_uInt16 i = 0; i < nPolyCount; i++ )
         {
-            pPoly = new Polygon;
+            pPoly = new tools::Polygon;
             pPoly->ImplRead( rIStream );
             mpImplPolyPolygon->mpPolyAry[i] = pPoly;
         }
@@ -670,8 +631,6 @@ void PolyPolygon::Write( SvStream& rOStream ) const
 {
     VersionCompat aCompat( rOStream, StreamMode::WRITE, 1 );
 
-    DBG_ASSERTWARNING( rOStream.GetVersion(), "PolyPolygon::<< - Solar-Version not set on rOStream" );
-
     // Write number of polygons
     sal_uInt16 nPolyCount = mpImplPolyPolygon->mnCount;
     rOStream.WriteUInt16( nPolyCount );
@@ -688,7 +647,7 @@ basegfx::B2DPolyPolygon PolyPolygon::getB2DPolyPolygon() const
 
     for(sal_uInt16 a(0); a < mpImplPolyPolygon->mnCount; a++)
     {
-        Polygon* pCandidate = mpImplPolyPolygon->mpPolyAry[a];
+        tools::Polygon* pCandidate = mpImplPolyPolygon->mpPolyAry[a];
         aRetval.append(pCandidate->getB2DPolygon());
     }
 
@@ -709,7 +668,7 @@ PolyPolygon::PolyPolygon(const basegfx::B2DPolyPolygon& rPolyPolygon)
         for(sal_uInt16 a(0); a < nCount; a++)
         {
             basegfx::B2DPolygon aCandidate(rPolyPolygon.getB2DPolygon(sal_uInt32(a)));
-            mpImplPolyPolygon->mpPolyAry[a] = new Polygon( aCandidate );
+            mpImplPolyPolygon->mpPolyAry[a] = new tools::Polygon( aCandidate );
         }
     }
     else
