@@ -177,11 +177,11 @@ public:
     StreamData() : rHandle( nullptr ) { }
 };
 
-static sal_uInt32 GetSvError( int nErrno )
+static ErrCode GetSvError( int nErrno )
 {
-    static struct { int nErr; sal_uInt32 sv; } errArr[] =
+    static struct { int nErr; ErrCode sv; } errArr[] =
     {
-        { 0,            SVSTREAM_OK },
+        { 0,            ERRCODE_NONE },
         { EACCES,       SVSTREAM_ACCESS_DENIED },
         { EBADF,        SVSTREAM_INVALID_HANDLE },
 #if defined(NETBSD) || \
@@ -214,7 +214,7 @@ static sal_uInt32 GetSvError( int nErrno )
         { (int)0xFFFF,  SVSTREAM_GENERALERROR }
     };
 
-    sal_uInt32 nRetVal = SVSTREAM_GENERALERROR; // default error
+    ErrCode nRetVal = SVSTREAM_GENERALERROR; // default error
     int i=0;
     do
     {
@@ -229,11 +229,11 @@ static sal_uInt32 GetSvError( int nErrno )
     return nRetVal;
 }
 
-static sal_uInt32 GetSvError( oslFileError nErrno )
+static ErrCode GetSvError( oslFileError nErrno )
 {
-    static struct { oslFileError nErr; sal_uInt32 sv; } errArr[] =
+    static struct { oslFileError nErr; ErrCode sv; } errArr[] =
     {
-        { osl_File_E_None,        SVSTREAM_OK },
+        { osl_File_E_None,        ERRCODE_NONE },
         { osl_File_E_ACCES,       SVSTREAM_ACCESS_DENIED },
         { osl_File_E_BADF,        SVSTREAM_INVALID_HANDLE },
         { osl_File_E_DEADLK,      SVSTREAM_LOCKING_VIOLATION },
@@ -254,7 +254,7 @@ static sal_uInt32 GetSvError( oslFileError nErrno )
         { (oslFileError)0xFFFF,   SVSTREAM_GENERALERROR }
     };
 
-    sal_uInt32 nRetVal = SVSTREAM_GENERALERROR; // default error
+    ErrCode nRetVal = SVSTREAM_GENERALERROR; // default error
     int i=0;
     do
     {
@@ -272,7 +272,6 @@ static sal_uInt32 GetSvError( oslFileError nErrno )
 SvFileStream::SvFileStream( const OUString& rFileName, StreamMode nOpenMode )
 {
     bIsOpen             = false;
-    nLockCounter        = 0;
     m_isWritable        = false;
     pInstanceData       = new StreamData;
 
@@ -290,7 +289,6 @@ SvFileStream::SvFileStream( const OUString& rFileName, StreamMode nOpenMode )
 SvFileStream::SvFileStream()
 {
     bIsOpen             = false;
-    nLockCounter        = 0;
     m_isWritable        = false;
     pInstanceData       = new StreamData;
     SetBufferSize( 1024 );
