@@ -34,16 +34,16 @@
 #include <com/sun/star/ucb/NameClashException.hpp>
 #include <com/sun/star/ucb/InteractiveBadTransferURLException.hpp>
 #include <com/sun/star/ucb/UnsupportedNameClashException.hpp>
-#include "com/sun/star/beans/PropertyState.hpp"
-#include "com/sun/star/beans/PropertyValue.hpp"
+#include <com/sun/star/beans/PropertyState.hpp>
+#include <com/sun/star/beans/PropertyValue.hpp>
 #include <com/sun/star/ucb/InteractiveAugmentedIOException.hpp>
-#include "com/sun/star/uno/Any.hxx"
-#include "com/sun/star/uno/Sequence.hxx"
-#include "osl/diagnose.h"
-#include "rtl/ustrbuf.hxx"
+#include <com/sun/star/uno/Any.hxx>
+#include <com/sun/star/uno/Sequence.hxx>
+#include <osl/diagnose.h>
+#include <rtl/ustrbuf.hxx>
 #include <rtl/uri.hxx>
 #include <rtl/ustring.hxx>
-#include "sal/types.h"
+#include <sal/types.h>
 
 using namespace ucbhelper;
 using namespace osl;
@@ -186,8 +186,7 @@ namespace fileaccess {
 
     OUString getTitle( const OUString& aPath )
     {
-        sal_Unicode slash = '/';
-        sal_Int32 lastIndex = aPath.lastIndexOf( slash );
+        sal_Int32 lastIndex = aPath.lastIndexOf( '/' );
         return aPath.copy( lastIndex + 1 );
     }
 
@@ -572,9 +571,7 @@ namespace fileaccess {
             excep.Message = "the name contained invalid characters";
             if(isHandled)
                 throw excep;
-            else {
-                cancelCommandExecution( Any(excep), xEnv );
-            }
+            cancelCommandExecution( Any(excep), xEnv );
 //              ioErrorCode = IOErrorCode_INVALID_CHARACTER;
 //              cancelCommandExecution(
 //                  ioErrorCode,
@@ -592,9 +589,7 @@ namespace fileaccess {
             excep.Message = "folder exists and overwrite forbidden";
             if(isHandled)
                 throw excep;
-            else {
-                cancelCommandExecution( Any(excep), xEnv );
-            }
+            cancelCommandExecution( Any(excep), xEnv );
 //              ioErrorCode = IOErrorCode_ALREADY_EXISTING;
 //              cancelCommandExecution(
 //                  ioErrorCode,
