@@ -28,6 +28,7 @@
 #include <osl/diagnose.h>
 #include <com/sun/star/beans/PropertyValue.hpp>
 #include <com/sun/star/container/XHierarchicalNameAccess.hpp>
+#include <com/sun/star/ucb/IllegalIdentifierException.hpp>
 #include <com/sun/star/util/theOfficeInstallationDirectories.hpp>
 #include <comphelper/processfactory.hxx>
 #include <ucbhelper/contentidentifier.hxx>
@@ -41,13 +42,9 @@ using namespace com::sun::star;
 using namespace hierarchy_ucp;
 
 
-
-
 // HierarchyContentProvider Implementation.
 
 
-
-
 HierarchyContentProvider::HierarchyContentProvider(
             const uno::Reference< uno::XComponentContext >& rxContext )
 : ::ucbhelper::ContentProviderImplHelper( rxContext )
@@ -61,7 +58,6 @@ HierarchyContentProvider::~HierarchyContentProvider()
 }
 
 
-
 // XInterface methods.
 
 void SAL_CALL HierarchyContentProvider::acquire()
@@ -77,13 +73,12 @@ void SAL_CALL HierarchyContentProvider::release()
 }
 
 css::uno::Any SAL_CALL HierarchyContentProvider::queryInterface( const css::uno::Type & rType )
-    throw( css::uno::RuntimeException, std::exception )
 {
     css::uno::Any aRet = cppu::queryInterface( rType,
-                                               (static_cast< lang::XTypeProvider* >(this)),
-                                               (static_cast< lang::XServiceInfo* >(this)),
-                                               (static_cast< ucb::XContentProvider* >(this)),
-                                               (static_cast< lang::XInitialization* >(this))
+                                               static_cast< lang::XTypeProvider* >(this),
+                                               static_cast< lang::XServiceInfo* >(this),
+                                               static_cast< ucb::XContentProvider* >(this),
+                                               static_cast< lang::XInitialization* >(this)
                                                );
     return aRet.hasValue() ? aRet : OWeakObject::queryInterface( rType );
 }
@@ -91,7 +86,6 @@ css::uno::Any SAL_CALL HierarchyContentProvider::queryInterface( const css::uno:
 // XTypeProvider methods.
 
 
-
 XTYPEPROVIDER_IMPL_4( HierarchyContentProvider,
                       lang::XTypeProvider,
                       lang::XServiceInfo,
@@ -99,34 +93,39 @@ XTYPEPROVIDER_IMPL_4( HierarchyContentProvider,
                       lang::XInitialization );
 
 
-
 // XServiceInfo methods.
 
+XSERVICEINFO_COMMOM_IMPL( HierarchyContentProvider,
+                          OUString( "com.sun.star.comp.ucb.HierarchyContentProvider" ) )
+/// @throws css::uno::Exception
+static css::uno::Reference< css::uno::XInterface > SAL_CALL
+HierarchyContentProvider_CreateInstance( const css::uno::Reference< css::lang::XMultiServiceFactory> & rSMgr )
+{
+    css::lang::XServiceInfo* pX =
+        static_cast<css::lang::XServiceInfo*>(new HierarchyContentProvider( ucbhelper::getComponentContext(rSMgr) ));
+    return css::uno::Reference< css::uno::XInterface >::query( pX );
+}
 
-
-XSERVICEINFO_IMPL_1_CTX( HierarchyContentProvider,
-                     OUString( "com.sun.star.comp.ucb.HierarchyContentProvider" ),
-                     HIERARCHY_CONTENT_PROVIDER_SERVICE_NAME );
-
-
+css::uno::Sequence< OUString >
+HierarchyContentProvider::getSupportedServiceNames_Static()
+{
+    css::uno::Sequence< OUString > aSNS { "com.sun.star.ucb.HierarchyContentProvider" };
+    return aSNS;
+}
 
 // Service factory implementation.
 
 
-
 ONE_INSTANCE_SERVICE_FACTORY_IMPL( HierarchyContentProvider );
 
 
-
 // XContentProvider methods.
 
 
-
 // virtual
 uno::Reference< ucb::XContent > SAL_CALL
 HierarchyContentProvider::queryContent(
         const uno::Reference< ucb::XContentIdentifier >& Identifier )
-    throw( ucb::IllegalIdentifierException, uno::RuntimeException, std::exception )
 {
     HierarchyUri aUri( Identifier->getContentIdentifier() );
     if ( !aUri.isValid() )
@@ -154,26 +153,21 @@ HierarchyContentProvider::queryContent(
 }
 
 
-
 // XInitialization methods.
 
 
-
 // virtual
 void SAL_CALL HierarchyContentProvider::initialize(
                                 const uno::Sequence< uno::Any >& aArguments )
-    throw( uno::Exception, uno::RuntimeException, std::exception )
 {
     if ( aArguments.getLength() > 0 )
         OSL_FAIL( "HierarchyContentProvider::initialize : not supported!" );
 }
 
 
-
 //  Non-interface methods.
 
 
-
 uno::Reference< lang::XMultiServiceFactory >
 HierarchyContentProvider::getConfigProvider(
                                 const OUString & rServiceSpecifier )
@@ -186,8 +180,7 @@ HierarchyContentProvider::getConfigProvider(
         try
         {
             ConfigProviderMapEntry aEntry;
-            aEntry.xConfigProvider
-                = uno::Reference< lang::XMultiServiceFactory >(
+            aEntry.xConfigProvider.set(
                                 m_xContext->getServiceManager()->createInstanceWithContext(rServiceSpecifier, m_xContext),
                                 uno::UNO_QUERY );
 
@@ -224,7 +217,7 @@ HierarchyContentProvider::getRootConfigReadNameAccess(
     {
         if ( !( (*it).second.xRootReadAccess.is() ) )
         {
-            if ( (*it).second.bTriedToGetRootReadAccess ) // #82494#
+            if ( (*it).second.bTriedToGetRootReadAccess )
             {
                 OSL_FAIL( "HierarchyContentProvider::getRootConfigReadNameAccess - "
                     "Unable to read any config data! -> #82494#" );
@@ -246,10 +239,9 @@ HierarchyContentProvider::getRootConfigReadNameAccess(
 
                     (*it).second.bTriedToGetRootReadAccess = true;
 
-                    (*it).second.xRootReadAccess
-                        = uno::Reference< container::XHierarchicalNameAccess >(
+                    (*it).second.xRootReadAccess.set(
                             xConfigProv->createInstanceWithArguments(
-                                OUString( "com.sun.star.ucb.HierarchyDataReadAccess"  ),
+                                "com.sun.star.ucb.HierarchyDataReadAccess",
                                 aArguments ),
                             uno::UNO_QUERY );
                 }
