@@ -27,7 +27,7 @@
 
  *************************************************************************/
 
-#include "ucbhelper/resultset.hxx"
+#include <ucbhelper/resultset.hxx>
 
 #include "tdoc_datasupplier.hxx"
 #include "tdoc_resultset.hxx"
@@ -38,13 +38,9 @@ using namespace com::sun::star;
 using namespace tdoc_ucp;
 
 
-
-
 // DynamicResultSet Implementation.
 
 
-
-
 DynamicResultSet::DynamicResultSet(
             const uno::Reference< uno::XComponentContext >& rxContext,
             const rtl::Reference< Content >& rxContent,
@@ -55,11 +51,9 @@ DynamicResultSet::DynamicResultSet(
 }
 
 
-
 // Non-interface methods.
 
 
-
 void DynamicResultSet::initStatic()
 {
     m_xResultSet1
