@@ -19,11 +19,15 @@
 
 #include <memory>
 
-#include "com/sun/star/beans/XPropertySet.hpp"
-#include "com/sun/star/embed/ElementModes.hpp"
-#include "com/sun/star/embed/StorageFactory.hpp"
+#include <com/sun/star/beans/XPropertySet.hpp>
+#include <com/sun/star/embed/ElementModes.hpp>
+#include <com/sun/star/embed/InvalidStorageException.hpp>
+#include <com/sun/star/embed/StorageFactory.hpp>
+#include <com/sun/star/embed/StorageWrappedTargetException.hpp>
+#include <com/sun/star/io/IOException.hpp>
+#include <com/sun/star/packages/NoEncryptionException.hpp>
 #include <osl/diagnose.h>
-#include "comphelper/processfactory.hxx"
+#include <comphelper/processfactory.hxx>
 
 #include "tdoc_uri.hxx"
 #include "tdoc_docmgr.hxx"
@@ -35,14 +39,9 @@ using namespace com::sun::star;
 using namespace tdoc_ucp;
 
 
-
-
-
 // StorageElementFactory Implementation.
 
 
-
-
 StorageElementFactory::StorageElementFactory(
     const uno::Reference< uno::XComponentContext > & rxContext,
     const rtl::Reference< OfficeDocumentsManager > & xDocsMgr )
@@ -61,8 +60,6 @@ StorageElementFactory::~StorageElementFactory()
 
 uno::Reference< embed::XStorage >
 StorageElementFactory::createTemporaryStorage()
-    throw ( uno::Exception,
-            uno::RuntimeException )
 {
     uno::Reference< embed::XStorage > xStorage;
     uno::Reference< lang::XSingleServiceFactory > xStorageFac;
@@ -85,11 +82,6 @@ StorageElementFactory::createTemporaryStorage()
 uno::Reference< embed::XStorage >
 StorageElementFactory::createStorage( const OUString & rUri,
                                       StorageAccessMode eMode )
-    throw ( embed::InvalidStorageException,
-            lang::IllegalArgumentException,
-            io::IOException,
-            embed::StorageWrappedTargetException,
-            uno::RuntimeException )
 {
     osl::MutexGuard aGuard( m_aMutex );
 
@@ -97,8 +89,7 @@ StorageElementFactory::createStorage( const OUString & rUri,
          ( eMode != READ_WRITE_NOCREATE ) &&
          ( eMode != READ_WRITE_CREATE ) )
         throw lang::IllegalArgumentException(
-            OUString(
-                "Invalid open mode!" ),
+            "Invalid open mode!",
             uno::Reference< uno::XInterface >(),
             sal_Int16( 2 ) );
 
@@ -106,8 +97,7 @@ StorageElementFactory::createStorage( const OUString & rUri,
     if ( aUri.isRoot() )
     {
         throw lang::IllegalArgumentException(
-            OUString(
-                "Root never has a storage!" ),
+            "Root never has a storage!",
             uno::Reference< uno::XInterface >(),
             sal_Int16( 1 ) );
     }
@@ -179,13 +169,12 @@ StorageElementFactory::createStorage( const OUString & rUri,
         bool bWritable = ( ( eMode == READ_WRITE_NOCREATE )
                             || ( eMode == READ_WRITE_CREATE ) );
 
-        uno::Reference< Storage > xElement(
+        rtl::Reference< Storage > xElement(
             new Storage( m_xContext, this, aUriKey, xParentStorage, xStorage ) );
 
-        aIt = m_aMap.insert(
-            StorageMap::value_type(
+        aIt = m_aMap.emplace(
                 std::pair< OUString, bool >( aUriKey, bWritable ),
-                xElement.get() ) ).first;
+                xElement.get() ).first;
 
         aIt->second->m_aContainerIt = aIt;
         return aIt->second;
@@ -238,12 +227,6 @@ StorageElementFactory::createStorage( const OUString & rUri,
 uno::Reference< io::XInputStream >
 StorageElementFactory::createInputStream( const OUString & rUri,
                                           const OUString & rPassword )
-    throw ( embed::InvalidStorageException,
-            lang::IllegalArgumentException,
-            io::IOException,
-            embed::StorageWrappedTargetException,
-            packages::WrongPasswordException,
-            uno::RuntimeException )
 {
     osl::MutexGuard aGuard( m_aMutex );
 
@@ -268,12 +251,6 @@ uno::Reference< io::XOutputStream >
 StorageElementFactory::createOutputStream( const OUString & rUri,
                                            const OUString & rPassword,
                                            bool bTruncate )
-    throw ( embed::InvalidStorageException,
-            lang::IllegalArgumentException,
-            io::IOException,
-            embed::StorageWrappedTargetException,
-            packages::WrongPasswordException,
-            uno::RuntimeException )
 {
     osl::MutexGuard aGuard( m_aMutex );
 
@@ -313,12 +290,6 @@ uno::Reference< io::XStream >
 StorageElementFactory::createStream( const OUString & rUri,
                                      const OUString & rPassword,
                                      bool bTruncate )
-    throw ( embed::InvalidStorageException,
-            lang::IllegalArgumentException,
-            io::IOException,
-            embed::StorageWrappedTargetException,
-            packages::WrongPasswordException,
-            uno::RuntimeException )
 {
     osl::MutexGuard aGuard( m_aMutex );
 
@@ -349,7 +320,7 @@ StorageElementFactory::createStream( const OUString & rUri,
 }
 
 
-void StorageElementFactory::releaseElement( Storage * pElement )
+void StorageElementFactory::releaseElement( Storage const * pElement )
 {
     OSL_ASSERT( pElement );
     osl::MutexGuard aGuard( m_aMutex );
@@ -358,18 +329,11 @@ void StorageElementFactory::releaseElement( Storage * pElement )
 }
 
 
-
 // Non-UNO interface
 
 
-
 uno::Reference< embed::XStorage > StorageElementFactory::queryParentStorage(
         const OUString & rUri, StorageAccessMode eMode )
-    throw ( embed::InvalidStorageException,
-            lang::IllegalArgumentException,
-            io::IOException,
-            embed::StorageWrappedTargetException,
-            uno::RuntimeException )
 {
     uno::Reference< embed::XStorage > xParentStorage;
 
@@ -391,11 +355,6 @@ uno::Reference< embed::XStorage > StorageElementFactory::queryStorage(
         const uno::Reference< embed::XStorage > & xParentStorage,
         const OUString & rUri,
         StorageAccessMode eMode )
-    throw ( embed::InvalidStorageException,
-            lang::IllegalArgumentException,
-            io::IOException,
-            embed::StorageWrappedTargetException,
-            uno::RuntimeException )
 {
     uno::Reference< embed::XStorage > xStorage;
 
@@ -411,14 +370,12 @@ uno::Reference< embed::XStorage > StorageElementFactory::queryStorage(
         {
             if ( eMode == READ_WRITE_CREATE )
                 throw lang::IllegalArgumentException(
-                    OUString(
-                        "Invalid open mode: document storages cannot be "
-                        "created!" ),
+                    "Invalid open mode: document storages cannot be created!",
                     uno::Reference< uno::XInterface >(),
                     sal_Int16( 2 ) );
             else
                 throw embed::InvalidStorageException(
-                    OUString( "Invalid document id!" ),
+                    "Invalid document id!",
                     uno::Reference< uno::XInterface >() );
         }
 
@@ -474,8 +431,7 @@ uno::Reference< embed::XStorage > StorageElementFactory::queryStorage(
             OSL_FAIL( "Property OpenMode not supported!" );
 
             throw embed::StorageWrappedTargetException(
-                    OUString(
-                        "Bug! Value of property OpenMode has wrong type!" ),
+                    "Bug! Value of property OpenMode has wrong type!",
                     uno::Reference< uno::XInterface >(),
                     uno::makeAny( e ) );
         }
@@ -484,8 +440,7 @@ uno::Reference< embed::XStorage > StorageElementFactory::queryStorage(
             OSL_FAIL( "Caught WrappedTargetException!" );
 
             throw embed::StorageWrappedTargetException(
-                    OUString(
-                        "WrappedTargetException during getPropertyValue!" ),
+                    "WrappedTargetException during getPropertyValue!",
                     uno::Reference< uno::XInterface >(),
                     uno::makeAny( e ) );
         }
@@ -500,7 +455,7 @@ uno::Reference< embed::XStorage > StorageElementFactory::queryStorage(
         {
             try
             {
-                sal_Int32 nOpenMode = embed::ElementModes::READ
+                sal_Int32 const nOpenMode = embed::ElementModes::READ
                                       | embed::ElementModes::NOCREATE;
                 xStorage
                     = xParentStorage->openStorageElement( rName, nOpenMode );
@@ -536,20 +491,13 @@ StorageElementFactory::queryStream(
                 const OUString & rPassword,
                 StorageAccessMode eMode,
                 bool bTruncate )
-    throw ( embed::InvalidStorageException,
-            lang::IllegalArgumentException,
-            io::IOException,
-            embed::StorageWrappedTargetException,
-            packages::WrongPasswordException,
-            uno::RuntimeException )
 {
     osl::MutexGuard aGuard( m_aMutex );
 
     if ( !xParentStorage.is() )
     {
         throw lang::IllegalArgumentException(
-            OUString(
-                "No parent storage!" ),
+            "No parent storage!",
             uno::Reference< uno::XInterface >(),
             sal_Int16( 2 ) );
     }
@@ -558,16 +506,14 @@ StorageElementFactory::queryStream(
     if ( aUri.isRoot() )
     {
         throw lang::IllegalArgumentException(
-            OUString(
-                "Root never is a stream!" ),
+            "Root never is a stream!",
             uno::Reference< uno::XInterface >(),
             sal_Int16( 2 ) );
     }
     else if ( aUri.isDocument() )
     {
         throw lang::IllegalArgumentException(
-            OUString(
-                "A document never is a stream!" ),
+            "A document never is a stream!",
             uno::Reference< uno::XInterface >(),
             sal_Int16( 2 ) );
     }
@@ -604,8 +550,7 @@ StorageElementFactory::queryStream(
             OSL_FAIL( "StorageElementFactory::queryStream : Unknown open mode!" );
 
             throw embed::InvalidStorageException(
-                OUString(
-                    "Unknown open mode!" ),
+                "Unknown open mode!",
                 uno::Reference< uno::XInterface >() );
     }
 
@@ -661,8 +606,7 @@ StorageElementFactory::queryStream(
     if ( !xStream.is() )
     {
         throw embed::InvalidStorageException(
-            OUString(
-                "No stream!" ),
+            "No stream!",
             uno::Reference< uno::XInterface >() );
     }
 
