@@ -64,7 +64,6 @@ css::uno::Reference< css::task::XInteractionContinuation > InterceptedInteractio
 }
 
 void SAL_CALL InterceptedInteraction::handle(const css::uno::Reference< css::task::XInteractionRequest >& xRequest)
-    throw(css::uno::RuntimeException, std::exception)
 {
     impl_handleDefault(xRequest);
 }
@@ -87,7 +86,7 @@ void InterceptedInteraction::impl_handleDefault(const css::uno::Reference< css::
         case E_NO_CONTINUATION_FOUND:
         {
             // Runtime error! The defined continuation could not be located
-            // inside the set of available containuations of the incoming request.
+            // inside the set of available continuations of the incoming request.
             // Whats wrong - the interception list or the request?
             OSL_FAIL("InterceptedInteraction::handle()\nCould intercept this interaction request - but can't locate the right continuation!");
         }
@@ -115,15 +114,11 @@ InterceptedInteraction::EInterceptionState InterceptedInteraction::impl_intercep
         css::uno::Type aInterceptedType = rInterception.Request.getValueType();
 
         // check the request
-        bool bMatch = false;
-        if (rInterception.MatchExact)
-            bMatch = aInterceptedType.equals(aRequestType);
-        else
-            bMatch = aInterceptedType.isAssignableFrom(aRequestType); // don't change intercepted and request type here -> it will check the wrong direction!
+        bool bMatch = aInterceptedType.isAssignableFrom(aRequestType); // don't change intercepted and request type here -> it will check the wrong direction!
 
         // intercepted ...
         // Call they might existing derived class, so they can handle that by its own.
-        // If its not interested on that (may be its not overwritten and the default implementation
+        // If it's not interested on that (maybe it's not overwritten and the default implementation
         // returns E_NOT_INTERCEPTED as default) -> break this loop and search for the right continuation.
         if (bMatch)
         {
