@@ -25,7 +25,6 @@
  *************************************************************************/
 #include <ucbhelper/interactionrequest.hxx>
 
-#include <osl/mutex.hxx>
 #include <osl/diagnose.h>
 #include <cppuhelper/typeprovider.hxx>
 #include <cppuhelper/queryinterface.hxx>
@@ -34,13 +33,9 @@ using namespace com::sun::star;
 using namespace ucbhelper;
 
 
-
-
 // InteractionRequest Implementation.
 
 
-
-
 namespace ucbhelper
 {
 
@@ -92,7 +87,7 @@ void InteractionRequest::setContinuations(
 }
 
 
-rtl::Reference< InteractionContinuation >
+rtl::Reference< InteractionContinuation > const &
 InteractionRequest::getSelection() const
 {
     return m_pImpl->m_xSelection;
@@ -106,11 +101,9 @@ void InteractionRequest::setSelection(
 }
 
 
-
 // XInterface methods.
 
 
-
 // virtual
 void SAL_CALL InteractionRequest::acquire()
     throw()
@@ -130,7 +123,6 @@ void SAL_CALL InteractionRequest::release()
 // virtual
 uno::Any SAL_CALL
 InteractionRequest::queryInterface( const uno::Type & rType )
-    throw ( uno::RuntimeException, std::exception )
 {
     uno::Any aRet = cppu::queryInterface( rType,
                 static_cast< lang::XTypeProvider * >( this ),
@@ -140,14 +132,11 @@ InteractionRequest::queryInterface( const uno::Type & rType )
 }
 
 
-
 // XTypeProvider methods.
 
 
-
 // virtual
 uno::Sequence< sal_Int8 > SAL_CALL InteractionRequest::getImplementationId()
-    throw( uno::RuntimeException, std::exception )
 {
     return css::uno::Sequence<sal_Int8>();
 }
@@ -155,32 +144,20 @@ uno::Sequence< sal_Int8 > SAL_CALL InteractionRequest::getImplementationId()
 
 // virtual
 uno::Sequence< uno::Type > SAL_CALL InteractionRequest::getTypes()
-    throw( uno::RuntimeException, std::exception )
 {
-    static cppu::OTypeCollection* pCollection = nullptr;
-      if ( !pCollection )
-      {
-        osl::Guard< osl::Mutex > aGuard( osl::Mutex::getGlobalMutex() );
-        if ( !pCollection )
-        {
-            static cppu::OTypeCollection collection(
+    static cppu::OTypeCollection s_aCollection(
                 cppu::UnoType<lang::XTypeProvider>::get(),
                 cppu::UnoType<task::XInteractionRequest>::get() );
-            pCollection = &collection;
-        }
-    }
-    return (*pCollection).getTypes();
-}
 
+    return s_aCollection.getTypes();
+}
 
 
 // XInteractionRequest methods.
 
 
-
 // virtual
 uno::Any SAL_CALL InteractionRequest::getRequest()
-    throw( uno::RuntimeException, std::exception )
 {
     return m_pImpl->m_aRequest;
 }
@@ -189,7 +166,6 @@ uno::Any SAL_CALL InteractionRequest::getRequest()
 // virtual
 uno::Sequence< uno::Reference< task::XInteractionContinuation > > SAL_CALL
 InteractionRequest::getContinuations()
-    throw( uno::RuntimeException, std::exception )
 {
     return m_pImpl->m_aContinuations;
 }
@@ -197,23 +173,10 @@ InteractionRequest::getContinuations()
 
 // InteractionContinuation Implementation.
 
-namespace ucbhelper
-{
-
-struct InteractionContinuation_Impl
-{
-    InteractionRequest * m_pRequest;
-
-    explicit InteractionContinuation_Impl( InteractionRequest * pRequest )
-    : m_pRequest( pRequest ) {}
-};
-
-}
-
 
 InteractionContinuation::InteractionContinuation(
                         InteractionRequest * pRequest )
-: m_pImpl( new InteractionContinuation_Impl( pRequest ) )
+: m_pRequest( pRequest )
 {
 }
 
@@ -226,23 +189,16 @@ InteractionContinuation::~InteractionContinuation()
 
 void InteractionContinuation::recordSelection()
 {
-    m_pImpl->m_pRequest->setSelection( this );
+    m_pRequest->setSelection( this );
 }
 
 
-
-
 // InteractionAbort Implementation.
 
 
-
-
-
-
 // XInterface methods.
 
 
-
 // virtual
 void SAL_CALL InteractionAbort::acquire()
     throw()
@@ -262,7 +218,6 @@ void SAL_CALL InteractionAbort::release()
 // virtual
 uno::Any SAL_CALL
 InteractionAbort::queryInterface( const uno::Type & rType )
-    throw ( uno::RuntimeException, std::exception )
 {
     uno::Any aRet = cppu::queryInterface( rType,
                 static_cast< lang::XTypeProvider * >( this ),
@@ -274,14 +229,11 @@ InteractionAbort::queryInterface( const uno::Type & rType )
 }
 
 
-
 // XTypeProvider methods.
 
 
-
 // virtual
 uno::Sequence< sal_Int8 > SAL_CALL InteractionAbort::getImplementationId()
-    throw( uno::RuntimeException, std::exception )
 {
     return css::uno::Sequence<sal_Int8>();
 }
@@ -289,50 +241,31 @@ uno::Sequence< sal_Int8 > SAL_CALL InteractionAbort::getImplementationId()
 
 // virtual
 uno::Sequence< uno::Type > SAL_CALL InteractionAbort::getTypes()
-    throw( uno::RuntimeException, std::exception )
 {
-    static cppu::OTypeCollection* pCollection = nullptr;
-      if ( !pCollection )
-      {
-        osl::Guard< osl::Mutex > aGuard( osl::Mutex::getGlobalMutex() );
-        if ( !pCollection )
-        {
-            static cppu::OTypeCollection collection(
+    static cppu::OTypeCollection s_aCollection(
                 cppu::UnoType<lang::XTypeProvider>::get(),
                 cppu::UnoType<task::XInteractionAbort>::get() );
-            pCollection = &collection;
-        }
-    }
-    return (*pCollection).getTypes();
-}
 
+    return s_aCollection.getTypes();
+}
 
 
 // XInteractionContinuation methods.
 
 
-
 // virtual
 void SAL_CALL InteractionAbort::select()
-    throw( uno::RuntimeException, std::exception )
 {
     recordSelection();
 }
 
 
-
-
 // InteractionRetry Implementation.
 
 
-
-
-
-
 // XInterface methods.
 
 
-
 // virtual
 void SAL_CALL InteractionRetry::acquire()
     throw()
@@ -352,7 +285,6 @@ void SAL_CALL InteractionRetry::release()
 // virtual
 uno::Any SAL_CALL
 InteractionRetry::queryInterface( const uno::Type & rType )
-    throw ( uno::RuntimeException, std::exception )
 {
     uno::Any aRet = cppu::queryInterface( rType,
                 static_cast< lang::XTypeProvider * >( this ),
@@ -364,14 +296,11 @@ InteractionRetry::queryInterface( const uno::Type & rType )
 }
 
 
-
 // XTypeProvider methods.
 
 
-
 // virtual
 uno::Sequence< sal_Int8 > SAL_CALL InteractionRetry::getImplementationId()
-    throw( uno::RuntimeException, std::exception )
 {
     return css::uno::Sequence<sal_Int8>();
 }
@@ -379,50 +308,31 @@ uno::Sequence< sal_Int8 > SAL_CALL InteractionRetry::getImplementationId()
 
 // virtual
 uno::Sequence< uno::Type > SAL_CALL InteractionRetry::getTypes()
-    throw( uno::RuntimeException, std::exception )
 {
-    static cppu::OTypeCollection* pCollection = nullptr;
-      if ( !pCollection )
-      {
-        osl::Guard< osl::Mutex > aGuard( osl::Mutex::getGlobalMutex() );
-        if ( !pCollection )
-        {
-            static cppu::OTypeCollection collection(
+    static cppu::OTypeCollection s_aCollection(
                 cppu::UnoType<lang::XTypeProvider>::get(),
                 cppu::UnoType<task::XInteractionRetry>::get() );
-            pCollection = &collection;
-        }
-    }
-    return (*pCollection).getTypes();
-}
 
+    return s_aCollection.getTypes();
+}
 
 
 // XInteractionContinuation methods.
 
 
-
 // virtual
 void SAL_CALL InteractionRetry::select()
-    throw( uno::RuntimeException, std::exception )
 {
     recordSelection();
 }
 
 
-
-
 // InteractionApprove Implementation.
 
 
-
-
-
-
 // XInterface methods.
 
 
-
 // virtual
 void SAL_CALL InteractionApprove::acquire()
     throw()
@@ -442,7 +352,6 @@ void SAL_CALL InteractionApprove::release()
 // virtual
 uno::Any SAL_CALL
 InteractionApprove::queryInterface( const uno::Type & rType )
-    throw ( uno::RuntimeException, std::exception )
 {
     uno::Any aRet = cppu::queryInterface( rType,
                 static_cast< lang::XTypeProvider * >( this ),
@@ -454,14 +363,11 @@ InteractionApprove::queryInterface( const uno::Type & rType )
 }
 
 
-
 // XTypeProvider methods.
 
 
-
 // virtual
 uno::Sequence< sal_Int8 > SAL_CALL InteractionApprove::getImplementationId()
-    throw( uno::RuntimeException, std::exception )
 {
     return css::uno::Sequence<sal_Int8>();
 }
@@ -469,50 +375,31 @@ uno::Sequence< sal_Int8 > SAL_CALL InteractionApprove::getImplementationId()
 
 // virtual
 uno::Sequence< uno::Type > SAL_CALL InteractionApprove::getTypes()
-    throw( uno::RuntimeException, std::exception )
 {
-    static cppu::OTypeCollection* pCollection = nullptr;
-      if ( !pCollection )
-      {
-        osl::Guard< osl::Mutex > aGuard( osl::Mutex::getGlobalMutex() );
-        if ( !pCollection )
-        {
-            static cppu::OTypeCollection collection(
+    static cppu::OTypeCollection s_aCollection(
                 cppu::UnoType<lang::XTypeProvider>::get(),
                 cppu::UnoType<task::XInteractionApprove>::get() );
-            pCollection = &collection;
-        }
-    }
-    return (*pCollection).getTypes();
-}
 
+    return s_aCollection.getTypes();
+}
 
 
 // XInteractionContinuation methods.
 
 
-
 // virtual
 void SAL_CALL InteractionApprove::select()
-    throw( uno::RuntimeException, std::exception )
 {
     recordSelection();
 }
 
 
-
-
 // InteractionDisapprove Implementation.
 
 
-
-
-
-
 // XInterface methods.
 
 
-
 // virtual
 void SAL_CALL InteractionDisapprove::acquire()
     throw()
@@ -532,7 +419,6 @@ void SAL_CALL InteractionDisapprove::release()
 // virtual
 uno::Any SAL_CALL
 InteractionDisapprove::queryInterface( const uno::Type & rType )
-    throw ( uno::RuntimeException, std::exception )
 {
     uno::Any aRet = cppu::queryInterface( rType,
                 static_cast< lang::XTypeProvider * >( this ),
@@ -544,14 +430,11 @@ InteractionDisapprove::queryInterface( const uno::Type & rType )
 }
 
 
-
 // XTypeProvider methods.
 
 
-
 // virtual
 uno::Sequence< sal_Int8 > SAL_CALL InteractionDisapprove::getImplementationId()
-    throw( uno::RuntimeException, std::exception )
 {
     return css::uno::Sequence<sal_Int8>();
 }
@@ -559,50 +442,31 @@ uno::Sequence< sal_Int8 > SAL_CALL InteractionDisapprove::getImplementationId()
 
 // virtual
 uno::Sequence< uno::Type > SAL_CALL InteractionDisapprove::getTypes()
-    throw( uno::RuntimeException, std::exception )
 {
-    static cppu::OTypeCollection* pCollection = nullptr;
-      if ( !pCollection )
-      {
-        osl::Guard< osl::Mutex > aGuard( osl::Mutex::getGlobalMutex() );
-        if ( !pCollection )
-        {
-            static cppu::OTypeCollection collection(
+    static cppu::OTypeCollection s_aCollection(
                 cppu::UnoType<lang::XTypeProvider>::get(),
                 cppu::UnoType<task::XInteractionDisapprove>::get() );
-            pCollection = &collection;
-        }
-    }
-    return (*pCollection).getTypes();
-}
 
+    return s_aCollection.getTypes();
+}
 
 
 // XInteractionContinuation methods.
 
 
-
 // virtual
 void SAL_CALL InteractionDisapprove::select()
-    throw( uno::RuntimeException, std::exception )
 {
     recordSelection();
 }
 
 
-
-
 // InteractionSupplyAuthentication Implementation.
 
 
-
-
-
-
 // XInterface methods.
 
 
-
 // virtual
 void SAL_CALL InteractionSupplyAuthentication::acquire()
     throw()
@@ -622,7 +486,6 @@ void SAL_CALL InteractionSupplyAuthentication::release()
 // virtual
 uno::Any SAL_CALL
 InteractionSupplyAuthentication::queryInterface( const uno::Type & rType )
-    throw ( uno::RuntimeException, std::exception )
 {
     uno::Any aRet = cppu::queryInterface( rType,
             static_cast< lang::XTypeProvider * >( this ),
@@ -635,15 +498,12 @@ InteractionSupplyAuthentication::queryInterface( const uno::Type & rType )
 }
 
 
-
 // XTypeProvider methods.
 
 
-
 // virtual
 uno::Sequence< sal_Int8 > SAL_CALL
 InteractionSupplyAuthentication::getImplementationId()
-    throw( uno::RuntimeException, std::exception )
 {
     return css::uno::Sequence<sal_Int8>();
 }
@@ -651,46 +511,31 @@ InteractionSupplyAuthentication::getImplementationId()
 
 // virtual
 uno::Sequence< uno::Type > SAL_CALL InteractionSupplyAuthentication::getTypes()
-    throw( uno::RuntimeException, std::exception )
 {
-    static cppu::OTypeCollection* pCollection = nullptr;
-      if ( !pCollection )
-      {
-        osl::Guard< osl::Mutex > aGuard( osl::Mutex::getGlobalMutex() );
-        if ( !pCollection )
-        {
-            static cppu::OTypeCollection collection(
+    static cppu::OTypeCollection s_aCollection(
                 cppu::UnoType<lang::XTypeProvider>::get(),
                 cppu::UnoType<ucb::XInteractionSupplyAuthentication2>::get() );
-            pCollection = &collection;
-        }
-    }
-    return (*pCollection).getTypes();
-}
 
+    return s_aCollection.getTypes();
+}
 
 
 // XInteractionContinuation methods.
 
 
-
 // virtual
 void SAL_CALL InteractionSupplyAuthentication::select()
-    throw( uno::RuntimeException, std::exception )
 {
     recordSelection();
 }
 
 
-
 // XInteractionSupplyAuthentication methods.
 
 
-
 // virtual
 sal_Bool SAL_CALL
 InteractionSupplyAuthentication::canSetRealm()
-    throw( uno::RuntimeException, std::exception )
 {
     return m_bCanSetRealm;
 }
@@ -699,7 +544,6 @@ InteractionSupplyAuthentication::canSetRealm()
 // virtual
 void SAL_CALL
 InteractionSupplyAuthentication::setRealm( const OUString& Realm )
-    throw( uno::RuntimeException, std::exception )
 {
     OSL_ENSURE( m_bCanSetPassword,
         "InteractionSupplyAuthentication::setRealm - Not supported!" );
@@ -712,7 +556,6 @@ InteractionSupplyAuthentication::setRealm( const OUString& Realm )
 // virtual
 sal_Bool SAL_CALL
 InteractionSupplyAuthentication::canSetUserName()
-    throw( uno::RuntimeException, std::exception )
 {
     return m_bCanSetUserName;
 }
@@ -721,7 +564,6 @@ InteractionSupplyAuthentication::canSetUserName()
 // virtual
 void SAL_CALL
 InteractionSupplyAuthentication::setUserName( const OUString& UserName )
-    throw( uno::RuntimeException, std::exception )
 {
     OSL_ENSURE( m_bCanSetUserName,
         "InteractionSupplyAuthentication::setUserName - Not supported!" );
@@ -734,7 +576,6 @@ InteractionSupplyAuthentication::setUserName( const OUString& UserName )
 // virtual
 sal_Bool SAL_CALL
 InteractionSupplyAuthentication::canSetPassword()
-    throw( uno::RuntimeException, std::exception )
 {
     return m_bCanSetPassword;
 }
@@ -743,7 +584,6 @@ InteractionSupplyAuthentication::canSetPassword()
 // virtual
 void SAL_CALL
 InteractionSupplyAuthentication::setPassword( const OUString& Password )
-    throw( uno::RuntimeException, std::exception )
 {
     OSL_ENSURE( m_bCanSetPassword,
         "InteractionSupplyAuthentication::setPassword - Not supported!" );
@@ -757,7 +597,6 @@ InteractionSupplyAuthentication::setPassword( const OUString& Password )
 uno::Sequence< ucb::RememberAuthentication > SAL_CALL
 InteractionSupplyAuthentication::getRememberPasswordModes(
                                     ucb::RememberAuthentication& Default )
-    throw( uno::RuntimeException, std::exception )
 {
     Default = m_eDefaultRememberPasswordMode;
     return m_aRememberPasswordModes;
@@ -768,7 +607,6 @@ InteractionSupplyAuthentication::getRememberPasswordModes(
 void SAL_CALL
 InteractionSupplyAuthentication::setRememberPassword(
                                     ucb::RememberAuthentication Remember )
-    throw( uno::RuntimeException, std::exception )
 {
     m_eRememberPasswordMode = Remember;
 }
@@ -777,7 +615,6 @@ InteractionSupplyAuthentication::setRememberPassword(
 // virtual
 sal_Bool SAL_CALL
 InteractionSupplyAuthentication::canSetAccount()
-    throw( uno::RuntimeException, std::exception )
 {
     return m_bCanSetAccount;
 }
@@ -786,7 +623,6 @@ InteractionSupplyAuthentication::canSetAccount()
 // virtual
 void SAL_CALL
 InteractionSupplyAuthentication::setAccount( const OUString& Account )
-    throw( uno::RuntimeException, std::exception )
 {
     OSL_ENSURE( m_bCanSetAccount,
         "InteractionSupplyAuthentication::setAccount - Not supported!" );
@@ -800,7 +636,6 @@ InteractionSupplyAuthentication::setAccount( const OUString& Account )
 uno::Sequence< ucb::RememberAuthentication > SAL_CALL
 InteractionSupplyAuthentication::getRememberAccountModes(
                                     ucb::RememberAuthentication& Default )
-    throw( uno::RuntimeException, std::exception )
 {
     Default = m_eDefaultRememberAccountMode;
     return m_aRememberAccountModes;
@@ -809,25 +644,20 @@ InteractionSupplyAuthentication::getRememberAccountModes(
 
 // virtual
 void SAL_CALL InteractionSupplyAuthentication::setRememberAccount(
-                                    ucb::RememberAuthentication Remember )
-    throw( uno::RuntimeException, std::exception )
+                                    ucb::RememberAuthentication )
 {
-    m_eRememberAccountMode = Remember;
 }
 
 
-
 // XInteractionSupplyAuthentication2 methods.
 
 
-
 // virtual
 sal_Bool SAL_CALL
 InteractionSupplyAuthentication::canUseSystemCredentials(
         sal_Bool& Default )
-    throw ( uno::RuntimeException, std::exception )
 {
-    Default = m_bDefaultUseSystemCredentials;
+    Default = false;
     return m_bCanUseSystemCredentials;
 }
 
@@ -835,27 +665,18 @@ InteractionSupplyAuthentication::canUseSystemCredentials(
 // virtual
 void SAL_CALL InteractionSupplyAuthentication::setUseSystemCredentials(
         sal_Bool UseSystemCredentials )
-    throw ( uno::RuntimeException, std::exception )
 {
     if ( m_bCanUseSystemCredentials )
         m_bUseSystemCredentials = UseSystemCredentials;
 }
 
 
-
-
-
 // InteractionReplaceExistingData Implementation.
 
 
-
-
-
-
 // XInterface methods.
 
 
-
 // virtual
 void SAL_CALL InteractionReplaceExistingData::acquire()
     throw()
@@ -875,7 +696,6 @@ void SAL_CALL InteractionReplaceExistingData::release()
 // virtual
 uno::Any SAL_CALL
 InteractionReplaceExistingData::queryInterface( const uno::Type & rType )
-    throw ( uno::RuntimeException, std::exception )
 {
     uno::Any aRet = cppu::queryInterface( rType,
                 static_cast< lang::XTypeProvider * >( this ),
@@ -887,15 +707,12 @@ InteractionReplaceExistingData::queryInterface( const uno::Type & rType )
 }
 
 
-
 // XTypeProvider methods.
 
 
-
 // virtual
 uno::Sequence< sal_Int8 > SAL_CALL
 InteractionReplaceExistingData::getImplementationId()
-    throw( uno::RuntimeException, std::exception )
 {
     return css::uno::Sequence<sal_Int8>();
 }
@@ -903,32 +720,20 @@ InteractionReplaceExistingData::getImplementationId()
 
 // virtual
 uno::Sequence< uno::Type > SAL_CALL InteractionReplaceExistingData::getTypes()
-    throw( uno::RuntimeException, std::exception )
 {
-    static cppu::OTypeCollection* pCollection = nullptr;
-      if ( !pCollection )
-      {
-        osl::Guard< osl::Mutex > aGuard( osl::Mutex::getGlobalMutex() );
-        if ( !pCollection )
-        {
-            static cppu::OTypeCollection collection(
+    static cppu::OTypeCollection s_aCollection(
                 cppu::UnoType<lang::XTypeProvider>::get(),
                 cppu::UnoType<ucb::XInteractionReplaceExistingData>::get() );
-            pCollection = &collection;
-        }
-    }
-    return (*pCollection).getTypes();
-}
 
+    return s_aCollection.getTypes();
+}
 
 
 // XInteractionContinuation methods.
 
 
-
 // virtual
 void SAL_CALL InteractionReplaceExistingData::select()
-    throw( uno::RuntimeException, std::exception )
 {
     recordSelection();
 }
@@ -954,7 +759,6 @@ void SAL_CALL InteractionAuthFallback::release()
 // virtual
 uno::Any SAL_CALL
 InteractionAuthFallback::queryInterface( const uno::Type & rType )
-    throw ( uno::RuntimeException, std::exception )
 {
     uno::Any aRet = cppu::queryInterface( rType,
             static_cast< task::XInteractionContinuation * >( this ),
@@ -968,7 +772,6 @@ InteractionAuthFallback::queryInterface( const uno::Type & rType )
 
 // virtual
 void SAL_CALL InteractionAuthFallback::select()
-    throw( uno::RuntimeException, std::exception )
 {
     recordSelection();
 }
@@ -977,14 +780,11 @@ void SAL_CALL InteractionAuthFallback::select()
 
 // virtual
 void SAL_CALL InteractionAuthFallback::setCode( const OUString& code )
-    throw ( uno::RuntimeException, std::exception )
 {
     m_aCode = code;
 }
 
-// virtual
-OUString SAL_CALL InteractionAuthFallback::getCode( )
-    throw ( uno::RuntimeException, std::exception )
+const OUString& SAL_CALL InteractionAuthFallback::getCode() const
 {
     return m_aCode;
 }
