@@ -17,14 +17,19 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
+#include <sal/config.h>
+
+#include <sal/log.hxx>
 #include <unotools/saveopt.hxx>
 #include <rtl/instance.hxx>
 #include <unotools/configmgr.hxx>
 #include <unotools/configitem.hxx>
 #include <tools/debug.hxx>
+#include <tools/solar.h>
 #include <com/sun/star/uno/Any.hxx>
 #include <com/sun/star/uno/Sequence.hxx>
 
+#include <osl/diagnose.h>
 #include <osl/mutex.hxx>
 #include <comphelper/processfactory.hxx>
 #include "itemholder1.hxx"
@@ -44,7 +49,7 @@ struct SvtLoadSaveOptions_Impl
     SvtLoadOptions_Impl* pLoadOpt;
 };
 
-static SvtLoadSaveOptions_Impl* pOptions = NULL;
+static SvtLoadSaveOptions_Impl* pOptions = nullptr;
 static sal_Int32           nRefCount = 0;
 
 class SvtSaveOptions_Impl : public utl::ConfigItem
@@ -63,9 +68,7 @@ class SvtSaveOptions_Impl : public utl::ConfigItem
                                         bSaveUnpacked,
                                         bDoPrettyPrinting,
                                         bWarnAlienFormat,
-                                        bLoadDocPrinter,
-                                        bUseSHA1InODF12,
-                                        bUseBlowfishInODF12;
+                                        bLoadDocPrinter;
 
     SvtSaveOptions::ODFDefaultVersion   eODFDefaultVersion;
 
@@ -84,16 +87,14 @@ class SvtSaveOptions_Impl : public utl::ConfigItem
                                         bROWarnAlienFormat,
                                         bRODoPrettyPrinting,
                                         bROLoadDocPrinter,
-                                        bROODFDefaultVersion,
-                                        bROUseSHA1InODF12,
-                                        bROUseBlowfishInODF12;
+                                        bROODFDefaultVersion;
+
+    virtual void            ImplCommit() override;
 
 public:
                             SvtSaveOptions_Impl();
-                            virtual ~SvtSaveOptions_Impl();
 
-    virtual void            Notify( const com::sun::star::uno::Sequence< OUString >& aPropertyNames ) SAL_OVERRIDE;
-    virtual void            Commit() SAL_OVERRIDE;
+    virtual void            Notify( const css::uno::Sequence< OUString >& aPropertyNames ) override;
 
     sal_Int32               GetAutoSaveTime() const             { return nAutoSaveTime; }
     bool                    IsUseUserData() const               { return bUseUserData; }
@@ -110,8 +111,6 @@ public:
     bool                IsPrettyPrintingEnabled( ) const    { return bDoPrettyPrinting; }
     bool                IsWarnAlienFormat() const           { return bWarnAlienFormat; }
     bool                IsLoadDocPrinter() const            { return bLoadDocPrinter; }
-    bool                IsUseSHA1InODF12() const            { return bUseSHA1InODF12; }
-    bool                IsUseBlowfishInODF12() const        { return bUseBlowfishInODF12; }
 
     SvtSaveOptions::ODFDefaultVersion
                             GetODFDefaultVersion() const        { return eODFDefaultVersion; }
@@ -278,60 +277,51 @@ bool SvtSaveOptions_Impl::IsReadOnly( SvtSaveOptions::EOption eOption ) const
     bool bReadOnly = CFG_READONLY_DEFAULT;
     switch(eOption)
     {
-        case SvtSaveOptions::E_AUTOSAVETIME :
+        case SvtSaveOptions::EOption::AutoSaveTime :
             bReadOnly = bROAutoSaveTime;
             break;
-        case SvtSaveOptions::E_USEUSERDATA :
+        case SvtSaveOptions::EOption::UseUserData :
             bReadOnly = bROUseUserData;
             break;
-        case SvtSaveOptions::E_BACKUP :
+        case SvtSaveOptions::EOption::Backup :
             bReadOnly = bROBackup;
             break;
-        case SvtSaveOptions::E_AUTOSAVE :
+        case SvtSaveOptions::EOption::AutoSave :
             bReadOnly = bROAutoSave;
             break;
-        case SvtSaveOptions::E_AUTOSAVEPROMPT :
+        case SvtSaveOptions::EOption::AutoSavePrompt :
             bReadOnly = bROAutoSavePrompt;
             break;
-        case SvtSaveOptions::E_USERAUTOSAVE :
+        case SvtSaveOptions::EOption::UserAutoSave :
             bReadOnly = bROUserAutoSave;
             break;
-        case SvtSaveOptions::E_DOCINFSAVE :
+        case SvtSaveOptions::EOption::DocInfSave :
             bReadOnly = bRODocInfSave;
             break;
-        case SvtSaveOptions::E_SAVEWORKINGSET :
+        case SvtSaveOptions::EOption::SaveWorkingSet :
             bReadOnly = bROSaveWorkingSet;
             break;
-        case SvtSaveOptions::E_SAVEDOCVIEW :
+        case SvtSaveOptions::EOption::SaveDocView :
             bReadOnly = bROSaveDocView;
             break;
-        case SvtSaveOptions::E_SAVERELINET :
+        case SvtSaveOptions::EOption::SaveRelInet :
             bReadOnly = bROSaveRelINet;
             break;
-        case SvtSaveOptions::E_SAVERELFSYS :
+        case SvtSaveOptions::EOption::SaveRelFsys :
             bReadOnly = bROSaveRelFSys;
             break;
-        case SvtSaveOptions::E_SAVEUNPACKED :
-            bReadOnly = bROSaveUnpacked;
-            break;
-        case SvtSaveOptions::E_DOPRETTYPRINTING :
+        case SvtSaveOptions::EOption::DoPrettyPrinting :
             bReadOnly = bRODoPrettyPrinting;
             break;
-        case SvtSaveOptions::E_WARNALIENFORMAT :
+        case SvtSaveOptions::EOption::WarnAlienFormat :
             bReadOnly = bROWarnAlienFormat;
             break;
-        case SvtSaveOptions::E_LOADDOCPRINTER :
+        case SvtSaveOptions::EOption::LoadDocPrinter :
             bReadOnly = bROLoadDocPrinter;
             break;
-        case SvtSaveOptions::E_ODFDEFAULTVERSION :
+        case SvtSaveOptions::EOption::OdfDefaultVersion :
             bReadOnly = bROLoadDocPrinter;
             break;
-        case SvtSaveOptions::E_USESHA1INODF12:
-            bReadOnly = bROUseSHA1InODF12;
-            break;
-        case SvtSaveOptions::E_USEBLOWFISHINODF12:
-            bReadOnly = bROUseBlowfishInODF12;
-            break;
     }
     return bReadOnly;
 }
@@ -352,8 +342,6 @@ bool SvtSaveOptions_Impl::IsReadOnly( SvtSaveOptions::EOption eOption ) const
 #define INTERNET            13
 #define SAVEWORKINGSET      14
 #define ODFDEFAULTVERSION   15
-#define USESHA1INODF12      16
-#define USEBLOWFISHINODF12  17
 
 Sequence< OUString > GetPropertyNames()
 {
@@ -375,11 +363,9 @@ Sequence< OUString > GetPropertyNames()
         "URL/Internet",
         "WorkingSet",
         "ODF/DefaultVersion",
-        "ODF/UseSHA1InODF12",
-        "ODF/UseBlowfishInODF12"
     };
 
-    const int nCount = sizeof( aPropNames ) / sizeof( const char* );
+    const int nCount = SAL_N_ELEMENTS( aPropNames );
     Sequence< OUString > aNames( nCount );
     OUString* pNames = aNames.getArray();
     for ( int i = 0; i < nCount; i++ )
@@ -389,7 +375,7 @@ Sequence< OUString > GetPropertyNames()
 }
 
 SvtSaveOptions_Impl::SvtSaveOptions_Impl()
-    : ConfigItem( OUString("Office.Common/Save") )
+    : ConfigItem( "Office.Common/Save" )
     , nAutoSaveTime( 0 )
     , bUseUserData( false )
     , bBackup( false )
@@ -405,8 +391,6 @@ SvtSaveOptions_Impl::SvtSaveOptions_Impl()
     , bDoPrettyPrinting( false )
     , bWarnAlienFormat( true )
     , bLoadDocPrinter( true )
-    , bUseSHA1InODF12( false )
-    , bUseBlowfishInODF12( false )
     , eODFDefaultVersion( SvtSaveOptions::ODFVER_LATEST )
     , bROAutoSaveTime( CFG_READONLY_DEFAULT )
     , bROUseUserData( CFG_READONLY_DEFAULT )
@@ -424,8 +408,6 @@ SvtSaveOptions_Impl::SvtSaveOptions_Impl()
     , bRODoPrettyPrinting( CFG_READONLY_DEFAULT )
     , bROLoadDocPrinter( CFG_READONLY_DEFAULT )
     , bROODFDefaultVersion( CFG_READONLY_DEFAULT )
-    , bROUseSHA1InODF12( CFG_READONLY_DEFAULT )
-    , bROUseBlowfishInODF12( CFG_READONLY_DEFAULT )
 {
     Sequence< OUString > aNames = GetPropertyNames();
     Sequence< Any > aValues = GetProperties( aNames );
@@ -537,16 +519,6 @@ SvtSaveOptions_Impl::SvtSaveOptions_Impl()
                                     bROLoadDocPrinter = pROStates[nProp];
                                     break;
 
-                                case USESHA1INODF12:
-                                    bUseSHA1InODF12 = bTemp;
-                                    bROUseSHA1InODF12 = pROStates[nProp];
-                                    break;
-
-                                case USEBLOWFISHINODF12:
-                                    bUseBlowfishInODF12 = bTemp;
-                                    bROUseBlowfishInODF12 = pROStates[nProp];
-                                    break;
-
                                 default :
                                     SAL_WARN( "unotools.config", "invalid index to load a path" );
                             }
@@ -561,15 +533,21 @@ SvtSaveOptions_Impl::SvtSaveOptions_Impl()
         }
     }
 
-    bAutoSave = officecfg::Office::Recovery::AutoSave::Enabled::get();
-    nAutoSaveTime = officecfg::Office::Recovery::AutoSave::TimeIntervall::get();
-    bUserAutoSave = officecfg::Office::Recovery::AutoSave::UserAutoSaveEnabled::get();
+    if (!utl::ConfigManager::IsFuzzing())
+    {
+        bAutoSave = officecfg::Office::Recovery::AutoSave::Enabled::get();
+        nAutoSaveTime = officecfg::Office::Recovery::AutoSave::TimeIntervall::get();
+        bUserAutoSave = officecfg::Office::Recovery::AutoSave::UserAutoSaveEnabled::get();
+    }
+    else
+    {
+        bAutoSave = false;
+        nAutoSaveTime = 0;
+        bUserAutoSave = false;
+    }
 }
 
-SvtSaveOptions_Impl::~SvtSaveOptions_Impl()
-{}
-
-void SvtSaveOptions_Impl::Commit()
+void SvtSaveOptions_Impl::ImplCommit()
 {
     Sequence< OUString > aOrgNames = GetPropertyNames();
     OUString* pOrgNames = aOrgNames.getArray();
@@ -708,22 +686,6 @@ void SvtSaveOptions_Impl::Commit()
                     ++nRealCount;
                 }
                 break;
-            case USESHA1INODF12:
-                if (!bROUseSHA1InODF12)
-                {
-                    pValues[nRealCount] <<= bUseSHA1InODF12;
-                    pNames[nRealCount] = pOrgNames[i];
-                    ++nRealCount;
-                }
-                break;
-            case USEBLOWFISHINODF12:
-                if (!bROUseBlowfishInODF12)
-                {
-                    pValues[nRealCount] <<= bUseBlowfishInODF12;
-                    pNames[nRealCount] = pOrgNames[i];
-                    ++nRealCount;
-                }
-                break;
 
             default:
                 SAL_WARN( "unotools.config", "invalid index to save a path" );
@@ -734,7 +696,7 @@ void SvtSaveOptions_Impl::Commit()
     aValues.realloc(nRealCount);
     PutProperties( aNames, aValues );
 
-    boost::shared_ptr< comphelper::ConfigurationChanges > batch(
+    std::shared_ptr< comphelper::ConfigurationChanges > batch(
     comphelper::ConfigurationChanges::create());
     officecfg::Office::Recovery::AutoSave::TimeIntervall::set(nAutoSaveTime, batch);
     officecfg::Office::Recovery::AutoSave::Enabled::set(bAutoSave, batch);
@@ -748,15 +710,15 @@ void SvtSaveOptions_Impl::Notify( const Sequence<OUString>& )
 
 class SvtLoadOptions_Impl : public utl::ConfigItem
 {
-
+private:
     bool                            bLoadUserDefinedSettings;
 
+    virtual void            ImplCommit() override;
+
 public:
                             SvtLoadOptions_Impl();
-                            virtual ~SvtLoadOptions_Impl();
 
-    virtual void            Notify( const com::sun::star::uno::Sequence< OUString >& aPropertyNames ) SAL_OVERRIDE;
-    virtual void            Commit() SAL_OVERRIDE;
+    virtual void            Notify( const css::uno::Sequence< OUString >& aPropertyNames ) override;
 
     void                    SetLoadUserSettings(bool b){bLoadUserDefinedSettings = b; SetModified();}
     bool                IsLoadUserSettings() const {return bLoadUserDefinedSettings;}
@@ -765,30 +727,21 @@ public:
 const sal_Char cUserDefinedSettings[] = "UserDefinedSettings";
 
 SvtLoadOptions_Impl::SvtLoadOptions_Impl()
-    : ConfigItem( OUString("Office.Common/Load") )
+    : ConfigItem( "Office.Common/Load" )
     , bLoadUserDefinedSettings( false )
 {
-    Sequence< OUString > aNames(1);
-    aNames[0] = OUString::createFromAscii(cUserDefinedSettings);
+    Sequence< OUString > aNames { cUserDefinedSettings };
     Sequence< Any > aValues = GetProperties( aNames );
     EnableNotification( aNames );
     const Any* pValues = aValues.getConstArray();
     DBG_ASSERT( aValues.getLength() == aNames.getLength(), "GetProperties failed" );
-    if (pValues[0].getValueTypeClass() == ::com::sun::star::uno::TypeClass_BOOLEAN)
-         bLoadUserDefinedSettings = *(sal_Bool *)pValues[0].getValue();
+    pValues[0] >>= bLoadUserDefinedSettings;
 }
 
-SvtLoadOptions_Impl::~SvtLoadOptions_Impl()
+void SvtLoadOptions_Impl::ImplCommit()
 {
-}
-
-void SvtLoadOptions_Impl::Commit()
-{
-    Sequence< OUString > aNames(1);
-    aNames[0] = OUString::createFromAscii(cUserDefinedSettings);
-    Sequence< Any > aValues( 1 );
-    aValues[0].setValue(&bLoadUserDefinedSettings, ::getBooleanCppuType());
-    PutProperties( aNames, aValues );
+    PutProperties(
+        {cUserDefinedSettings}, {css::uno::Any(bLoadUserDefinedSettings)});
 }
 
 void SvtLoadOptions_Impl::Notify( const Sequence<OUString>& )
@@ -813,7 +766,7 @@ SvtSaveOptions::SvtSaveOptions()
         pOptions->pSaveOpt = new SvtSaveOptions_Impl;
         pOptions->pLoadOpt = new SvtLoadOptions_Impl;
 
-        ItemHolder1::holdConfigItem(E_SAVEOPTIONS);
+        ItemHolder1::holdConfigItem(EItem::SaveOptions);
    }
    ++nRefCount;
     pImp = pOptions;
@@ -1001,14 +954,26 @@ SvtSaveOptions::ODFDefaultVersion SvtSaveOptions::GetODFDefaultVersion() const
     return pImp->pSaveOpt->GetODFDefaultVersion();
 }
 
-bool SvtSaveOptions::IsUseSHA1InODF12() const
+SvtSaveOptions::ODFSaneDefaultVersion SvtSaveOptions::GetODFSaneDefaultVersion() const
 {
-    return pImp->pSaveOpt->IsUseSHA1InODF12();
-}
-
-bool SvtSaveOptions::IsUseBlowfishInODF12() const
-{
-    return pImp->pSaveOpt->IsUseBlowfishInODF12();
+    switch (pImp->pSaveOpt->GetODFDefaultVersion())
+    {
+        default:
+            assert(!"map new ODFDefaultVersion to ODFSaneDefaultVersion");
+            break;
+        case ODFVER_UNKNOWN:
+        case ODFVER_LATEST:
+            return ODFSVER_LATEST_EXTENDED;
+        case ODFVER_010:
+            return ODFSVER_010;
+        case ODFVER_011:
+            return ODFSVER_011;
+        case ODFVER_012:
+            return ODFSVER_012;
+        case ODFVER_012_EXT_COMPAT:
+            return ODFSVER_012_EXT_COMPAT;
+    }
+    return ODFSVER_LATEST_EXTENDED;
 }
 
 bool SvtSaveOptions::IsReadOnly( SvtSaveOptions::EOption eOption ) const
