@@ -17,11 +17,17 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
+#include <sal/config.h>
+
+#include <cstdlib>
+
 #include <i18nlangtag/languagetag.hxx>
+#include <i18nutil/searchopt.hxx>
+#include <i18nutil/transliteration.hxx>
 #include <com/sun/star/lang/XMultiServiceFactory.hpp>
-#include <com/sun/star/util/TextSearch.hpp>
+#include <com/sun/star/util/TextSearch2.hpp>
+#include <com/sun/star/util/SearchAlgorithms2.hpp>
 #include <com/sun/star/util/SearchFlags.hpp>
-#include <com/sun/star/i18n/TransliterationModules.hpp>
 #include <sal/log.hxx>
 #include <unotools/charclass.hxx>
 #include <comphelper/processfactory.hxx>
@@ -39,23 +45,20 @@ namespace utl
 SearchParam::SearchParam( const OUString &rText,
                                 SearchType eType,
                                 bool bCaseSensitive,
-                                bool bWrdOnly,
-                                bool bSearchInSel )
+                                sal_uInt32 cWildEscChar,
+                                bool bWildMatchSel )
 {
     sSrchStr        = rText;
     m_eSrchType     = eType;
 
-    m_bWordOnly     = bWrdOnly;
-    m_bSrchInSel    = bSearchInSel;
+    m_cWildEscChar  = cWildEscChar;
+
+    m_bWordOnly     = false;
+    m_bSrchInSel    = false;
     m_bCaseSense    = bCaseSensitive;
+    m_bWildMatchSel = bWildMatchSel;
 
-    nTransliterationFlags = 0;
-
-    // Parameters for weighted Levenshtein distance
-    bLEV_Relaxed    = true;
-    nLEV_OtherX     = 2;
-    nLEV_ShorterY   = 1;
-    nLEV_LongerZ    = 3;
+    nTransliterationFlags = TransliterationFlags::NONE;
 }
 
 SearchParam::SearchParam( const SearchParam& rParam )
@@ -64,26 +67,27 @@ SearchParam::SearchParam( const SearchParam& rParam )
     sReplaceStr     = rParam.sReplaceStr;
     m_eSrchType     = rParam.m_eSrchType;
 
+    m_cWildEscChar  = rParam.m_cWildEscChar;
+
     m_bWordOnly     = rParam.m_bWordOnly;
     m_bSrchInSel    = rParam.m_bSrchInSel;
     m_bCaseSense    = rParam.m_bCaseSense;
-
-    bLEV_Relaxed    = rParam.bLEV_Relaxed;
-    nLEV_OtherX     = rParam.nLEV_OtherX;
-    nLEV_ShorterY   = rParam.nLEV_ShorterY;
-    nLEV_LongerZ    = rParam.nLEV_LongerZ;
+    m_bWildMatchSel = rParam.m_bWildMatchSel;
 
     nTransliterationFlags = rParam.nTransliterationFlags;
 }
 
 SearchParam::~SearchParam() {}
 
-static bool lcl_Equals( const SearchOptions& rSO1, const SearchOptions& rSO2 )
+static bool lcl_Equals( const i18nutil::SearchOptions2& rSO1, const i18nutil::SearchOptions2& rSO2 )
 {
-    return rSO1.algorithmType == rSO2.algorithmType &&
+    return
+        rSO1.AlgorithmType2 == rSO2.AlgorithmType2 &&
+        rSO1.WildcardEscapeCharacter == rSO2.WildcardEscapeCharacter &&
+        rSO1.algorithmType == rSO2.algorithmType &&
         rSO1.searchFlag == rSO2.searchFlag &&
-        rSO1.searchString.equals(rSO2.searchString) &&
-        rSO1.replaceString.equals(rSO2.replaceString) &&
+        rSO1.searchString == rSO2.searchString &&
+        rSO1.replaceString == rSO2.replaceString &&
         rSO1.changedChars == rSO2.changedChars &&
         rSO1.deletedChars == rSO2.deletedChars &&
         rSO1.insertedChars == rSO2.insertedChars &&
@@ -98,15 +102,15 @@ namespace
     struct CachedTextSearch
     {
         ::osl::Mutex mutex;
-        css::util::SearchOptions Options;
-        css::uno::Reference< css::util::XTextSearch > xTextSearch;
+        i18nutil::SearchOptions2 Options;
+        css::uno::Reference< css::util::XTextSearch2 > xTextSearch;
     };
 
     struct theCachedTextSearch
         : public rtl::Static< CachedTextSearch, theCachedTextSearch > {};
 }
 
-Reference<XTextSearch> TextSearch::getXTextSearch( const SearchOptions& rPara )
+Reference<XTextSearch2> TextSearch::getXTextSearch( const i18nutil::SearchOptions2& rPara )
 {
     CachedTextSearch &rCache = theCachedTextSearch::get();
 
@@ -116,8 +120,8 @@ Reference<XTextSearch> TextSearch::getXTextSearch( const SearchOptions& rPara )
         return rCache.xTextSearch;
 
     Reference< XComponentContext > xContext = ::comphelper::getProcessComponentContext();
-    rCache.xTextSearch.set( ::TextSearch::create(xContext) );
-    rCache.xTextSearch->setOptions( rPara );
+    rCache.xTextSearch.set( ::TextSearch2::create(xContext) );
+    rCache.xTextSearch->setOptions2( rPara.toUnoSearchOptions2() );
     rCache.Options = rPara;
 
     return rCache.xTextSearch;
@@ -137,41 +141,79 @@ TextSearch::TextSearch(const SearchParam & rParam, const CharClass& rCClass )
     Init( rParam, rCClass.getLanguageTag().getLocale() );
 }
 
-TextSearch::TextSearch( const SearchOptions& rPara )
+TextSearch::TextSearch( const i18nutil::SearchOptions2& rPara )
 {
     xTextSearch = getXTextSearch( rPara );
 }
 
+i18nutil::SearchOptions2 TextSearch::UpgradeToSearchOptions2( const i18nutil::SearchOptions& rOptions )
+{
+    sal_Int16 nAlgorithmType2;
+    switch (rOptions.algorithmType)
+    {
+        case SearchAlgorithms_REGEXP:
+            nAlgorithmType2 = SearchAlgorithms2::REGEXP;
+            break;
+        case SearchAlgorithms_APPROXIMATE:
+            nAlgorithmType2 = SearchAlgorithms2::APPROXIMATE;
+            break;
+        case SearchAlgorithms_ABSOLUTE:
+            nAlgorithmType2 = SearchAlgorithms2::ABSOLUTE;
+            break;
+        default:
+            for (;;) std::abort();
+    }
+    // It would be nice if an inherited struct had a ctor that takes an
+    // instance of the object the struct derived from..
+    i18nutil::SearchOptions2 aOptions2(
+            rOptions.algorithmType,
+            rOptions.searchFlag,
+            rOptions.searchString,
+            rOptions.replaceString,
+            rOptions.Locale,
+            rOptions.changedChars,
+            rOptions.deletedChars,
+            rOptions.insertedChars,
+            rOptions.transliterateFlags,
+            nAlgorithmType2,
+            0       // no wildcard search, no escape character..
+            );
+    return aOptions2;
+}
+
 void TextSearch::Init( const SearchParam & rParam,
                         const css::lang::Locale& rLocale )
 {
-    // convert SearchParam to the UNO SearchOptions
-    SearchOptions aSOpt;
+    // convert SearchParam to the UNO SearchOptions2
+    i18nutil::SearchOptions2 aSOpt;
 
     switch( rParam.GetSrchType() )
     {
-    case SearchParam::SRCH_REGEXP:
+    case SearchParam::SearchType::Wildcard:
+        aSOpt.AlgorithmType2 = SearchAlgorithms2::WILDCARD;
+        aSOpt.algorithmType = SearchAlgorithms::SearchAlgorithms_MAKE_FIXED_SIZE;    // no old enum for that
+        aSOpt.WildcardEscapeCharacter = rParam.GetWildEscChar();
+        if (rParam.IsWildMatchSel())
+            aSOpt.searchFlag |= SearchFlags::WILD_MATCH_SELECTION;
+        break;
+
+    case SearchParam::SearchType::Regexp:
+        aSOpt.AlgorithmType2 = SearchAlgorithms2::REGEXP;
         aSOpt.algorithmType = SearchAlgorithms_REGEXP;
         if( rParam.IsSrchInSelection() )
             aSOpt.searchFlag |= SearchFlags::REG_NOT_BEGINOFLINE |
                                 SearchFlags::REG_NOT_ENDOFLINE;
         break;
 
-    case SearchParam::SRCH_LEVDIST:
-        aSOpt.algorithmType = SearchAlgorithms_APPROXIMATE;
-        aSOpt.changedChars = rParam.GetLEVOther();
-        aSOpt.deletedChars = rParam.GetLEVLonger();
-        aSOpt.insertedChars = rParam.GetLEVShorter();
-        if( rParam.IsSrchRelaxed() )
-            aSOpt.searchFlag |= SearchFlags::LEV_RELAXED;
-        break;
-
-//  case SearchParam::SRCH_NORMAL:
-    default:
+    case SearchParam::SearchType::Normal:
+        aSOpt.AlgorithmType2 = SearchAlgorithms2::ABSOLUTE;
         aSOpt.algorithmType = SearchAlgorithms_ABSOLUTE;
         if( rParam.IsSrchWordOnly() )
             aSOpt.searchFlag |= SearchFlags::NORM_WORD_ONLY;
         break;
+
+    default:
+        for (;;) std::abort();
     }
     aSOpt.searchString = rParam.GetSrchStr();
     aSOpt.replaceString = rParam.GetReplaceStr();
@@ -180,17 +222,16 @@ void TextSearch::Init( const SearchParam & rParam,
     if( !rParam.IsCaseSensitive() )
     {
         aSOpt.searchFlag |= SearchFlags::ALL_IGNORE_CASE;
-        aSOpt.transliterateFlags |= css::i18n::TransliterationModules_IGNORE_CASE;
+        aSOpt.transliterateFlags |= TransliterationFlags::IGNORE_CASE;
     }
 
     xTextSearch = getXTextSearch( aSOpt );
 }
 
-void TextSearch::SetLocale( const css::util::SearchOptions& rOptions,
+void TextSearch::SetLocale( const i18nutil::SearchOptions2& rOptions,
                             const css::lang::Locale& rLocale )
 {
-    // convert SearchParam to the UNO SearchOptions
-    SearchOptions aSOpt( rOptions );
+    i18nutil::SearchOptions2 aSOpt( rOptions );
     aSOpt.Locale = rLocale;
 
     xTextSearch = getXTextSearch( aSOpt );
@@ -266,7 +307,7 @@ bool TextSearch::SearchBackward( const OUString & rStr, sal_Int32* pStart,
     return bRet;
 }
 
-void TextSearch::ReplaceBackReferences( OUString& rReplaceStr, const OUString &rStr, const SearchResult& rResult )
+void TextSearch::ReplaceBackReferences( OUString& rReplaceStr, const OUString &rStr, const SearchResult& rResult ) const
 {
     if( rResult.subRegExpressions > 0 )
     {
