@@ -17,6 +17,10 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
+#include <sal/config.h>
+
+#include <com/sun/star/io/BufferSizeExceededException.hpp>
+#include <com/sun/star/io/NotConnectedException.hpp>
 #include <unotools/streamwrap.hxx>
 #include <tools/stream.hxx>
 
@@ -46,7 +50,6 @@ OInputStreamWrapper::~OInputStreamWrapper()
 }
 
 sal_Int32 SAL_CALL OInputStreamWrapper::readBytes(css::uno::Sequence< sal_Int8 >& aData, sal_Int32 nBytesToRead)
-                throw( css::io::NotConnectedException, css::io::BufferSizeExceededException, css::uno::RuntimeException, std::exception )
 {
     checkConnected();
 
@@ -55,26 +58,27 @@ sal_Int32 SAL_CALL OInputStreamWrapper::readBytes(css::uno::Sequence< sal_Int8 >
 
     ::osl::MutexGuard aGuard( m_aMutex );
 
-    aData.realloc(nBytesToRead);
+    if (aData.getLength() < nBytesToRead)
+        aData.realloc(nBytesToRead);
 
-    sal_uInt32 nRead = m_pSvStream->Read(static_cast<void*>(aData.getArray()), nBytesToRead);
+    sal_uInt32 nRead = m_pSvStream->ReadBytes(static_cast<void*>(aData.getArray()), nBytesToRead);
     checkError();
 
-    // Wenn gelesene Zeichen < MaxLength, css::uno::Sequence anpassen
-    if (nRead < (sal_uInt32)nBytesToRead)
+    // If read characters < MaxLength, adjust css::uno::Sequence
+    if (nRead < (std::size_t)aData.getLength())
         aData.realloc( nRead );
 
     return nRead;
 }
 
-sal_Int32 SAL_CALL OInputStreamWrapper::readSomeBytes(css::uno::Sequence< sal_Int8 >& aData, sal_Int32 nMaxBytesToRead) throw( css::io::NotConnectedException, css::io::BufferSizeExceededException, css::uno::RuntimeException, std::exception )
+sal_Int32 SAL_CALL OInputStreamWrapper::readSomeBytes(css::uno::Sequence< sal_Int8 >& aData, sal_Int32 nMaxBytesToRead)
 {
     checkError();
 
     if (nMaxBytesToRead < 0)
         throw css::io::BufferSizeExceededException(OUString(),static_cast<css::uno::XWeak*>(this));
 
-    if (m_pSvStream->IsEof())
+    if (m_pSvStream->eof())
     {
         aData.realloc(0);
         return 0;
@@ -83,7 +87,7 @@ sal_Int32 SAL_CALL OInputStreamWrapper::readSomeBytes(css::uno::Sequence< sal_In
         return readBytes(aData, nMaxBytesToRead);
 }
 
-void SAL_CALL OInputStreamWrapper::skipBytes(sal_Int32 nBytesToSkip) throw( css::io::NotConnectedException, css::io::BufferSizeExceededException, css::uno::RuntimeException, std::exception )
+void SAL_CALL OInputStreamWrapper::skipBytes(sal_Int32 nBytesToSkip)
 {
     ::osl::MutexGuard aGuard( m_aMutex );
     checkError();
@@ -92,7 +96,7 @@ void SAL_CALL OInputStreamWrapper::skipBytes(sal_Int32 nBytesToSkip) throw( css:
     checkError();
 }
 
-sal_Int32 SAL_CALL OInputStreamWrapper::available() throw( css::io::NotConnectedException, css::uno::RuntimeException, std::exception )
+sal_Int32 SAL_CALL OInputStreamWrapper::available()
 {
     ::osl::MutexGuard aGuard( m_aMutex );
     checkConnected();
@@ -110,7 +114,7 @@ sal_Int32 SAL_CALL OInputStreamWrapper::available() throw( css::io::NotConnected
     return nAvailable;
 }
 
-void SAL_CALL OInputStreamWrapper::closeInput() throw( css::io::NotConnectedException, css::uno::RuntimeException, std::exception )
+void SAL_CALL OInputStreamWrapper::closeInput()
 {
     ::osl::MutexGuard aGuard( m_aMutex );
     checkConnected();
@@ -138,6 +142,8 @@ void OInputStreamWrapper::checkError() const
 
 //= OSeekableInputStreamWrapper
 
+OSeekableInputStreamWrapper::~OSeekableInputStreamWrapper() = default;
+
 OSeekableInputStreamWrapper::OSeekableInputStreamWrapper(SvStream& _rStream)
 {
     SetStream( &_rStream, false );
@@ -148,7 +154,7 @@ OSeekableInputStreamWrapper::OSeekableInputStreamWrapper(SvStream* _pStream, boo
     SetStream( _pStream, _bOwner );
 }
 
-void SAL_CALL OSeekableInputStreamWrapper::seek( sal_Int64 _nLocation ) throw (IllegalArgumentException, IOException, RuntimeException, std::exception)
+void SAL_CALL OSeekableInputStreamWrapper::seek( sal_Int64 _nLocation )
 {
     ::osl::MutexGuard aGuard( m_aMutex );
     checkConnected();
@@ -157,7 +163,7 @@ void SAL_CALL OSeekableInputStreamWrapper::seek( sal_Int64 _nLocation ) throw (I
     checkError();
 }
 
-sal_Int64 SAL_CALL OSeekableInputStreamWrapper::getPosition(  ) throw (IOException, RuntimeException, std::exception)
+sal_Int64 SAL_CALL OSeekableInputStreamWrapper::getPosition(  )
 {
     ::osl::MutexGuard aGuard( m_aMutex );
     checkConnected();
@@ -167,7 +173,7 @@ sal_Int64 SAL_CALL OSeekableInputStreamWrapper::getPosition(  ) throw (IOExcepti
     return (sal_Int64)nPos;
 }
 
-sal_Int64 SAL_CALL OSeekableInputStreamWrapper::getLength(  ) throw (IOException, RuntimeException, std::exception)
+sal_Int64 SAL_CALL OSeekableInputStreamWrapper::getLength(  )
 {
     ::osl::MutexGuard aGuard( m_aMutex );
     checkConnected();
@@ -192,9 +198,9 @@ OOutputStreamWrapper::OOutputStreamWrapper(SvStream& _rStream):
 
 OOutputStreamWrapper::~OOutputStreamWrapper() {}
 
-void SAL_CALL OOutputStreamWrapper::writeBytes(const css::uno::Sequence< sal_Int8 >& aData) throw( css::io::NotConnectedException, css::io::BufferSizeExceededException, css::uno::RuntimeException, std::exception )
+void SAL_CALL OOutputStreamWrapper::writeBytes(const css::uno::Sequence< sal_Int8 >& aData)
 {
-    sal_uInt32 nWritten = rStream.Write(aData.getConstArray(),aData.getLength());
+    sal_uInt32 nWritten = rStream.WriteBytes(aData.getConstArray(), aData.getLength());
     ErrCode err = rStream.GetError();
     if  (   (ERRCODE_NONE != err)
         ||  (nWritten != (sal_uInt32)aData.getLength())
@@ -204,13 +210,13 @@ void SAL_CALL OOutputStreamWrapper::writeBytes(const css::uno::Sequence< sal_Int
     }
 }
 
-void SAL_CALL OOutputStreamWrapper::flush() throw( css::io::NotConnectedException, css::io::BufferSizeExceededException, css::uno::RuntimeException, std::exception )
+void SAL_CALL OOutputStreamWrapper::flush()
 {
     rStream.Flush();
     checkError();
 }
 
-void SAL_CALL OOutputStreamWrapper::closeOutput() throw( css::io::NotConnectedException, css::io::BufferSizeExceededException, css::uno::RuntimeException, std::exception )
+void SAL_CALL OOutputStreamWrapper::closeOutput()
 {
 }
 
@@ -230,7 +236,7 @@ OSeekableOutputStreamWrapper::OSeekableOutputStreamWrapper(SvStream& _rStream)
 
 OSeekableOutputStreamWrapper::~OSeekableOutputStreamWrapper() {}
 
-Any SAL_CALL OSeekableOutputStreamWrapper::queryInterface( const Type& _rType ) throw (RuntimeException, std::exception)
+Any SAL_CALL OSeekableOutputStreamWrapper::queryInterface( const Type& _rType )
 {
     Any aReturn = OOutputStreamWrapper::queryInterface(_rType);
     if (!aReturn.hasValue())
@@ -248,20 +254,20 @@ void SAL_CALL OSeekableOutputStreamWrapper::release(  ) throw ()
     OOutputStreamWrapper::release();
 }
 
-void SAL_CALL OSeekableOutputStreamWrapper::seek( sal_Int64 _nLocation ) throw (IllegalArgumentException, IOException, RuntimeException, std::exception)
+void SAL_CALL OSeekableOutputStreamWrapper::seek( sal_Int64 _nLocation )
 {
     rStream.Seek((sal_uInt32)_nLocation);
     checkError();
 }
 
-sal_Int64 SAL_CALL OSeekableOutputStreamWrapper::getPosition(  ) throw (IOException, RuntimeException, std::exception)
+sal_Int64 SAL_CALL OSeekableOutputStreamWrapper::getPosition(  )
 {
     sal_uInt32 nPos = rStream.Tell();
     checkError();
     return (sal_Int64)nPos;
 }
 
-sal_Int64 SAL_CALL OSeekableOutputStreamWrapper::getLength(  ) throw (IOException, RuntimeException, std::exception)
+sal_Int64 SAL_CALL OSeekableOutputStreamWrapper::getLength(  )
 {
     sal_uInt32 nCurrentPos = rStream.Tell();
     checkError();
@@ -275,24 +281,26 @@ sal_Int64 SAL_CALL OSeekableOutputStreamWrapper::getLength(  ) throw (IOExceptio
     return (sal_Int64)nEndPos;
 }
 
+OStreamWrapper::~OStreamWrapper() = default;
+
 OStreamWrapper::OStreamWrapper(SvStream& _rStream)
 {
     SetStream( &_rStream, false );
 }
 
-css::uno::Reference< css::io::XInputStream > SAL_CALL OStreamWrapper::getInputStream(  ) throw (css::uno::RuntimeException, std::exception)
+css::uno::Reference< css::io::XInputStream > SAL_CALL OStreamWrapper::getInputStream(  )
 {
     return this;
 }
 
-css::uno::Reference< css::io::XOutputStream > SAL_CALL OStreamWrapper::getOutputStream(  ) throw (css::uno::RuntimeException, std::exception)
+css::uno::Reference< css::io::XOutputStream > SAL_CALL OStreamWrapper::getOutputStream(  )
 {
     return this;
 }
 
-void SAL_CALL OStreamWrapper::writeBytes(const css::uno::Sequence< sal_Int8 >& aData) throw(css::io::NotConnectedException, css::io::BufferSizeExceededException, css::uno::RuntimeException, std::exception)
+void SAL_CALL OStreamWrapper::writeBytes(const css::uno::Sequence< sal_Int8 >& aData)
 {
-    sal_uInt32 nWritten = m_pSvStream->Write(aData.getConstArray(),aData.getLength());
+    sal_uInt32 nWritten = m_pSvStream->WriteBytes(aData.getConstArray(), aData.getLength());
     ErrCode err = m_pSvStream->GetError();
     if  (   (ERRCODE_NONE != err)
         ||  (nWritten != (sal_uInt32)aData.getLength())
@@ -302,18 +310,18 @@ void SAL_CALL OStreamWrapper::writeBytes(const css::uno::Sequence< sal_Int8 >& a
     }
 }
 
-void SAL_CALL OStreamWrapper::flush() throw(css::io::NotConnectedException, css::io::BufferSizeExceededException, css::uno::RuntimeException, std::exception)
+void SAL_CALL OStreamWrapper::flush()
 {
     m_pSvStream->Flush();
     if (m_pSvStream->GetError() != ERRCODE_NONE)
         throw css::io::NotConnectedException(OUString(),static_cast<css::uno::XWeak*>(this));
 }
 
-void SAL_CALL OStreamWrapper::closeOutput() throw(css::io::NotConnectedException, css::io::BufferSizeExceededException, css::uno::RuntimeException, std::exception)
+void SAL_CALL OStreamWrapper::closeOutput()
 {
 }
 
-void SAL_CALL OStreamWrapper::truncate() throw(css::io::IOException, css::uno::RuntimeException, std::exception)
+void SAL_CALL OStreamWrapper::truncate()
 {
     m_pSvStream->SetStreamSize(0);
 }
