@@ -20,15 +20,17 @@
 #include <rtl/ustring.hxx>
 #include <unotools/ucbstreamhelper.hxx>
 #include <comphelper/processfactory.hxx>
+#include <com/sun/star/task/InteractionHandler.hpp>
 #include <com/sun/star/ucb/CommandAbortedException.hpp>
 #include <com/sun/star/ucb/UniversalContentBroker.hpp>
 #include <com/sun/star/ucb/XCommandEnvironment.hpp>
 #include <com/sun/star/ucb/InsertCommandArgument.hpp>
 #include <com/sun/star/io/XActiveDataStreamer.hpp>
 
+#include <comphelper/simplefileaccessinteraction.hxx>
 #include <ucbhelper/content.hxx>
 #include <unotools/streamwrap.hxx>
-#include <ucblockbytes.hxx>
+#include "ucblockbytes.hxx"
 
 using namespace ::com::sun::star::uno;
 using namespace ::com::sun::star::io;
@@ -41,13 +43,10 @@ namespace utl
 {
 
 static SvStream* lcl_CreateStream( const OUString& rFileName, StreamMode eOpenMode,
-                                   Reference < XInteractionHandler > xInteractionHandler,
-                                   UcbLockBytesHandler* pHandler, bool bEnsureFileExists )
+                                   const Reference < XInteractionHandler >& xInteractionHandler,
+                                   bool bEnsureFileExists )
 {
     SvStream* pStream = nullptr;
-    Reference< XUniversalContentBroker > ucb(
-        UniversalContentBroker::create(
-            comphelper::getProcessComponentContext() ) );
     UcbLockBytesRef xLockBytes;
     if ( eOpenMode & StreamMode::WRITE )
     {
@@ -90,7 +89,7 @@ static SvStream* lcl_CreateStream( const OUString& rFileName, StreamMode eOpenMo
                 InsertCommandArgument aInsertArg;
                 aInsertArg.Data = xInput;
 
-                aInsertArg.ReplaceExisting = sal_False;
+                aInsertArg.ReplaceExisting = false;
                 Any aCmdArg;
                 aCmdArg <<= aInsertArg;
                 aContent.executeCommand( "insert", aCmdArg );
@@ -117,10 +116,10 @@ static SvStream* lcl_CreateStream( const OUString& rFileName, StreamMode eOpenMo
             rFileName, Reference < XCommandEnvironment >(),
             comphelper::getProcessComponentContext() );
         xLockBytes = UcbLockBytes::CreateLockBytes( aContent.get(), Sequence < PropertyValue >(),
-                                                    eOpenMode, xInteractionHandler, pHandler );
-        if ( xLockBytes.Is() )
+                                                    eOpenMode, xInteractionHandler );
+        if ( xLockBytes.is() )
         {
-            pStream = new SvStream( xLockBytes );
+            pStream = new SvStream( xLockBytes.get() );
             pStream->SetBufferSize( 4096 );
             pStream->SetError( xLockBytes->GetError() );
         }
@@ -138,33 +137,38 @@ static SvStream* lcl_CreateStream( const OUString& rFileName, StreamMode eOpenMo
     return pStream;
 }
 
-SvStream* UcbStreamHelper::CreateStream( const OUString& rFileName, StreamMode eOpenMode,
-                                         UcbLockBytesHandler* pHandler )
+SvStream* UcbStreamHelper::CreateStream( const OUString& rFileName, StreamMode eOpenMode )
 {
-    return lcl_CreateStream( rFileName, eOpenMode, Reference < XInteractionHandler >(), pHandler, true /* bEnsureFileExists */ );
+    // related tdf#99312
+    // create a specialized interaction handler to manages Web certificates and Web credentials when needed
+    Reference< XInteractionHandler > xIH(
+        css::task::InteractionHandler::createWithParent( comphelper::getProcessComponentContext(), nullptr ) );
+    Reference < XInteractionHandler > xIHScoped( static_cast< XInteractionHandler *> (
+                                                     new comphelper::SimpleFileAccessInteraction( xIH ) ) );
+
+    return lcl_CreateStream( rFileName, eOpenMode, xIHScoped, true /* bEnsureFileExists */ );
 }
 
 SvStream* UcbStreamHelper::CreateStream( const OUString& rFileName, StreamMode eOpenMode,
-                                         Reference < XInteractionHandler > xInteractionHandler,
-                                         UcbLockBytesHandler* pHandler )
+                                         bool bFileExists )
 {
-    return lcl_CreateStream( rFileName, eOpenMode, xInteractionHandler, pHandler, true /* bEnsureFileExists */ );
+    // related tdf#99312
+    // create a specialized interaction handler to manages Web certificates and Web credentials when needed
+    Reference< XInteractionHandler > xIH(
+        css::task::InteractionHandler::createWithParent( comphelper::getProcessComponentContext(), nullptr ) );
+    Reference < XInteractionHandler > xIHScoped( static_cast< XInteractionHandler *> (
+                                                     new comphelper::SimpleFileAccessInteraction( xIH ) ) );
+    return lcl_CreateStream( rFileName, eOpenMode, xIHScoped,!bFileExists );
 }
 
-SvStream* UcbStreamHelper::CreateStream( const OUString& rFileName, StreamMode eOpenMode,
-                                         bool bFileExists,
-                                         UcbLockBytesHandler* pHandler )
-{
-    return lcl_CreateStream( rFileName, eOpenMode, Reference < XInteractionHandler >(), pHandler, !bFileExists );
-}
 
-SvStream* UcbStreamHelper::CreateStream( Reference < XInputStream > xStream )
+SvStream* UcbStreamHelper::CreateStream( const Reference < XInputStream >& xStream )
 {
     SvStream* pStream = nullptr;
     UcbLockBytesRef xLockBytes = UcbLockBytes::CreateInputLockBytes( xStream );
-    if ( xLockBytes.Is() )
+    if ( xLockBytes.is() )
     {
-        pStream = new SvStream( xLockBytes );
+        pStream = new SvStream( xLockBytes.get() );
         pStream->SetBufferSize( 4096 );
         pStream->SetError( xLockBytes->GetError() );
     }
@@ -172,15 +176,15 @@ SvStream* UcbStreamHelper::CreateStream( Reference < XInputStream > xStream )
     return pStream;
 }
 
-SvStream* UcbStreamHelper::CreateStream( Reference < XStream > xStream )
+SvStream* UcbStreamHelper::CreateStream( const Reference < XStream >& xStream )
 {
     SvStream* pStream = nullptr;
     if ( xStream->getOutputStream().is() )
     {
         UcbLockBytesRef xLockBytes = UcbLockBytes::CreateLockBytes( xStream );
-        if ( xLockBytes.Is() )
+        if ( xLockBytes.is() )
         {
-            pStream = new SvStream( xLockBytes );
+            pStream = new SvStream( xLockBytes.get() );
             pStream->SetBufferSize( 4096 );
             pStream->SetError( xLockBytes->GetError() );
         }
@@ -191,16 +195,16 @@ SvStream* UcbStreamHelper::CreateStream( Reference < XStream > xStream )
     return pStream;
 }
 
-SvStream* UcbStreamHelper::CreateStream( Reference < XInputStream > xStream, bool bCloseStream )
+SvStream* UcbStreamHelper::CreateStream( const Reference < XInputStream >& xStream, bool bCloseStream )
 {
     SvStream* pStream = nullptr;
     UcbLockBytesRef xLockBytes = UcbLockBytes::CreateInputLockBytes( xStream );
-    if ( xLockBytes.Is() )
+    if ( xLockBytes.is() )
     {
         if ( !bCloseStream )
             xLockBytes->setDontClose_Impl();
 
-        pStream = new SvStream( xLockBytes );
+        pStream = new SvStream( xLockBytes.get() );
         pStream->SetBufferSize( 4096 );
         pStream->SetError( xLockBytes->GetError() );
     }
@@ -208,18 +212,18 @@ SvStream* UcbStreamHelper::CreateStream( Reference < XInputStream > xStream, boo
     return pStream;
 };
 
-SvStream* UcbStreamHelper::CreateStream( Reference < XStream > xStream, bool bCloseStream )
+SvStream* UcbStreamHelper::CreateStream( const Reference < XStream >& xStream, bool bCloseStream )
 {
     SvStream* pStream = nullptr;
     if ( xStream->getOutputStream().is() )
     {
         UcbLockBytesRef xLockBytes = UcbLockBytes::CreateLockBytes( xStream );
-        if ( xLockBytes.Is() )
+        if ( xLockBytes.is() )
         {
             if ( !bCloseStream )
                 xLockBytes->setDontClose_Impl();
 
-            pStream = new SvStream( xLockBytes );
+            pStream = new SvStream( xLockBytes.get() );
             pStream->SetBufferSize( 4096 );
             pStream->SetError( xLockBytes->GetError() );
         }
