@@ -28,10 +28,10 @@
 // Horrible hack
 static int viewWidth = 1, viewHeight = 1;
 
-class AndroidSalData : public SalGenericData
+class AndroidSalData : public GenericUnixSalData
 {
 public:
-    explicit AndroidSalData( SalInstance *pInstance ) : SalGenericData( SAL_DATA_ANDROID, pInstance ) {}
+    explicit AndroidSalData( SalInstance *pInstance ) : GenericUnixSalData( SAL_DATA_ANDROID, pInstance ) {}
     virtual void ErrorTrapPush() {}
     virtual bool ErrorTrapPop( bool ) { return false; }
 };
@@ -73,7 +73,7 @@ bool AndroidSalInstance::AnyInput( VclInputFlags nType )
 
     // Unfortunately there is no way to check for a specific type of
     // input being queued. That information is too hidden, sigh.
-    return SvpSalInstance::s_pDefaultInstance->PostedEventsInQueue();
+    return SvpSalInstance::s_pDefaultInstance->HasUserEvents();
 }
 
 class AndroidSalSystem : public SvpSalSystem {
@@ -82,8 +82,7 @@ public:
     virtual ~AndroidSalSystem() {}
     virtual int ShowNativeDialog( const OUString& rTitle,
                                   const OUString& rMessage,
-                                  const std::list< OUString >& rButtons,
-                                  int nDefButton );
+                                  const std::vector< OUString >& rButtons );
 };
 
 SalSystem *AndroidSalInstance::CreateSalSystem()
@@ -178,7 +177,6 @@ const OUString& SalGetDesktopEnvironment()
 
 SalData::SalData() :
     m_pInstance( 0 ),
-    m_pPlugin( 0 ),
     m_pPIManager(0 )
 {
 }
@@ -193,22 +191,21 @@ SalInstance *CreateSalInstance()
     LOGI("Android: CreateSalInstance!");
     AndroidSalInstance* pInstance = new AndroidSalInstance( new SalYieldMutex() );
     new AndroidSalData( pInstance );
-    pInstance->AcquireYieldMutex(1);
+    pInstance->AcquireYieldMutex();
     return pInstance;
 }
 
 void DestroySalInstance( SalInstance *pInst )
 {
-    pInst->ReleaseYieldMutex();
+    pInst->ReleaseYieldMutexAll();
     delete pInst;
 }
 
 int AndroidSalSystem::ShowNativeDialog( const OUString& rTitle,
                                         const OUString& rMessage,
-                                        const std::list< OUString >& rButtons,
-                                        int nDefButton )
+                                        const std::vector< OUString >& rButtons )
 {
-    (void)rButtons; (void)nDefButton;
+    (void)rButtons;
     LOGI("LibreOffice native dialog '%s': '%s'",
          OUStringToOString(rTitle, RTL_TEXTENCODING_ASCII_US).getStr(),
          OUStringToOString(rMessage, RTL_TEXTENCODING_ASCII_US).getStr());
