@@ -26,12 +26,12 @@
 #include <vcl/svapp.hxx>
 #include <vcl/window.hxx>
 
-#include "osx/a11yfactory.h"
-#include "osx/salframe.h"
-#include "osx/salframeview.h"
-#include "osx/salinst.h"
-#include "quartz/salgdi.h"
-#include "quartz/utils.h"
+#include <osx/a11yfactory.h>
+#include <osx/salframe.h>
+#include <osx/salframeview.h>
+#include <osx/salinst.h>
+#include <quartz/salgdi.h>
+#include <quartz/utils.h>
 
 #define WHEEL_EVENT_FACTOR 1.5
 
@@ -196,7 +196,7 @@ static AquaSalFrame* getMouseContainerFrame()
 
     // enable OSX>=10.7 fullscreen options if available and useful
     bool bAllowFullScreen = (SalFrameStyleFlags::NONE == (mpFrame->mnStyle & (SalFrameStyleFlags::DIALOG | SalFrameStyleFlags::TOOLTIP | SalFrameStyleFlags::SYSTEMCHILD | SalFrameStyleFlags::FLOAT | SalFrameStyleFlags::TOOLWINDOW | SalFrameStyleFlags::INTRO)));
-    bAllowFullScreen &= (SalFrameStyleFlags::NONE == (~mpFrame->mnStyle & (SalFrameStyleFlags::SIZEABLE)));
+    bAllowFullScreen &= (SalFrameStyleFlags::NONE == (~mpFrame->mnStyle & SalFrameStyleFlags::SIZEABLE));
     bAllowFullScreen &= (mpFrame->mpParent == nullptr);
     const SEL setCollectionBehavior = @selector(setCollectionBehavior:);
     if( bAllowFullScreen && [pNSWindow respondsToSelector: setCollectionBehavior])
@@ -221,15 +221,10 @@ static AquaSalFrame* getMouseContainerFrame()
 
 -(void)displayIfNeeded
 {
-    if( GetSalData() && GetSalData()->mpFirstInstance )
+    if( GetSalData() && GetSalData()->mpInstance )
     {
-        comphelper::SolarMutex* pMutex = GetSalData()->mpFirstInstance->GetYieldMutex();
-        if( pMutex )
-        {
-            pMutex->acquire();
-            [super displayIfNeeded];
-            pMutex->release();
-        }
+        SolarMutexGuard aGuard;
+        [super displayIfNeeded];
     }
 }
 
@@ -374,6 +369,9 @@ static AquaSalFrame* getMouseContainerFrame()
         {
             mpFrame->CallCallback( SalEvent::Close, nullptr );
             bRet = NO; // application will close the window or not, AppKit shouldn't
+            AquaSalTimer *pTimer = static_cast<AquaSalTimer*>( ImplGetSVData()->maSchedCtx.mpSalTimer );
+            assert( pTimer );
+            pTimer->handleWindowShouldClose();
         }
     }
 
@@ -533,6 +531,17 @@ private:
 
 -(void)drawRect: (NSRect)aRect
 {
+    if( GetSalData()->mpInstance )
+    {
+        const bool bIsLiveResize = [self inLiveResize];
+        const bool bWasLiveResize = GetSalData()->mpInstance->mbIsLiveResize;
+        if ( bWasLiveResize != bIsLiveResize )
+        {
+            GetSalData()->mpInstance->mbIsLiveResize = bIsLiveResize;
+            Scheduler::ProcessTaskScheduling();
+        }
+    }
+
     // HOTFIX: #i93512# prevent deadlocks if any other thread already has the SalYieldMutex
     TryGuard aTryGuard;
     if( !aTryGuard.IsGuarded() )
@@ -1515,22 +1524,21 @@ SAL_WNODEPRECATED_DECLARATIONS_POP
 {
     SolarMutexGuard aGuard;
 
-    long nRet = 0;
+    bool nRet = false;
     if( AquaSalFrame::isAlive( mpFrame ) )
     {
         SalKeyEvent aEvent;
-        aEvent.mnTime           = mpFrame->mnLastEventTime;
         aEvent.mnCode           = nKeyCode | ImplGetModifierMask( nMod );
         aEvent.mnCharCode       = aChar;
         aEvent.mnRepeat         = FALSE;
         nRet = mpFrame->CallCallback( SalEvent::KeyInput, &aEvent );
         std::map< NSEvent*, bool >::iterator it = GetSalData()->maKeyEventAnswer.find( mpLastEvent );
         if( it != GetSalData()->maKeyEventAnswer.end() )
-            it->second = nRet != 0;
+            it->second = nRet;
         if( AquaSalFrame::isAlive( mpFrame ) )
             mpFrame->CallCallback( SalEvent::KeyUp, &aEvent );
     }
-    return nRet ? YES : NO;
+    return nRet;
 }
 
 
