@@ -21,38 +21,44 @@
 
 #include <comphelper/processfactory.hxx>
 #include <comphelper/string.hxx>
-#include <osl/mutex.hxx>
 #include <rtl/process.h>
-#include <tools/debug.hxx>
-#include <tools/resary.hxx>
 #include <tools/gen.hxx>
+#include <unotools/resmgr.hxx>
 #include <uno/current_context.hxx>
 
-#include "vcl/configsettings.hxx"
-#include "vcl/svapp.hxx"
-#include "vcl/settings.hxx"
-#include "vcl/wrkwin.hxx"
-#include "vcl/layout.hxx"
-#include "vcl/button.hxx"
-#include "vcl/dockwin.hxx"
-#include "vcl/print.hxx"
-#include "vcl/virdev.hxx"
-#include "salinst.hxx"
-#include "salframe.hxx"
-#include "salgdi.hxx"
-#include "svdata.hxx"
-#include "window.h"
-#include "salimestatus.hxx"
-#include "salsys.hxx"
-#include "svids.hrc"
-#include "helpwin.hxx"
-#include "../window/scrwnd.hxx"
+#include <vcl/button.hxx>
+#include <vcl/configsettings.hxx>
+#include <vcl/dockwin.hxx>
+#include <vcl/layout.hxx>
+#include <vcl/menu.hxx>
+#include <vcl/print.hxx>
+#include <vcl/settings.hxx>
+#include <vcl/svapp.hxx>
+#include <vcl/virdev.hxx>
+#include <vcl/wrkwin.hxx>
+#include <vcl/uitest/logger.hxx>
+#include <scrwnd.hxx>
+#include <helpwin.hxx>
+#include <vcl/dialog.hxx>
+#include <salinst.hxx>
+#include <salframe.hxx>
+#include <salgdi.hxx>
+#include <svdata.hxx>
+#include <window.h>
+#include <salimestatus.hxx>
+#include <salsys.hxx>
+#include <strings.hrc>
+#include <units.hrc>
 
-#include "com/sun/star/accessibility/MSAAService.hpp"
+#include <com/sun/star/accessibility/MSAAService.hpp>
 
-#include "officecfg/Office/Common.hxx"
+#include <officecfg/Office/Common.hxx>
 
-#include "vcl/opengl/OpenGLContext.hxx"
+#include <config_folders.h>
+#include <config_features.h>
+#if HAVE_FEATURE_OPENGL
+#include <vcl/opengl/OpenGLContext.hxx>
+#endif
 
 using namespace com::sun::star::uno;
 using namespace com::sun::star::lang;
@@ -76,41 +82,38 @@ SalSystem* ImplGetSalSystem()
     return pSVData->mpSalSystem;
 }
 
-ImplSVData::ImplSVData()
-{
-    // init global instance data
-    memset( this, 0, sizeof( ImplSVData ) );
-    maHelpData.mbAutoHelpId = true;
-    maNWFData.maMenuBarHighlightTextColor = Color( COL_TRANSPARENT );
-    maNWFData.mbEnableAccel = true;
-    maNWFData.mbAutoAccel = false;
-}
-
-ImplSVGDIData::~ImplSVGDIData()
-{
-    // FIXME: deliberately leak any remaining OutputDevice
-    // until we have their pGraphics reference counted, doing
-    // any disposes so late in shutdown is rather unsafe.
-    memset( this, 0, sizeof( ImplSVGDIData ) );
-}
-
 void ImplDeInitSVData()
 {
     ImplSVData* pSVData = ImplGetSVData();
 
     // delete global instance data
     if( pSVData->mpSettingsConfigItem )
+    {
         delete pSVData->mpSettingsConfigItem;
+        pSVData->mpSettingsConfigItem = nullptr;
+    }
 
     if( pSVData->mpDockingManager )
+    {
         delete pSVData->mpDockingManager;
+        pSVData->mpDockingManager = nullptr;
+    }
 
     if( pSVData->maCtrlData.mpFieldUnitStrings )
-        delete pSVData->maCtrlData.mpFieldUnitStrings, pSVData->maCtrlData.mpFieldUnitStrings = nullptr;
+    {
+        delete pSVData->maCtrlData.mpFieldUnitStrings;
+        pSVData->maCtrlData.mpFieldUnitStrings = nullptr;
+    }
     if( pSVData->maCtrlData.mpCleanUnitStrings )
-        delete pSVData->maCtrlData.mpCleanUnitStrings, pSVData->maCtrlData.mpCleanUnitStrings = nullptr;
+    {
+        delete pSVData->maCtrlData.mpCleanUnitStrings;
+        pSVData->maCtrlData.mpCleanUnitStrings = nullptr;
+    }
     if( pSVData->mpPaperNames )
-        delete pSVData->mpPaperNames, pSVData->mpPaperNames = nullptr;
+    {
+        delete pSVData->mpPaperNames;
+        pSVData->mpPaperNames = nullptr;
+    }
 }
 
 /// Returns either the application window, or the default GL context window
@@ -133,52 +136,46 @@ vcl::Window *ImplGetDefaultContextWindow()
     {
         SolarMutexGuard aGuard;
 
-        if ( !pSVData->mpDefaultWin && !pSVData->mbDeInit )
+        if (!pSVData->mpDefaultWin && !pSVData->mbDeInit)
         {
-            SAL_INFO( "vcl", "ImplGetDefaultWindow(): No AppWindow" );
-            pSVData->mpDefaultWin = VclPtr<WorkWindow>::Create( nullptr, WB_DEFAULTWIN );
-            pSVData->mpDefaultWin->SetText( "VCL ImplGetDefaultWindow" );
+            try
+            {
+                SAL_INFO( "vcl", "ImplGetDefaultWindow(): No AppWindow" );
 
-            // Add a reference to the default context so it never gets deleted
-            rtl::Reference<OpenGLContext> pContext = pSVData->mpDefaultWin->GetGraphics()->GetOpenGLContext();
-            if( pContext.is() )
-                pContext->acquire();
+                pSVData->mpDefaultWin = VclPtr<WorkWindow>::Create( nullptr, WB_DEFAULTWIN );
+                pSVData->mpDefaultWin->SetText( "VCL ImplGetDefaultWindow" );
+
+#if HAVE_FEATURE_OPENGL
+                // Add a reference to the default context so it never gets deleted
+                rtl::Reference<OpenGLContext> pContext = pSVData->mpDefaultWin->GetGraphics()->GetOpenGLContext();
+                if( pContext.is() )
+                    pContext->acquire();
+#endif
+            }
+            catch (const css::uno::Exception& e)
+            {
+                 SAL_WARN("vcl", "unable to create Default Window: " << e);
+            }
         }
     }
 
     return pSVData->mpDefaultWin;
 }
 
-ResMgr* ImplGetResMgr()
+const std::locale& ImplGetResLocale()
 {
     ImplSVData* pSVData = ImplGetSVData();
-    if ( !pSVData->mpResMgr )
+    if (!pSVData->mbResLocaleSet)
     {
-        LanguageTag aLocale( Application::GetSettings().GetUILanguageTag());
-        pSVData->mpResMgr = ResMgr::SearchCreateResMgr( "vcl", aLocale );
-
-        static bool bMessageOnce = false;
-        if( !pSVData->mpResMgr && ! bMessageOnce )
-        {
-            bMessageOnce = true;
-            const char* pMsg =
-                "Missing vcl resource. This indicates that files vital to localization are missing. "
-                "You might have a corrupt installation.";
-            SAL_WARN("vcl", "" << pMsg << "\n");
-            ScopedVclPtrInstance< MessageDialog > aBox( nullptr, OUString(pMsg, strlen(pMsg), RTL_TEXTENCODING_ASCII_US) );
-            aBox->Execute();
-        }
+        pSVData->maResLocale = Translate::Create("vcl");
+        pSVData->mbResLocaleSet = true;
     }
-    return pSVData->mpResMgr;
+    return pSVData->maResLocale;
 }
 
-ResId VclResId( sal_Int32 nId )
+OUString VclResId(const char* pId)
 {
-    ResMgr* pMgr = ImplGetResMgr();
-    if( ! pMgr )
-        throw std::bad_alloc();
-
-    return ResId( nId, *pMgr );
+    return Translate::get(pId, ImplGetResLocale());
 }
 
 FieldUnitStringList* ImplGetFieldUnits()
@@ -186,18 +183,13 @@ FieldUnitStringList* ImplGetFieldUnits()
     ImplSVData* pSVData = ImplGetSVData();
     if( ! pSVData->maCtrlData.mpFieldUnitStrings )
     {
-        ResMgr* pResMgr = ImplGetResMgr();
-        if( pResMgr )
+        sal_uInt32 nUnits = SAL_N_ELEMENTS(SV_FUNIT_STRINGS);
+        pSVData->maCtrlData.mpFieldUnitStrings = new FieldUnitStringList;
+        pSVData->maCtrlData.mpFieldUnitStrings->reserve( nUnits );
+        for (sal_uInt32 i = 0; i < nUnits; i++)
         {
-            ResStringArray aUnits( ResId (SV_FUNIT_STRINGS, *pResMgr) );
-            sal_uInt32 nUnits = aUnits.Count();
-            pSVData->maCtrlData.mpFieldUnitStrings = new FieldUnitStringList();
-            pSVData->maCtrlData.mpFieldUnitStrings->reserve( nUnits );
-            for( sal_uInt32 i = 0; i < nUnits; i++ )
-            {
-                std::pair< OUString, FieldUnit > aElement( aUnits.GetString(i), static_cast<FieldUnit>(aUnits.GetValue(i)) );
-                pSVData->maCtrlData.mpFieldUnitStrings->push_back( aElement );
-            }
+            std::pair<OUString, FieldUnit> aElement(VclResId(SV_FUNIT_STRINGS[i].first), SV_FUNIT_STRINGS[i].second);
+            pSVData->maCtrlData.mpFieldUnitStrings->push_back( aElement );
         }
     }
     return pSVData->maCtrlData.mpFieldUnitStrings;
@@ -212,12 +204,12 @@ FieldUnitStringList* ImplGetCleanedFieldUnits()
         if( pUnits )
         {
             size_t nUnits = pUnits->size();
-            pSVData->maCtrlData.mpCleanUnitStrings = new FieldUnitStringList();
+            pSVData->maCtrlData.mpCleanUnitStrings = new FieldUnitStringList;
             pSVData->maCtrlData.mpCleanUnitStrings->reserve( nUnits );
             for( size_t i = 0; i < nUnits; ++i )
             {
                 OUString aUnit( (*pUnits)[i].first );
-                aUnit = comphelper::string::remove(aUnit, ' ');
+                aUnit = aUnit.replaceAll(" ", "");
                 aUnit = aUnit.toAsciiLowerCase();
                 std::pair< OUString, FieldUnit > aElement( aUnit, (*pUnits)[i].second );
                 pSVData->maCtrlData.mpCleanUnitStrings->push_back( aElement );
@@ -245,10 +237,6 @@ BlendFrameCache* ImplGetBlendFrameCache()
     return pSVData->mpBlendFrameCache;
 }
 
-#ifdef _WIN32
-bool HasAtHook();
-#endif
-
 #ifdef _WIN32
 bool ImplInitAccessBridge()
 {
@@ -272,7 +260,7 @@ bool ImplInitAccessBridge()
              } catch (css::uno::DeploymentException & e) {
                  SAL_WARN(
                     "vcl",
-                    "got no IAccessible2 bridge" << e.Message);
+                    "got no IAccessible2 bridge" << e);
                  return false;
              }
         }
@@ -282,9 +270,16 @@ bool ImplInitAccessBridge()
 }
 #endif
 
-void LocaleConfigurationListener::ConfigurationChanged( utl::ConfigurationBroadcaster*, sal_uInt32 nHint )
+void LocaleConfigurationListener::ConfigurationChanged( utl::ConfigurationBroadcaster*, ConfigurationHints nHint )
 {
     AllSettings::LocaleSettingsChanged( nHint );
 }
 
+
+ImplSVData::~ImplSVData() {}
+ImplSVAppData::~ImplSVAppData() {}
+ImplSVGDIData::~ImplSVGDIData() {}
+ImplSVWinData::~ImplSVWinData() {}
+ImplSVHelpData::~ImplSVHelpData() {}
+
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
