@@ -24,30 +24,41 @@
 #include <osl/file.hxx>
 #include <osl/signal.h>
 
-#include "tools/debug.hxx"
-#include "tools/resmgr.hxx"
+#include <desktop/exithelper.h>
 
-#include "comphelper/processfactory.hxx"
+#include <tools/debug.hxx>
+#include <unotools/resmgr.hxx>
 
-#include "unotools/syslocaleoptions.hxx"
-#include "vcl/svapp.hxx"
-#include "vcl/wrkwin.hxx"
-#include "vcl/cvtgrf.hxx"
-#include "vcl/scheduler.hxx"
-#include "vcl/image.hxx"
-#include "vcl/implimagetree.hxx"
-#include "vcl/settings.hxx"
-#include "vcl/unowrap.hxx"
-#include "vcl/commandinfoprovider.hxx"
-#include "vcl/configsettings.hxx"
-#include "vcl/lazydelete.hxx"
-#include "vcl/embeddedfontshelper.hxx"
-#include "vcl/debugevent.hxx"
+#include <comphelper/processfactory.hxx>
+#include <comphelper/asyncnotification.hxx>
 
-#ifdef WNT
+#include <unotools/syslocaleoptions.hxx>
+#include <vcl/svapp.hxx>
+#include <vcl/vclmain.hxx>
+#include <vcl/wrkwin.hxx>
+#include <vcl/cvtgrf.hxx>
+#include <vcl/scheduler.hxx>
+#include <vcl/image.hxx>
+#include <vcl/ImageTree.hxx>
+#include <vcl/settings.hxx>
+#include <vcl/unowrap.hxx>
+#include <vcl/commandinfoprovider.hxx>
+#include <vcl/configsettings.hxx>
+#include <vcl/lazydelete.hxx>
+#include <vcl/embeddedfontshelper.hxx>
+#include <vcl/debugevent.hxx>
+#include <vcl/dialog.hxx>
+#include <vcl/menu.hxx>
+#include <vcl/virdev.hxx>
+#include <vcl/print.hxx>
+#include <scrwnd.hxx>
+
+#ifdef _WIN32
 #include <svsys.h>
 #include <process.h>
 #include <ole2.h>
+#else
+#include <stdlib.h>
 #endif
 
 #ifdef ANDROID
@@ -55,97 +66,110 @@
 #include <jni.h>
 #endif
 
-#include "salinst.hxx"
-#include "salwtype.hxx"
-#include "svdata.hxx"
-#include "vcl/svmain.hxx"
-#include "dbggui.hxx"
-#include "accmgr.hxx"
-#include "idlemgr.hxx"
-#include "outdev.h"
-#include "outfont.hxx"
-#include "PhysicalFontCollection.hxx"
-#include "print.h"
-#include "salgdi.hxx"
-#include "salsys.hxx"
-#include "saltimer.hxx"
-#include "salimestatus.hxx"
-#include "xconnection.hxx"
+#include <salinst.hxx>
+#include <salwtype.hxx>
+#include <svdata.hxx>
+#include <vcl/svmain.hxx>
+#include <dbggui.hxx>
+#include <accmgr.hxx>
+#include <outdev.h>
+#include <fontinstance.hxx>
+#include <PhysicalFontCollection.hxx>
+#include <print.h>
+#include <salgdi.hxx>
+#include <salsys.hxx>
+#include <saltimer.hxx>
+#include <salimestatus.hxx>
+#include <displayconnectiondispatch.hxx>
 
-#include "vcl/opengl/OpenGLContext.hxx"
+#include <config_features.h>
+#if HAVE_FEATURE_OPENGL
+#include <vcl/opengl/OpenGLContext.hxx>
+#endif
 
-#include "osl/process.h"
-#include "com/sun/star/lang/XMultiServiceFactory.hpp"
-#include "com/sun/star/lang/XComponent.hpp"
-#include "com/sun/star/frame/Desktop.hpp"
+#include <osl/process.h>
+#include <com/sun/star/lang/XMultiServiceFactory.hpp>
+#include <com/sun/star/lang/XComponent.hpp>
+#include <com/sun/star/frame/Desktop.hpp>
 
+#include <comphelper/lok.hxx>
 #include <cppuhelper/implbase.hxx>
-#include "uno/current_context.hxx"
+#include <uno/current_context.hxx>
 
-#include "opengl/zone.hxx"
-#include "opengl/watchdog.hxx"
+#include <opencl/OpenCLZone.hxx>
+#include <opengl/zone.hxx>
+#include <opengl/watchdog.hxx>
 
 #if OSL_DEBUG_LEVEL > 0
 #include <typeinfo>
-#include "rtl/strbuf.hxx"
+#include <rtl/strbuf.hxx>
 #endif
 
 using namespace ::com::sun::star;
 
+static bool g_bIsLeanException;
+
+static bool isInitVCL();
+
 oslSignalAction SAL_CALL VCLExceptionSignal_impl( void* /*pData*/, oslSignalInfo* pInfo)
 {
-    static bool bIn = false;
+    static volatile bool bIn = false;
 
     // if we crash again, bail out immediately
-    if ( !bIn )
+    if ( bIn  || g_bIsLeanException)
+        return osl_Signal_ActCallNextHdl;
+
+    ExceptionCategory nVCLException = ExceptionCategory::NONE;
+
+    // UAE
+    if ( (pInfo->Signal == osl_Signal_AccessViolation)     ||
+         (pInfo->Signal == osl_Signal_IntegerDivideByZero) ||
+         (pInfo->Signal == osl_Signal_FloatDivideByZero)   ||
+         (pInfo->Signal == osl_Signal_DebugBreak) )
     {
-        sal_uInt16 nVCLException = 0;
-
-        // UAE
-        if ( (pInfo->Signal == osl_Signal_AccessViolation)     ||
-             (pInfo->Signal == osl_Signal_IntegerDivideByZero) ||
-             (pInfo->Signal == osl_Signal_FloatDivideByZero)   ||
-             (pInfo->Signal == osl_Signal_DebugBreak) )
+        nVCLException = ExceptionCategory::System;
+#if HAVE_FEATURE_OPENGL
+        if (OpenGLZone::isInZone())
+            OpenGLZone::hardDisable();
+#endif
+#if HAVE_FEATURE_OPENCL
+        if (OpenCLZone::isInZone())
         {
-            nVCLException = EXC_SYSTEM;
-            if (OpenGLZone::isInZone())
-                OpenGLZone::hardDisable();
+            OpenCLZone::hardDisable();
+#ifdef _WIN32
+            if (OpenCLZone::isInInitialTest())
+                TerminateProcess(GetCurrentProcess(), EXITHELPER_NORMAL_RESTART);
+#endif
         }
+#endif
+    }
 
-        // RC
-        if ((pInfo->Signal == osl_Signal_User) &&
-            (pInfo->UserSignal == OSL_SIGNAL_USER_RESOURCEFAILURE) )
-            nVCLException = EXC_RSCNOTLOADED;
+    // RC
+    if ((pInfo->Signal == osl_Signal_User) &&
+        (pInfo->UserSignal == OSL_SIGNAL_USER_RESOURCEFAILURE) )
+        nVCLException = ExceptionCategory::ResourceNotLoaded;
 
-        // DISPLAY-Unix
-        if ((pInfo->Signal == osl_Signal_User) &&
-            (pInfo->UserSignal == OSL_SIGNAL_USER_X11SUBSYSTEMERROR) )
-            nVCLException = EXC_DISPLAY;
+    // DISPLAY-Unix
+    if ((pInfo->Signal == osl_Signal_User) &&
+        (pInfo->UserSignal == OSL_SIGNAL_USER_X11SUBSYSTEMERROR) )
+        nVCLException = ExceptionCategory::UserInterface;
 
-        // Remote-Client
-        if ((pInfo->Signal == osl_Signal_User) &&
-            (pInfo->UserSignal == OSL_SIGNAL_USER_RVPCONNECTIONERROR) )
-            nVCLException = EXC_REMOTE;
+    if ( nVCLException != ExceptionCategory::NONE )
+    {
+        bIn = true;
 
-        if ( nVCLException )
+        SolarMutexGuard aLock;
+
+        // do not stop timer because otherwise the UAE-Box will not be painted as well
+        ImplSVData* pSVData = ImplGetSVData();
+        if ( pSVData->mpApp )
         {
-            bIn = true;
-
-            SolarMutexGuard aLock;
-
-            // do not stop timer because otherwise the UAE-Box will not be painted as well
-            ImplSVData* pSVData = ImplGetSVData();
-            if ( pSVData->mpApp )
-            {
-                SystemWindowFlags nOldMode = Application::GetSystemWindowMode();
-                Application::SetSystemWindowMode( nOldMode & ~SystemWindowFlags::NOAUTOMODE );
-                pSVData->mpApp->Exception( nVCLException );
-                Application::SetSystemWindowMode( nOldMode );
-            }
-            bIn = false;
-
-            return osl_Signal_ActCallNextHdl;
+            SystemWindowFlags nOldMode = Application::GetSystemWindowMode();
+            Application::SetSystemWindowMode( nOldMode & ~SystemWindowFlags::NOAUTOMODE );
+            pSVData->mpApp->Exception( nVCLException );
+            Application::SetSystemWindowMode( nOldMode );
         }
+        bIn = false;
     }
 
     return osl_Signal_ActCallNextHdl;
@@ -157,11 +181,15 @@ int ImplSVMain()
     // The 'real' SVMain()
     ImplSVData* pSVData = ImplGetSVData();
 
-    DBG_ASSERT( pSVData->mpApp, "no instance of class Application" );
+    SAL_WARN_IF( !pSVData->mpApp, "vcl", "no instance of class Application" );
 
     int nReturn = EXIT_FAILURE;
 
-    bool bInit = InitVCL();
+    bool bInit = isInitVCL() || InitVCL();
+
+#ifdef MACOSX
+    postInitVCLinitNSApp();
+#endif
 
     if( bInit )
     {
@@ -191,8 +219,9 @@ int ImplSVMain()
       pSVData->mxAccessBridge.clear();
     }
 
+#if HAVE_FEATURE_OPENGL
     OpenGLWatchdogThread::stop();
-
+#endif
     DeInitVCL();
 
     return nReturn;
@@ -221,20 +250,19 @@ public:
         : m_xNextContext( ctx ) {}
 
     // XCurrentContext
-    virtual css::uno::Any SAL_CALL getValueByName( const OUString& Name )
-            throw (css::uno::RuntimeException, std::exception) override;
+    virtual css::uno::Any SAL_CALL getValueByName( const OUString& Name ) override;
 
 private:
     css::uno::Reference< css::uno::XCurrentContext > m_xNextContext;
 };
 
-uno::Any SAL_CALL DesktopEnvironmentContext::getValueByName( const OUString& Name) throw (uno::RuntimeException, std::exception)
+uno::Any SAL_CALL DesktopEnvironmentContext::getValueByName( const OUString& Name)
 {
     uno::Any retVal;
 
     if ( Name == "system.desktop-environment" )
     {
-        retVal = uno::makeAny( Application::GetDesktopEnvironment() );
+        retVal <<= Application::GetDesktopEnvironment();
     }
     else if( m_xNextContext.is() )
     {
@@ -244,6 +272,25 @@ uno::Any SAL_CALL DesktopEnvironmentContext::getValueByName( const OUString& Nam
     return retVal;
 }
 
+static bool isInitVCL()
+{
+    ImplSVData* pSVData = ImplGetSVData();
+    return  pExceptionHandler != nullptr &&
+            pSVData->mpApp != nullptr &&
+            pSVData->mpDefInst != nullptr;
+}
+
+#ifdef DBG_UTIL
+namespace vclmain
+{
+    bool isAlive()
+    {
+        return ImplGetSVData()->mpDefInst;
+    }
+}
+#endif
+
+
 bool InitVCL()
 {
     if( pExceptionHandler != nullptr )
@@ -272,10 +319,30 @@ bool InitVCL()
         new DesktopEnvironmentContext( css::uno::getCurrentContext() ) );
 
     // Initialize application instance (should be done after initialization of VCL SAL part)
-    if( pSVData->mpApp )
+    if (pSVData->mpApp)
+    {
         // call init to initialize application class
         // soffice/sfx implementation creates the global service manager
         pSVData->mpApp->Init();
+    }
+
+    try
+    {
+        //Now that uno has been bootstrapped we can ask the config what the UI language is so that we can
+        //force that in as $LANGUAGE. That way we can get gtk to render widgets RTL
+        //if we have a RTL UI in an otherwise LTR locale and get gettext using externals (e.g. python)
+        //to match their translations to our preferred UI language
+        OUString aLocaleString(SvtSysLocaleOptions().GetRealUILanguageTag().getGlibcLocaleString(".UTF-8"));
+        if (!aLocaleString.isEmpty())
+        {
+            OUString envVar("LANGUAGE");
+            osl_setEnvironment(envVar.pData, aLocaleString.pData);
+        }
+    }
+    catch (const uno::Exception &e)
+    {
+        SAL_INFO("vcl.app", "Unable to get ui language: '" << e);
+    }
 
     pSVData->mpDefInst->AfterAppInit();
 
@@ -293,15 +360,24 @@ bool InitVCL()
     pSVData->maGDIData.mpScreenFontCache    = new ImplFontCache;
     pSVData->maGDIData.mpGrfConverter       = new GraphicConverter;
 
+    g_bIsLeanException = getenv("LO_LEAN_EXCEPTION") != nullptr;
     // Set exception handler
     pExceptionHandler = osl_addSignalHandler(VCLExceptionSignal_impl, nullptr);
 
-    DBGGUI_INIT_SOLARMUTEXCHECK();
+#ifdef DBG_UTIL
+    DbgGUIInitSolarMutexCheck();
+#endif
 
 #if OSL_DEBUG_LEVEL > 0
     DebugEventInjector::getCreate();
 #endif
 
+#ifndef _WIN32
+    // Clear startup notification details for child processes
+    // See https://bugs.freedesktop.org/show_bug.cgi?id=11375 for discussion
+    unsetenv("DESKTOP_STARTUP_ID");
+#endif
+
     return true;
 }
 
@@ -315,12 +391,11 @@ namespace
  */
 class VCLUnoWrapperDeleter : public cppu::WeakImplHelper<css::lang::XEventListener>
 {
-    virtual void SAL_CALL disposing(lang::EventObject const& rSource) throw(uno::RuntimeException, std::exception) override;
+    virtual void SAL_CALL disposing(lang::EventObject const& rSource) override;
 };
 
 void
 VCLUnoWrapperDeleter::disposing(lang::EventObject const& /* rSource */)
-    throw(uno::RuntimeException, std::exception)
 {
     ImplSVData* const pSVData = ImplGetSVData();
     if (pSVData && pSVData->mpUnoWrapper)
@@ -334,7 +409,19 @@ VCLUnoWrapperDeleter::disposing(lang::EventObject const& /* rSource */)
 
 void DeInitVCL()
 {
+    //rhbz#1444437, when using LibreOffice like a library you can't realistically
+    //tear everything down and recreate them on the next call, there's too many
+    //(c++) singletons that point to stuff that gets deleted during shutdown
+    //which won't be recreated on restart.
+    if (comphelper::LibreOfficeKit::isActive())
+        return;
+
+    {
+        SolarMutexReleaser r; // unblock threads blocked on that so we can join
+        ::comphelper::JoinAsyncEventNotifiers();
+    }
     ImplSVData* pSVData = ImplGetSVData();
+
     // lp#1560328: clear cache before disposing rest of VCL
     if(pSVData->mpBlendFrameCache)
         pSVData->mpBlendFrameCache->m_aLastResult.Clear();
@@ -369,10 +456,10 @@ void DeInitVCL()
             aBuf.append( "\n" );
         }
     }
-    DBG_ASSERT( nBadTopWindows==0, aBuf.getStr() );
+    SAL_WARN_IF( nBadTopWindows!=0, "vcl", aBuf.getStr() );
 #endif
 
-    ImplImageTree::get().shutDown();
+    ImageTree::get().shutdown();
 
     osl_removeSignalHandler( pExceptionHandler);
     pExceptionHandler = nullptr;
@@ -381,52 +468,14 @@ void DeInitVCL()
     delete pSVData->maGDIData.mpGrfConverter;
 
     if( pSVData->mpSettingsConfigItem )
-        delete pSVData->mpSettingsConfigItem, pSVData->mpSettingsConfigItem = nullptr;
+    {
+        delete pSVData->mpSettingsConfigItem;
+        pSVData->mpSettingsConfigItem = nullptr;
+    }
 
-    if ( pSVData->maAppData.mpIdleMgr )
-        delete pSVData->maAppData.mpIdleMgr;
-    Scheduler::ImplDeInitScheduler();
-
-    if ( pSVData->maWinData.mpMsgBoxImgList )
-    {
-        delete pSVData->maWinData.mpMsgBoxImgList;
-        pSVData->maWinData.mpMsgBoxImgList = nullptr;
-    }
-    if ( pSVData->maCtrlData.mpCheckImgList )
-    {
-        delete pSVData->maCtrlData.mpCheckImgList;
-        pSVData->maCtrlData.mpCheckImgList = nullptr;
-    }
-    if ( pSVData->maCtrlData.mpRadioImgList )
-    {
-        delete pSVData->maCtrlData.mpRadioImgList;
-        pSVData->maCtrlData.mpRadioImgList = nullptr;
-    }
-    if ( pSVData->maCtrlData.mpPinImgList )
-    {
-        delete pSVData->maCtrlData.mpPinImgList;
-        pSVData->maCtrlData.mpPinImgList = nullptr;
-    }
-    if ( pSVData->maCtrlData.mpSplitHPinImgList )
-    {
-        delete pSVData->maCtrlData.mpSplitHPinImgList;
-        pSVData->maCtrlData.mpSplitHPinImgList = nullptr;
-    }
-    if ( pSVData->maCtrlData.mpSplitVPinImgList )
-    {
-        delete pSVData->maCtrlData.mpSplitVPinImgList;
-        pSVData->maCtrlData.mpSplitVPinImgList = nullptr;
-    }
-    if ( pSVData->maCtrlData.mpSplitHArwImgList )
-    {
-        delete pSVData->maCtrlData.mpSplitHArwImgList;
-        pSVData->maCtrlData.mpSplitHArwImgList = nullptr;
-    }
-    if ( pSVData->maCtrlData.mpSplitVArwImgList )
-    {
-        delete pSVData->maCtrlData.mpSplitVArwImgList;
-        pSVData->maCtrlData.mpSplitVArwImgList = nullptr;
-    }
+    pSVData->maWinData.maMsgBoxImgList.clear();
+    pSVData->maCtrlData.maCheckImgList.clear();
+    pSVData->maCtrlData.maRadioImgList.clear();
     if ( pSVData->maCtrlData.mpDisclosurePlus )
     {
         delete pSVData->maCtrlData.mpDisclosurePlus;
@@ -439,7 +488,9 @@ void DeInitVCL()
     }
     pSVData->mpDefaultWin.disposeAndClear();
 
-    DBGGUI_DEINIT_SOLARMUTEXCHECK();
+#ifdef DBG_UTIL
+    DbgGUIDeInitSolarMutexCheck();
+#endif
 
     if ( pSVData->mpUnoWrapper )
     {
@@ -447,7 +498,7 @@ void DeInitVCL()
         {
             uno::Reference<frame::XDesktop2> const xDesktop = frame::Desktop::create(
                     comphelper::getProcessComponentContext() );
-            xDesktop->addEventListener(new VCLUnoWrapperDeleter());
+            xDesktop->addEventListener(new VCLUnoWrapperDeleter);
         }
         catch (uno::Exception const&)
         {
@@ -517,44 +568,61 @@ void DeInitVCL()
         delete pSVData->maAppData.mpKeyListeners;
         pSVData->maAppData.mpKeyListeners = nullptr;
     }
-
-    if ( pSVData->maAppData.mpFirstHotKey )
-        ImplFreeHotKeyData();
-    if ( pSVData->maAppData.mpFirstEventHook )
-        ImplFreeEventHookData();
-
     if (pSVData->mpBlendFrameCache)
-        delete pSVData->mpBlendFrameCache, pSVData->mpBlendFrameCache = nullptr;
-
-    if (pSVData->mpCommandInfoProvider)
     {
-        pSVData->mpCommandInfoProvider->dispose();
-        pSVData->mpCommandInfoProvider = nullptr;
+        delete pSVData->mpBlendFrameCache;
+        pSVData->mpBlendFrameCache = nullptr;
     }
 
     ImplDeletePrnQueueList();
+
+    Scheduler::ImplDeInitScheduler();
+
+    // destroy all Sal interfaces before destroying the instance
+    // and thereby unloading the plugin
+    delete pSVData->mpSalSystem;
+    pSVData->mpSalSystem = nullptr;
+    assert( !pSVData->maSchedCtx.mpSalTimer );
+    delete pSVData->maSchedCtx.mpSalTimer;
+    pSVData->maSchedCtx.mpSalTimer = nullptr;
+
+    pSVData->mpDefaultWin = nullptr;
+    pSVData->mpIntroWindow = nullptr;
+    pSVData->maAppData.mpActivePopupMenu = nullptr;
+    pSVData->maAppData.mpWheelWindow = nullptr;
+    pSVData->maGDIData.mpFirstWinGraphics = nullptr;
+    pSVData->maGDIData.mpLastWinGraphics = nullptr;
+    pSVData->maGDIData.mpFirstVirGraphics = nullptr;
+    pSVData->maGDIData.mpLastVirGraphics = nullptr;
+    pSVData->maGDIData.mpFirstPrnGraphics = nullptr;
+    pSVData->maGDIData.mpLastPrnGraphics = nullptr;
+    pSVData->maGDIData.mpFirstVirDev = nullptr;
+    pSVData->maGDIData.mpLastVirDev = nullptr;
+    pSVData->maGDIData.mpFirstPrinter = nullptr;
+    pSVData->maGDIData.mpLastPrinter = nullptr;
+    pSVData->maWinData.mpFirstFrame = nullptr;
+    pSVData->maWinData.mpAppWin = nullptr;
+    pSVData->maWinData.mpActiveApplicationFrame = nullptr;
+    pSVData->maWinData.mpCaptureWin = nullptr;
+    pSVData->maWinData.mpLastDeacWin = nullptr;
+    pSVData->maWinData.mpFirstFloat = nullptr;
+    pSVData->maWinData.mpLastExecuteDlg = nullptr;
+    pSVData->maWinData.mpExtTextInputWin = nullptr;
+    pSVData->maWinData.mpTrackWin = nullptr;
+    pSVData->maWinData.mpAutoScrollWin = nullptr;
+    pSVData->maWinData.mpLastWheelWindow = nullptr;
+
     delete pSVData->maGDIData.mpScreenFontList;
     pSVData->maGDIData.mpScreenFontList = nullptr;
     delete pSVData->maGDIData.mpScreenFontCache;
     pSVData->maGDIData.mpScreenFontCache = nullptr;
 
-    if ( pSVData->mpResMgr )
-    {
-        delete pSVData->mpResMgr;
-        pSVData->mpResMgr = nullptr;
-    }
-
-    ResMgr::DestroyAllResMgr();
-
-    // destroy all Sal interfaces before destorying the instance
-    // and thereby unloading the plugin
-    delete pSVData->mpSalSystem;
-    pSVData->mpSalSystem = nullptr;
-    delete pSVData->mpSalTimer;
-    pSVData->mpSalTimer = nullptr;
-
     // Deinit Sal
-    DestroySalInstance( pSVData->mpDefInst );
+    if (pSVData->mpDefInst)
+    {
+        DestroySalInstance( pSVData->mpDefInst );
+        pSVData->mpDefInst = nullptr;
+    }
 
     if( pOwnSvApp )
     {
@@ -577,15 +645,15 @@ struct WorkerThreadData
     }
 };
 
-#ifdef WNT
-static HANDLE hThreadID = 0;
-static unsigned __stdcall _threadmain( void *pArgs )
+#ifdef _WIN32
+static HANDLE hThreadID = nullptr;
+static unsigned __stdcall threadmain( void *pArgs )
 {
-    OleInitialize( NULL );
-    ((WorkerThreadData*)pArgs)->pWorker( ((WorkerThreadData*)pArgs)->pThreadData );
-    delete (WorkerThreadData*)pArgs;
+    OleInitialize( nullptr );
+    static_cast<WorkerThreadData*>(pArgs)->pWorker( static_cast<WorkerThreadData*>(pArgs)->pThreadData );
+    delete static_cast<WorkerThreadData*>(pArgs);
     OleUninitialize();
-    hThreadID = 0;
+    hThreadID = nullptr;
     return 0;
 }
 #else
@@ -603,17 +671,17 @@ static void SAL_CALL MainWorkerFunction( void* pArgs )
 
 void CreateMainLoopThread( oslWorkerFunction pWorker, void * pThreadData )
 {
-#ifdef WNT
+#ifdef _WIN32
     // sal thread always call CoInitializeEx, so a system dependent implementation is necessary
 
     unsigned uThreadID;
-    hThreadID = (HANDLE)_beginthreadex(
-        NULL,       // no security handle
+    hThreadID = reinterpret_cast<HANDLE>(_beginthreadex(
+        nullptr,       // no security handle
         0,          // stacksize 0 means default
-        _threadmain,    // thread worker function
+        threadmain,    // thread worker function
         new WorkerThreadData( pWorker, pThreadData ),       // arguments for worker function
         0,          // 0 means: create immediately otherwise use CREATE_SUSPENDED
-        &uThreadID );   // thread id to fill
+        &uThreadID ));   // thread id to fill
 #else
     hThreadID = osl_createThread( MainWorkerFunction, new WorkerThreadData( pWorker, pThreadData ) );
 #endif
@@ -623,7 +691,7 @@ void JoinMainLoopThread()
 {
     if( hThreadID )
     {
-#ifdef WNT
+#ifdef _WIN32
         WaitForSingleObject(hThreadID, INFINITE);
 #else
         osl_joinWithThread(hThreadID);
