@@ -29,10 +29,10 @@
 #include <vcl/settings.hxx>
 #include <vcl/uitest/uiobject.hxx>
 
-#include "svdata.hxx"
-#include "controldata.hxx"
-#include "listbox.hxx"
-#include "dndeventdispatcher.hxx"
+#include <svdata.hxx>
+#include <controldata.hxx>
+#include <listbox.hxx>
+#include <dndeventdispatcher.hxx>
 
 #include <com/sun/star/datatransfer/dnd/XDropTarget.hpp>
 
@@ -185,11 +185,11 @@ IMPL_LINK_NOARG(ListBox, ImplSelectHdl, LinkParamNone*, void)
             mpImplWin->GrabFocus();
         }
 
-        mpImplWin->SetItemPos( GetSelectEntryPos() );
-        mpImplWin->SetString( GetSelectEntry() );
+        mpImplWin->SetItemPos( GetSelectedEntryPos() );
+        mpImplWin->SetString( GetSelectedEntry() );
         if( mpImplLB->GetEntryList()->HasImages() )
         {
-            Image aImage = mpImplLB->GetEntryList()->GetEntryImage( GetSelectEntryPos() );
+            Image aImage = mpImplLB->GetEntryList()->GetEntryImage( GetSelectedEntryPos() );
             mpImplWin->SetImage( aImage );
         }
         mpImplWin->Invalidate();
@@ -392,7 +392,7 @@ void ListBox::Draw( OutputDevice* pDev, const Point& rPos, const Size& rSize, Dr
 
     if ( IsDropDownBox() )
     {
-        OUString   aText = GetSelectEntry();
+        OUString   aText = GetSelectedEntry();
         long       nTextHeight = pDev->GetTextHeight();
         long       nTextWidth = pDev->GetTextWidth( aText );
         long       nOffY = (aSize.Height()-nTextHeight) / 2;
@@ -1016,24 +1016,24 @@ sal_Int32 ListBox::GetEntryCount() const
     return mpImplLB->GetEntryList()->GetEntryCount() - mpImplLB->GetEntryList()->GetMRUCount();
 }
 
-OUString ListBox::GetSelectEntry(sal_Int32 nIndex) const
+OUString ListBox::GetSelectedEntry(sal_Int32 nIndex) const
 {
-    return GetEntry( GetSelectEntryPos( nIndex ) );
+    return GetEntry( GetSelectedEntryPos( nIndex ) );
 }
 
-sal_Int32 ListBox::GetSelectEntryCount() const
+sal_Int32 ListBox::GetSelectedEntryCount() const
 {
     if (!mpImplLB)
         return 0;
-    return mpImplLB->GetEntryList()->GetSelectEntryCount();
+    return mpImplLB->GetEntryList()->GetSelectedEntryCount();
 }
 
-sal_Int32 ListBox::GetSelectEntryPos( sal_Int32 nIndex ) const
+sal_Int32 ListBox::GetSelectedEntryPos( sal_Int32 nIndex ) const
 {
     if (!mpImplLB || !mpImplLB->GetEntryList())
         return LISTBOX_ENTRY_NOTFOUND;
 
-    sal_Int32 nPos = mpImplLB->GetEntryList()->GetSelectEntryPos( nIndex );
+    sal_Int32 nPos = mpImplLB->GetEntryList()->GetSelectedEntryPos( nIndex );
     if ( nPos != LISTBOX_ENTRY_NOTFOUND )
     {
         if ( nPos < mpImplLB->GetEntryList()->GetMRUCount() )
@@ -1065,9 +1065,9 @@ void ListBox::SelectEntryPos( sal_Int32 nPos, bool bSelect )
 
     if ( 0 <= nPos && nPos < mpImplLB->GetEntryList()->GetEntryCount() )
     {
-        sal_Int32 oldSelectCount = GetSelectEntryCount(), newSelectCount = 0, nCurrentPos = mpImplLB->GetCurrentPos();
+        sal_Int32 oldSelectCount = GetSelectedEntryCount(), newSelectCount = 0, nCurrentPos = mpImplLB->GetCurrentPos();
         mpImplLB->SelectEntry( nPos + mpImplLB->GetEntryList()->GetMRUCount(), bSelect );
-        newSelectCount = GetSelectEntryCount();
+        newSelectCount = GetSelectedEntryCount();
         if (oldSelectCount == 0 && newSelectCount > 0)
             CallEventListeners(VclEventId::ListboxStateUpdate);
         //Only when bSelect == true, send both Selection & Focus events
