@@ -17,48 +17,45 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-
 #include <vcl/animate.hxx>
-#include <tools/debug.hxx>
 #include <tools/stream.hxx>
 #include <rtl/crc.h>
 #include <vcl/virdev.hxx>
 #include <vcl/window.hxx>
-#include <impanmvw.hxx>
 #include <vcl/dibtools.hxx>
 
-DBG_NAME( Animation )
+#include <impanmvw.hxx>
 
-#define MIN_TIMEOUT 2L
-#define INC_TIMEOUT 0L
+#define MIN_TIMEOUT 2
+#define INC_TIMEOUT 0
 
-sal_uLong Animation::mnAnimCount = 0UL;
+sal_uLong Animation::mnAnimCount = 0;
 
-sal_uLong AnimationBitmap::GetChecksum() const
+BitmapChecksum AnimationBitmap::GetChecksum() const
 {
-    sal_uInt32  nCrc = aBmpEx.GetChecksum();
+    BitmapChecksum  nCrc = aBmpEx.GetChecksum();
     SVBT32      aBT32;
 
     UInt32ToSVBT32( aPosPix.X(), aBT32 );
-    nCrc = rtl_crc32( nCrc, aBT32, 4 );
+    nCrc = vcl_get_checksum( nCrc, aBT32, 4 );
 
     UInt32ToSVBT32( aPosPix.Y(), aBT32 );
-    nCrc = rtl_crc32( nCrc, aBT32, 4 );
+    nCrc = vcl_get_checksum( nCrc, aBT32, 4 );
 
     UInt32ToSVBT32( aSizePix.Width(), aBT32 );
-    nCrc = rtl_crc32( nCrc, aBT32, 4 );
+    nCrc = vcl_get_checksum( nCrc, aBT32, 4 );
 
     UInt32ToSVBT32( aSizePix.Height(), aBT32 );
-    nCrc = rtl_crc32( nCrc, aBT32, 4 );
+    nCrc = vcl_get_checksum( nCrc, aBT32, 4 );
 
     UInt32ToSVBT32( (long) nWait, aBT32 );
-    nCrc = rtl_crc32( nCrc, aBT32, 4 );
+    nCrc = vcl_get_checksum( nCrc, aBT32, 4 );
 
     UInt32ToSVBT32( (long) eDisposal, aBT32 );
-    nCrc = rtl_crc32( nCrc, aBT32, 4 );
+    nCrc = vcl_get_checksum( nCrc, aBT32, 4 );
 
     UInt32ToSVBT32( (long) bUserInput, aBT32 );
-    nCrc = rtl_crc32( nCrc, aBT32, 4 );
+    nCrc = vcl_get_checksum( nCrc, aBT32, 4 );
 
     return nCrc;
 }
@@ -67,13 +64,10 @@ Animation::Animation() :
     mnLoopCount         ( 0 ),
     mnLoops             ( 0 ),
     mnPos               ( 0 ),
-    meCycleMode         ( CYCLE_NORMAL ),
-    mbIsInAnimation     ( sal_False ),
-    mbLoopTerminated    ( sal_False ),
-    mbIsWaiting         ( sal_False )
+    mbIsInAnimation     ( false ),
+    mbLoopTerminated    ( false )
 {
-    DBG_CTOR( Animation, NULL );
-    maTimer.SetTimeoutHdl( LINK( this, Animation, ImplTimeoutHdl ) );
+    maTimer.SetInvokeHandler( LINK( this, Animation, ImplTimeoutHdl ) );
 }
 
 Animation::Animation( const Animation& rAnimation ) :
@@ -81,48 +75,35 @@ Animation::Animation( const Animation& rAnimation ) :
     maGlobalSize        ( rAnimation.maGlobalSize ),
     mnLoopCount         ( rAnimation.mnLoopCount ),
     mnPos               ( rAnimation.mnPos ),
-    meCycleMode         ( rAnimation.meCycleMode ),
-    mbIsInAnimation     ( sal_False ),
-    mbLoopTerminated    ( rAnimation.mbLoopTerminated ),
-    mbIsWaiting         ( rAnimation.mbIsWaiting )
+    mbIsInAnimation     ( false ),
+    mbLoopTerminated    ( rAnimation.mbLoopTerminated )
 {
-    DBG_CTOR( Animation, NULL );
 
-    for( size_t i = 0, nCount = rAnimation.maList.size(); i < nCount; i++ )
-        maList.push_back( new AnimationBitmap( *rAnimation.maList[ i ] ) );
+    for(auto const & i : rAnimation.maList)
+        maList.emplace_back( new AnimationBitmap( *i ) );
 
-    maTimer.SetTimeoutHdl( LINK( this, Animation, ImplTimeoutHdl ) );
+    maTimer.SetInvokeHandler( LINK( this, Animation, ImplTimeoutHdl ) );
     mnLoops = mbLoopTerminated ? 0 : mnLoopCount;
 }
 
 Animation::~Animation()
 {
-    DBG_DTOR( Animation, NULL );
-
     if( mbIsInAnimation )
         Stop();
-
-    for( size_t i = 0, n = maList.size(); i < n; ++i )
-        delete maList[ i ];
-
-    for( size_t i = 0, n = maViewList.size(); i < n; ++i )
-        delete maViewList[ i ];
 }
 
 Animation& Animation::operator=( const Animation& rAnimation )
 {
     Clear();
 
-    for( size_t i = 0, nCount = rAnimation.maList.size(); i < nCount; i++ )
-        maList.push_back( new AnimationBitmap( *rAnimation.maList[ i ] ) );
+    for(auto const & i : rAnimation.maList)
+        maList.emplace_back( new AnimationBitmap( *i ) );
 
     maGlobalSize = rAnimation.maGlobalSize;
     maBitmapEx = rAnimation.maBitmapEx;
-    meCycleMode = rAnimation.meCycleMode;
     mnLoopCount = rAnimation.mnLoopCount;
     mnPos = rAnimation.mnPos;
     mbLoopTerminated = rAnimation.mbLoopTerminated;
-    mbIsWaiting = rAnimation.mbIsWaiting;
     mnLoops = mbLoopTerminated ? 0 : mnLoopCount;
 
     return *this;
@@ -136,7 +117,6 @@ bool Animation::operator==( const Animation& rAnimation ) const
     if(  rAnimation.maList.size() == nCount
       && rAnimation.maBitmapEx    == maBitmapEx
       && rAnimation.maGlobalSize  == maGlobalSize
-      && rAnimation.meCycleMode   == meCycleMode
       )
     {
         bRet = true;
@@ -157,38 +137,30 @@ bool Animation::operator==( const Animation& rAnimation ) const
 void Animation::Clear()
 {
     maTimer.Stop();
-    mbIsInAnimation = sal_False;
+    mbIsInAnimation = false;
     maGlobalSize = Size();
     maBitmapEx.SetEmpty();
-
-    for( size_t i = 0, n = maList.size(); i < n; ++i )
-        delete maList[ i ];
     maList.clear();
-
-    for( size_t i = 0, n = maViewList.size(); i < n; ++i )
-        delete maViewList[ i ];
     maViewList.clear();
 }
 
-sal_Bool Animation::IsTransparent() const
+bool Animation::IsTransparent() const
 {
     Point       aPoint;
-    Rectangle   aRect( aPoint, maGlobalSize );
-    sal_Bool        bRet = sal_False;
+    tools::Rectangle   aRect( aPoint, maGlobalSize );
+    bool        bRet = false;
 
     // If some small bitmap needs to be replaced by the background,
     // we need to be transparent, in order to be displayed correctly
     // as the application (?) does not invalidate on non-transparent
     // graphics due to performance reasons.
-    for( size_t i = 0, nCount = maList.size(); i < nCount; i++ )
+    for(auto const & pAnimBmp : maList)
     {
-        const AnimationBitmap* pAnimBmp = maList[ i ];
-
-        if(  DISPOSE_BACK == pAnimBmp->eDisposal
-          && Rectangle( pAnimBmp->aPosPix, pAnimBmp->aSizePix ) != aRect
+        if(  Disposal::Back == pAnimBmp->eDisposal
+          && tools::Rectangle( pAnimBmp->aPosPix, pAnimBmp->aSizePix ) != aRect
           )
         {
-            bRet = sal_True;
+            bRet = true;
             break;
         }
     }
@@ -203,45 +175,42 @@ sal_uLong Animation::GetSizeBytes() const
 {
     sal_uLong nSizeBytes = GetBitmapEx().GetSizeBytes();
 
-    for( size_t i = 0, nCount = maList.size(); i < nCount; i++ )
+    for(auto const & pAnimBmp : maList)
     {
-        const AnimationBitmap* pAnimBmp = maList[ i ];
         nSizeBytes += pAnimBmp->aBmpEx.GetSizeBytes();
     }
 
     return nSizeBytes;
 }
 
-sal_uLong Animation::GetChecksum() const
+BitmapChecksum Animation::GetChecksum() const
 {
     SVBT32      aBT32;
-    sal_uInt32  nCrc = GetBitmapEx().GetChecksum();
+    BitmapChecksumOctetArray aBCOA;
+    BitmapChecksum  nCrc = GetBitmapEx().GetChecksum();
 
     UInt32ToSVBT32( maList.size(), aBT32 );
-    nCrc = rtl_crc32( nCrc, aBT32, 4 );
+    nCrc = vcl_get_checksum( nCrc, aBT32, 4 );
 
     UInt32ToSVBT32( maGlobalSize.Width(), aBT32 );
-    nCrc = rtl_crc32( nCrc, aBT32, 4 );
+    nCrc = vcl_get_checksum( nCrc, aBT32, 4 );
 
     UInt32ToSVBT32( maGlobalSize.Height(), aBT32 );
-    nCrc = rtl_crc32( nCrc, aBT32, 4 );
+    nCrc = vcl_get_checksum( nCrc, aBT32, 4 );
 
-    UInt32ToSVBT32( (long) meCycleMode, aBT32 );
-    nCrc = rtl_crc32( nCrc, aBT32, 4 );
-
-    for( size_t i = 0, nCount = maList.size(); i < nCount; i++ )
+    for(auto const & i : maList)
     {
-        UInt32ToSVBT32( maList[ i ]->GetChecksum(), aBT32 );
-        nCrc = rtl_crc32( nCrc, aBT32, 4 );
+        BCToBCOA( i->GetChecksum(), aBCOA );
+        nCrc = vcl_get_checksum( nCrc, aBCOA, BITMAP_CHECKSUM_SIZE );
     }
 
     return nCrc;
 }
 
-sal_Bool Animation::Start( OutputDevice* pOut, const Point& rDestPt, const Size& rDestSz, long nExtraData,
+bool Animation::Start( OutputDevice* pOut, const Point& rDestPt, const Size& rDestSz, long nExtraData,
                        OutputDevice* pFirstFrameOutDev )
 {
-    sal_Bool bRet = sal_False;
+    bool bRet = false;
 
     if( !maList.empty() )
     {
@@ -251,24 +220,23 @@ sal_Bool Animation::Start( OutputDevice* pOut, const Point& rDestPt, const Size&
           )
         {
             ImplAnimView*   pView;
-            ImplAnimView*   pMatch = NULL;
+            ImplAnimView*   pMatch = nullptr;
 
             for( size_t i = 0; i < maViewList.size(); ++i )
             {
-                pView = maViewList[ i ];
-                if( pView->ImplMatches( pOut, nExtraData ) )
+                pView = maViewList[ i ].get();
+                if( pView->matches( pOut, nExtraData ) )
                 {
-                    if( pView->ImplGetOutPos() == rDestPt &&
-                        pView->ImplGetOutSizePix() == pOut->LogicToPixel( rDestSz ) )
+                    if( pView->getOutPos() == rDestPt &&
+                        pView->getOutSizePix() == pOut->LogicToPixel( rDestSz ) )
                     {
-                        pView->ImplRepaint();
+                        pView->repaint();
                         pMatch = pView;
                     }
                     else
                     {
-                        delete maViewList[ i ];
                         maViewList.erase( maViewList.begin() + i );
-                        pView = NULL;
+                        pView = nullptr;
                     }
 
                     break;
@@ -278,23 +246,23 @@ sal_Bool Animation::Start( OutputDevice* pOut, const Point& rDestPt, const Size&
             if( maViewList.empty() )
             {
                 maTimer.Stop();
-                mbIsInAnimation = sal_False;
-                mnPos = 0UL;
+                mbIsInAnimation = false;
+                mnPos = 0;
             }
 
             if( !pMatch )
-                maViewList.push_back( new ImplAnimView( this, pOut, rDestPt, rDestSz, nExtraData, pFirstFrameOutDev ) );
+                maViewList.emplace_back( new ImplAnimView( this, pOut, rDestPt, rDestSz, nExtraData, pFirstFrameOutDev ) );
 
             if( !mbIsInAnimation )
             {
                 ImplRestartTimer( maList[ mnPos ]->nWait );
-                mbIsInAnimation = sal_True;
+                mbIsInAnimation = true;
             }
         }
         else
             Draw( pOut, rDestPt, rDestSz );
 
-        bRet = sal_True;
+        bRet = true;
     }
 
     return bRet;
@@ -304,12 +272,9 @@ void Animation::Stop( OutputDevice* pOut, long nExtraData )
 {
     for( size_t i = 0; i < maViewList.size(); )
     {
-
-
-        ImplAnimView* pView = maViewList[ i ];
-        if( pView->ImplMatches( pOut, nExtraData ) )
+        ImplAnimView* pView = maViewList[ i ].get();
+        if( pView->matches( pOut, nExtraData ) )
         {
-            delete pView;
             maViewList.erase( maViewList.begin() + i );
         }
         else
@@ -319,7 +284,7 @@ void Animation::Stop( OutputDevice* pOut, long nExtraData )
     if( maViewList.empty() )
     {
         maTimer.Stop();
-        mbIsInAnimation = sal_False;
+        mbIsInAnimation = false;
     }
 }
 
@@ -334,7 +299,7 @@ void Animation::Draw( OutputDevice* pOut, const Point& rDestPt, const Size& rDes
 
     if( nCount )
     {
-        AnimationBitmap* pObj = maList[ std::min( mnPos, nCount - 1 ) ];
+        AnimationBitmap* pObj = maList[ std::min( mnPos, nCount - 1 ) ].get();
 
         if(  pOut->GetConnectMetaFile()
           || ( pOut->GetOutDevType() == OUTDEV_PRINTER )
@@ -345,25 +310,23 @@ void Animation::Draw( OutputDevice* pOut, const Point& rDestPt, const Size& rDes
         else
         {
             const size_t nOldPos = mnPos;
-            ( (Animation*) this )->mnPos = mbLoopTerminated ? ( nCount - 1UL ) : mnPos;
-            delete new ImplAnimView( (Animation*) this, pOut, rDestPt, rDestSz, 0 );
-            ( (Animation*) this )->mnPos = nOldPos;
+            const_cast<Animation*>(this)->mnPos = mbLoopTerminated ? ( nCount - 1 ) : mnPos;
+            delete new ImplAnimView( const_cast<Animation*>(this), pOut, rDestPt, rDestSz, 0 );
+            const_cast<Animation*>(this)->mnPos = nOldPos;
         }
     }
 }
 
 void Animation::ImplRestartTimer( sal_uLong nTimeout )
 {
-    maTimer.SetTimeout( std::max( nTimeout, (sal_uLong)(MIN_TIMEOUT + ( mnAnimCount - 1 ) * INC_TIMEOUT) ) * 10L );
+    maTimer.SetTimeout( std::max( nTimeout, (sal_uLong)(MIN_TIMEOUT + ( mnAnimCount - 1 ) * INC_TIMEOUT) ) * 10 );
     maTimer.Start();
 }
 
-typedef ::std::vector< AInfo* > AInfoList_impl;
-
-IMPL_LINK_NOARG(Animation, ImplTimeoutHdl)
+IMPL_LINK_NOARG(Animation, ImplTimeoutHdl, Timer *, void)
 {
     const size_t nAnimCount = maList.size();
-    AInfoList_impl aAInfoList;
+    std::vector< AInfo* > aAInfoList;
 
     if( nAnimCount )
     {
@@ -372,52 +335,48 @@ IMPL_LINK_NOARG(Animation, ImplTimeoutHdl)
 
         if( maNotifyLink.IsSet() )
         {
-            AInfo* pAInfo;
-
             // create AInfo-List
-            for( size_t i = 0, n = maViewList.size(); i < n; ++i )
-                aAInfoList.push_back( maViewList[ i ]->ImplCreateAInfo() );
+            for(auto const & i : maViewList)
+                aAInfoList.push_back( i->createAInfo() );
 
             maNotifyLink.Call( this );
 
             // set view state from AInfo structure
-            for( size_t i = 0, n = aAInfoList.size(); i < n; ++i )
+            for(AInfo* pAInfo : aAInfoList)
             {
-                pAInfo = aAInfoList[ i ];
                 if( !pAInfo->pViewData )
                 {
                     pView = new ImplAnimView( this, pAInfo->pOutDev,
                                               pAInfo->aStartOrg, pAInfo->aStartSize, pAInfo->nExtraData );
 
-                    maViewList.push_back( pView );
+                    maViewList.push_back( std::unique_ptr<ImplAnimView>(pView) );
                 }
                 else
-                    pView = (ImplAnimView*) pAInfo->pViewData;
+                    pView = static_cast<ImplAnimView*>(pAInfo->pViewData);
 
-                pView->ImplPause( pAInfo->bPause );
-                pView->ImplSetMarked( sal_True );
+                pView->pause( pAInfo->bPause );
+                pView->setMarked( true );
             }
 
             // delete AInfo structures
-            for( size_t i = 0, n = aAInfoList.size(); i < n; ++i )
-                delete aAInfoList[ i ];
+            for(AInfo* i : aAInfoList)
+                delete i;
             aAInfoList.clear();
 
             // delete all unmarked views and reset marked state
             for( size_t i = 0; i < maViewList.size(); )
             {
-                pView = maViewList[ i ];
-                if( !pView->ImplIsMarked() )
+                pView = maViewList[ i ].get();
+                if( !pView->isMarked() )
                 {
-                    delete pView;
                     maViewList.erase( maViewList.begin() + i );
                 }
                 else
                 {
-                    if( !pView->ImplIsPause() )
+                    if( !pView->isPause() )
                         bGlobalPause = false;
 
-                    pView->ImplSetMarked( sal_False );
+                    pView->setMarked( false );
                     i++;
                 }
             }
@@ -431,17 +390,17 @@ IMPL_LINK_NOARG(Animation, ImplTimeoutHdl)
             ImplRestartTimer( 10 );
         else
         {
-            AnimationBitmap* pStepBmp = (++mnPos < maList.size()) ? maList[ mnPos ] : NULL;
+            AnimationBitmap* pStepBmp = (++mnPos < maList.size()) ? maList[ mnPos ].get() : nullptr;
 
             if( !pStepBmp )
             {
                 if( mnLoops == 1 )
                 {
                     Stop();
-                    mbLoopTerminated = sal_True;
-                    mnPos = nAnimCount - 1UL;
+                    mbLoopTerminated = true;
+                    mnPos = nAnimCount - 1;
                     maBitmapEx = maList[ mnPos ]->aBmpEx;
-                    return 0L;
+                    return;
                 }
                 else
                 {
@@ -449,7 +408,7 @@ IMPL_LINK_NOARG(Animation, ImplTimeoutHdl)
                         mnLoops--;
 
                     mnPos = 0;
-                    pStepBmp = maList[ mnPos ];
+                    pStepBmp = maList[ mnPos ].get();
                 }
             }
 
@@ -459,12 +418,11 @@ IMPL_LINK_NOARG(Animation, ImplTimeoutHdl)
             // set from view itself
             for( size_t i = 0; i < maViewList.size(); )
             {
-                pView = maViewList[ i ];
-                pView->ImplDraw( mnPos );
+                pView = maViewList[ i ].get();
+                pView->draw( mnPos );
 
-                if( pView->ImplIsMarked() )
+                if( pView->isMarked() )
                 {
-                    delete pView;
                     maViewList.erase( maViewList.begin() + i );
                 }
                 else
@@ -480,27 +438,25 @@ IMPL_LINK_NOARG(Animation, ImplTimeoutHdl)
     }
     else
         Stop();
-
-    return 0L;
 }
 
-sal_Bool Animation::Insert( const AnimationBitmap& rStepBmp )
+bool Animation::Insert( const AnimationBitmap& rStepBmp )
 {
-    sal_Bool bRet = sal_False;
+    bool bRet = false;
 
     if( !IsInAnimation() )
     {
         Point       aPoint;
-        Rectangle   aGlobalRect( aPoint, maGlobalSize );
+        tools::Rectangle   aGlobalRect( aPoint, maGlobalSize );
 
-        maGlobalSize = aGlobalRect.Union( Rectangle( rStepBmp.aPosPix, rStepBmp.aSizePix ) ).GetSize();
-        maList.push_back( new AnimationBitmap( rStepBmp ) );
+        maGlobalSize = aGlobalRect.Union( tools::Rectangle( rStepBmp.aPosPix, rStepBmp.aSizePix ) ).GetSize();
+        maList.emplace_back( new AnimationBitmap( rStepBmp ) );
 
         // As a start, we make the first BitmapEx the replacement BitmapEx
         if( maList.size() == 1 )
             maBitmapEx = rStepBmp.aBmpEx;
 
-        bRet = sal_True;
+        bRet = true;
     }
 
     return bRet;
@@ -508,16 +464,15 @@ sal_Bool Animation::Insert( const AnimationBitmap& rStepBmp )
 
 const AnimationBitmap& Animation::Get( sal_uInt16 nAnimation ) const
 {
-    DBG_ASSERT( ( nAnimation < maList.size() ), "No object at this position" );
+    SAL_WARN_IF( ( nAnimation >= maList.size() ), "vcl", "No object at this position" );
     return *maList[ nAnimation ];
 }
 
 void Animation::Replace( const AnimationBitmap& rNewAnimationBitmap, sal_uInt16 nAnimation )
 {
-    DBG_ASSERT( ( nAnimation < maList.size() ), "No object at this position" );
+    SAL_WARN_IF( ( nAnimation >= maList.size() ), "vcl", "No object at this position" );
 
-    delete maList[ nAnimation ];
-    maList[ nAnimation ] = new AnimationBitmap( rNewAnimationBitmap );
+    maList[ nAnimation ].reset( new AnimationBitmap( rNewAnimationBitmap ) );
 
     // If we insert at first position we also need to
     // update the replacement BitmapEx
@@ -536,7 +491,7 @@ void Animation::Replace( const AnimationBitmap& rNewAnimationBitmap, sal_uInt16
     }
 }
 
-void Animation::SetLoopCount( const sal_uLong nLoopCount )
+void Animation::SetLoopCount(const sal_uInt32 nLoopCount)
 {
     mnLoopCount = nLoopCount;
     ResetLoopCount();
@@ -545,18 +500,18 @@ void Animation::SetLoopCount( const sal_uLong nLoopCount )
 void Animation::ResetLoopCount()
 {
     mnLoops = mnLoopCount;
-    mbLoopTerminated = sal_False;
+    mbLoopTerminated = false;
 }
 
-sal_Bool Animation::Convert( BmpConversion eConversion )
+bool Animation::Convert( BmpConversion eConversion )
 {
-    DBG_ASSERT( !IsInAnimation(), "Animation modified while it is animated" );
+    SAL_WARN_IF( IsInAnimation(), "vcl", "Animation modified while it is animated" );
 
-    sal_Bool bRet;
+    bool bRet;
 
     if( !IsInAnimation() && !maList.empty() )
     {
-        bRet = sal_True;
+        bRet = true;
 
         for( size_t i = 0, n = maList.size(); ( i < n ) && bRet; ++i )
             bRet = maList[ i ]->aBmpEx.Convert( eConversion );
@@ -564,41 +519,41 @@ sal_Bool Animation::Convert( BmpConversion eConversion )
         maBitmapEx.Convert( eConversion );
     }
     else
-        bRet = sal_False;
+        bRet = false;
 
     return bRet;
 }
 
-sal_Bool Animation::ReduceColors( sal_uInt16 nNewColorCount, BmpReduce eReduce )
+bool Animation::ReduceColors( sal_uInt16 nNewColorCount )
 {
-    DBG_ASSERT( !IsInAnimation(), "Animation modified while it is animated" );
+    SAL_WARN_IF( IsInAnimation(), "vcl", "Animation modified while it is animated" );
 
-    sal_Bool bRet;
+    bool bRet;
 
     if( !IsInAnimation() && !maList.empty() )
     {
-        bRet = sal_True;
+        bRet = true;
 
         for( size_t i = 0, n = maList.size(); ( i < n ) && bRet; ++i )
-            bRet = maList[ i ]->aBmpEx.ReduceColors( nNewColorCount, eReduce );
+            bRet = maList[ i ]->aBmpEx.ReduceColors( nNewColorCount );
 
-        maBitmapEx.ReduceColors( nNewColorCount, eReduce );
+        maBitmapEx.ReduceColors( nNewColorCount );
     }
     else
-        bRet = sal_False;
+        bRet = false;
 
     return bRet;
 }
 
-sal_Bool Animation::Invert()
+bool Animation::Invert()
 {
-    DBG_ASSERT( !IsInAnimation(), "Animation modified while it is animated" );
+    SAL_WARN_IF( IsInAnimation(), "vcl", "Animation modified while it is animated" );
 
-    sal_Bool bRet;
+    bool bRet;
 
     if( !IsInAnimation() && !maList.empty() )
     {
-        bRet = sal_True;
+        bRet = true;
 
         for( size_t i = 0, n = maList.size(); ( i < n ) && bRet; ++i )
             bRet = maList[ i ]->aBmpEx.Invert();
@@ -606,32 +561,33 @@ sal_Bool Animation::Invert()
         maBitmapEx.Invert();
     }
     else
-        bRet = sal_False;
+        bRet = false;
 
     return bRet;
 }
 
-sal_Bool Animation::Mirror( sal_uLong nMirrorFlags )
+bool Animation::Mirror( BmpMirrorFlags nMirrorFlags )
 {
-    DBG_ASSERT( !IsInAnimation(), "Animation modified while it is animated" );
+    SAL_WARN_IF( IsInAnimation(), "vcl", "Animation modified while it is animated" );
 
-    sal_Bool    bRet;
+    bool    bRet;
 
     if( !IsInAnimation() && !maList.empty() )
     {
-        bRet = sal_True;
+        bRet = true;
 
-        if( nMirrorFlags )
+        if( nMirrorFlags != BmpMirrorFlags::NONE )
         {
             for( size_t i = 0, n = maList.size(); ( i < n ) && bRet; ++i )
             {
-                AnimationBitmap* pStepBmp = maList[ i ];
-                if( ( bRet = pStepBmp->aBmpEx.Mirror( nMirrorFlags ) ) == sal_True )
+                AnimationBitmap* pStepBmp = maList[ i ].get();
+                bRet = pStepBmp->aBmpEx.Mirror( nMirrorFlags );
+                if( bRet )
                 {
-                    if( nMirrorFlags & BMP_MIRROR_HORZ )
+                    if( nMirrorFlags & BmpMirrorFlags::Horizontal )
                         pStepBmp->aPosPix.X() = maGlobalSize.Width() - pStepBmp->aPosPix.X() - pStepBmp->aSizePix.Width();
 
-                    if( nMirrorFlags & BMP_MIRROR_VERT )
+                    if( nMirrorFlags & BmpMirrorFlags::Vertical )
                         pStepBmp->aPosPix.Y() = maGlobalSize.Height() - pStepBmp->aPosPix.Y() - pStepBmp->aSizePix.Height();
                 }
             }
@@ -640,22 +596,22 @@ sal_Bool Animation::Mirror( sal_uLong nMirrorFlags )
         }
     }
     else
-        bRet = sal_False;
+        bRet = false;
 
     return bRet;
 }
 
-sal_Bool Animation::Adjust( short nLuminancePercent, short nContrastPercent,
+bool Animation::Adjust( short nLuminancePercent, short nContrastPercent,
              short nChannelRPercent, short nChannelGPercent, short nChannelBPercent,
-             double fGamma, sal_Bool bInvert )
+             double fGamma, bool bInvert )
 {
-    DBG_ASSERT( !IsInAnimation(), "Animation modified while it is animated" );
+    SAL_WARN_IF( IsInAnimation(), "vcl", "Animation modified while it is animated" );
 
-    sal_Bool bRet;
+    bool bRet;
 
     if( !IsInAnimation() && !maList.empty() )
     {
-        bRet = sal_True;
+        bRet = true;
 
         for( size_t i = 0, n = maList.size(); ( i < n ) && bRet; ++i )
         {
@@ -673,39 +629,39 @@ sal_Bool Animation::Adjust( short nLuminancePercent, short nContrastPercent,
                            fGamma, bInvert );
     }
     else
-        bRet = sal_False;
+        bRet = false;
 
     return bRet;
 }
 
-sal_Bool Animation::Filter( BmpFilter eFilter, const BmpFilterParam* pFilterParam, const Link* pProgress )
+bool Animation::Filter( BmpFilter eFilter, const BmpFilterParam* pFilterParam )
 {
-    DBG_ASSERT( !IsInAnimation(), "Animation modified while it is animated" );
+    SAL_WARN_IF( IsInAnimation(), "vcl", "Animation modified while it is animated" );
 
-    sal_Bool bRet;
+    bool bRet;
 
     if( !IsInAnimation() && !maList.empty() )
     {
-        bRet = sal_True;
+        bRet = true;
 
         for( size_t i = 0, n = maList.size(); ( i < n ) && bRet; ++i )
-            bRet = maList[ i ]->aBmpEx.Filter( eFilter, pFilterParam, pProgress );
+            bRet = maList[ i ]->aBmpEx.Filter( eFilter, pFilterParam );
 
-        maBitmapEx.Filter( eFilter, pFilterParam, pProgress );
+        (void)maBitmapEx.Filter(eFilter, pFilterParam);
     }
     else
-        bRet = sal_False;
+        bRet = false;
 
     return bRet;
 }
 
-SvStream& operator<<( SvStream& rOStm, const Animation& rAnimation )
+SvStream& WriteAnimation( SvStream& rOStm, const Animation& rAnimation )
 {
     const sal_uInt16 nCount = rAnimation.Count();
 
     if( nCount )
     {
-        const sal_uInt32    nDummy32 = 0UL;
+        const sal_uInt32    nDummy32 = 0;
 
         // If no BitmapEx was set we write the first Bitmap of
         // the Animation
@@ -715,7 +671,7 @@ SvStream& operator<<( SvStream& rOStm, const Animation& rAnimation )
             WriteDIBBitmapEx(rAnimation.GetBitmapEx(), rOStm);
 
         // Write identifier ( SDANIMA1 )
-        rOStm << (sal_uInt32) 0x5344414e << (sal_uInt32) 0x494d4931;
+        rOStm.WriteUInt32( 0x5344414e ).WriteUInt32( 0x494d4931 );
 
         for( sal_uInt16 i = 0; i < nCount; i++ )
         {
@@ -724,35 +680,35 @@ SvStream& operator<<( SvStream& rOStm, const Animation& rAnimation )
 
             // Write AnimationBitmap
             WriteDIBBitmapEx(rAnimBmp.aBmpEx, rOStm);
-            rOStm << rAnimBmp.aPosPix;
-            rOStm << rAnimBmp.aSizePix;
-            rOStm << rAnimation.maGlobalSize;
-            rOStm << (sal_uInt16) ( ( ANIMATION_TIMEOUT_ON_CLICK == rAnimBmp.nWait ) ? 65535 : rAnimBmp.nWait );
-            rOStm << (sal_uInt16) rAnimBmp.eDisposal;
-            rOStm << (sal_uInt8) rAnimBmp.bUserInput;
-            rOStm << (sal_uInt32) rAnimation.mnLoopCount;
-            rOStm << nDummy32; // Unused
-            rOStm << nDummy32; // Unused
-            rOStm << nDummy32; // Unused
-            write_lenPrefixed_uInt8s_FromOString<sal_uInt16>(rOStm, OString()); // dummy
-            rOStm << nRest; // Count of remaining structures
+            WritePair( rOStm, rAnimBmp.aPosPix );
+            WritePair( rOStm, rAnimBmp.aSizePix );
+            WritePair( rOStm, rAnimation.maGlobalSize );
+            rOStm.WriteUInt16( ( ANIMATION_TIMEOUT_ON_CLICK == rAnimBmp.nWait ) ? 65535 : rAnimBmp.nWait );
+            rOStm.WriteUInt16( (sal_uInt16)rAnimBmp.eDisposal );
+            rOStm.WriteBool( rAnimBmp.bUserInput );
+            rOStm.WriteUInt32( rAnimation.mnLoopCount );
+            rOStm.WriteUInt32( nDummy32 ); // Unused
+            rOStm.WriteUInt32( nDummy32 ); // Unused
+            rOStm.WriteUInt32( nDummy32 ); // Unused
+            write_uInt16_lenPrefixed_uInt8s_FromOString(rOStm, OString()); // dummy
+            rOStm.WriteUInt16( nRest ); // Count of remaining structures
         }
     }
 
     return rOStm;
 }
 
-SvStream& operator>>( SvStream& rIStm, Animation& rAnimation )
+SvStream& ReadAnimation( SvStream& rIStm, Animation& rAnimation )
 {
-    Bitmap  aBmp;
-    sal_uLong   nStmPos = rIStm.Tell();
+    Bitmap      aBmp;
+    sal_uLong   nStmPos;
     sal_uInt32  nAnimMagic1, nAnimMagic2;
-    sal_uInt16  nOldFormat = rIStm.GetNumberFormatInt();
-    bool    bReadAnimations = false;
+    SvStreamEndian nOldFormat = rIStm.GetEndian();
+    bool        bReadAnimations = false;
 
-    rIStm.SetNumberFormatInt( NUMBERFORMAT_INT_LITTLEENDIAN );
+    rIStm.SetEndian( SvStreamEndian::LITTLE );
     nStmPos = rIStm.Tell();
-    rIStm >> nAnimMagic1 >> nAnimMagic2;
+    rIStm.ReadUInt32( nAnimMagic1 ).ReadUInt32( nAnimMagic2 );
 
     rAnimation.Clear();
 
@@ -766,7 +722,7 @@ SvStream& operator>>( SvStream& rIStm, Animation& rAnimation )
         rIStm.Seek( nStmPos );
         ReadDIBBitmapEx(rAnimation.maBitmapEx, rIStm);
         nStmPos = rIStm.Tell();
-        rIStm >> nAnimMagic1 >> nAnimMagic2;
+        rIStm.ReadUInt32( nAnimMagic1 ).ReadUInt32( nAnimMagic2 );
 
         if( ( nAnimMagic1 == 0x5344414e ) && ( nAnimMagic2 == 0x494d4931 ) && !rIStm.GetError() )
             bReadAnimations = true;
@@ -781,23 +737,23 @@ SvStream& operator>>( SvStream& rIStm, Animation& rAnimation )
         BitmapEx        aBmpEx;
         sal_uInt32          nTmp32;
         sal_uInt16          nTmp16;
-        sal_uInt8           cTmp;
+        bool           cTmp;
 
         do
         {
             ReadDIBBitmapEx(aAnimBmp.aBmpEx, rIStm);
-            rIStm >> aAnimBmp.aPosPix;
-            rIStm >> aAnimBmp.aSizePix;
-            rIStm >> rAnimation.maGlobalSize;
-            rIStm >> nTmp16; aAnimBmp.nWait = ( ( 65535 == nTmp16 ) ? ANIMATION_TIMEOUT_ON_CLICK : nTmp16 );
-            rIStm >> nTmp16; aAnimBmp.eDisposal = ( Disposal) nTmp16;
-            rIStm >> cTmp; aAnimBmp.bUserInput = (sal_Bool) cTmp;
-            rIStm >> nTmp32; rAnimation.mnLoopCount = (sal_uInt16) nTmp32;
-            rIStm >> nTmp32; // Unused
-            rIStm >> nTmp32; // Unused
-            rIStm >> nTmp32; // Unused
-            read_lenPrefixed_uInt8s_ToOString<sal_uInt16>(rIStm); // Unused
-            rIStm >> nTmp16; // The rest to read
+            ReadPair( rIStm, aAnimBmp.aPosPix );
+            ReadPair( rIStm, aAnimBmp.aSizePix );
+            ReadPair( rIStm, rAnimation.maGlobalSize );
+            rIStm.ReadUInt16( nTmp16 ); aAnimBmp.nWait = ( ( 65535 == nTmp16 ) ? ANIMATION_TIMEOUT_ON_CLICK : nTmp16 );
+            rIStm.ReadUInt16( nTmp16 ); aAnimBmp.eDisposal = ( Disposal) nTmp16;
+            rIStm.ReadCharAsBool( cTmp ); aAnimBmp.bUserInput = cTmp;
+            rIStm.ReadUInt32( rAnimation.mnLoopCount );
+            rIStm.ReadUInt32( nTmp32 ); // Unused
+            rIStm.ReadUInt32( nTmp32 ); // Unused
+            rIStm.ReadUInt32( nTmp32 ); // Unused
+            read_uInt16_lenPrefixed_uInt8s_ToOString(rIStm); // Unused
+            rIStm.ReadUInt16( nTmp16 ); // The rest to read
 
             rAnimation.Insert( aAnimBmp );
         }
@@ -806,9 +762,14 @@ SvStream& operator>>( SvStream& rIStm, Animation& rAnimation )
         rAnimation.ResetLoopCount();
     }
 
-    rIStm.SetNumberFormatInt( nOldFormat );
+    rIStm.SetEndian( nOldFormat );
 
     return rIStm;
 }
 
+AInfo::AInfo() : pOutDev( nullptr ),
+                              pViewData( nullptr ),
+                              nExtraData( 0 ),
+                              bPause( false ) {}
+
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
