@@ -17,9 +17,10 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
+#include <memory>
 #include <stdlib.h>
 #include <osl/diagnose.h>
-#include <vcl/bmpacc.hxx>
+#include <vcl/bitmapaccess.hxx>
 #include <vcl/bitmap.hxx>
 
 #define S2(a,b)             { long t; if( ( t = b - a ) < 0 ) { a += t; b -= t; } }
@@ -44,7 +45,7 @@ bool Bitmap::Filter( BmpFilter eFilter, const BmpFilterParam* pFilterParam )
 
     switch( eFilter )
     {
-        case( BMP_FILTER_SMOOTH ):
+        case BmpFilter::Smooth:
         {
             // Blur for positive values of mnRadius
             if (pFilterParam->mnRadius > 0.0)
@@ -63,42 +64,42 @@ bool Bitmap::Filter( BmpFilter eFilter, const BmpFilterParam* pFilterParam )
         }
         break;
 
-        case( BMP_FILTER_SHARPEN ):
+        case BmpFilter::Sharpen:
         {
             const long pSharpenMatrix[] = { -1, -1,  -1, -1, 16, -1, -1, -1,  -1 };
-            bRet = ImplConvolute3( &pSharpenMatrix[ 0 ], 8 );
+            bRet = ImplConvolute3( &pSharpenMatrix[ 0 ] );
         }
         break;
 
-        case( BMP_FILTER_REMOVENOISE ):
+        case BmpFilter::RemoveNoise:
             bRet = ImplMedianFilter();
         break;
 
-        case( BMP_FILTER_SOBEL_GREY ):
+        case BmpFilter::SobelGrey:
             bRet = ImplSobelGrey();
         break;
 
-        case( BMP_FILTER_SOLARIZE ):
+        case BmpFilter::Solarize:
             bRet = ImplSolarize( pFilterParam );
         break;
 
-        case( BMP_FILTER_SEPIA ):
+        case BmpFilter::Sepia:
             bRet = ImplSepia( pFilterParam );
         break;
 
-        case( BMP_FILTER_MOSAIC ):
+        case BmpFilter::Mosaic:
             bRet = ImplMosaic( pFilterParam );
         break;
 
-        case( BMP_FILTER_EMBOSS_GREY ):
+        case BmpFilter::EmbossGrey:
             bRet = ImplEmbossGrey( pFilterParam );
         break;
 
-        case( BMP_FILTER_POPART ):
+        case BmpFilter::PopArt:
             bRet = ImplPopArt();
         break;
 
-        case( BMP_FILTER_DUOTONE ):
+        case BmpFilter::DuoTone:
             bRet = ImplDuotoneFilter( pFilterParam->mnProgressStart, pFilterParam->mnProgressEnd );
         break;
 
@@ -110,15 +111,16 @@ bool Bitmap::Filter( BmpFilter eFilter, const BmpFilterParam* pFilterParam )
     return bRet;
 }
 
-bool Bitmap::ImplConvolute3( const long* pMatrix, long nDivisor )
+bool Bitmap::ImplConvolute3( const long* pMatrix )
 {
-    BitmapReadAccess*   pReadAcc = AcquireReadAccess();
+    const long          nDivisor = 8;
+    ScopedReadAccess    pReadAcc(*this);
     bool                bRet = false;
 
     if( pReadAcc )
     {
         Bitmap              aNewBmp( GetSizePixel(), 24 );
-        BitmapWriteAccess*  pWriteAcc = aNewBmp.AcquireWriteAccess();
+        ScopedWriteAccess   pWriteAcc(aNewBmp);
 
         if( pWriteAcc )
         {
@@ -215,11 +217,23 @@ bool Bitmap::ImplConvolute3( const long* pMatrix, long nDivisor )
                 if( ++nY < nHeight )
                 {
                     if( pRowTmp1 == pColRow1 )
-                        pRowTmp1 = pColRow2, pRowTmp2 = pColRow3, pRowTmp3 = pColRow1;
+                    {
+                        pRowTmp1 = pColRow2;
+                        pRowTmp2 = pColRow3;
+                        pRowTmp3 = pColRow1;
+                    }
                     else if( pRowTmp1 == pColRow2 )
-                        pRowTmp1 = pColRow3, pRowTmp2 = pColRow1, pRowTmp3 = pColRow2;
+                    {
+                        pRowTmp1 = pColRow3;
+                        pRowTmp2 = pColRow1;
+                        pRowTmp3 = pColRow2;
+                    }
                     else
-                        pRowTmp1 = pColRow1, pRowTmp2 = pColRow2, pRowTmp3 = pColRow3;
+                    {
+                        pRowTmp1 = pColRow1;
+                        pRowTmp2 = pColRow2;
+                        pRowTmp3 = pColRow3;
+                    }
 
                     for( i = 0; i < nWidth2; i++ )
                         pRowTmp3[ i ] = pReadAcc->GetColor( pRows[ nY + 2 ], pColm[ i ] );
@@ -233,12 +247,12 @@ bool Bitmap::ImplConvolute3( const long* pMatrix, long nDivisor )
             delete[] pColm;
             delete[] pRows;
 
-            Bitmap::ReleaseAccess( pWriteAcc );
+            pWriteAcc.reset();
 
             bRet = true;
         }
 
-        ReleaseAccess( pReadAcc );
+        pReadAcc.reset();
 
         if( bRet )
         {
@@ -257,13 +271,13 @@ bool Bitmap::ImplConvolute3( const long* pMatrix, long nDivisor )
 
 bool Bitmap::ImplMedianFilter()
 {
-    BitmapReadAccess*   pReadAcc = AcquireReadAccess();
+    ScopedReadAccess    pReadAcc(*this);
     bool                bRet = false;
 
     if( pReadAcc )
     {
         Bitmap              aNewBmp( GetSizePixel(), 24 );
-        BitmapWriteAccess*  pWriteAcc = aNewBmp.AcquireWriteAccess();
+        ScopedWriteAccess   pWriteAcc(aNewBmp);
 
         if( pWriteAcc )
         {
@@ -311,17 +325,35 @@ bool Bitmap::ImplMedianFilter()
             {
                 for( nX = 0; nX < nWidth; nX++ )
                 {
-                    nR1 = ( pColor = pRowTmp1 + nX )->GetRed(), nG1 = pColor->GetGreen(), nB1 = pColor->GetBlue();
-                    nR2 = ( ++pColor )->GetRed(), nG2 = pColor->GetGreen(), nB2 = pColor->GetBlue();
-                    nR3 = ( ++pColor )->GetRed(), nG3 = pColor->GetGreen(), nB3 = pColor->GetBlue();
+                    nR1 = ( pColor = pRowTmp1 + nX )->GetRed();
+                    nG1 = pColor->GetGreen();
+                    nB1 = pColor->GetBlue();
+                    nR2 = ( ++pColor )->GetRed();
+                    nG2 = pColor->GetGreen();
+                    nB2 = pColor->GetBlue();
+                    nR3 = ( ++pColor )->GetRed();
+                    nG3 = pColor->GetGreen();
+                    nB3 = pColor->GetBlue();
 
-                    nR4 = ( pColor = pRowTmp2 + nX )->GetRed(), nG4 = pColor->GetGreen(), nB4 = pColor->GetBlue();
-                    nR5 = ( ++pColor )->GetRed(), nG5 = pColor->GetGreen(), nB5 = pColor->GetBlue();
-                    nR6 = ( ++pColor )->GetRed(), nG6 = pColor->GetGreen(), nB6 = pColor->GetBlue();
+                    nR4 = ( pColor = pRowTmp2 + nX )->GetRed();
+                    nG4 = pColor->GetGreen();
+                    nB4 = pColor->GetBlue();
+                    nR5 = ( ++pColor )->GetRed();
+                    nG5 = pColor->GetGreen();
+                    nB5 = pColor->GetBlue();
+                    nR6 = ( ++pColor )->GetRed();
+                    nG6 = pColor->GetGreen();
+                    nB6 = pColor->GetBlue();
 
-                    nR7 = ( pColor = pRowTmp3 + nX )->GetRed(), nG7 = pColor->GetGreen(), nB7 = pColor->GetBlue();
-                    nR8 = ( ++pColor )->GetRed(), nG8 = pColor->GetGreen(), nB8 = pColor->GetBlue();
-                    nR9 = ( ++pColor )->GetRed(), nG9 = pColor->GetGreen(), nB9 = pColor->GetBlue();
+                    nR7 = ( pColor = pRowTmp3 + nX )->GetRed();
+                    nG7 = pColor->GetGreen();
+                    nB7 = pColor->GetBlue();
+                    nR8 = ( ++pColor )->GetRed();
+                    nG8 = pColor->GetGreen();
+                    nB8 = pColor->GetBlue();
+                    nR9 = ( ++pColor )->GetRed();
+                    nG9 = pColor->GetGreen();
+                    nB9 = pColor->GetBlue();
 
                     MNMX6( nR1, nR2, nR3, nR4, nR5, nR6 );
                     MNMX5( nR7, nR2, nR3, nR4, nR5 );
@@ -345,11 +377,23 @@ bool Bitmap::ImplMedianFilter()
                 if( ++nY < nHeight )
                 {
                     if( pRowTmp1 == pColRow1 )
-                        pRowTmp1 = pColRow2, pRowTmp2 = pColRow3, pRowTmp3 = pColRow1;
+                    {
+                        pRowTmp1 = pColRow2;
+                        pRowTmp2 = pColRow3;
+                        pRowTmp3 = pColRow1;
+                    }
                     else if( pRowTmp1 == pColRow2 )
-                        pRowTmp1 = pColRow3, pRowTmp2 = pColRow1, pRowTmp3 = pColRow2;
+                    {
+                        pRowTmp1 = pColRow3;
+                        pRowTmp2 = pColRow1;
+                        pRowTmp3 = pColRow2;
+                    }
                     else
-                        pRowTmp1 = pColRow1, pRowTmp2 = pColRow2, pRowTmp3 = pColRow3;
+                    {
+                        pRowTmp1 = pColRow1;
+                        pRowTmp2 = pColRow2;
+                        pRowTmp3 = pColRow3;
+                    }
 
                     for( i = 0; i < nWidth2; i++ )
                         pRowTmp3[ i ] = pReadAcc->GetColor( pRows[ nY + 2 ], pColm[ i ] );
@@ -362,12 +406,12 @@ bool Bitmap::ImplMedianFilter()
             delete[] pColm;
             delete[] pRows;
 
-            Bitmap::ReleaseAccess( pWriteAcc );
+            pWriteAcc.reset();
 
             bRet = true;
         }
 
-        ReleaseAccess( pReadAcc );
+        pReadAcc.reset();
 
         if( bRet )
         {
@@ -392,12 +436,12 @@ bool Bitmap::ImplSobelGrey()
     {
         bRet = false;
 
-        BitmapReadAccess* pReadAcc = AcquireReadAccess();
+        ScopedReadAccess pReadAcc(*this);
 
         if( pReadAcc )
         {
             Bitmap              aNewBmp( GetSizePixel(), 8, &pReadAcc->GetPalette() );
-            BitmapWriteAccess*  pWriteAcc = aNewBmp.AcquireWriteAccess();
+            ScopedWriteAccess   pWriteAcc(aNewBmp);
 
             if( pWriteAcc )
             {
@@ -488,11 +532,11 @@ bool Bitmap::ImplSobelGrey()
 
                 delete[] pHMap;
                 delete[] pVMap;
-                Bitmap::ReleaseAccess( pWriteAcc );
+                pWriteAcc.reset();
                 bRet = true;
             }
 
-            ReleaseAccess( pReadAcc );
+            pReadAcc.reset();
 
             if( bRet )
             {
@@ -518,12 +562,12 @@ bool Bitmap::ImplEmbossGrey( const BmpFilterParam* pFilterParam )
     {
         bRet = false;
 
-        BitmapReadAccess* pReadAcc = AcquireReadAccess();
+        ScopedReadAccess pReadAcc(*this);
 
         if( pReadAcc )
         {
             Bitmap              aNewBmp( GetSizePixel(), 8, &pReadAcc->GetPalette() );
-            BitmapWriteAccess*  pWriteAcc = aNewBmp.AcquireWriteAccess();
+            ScopedWriteAccess   pWriteAcc(aNewBmp);
 
             if( pWriteAcc )
             {
@@ -533,9 +577,9 @@ bool Bitmap::ImplEmbossGrey( const BmpFilterParam* pFilterParam )
                 long        nGrey11, nGrey12, nGrey13;
                 long        nGrey21, nGrey22, nGrey23;
                 long        nGrey31, nGrey32, nGrey33;
-                double      fAzim = ( ( pFilterParam && pFilterParam->meFilter == BMP_FILTER_EMBOSS_GREY ) ?
+                double      fAzim = ( ( pFilterParam && pFilterParam->meFilter == BmpFilter::EmbossGrey ) ?
                                       ( pFilterParam->maEmbossAngles.mnAzimuthAngle100 * 0.01 ) : 0.0 ) * F_PI180;
-                double      fElev = ( ( pFilterParam && pFilterParam->meFilter == BMP_FILTER_EMBOSS_GREY ) ?
+                double      fElev = ( ( pFilterParam && pFilterParam->meFilter == BmpFilter::EmbossGrey ) ?
                                       ( pFilterParam->maEmbossAngles.mnElevationAngle100 * 0.01 ) : 90.0 ) * F_PI180;
                 long*       pHMap = new long[ nWidth + 2 ];
                 long*       pVMap = new long[ nHeight + 2 ];
@@ -543,7 +587,7 @@ bool Bitmap::ImplEmbossGrey( const BmpFilterParam* pFilterParam )
                 const long  nLx = FRound( cos( fAzim ) * cos( fElev ) * 255.0 );
                 const long  nLy = FRound( sin( fAzim ) * cos( fElev ) * 255.0 );
                 const long  nLz = FRound( sin( fElev ) * 255.0 );
-                const long  nZ2 = ( ( 6 * 255 ) / 4 ) * ( ( 6 * 255 ) / 4 );
+                const auto  nZ2 = ( ( 6 * 255 ) / 4 ) * ( ( 6 * 255 ) / 4 );
                 const long  nNzLz = ( ( 6 * 255 ) / 4 ) * nLz;
                 const sal_uInt8 cLz = (sal_uInt8) SAL_BOUND( nLz, 0, 255 );
 
@@ -600,11 +644,11 @@ bool Bitmap::ImplEmbossGrey( const BmpFilterParam* pFilterParam )
 
                 delete[] pHMap;
                 delete[] pVMap;
-                Bitmap::ReleaseAccess( pWriteAcc );
+                pWriteAcc.reset();
                 bRet = true;
             }
 
-            ReleaseAccess( pReadAcc );
+            pReadAcc.reset();
 
             if( bRet )
             {
@@ -625,11 +669,11 @@ bool Bitmap::ImplEmbossGrey( const BmpFilterParam* pFilterParam )
 bool Bitmap::ImplSolarize( const BmpFilterParam* pFilterParam )
 {
     bool                bRet = false;
-    BitmapWriteAccess*  pWriteAcc = AcquireWriteAccess();
+    ScopedWriteAccess   pWriteAcc(*this);
 
     if( pWriteAcc )
     {
-        const sal_uInt8 cThreshold = ( pFilterParam && pFilterParam->meFilter == BMP_FILTER_SOLARIZE ) ?
+        const sal_uInt8 cThreshold = ( pFilterParam && pFilterParam->meFilter == BmpFilter::Solarize ) ?
                                 pFilterParam->mcSolarGreyThreshold : 128;
 
         if( pWriteAcc->HasPalette() )
@@ -663,7 +707,7 @@ bool Bitmap::ImplSolarize( const BmpFilterParam* pFilterParam )
             }
         }
 
-        ReleaseAccess( pWriteAcc );
+        pWriteAcc.reset();
         bRet = true;
     }
 
@@ -672,22 +716,20 @@ bool Bitmap::ImplSolarize( const BmpFilterParam* pFilterParam )
 
 bool Bitmap::ImplSepia( const BmpFilterParam* pFilterParam )
 {
-    BitmapReadAccess*   pReadAcc = AcquireReadAccess();
+    ScopedReadAccess    pReadAcc(*this);
     bool                bRet = false;
 
     if( pReadAcc )
     {
-        long            nSepiaPercent = ( pFilterParam && pFilterParam->meFilter == BMP_FILTER_SEPIA ) ?
-                                        pFilterParam->mcSolarGreyThreshold : 10;
+        long            nSepiaPercent = ( pFilterParam && pFilterParam->meFilter == BmpFilter::Sepia ) ?
+                                        pFilterParam->mnSepiaPercent : 10;
         const long      nSepia = 10000 - 100 * SAL_BOUND( nSepiaPercent, 0, 100 );
         BitmapPalette   aSepiaPal( 256 );
 
-        DBG_ASSERT( nSepiaPercent <= 100, "Bitmap::ImplSepia(): sepia value out of range; defaulting to 100%" );
-
         for( sal_uInt16 i = 0; i < 256; i++ )
         {
             BitmapColor&    rCol = aSepiaPal[ i ];
-            const sal_uInt8     cSepiaValue = (sal_uInt8) ( ( nSepia * i ) / 10000 );
+            const sal_uInt8 cSepiaValue = (sal_uInt8) ( nSepia * i / 10000 );
 
             rCol.SetRed( (sal_uInt8) i );
             rCol.SetGreen( cSepiaValue );
@@ -695,7 +737,7 @@ bool Bitmap::ImplSepia( const BmpFilterParam* pFilterParam )
         }
 
         Bitmap              aNewBmp( GetSizePixel(), 8, &aSepiaPal );
-        BitmapWriteAccess*  pWriteAcc = aNewBmp.AcquireWriteAccess();
+        ScopedWriteAccess   pWriteAcc(aNewBmp);
 
         if( pWriteAcc )
         {
@@ -707,8 +749,8 @@ bool Bitmap::ImplSepia( const BmpFilterParam* pFilterParam )
             {
                 for( long nY = 0; nY < nHeight ; nY++ )
                 {
-                    const sal_uInt16    nPalCount = pReadAcc->GetPaletteEntryCount();
-                    sal_uInt8*          pIndexMap = new sal_uInt8[ nPalCount ];
+                    const sal_uInt16             nPalCount = pReadAcc->GetPaletteEntryCount();
+                    std::unique_ptr<sal_uInt8[]> pIndexMap( new sal_uInt8[ nPalCount ] );
 
                     for( sal_uInt16 i = 0; i < nPalCount; i++ )
                         pIndexMap[ i ] = pReadAcc->GetPaletteColor( i ).GetLuminance();
@@ -718,8 +760,6 @@ bool Bitmap::ImplSepia( const BmpFilterParam* pFilterParam )
                         aCol.SetIndex( pIndexMap[ pReadAcc->GetPixel( nY, nX ).GetIndex() ] );
                         pWriteAcc->SetPixel( nY, nX, aCol );
                     }
-
-                    delete[] pIndexMap;
                 }
             }
             else
@@ -734,11 +774,11 @@ bool Bitmap::ImplSepia( const BmpFilterParam* pFilterParam )
                 }
             }
 
-            Bitmap::ReleaseAccess( pWriteAcc );
+            pWriteAcc.reset();
             bRet = true;
         }
 
-        ReleaseAccess( pReadAcc );
+        pReadAcc.reset();
 
         if( bRet )
         {
@@ -757,9 +797,9 @@ bool Bitmap::ImplSepia( const BmpFilterParam* pFilterParam )
 
 bool Bitmap::ImplMosaic( const BmpFilterParam* pFilterParam )
 {
-    sal_uLong               nTileWidth = ( pFilterParam && pFilterParam->meFilter == BMP_FILTER_MOSAIC ) ?
+    sal_uLong               nTileWidth = ( pFilterParam && pFilterParam->meFilter == BmpFilter::Mosaic ) ?
                                      pFilterParam->maMosaicTileSize.mnTileWidth : 4;
-    sal_uLong               nTileHeight = ( pFilterParam && pFilterParam->meFilter == BMP_FILTER_MOSAIC ) ?
+    sal_uLong               nTileHeight = ( pFilterParam && pFilterParam->meFilter == BmpFilter::Mosaic ) ?
                                       pFilterParam->maMosaicTileSize.mnTileHeight : 4;
     bool                bRet = false;
 
@@ -920,6 +960,7 @@ bool Bitmap::ImplMosaic( const BmpFilterParam* pFilterParam )
     return bRet;
 }
 
+
 struct PopArtEntry
 {
     sal_uInt32  mnIndex;
@@ -943,13 +984,13 @@ extern "C" int SAL_CALL ImplPopArtCmpFnc( const void* p1, const void* p2 )
 bool Bitmap::ImplPopArt()
 {
     /* note: GetBitCount() after that is no more than 8 */
-    bool bRet = ( GetBitCount() <= 8 ) || Convert( BMP_CONVERSION_8BIT_COLORS );
+    bool bRet = ( GetBitCount() <= 8 ) || Convert( BmpConversion::N8BitColors );
 
     if( bRet )
     {
         bRet = false;
 
-        BitmapWriteAccess* pWriteAcc = AcquireWriteAccess();
+        ScopedWriteAccess pWriteAcc(*this);
 
         if( pWriteAcc )
         {
@@ -993,7 +1034,7 @@ bool Bitmap::ImplPopArt()
 
             // cleanup
             delete[] pPopArtTable;
-            ReleaseAccess( pWriteAcc );
+            pWriteAcc.reset();
             bRet = true;
         }
     }
@@ -1023,7 +1064,7 @@ double* MakeBlurKernel(const double radius, int& rows) {
 }
 
 void Bitmap::ImplBlurContributions( const int aSize, const int aNumberOfContributions,
-                                    double* pBlurVector, double*& pWeights, int*& pPixels, int*& pCount )
+                                    const double* pBlurVector, double*& pWeights, int*& pPixels, int*& pCount )
 {
     pWeights = new double[ aSize*aNumberOfContributions ];
     pPixels = new int[ aSize*aNumberOfContributions ];
@@ -1034,8 +1075,8 @@ void Bitmap::ImplBlurContributions( const int aSize, const int aNumberOfContribu
 
     for ( int i = 0; i < aSize; i++ )
     {
-        aLeft = (int)  i - aNumberOfContributions / 2;
-        aRight = (int) i + aNumberOfContributions / 2;
+        aLeft  = i - aNumberOfContributions / 2;
+        aRight = i + aNumberOfContributions / 2;
         aCurrentCount = 0;
         for ( int j = aLeft; j <= aRight; j++ )
         {
@@ -1094,15 +1135,15 @@ bool Bitmap::ImplSeparableBlurFilter(const double radius)
     // Do horizontal filtering
     ImplBlurContributions( nWidth, aNumberOfContributions, pBlurVector, pWeights, pPixels, pCount);
 
-    BitmapReadAccess* pReadAcc = AcquireReadAccess();
+    ScopedReadAccess pReadAcc(*this);
 
     // switch coordinates as convolution pass transposes result
     Bitmap aNewBitmap( Size( nHeight, nWidth ), 24 );
 
-    bool bResult = ImplConvolutionPass( aNewBitmap, pReadAcc, aNumberOfContributions, pWeights, pPixels, pCount );
+    bool bResult = ImplConvolutionPass( aNewBitmap, pReadAcc.get(), aNumberOfContributions, pWeights, pPixels, pCount );
 
     // Cleanup
-    ReleaseAccess( pReadAcc );
+    pReadAcc.reset();
     delete[] pWeights;
     delete[] pPixels;
     delete[] pCount;
@@ -1119,12 +1160,12 @@ bool Bitmap::ImplSeparableBlurFilter(const double radius)
     // Do vertical filtering
     ImplBlurContributions(nHeight, aNumberOfContributions, pBlurVector, pWeights, pPixels, pCount );
 
-    pReadAcc = AcquireReadAccess();
+    pReadAcc = ScopedReadAccess(*this);
     aNewBitmap = Bitmap( Size( nWidth, nHeight ), 24 );
-    bResult = ImplConvolutionPass( aNewBitmap, pReadAcc, aNumberOfContributions, pWeights, pPixels, pCount );
+    bResult = ImplConvolutionPass( aNewBitmap, pReadAcc.get(), aNumberOfContributions, pWeights, pPixels, pCount );
 
     // Cleanup
-    ReleaseAccess( pReadAcc );
+    pReadAcc.reset();
     delete[] pWeights;
     delete[] pCount;
     delete[] pPixels;
@@ -1153,9 +1194,9 @@ bool Bitmap::ImplSeparableUnsharpenFilter(const double radius) {
 
     Bitmap aResultBitmap( Size( nWidth, nHeight ), 24);
 
-    BitmapReadAccess* pReadAccBlur = aBlur.AcquireReadAccess();
-    BitmapReadAccess* pReadAcc = AcquireReadAccess();
-    BitmapWriteAccess* pWriteAcc = aResultBitmap.AcquireWriteAccess();
+    ScopedReadAccess pReadAccBlur(aBlur);
+    ScopedReadAccess pReadAcc(*this);
+    ScopedWriteAccess pWriteAcc(aResultBitmap);
 
     BitmapColor aColor, aColorBlur;
 
@@ -1176,9 +1217,9 @@ bool Bitmap::ImplSeparableUnsharpenFilter(const double radius) {
         }
     }
 
-    ReleaseAccess( pWriteAcc );
-    ReleaseAccess( pReadAcc );
-    ReleaseAccess( pReadAccBlur );
+    pWriteAcc.reset();
+    pReadAcc.reset();
+    pReadAccBlur.reset();
     ImplAssignWithSize ( aResultBitmap );
     return true;
 }
@@ -1189,8 +1230,8 @@ bool Bitmap::ImplDuotoneFilter( const sal_uLong nColorOne, const sal_uLong nColo
     const long  nHeight = GetSizePixel().Height();
 
     Bitmap aResultBitmap( GetSizePixel(), 24);
-    BitmapReadAccess* pReadAcc = AcquireReadAccess();
-    BitmapWriteAccess* pWriteAcc = aResultBitmap.AcquireWriteAccess();
+    ScopedReadAccess pReadAcc(*this);
+    ScopedWriteAccess pWriteAcc(aResultBitmap);
     const BitmapColor aColorOne( static_cast< sal_uInt8 >( nColorOne >> 16 ), static_cast< sal_uInt8 >( nColorOne >> 8 ), static_cast< sal_uInt8 >( nColorOne ) );
     const BitmapColor aColorTwo( static_cast< sal_uInt8 >( nColorTwo >> 16 ), static_cast< sal_uInt8 >( nColorTwo >> 8 ), static_cast< sal_uInt8 >( nColorTwo ) );
 
@@ -1208,8 +1249,8 @@ bool Bitmap::ImplDuotoneFilter( const sal_uLong nColorOne, const sal_uLong nColo
         }
     }
 
-    ReleaseAccess( pWriteAcc );
-    ReleaseAccess( pReadAcc );
+    pWriteAcc.reset();
+    pReadAcc.reset();
     ImplAssignWithSize ( aResultBitmap );
     return true;
 }
