@@ -19,7 +19,6 @@
 
 #include <sal/types.h>
 
-#include <tools/resary.hxx>
 #include <tools/helpers.hxx>
 
 #include <vcl/virdev.hxx>
@@ -27,23 +26,24 @@
 
 #include <comphelper/processfactory.hxx>
 
-#include "salinst.hxx"
-#include "salvd.hxx"
-#include "salgdi.hxx"
-#include "salptype.hxx"
-#include "salprn.hxx"
-#include "svdata.hxx"
-#include "svids.hrc"
-#include "jobset.h"
-#include "outdev.h"
-#include "PhysicalFontCollection.hxx"
-#include "print.h"
+#include <salinst.hxx>
+#include <salvd.hxx>
+#include <salgdi.hxx>
+#include <salptype.hxx>
+#include <salprn.hxx>
+#include <svdata.hxx>
+#include <print.hrc>
+#include <strings.hrc>
+#include <jobset.h>
+#include <outdev.h>
+#include <PhysicalFontCollection.hxx>
+#include <print.h>
 
-#include "com/sun/star/beans/XPropertySet.hpp"
-#include "com/sun/star/configuration/theDefaultProvider.hpp"
-#include "com/sun/star/container/XNameAccess.hpp"
-#include "com/sun/star/lang/XMultiServiceFactory.hpp"
-#include "com/sun/star/uno/Sequence.h"
+#include <com/sun/star/beans/XPropertySet.hpp>
+#include <com/sun/star/configuration/theDefaultProvider.hpp>
+#include <com/sun/star/container/XNameAccess.hpp>
+#include <com/sun/star/lang/XMultiServiceFactory.hpp>
+#include <com/sun/star/uno/Sequence.h>
 
 int nImplSysDialog = 0;
 
@@ -241,7 +241,7 @@ void Printer::EmulateDrawTransparent ( const tools::PolyPolygon& rPolyPoly,
     mpAlphaVDev = pOldAlphaVDev;
 
     tools::Rectangle       aPolyRect( LogicToPixel( rPolyPoly ).GetBoundRect() );
-    const Size      aDPISize( LogicToPixel( Size( 1, 1 ), MapUnit::MapInch ) );
+    const Size      aDPISize( LogicToPixel(Size(1, 1), MapMode(MapUnit::MapInch)) );
     const long      nBaseExtent = std::max( FRound( aDPISize.Width() / 300. ), 1L );
     long            nMove;
     const sal_uInt16    nTrans = ( nTransparencePercent < 13 ) ? 0 :
@@ -374,12 +374,12 @@ ImplPrnQueueList::~ImplPrnQueueList()
 
 void ImplPrnQueueList::Add( SalPrinterQueueInfo* pData )
 {
-    std::unordered_map< OUString, sal_Int32, OUStringHash >::iterator it =
+    std::unordered_map< OUString, sal_Int32 >::iterator it =
         m_aNameToIndex.find( pData->maPrinterName );
     if( it == m_aNameToIndex.end() )
     {
         m_aNameToIndex[ pData->maPrinterName ] = m_aQueueInfos.size();
-        m_aQueueInfos.push_back( ImplPrnQueueData() );
+        m_aQueueInfos.emplace_back( );
         m_aQueueInfos.back().mpQueueInfo = nullptr;
         m_aQueueInfos.back().mpSalQueueInfo = pData;
         m_aPrinterList.push_back( pData->maPrinterName );
@@ -397,7 +397,7 @@ void ImplPrnQueueList::Add( SalPrinterQueueInfo* pData )
 ImplPrnQueueData* ImplPrnQueueList::Get( const OUString& rPrinter )
 {
     ImplPrnQueueData* pData = nullptr;
-    std::unordered_map<OUString,sal_Int32,OUStringHash>::iterator it =
+    std::unordered_map<OUString,sal_Int32>::iterator it =
         m_aNameToIndex.find( rPrinter );
     if( it != m_aNameToIndex.end() )
         pData = &m_aQueueInfos[it->second];
@@ -482,9 +482,7 @@ void Printer::ImplInitData()
     mbDevOutput         = false;
     meOutDevType        = OUTDEV_PRINTER;
     mbDefPrinter        = false;
-    mnError             = 0;
-    mnCurPage           = 0;
-    mnCurPrintPage      = 0;
+    mnError             = ERRCODE_NONE;
     mnPageQueueSize     = 0;
     mnCopyCount         = 1;
     mbCollateCopy       = false;
@@ -743,82 +741,83 @@ void Printer::DrawDeviceMask( const Bitmap& rMask, const Color& rMaskColor,
 
     aSrcRect.Justify();
 
-    if( !rMask.IsEmpty() && aSrcRect.GetWidth() && aSrcRect.GetHeight() && aDestSz.Width() && aDestSz.Height() )
+    if( !(!rMask.IsEmpty() && aSrcRect.GetWidth() && aSrcRect.GetHeight() && aDestSz.Width() && aDestSz.Height()) )
+        return;
+
+    Bitmap  aMask( rMask );
+    BmpMirrorFlags nMirrFlags = BmpMirrorFlags::NONE;
+
+    if( aMask.GetBitCount() > 1 )
+        aMask.Convert( BmpConversion::N1BitThreshold );
+
+    // mirrored horizontically
+    if( aDestSz.Width() < 0 )
     {
-        Bitmap  aMask( rMask );
-        BmpMirrorFlags nMirrFlags = BmpMirrorFlags::NONE;
-
-        if( aMask.GetBitCount() > 1 )
-            aMask.Convert( BmpConversion::N1BitThreshold );
-
-        // mirrored horizontically
-        if( aDestSz.Width() < 0 )
-        {
-            aDestSz.Width() = -aDestSz.Width();
-            aDestPt.X() -= ( aDestSz.Width() - 1 );
-            nMirrFlags |= BmpMirrorFlags::Horizontal;
-        }
-
-        // mirrored vertically
-        if( aDestSz.Height() < 0 )
-        {
-            aDestSz.Height() = -aDestSz.Height();
-            aDestPt.Y() -= ( aDestSz.Height() - 1 );
-            nMirrFlags |= BmpMirrorFlags::Vertical;
-        }
-
-        // source cropped?
-        if( aSrcRect != tools::Rectangle( aPt, aMask.GetSizePixel() ) )
-            aMask.Crop( aSrcRect );
-
-        // destination mirrored
-        if( nMirrFlags != BmpMirrorFlags::NONE)
-            aMask.Mirror( nMirrFlags );
-
-        // do painting
-        const long      nSrcWidth = aSrcRect.GetWidth(), nSrcHeight = aSrcRect.GetHeight();
-        long            nX, nY; //, nWorkX, nWorkY, nWorkWidth, nWorkHeight;
-        long*           pMapX = new long[ nSrcWidth + 1 ];
-        long*           pMapY = new long[ nSrcHeight + 1 ];
-        GDIMetaFile*    pOldMetaFile = mpMetaFile;
-        const bool      bOldMap = mbMap;
-
-        mpMetaFile = nullptr;
-        mbMap = false;
-        Push( PushFlags::FILLCOLOR | PushFlags::LINECOLOR );
-        SetLineColor( rMaskColor );
-        SetFillColor( rMaskColor );
-        InitLineColor();
-        InitFillColor();
-
-        // create forward mapping tables
-        for( nX = 0; nX <= nSrcWidth; nX++ )
-            pMapX[ nX ] = aDestPt.X() + FRound( (double) aDestSz.Width() * nX / nSrcWidth );
-
-        for( nY = 0; nY <= nSrcHeight; nY++ )
-            pMapY[ nY ] = aDestPt.Y() + FRound( (double) aDestSz.Height() * nY / nSrcHeight );
-
-        // walk through all rectangles of mask
-        const vcl::Region aWorkRgn(aMask.CreateRegion(COL_BLACK, tools::Rectangle(Point(), aMask.GetSizePixel())));
-        RectangleVector aRectangles;
-        aWorkRgn.GetRegionRectangles(aRectangles);
-
-        for(RectangleVector::const_iterator aRectIter(aRectangles.begin()); aRectIter != aRectangles.end(); ++aRectIter)
-        {
-            const Point aMapPt(pMapX[aRectIter->Left()], pMapY[aRectIter->Top()]);
-            const Size aMapSz(
-                pMapX[aRectIter->Right() + 1] - aMapPt.X(),      // pMapX[L + W] -> L + ((R - L) + 1) -> R + 1
-                pMapY[aRectIter->Bottom() + 1] - aMapPt.Y());    // same for Y
-
-            DrawRect(tools::Rectangle(aMapPt, aMapSz));
-        }
-
-        Pop();
-        delete[] pMapX;
-        delete[] pMapY;
-        mbMap = bOldMap;
-        mpMetaFile = pOldMetaFile;
+        aDestSz.Width() = -aDestSz.Width();
+        aDestPt.X() -= ( aDestSz.Width() - 1 );
+        nMirrFlags |= BmpMirrorFlags::Horizontal;
     }
+
+    // mirrored vertically
+    if( aDestSz.Height() < 0 )
+    {
+        aDestSz.Height() = -aDestSz.Height();
+        aDestPt.Y() -= ( aDestSz.Height() - 1 );
+        nMirrFlags |= BmpMirrorFlags::Vertical;
+    }
+
+    // source cropped?
+    if( aSrcRect != tools::Rectangle( aPt, aMask.GetSizePixel() ) )
+        aMask.Crop( aSrcRect );
+
+    // destination mirrored
+    if( nMirrFlags != BmpMirrorFlags::NONE)
+        aMask.Mirror( nMirrFlags );
+
+    // do painting
+    const long      nSrcWidth = aSrcRect.GetWidth(), nSrcHeight = aSrcRect.GetHeight();
+    long            nX, nY; //, nWorkX, nWorkY, nWorkWidth, nWorkHeight;
+    long*           pMapX = new long[ nSrcWidth + 1 ];
+    long*           pMapY = new long[ nSrcHeight + 1 ];
+    GDIMetaFile*    pOldMetaFile = mpMetaFile;
+    const bool      bOldMap = mbMap;
+
+    mpMetaFile = nullptr;
+    mbMap = false;
+    Push( PushFlags::FILLCOLOR | PushFlags::LINECOLOR );
+    SetLineColor( rMaskColor );
+    SetFillColor( rMaskColor );
+    InitLineColor();
+    InitFillColor();
+
+    // create forward mapping tables
+    for( nX = 0; nX <= nSrcWidth; nX++ )
+        pMapX[ nX ] = aDestPt.X() + FRound( (double) aDestSz.Width() * nX / nSrcWidth );
+
+    for( nY = 0; nY <= nSrcHeight; nY++ )
+        pMapY[ nY ] = aDestPt.Y() + FRound( (double) aDestSz.Height() * nY / nSrcHeight );
+
+    // walk through all rectangles of mask
+    const vcl::Region aWorkRgn(aMask.CreateRegion(COL_BLACK, tools::Rectangle(Point(), aMask.GetSizePixel())));
+    RectangleVector aRectangles;
+    aWorkRgn.GetRegionRectangles(aRectangles);
+
+    for(RectangleVector::const_iterator aRectIter(aRectangles.begin()); aRectIter != aRectangles.end(); ++aRectIter)
+    {
+        const Point aMapPt(pMapX[aRectIter->Left()], pMapY[aRectIter->Top()]);
+        const Size aMapSz(
+            pMapX[aRectIter->Right() + 1] - aMapPt.X(),      // pMapX[L + W] -> L + ((R - L) + 1) -> R + 1
+            pMapY[aRectIter->Bottom() + 1] - aMapPt.Y());    // same for Y
+
+        DrawRect(tools::Rectangle(aMapPt, aMapSz));
+    }
+
+    Pop();
+    delete[] pMapX;
+    delete[] pMapY;
+    mbMap = bOldMap;
+    mpMetaFile = pOldMetaFile;
+
 }
 
 SalPrinterQueueInfo* Printer::ImplGetQueueInfo( const OUString& rPrinterName,
@@ -1431,7 +1430,7 @@ bool Printer::SetPaperSizeUser( const Size& rSize, bool bMatchNearest )
         return false;
 
     const Size aPixSize = LogicToPixel( rSize );
-    const Size aPageSize = PixelToLogic( aPixSize, MapUnit::Map100thMM );
+    const Size aPageSize = PixelToLogic(aPixSize, MapMode(MapUnit::Map100thMM));
     bool bNeedToChange(maJobSetup.ImplGetConstData().GetPaperWidth() != aPageSize.Width() ||
         maJobSetup.ImplGetConstData().GetPaperHeight() != aPageSize.Height());
 
@@ -1498,24 +1497,20 @@ OUString Printer::GetPaperName( Paper ePaper )
     if( ! pSVData->mpPaperNames )
     {
         pSVData->mpPaperNames = new std::unordered_map< int, OUString >;
-        if( ImplGetResMgr() )
+        static const int PaperIndex[] =
         {
-            ResStringArray aPaperStrings( VclResId( RID_STR_PAPERNAMES ) );
-            static const int PaperIndex[] =
-            {
-                PAPER_A0, PAPER_A1, PAPER_A2, PAPER_A3, PAPER_A4, PAPER_A5,
-                PAPER_B4_ISO, PAPER_B5_ISO, PAPER_LETTER, PAPER_LEGAL, PAPER_TABLOID,
-                PAPER_USER, PAPER_B6_ISO, PAPER_ENV_C4, PAPER_ENV_C5, PAPER_ENV_C6, PAPER_ENV_C65,
-                PAPER_ENV_DL, PAPER_SLIDE_DIA, PAPER_C, PAPER_D, PAPER_E,
-                PAPER_EXECUTIVE, PAPER_FANFOLD_LEGAL_DE, PAPER_ENV_MONARCH, PAPER_ENV_PERSONAL,
-                PAPER_ENV_9, PAPER_ENV_10, PAPER_ENV_11, PAPER_ENV_12, PAPER_KAI16,
-                PAPER_KAI32, PAPER_KAI32BIG, PAPER_B4_JIS, PAPER_B5_JIS, PAPER_B6_JIS,
-                PAPER_POSTCARD_JP
-            };
-            OSL_ENSURE( sal_uInt32(SAL_N_ELEMENTS(PaperIndex)) == aPaperStrings.Count(), "localized paper name count wrong" );
-            for( int i = 0; i < int(SAL_N_ELEMENTS(PaperIndex)); i++ )
-                (*pSVData->mpPaperNames)[PaperIndex[i]] = aPaperStrings.GetString(i);
-        }
+            PAPER_A0, PAPER_A1, PAPER_A2, PAPER_A3, PAPER_A4, PAPER_A5,
+            PAPER_B4_ISO, PAPER_B5_ISO, PAPER_LETTER, PAPER_LEGAL, PAPER_TABLOID,
+            PAPER_USER, PAPER_B6_ISO, PAPER_ENV_C4, PAPER_ENV_C5, PAPER_ENV_C6, PAPER_ENV_C65,
+            PAPER_ENV_DL, PAPER_SLIDE_DIA, PAPER_C, PAPER_D, PAPER_E,
+            PAPER_EXECUTIVE, PAPER_FANFOLD_LEGAL_DE, PAPER_ENV_MONARCH, PAPER_ENV_PERSONAL,
+            PAPER_ENV_9, PAPER_ENV_10, PAPER_ENV_11, PAPER_ENV_12, PAPER_KAI16,
+            PAPER_KAI32, PAPER_KAI32BIG, PAPER_B4_JIS, PAPER_B5_JIS, PAPER_B6_JIS,
+            PAPER_POSTCARD_JP
+        };
+        assert(SAL_N_ELEMENTS(PaperIndex) == SAL_N_ELEMENTS(RID_STR_PAPERNAMES) && "localized paper name count wrong");
+        for (size_t i = 0; i < SAL_N_ELEMENTS(PaperIndex); ++i)
+            (*pSVData->mpPaperNames)[PaperIndex[i]] = VclResId(RID_STR_PAPERNAMES[i]);
     }
 
     std::unordered_map<int,OUString>::const_iterator it = pSVData->mpPaperNames->find( (int)ePaper );
@@ -1524,7 +1519,7 @@ OUString Printer::GetPaperName( Paper ePaper )
 
 OUString Printer::GetPaperName() const
 {
-    Size  aPageSize = PixelToLogic( GetPaperSizePixel(), MapUnit::Map100thMM );
+    Size  aPageSize = PixelToLogic( GetPaperSizePixel(), MapMode(MapUnit::Map100thMM));
     Paper ePaper    = ImplGetPaperFormat( aPageSize.Width(), aPageSize.Height() );
     if( ePaper == PAPER_USER )
         ePaper = ImplGetPaperFormat( aPageSize.Height(), aPageSize.Width() );
@@ -1609,13 +1604,13 @@ bool Printer::SetCopyCount( sal_uInt16 nCopy, bool bCollate )
     return true;
 }
 
-sal_uLong Printer::ImplSalPrinterErrorCodeToVCL( sal_uLong nError )
+ErrCode Printer::ImplSalPrinterErrorCodeToVCL( sal_uLong nError )
 {
-    sal_uLong nVCLError;
+    ErrCode nVCLError;
     switch ( nError )
     {
         case 0:
-            nVCLError = PRINTER_OK;
+            nVCLError = ERRCODE_NONE;
             break;
         case SAL_PRINTER_ERROR_ABORT:
             nVCLError = PRINTER_ABORT;
@@ -1642,10 +1637,7 @@ bool Printer::EndJob()
     {
         ReleaseGraphics();
 
-        mnCurPage = 0;
-
         mbPrinting      = false;
-        mnCurPrintPage  = 0;
         maJobName.clear();
 
         mbDevOutput = false;
@@ -1678,11 +1670,7 @@ void Printer::ImplStartPage()
 
         // PrintJob not aborted ???
         if ( IsJobActive() )
-        {
             mbInPrintPage = true;
-            mnCurPage++;
-            mnCurPrintPage++;
-        }
     }
 }
 
