@@ -17,34 +17,19 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include <tools/debug.hxx>
-#include <tools/poly.hxx>
-
-#include <vcl/svapp.hxx>
-#include <vcl/region.hxx>
-#include <vcl/virdev.hxx>
-#include <vcl/window.hxx>
-#include <vcl/metaact.hxx>
-#include <vcl/gdimtf.hxx>
-#include <vcl/print.hxx>
-#include <vcl/opengl/OpenGLContext.hxx>
-#include <vcl/outdev.hxx>
-#include <vcl/unowrap.hxx>
-#include <vcl/settings.hxx>
-
-#include <window.h>
+#include <memory>
+#include <config_features.h>
+#if HAVE_FEATURE_OPENGL
 #include <openglgdiimpl.hxx>
-#include <outdev.h>
-#include <sallayout.hxx>
+#include <opengl/zone.hxx>
+#include <desktop/exithelper.h>
+#ifdef _WIN32
+#include <svsys.h>
+#endif
+#endif
 #include <salgdi.hxx>
 #include <salframe.hxx>
-#include <salvd.hxx>
-#include <salprn.hxx>
-#include <svdata.hxx>
-#include <outdata.hxx>
-#include <memory>
-
-#include <basegfx/polygon/b2dpolygon.hxx>
+#include <basegfx/numeric/ftools.hxx> //for F_PI180
 
 // The only common SalFrame method
 
@@ -76,14 +61,39 @@ SalGraphics::~SalGraphics()
 {
 }
 
+#if HAVE_FEATURE_OPENGL
+
+namespace
+{
+    void disableOpenGLAndTerminateForRestart()
+    {
+        OpenGLZone::hardDisable();
+#ifdef _WIN32
+        TerminateProcess(GetCurrentProcess(), EXITHELPER_NORMAL_RESTART);
+#endif
+    }
+}
+
 rtl::Reference<OpenGLContext> SalGraphics::GetOpenGLContext() const
 {
     OpenGLSalGraphicsImpl *pImpl = dynamic_cast<OpenGLSalGraphicsImpl*>(GetImpl());
     if (pImpl)
-        return pImpl->GetOpenGLContext();
-
+    {
+        // If we notice that OpenGL is broken the first time being called, it is not too late to call
+        // disableOpenGLAndTerminateForRestart(). The first time this will be called is from displaying
+        // the splash screen, so if OpenGL is broken, it is "early enough" for us to be able to disable
+        // OpenGL and terminate bluntly with EXITHELPER_NORMAL_RESTART, thus causing the wrapper process
+        // to restart us, then without using OpenGL.
+        static bool bFirstCall = true;
+        rtl::Reference<OpenGLContext> xRet(pImpl->GetOpenGLContext());
+        if (!xRet.is() && bFirstCall)
+            disableOpenGLAndTerminateForRestart();
+        bFirstCall = false;
+        return xRet;
+    }
     return nullptr;
 }
+#endif
 
 bool SalGraphics::drawTransformedBitmap(
     const basegfx::B2DPoint& /* rNull */,
@@ -96,7 +106,7 @@ bool SalGraphics::drawTransformedBitmap(
     return false;
 }
 
-void SalGraphics::mirror( long& x, const OutputDevice *pOutDev, bool bBack ) const
+void SalGraphics::mirror( long& x, const OutputDevice *pOutDev ) const
 {
     long w;
     if( pOutDev && pOutDev->GetOutDevType() == OUTDEV_VIRDEV )
@@ -110,29 +120,23 @@ void SalGraphics::mirror( long& x, const OutputDevice *pOutDev, bool bBack ) con
         {
             OutputDevice *pOutDevRef = const_cast<OutputDevice*>(pOutDev);
             // mirror this window back
-            if( (m_nLayout & SalLayoutFlags::BiDiRtl) )
+            if( m_nLayout & SalLayoutFlags::BiDiRtl )
             {
                 long devX = w-pOutDevRef->GetOutputWidthPixel()-pOutDevRef->GetOutOffXPixel();   // re-mirrored mnOutOffX
-                if( bBack )
-                    x = x - devX + pOutDevRef->GetOutOffXPixel();
-                else
-                    x = devX + (x - pOutDevRef->GetOutOffXPixel());
+                x = devX + (x - pOutDevRef->GetOutOffXPixel());
             }
             else
             {
                 long devX = pOutDevRef->GetOutOffXPixel();   // re-mirrored mnOutOffX
-                if( bBack )
-                    x = devX + (pOutDevRef->GetOutputWidthPixel() + devX) - (x + 1);
-                else
-                    x = pOutDevRef->GetOutputWidthPixel() - (x - devX) + pOutDevRef->GetOutOffXPixel() - 1;
+                x = pOutDevRef->GetOutputWidthPixel() - (x - devX) + pOutDevRef->GetOutOffXPixel() - 1;
             }
         }
-        else if( (m_nLayout & SalLayoutFlags::BiDiRtl) )
+        else if( m_nLayout & SalLayoutFlags::BiDiRtl )
             x = w-1-x;
     }
 }
 
-void SalGraphics::mirror( long& x, long& nWidth, const OutputDevice *pOutDev, bool bBack ) const
+void SalGraphics::mirror( long& x, long nWidth, const OutputDevice *pOutDev, bool bBack ) const
 {
     long w;
     if( pOutDev && pOutDev->GetOutDevType() == OUTDEV_VIRDEV )
@@ -146,7 +150,7 @@ void SalGraphics::mirror( long& x, long& nWidth, const OutputDevice *pOutDev, bo
         {
             OutputDevice *pOutDevRef = const_cast<OutputDevice*>(pOutDev);
             // mirror this window back
-            if( (m_nLayout & SalLayoutFlags::BiDiRtl) )
+            if( m_nLayout & SalLayoutFlags::BiDiRtl )
             {
                 long devX = w-pOutDevRef->GetOutputWidthPixel()-pOutDevRef->GetOutOffXPixel();   // re-mirrored mnOutOffX
                 if( bBack )
@@ -163,13 +167,13 @@ void SalGraphics::mirror( long& x, long& nWidth, const OutputDevice *pOutDev, bo
                     x = pOutDevRef->GetOutputWidthPixel() - (x - devX) + pOutDevRef->GetOutOffXPixel() - nWidth;
             }
         }
-        else if( (m_nLayout & SalLayoutFlags::BiDiRtl) )
+        else if( m_nLayout & SalLayoutFlags::BiDiRtl )
             x = w-nWidth-x;
 
     }
 }
 
-bool SalGraphics::mirror( sal_uInt32 nPoints, const SalPoint *pPtAry, SalPoint *pPtAry2, const OutputDevice *pOutDev, bool bBack ) const
+bool SalGraphics::mirror( sal_uInt32 nPoints, const SalPoint *pPtAry, SalPoint *pPtAry2, const OutputDevice *pOutDev ) const
 {
     long w;
     if( pOutDev && pOutDev->GetOutDevType() == OUTDEV_VIRDEV )
@@ -185,56 +189,26 @@ bool SalGraphics::mirror( sal_uInt32 nPoints, const SalPoint *pPtAry, SalPoint *
         {
             OutputDevice *pOutDevRef = const_cast<OutputDevice*>(pOutDev);
             // mirror this window back
-            if( (m_nLayout & SalLayoutFlags::BiDiRtl) )
+            if( m_nLayout & SalLayoutFlags::BiDiRtl )
             {
                 long devX = w-pOutDevRef->GetOutputWidthPixel()-pOutDevRef->GetOutOffXPixel();   // re-mirrored mnOutOffX
-                if( bBack )
+                for( i=0, j=nPoints-1; i<nPoints; i++,j-- )
                 {
-                    for( i=0, j=nPoints-1; i<nPoints; i++,j-- )
-                    {
-                        //long x = w-1-pPtAry[i].mnX;
-                        //pPtAry2[j].mnX = devX + ( pOutDevRef->mnOutWidth - 1 - (x - devX) );
-                        pPtAry2[j].mnX = pOutDevRef->GetOutOffXPixel() + (pPtAry[i].mnX - devX);
-                        pPtAry2[j].mnY = pPtAry[i].mnY;
-                    }
-                }
-                else
-                {
-                    for( i=0, j=nPoints-1; i<nPoints; i++,j-- )
-                    {
-                        //long x = w-1-pPtAry[i].mnX;
-                        //pPtAry2[j].mnX = devX + ( pOutDevRef->mnOutWidth - 1 - (x - devX) );
-                        pPtAry2[j].mnX = devX + (pPtAry[i].mnX - pOutDevRef->GetOutOffXPixel());
-                        pPtAry2[j].mnY = pPtAry[i].mnY;
-                    }
+                    pPtAry2[j].mnX = devX + (pPtAry[i].mnX - pOutDevRef->GetOutOffXPixel());
+                    pPtAry2[j].mnY = pPtAry[i].mnY;
                 }
             }
             else
             {
                 long devX = pOutDevRef->GetOutOffXPixel();   // re-mirrored mnOutOffX
-                if( bBack )
+                for( i=0, j=nPoints-1; i<nPoints; i++,j-- )
                 {
-                    for( i=0, j=nPoints-1; i<nPoints; i++,j-- )
-                    {
-                        //long x = w-1-pPtAry[i].mnX;
-                        //pPtAry2[j].mnX = devX + ( pOutDevRef->mnOutWidth - 1 - (x - devX) );
-                        pPtAry2[j].mnX = pPtAry[i].mnX - pOutDevRef->GetOutputWidthPixel() + devX - pOutDevRef->GetOutOffXPixel() + 1;
-                        pPtAry2[j].mnY = pPtAry[i].mnY;
-                    }
-                }
-                else
-                {
-                    for( i=0, j=nPoints-1; i<nPoints; i++,j-- )
-                    {
-                        //long x = w-1-pPtAry[i].mnX;
-                        //pPtAry2[j].mnX = devX + ( pOutDevRef->mnOutWidth - 1 - (x - devX) );
-                        pPtAry2[j].mnX = pOutDevRef->GetOutputWidthPixel() - (pPtAry[i].mnX - devX) + pOutDevRef->GetOutOffXPixel() - 1;
-                        pPtAry2[j].mnY = pPtAry[i].mnY;
-                    }
+                    pPtAry2[j].mnX = pOutDevRef->GetOutputWidthPixel() - (pPtAry[i].mnX - devX) + pOutDevRef->GetOutOffXPixel() - 1;
+                    pPtAry2[j].mnY = pPtAry[i].mnY;
                 }
             }
         }
-        else if( (m_nLayout & SalLayoutFlags::BiDiRtl) )
+        else if( m_nLayout & SalLayoutFlags::BiDiRtl )
         {
             for( i=0, j=nPoints-1; i<nPoints; i++,j-- )
             {
@@ -248,11 +222,11 @@ bool SalGraphics::mirror( sal_uInt32 nPoints, const SalPoint *pPtAry, SalPoint *
         return false;
 }
 
-void SalGraphics::mirror( vcl::Region& rRgn, const OutputDevice *pOutDev, bool bBack ) const
+void SalGraphics::mirror( vcl::Region& rRgn, const OutputDevice *pOutDev ) const
 {
     if( rRgn.HasPolyPolygonOrB2DPolyPolygon() )
     {
-        const basegfx::B2DPolyPolygon aPolyPoly(mirror(rRgn.GetAsB2DPolyPolygon(), pOutDev, bBack));
+        const basegfx::B2DPolyPolygon aPolyPoly(mirror(rRgn.GetAsB2DPolyPolygon(), pOutDev));
 
         rRgn = vcl::Region(aPolyPoly);
     }
@@ -264,7 +238,7 @@ void SalGraphics::mirror( vcl::Region& rRgn, const OutputDevice *pOutDev, bool b
 
         for(RectangleVector::iterator aRectIter(aRectangles.begin()); aRectIter != aRectangles.end(); ++aRectIter)
         {
-            mirror(*aRectIter, pOutDev, bBack);
+            mirror(*aRectIter, pOutDev);
             rRgn.Union(*aRectIter);
         }
 
@@ -285,7 +259,7 @@ void SalGraphics::mirror( vcl::Region& rRgn, const OutputDevice *pOutDev, bool b
     }
 }
 
-void SalGraphics::mirror( Rectangle& rRect, const OutputDevice *pOutDev, bool bBack ) const
+void SalGraphics::mirror( tools::Rectangle& rRect, const OutputDevice *pOutDev, bool bBack ) const
 {
     long nWidth = rRect.GetWidth();
     long x      = rRect.Left();
@@ -295,7 +269,7 @@ void SalGraphics::mirror( Rectangle& rRect, const OutputDevice *pOutDev, bool bB
     rRect.Move( x - x_org, 0 );
 }
 
-basegfx::B2DPoint SalGraphics::mirror( const basegfx::B2DPoint& i_rPoint, const OutputDevice *i_pOutDev, bool i_bBack ) const
+basegfx::B2DPoint SalGraphics::mirror( const basegfx::B2DPoint& i_rPoint, const OutputDevice *i_pOutDev ) const
 {
     long w;
     if( i_pOutDev && i_pOutDev->GetOutDevType() == OUTDEV_VIRDEV )
@@ -303,7 +277,7 @@ basegfx::B2DPoint SalGraphics::mirror( const basegfx::B2DPoint& i_rPoint, const
     else
         w = GetGraphicsWidth();
 
-    DBG_ASSERT( w, "missing graphics width" );
+    SAL_WARN_IF( !w, "vcl", "missing graphics width" );
 
     basegfx::B2DPoint aRet( i_rPoint );
     if( w )
@@ -313,10 +287,7 @@ basegfx::B2DPoint SalGraphics::mirror( const basegfx::B2DPoint& i_rPoint, const
             OutputDevice *pOutDevRef = const_cast<OutputDevice*>(i_pOutDev);
             // mirror this window back
             double devX = w-pOutDevRef->GetOutputWidthPixel()-pOutDevRef->GetOutOffXPixel();   // re-mirrored mnOutOffX
-            if( i_bBack )
-                aRet.setX( i_rPoint.getX() - devX + pOutDevRef->GetOutOffXPixel() );
-            else
-                aRet.setX( devX + (i_rPoint.getX() - pOutDevRef->GetOutOffXPixel()) );
+            aRet.setX( devX + (i_rPoint.getX() - pOutDevRef->GetOutOffXPixel()) );
         }
         else
             aRet.setX( w-1-i_rPoint.getX() );
@@ -324,7 +295,7 @@ basegfx::B2DPoint SalGraphics::mirror( const basegfx::B2DPoint& i_rPoint, const
     return aRet;
 }
 
-basegfx::B2DPolygon SalGraphics::mirror( const basegfx::B2DPolygon& i_rPoly, const OutputDevice *i_pOutDev, bool i_bBack ) const
+basegfx::B2DPolygon SalGraphics::mirror( const basegfx::B2DPolygon& i_rPoly, const OutputDevice *i_pOutDev ) const
 {
     long w;
     if( i_pOutDev && i_pOutDev->GetOutDevType() == OUTDEV_VIRDEV )
@@ -332,7 +303,7 @@ basegfx::B2DPolygon SalGraphics::mirror( const basegfx::B2DPolygon& i_rPoly, con
     else
         w = GetGraphicsWidth();
 
-    DBG_ASSERT( w, "missing graphics width" );
+    SAL_WARN_IF( !w, "vcl", "missing graphics width" );
 
     basegfx::B2DPolygon aRet;
     if( w )
@@ -340,11 +311,11 @@ basegfx::B2DPolygon SalGraphics::mirror( const basegfx::B2DPolygon& i_rPoly, con
         sal_Int32 nPoints = i_rPoly.count();
         for( sal_Int32 i = 0; i < nPoints; i++ )
         {
-            aRet.append( mirror( i_rPoly.getB2DPoint( i ), i_pOutDev, i_bBack ) );
+            aRet.append( mirror( i_rPoly.getB2DPoint( i ), i_pOutDev ) );
             if( i_rPoly.isPrevControlPointUsed( i ) )
-                aRet.setPrevControlPoint( i, mirror( i_rPoly.getPrevControlPoint( i ), i_pOutDev, i_bBack ) );
+                aRet.setPrevControlPoint( i, mirror( i_rPoly.getPrevControlPoint( i ), i_pOutDev ) );
             if( i_rPoly.isNextControlPointUsed( i ) )
-                aRet.setNextControlPoint( i, mirror( i_rPoly.getNextControlPoint( i ), i_pOutDev, i_bBack ) );
+                aRet.setNextControlPoint( i, mirror( i_rPoly.getNextControlPoint( i ), i_pOutDev ) );
         }
         aRet.setClosed( i_rPoly.isClosed() );
         aRet.flip();
@@ -354,7 +325,7 @@ basegfx::B2DPolygon SalGraphics::mirror( const basegfx::B2DPolygon& i_rPoly, con
     return aRet;
 }
 
-basegfx::B2DPolyPolygon SalGraphics::mirror( const basegfx::B2DPolyPolygon& i_rPoly, const OutputDevice *i_pOutDev, bool i_bBack ) const
+basegfx::B2DPolyPolygon SalGraphics::mirror( const basegfx::B2DPolyPolygon& i_rPoly, const OutputDevice *i_pOutDev ) const
 {
     long w;
     if( i_pOutDev && i_pOutDev->GetOutDevType() == OUTDEV_VIRDEV )
@@ -362,14 +333,14 @@ basegfx::B2DPolyPolygon SalGraphics::mirror( const basegfx::B2DPolyPolygon& i_rP
     else
         w = GetGraphicsWidth();
 
-    DBG_ASSERT( w, "missing graphics width" );
+    SAL_WARN_IF( !w, "vcl", "missing graphics width" );
 
     basegfx::B2DPolyPolygon aRet;
     if( w )
     {
         sal_Int32 nPoly = i_rPoly.count();
         for( sal_Int32 i = 0; i < nPoly; i++ )
-            aRet.append( mirror( i_rPoly.getB2DPolygon( i ), i_pOutDev, i_bBack ) );
+            aRet.append( mirror( i_rPoly.getB2DPolygon( i ), i_pOutDev ) );
         aRet.setClosed( i_rPoly.isClosed() );
         aRet.flip();
     }
@@ -420,7 +391,7 @@ void SalGraphics::DrawRect( long nX, long nY, long nWidth, long nHeight, const O
     drawRect( nX, nY, nWidth, nHeight );
 }
 
-void SalGraphics::DrawPolyLine( sal_uInt32 nPoints, const SalPoint* pPtAry, const OutputDevice *pOutDev )
+void SalGraphics::DrawPolyLine( sal_uInt32 nPoints, SalPoint const * pPtAry, const OutputDevice *pOutDev )
 {
     if( (m_nLayout & SalLayoutFlags::BiDiRtl) || (pOutDev && pOutDev->IsRTLEnabled()) )
     {
@@ -449,7 +420,7 @@ void SalGraphics::DrawPolyPolygon( sal_uInt32 nPoly, const sal_uInt32* pPoints,
     if( (m_nLayout & SalLayoutFlags::BiDiRtl) || (pOutDev && pOutDev->IsRTLEnabled()) )
     {
         // TODO: optimize, reduce new/delete calls
-        SalPoint **pPtAry2 = new SalPoint*[nPoly];
+        std::unique_ptr<SalPoint*[]> pPtAry2( new SalPoint*[nPoly] );
         sal_uLong i;
         for(i=0; i<nPoly; i++)
         {
@@ -458,11 +429,10 @@ void SalGraphics::DrawPolyPolygon( sal_uInt32 nPoly, const sal_uInt32* pPoints,
             mirror( nPoints, pPtAry[i], pPtAry2[i], pOutDev );
         }
 
-        drawPolyPolygon( nPoly, pPoints, const_cast<PCONSTSALPOINT*>(pPtAry2) );
+        drawPolyPolygon( nPoly, pPoints, const_cast<PCONSTSALPOINT*>(pPtAry2.get()) );
 
         for(i=0; i<nPoly; i++)
             delete [] pPtAry2[i];
-        delete [] pPtAry2;
     }
     else
         drawPolyPolygon( nPoly, pPoints, pPtAry );
@@ -481,7 +451,7 @@ bool SalGraphics::DrawPolyPolygon( const basegfx::B2DPolyPolygon& i_rPolyPolygon
     return bRet;
 }
 
-bool SalGraphics::DrawPolyLineBezier( sal_uInt32 nPoints, const SalPoint* pPtAry, const sal_uInt8* pFlgAry, const OutputDevice* pOutDev )
+bool SalGraphics::DrawPolyLineBezier( sal_uInt32 nPoints, const SalPoint* pPtAry, const PolyFlags* pFlgAry, const OutputDevice* pOutDev )
 {
     bool bResult = false;
     if( (m_nLayout & SalLayoutFlags::BiDiRtl) || (pOutDev && pOutDev->IsRTLEnabled()) )
@@ -495,7 +465,7 @@ bool SalGraphics::DrawPolyLineBezier( sal_uInt32 nPoints, const SalPoint* pPtAry
     return bResult;
 }
 
-bool SalGraphics::DrawPolygonBezier( sal_uInt32 nPoints, const SalPoint* pPtAry, const sal_uInt8* pFlgAry, const OutputDevice* pOutDev )
+bool SalGraphics::DrawPolygonBezier( sal_uInt32 nPoints, const SalPoint* pPtAry, const PolyFlags* pFlgAry, const OutputDevice* pOutDev )
 {
     bool bResult = false;
     if( (m_nLayout & SalLayoutFlags::BiDiRtl) || (pOutDev && pOutDev->IsRTLEnabled()) )
@@ -510,13 +480,13 @@ bool SalGraphics::DrawPolygonBezier( sal_uInt32 nPoints, const SalPoint* pPtAry,
 }
 
 bool SalGraphics::DrawPolyPolygonBezier( sal_uInt32 i_nPoly, const sal_uInt32* i_pPoints,
-                                         const SalPoint* const* i_pPtAry, const sal_uInt8* const* i_pFlgAry, const OutputDevice* i_pOutDev )
+                                         const SalPoint* const* i_pPtAry, const PolyFlags* const* i_pFlgAry, const OutputDevice* i_pOutDev )
 {
     bool bRet = false;
     if( (m_nLayout & SalLayoutFlags::BiDiRtl) || (i_pOutDev && i_pOutDev->IsRTLEnabled()) )
     {
         // TODO: optimize, reduce new/delete calls
-        SalPoint **pPtAry2 = new SalPoint*[i_nPoly];
+        std::unique_ptr<SalPoint*[]> pPtAry2( new SalPoint*[i_nPoly] );
         sal_uLong i;
         for(i=0; i<i_nPoly; i++)
         {
@@ -525,11 +495,10 @@ bool SalGraphics::DrawPolyPolygonBezier( sal_uInt32 i_nPoly, const sal_uInt32* i
             mirror( nPoints, i_pPtAry[i], pPtAry2[i], i_pOutDev );
         }
 
-        bRet = drawPolyPolygonBezier( i_nPoly, i_pPoints, const_cast<PCONSTSALPOINT const *>(pPtAry2), i_pFlgAry );
+        bRet = drawPolyPolygonBezier( i_nPoly, i_pPoints, const_cast<PCONSTSALPOINT const *>(pPtAry2.get()), i_pFlgAry );
 
         for(i=0; i<i_nPoly; i++)
             delete [] pPtAry2[i];
-        delete [] pPtAry2;
     }
     else
         bRet = drawPolyPolygonBezier( i_nPoly, i_pPoints, i_pPtAry, i_pFlgAry );
@@ -541,20 +510,21 @@ bool SalGraphics::DrawPolyLine( const basegfx::B2DPolygon& i_rPolygon,
                                 const basegfx::B2DVector& i_rLineWidth,
                                 basegfx::B2DLineJoin i_eLineJoin,
                                 css::drawing::LineCap i_eLineCap,
+                                double i_fMiterMinimumAngle,
                                 const OutputDevice* i_pOutDev )
 {
     bool bRet = false;
     if( (m_nLayout & SalLayoutFlags::BiDiRtl) || (i_pOutDev && i_pOutDev->IsRTLEnabled()) )
     {
         basegfx::B2DPolygon aMirror( mirror( i_rPolygon, i_pOutDev ) );
-        bRet = drawPolyLine( aMirror, i_fTransparency, i_rLineWidth, i_eLineJoin, i_eLineCap );
+        bRet = drawPolyLine( aMirror, i_fTransparency, i_rLineWidth, i_eLineJoin, i_eLineCap, i_fMiterMinimumAngle );
     }
     else
-        bRet = drawPolyLine( i_rPolygon, i_fTransparency, i_rLineWidth, i_eLineJoin, i_eLineCap );
+        bRet = drawPolyLine( i_rPolygon, i_fTransparency, i_rLineWidth, i_eLineJoin, i_eLineCap, i_fMiterMinimumAngle );
     return bRet;
 }
 
-bool SalGraphics::DrawGradient( const tools::PolyPolygon& rPolyPoly, const Gradient& rGradient, OutputDevice* )
+bool SalGraphics::DrawGradient( const tools::PolyPolygon& rPolyPoly, const Gradient& rGradient )
 {
     return drawGradient( rPolyPoly, rGradient );
 }
@@ -562,14 +532,14 @@ bool SalGraphics::DrawGradient( const tools::PolyPolygon& rPolyPoly, const Gradi
 void SalGraphics::CopyArea( long nDestX, long nDestY,
                             long nSrcX, long nSrcY,
                             long nSrcWidth, long nSrcHeight,
-                            sal_uInt16 nFlags, const OutputDevice *pOutDev )
+                            const OutputDevice *pOutDev )
 {
     if( (m_nLayout & SalLayoutFlags::BiDiRtl) || (pOutDev && pOutDev->IsRTLEnabled()) )
     {
         mirror( nDestX, nSrcWidth, pOutDev );
         mirror( nSrcX, nSrcWidth, pOutDev );
     }
-    copyArea( nDestX, nDestY, nSrcX, nSrcY, nSrcWidth, nSrcHeight, nFlags );
+    copyArea( nDestX, nDestY, nSrcX, nSrcY, nSrcWidth, nSrcHeight, true/*bWindowInvalidate*/ );
 }
 
 void SalGraphics::CopyBits( const SalTwoRect& rPosAry,
@@ -670,64 +640,65 @@ bool SalGraphics::DrawEPS( long nX, long nY, long nWidth, long nHeight, void* pP
     return drawEPS( nX, nY, nWidth, nHeight,  pPtr, nSize );
 }
 
-bool SalGraphics::HitTestNativeControl( ControlType nType, ControlPart nPart, const Rectangle& rControlRegion,
+bool SalGraphics::HitTestNativeScrollbar( ControlPart nPart, const tools::Rectangle& rControlRegion,
                                                 const Point& aPos, bool& rIsInside, const OutputDevice *pOutDev )
 {
     if( (m_nLayout & SalLayoutFlags::BiDiRtl) || (pOutDev && pOutDev->IsRTLEnabled()) )
     {
         Point pt( aPos );
-        Rectangle rgn( rControlRegion );
+        tools::Rectangle rgn( rControlRegion );
         mirror( pt.X(), pOutDev );
         mirror( rgn, pOutDev );
-        return hitTestNativeControl( nType, nPart, rgn, pt, rIsInside );
+        return hitTestNativeControl( ControlType::Scrollbar, nPart, rgn, pt, rIsInside );
     }
     else
-        return hitTestNativeControl( nType, nPart, rControlRegion, aPos, rIsInside );
+        return hitTestNativeControl( ControlType::Scrollbar, nPart, rControlRegion, aPos, rIsInside );
 }
 
-void SalGraphics::mirror( ImplControlValue& rVal, const OutputDevice* pOutDev, bool bBack ) const
+void SalGraphics::mirror( ImplControlValue& rVal, const OutputDevice* pOutDev ) const
 {
     switch( rVal.getType() )
     {
-        case CTRL_SLIDER:
+        case ControlType::Slider:
         {
             SliderValue* pSlVal = static_cast<SliderValue*>(&rVal);
-            mirror(pSlVal->maThumbRect,pOutDev,bBack);
+            mirror(pSlVal->maThumbRect,pOutDev);
         }
         break;
-        case CTRL_SCROLLBAR:
+        case ControlType::Scrollbar:
         {
             ScrollbarValue* pScVal = static_cast<ScrollbarValue*>(&rVal);
-            mirror(pScVal->maThumbRect,pOutDev,bBack);
-            mirror(pScVal->maButton1Rect,pOutDev,bBack);
-            mirror(pScVal->maButton2Rect,pOutDev,bBack);
+            mirror(pScVal->maThumbRect,pOutDev);
+            mirror(pScVal->maButton1Rect,pOutDev);
+            mirror(pScVal->maButton2Rect,pOutDev);
         }
         break;
-        case CTRL_SPINBOX:
-        case CTRL_SPINBUTTONS:
+        case ControlType::Spinbox:
+        case ControlType::SpinButtons:
         {
             SpinbuttonValue* pSpVal = static_cast<SpinbuttonValue*>(&rVal);
-            mirror(pSpVal->maUpperRect,pOutDev,bBack);
-            mirror(pSpVal->maLowerRect,pOutDev,bBack);
+            mirror(pSpVal->maUpperRect,pOutDev);
+            mirror(pSpVal->maLowerRect,pOutDev);
         }
         break;
-        case CTRL_TOOLBAR:
+        case ControlType::Toolbar:
         {
             ToolbarValue* pTVal = static_cast<ToolbarValue*>(&rVal);
-            mirror(pTVal->maGripRect,pOutDev,bBack);
+            mirror(pTVal->maGripRect,pOutDev);
         }
         break;
+        default: break;
     }
 }
 
-bool SalGraphics::DrawNativeControl( ControlType nType, ControlPart nPart, const Rectangle& rControlRegion,
+bool SalGraphics::DrawNativeControl( ControlType nType, ControlPart nPart, const tools::Rectangle& rControlRegion,
                                                 ControlState nState, const ImplControlValue& aValue,
                                                 const OUString& aCaption, const OutputDevice *pOutDev )
 {
     if( (m_nLayout & SalLayoutFlags::BiDiRtl) || (pOutDev && pOutDev->IsRTLEnabled()) )
     {
-        Rectangle rgn( rControlRegion );
-        Rectangle aNull;
+        tools::Rectangle rgn( rControlRegion );
+        tools::Rectangle aNull;
         if (rgn != aNull)
             mirror(rgn, pOutDev);
         std::unique_ptr< ImplControlValue > mirrorValue( aValue.clone());
@@ -739,17 +710,17 @@ bool SalGraphics::DrawNativeControl( ControlType nType, ControlPart nPart, const
         return drawNativeControl( nType, nPart, rControlRegion, nState, aValue, aCaption );
 }
 
-bool SalGraphics::GetNativeControlRegion( ControlType nType, ControlPart nPart, const Rectangle& rControlRegion, ControlState nState,
-                                                const ImplControlValue& aValue, const OUString& aCaption,
-                                                Rectangle &rNativeBoundingRegion, Rectangle &rNativeContentRegion, const OutputDevice *pOutDev )
+bool SalGraphics::GetNativeControlRegion( ControlType nType, ControlPart nPart, const tools::Rectangle& rControlRegion, ControlState nState,
+                                                const ImplControlValue& aValue,
+                                                tools::Rectangle &rNativeBoundingRegion, tools::Rectangle &rNativeContentRegion, const OutputDevice *pOutDev )
 {
     if( (m_nLayout & SalLayoutFlags::BiDiRtl) || (pOutDev && pOutDev->IsRTLEnabled()) )
     {
-        Rectangle rgn( rControlRegion );
+        tools::Rectangle rgn( rControlRegion );
         mirror( rgn, pOutDev );
         std::unique_ptr< ImplControlValue > mirrorValue( aValue.clone());
         mirror( *mirrorValue, pOutDev );
-        if( getNativeControlRegion( nType, nPart, rgn, nState, *mirrorValue, aCaption,
+        if( getNativeControlRegion( nType, nPart, rgn, nState, *mirrorValue, OUString(),
                                                 rNativeBoundingRegion, rNativeContentRegion ) )
         {
             mirror( rNativeBoundingRegion, pOutDev, true );
@@ -759,7 +730,7 @@ bool SalGraphics::GetNativeControlRegion( ControlType nType, ControlPart nPart,
         return false;
     }
     else
-        return getNativeControlRegion( nType, nPart, rControlRegion, nState, aValue, aCaption,
+        return getNativeControlRegion( nType, nPart, rControlRegion, nState, aValue, OUString(),
                                                 rNativeBoundingRegion, rNativeContentRegion );
 }
 
@@ -818,15 +789,11 @@ bool SalGraphics::DrawTransformedBitmap(
 {
     if( (m_nLayout & SalLayoutFlags::BiDiRtl) || (pOutDev && pOutDev->IsRTLEnabled()) )
     {
-        basegfx::B2DPoint aNull(rNull);
-        basegfx::B2DPoint aX(rX);
-        basegfx::B2DPoint aY(rY);
+        mirror(rNull, pOutDev);
+        mirror(rX, pOutDev);
+        mirror(rY, pOutDev);
 
-        mirror(aNull, pOutDev);
-        mirror(aX, pOutDev);
-        mirror(aY, pOutDev);
-
-        return drawTransformedBitmap(aNull, aX, aY, rSourceBitmap, pAlphaBitmap);
+        return drawTransformedBitmap(rNull, rX, rY, rSourceBitmap, pAlphaBitmap);
     }
     else
     {
