@@ -17,57 +17,18 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include <tools/debug.hxx>
-#include <tools/poly.hxx>
-
-#include <vcl/svapp.hxx>
-#include <vcl/ctrl.hxx>
-#include <vcl/region.hxx>
 #include <vcl/virdev.hxx>
-#include <vcl/window.hxx>
-#include <vcl/metaact.hxx>
-#include <vcl/gdimtf.hxx>
-#include <vcl/print.hxx>
 #include <vcl/outdev.hxx>
 #include <vcl/unowrap.hxx>
-#include <vcl/settings.hxx>
 #include <vcl/sysdata.hxx>
-
-#include <vcl/outdevstate.hxx>
+#include <comphelper/lok.hxx>
 
 #include <salgdi.hxx>
-#include <sallayout.hxx>
-#include <salframe.hxx>
-#include <salvd.hxx>
-#include <salprn.hxx>
 #include <svdata.hxx>
 #include <window.h>
 #include <outdev.h>
-#include <outdata.hxx>
 #include <outdevstatestack.hxx>
-
-#include "PhysicalFontCollection.hxx"
-
-#include <basegfx/point/b2dpoint.hxx>
-#include <basegfx/vector/b2dvector.hxx>
-#include <basegfx/polygon/b2dpolygon.hxx>
-#include <basegfx/polygon/b2dpolypolygon.hxx>
-#include <basegfx/matrix/b2dhommatrix.hxx>
-#include <basegfx/polygon/b2dpolygontools.hxx>
-#include <basegfx/polygon/b2dpolypolygontools.hxx>
-#include <basegfx/polygon/b2dlinegeometry.hxx>
-
-#include <com/sun/star/awt/XGraphics.hpp>
-#include <com/sun/star/uno/Sequence.hxx>
-#include <com/sun/star/rendering/XCanvas.hpp>
-#include <com/sun/star/rendering/CanvasFactory.hpp>
-#include <com/sun/star/lang/XMultiServiceFactory.hpp>
-#include <comphelper/processfactory.hxx>
-
-#include <config_cairo_canvas.h>
-
-#include <numeric>
-#include <stack>
+#include <PhysicalFontCollection.hxx>
 
 #ifdef DISABLE_DYNLOADING
 // Linking all needed LO code into one .so/executable, these already
@@ -82,7 +43,6 @@ namespace {
 // Begin initializer and accessor public functions
 
 OutputDevice::OutputDevice() :
-    mnRefCnt(1), // cf. VclPtrInstance and README.lifecycle
     maRegion(true),
     maFillColor( COL_WHITE ),
     maTextLineColor( COL_TRANSPARENT ),
@@ -93,11 +53,11 @@ OutputDevice::OutputDevice() :
     mpPrevGraphics                  = nullptr;
     mpNextGraphics                  = nullptr;
     mpMetaFile                      = nullptr;
-    mpFontEntry                     = nullptr;
+    mpFontInstance                     = nullptr;
     mpFontCache                     = nullptr;
     mpFontCollection                = nullptr;
-    mpGetDevFontList                = nullptr;
-    mpGetDevSizeList                = nullptr;
+    mpDeviceFontList                = nullptr;
+    mpDeviceFontSizeList            = nullptr;
     mpOutDevStateStack              = new OutDevStateStack;
     mpPDFWriter                     = nullptr;
     mpAlphaVDev                     = nullptr;
@@ -108,7 +68,7 @@ OutputDevice::OutputDevice() :
     mnOutHeight                     = 0;
     mnDPIX                          = 0;
     mnDPIY                          = 0;
-    mnDPIScaleFactor                = 1;
+    mnDPIScalePercentage            = 100;
     mnTextOffX                      = 0;
     mnTextOffY                      = 0;
     mnOutOffOrigX                   = 0;
@@ -118,15 +78,14 @@ OutputDevice::OutputDevice() :
     mnEmphasisAscent                = 0;
     mnEmphasisDescent               = 0;
     mnDrawMode                      = DrawModeFlags::Default;
-    mnTextLayoutMode                = TEXT_LAYOUT_DEFAULT;
+    mnTextLayoutMode                = ComplexTextLayoutFlags::Default;
 
     if( AllSettings::GetLayoutRTL() ) //#i84553# tip BiDi preference to RTL
-        mnTextLayoutMode            = TEXT_LAYOUT_BIDI_RTL | TEXT_LAYOUT_TEXTORIGIN_LEFT;
+        mnTextLayoutMode            = ComplexTextLayoutFlags::BiDiRtl | ComplexTextLayoutFlags::TextOriginLeft;
 
     meOutDevType                    = OUTDEV_DONTKNOW;
-    meOutDevViewType                = OUTDEV_VIEWTYPE_DONTKNOW;
+    meOutDevViewType                = OutDevViewType::DontKnow;
     mbMap                           = false;
-    mbMapIsDefault                  = true;
     mbClipRegion                    = false;
     mbBackground                    = false;
     mbOutput                        = true;
@@ -134,10 +93,9 @@ OutputDevice::OutputDevice() :
     mbOutputClipped                 = false;
     maTextColor                     = Color( COL_BLACK );
     maOverlineColor                 = Color( COL_TRANSPARENT );
-    meTextAlign                     = maFont.GetAlign();
-    meRasterOp                      = ROP_OVERPAINT;
+    meRasterOp                      = RasterOp::OverPaint;
     mnAntialiasing                  = AntialiasingFlags::NONE;
-    meTextLanguage                  = 0;  // TODO: get default from configuration?
+    meTextLanguage                  = LANGUAGE_SYSTEM;  // TODO: get default from configuration?
     mbLineColor                     = true;
     mbFillColor                     = true;
     mbInitLineColor                 = true;
@@ -146,7 +104,6 @@ OutputDevice::OutputDevice() :
     mbInitTextColor                 = true;
     mbInitClipRegion                = true;
     mbClipRegionSet                 = false;
-    mbKerning                       = false;
     mbNewFont                       = true;
     mbTextLines                     = false;
     mbTextSpecial                   = false;
@@ -160,10 +117,6 @@ OutputDevice::OutputDevice() :
     maMapRes.mnMapScNumY            = 1;
     maMapRes.mnMapScDenomX          = 1;
     maMapRes.mnMapScDenomY          = 1;
-    maMapRes.mfOffsetX              = 0.0;
-    maMapRes.mfOffsetY              = 0.0;
-    maMapRes.mfScaleX               = 1.0;
-    maMapRes.mfScaleY               = 1.0;
     // struct ImplThresholdRes
     maThresRes.mnThresLogToPixX     = 0;
     maThresRes.mnThresLogToPixY     = 0;
@@ -178,8 +131,6 @@ OutputDevice::OutputDevice() :
     // #i75163#
     mpOutDevData->mpViewTransform   = nullptr;
     mpOutDevData->mpInverseViewTransform = nullptr;
-
-    mbDisposed = false;
 }
 
 OutputDevice::~OutputDevice()
@@ -187,21 +138,6 @@ OutputDevice::~OutputDevice()
     disposeOnce();
 }
 
-void OutputDevice::disposeOnce()
-{
-    if ( mbDisposed )
-        return;
-    mbDisposed = true;
-
-    // catch badness where our OutputDevice sub-class was not
-    // wrapped safely in a VclPtr cosily.
-    // FIXME: as/when we make our destructors all protected,
-    // we should introduce this assert:
-    //    assert( mnRefCnt > 0 );
-
-    dispose();
-}
-
 void OutputDevice::dispose()
 {
     if ( GetUnoGraphicsList() )
@@ -234,16 +170,16 @@ void OutputDevice::dispose()
     mpOutDevStateStack = nullptr;
 
     // release the active font instance
-    if( mpFontEntry )
-        mpFontCache->Release( mpFontEntry );
+    if( mpFontInstance )
+        mpFontCache->Release( mpFontInstance );
 
     // remove cached results of GetDevFontList/GetDevSizeList
     // TODO: use smart pointers for them
-    delete mpGetDevFontList;
-    mpGetDevFontList = nullptr;
+    delete mpDeviceFontList;
+    mpDeviceFontList = nullptr;
 
-    delete mpGetDevSizeList;
-    mpGetDevSizeList = nullptr;
+    delete mpDeviceFontSizeList;
+    mpDeviceFontSizeList = nullptr;
 
     // release ImplFontCache specific to this OutputDevice
     // TODO: refcount ImplFontCache
@@ -267,6 +203,9 @@ void OutputDevice::dispose()
     }
 
     mpAlphaVDev.disposeAndClear();
+    mpPrevGraphics.clear();
+    mpNextGraphics.clear();
+    VclReferenceBase::dispose();
 }
 
 SalGraphics* OutputDevice::GetGraphics()
@@ -277,7 +216,7 @@ SalGraphics* OutputDevice::GetGraphics()
     {
         if ( !AcquireGraphics() )
         {
-            SAL_WARN("vcl", "No mpGraphics set");
+            SAL_WARN("vcl.gdi", "No mpGraphics set");
         }
     }
 
@@ -292,7 +231,7 @@ SalGraphics const *OutputDevice::GetGraphics() const
     {
         if ( !AcquireGraphics() )
         {
-            SAL_WARN("vcl", "No mpGraphics set");
+            SAL_WARN("vcl.gdi", "No mpGraphics set");
         }
     }
 
@@ -366,7 +305,7 @@ cairo::SurfaceSharedPtr OutputDevice::CreateBitmapSurface(const BitmapSystemData
     return mpGraphics->CreateBitmapSurface(*this, rData, rSize);
 }
 
-css::uno::Any OutputDevice::GetNativeSurfaceHandle(cairo::SurfaceSharedPtr& rSurface, const ::basegfx::B2ISize& rSize) const
+css::uno::Any OutputDevice::GetNativeSurfaceHandle(cairo::SurfaceSharedPtr& rSurface, const basegfx::B2ISize& rSize) const
 {
     if (!mpGraphics)
     {
@@ -394,7 +333,7 @@ void OutputDevice::SetRefPoint()
         mpMetaFile->AddAction( new MetaRefPointAction( Point(), false ) );
 
     mbRefPoint = false;
-    maRefPoint.X() = maRefPoint.Y() = 0L;
+    maRefPoint.X() = maRefPoint.Y() = 0;
 
     if( mpAlphaVDev )
         mpAlphaVDev->SetRefPoint();
@@ -422,7 +361,7 @@ sal_uInt16 OutputDevice::GetBitCount() const
             return 0;
     }
 
-    return (sal_uInt16)mpGraphics->GetBitCount();
+    return mpGraphics->GetBitCount();
 }
 
 void OutputDevice::SetOutOffXPixel(long nOutOffX)
@@ -450,7 +389,7 @@ css::uno::Reference< css::awt::XGraphics > OutputDevice::CreateUnoGraphics()
 
 std::vector< VCLXGraphics* > *OutputDevice::CreateUnoGraphicsList()
 {
-    mpUnoGraphicsList = new std::vector< VCLXGraphics* >();
+    mpUnoGraphicsList = new std::vector< VCLXGraphics* >;
     return mpUnoGraphicsList;
 }
 
@@ -473,9 +412,9 @@ void OutputDevice::DrawOutDev( const Point& rDestPt, const Size& rDestSize,
     if( ImplIsRecordLayout() )
         return;
 
-    if ( ROP_INVERT == meRasterOp )
+    if ( RasterOp::Invert == meRasterOp )
     {
-        DrawRect( Rectangle( rDestPt, rDestSize ) );
+        DrawRect( tools::Rectangle( rDestPt, rDestSize ) );
         return;
     }
 
@@ -510,7 +449,7 @@ void OutputDevice::DrawOutDev( const Point& rDestPt, const Size& rDestSize,
                            ImplLogicXToDevicePixel(rDestPt.X()), ImplLogicYToDevicePixel(rDestPt.Y()),
                            nDestWidth, nDestHeight);
 
-        const Rectangle aSrcOutRect( Point( mnOutOffX, mnOutOffY ),
+        const tools::Rectangle aSrcOutRect( Point( mnOutOffX, mnOutOffY ),
                                      Size( mnOutWidth, mnOutHeight ) );
 
         AdjustTwoRect( aPosAry, aSrcOutRect );
@@ -530,9 +469,9 @@ void OutputDevice::DrawOutDev( const Point& rDestPt, const Size& rDestSize,
     if ( ImplIsRecordLayout() )
         return;
 
-    if ( ROP_INVERT == meRasterOp )
+    if ( RasterOp::Invert == meRasterOp )
     {
-        DrawRect( Rectangle( rDestPt, rDestSize ) );
+        DrawRect( tools::Rectangle( rDestPt, rDestSize ) );
         return;
     }
 
@@ -576,7 +515,7 @@ void OutputDevice::DrawOutDev( const Point& rDestPt, const Size& rDestSize,
             drawOutDevDirect( &rOutDev, aPosAry );
 
             // #i32109#: make destination rectangle opaque - source has no alpha
-            mpAlphaVDev->ImplFillOpaqueRectangle( Rectangle(rDestPt, rDestSize) );
+            mpAlphaVDev->ImplFillOpaqueRectangle( tools::Rectangle(rDestPt, rDestSize) );
         }
     }
     else
@@ -602,7 +541,7 @@ void OutputDevice::CopyArea( const Point& rDestPt,
         return;
 
     RasterOp eOldRop = GetRasterOp();
-    SetRasterOp( ROP_OVERPAINT );
+    SetRasterOp( RasterOp::OverPaint );
 
     if ( !IsDeviceOutputNecessary() )
         return;
@@ -626,7 +565,7 @@ void OutputDevice::CopyArea( const Point& rDestPt,
                            ImplLogicXToDevicePixel(rDestPt.X()), ImplLogicYToDevicePixel(rDestPt.Y()),
                            nSrcWidth, nSrcHeight);
 
-        const Rectangle aSrcOutRect( Point( mnOutOffX, mnOutOffY ),
+        const tools::Rectangle aSrcOutRect( Point( mnOutOffX, mnOutOffY ),
                                      Size( mnOutWidth, mnOutHeight ) );
 
         AdjustTwoRect( aPosAry, aSrcOutRect );
@@ -690,21 +629,21 @@ void OutputDevice::drawOutDevDirect( const OutputDevice* pSrcDev, SalTwoRect& rP
                     if ( !AcquireGraphics() )
                         return;
                 }
-                DBG_ASSERT( mpGraphics && pSrcDev->mpGraphics,
+                SAL_WARN_IF( !mpGraphics || !pSrcDev->mpGraphics, "vcl.gdi",
                             "OutputDevice::DrawOutDev(): We need more than one Graphics" );
             }
         }
     }
 
     // #102532# Offset only has to be pseudo window offset
-    const Rectangle aSrcOutRect( Point( pSrcDev->mnOutOffX, pSrcDev->mnOutOffY ),
+    const tools::Rectangle aSrcOutRect( Point( pSrcDev->mnOutOffX, pSrcDev->mnOutOffY ),
                                  Size( pSrcDev->mnOutWidth, pSrcDev->mnOutHeight ) );
 
     AdjustTwoRect( rPosAry, aSrcOutRect );
 
     if ( rPosAry.mnSrcWidth && rPosAry.mnSrcHeight && rPosAry.mnDestWidth && rPosAry.mnDestHeight )
     {
-        // --- RTL --- if this is no window, but pSrcDev is a window
+        // if this is no window, but pSrcDev is a window
         // mirroring may be required
         // because only windows have a SalGraphicsLayout
         // mirroring is performed here
@@ -749,7 +688,7 @@ void    OutputDevice::ReMirror( Point &rPoint ) const
 {
     rPoint.X() = mnOutOffX + mnOutWidth - 1 - rPoint.X() + mnOutOffX;
 }
-void    OutputDevice::ReMirror( Rectangle &rRect ) const
+void    OutputDevice::ReMirror( tools::Rectangle &rRect ) const
 {
     long nWidth = rRect.Right() - rRect.Left();
 
@@ -810,7 +749,7 @@ bool OutputDevice::DrawEPS( const Point& rPoint, const Size& rSize,
     if( mbOutputClipped )
         return bDrawn;
 
-    Rectangle aRect( ImplLogicToDevicePixel( Rectangle( rPoint, rSize ) ) );
+    tools::Rectangle aRect( ImplLogicToDevicePixel( tools::Rectangle( rPoint, rSize ) ) );
 
     if( !aRect.IsEmpty() )
     {
