@@ -17,11 +17,10 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include <tools/debug.hxx>
 
 #include <svdata.hxx>
 
-#include <dlgctrl.hxx>
+#include "dlgctrl.hxx"
 #include <vcl/event.hxx>
 #include <vcl/fixed.hxx>
 #include <vcl/layout.hxx>
@@ -93,7 +92,7 @@ static vcl::Window* ImplGetSubChildWindow( vcl::Window* pParent, sal_uInt16 n, s
                 pFoundWindow = pWindow;
 
                 // for a TabControl, remember the current TabPage for later use
-                if ( pWindow->GetType() == WINDOW_TABCONTROL )
+                if ( pWindow->GetType() == WindowType::TABCONTROL )
                 {
                     TabControl* pTabControl = static_cast<TabControl*>(pWindow);
                     // Check if the TabPage is a Child of the TabControl and still exists (by
@@ -264,7 +263,7 @@ vcl::Window* Window::ImplGetDlgWindow( sal_uInt16 nIndex, GetDlgWindowType nType
         {
             if ( pWindow )
             {
-                if ( pWindow->GetType() == WINDOW_TABCONTROL )
+                if ( pWindow->GetType() == WindowType::TABCONTROL )
                 {
                     vcl::Window* pNextWindow = ImplGetDlgWindow( i, GetDlgWindowType::Next );
                     if ( pNextWindow )
@@ -391,10 +390,7 @@ vcl::Window* ImplFindAccelWindow( vcl::Window* pParent, sal_uInt16& rIndex, sal_
     sal_uInt16  i = rIndex;
     vcl::Window* pWindow;
 
-    // MT: Where can we keep the CharClass?!
-    static uno::Reference< i18n::XCharacterClassification > xCharClass;
-    if ( !xCharClass.is() )
-        xCharClass = vcl::unohelper::CreateCharacterClassification();
+    uno::Reference<i18n::XCharacterClassification> const xCharClass(ImplGetCharClass());
 
     const css::lang::Locale& rLocale = Application::GetSettings().GetUILanguageTag().getLocale();
     cCharCode = xCharClass->toUpper( OUString(cCharCode), 0, 1, rLocale )[0];
@@ -413,7 +409,7 @@ vcl::Window* ImplFindAccelWindow( vcl::Window* pParent, sal_uInt16& rIndex, sal_
             cCompareChar = xCharClass->toUpper( OUString(cCompareChar), 0, 1, rLocale )[0];
             if ( cCompareChar == cCharCode )
             {
-                if (pWindow->GetType() == WINDOW_FIXEDTEXT)
+                if (pWindow->GetType() == WindowType::FIXEDTEXT)
                 {
                     FixedText *pFixedText = static_cast<FixedText*>(pWindow);
                     vcl::Window *pMnemonicWidget = pFixedText->get_mnemonic_widget();
@@ -424,9 +420,9 @@ vcl::Window* ImplFindAccelWindow( vcl::Window* pParent, sal_uInt16& rIndex, sal_
                 }
 
                 // skip Static-Controls
-                if ( (pWindow->GetType() == WINDOW_FIXEDTEXT)   ||
-                     (pWindow->GetType() == WINDOW_FIXEDLINE)   ||
-                     (pWindow->GetType() == WINDOW_GROUPBOX) )
+                if ( (pWindow->GetType() == WindowType::FIXEDTEXT)   ||
+                     (pWindow->GetType() == WindowType::FIXEDLINE)   ||
+                     (pWindow->GetType() == WindowType::GROUPBOX) )
                     pWindow = pParent->ImplGetDlgWindow( i, GetDlgWindowType::Next );
                 rIndex = i;
                 return pWindow;
@@ -476,7 +472,7 @@ void Window::ImplControlFocus( GetFocusFlags nFlags )
 {
     if ( nFlags & GetFocusFlags::Mnemonic )
     {
-        if ( GetType() == WINDOW_RADIOBUTTON )
+        if ( GetType() == WindowType::RADIOBUTTON )
         {
             if ( !static_cast<RadioButton*>(this)->IsChecked() )
                 static_cast<RadioButton*>(this)->ImplCallClick( true, nFlags );
@@ -488,7 +484,7 @@ void Window::ImplControlFocus( GetFocusFlags nFlags )
             ImplGrabFocus( nFlags );
             if ( nFlags & GetFocusFlags::UniqueMnemonic )
             {
-                if ( GetType() == WINDOW_CHECKBOX )
+                if ( GetType() == WindowType::CHECKBOX )
                     static_cast<CheckBox*>(this)->ImplCheck();
                 else if ( mpWindowImpl->mbPushButton )
                 {
@@ -501,7 +497,7 @@ void Window::ImplControlFocus( GetFocusFlags nFlags )
     }
     else
     {
-        if ( GetType() == WINDOW_RADIOBUTTON )
+        if ( GetType() == WindowType::RADIOBUTTON )
         {
             if ( !static_cast<RadioButton*>(this)->IsChecked() )
                 static_cast<RadioButton*>(this)->ImplCallClick( true, nFlags );
@@ -517,14 +513,14 @@ void Window::ImplControlFocus( GetFocusFlags nFlags )
 
 namespace
 {
-    bool isSuitableDestination(vcl::Window *pWindow)
+    bool isSuitableDestination(vcl::Window const *pWindow)
     {
         return (pWindow && isVisibleInLayout(pWindow) &&
                 isEnabledInLayout(pWindow) && pWindow->IsInputEnabled() &&
                 //Pure window shouldn't get window after controls such as
                 //buttons.
-                (pWindow->GetType() != WINDOW_WINDOW && pWindow->GetType() != WINDOW_SYSWINDOW &&
-                  pWindow->GetType() != WINDOW_WORKWINDOW && pWindow->GetType() != WINDOW_CONTROL)
+                (pWindow->GetType() != WindowType::WINDOW &&
+                  pWindow->GetType() != WindowType::WORKWINDOW && pWindow->GetType() != WindowType::CONTROL)
                );
     }
 
@@ -704,7 +700,7 @@ bool Window::ImplDlgCtrl( const KeyEvent& rKEvt, bool bKeyInput )
         iButtonStart = iButton;
         while ( pButtonWindow )
         {
-            if ( pButtonWindow->GetType() == WINDOW_CANCELBUTTON )
+            if ( pButtonWindow->GetType() == WindowType::CANCELBUTTON )
                 break;
 
             pButtonWindow = ImplGetNextWindow( this, iButton, iButton, true );
@@ -848,7 +844,7 @@ bool Window::ImplDlgCtrl( const KeyEvent& rKEvt, bool bKeyInput )
         }
         else if ( (nKeyCode == KEY_LEFT) || (nKeyCode == KEY_UP) )
         {
-            if (pSWindow->GetType() == WINDOW_RADIOBUTTON)
+            if (pSWindow->GetType() == WindowType::RADIOBUTTON)
                 return nextInGroup(static_cast<RadioButton*>(pSWindow), true);
             else
             {
@@ -879,7 +875,7 @@ bool Window::ImplDlgCtrl( const KeyEvent& rKEvt, bool bKeyInput )
         }
         else if ( (nKeyCode == KEY_RIGHT) || (nKeyCode == KEY_DOWN) )
         {
-            if (pSWindow->GetType() == WINDOW_RADIOBUTTON)
+            if (pSWindow->GetType() == WindowType::RADIOBUTTON)
                 return nextInGroup(static_cast<RadioButton*>(pSWindow), false);
             else
             {
@@ -948,7 +944,7 @@ bool Window::ImplDlgCtrl( const KeyEvent& rKEvt, bool bKeyInput )
 }
 
 // checks if this window has dialog control
-bool Window::ImplHasDlgCtrl()
+bool Window::ImplHasDlgCtrl() const
 {
     vcl::Window* pDlgCtrlParent;
 
@@ -959,10 +955,7 @@ bool Window::ImplHasDlgCtrl()
             ((pDlgCtrlParent->GetStyle() & (WB_DIALOGCONTROL | WB_NODIALOGCONTROL)) != WB_DIALOGCONTROL) )
         pDlgCtrlParent = pDlgCtrlParent->ImplGetParent();
 
-    if ( !pDlgCtrlParent || ((pDlgCtrlParent->GetStyle() & (WB_DIALOGCONTROL | WB_NODIALOGCONTROL)) != WB_DIALOGCONTROL) )
-        return false;
-    else
-        return true;
+    return pDlgCtrlParent && ((pDlgCtrlParent->GetStyle() & (WB_DIALOGCONTROL | WB_NODIALOGCONTROL)) == WB_DIALOGCONTROL);
 }
 
 void Window::ImplDlgCtrlNextWindow()
