@@ -21,13 +21,13 @@
 #include <vcl/layout.hxx>
 #include <vcl/tabctrl.hxx>
 #include <vcl/tabdlg.hxx>
-#include <tools/rc.h>
+#include <vcl/tabpage.hxx>
 
 void TabDialog::ImplInitTabDialogData()
 {
-    mpFixedLine     = NULL;
-    mpViewWindow    = NULL;
-    meViewAlign     = WINDOWALIGN_LEFT;
+    mpFixedLine     = nullptr;
+    mpViewWindow    = nullptr;
+    meViewAlign     = WindowAlign::Left;
     mbPosControls   = true;
 }
 
@@ -39,18 +39,18 @@ void TabDialog::ImplPosControls()
     Size        aCtrlSize( IMPL_MINSIZE_BUTTON_WIDTH, IMPL_MINSIZE_BUTTON_HEIGHT );
     long        nDownCtrl = 0;
     long        nOffY = 0;
-    Window*     pTabControl = NULL;
+    vcl::Window*     pTabControl = nullptr;
 
-    Window* pChild = GetWindow( WINDOW_FIRSTCHILD );
+    vcl::Window* pChild = GetWindow( GetWindowType::FirstChild );
     while ( pChild )
     {
         if ( pChild->IsVisible() && (pChild != mpViewWindow) )
         {
-            if (pChild->GetType() == WINDOW_TABCONTROL || isContainerWindow(*pChild))
+            if (pChild->GetType() == WindowType::TABCONTROL || isContainerWindow(*pChild))
                 pTabControl = pChild;
             else if ( pTabControl )
             {
-                Size aOptimalSize(pChild->GetOptimalSize());
+                Size aOptimalSize(pChild->get_preferred_size());
                 long nTxtWidth = aOptimalSize.Width();
                 if ( nTxtWidth > aCtrlSize.Width() )
                     aCtrlSize.Width() = nTxtWidth;
@@ -67,7 +67,7 @@ void TabDialog::ImplPosControls()
             }
         }
 
-        pChild = pChild->GetWindow( WINDOW_NEXT );
+        pChild = pChild->GetWindow( GetWindowType::Next );
     }
 
     // do we have a TabControl ?
@@ -80,7 +80,7 @@ void TabDialog::ImplPosControls()
         Point   aTabOffset( IMPL_DIALOG_OFFSET, IMPL_DIALOG_OFFSET+nOffY );
 
         if (isContainerWindow(*pTabControl))
-            pTabControl->SetSizePixel(pTabControl->GetOptimalSize());
+            pTabControl->SetSizePixel(pTabControl->get_preferred_size());
 
         Size    aTabSize = pTabControl->GetSizePixel();
 
@@ -88,47 +88,47 @@ void TabDialog::ImplPosControls()
                           aTabSize.Height() + IMPL_DIALOG_OFFSET*2 + nOffY );
         long    nBtnEx = 0;
 
-        // consider Preview-Fenster and adapt the sizes/offsets
+        // consider preview window and adapt the sizes/offsets
         if ( mpViewWindow && mpViewWindow->IsVisible() )
         {
             long    nViewOffX = 0;
             long    nViewOffY = 0;
             long    nViewWidth = 0;
             long    nViewHeight = 0;
-            sal_uInt16  nViewPosFlags = WINDOW_POSSIZE_POS;
+            PosSizeFlags nViewPosFlags = PosSizeFlags::Pos;
             Size    aViewSize = mpViewWindow->GetSizePixel();
-            if (  meViewAlign == WINDOWALIGN_TOP )
+            if (  meViewAlign == WindowAlign::Top )
             {
                 nViewOffX       = aTabOffset.X();
                 nViewOffY       = nOffY+IMPL_DIALOG_OFFSET;
                 nViewWidth      = aTabSize.Width();
-                nViewPosFlags  |= WINDOW_POSSIZE_WIDTH;
+                nViewPosFlags  |= PosSizeFlags::Width;
                 aTabOffset.Y() += aViewSize.Height()+IMPL_DIALOG_OFFSET;
                 aDlgSize.Height() += aViewSize.Height()+IMPL_DIALOG_OFFSET;
             }
-            else if (  meViewAlign == WINDOWALIGN_BOTTOM )
+            else if (  meViewAlign == WindowAlign::Bottom )
             {
                 nViewOffX       = aTabOffset.X();
                 nViewOffY       = aTabOffset.Y()+aTabSize.Height()+IMPL_DIALOG_OFFSET;
                 nViewWidth      = aTabSize.Width();
-                nViewPosFlags  |= WINDOW_POSSIZE_WIDTH;
+                nViewPosFlags  |= PosSizeFlags::Width;
                 aDlgSize.Height() += aViewSize.Height()+IMPL_DIALOG_OFFSET;
             }
-            else if (  meViewAlign == WINDOWALIGN_RIGHT )
+            else if (  meViewAlign == WindowAlign::Right )
             {
                 nViewOffX       = aTabOffset.X()+aTabSize.Width()+IMPL_DIALOG_OFFSET;
                 nViewOffY       = aTabOffset.Y();
                 nViewHeight     = aTabSize.Height();
-                nViewPosFlags  |= WINDOW_POSSIZE_HEIGHT;
+                nViewPosFlags  |= PosSizeFlags::Height;
                 aDlgSize.Width() += aViewSize.Width()+IMPL_DIALOG_OFFSET;
                 nBtnEx          = aViewSize.Width()+IMPL_DIALOG_OFFSET;
             }
-            else // meViewAlign == WINDOWALIGN_LEFT
+            else // meViewAlign == WindowAlign::Left
             {
                 nViewOffX       = IMPL_DIALOG_OFFSET;
                 nViewOffY       = aTabOffset.Y();
                 nViewHeight     = aTabSize.Height();
-                nViewPosFlags  |= WINDOW_POSSIZE_HEIGHT;
+                nViewPosFlags  |= PosSizeFlags::Height;
                 aTabOffset.X() += aViewSize.Width()+IMPL_DIALOG_OFFSET;
                 aDlgSize.Width() += aViewSize.Width()+IMPL_DIALOG_OFFSET;
                 nBtnEx          = aViewSize.Width()+IMPL_DIALOG_OFFSET;
@@ -155,7 +155,7 @@ void TabDialog::ImplPosControls()
         if ( nCtrlBarWidth <= (aTabSize.Width()+nBtnEx) )
             nX = (aTabSize.Width()+nBtnEx) - nCtrlBarWidth + IMPL_DIALOG_OFFSET;
 
-        Window* pChild2 = GetWindow( WINDOW_FIRSTCHILD );
+        vcl::Window* pChild2 = GetWindow( GetWindowType::FirstChild );
         while ( pChild2 )
         {
             if ( pChild2->IsVisible() && (pChild2 != mpViewWindow) )
@@ -185,7 +185,7 @@ void TabDialog::ImplPosControls()
                 }
             }
 
-            pChild2 = pChild2->GetWindow( WINDOW_NEXT );
+            pChild2 = pChild2->GetWindow( GetWindowType::Next );
         }
 
         aDlgSize.Height() += nLines * (aCtrlSize.Height()+IMPL_DIALOG_OFFSET);
@@ -197,7 +197,7 @@ void TabDialog::ImplPosControls()
     {
         Size aDlgSize = GetOutputSizePixel();
         if ( !mpFixedLine )
-            mpFixedLine = new FixedLine( this );
+            mpFixedLine = VclPtr<FixedLine>::Create( this );
         mpFixedLine->SetPosSizePixel( Point( 0, nOffY ),
                                       Size( aDlgSize.Width(), 2 ) );
         mpFixedLine->Show();
@@ -206,35 +206,34 @@ void TabDialog::ImplPosControls()
     mbPosControls = false;
 }
 
-TabDialog::TabDialog( Window* pParent, WinBits nStyle ) :
-    Dialog( WINDOW_TABDIALOG )
+TabDialog::TabDialog( vcl::Window* pParent, WinBits nStyle ) :
+    Dialog( WindowType::TABDIALOG )
 {
     ImplInitTabDialogData();
     ImplInit( pParent, nStyle );
 }
 
-TabDialog::TabDialog( Window* pParent, const ResId& rResId ) :
-    Dialog( WINDOW_TABDIALOG )
-{
-    ImplInitTabDialogData();
-    rResId.SetRT( RSC_TABDIALOG );
-    init(pParent, rResId);
-}
-
-TabDialog::TabDialog( Window* pParent, const OString& rID, const OUString& rUIXMLDescription ) :
-    Dialog(pParent, rID, rUIXMLDescription, WINDOW_TABDIALOG)
+TabDialog::TabDialog( vcl::Window* pParent, const OUString& rID, const OUString& rUIXMLDescription ) :
+    Dialog(pParent, rID, rUIXMLDescription, WindowType::TABDIALOG)
 {
     ImplInitTabDialogData();
 }
 
 TabDialog::~TabDialog()
 {
-    delete mpFixedLine;
+    disposeOnce();
+}
+
+void TabDialog::dispose()
+{
+    mpFixedLine.disposeAndClear();
+    mpViewWindow.clear();
+    Dialog::dispose();
 }
 
 void TabDialog::StateChanged( StateChangedType nType )
 {
-    if ( nType == STATE_CHANGE_INITSHOW )
+    if ( nType == StateChangedType::InitShow )
     {
         // Calculate the Layout only for the initialized state
         if ( mbPosControls )
@@ -243,12 +242,144 @@ void TabDialog::StateChanged( StateChangedType nType )
     Dialog::StateChanged( nType );
 }
 
-void TabDialog::AdjustLayout()
+vcl::Window* findTabControl(vcl::Window* pCurrent)
 {
-    SAL_WARN_IF(isLayoutEnabled(), "vcl.layout", "unnecessary to call TabDialog::AdjustLayout when layout enabled");
+    if (!pCurrent)
+    {
+        return nullptr;
+    }
 
-    ImplPosControls();
-    queue_resize();
+    if (pCurrent->GetType() == WindowType::TABCONTROL)
+    {
+        return pCurrent;
+    }
+
+    vcl::Window* pChild = pCurrent->GetWindow(GetWindowType::FirstChild);
+
+    while (pChild)
+    {
+
+        vcl::Window* pInorderChild = findTabControl(pChild);
+
+        if (pInorderChild)
+        {
+            return pInorderChild;
+        }
+
+        pChild = pChild->GetWindow(GetWindowType::Next);
+    }
+
+    return nullptr;
+}
+
+std::vector<OString> TabDialog::getAllPageUIXMLDescriptions() const
+{
+    std::vector<OString> aRetval;
+
+    const TabControl* pTabCtrl = dynamic_cast<TabControl*>(findTabControl(const_cast<TabDialog*>(this)));
+
+    if (pTabCtrl)
+    {
+        for (sal_uInt16 a(0); a < pTabCtrl->GetPageCount(); a++)
+        {
+            const sal_uInt16 nPageId(pTabCtrl->GetPageId(a));
+
+            if (TAB_PAGE_NOTFOUND != nPageId)
+            {
+                TabPage* pCandidate = pTabCtrl->GetTabPage(nPageId);
+
+                if (pCandidate)
+                {
+                    OString aNewName(pCandidate->getUIFile());
+
+                    if (!aNewName.isEmpty())
+                    {
+                        // we have to check for double entries, this may happen e.g.
+                        // in the HeaderFooterDialog which has two times the same
+                        // tabPage added. Add the PageID as hint to the name, separated
+                        // by a token (using "|" here). Do not do this for 1st occurrence,
+                        // that is used for detection and is not necessary.
+                        // Use the UIXMLDescription without trailing '.ui', with one trailing '/'
+                        bool bAlreadyAdded(false);
+
+                        for (auto i = aRetval.begin(); !bAlreadyAdded && i != aRetval.end(); i++)
+                        {
+                            bAlreadyAdded = (*i == aNewName);
+                        }
+
+                        if (bAlreadyAdded)
+                        {
+                            // add the PageId to be able to detect the correct tabPage in
+                            // selectPageByUIXMLDescription below
+                            aNewName = aNewName + "|" + OString::number(nPageId);
+                        }
+
+                        aRetval.push_back(aNewName);
+                    }
+                }
+            }
+        }
+    }
+
+    return aRetval;
+}
+
+bool TabDialog::selectPageByUIXMLDescription(const OString& rUIXMLDescription)
+{
+    TabControl* pTabCtrl = dynamic_cast<TabControl*>(findTabControl(this));
+
+    if (pTabCtrl)
+    {
+        sal_uInt32 nTargetPageId(0);
+        OString aTargetName(rUIXMLDescription);
+        const sal_Int32 nIndexOfSeparator(rUIXMLDescription.indexOf("|"));
+
+        if (-1 != nIndexOfSeparator)
+        {
+            // more than one tabPage with that UXMLDescription is added to this dialog,
+            // see getAllPageUIXMLDescriptions() above. Extract target PageId and
+            // strip the UXMLDescription name for comparison
+            nTargetPageId = rUIXMLDescription.copy(nIndexOfSeparator + 1).toUInt32();
+            aTargetName = rUIXMLDescription.copy(0, nIndexOfSeparator);
+        }
+
+        for (sal_uInt16 a(0); a < pTabCtrl->GetPageCount(); a++)
+        {
+            const sal_uInt16 nPageId(pTabCtrl->GetPageId(a));
+
+            if (TAB_PAGE_NOTFOUND != nPageId)
+            {
+                TabPage* pCandidate = pTabCtrl->GetTabPage(nPageId);
+
+                if (pCandidate)
+                {
+                    if (pCandidate->getUIFile() == aTargetName)
+                    {
+                        if (nTargetPageId)
+                        {
+                            // when multiple versions may exist, name is not sufficient. Also
+                            // check for the given PageId to select the correct tabPage
+                            // for cases where the same TabPage is used more than once
+                            // in a tabDialog (e.g. HeaderFooterDialog)
+                            if (nTargetPageId == nPageId)
+                            {
+                                pTabCtrl->SelectTabPage(nPageId);
+                                return true;
+                            }
+                        }
+                        else
+                        {
+                            // select that tabPage
+                            pTabCtrl->SelectTabPage(nPageId);
+                            return true;
+                        }
+                    }
+                }
+            }
+        }
+    }
+
+    return false;
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
