@@ -17,20 +17,22 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "unx/fontcache.hxx"
-#include "impfont.hxx"
-#include "unx/fontmanager.hxx"
+#include <memory>
+#include <unx/fontmanager.hxx>
+#include <impfont.hxx>
 #include <vcl/svapp.hxx>
 #include <vcl/sysdata.hxx>
 #include <vcl/vclenum.hxx>
 #include <vcl/wrkwin.hxx>
-#include "fontinstance.hxx"
-#include "sallayout.hxx"
+#include <fontinstance.hxx>
+#include <sallayout.hxx>
 #include <i18nlangtag/languagetag.hxx>
 #include <i18nutil/unicode.hxx>
 #include <rtl/strbuf.hxx>
 #include <unicode/uchar.h>
 #include <unicode/uscript.h>
+#include <config_gio.h>
+#include <officecfg/Office/Common.hxx>
 
 using namespace psp;
 
@@ -38,21 +40,20 @@ using namespace psp;
 #include <ft2build.h>
 #include <fontconfig/fcfreetype.h>
 
-#if ENABLE_DBUS
-#include <dbus/dbus-glib.h>
+#if ENABLE_GIO
+#include <gio/gio.h>
 #endif
 
 #include <cstdio>
 #include <cstdarg>
 
-#include <unotools/atom.hxx>
 #include <unotools/configmgr.hxx>
 
-#include "osl/module.h"
-#include "osl/thread.h"
-#include "osl/process.h"
+#include <osl/module.h>
+#include <osl/thread.h>
+#include <osl/process.h>
 
-#include "rtl/ustrbuf.hxx"
+#include <rtl/ustrbuf.hxx>
 
 #include <utility>
 #include <algorithm>
@@ -82,11 +83,11 @@ public:
     void clear();
 
 public:
-    FcResult LocalizedElementFromPattern(FcPattern* pPattern, FcChar8 **family,
+    FcResult LocalizedElementFromPattern(FcPattern const * pPattern, FcChar8 **family,
                                          const char *elementtype, const char *elementlangtype);
 //to-do, make private and add some cleaner accessor methods
-    std::unordered_map< OString, OString, OStringHash > m_aFontNameToLocalized;
-    std::unordered_map< OString, OString, OStringHash > m_aLocalizedToCanonical;
+    std::unordered_map< OString, OString > m_aFontNameToLocalized;
+    std::unordered_map< OString, OString > m_aLocalizedToCanonical;
 private:
     void cacheLocalizedFontNames(const FcChar8 *origfontname, const FcChar8 *bestfontname, const std::vector< lang_and_element > &lang_and_elements);
 
@@ -120,17 +121,13 @@ void FontCfgWrapper::addFontSet( FcSetName eSetName )
         FcResult eOutRes = FcPatternGetBool( pPattern, FC_OUTLINE, 0, &bOutline );
         if( (eOutRes != FcResultMatch) || (bOutline == FcFalse) )
             continue;
-        if (SalLayout::UseCommonLayout())
-        {
-            // Ignore Type 1 fonts; CommonSalLayout does not support them.
-            FcChar8* pFormat = nullptr;
-            FcResult eFormatRes = FcPatternGetString(pPattern, FC_FONTFORMAT, 0, &pFormat);
-            if ((eFormatRes == FcResultMatch) &&
-                (strcmp(reinterpret_cast<char*>(pFormat), "Type 1") == 0))
-            {
-                continue;
-            }
-        }
+
+        // Ignore Type 1 fonts, too.
+        FcChar8* pFormat = nullptr;
+        FcResult eFormatRes = FcPatternGetString(pPattern, FC_FONTFORMAT, 0, &pFormat);
+        if ((eFormatRes == FcResultMatch) && (strcmp(reinterpret_cast<char*>(pFormat), "Type 1") == 0))
+            continue;
+
         FcPatternReference( pPattern );
         FcFontSetAdd( m_pOutlineSet, pPattern );
     }
@@ -155,7 +152,7 @@ namespace
 
     //Sort fonts so that fonts with the same family name are side-by-side, with
     //those with higher version numbers first
-    class SortFont : public ::std::binary_function< const FcPattern*, const FcPattern*, bool >
+    class SortFont
     {
     public:
         bool operator()(const FcPattern *a, const FcPattern *b)
@@ -182,7 +179,7 @@ namespace
     //See if this font is a duplicate with equal attributes which has already been
     //inserted, or if it an older version of an inserted fonts. Depends on FcFontSet
     //on being sorted with SortFont
-    bool isPreviouslyDuplicateOrObsoleted(FcFontSet *pFSet, int i)
+    bool isPreviouslyDuplicateOrObsoleted(FcFontSet const *pFSet, int i)
     {
         const FcPattern *a = pFSet->fonts[i];
 
@@ -227,8 +224,7 @@ FcFontSet* FontCfgWrapper::getFontSet()
     {
         m_pOutlineSet = FcFontSetCreate();
         addFontSet( FcSetSystem );
-        if( FcGetVersion() > 20400 ) // #i85462# prevent crashes
-            addFontSet( FcSetApplication );
+        addFontSet( FcSetApplication );
 
         ::std::sort(m_pOutlineSet->fonts,m_pOutlineSet->fonts+m_pOutlineSet->nfont,SortFont());
     }
@@ -282,7 +278,7 @@ namespace
         for( std::vector<lang_and_element>::const_iterator aIter = elements.begin(); aIter != aEnd; ++aIter )
         {
             const char *pLang = reinterpret_cast<const char*>(aIter->first);
-            if( rtl_str_compare( pLang, sFullMatch.getStr() ) == 0)
+            if( sFullMatch == pLang)
             {
                 // both language and country match
                 candidate = aIter->second;
@@ -294,7 +290,7 @@ namespace
                 // override candidate only if there is a full match
                 continue;
             }
-            else if( rtl_str_compare( pLang, sLangMatch.getStr()) == 0)
+            else if( sLangMatch == pLang)
             {
                 // just the language matches
                 candidate = aIter->second;
@@ -333,7 +329,7 @@ void FontCfgWrapper::cacheLocalizedFontNames(const FcChar8 *origfontname, const
         m_aLocalizedToCanonical[OString(reinterpret_cast<const char*>(bestfontname))] = OString(reinterpret_cast<const char*>(origfontname));
 }
 
-FcResult FontCfgWrapper::LocalizedElementFromPattern(FcPattern* pPattern, FcChar8 **element,
+FcResult FontCfgWrapper::LocalizedElementFromPattern(FcPattern const * pPattern, FcChar8 **element,
                                                      const char *elementtype, const char *elementlangtype)
 {                                                /* e. g.:      ^ FC_FAMILY              ^ FC_FAMILYLANG */
     FcChar8 *origelement;
@@ -346,7 +342,7 @@ FcResult FontCfgWrapper::LocalizedElementFromPattern(FcPattern* pPattern, FcChar
         if (FcPatternGetString( pPattern, elementlangtype, 0, &elementlang ) == FcResultMatch)
         {
             std::vector< lang_and_element > lang_and_elements;
-            lang_and_elements.push_back(lang_and_element(elementlang, *element));
+            lang_and_elements.emplace_back(elementlang, *element);
             int k = 1;
             while (true)
             {
@@ -354,7 +350,7 @@ FcResult FontCfgWrapper::LocalizedElementFromPattern(FcPattern* pPattern, FcChar
                     break;
                 if (FcPatternGetString( pPattern, elementtype, k, element ) != FcResultMatch)
                     break;
-                lang_and_elements.push_back(lang_and_element(elementlang, *element));
+                lang_and_elements.emplace_back(elementlang, *element);
                 ++k;
             }
 
@@ -478,7 +474,7 @@ static void lcl_FcFontSetRemove(FcFontSet* pFSet, int i)
     memmove(pFSet->fonts + i, pFSet->fonts + i + 1, nTail*sizeof(FcPattern*));
 }
 
-void PrintFontManager::countFontconfigFonts( std::unordered_map<OString, int, OStringHash>& o_rVisitedPaths )
+void PrintFontManager::countFontconfigFonts( std::unordered_map<OString, int>& o_rVisitedPaths )
 {
 #if OSL_DEBUG_LEVEL > 1
     int nFonts = 0;
@@ -486,7 +482,7 @@ void PrintFontManager::countFontconfigFonts( std::unordered_map<OString, int, OS
     FontCfgWrapper& rWrapper = FontCfgWrapper::get();
 
     FcFontSet* pFSet = rWrapper.getFontSet();
-    const bool bMinimalFontset = utl::ConfigManager::IsAvoidConfig();
+    const bool bMinimalFontset = utl::ConfigManager::IsFuzzing();
     if( pFSet )
     {
 #if OSL_DEBUG_LEVEL > 1
@@ -552,30 +548,25 @@ void PrintFontManager::countFontconfigFonts( std::unordered_map<OString, int, OS
 
             // see if this font is already cached
             // update attributes
-            std::list< PrintFont* > aFonts;
             OString aDir, aBase, aOrgPath( reinterpret_cast<char*>(file) );
             splitPath( aOrgPath, aDir, aBase );
 
             o_rVisitedPaths[aDir] = 1;
 
-            int nDirID = getDirectoryAtom( aDir, true );
-            if( ! m_pFontCache->getFontCacheFile( nDirID, aBase, aFonts ) )
-            {
+            int nDirID = getDirectoryAtom( aDir );
 #if OSL_DEBUG_LEVEL > 2
-                fprintf( stderr, "file %s not cached\n", aBase.getStr() );
+            fprintf( stderr, "file %s not cached\n", aBase.getStr() );
 #endif
-                // not known, analyze font file to get attributes
-                // not described by fontconfig (e.g. alias names, PSName)
-                if (eFormatRes != FcResultMatch)
-                    format = nullptr;
-                analyzeFontFile( nDirID, aBase, aFonts, reinterpret_cast<char*>(format) );
-#if OSL_DEBUG_LEVEL > 1
-                if( aFonts.empty() )
-                    fprintf( stderr, "Warning: file \"%s\" is unusable to psprint\n", aOrgPath.getStr() );
-#endif
-            }
-            if( aFonts.empty() )
+            // not known, analyze font file to get attributes
+            // not described by fontconfig (e.g. alias names, PSName)
+            if (eFormatRes != FcResultMatch)
+                format = nullptr;
+            std::vector<std::unique_ptr<PrintFont>> aFonts = analyzeFontFile( nDirID, aBase, reinterpret_cast<char*>(format) );
+            if(aFonts.empty())
             {
+#if OSL_DEBUG_LEVEL > 1
+                fprintf( stderr, "Warning: file \"%s\" is unusable to psprint\n", aOrgPath.getStr() );
+#endif
                 //remove font, reuse index
                 //we want to remove unusable fonts here, in case there is a usable font
                 //which duplicates the properties of the unusable one
@@ -586,67 +577,65 @@ void PrintFontManager::countFontconfigFonts( std::unordered_map<OString, int, OS
                 continue;
             }
 
-            int nFamilyName = m_pAtoms->getAtom( ATOM_FAMILYNAME, OStringToOUString( OString( reinterpret_cast<char*>(family) ), RTL_TEXTENCODING_UTF8 ) );
-            PrintFont* pUpdate = aFonts.front();
-            std::list<PrintFont*>::const_iterator second_font = aFonts.begin();
+            std::unique_ptr<PrintFont> xUpdate;
+
+            auto second_font = aFonts.begin();
             ++second_font;
-            if( second_font != aFonts.end() ) // more than one font
+            if (second_font == aFonts.end()) // one font
+                xUpdate = std::move(aFonts.front());
+            else // more than one font
             {
                 // a collection entry, get the correct index
                 if( eIndexRes == FcResultMatch && nCollectionEntry != -1 )
                 {
-                    for( std::list< PrintFont* >::iterator it = aFonts.begin(); it != aFonts.end(); ++it )
+                    for (auto it = aFonts.begin(); it != aFonts.end(); ++it)
                     {
-                        if( (*it)->m_eType == fonttype::TrueType &&
-                            static_cast<TrueTypeFontFile*>(*it)->m_nCollectionEntry == nCollectionEntry )
+                        if( (*it)->m_nCollectionEntry == nCollectionEntry )
                         {
-                            pUpdate = *it;
+                            xUpdate = std::move(*it);
                             break;
                         }
                     }
+                }
+
+                if (xUpdate)
+                {
                     // update collection entry
                     // additional entries will be created in the cache
                     // if this is a new index (that is if the loop above
                     // ran to the end of the list)
-                    if( pUpdate->m_eType == fonttype::TrueType ) // sanity check, this should always be the case here
-                        static_cast<TrueTypeFontFile*>(pUpdate)->m_nCollectionEntry = nCollectionEntry;
+                    xUpdate->m_nCollectionEntry = nCollectionEntry;
                 }
+#if OSL_DEBUG_LEVEL > 1
                 else
                 {
-#if OSL_DEBUG_LEVEL > 1
                     fprintf( stderr, "multiple fonts for file, but no index in fontconfig pattern ! (index res = %d collection entry = %d\nfile will not be used\n", eIndexRes, nCollectionEntry );
-#endif
                     // we have found more than one font in this file
                     // but fontconfig will not tell us which index is meant
                     // -> something is in disorder, do not use this font
-                    pUpdate = nullptr;
                 }
+#endif
             }
 
-            if( pUpdate )
+            if (xUpdate)
             {
                 // set family name
-                if( pUpdate->m_nFamilyName != nFamilyName )
-                {
-                }
                 if( eWeightRes == FcResultMatch )
-                    pUpdate->m_eWeight = convertWeight(weight);
+                    xUpdate->m_eWeight = convertWeight(weight);
                 if( eWidthRes == FcResultMatch )
-                    pUpdate->m_eWidth = convertWidth(width);
+                    xUpdate->m_eWidth = convertWidth(width);
                 if( eSpacRes == FcResultMatch )
-                    pUpdate->m_ePitch = convertSpacing(spacing);
+                    xUpdate->m_ePitch = convertSpacing(spacing);
                 if( eSlantRes == FcResultMatch )
-                    pUpdate->m_eItalic = convertSlant(slant);
+                    xUpdate->m_eItalic = convertSlant(slant);
                 if( eStyleRes == FcResultMatch )
                 {
-                    pUpdate->m_aStyleName = OStringToOUString( OString( reinterpret_cast<char*>(style) ), RTL_TEXTENCODING_UTF8 );
+                    xUpdate->m_aStyleName = OStringToOUString( OString( reinterpret_cast<char*>(style) ), RTL_TEXTENCODING_UTF8 );
                 }
 
-                // update font cache
-                m_pFontCache->updateFontCacheEntry( pUpdate, false );
                 // sort into known fonts
                 fontID aFont = m_nNextFontID++;
-                m_aFonts[ aFont ] = pUpdate;
+                m_aFonts[ aFont ] = xUpdate.release();
                 m_aFontFileToFontID[ aBase ].insert( aFont );
 #if OSL_DEBUG_LEVEL > 1
                 nFonts++;
@@ -655,15 +644,6 @@ void PrintFontManager::countFontconfigFonts( std::unordered_map<OString, int, OS
                 fprintf( stderr, "inserted font %s as fontID %d\n", family, aFont );
 #endif
             }
-            // clean up the fonts we did not put into the list
-            for( std::list< PrintFont* >::iterator it = aFonts.begin(); it != aFonts.end(); ++it )
-            {
-                if( *it != pUpdate )
-                {
-                    m_pFontCache->updateFontCacheEntry( *it, false ); // prepare a cache entry for a collection item
-                    delete *it;
-                }
-            }
         }
     }
 
@@ -678,13 +658,8 @@ void PrintFontManager::deinitFontconfig()
     FontCfgWrapper::release();
 }
 
-bool PrintFontManager::addFontconfigDir( const OString& rDirName )
+void PrintFontManager::addFontconfigDir( const OString& rDirName )
 {
-    // workaround for a stability problems in older FC versions
-    // when handling application specific fonts
-    const int nVersion = FcGetVersion();
-    if( nVersion <= 20400 )
-        return false;
     const char* pDirName = rDirName.getStr();
     bool bDirOk = (FcConfigAppFontAddDir(FcConfigGetCurrent(), reinterpret_cast<FcChar8 const *>(pDirName) ) == FcTrue);
 
@@ -693,7 +668,7 @@ bool PrintFontManager::addFontconfigDir( const OString& rDirName )
 #endif
 
     if( !bDirOk )
-        return false;
+        return;
 
     // load dir-specific fc-config file too if available
     const OString aConfFileName = rDirName + "/fc_local.conf";
@@ -705,9 +680,9 @@ bool PrintFontManager::addFontconfigDir( const OString& rDirName )
                         reinterpret_cast<FcChar8 const *>(aConfFileName.getStr()), FcTrue);
         if( !bCfgOk )
             fprintf( stderr, "FcConfigParseAndLoad( \"%s\") => %d\n", aConfFileName.getStr(), bCfgOk );
+    } else {
+        SAL_INFO("vcl", "cannot open " << aConfFileName);
     }
-
-    return true;
 }
 
 static void addtopattern(FcPattern *pPattern,
@@ -888,9 +863,11 @@ namespace
         return OStringToOUString(aBuf.makeStringAndClear(), RTL_TEXTENCODING_UTF8);
     }
 
-#if ENABLE_DBUS
+#if ENABLE_GIO
     guint get_xid_for_dbus()
     {
+        // FIXME: Application::GetActiveTopWindow only returns something sensible if LO currently has the focus
+        // (which is not the case when you are trying to debug this...). It should instead return the last active window.
         const vcl::Window *pTopWindow = Application::IsHeadlessModeEnabled() ? nullptr : Application::GetActiveTopWindow();
         const SystemEnvData* pEnvData = pTopWindow ? pTopWindow->GetSystemData() : nullptr;
         return pEnvData ? pEnvData->aWindow : 0;
@@ -898,17 +875,24 @@ namespace
 #endif
 }
 
-#if ENABLE_DBUS
+#if ENABLE_GIO
 IMPL_LINK_NOARG(PrintFontManager, autoInstallFontLangSupport, Timer *, void)
 {
+    if (!officecfg::Office::Common::PackageKit::EnableFontInstallation::get())
+        return;
+
     guint xid = get_xid_for_dbus();
 
     if (!xid)
+    {
+        SAL_WARN("vcl", "Could not retrieve X Window ID for DBUS");
         return;
+    }
+
 
     GError *error = nullptr;
     /* get the DBUS session connection */
-    DBusGConnection *session_connection = dbus_g_bus_get(DBUS_BUS_SESSION, &error);
+    GDBusConnection *session_connection = g_bus_get_sync(G_BUS_TYPE_SESSION, nullptr, &error);
     if (error != nullptr)
     {
         g_debug ("DBUS cannot connect : %s", error->message);
@@ -917,40 +901,54 @@ IMPL_LINK_NOARG(PrintFontManager, autoInstallFontLangSupport, Timer *, void)
     }
 
     /* get the proxy with gnome-session-manager */
-    DBusGProxy *proxy = dbus_g_proxy_new_for_name(session_connection,
-                                       "org.freedesktop.PackageKit",
-                                       "/org/freedesktop/PackageKit",
-                                       "org.freedesktop.PackageKit.Modify");
-    if (proxy == nullptr)
+    GDBusProxy *proxy = g_dbus_proxy_new_sync(session_connection,
+                                              G_DBUS_PROXY_FLAGS_NONE,
+                                              nullptr, // GDBusInterfaceInfo
+                                              "org.freedesktop.PackageKit",
+                                              "/org/freedesktop/PackageKit",
+                                              "org.freedesktop.PackageKit.Modify",
+                                              nullptr, // GCancellable
+                                              &error);
+    if (proxy == nullptr && error != nullptr)
     {
-        g_debug("Could not get DBUS proxy: org.freedesktop.PackageKit");
+        g_debug("Could not get DBUS proxy: org.freedesktop.PackageKit: %s", error->message);
+        g_error_free(error);
         return;
     }
 
-    gchar **fonts = static_cast<gchar**>(g_malloc((m_aCurrentRequests.size() + 1) * sizeof(gchar*)));
-    gchar **font = fonts;
+    GVariantBuilder *builder = g_variant_builder_new (G_VARIANT_TYPE("as")); // 'as'=array of strings
     for (std::vector<OString>::const_iterator aI = m_aCurrentRequests.begin(); aI != m_aCurrentRequests.end(); ++aI)
-        *font++ = const_cast<gchar*>(aI->getStr());
-    *font = nullptr;
-    gboolean res = dbus_g_proxy_call(proxy, "InstallFontconfigResources", &error,
-                 G_TYPE_UINT, xid, /* xid */
-                 G_TYPE_STRV, fonts, /* data */
-                 G_TYPE_STRING, "hide-finished", /* interaction */
-                 G_TYPE_INVALID,
-                 G_TYPE_INVALID);
-    /* check the return value */
-    if (!res)
-       g_debug("InstallFontconfigResources method failed");
+        g_variant_builder_add (builder, "s", aI->getStr());
 
-    /* check the error value */
-    if (error != nullptr)
+    GVariant *res = g_dbus_proxy_call_sync(proxy,
+                                     "InstallFontconfigResources",
+                                     // Create a new variant with the following types:
+                                     //   'u'=guint32 (xid); 'as'=array of strings (builder); 's'=string ("hide-finished")
+                                     // See also https://people.gnome.org/~ryanl/glib-docs/gvariant-format-strings.html
+                                     g_variant_new("(uass)", xid, builder, "hide-finished"),
+                                     G_DBUS_CALL_FLAGS_NONE,
+                                     -1, // Timeout
+                                     nullptr, // GCancellable
+                                     &error);
+
+    if (res == nullptr && error != nullptr)
     {
+        // Disable this method from now on. It's simply not available on some systems
+        // and leads to an error dialog being shown each time this is called tdf#104883
+        std::shared_ptr<comphelper::ConfigurationChanges> batch( comphelper::ConfigurationChanges::create() );
+        officecfg::Office::Common::PackageKit::EnableFontInstallation::set(false, batch);
+        batch->commit();
         g_debug("InstallFontconfigResources problem : %s", error->message);
         g_error_free(error);
     }
+    else
+    {
+        g_variant_unref(res);
+    }
 
-    g_free(fonts);
+    g_variant_builder_unref(builder);
     g_object_unref(G_OBJECT (proxy));
+
     m_aCurrentRequests.clear();
 }
 #endif
@@ -975,12 +973,12 @@ void PrintFontManager::Substitute( FontSelectPattern &rPattern, OUString& rMissi
     // Add required Unicode characters, if any
     if ( !rMissingCodes.isEmpty() )
     {
-        FcCharSet *unicodes = FcCharSetCreate();
+        FcCharSet *codePoints = FcCharSetCreate();
         for( sal_Int32 nStrIndex = 0; nStrIndex < rMissingCodes.getLength(); )
         {
             // also handle unicode surrogates
             const sal_uInt32 nCode = rMissingCodes.iterateCodePoints( &nStrIndex );
-            FcCharSetAddChar( unicodes, nCode );
+            FcCharSetAddChar( codePoints, nCode );
             //if the codepoint is impossible for this lang tag, then clear it
             //and autodetect something useful
             if (!aLangAttrib.isEmpty() && isImpossibleCodePointForLang(aLangTag, nCode))
@@ -992,8 +990,8 @@ void PrintFontManager::Substitute( FontSelectPattern &rPattern, OUString& rMissi
                 aLangAttrib = mapToFontConfigLangTag(aLangTag);
             }
         }
-        FcPatternAddCharSet(pPattern, FC_CHARSET, unicodes);
-        FcCharSetDestroy(unicodes);
+        FcPatternAddCharSet(pPattern, FC_CHARSET, codePoints);
+        FcCharSetDestroy(codePoints);
     }
 
     if (!aLangAttrib.isEmpty())
@@ -1038,7 +1036,7 @@ void PrintFontManager::Substitute( FontSelectPattern &rPattern, OUString& rMissi
             {
                 OString aDir, aBase, aOrgPath( reinterpret_cast<char*>(file) );
                 splitPath( aOrgPath, aDir, aBase );
-                int nDirID = getDirectoryAtom( aDir, true );
+                int nDirID = getDirectoryAtom( aDir );
                 fontID aFont = findFontFileID( nDirID, aBase, nCollectionEntry );
                 if( aFont > 0 )
                 {
@@ -1059,7 +1057,7 @@ void PrintFontManager::Substitute( FontSelectPattern &rPattern, OUString& rMissi
                 if( eFamilyRes == FcResultMatch )
                 {
                     OString sFamily(reinterpret_cast<char*>(family));
-                    std::unordered_map< OString, OString, OStringHash >::const_iterator aI =
+                    std::unordered_map< OString, OString >::const_iterator aI =
                         rWrapper.m_aFontNameToLocalized.find(sFamily);
                     if (aI != rWrapper.m_aFontNameToLocalized.end())
                         sFamily = aI->second;
@@ -1092,24 +1090,24 @@ void PrintFontManager::Substitute( FontSelectPattern &rPattern, OUString& rMissi
                 }
             }
 
-            // update rMissingCodes by removing resolved unicodes
+            // update rMissingCodes by removing resolved code points
             if( !rMissingCodes.isEmpty() )
             {
                 std::unique_ptr<sal_uInt32[]> const pRemainingCodes(new sal_uInt32[rMissingCodes.getLength()]);
                 int nRemainingLen = 0;
-                FcCharSet* unicodes;
-                if (!FcPatternGetCharSet(pSet->fonts[0], FC_CHARSET, 0, &unicodes))
+                FcCharSet* codePoints;
+                if (!FcPatternGetCharSet(pSet->fonts[0], FC_CHARSET, 0, &codePoints))
                 {
                     for( sal_Int32 nStrIndex = 0; nStrIndex < rMissingCodes.getLength(); )
                     {
-                        // also handle unicode surrogates
+                        // also handle surrogates
                         const sal_uInt32 nCode = rMissingCodes.iterateCodePoints( &nStrIndex );
-                        if (FcCharSetHasChar(unicodes, nCode) != FcTrue)
+                        if (FcCharSetHasChar(codePoints, nCode) != FcTrue)
                             pRemainingCodes[ nRemainingLen++ ] = nCode;
                     }
                 }
                 OUString sStillMissing(pRemainingCodes.get(), nRemainingLen);
-#if ENABLE_DBUS
+#if ENABLE_GIO
                 if (get_xid_for_dbus())
                 {
                     if (sStillMissing == rMissingCodes) //replaced nothing
@@ -1179,7 +1177,7 @@ FontConfigFontOptions* PrintFontManager::getFontOptions(const FastPrintFontInfo&
 
     OString sFamily = OUStringToOString( rInfo.m_aFamilyName, RTL_TEXTENCODING_UTF8 );
 
-    std::unordered_map< OString, OString, OStringHash >::const_iterator aI = rWrapper.m_aLocalizedToCanonical.find(sFamily);
+    std::unordered_map< OString, OString >::const_iterator aI = rWrapper.m_aLocalizedToCanonical.find(sFamily);
     if (aI != rWrapper.m_aLocalizedToCanonical.end())
         sFamily = aI->second;
     if( !sFamily.isEmpty() )
@@ -1188,7 +1186,6 @@ FontConfigFontOptions* PrintFontManager::getFontOptions(const FastPrintFontInfo&
     addtopattern(pPattern, rInfo.m_eItalic, rInfo.m_eWeight, rInfo.m_eWidth, rInfo.m_ePitch);
     FcPatternAddDouble(pPattern, FC_PIXEL_SIZE, nSize);
 
-    FcBool embitmap = true, antialias = true, autohint = true, hinting = true;
     int hintstyle = FC_HINT_FULL;
 
     FcConfigSubstitute(pConfig, pPattern, FcMatchPattern);
@@ -1200,35 +1197,10 @@ FontConfigFontOptions* PrintFontManager::getFontOptions(const FastPrintFontInfo&
     FcPattern* pResult = FcFontSetMatch( pConfig, &pFontSet, 1, pPattern, &eResult );
     if( pResult )
     {
-        FcResult eEmbeddedBitmap = FcPatternGetBool(pResult,
-            FC_EMBEDDED_BITMAP, 0, &embitmap);
-        FcResult eAntialias = FcPatternGetBool(pResult,
-            FC_ANTIALIAS, 0, &antialias);
-        FcResult eAutoHint = FcPatternGetBool(pResult,
-            FC_AUTOHINT, 0, &autohint);
-        FcResult eHinting = FcPatternGetBool(pResult,
-            FC_HINTING, 0, &hinting);
         (void) FcPatternGetInteger(pResult,
             FC_HINT_STYLE, 0, &hintstyle);
 
         pOptions = new FontConfigFontOptions(pResult);
-
-        if( eEmbeddedBitmap == FcResultMatch )
-            pOptions->meEmbeddedBitmap = embitmap ? EMBEDDEDBITMAP_TRUE : EMBEDDEDBITMAP_FALSE;
-        if( eAntialias == FcResultMatch )
-            pOptions->meAntiAlias = antialias ? ANTIALIAS_TRUE : ANTIALIAS_FALSE;
-        if( eAutoHint == FcResultMatch )
-            pOptions->meAutoHint = autohint ? FontAutoHint::Yes : FontAutoHint::No;
-        if( eHinting == FcResultMatch )
-            pOptions->meHinting = hinting ? FontHinting::Yes : FontHinting::No;
-        switch (hintstyle)
-        {
-            case FC_HINT_NONE:   pOptions->meHintStyle = FontHintStyle::NONE; break;
-            case FC_HINT_SLIGHT: pOptions->meHintStyle = FontHintStyle::Slight; break;
-            case FC_HINT_MEDIUM: pOptions->meHintStyle = FontHintStyle::Medium; break;
-            default: // fall through
-            case FC_HINT_FULL:   pOptions->meHintStyle = FontHintStyle::Full; break;
-        }
     }
 
     // cleanup
@@ -1278,7 +1250,7 @@ void PrintFontManager::matchFont( FastPrintFontInfo& rInfo, const css::lang::Loc
             {
                 OString aDir, aBase, aOrgPath( reinterpret_cast<char*>(file) );
                 splitPath( aOrgPath, aDir, aBase );
-                int nDirID = getDirectoryAtom( aDir, true );
+                int nDirID = getDirectoryAtom( aDir );
                 fontID aFont = findFontFileID( nDirID, aBase, nCollectionEntry );
                 if( aFont > 0 )
                     getFontFastInfo( aFont, rInfo );
