@@ -20,29 +20,39 @@
 #include <stdlib.h>
 
 #include <comphelper/string.hxx>
-#include "vcl/ppdparser.hxx"
-#include "vcl/strhelper.hxx"
-#include "vcl/helper.hxx"
-#include "vcl/svapp.hxx"
-#include "vcl/settings.hxx"
-#include "cupsmgr.hxx"
-#include "tools/urlobj.hxx"
-#include "tools/stream.hxx"
-#include "tools/zcodec.hxx"
-#include "osl/mutex.hxx"
-#include "osl/file.hxx"
-#include "osl/process.h"
-#include "osl/thread.h"
-#include "rtl/strbuf.hxx"
-#include "rtl/ustrbuf.hxx"
-#include "rtl/instance.hxx"
+#include <vcl/ppdparser.hxx>
+#include <vcl/strhelper.hxx>
+#include <vcl/svapp.hxx>
+#include <vcl/settings.hxx>
+
+#include <unx/helper.hxx>
+#include <unx/cupsmgr.hxx>
+#include <unx/cpdmgr.hxx>
+
+#include <tools/urlobj.hxx>
+#include <tools/stream.hxx>
+#include <tools/zcodec.hxx>
+#include <osl/mutex.hxx>
+#include <osl/file.hxx>
+#include <osl/process.h>
+#include <osl/thread.h>
+#include <rtl/strbuf.hxx>
+#include <rtl/ustrbuf.hxx>
+#include <rtl/instance.hxx>
 #include <sal/macros.h>
 #include <salhelper/linkhelper.hxx>
 
-#include "com/sun/star/lang/Locale.hpp"
+#include <com/sun/star/lang/Locale.hpp>
 
 #include <unordered_map>
 
+#ifdef ENABLE_CUPS
+#include <cups/cups.h>
+#endif
+
+#include <config_dbus.h>
+#include <config_gio.h>
+
 namespace psp
 {
     class PPDTranslator
@@ -52,9 +62,9 @@ namespace psp
             bool operator()(const css::lang::Locale& i_rLeft,
                             const css::lang::Locale& i_rRight) const
             {
-                return i_rLeft.Language.equals( i_rRight.Language ) &&
-                i_rLeft.Country.equals( i_rRight.Country ) &&
-                i_rLeft.Variant.equals( i_rRight.Variant );
+                return i_rLeft.Language == i_rRight.Language &&
+                    i_rLeft.Country == i_rRight.Country &&
+                    i_rLeft.Variant == i_rRight.Variant;
             }
         };
 
@@ -70,25 +80,24 @@ namespace psp
         };
 
         typedef std::unordered_map< css::lang::Locale, OUString, LocaleHash, LocaleEqual > translation_map;
-        typedef std::unordered_map< OUString, translation_map, OUStringHash > key_translation_map;
+        typedef std::unordered_map< OUString, translation_map > key_translation_map;
 
         key_translation_map     m_aTranslations;
         public:
         PPDTranslator() {}
-        ~PPDTranslator() {}
 
         void insertValue(
             const OUString& i_rKey,
             const OUString& i_rOption,
             const OUString& i_rValue,
             const OUString& i_rTranslation,
-            const css::lang::Locale& i_rLocale = css::lang::Locale()
+            const css::lang::Locale& i_rLocale
             );
 
         void insertOption( const OUString& i_rKey,
                            const OUString& i_rOption,
                            const OUString& i_rTranslation,
-                           const css::lang::Locale& i_rLocale = css::lang::Locale() )
+                           const css::lang::Locale& i_rLocale )
         {
             insertValue( i_rKey, i_rOption, OUString(), i_rTranslation, i_rLocale );
         }
@@ -102,28 +111,24 @@ namespace psp
 
         OUString translateValue(
             const OUString& i_rKey,
-            const OUString& i_rOption,
-            const OUString& i_rValue,
-            const css::lang::Locale& i_rLocale = css::lang::Locale()
+            const OUString& i_rOption
             ) const;
 
         OUString translateOption( const OUString& i_rKey,
-                                       const OUString& i_rOption,
-                                       const css::lang::Locale& i_rLocale = css::lang::Locale() ) const
+                                       const OUString& i_rOption ) const
         {
-            return translateValue( i_rKey, i_rOption, OUString(), i_rLocale );
+            return translateValue( i_rKey, i_rOption  );
         }
 
-        OUString translateKey( const OUString& i_rKey,
-                                    const css::lang::Locale& i_rLocale = css::lang::Locale() ) const
+        OUString translateKey( const OUString& i_rKey ) const
         {
-            return translateValue( i_rKey, OUString(), OUString(), i_rLocale );
+            return translateValue( i_rKey, OUString() );
         }
     };
 
     static css::lang::Locale normalizeInputLocale(
         const css::lang::Locale& i_rLocale,
-        bool bInsertDefault = false
+        bool bInsertDefault
         )
     {
         css::lang::Locale aLoc( i_rLocale );
@@ -189,25 +194,18 @@ namespace psp
 
     OUString PPDTranslator::translateValue(
         const OUString& i_rKey,
-        const OUString& i_rOption,
-        const OUString& i_rValue,
-        const css::lang::Locale& i_rLocale
+        const OUString& i_rOption
         ) const
     {
         OUString aResult;
 
-        OUStringBuffer aKey( i_rKey.getLength() + i_rOption.getLength() + i_rValue.getLength() + 2 );
+        OUStringBuffer aKey( i_rKey.getLength() + i_rOption.getLength() + 2 );
         aKey.append( i_rKey );
-        if( !i_rOption.isEmpty() || !i_rValue.isEmpty() )
+        if( !i_rOption.isEmpty() )
         {
             aKey.append( ':' );
             aKey.append( i_rOption );
         }
-        if( !i_rValue.isEmpty() )
-        {
-            aKey.append( ':' );
-            aKey.append( i_rValue );
-        }
         if( !aKey.isEmpty() )
         {
             OUString aK( aKey.makeStringAndClear() );
@@ -216,7 +214,7 @@ namespace psp
             {
                 const translation_map& rMap( it->second );
 
-                css::lang::Locale aLoc( normalizeInputLocale( i_rLocale, true ) );
+                css::lang::Locale aLoc( normalizeInputLocale( css::lang::Locale(), true ) );
                 /* FIXME-BCP47: use LanguageTag::getFallbackStrings()? */
                 for( int nTry = 0; nTry < 4; nTry++ )
                 {
@@ -241,21 +239,11 @@ namespace psp
     class PPDCache
     {
     public:
-        std::list< PPDParser* > aAllParsers;
-        std::unordered_map< OUString, OUString, OUStringHash >* pAllPPDFiles;
+        std::vector< std::unique_ptr<PPDParser> > aAllParsers;
+        std::unique_ptr<std::unordered_map< OUString, OUString >> pAllPPDFiles;
         PPDCache()
             : pAllPPDFiles(nullptr)
         {}
-        ~PPDCache()
-        {
-            while( aAllParsers.begin() != aAllParsers.end() )
-            {
-                delete aAllParsers.front();
-                aAllParsers.pop_front();
-            }
-            delete pAllPPDFiles;
-            pAllPPDFiles = nullptr;
-        }
     };
 }
 
@@ -281,7 +269,7 @@ public:
     ~PPDDecompressStream();
 
     bool IsOpen() const;
-    bool IsEof() const;
+    bool eof() const;
     OString ReadLine();
     void Open( const OUString& i_rFile );
     void Close();
@@ -330,13 +318,15 @@ void PPDDecompressStream::Open( const OUString& i_rFile )
         if( nComp < 0 )
         {
             // decompression failed, must be an uncompressed stream after all
-            delete mpMemStream, mpMemStream = nullptr;
+            delete mpMemStream;
+            mpMemStream = nullptr;
             mpFileStream->Seek( 0 );
         }
         else
         {
             // compression successful, can get rid of file stream
-            delete mpFileStream, mpFileStream = nullptr;
+            delete mpFileStream;
+            mpFileStream = nullptr;
             mpMemStream->Seek( 0 );
         }
     }
@@ -344,8 +334,10 @@ void PPDDecompressStream::Open( const OUString& i_rFile )
 
 void PPDDecompressStream::Close()
 {
-    delete mpMemStream, mpMemStream = nullptr;
-    delete mpFileStream, mpFileStream = nullptr;
+    delete mpMemStream;
+    mpMemStream = nullptr;
+    delete mpFileStream;
+    mpFileStream = nullptr;
 }
 
 bool PPDDecompressStream::IsOpen() const
@@ -353,9 +345,9 @@ bool PPDDecompressStream::IsOpen() const
     return (mpMemStream || (mpFileStream && mpFileStream->IsOpen()));
 }
 
-bool PPDDecompressStream::IsEof() const
+bool PPDDecompressStream::eof() const
 {
-    return ( mpMemStream ? mpMemStream->IsEof() : ( mpFileStream == nullptr || mpFileStream->IsEof() ) );
+    return ( mpMemStream ? mpMemStream->eof() : ( mpFileStream == nullptr || mpFileStream->eof() ) );
 }
 
 OString PPDDecompressStream::ReadLine()
@@ -368,13 +360,13 @@ OString PPDDecompressStream::ReadLine()
     return o_rLine;
 }
 
-static osl::FileBase::RC resolveLink( const OUString& i_rURL, OUString& o_rResolvedURL, OUString& o_rBaseName, osl::FileStatus::Type& o_rType, int nLinkLevel = 10 )
+static osl::FileBase::RC resolveLink( const OUString& i_rURL, OUString& o_rResolvedURL, OUString& o_rBaseName, osl::FileStatus::Type& o_rType)
 {
     salhelper::LinkResolver aResolver(osl_FileStatus_Mask_FileName |
                                       osl_FileStatus_Mask_Type |
                                       osl_FileStatus_Mask_FileURL);
 
-    osl::FileBase::RC aRet = aResolver.fetchFileStatus(i_rURL, nLinkLevel);
+    osl::FileBase::RC aRet = aResolver.fetchFileStatus(i_rURL, 10/*nLinkLevel*/);
 
     if (aRet  == osl::FileBase::E_None)
     {
@@ -395,8 +387,6 @@ void PPDParser::scanPPDDir( const OUString& rDir )
     } const pSuffixes[] =
     { { ".PS", 3 },  { ".PPD", 4 }, { ".PS.GZ", 6 }, { ".PPD.GZ", 7 } };
 
-    const int nSuffixes = SAL_N_ELEMENTS(pSuffixes);
-
     PPDCache &rPPDCache = thePPDCache::get();
 
     osl::Directory aDir( rDir );
@@ -422,13 +412,13 @@ void PPDParser::scanPPDDir( const OUString& rDir )
                         aPPDFile.Append( aFileName );
 
                         // match extension
-                        for( int nSuffix = 0; nSuffix < nSuffixes; nSuffix++ )
+                        for(const suffix_t & rSuffix : pSuffixes)
                         {
-                            if( aFileName.getLength() > pSuffixes[nSuffix].nSuffixLen )
+                            if( aFileName.getLength() > rSuffix.nSuffixLen )
                             {
-                                if( aFileName.endsWithIgnoreAsciiCaseAsciiL( pSuffixes[nSuffix].pSuffix, pSuffixes[nSuffix].nSuffixLen ) )
+                                if( aFileName.endsWithIgnoreAsciiCaseAsciiL( rSuffix.pSuffix, rSuffix.nSuffixLen ) )
                                 {
-                                (*rPPDCache.pAllPPDFiles)[ aFileName.copy( 0, aFileName.getLength() - pSuffixes[nSuffix].nSuffixLen ) ] = aPPDFile.PathToFileName();
+                                (*rPPDCache.pAllPPDFiles)[ aFileName.copy( 0, aFileName.getLength() - rSuffix.nSuffixLen ) ] = aPPDFile.PathToFileName();
                                     break;
                                 }
                             }
@@ -450,15 +440,15 @@ void PPDParser::initPPDFiles(PPDCache &rPPDCache)
     if( rPPDCache.pAllPPDFiles )
         return;
 
-    rPPDCache.pAllPPDFiles = new std::unordered_map< OUString, OUString, OUStringHash >();
+    rPPDCache.pAllPPDFiles.reset(new std::unordered_map< OUString, OUString >);
 
     // check installation directories
-    std::list< OUString > aPathList;
+    std::vector< OUString > aPathList;
     psp::getPrinterPathList( aPathList, PRINTER_PPDDIR );
-    for( std::list< OUString >::const_iterator ppd_it = aPathList.begin(); ppd_it != aPathList.end(); ++ppd_it )
+    for( std::vector< OUString >::const_iterator ppd_it = aPathList.begin(); ppd_it != aPathList.end(); ++ppd_it )
     {
-        INetURLObject aPPDDir( *ppd_it, INetProtocol::File, INetURLObject::ENCODE_ALL );
-        scanPPDDir( aPPDDir.GetMainURL( INetURLObject::NO_DECODE ) );
+        INetURLObject aPPDDir( *ppd_it, INetProtocol::File, INetURLObject::EncodeMechanism::All );
+        scanPPDDir( aPPDDir.GetMainURL( INetURLObject::DecodeMechanism::NONE ) );
     }
     if( rPPDCache.pAllPPDFiles->find( OUString( "SGENPRT" ) ) == rPPDCache.pAllPPDFiles->end() )
     {
@@ -469,8 +459,8 @@ void PPDParser::initPPDFiles(PPDCache &rPPDCache)
             INetURLObject aDir( aExe );
             aDir.removeSegment();
             SAL_INFO("vcl.unx.print", "scanning last chance dir: "
-                    << aDir.GetMainURL(INetURLObject::NO_DECODE));
-            scanPPDDir( aDir.GetMainURL( INetURLObject::NO_DECODE ) );
+                    << aDir.GetMainURL(INetURLObject::DecodeMechanism::NONE));
+            scanPPDDir( aDir.GetMainURL( INetURLObject::DecodeMechanism::NONE ) );
             SAL_INFO("vcl.unx.print", "SGENPRT "
                     << (rPPDCache.pAllPPDFiles->find("SGENPRT") ==
                         rPPDCache.pAllPPDFiles->end() ? "not found" : "found"));
@@ -480,12 +470,12 @@ void PPDParser::initPPDFiles(PPDCache &rPPDCache)
 
 OUString PPDParser::getPPDFile( const OUString& rFile )
 {
-    INetURLObject aPPD( rFile, INetProtocol::File, INetURLObject::ENCODE_ALL );
+    INetURLObject aPPD( rFile, INetProtocol::File, INetURLObject::EncodeMechanism::All );
     // someone might enter a full qualified name here
     PPDDecompressStream aStream( aPPD.PathToFileName() );
     if( ! aStream.IsOpen() )
     {
-        std::unordered_map< OUString, OUString, OUStringHash >::const_iterator it;
+        std::unordered_map< OUString, OUString >::const_iterator it;
         PPDCache &rPPDCache = thePPDCache::get();
 
         bool bRetry = true;
@@ -509,7 +499,7 @@ OUString PPDParser::getPPDFile( const OUString& rFile )
             if( it == rPPDCache.pAllPPDFiles->end() && bRetry )
             {
                 // a new file ? rehash
-                delete rPPDCache.pAllPPDFiles; rPPDCache.pAllPPDFiles = nullptr;
+                rPPDCache.pAllPPDFiles.reset();
                 bRetry = false;
                 // note this is optimized for office start where
                 // no new files occur and initPPDFiles is called only once
@@ -547,7 +537,7 @@ const PPDParser* PPDParser::getParser( const OUString& rFile )
     ::osl::Guard< ::osl::Mutex > aGuard( aMutex );
 
     OUString aFile = rFile;
-    if( !rFile.startsWith( "CUPS:" ) )
+    if( !rFile.startsWith( "CUPS:" ) && !rFile.startsWith( "CPD:" ) )
         aFile = getPPDFile( rFile );
     if( aFile.isEmpty() )
     {
@@ -555,39 +545,169 @@ const PPDParser* PPDParser::getParser( const OUString& rFile )
                 << rFile << "\" !");
         return nullptr;
     }
+    else
+        SAL_INFO("vcl.unx.print", "Parsing printer info from \""
+                 << rFile << "\" !");
+
 
     PPDCache &rPPDCache = thePPDCache::get();
-    for( ::std::list< PPDParser* >::const_iterator it = rPPDCache.aAllParsers.begin(); it != rPPDCache.aAllParsers.end(); ++it )
-        if( (*it)->m_aFile == aFile )
-            return *it;
+    for( auto const & i : rPPDCache.aAllParsers )
+        if( i->m_aFile == aFile )
+            return i.get();
 
     PPDParser* pNewParser = nullptr;
-    if( !aFile.startsWith( "CUPS:" ) )
+    if( !aFile.startsWith( "CUPS:" ) && !aFile.startsWith( "CPD:" ) )
         pNewParser = new PPDParser( aFile );
     else
     {
         PrinterInfoManager& rMgr = PrinterInfoManager::get();
-        if( rMgr.getType() == PrinterInfoManager::CUPS )
+        if( rMgr.getType() == PrinterInfoManager::Type::CUPS )
         {
 #ifdef ENABLE_CUPS
             pNewParser = const_cast<PPDParser*>(static_cast<CUPSManager&>(rMgr).createCUPSParser( aFile ));
+#endif
+        } else if ( rMgr.getType() == PrinterInfoManager::Type::CPD )
+        {
+#if ENABLE_DBUS && ENABLE_GIO
+            pNewParser = const_cast<PPDParser*>(static_cast<CPDManager&>(rMgr).createCPDParser( aFile ));
 #endif
         }
     }
     if( pNewParser )
     {
         // this may actually be the SGENPRT parser,
-        // so ensure uniquness here
-        rPPDCache.aAllParsers.remove( pNewParser );
-        // insert new parser to list
-        rPPDCache.aAllParsers.push_front( pNewParser );
+        // so ensure uniqueness here (but don't remove lest we delete us!)
+        if (std::find_if(
+                    rPPDCache.aAllParsers.begin(),
+                    rPPDCache.aAllParsers.end(),
+                    [pNewParser] (std::unique_ptr<PPDParser> const & x) { return x.get() == pNewParser; } ) == rPPDCache.aAllParsers.end())
+        {
+            // insert new parser to vector
+            rPPDCache.aAllParsers.emplace_back(pNewParser);
+        }
     }
     return pNewParser;
 }
 
+PPDParser::PPDParser( const OUString& rFile, std::vector<PPDKey*> keys) :
+    m_aFile( rFile ),
+    m_bColorDevice( false ),
+    m_bType42Capable( false ),
+    m_nLanguageLevel( 0 ),
+    m_aFileEncoding( RTL_TEXTENCODING_MS_1252 ),
+    m_pDefaultImageableArea( nullptr ),
+    m_pImageableAreas( nullptr ),
+    m_pDefaultPaperDimension( nullptr ),
+    m_pPaperDimensions( nullptr ),
+    m_pDefaultInputSlot( nullptr ),
+    m_pInputSlots( nullptr ),
+    m_pDefaultResolution( nullptr ),
+    m_pResolutions( nullptr ),
+    m_pFontList( nullptr ),
+    m_pTranslator( new PPDTranslator() )
+{
+    for (PPDKey* key: keys)
+    {
+        insertKey( key -> getKey(), key );
+    }
+
+    // fill in shortcuts
+    const PPDKey* pKey;
+
+    pKey = getKey( OUString( "PageSize" ) );
+
+    if ( pKey ) {
+        PPDKey* pImageableAreas = new PPDKey("ImageableArea");
+        PPDKey* pPaperDimensions = new PPDKey("PaperDimension");
+#if defined(CUPS_VERSION_MAJOR)
+#if (CUPS_VERSION_MAJOR == 1 && CUPS_VERSION_MINOR >= 7) || CUPS_VERSION_MAJOR > 1
+        for (int i = 0; i < pKey->countValues(); i++) {
+            const PPDValue* pValue = pKey -> getValue(i);
+            OUString aValueName = pValue -> m_aOption;
+            PPDValue* pImageableAreaValue = pImageableAreas -> insertValue( aValueName, eQuoted );
+            PPDValue* pPaperDimensionValue = pPaperDimensions -> insertValue( aValueName, eQuoted );
+            rtl_TextEncoding aEncoding = osl_getThreadTextEncoding();
+            OString o = OUStringToOString( aValueName, aEncoding );
+            pwg_media_t *pPWGMedia = pwgMediaForPWG(o.pData->buffer);
+            if (pPWGMedia != nullptr) {
+                OUStringBuffer aBuf( 256 );
+                aBuf.append( "0 0 " );
+                aBuf.append( PWG_TO_POINTS(pPWGMedia -> width) );
+                aBuf.append( " " );
+                aBuf.append( PWG_TO_POINTS(pPWGMedia -> length) );
+                if ( pImageableAreaValue )
+                    pImageableAreaValue->m_aValue = aBuf.makeStringAndClear();
+                aBuf.append( PWG_TO_POINTS(pPWGMedia -> width) );
+                aBuf.append( " " );
+                aBuf.append( PWG_TO_POINTS(pPWGMedia -> length) );
+                if ( pPaperDimensionValue )
+                    pPaperDimensionValue->m_aValue = aBuf.makeStringAndClear();
+                if (aValueName.equals(pKey -> getDefaultValue() -> m_aOption)) {
+                    pImageableAreas -> m_pDefaultValue = pImageableAreaValue;
+                    pPaperDimensions -> m_pDefaultValue = pPaperDimensionValue;
+                }
+            }
+        }
+#endif // HAVE_CUPS_API_1_7
+#endif
+        insertKey("ImageableArea", pImageableAreas);
+        insertKey("PaperDimension", pPaperDimensions);
+    }
+
+    m_pImageableAreas = getKey(  OUString( "ImageableArea" ) );
+    if( m_pImageableAreas )
+        m_pDefaultImageableArea = m_pImageableAreas->getDefaultValue();
+    if (m_pImageableAreas == nullptr) {
+        SAL_WARN( "vcl.unx.print", "no ImageableArea in " << m_aFile);
+    }
+    if (m_pDefaultImageableArea == nullptr) {
+        SAL_WARN( "vcl.unx.print", "no DefaultImageableArea in " << m_aFile);
+    }
+
+    m_pPaperDimensions = getKey( OUString( "PaperDimension" ) );
+    if( m_pPaperDimensions )
+        m_pDefaultPaperDimension = m_pPaperDimensions->getDefaultValue();
+    if (m_pPaperDimensions == nullptr) {
+        SAL_WARN( "vcl.unx.print", "no PaperDimensions in " << m_aFile);
+    }
+    if (m_pDefaultPaperDimension == nullptr) {
+        SAL_WARN( "vcl.unx.print", "no DefaultPaperDimensions in " << m_aFile);
+    }
+
+    m_pResolutions = getKey( OUString( "Resolution" ) );
+    if( m_pResolutions )
+        m_pDefaultResolution = m_pResolutions->getDefaultValue();
+    if (m_pResolutions == nullptr) {
+        SAL_WARN( "vcl.unx.print", "no Resolution in " << m_aFile);
+    }
+    SAL_INFO_IF(!m_pDefaultResolution, "vcl.unx.print", "no DefaultResolution in " + m_aFile);
+
+    m_pInputSlots = getKey( OUString( "InputSlot" ) );
+    if( m_pInputSlots )
+        m_pDefaultInputSlot = m_pInputSlots->getDefaultValue();
+    SAL_INFO_IF(!m_pInputSlots, "vcl.unx.print", "no InputSlot in " << m_aFile);
+    SAL_INFO_IF(!m_pDefaultInputSlot, "vcl.unx.print", "no DefaultInputSlot in " << m_aFile);
+
+    m_pFontList = getKey( OUString( "Font" ) );
+    if (m_pFontList == nullptr) {
+        SAL_WARN( "vcl.unx.print", "no Font in " << m_aFile);
+    }
+
+    // fill in direct values
+    if( (pKey = getKey( OUString( "ModelName" ) )) )
+        m_aPrinterName = pKey->getValue( 0 )->m_aValue;
+    if( (pKey = getKey( OUString( "NickName" ) )) )
+        m_aNickName = pKey->getValue( 0 )->m_aValue;
+    if( (pKey = getKey( OUString( "print-color-mode" ) )) )
+        m_bColorDevice = pKey->countValues() > 1;
+
+}
+
 PPDParser::PPDParser( const OUString& rFile ) :
         m_aFile( rFile ),
+        m_bColorDevice( false ),
         m_bType42Capable( false ),
+        m_nLanguageLevel( 0 ),
         m_aFileEncoding( RTL_TEXTENCODING_MS_1252 ),
         m_pDefaultImageableArea( nullptr ),
         m_pImageableAreas( nullptr ),
@@ -597,18 +717,16 @@ PPDParser::PPDParser( const OUString& rFile ) :
         m_pInputSlots( nullptr ),
         m_pDefaultResolution( nullptr ),
         m_pResolutions( nullptr ),
-        m_pDefaultDuplexType( nullptr ),
-        m_pDuplexTypes( nullptr ),
         m_pFontList( nullptr ),
         m_pTranslator( new PPDTranslator() )
 {
     // read in the file
-    std::list< OString > aLines;
+    std::vector< OString > aLines;
     PPDDecompressStream aStream( m_aFile );
     if( aStream.IsOpen() )
     {
         bool bLanguageEncoding = false;
-        while( ! aStream.IsEof() )
+        while( ! aStream.eof() )
         {
             OString aCurLine = aStream.ReadLine();
             if( aCurLine.startsWith("*") )
@@ -664,12 +782,12 @@ PPDParser::PPDParser( const OUString& rFile ) :
         char const* pSetupType = "<unknown>";
         switch( pKey->m_eSetupType )
         {
-            case PPDKey::ExitServer:        pSetupType = "ExitServer";break;
-            case PPDKey::Prolog:            pSetupType = "Prolog";break;
-            case PPDKey::DocumentSetup: pSetupType = "DocumentSetup";break;
-            case PPDKey::PageSetup:     pSetupType = "PageSetup";break;
-            case PPDKey::JCLSetup:          pSetupType = "JCLSetup";break;
-            case PPDKey::AnySetup:          pSetupType = "AnySetup";break;
+            case PPDKey::SetupType::ExitServer:        pSetupType = "ExitServer";break;
+            case PPDKey::SetupType::Prolog:            pSetupType = "Prolog";break;
+            case PPDKey::SetupType::DocumentSetup:     pSetupType = "DocumentSetup";break;
+            case PPDKey::SetupType::PageSetup:         pSetupType = "PageSetup";break;
+            case PPDKey::SetupType::JCLSetup:          pSetupType = "JCLSetup";break;
+            case PPDKey::SetupType::AnySetup:          pSetupType = "AnySetup";break;
             default: break;
         };
         SAL_INFO("vcl.unx.print", "\t\"" << pKey->getKey() << "\" ("
@@ -697,7 +815,7 @@ PPDParser::PPDParser( const OUString& rFile ) :
     }
     SAL_INFO("vcl.unx.print",
             "constraints: (" << m_aConstraints.size() << " found)");
-    for( std::list< PPDConstraint >::const_iterator cit = m_aConstraints.begin(); cit != m_aConstraints.end(); ++cit )
+    for( std::vector< PPDConstraint >::const_iterator cit = m_aConstraints.begin(); cit != m_aConstraints.end(); ++cit )
     {
         SAL_INFO("vcl.unx.print", "*\"" << cit->m_pKey1->getKey() << "\" \""
                 << (cit->m_pOption1 ? cit->m_pOption1->m_aOption : "<nil>")
@@ -714,67 +832,39 @@ PPDParser::PPDParser( const OUString& rFile ) :
     if( m_pImageableAreas )
         m_pDefaultImageableArea = m_pImageableAreas->getDefaultValue();
     if (m_pImageableAreas == nullptr) {
-        OSL_TRACE(
-            "Warning: no ImageableArea in %s\n",
-            OUStringToOString(m_aFile, RTL_TEXTENCODING_UTF8).getStr());
+        SAL_WARN( "vcl.unx.print", "no ImageableArea in " << m_aFile);
     }
     if (m_pDefaultImageableArea == nullptr) {
-        OSL_TRACE(
-            "Warning: no DefaultImageableArea in %s\n",
-            OUStringToOString(m_aFile, RTL_TEXTENCODING_UTF8).getStr());
+        SAL_WARN( "vcl.unx.print", "no DefaultImageableArea in " << m_aFile);
     }
 
     m_pPaperDimensions = getKey( OUString( "PaperDimension" ) );
     if( m_pPaperDimensions )
         m_pDefaultPaperDimension = m_pPaperDimensions->getDefaultValue();
     if (m_pPaperDimensions == nullptr) {
-        OSL_TRACE(
-            "Warning: no PaperDimensions in %s\n",
-            OUStringToOString(m_aFile, RTL_TEXTENCODING_UTF8).getStr());
+        SAL_WARN( "vcl.unx.print", "no PaperDimensions in " << m_aFile);
     }
     if (m_pDefaultPaperDimension == nullptr) {
-        OSL_TRACE(
-            "Warning: no DefaultPaperDimensions in %s\n",
-            OUStringToOString(m_aFile, RTL_TEXTENCODING_UTF8).getStr());
+        SAL_WARN( "vcl.unx.print", "no DefaultPaperDimensions in " << m_aFile);
     }
 
     m_pResolutions = getKey( OUString( "Resolution" ) );
     if( m_pResolutions )
         m_pDefaultResolution = m_pResolutions->getDefaultValue();
     if (m_pResolutions == nullptr) {
-        OSL_TRACE(
-            "Warning: no Resolution in %s\n",
-            OUStringToOString(m_aFile, RTL_TEXTENCODING_UTF8).getStr());
-    }
-    if (m_pDefaultResolution == nullptr) {
-        OSL_TRACE(
-            "Warning: no DefaultResolution in %s\n",
-            OUStringToOString(m_aFile, RTL_TEXTENCODING_UTF8).getStr());
+        SAL_WARN( "vcl.unx.print", "no Resolution in " << m_aFile);
     }
+    SAL_INFO_IF(!m_pDefaultResolution, "vcl.unx.print", "no DefaultResolution in " + m_aFile);
 
     m_pInputSlots = getKey( OUString( "InputSlot" ) );
     if( m_pInputSlots )
         m_pDefaultInputSlot = m_pInputSlots->getDefaultValue();
-    if (m_pInputSlots == nullptr) {
-        OSL_TRACE(
-            "Warning: no InputSlot in %s\n",
-            OUStringToOString(m_aFile, RTL_TEXTENCODING_UTF8).getStr());
-    }
-    if (m_pDefaultInputSlot == nullptr) {
-        OSL_TRACE(
-            "Warning: no DefaultInputSlot in %s\n",
-            OUStringToOString(m_aFile, RTL_TEXTENCODING_UTF8).getStr());
-    }
-
-    m_pDuplexTypes = getKey( OUString( "Duplex" ) );
-    if( m_pDuplexTypes )
-        m_pDefaultDuplexType = m_pDuplexTypes->getDefaultValue();
+    SAL_INFO_IF(!m_pInputSlots, "vcl.unx.print", "no InputSlot in " << m_aFile);
+    SAL_INFO_IF(!m_pDefaultInputSlot, "vcl.unx.print", "no DefaultInputSlot in " << m_aFile);
 
     m_pFontList = getKey( OUString( "Font" ) );
     if (m_pFontList == nullptr) {
-        OSL_TRACE(
-            "Warning: no Font in %s\n",
-            OUStringToOString(m_aFile, RTL_TEXTENCODING_UTF8).getStr());
+        SAL_WARN( "vcl.unx.print", "no Font in " << m_aFile);
     }
 
     // fill in direct values
@@ -872,7 +962,7 @@ namespace
     }
 }
 
-void PPDParser::parse( ::std::list< OString >& rLines )
+void PPDParser::parse( ::std::vector< OString >& rLines )
 {
     // Name for PPD group into which all options are put for which the PPD
     // does not explicitly define a group.
@@ -884,7 +974,7 @@ void PPDParser::parse( ::std::list< OString >& rLines )
     // "Extra" group depending on the option.
     static const OString aDefaultPPDGroupName("General");
 
-    std::list< OString >::iterator line = rLines.begin();
+    std::vector< OString >::iterator line = rLines.begin();
     PPDParser::hash_type::const_iterator keyit;
 
     // name of the PPD group that is currently being processed
@@ -894,6 +984,9 @@ void PPDParser::parse( ::std::list< OString >& rLines )
     {
         OString aCurrentLine( *line );
         ++line;
+
+        SAL_INFO("vcl.unx.print", "Parse line '" << aCurrentLine << "'");
+
         if (aCurrentLine.getLength() < 2 || aCurrentLine[0] != '*')
             continue;
         if( aCurrentLine[1] == '%' )
@@ -1153,6 +1246,7 @@ void PPDParser::parse( ::std::list< OString >& rLines )
         OString aLine(*line);
         if (aLine.startsWith("*Default"))
         {
+            SAL_INFO("vcl.unx.print", "Found a default: '" << aLine << "'");
             OUString aKey(OStringToOUString(aLine.copy(8), RTL_TEXTENCODING_MS_1252));
             sal_Int32 nPos = aKey.indexOf( ':' );
             if( nPos != -1 )
@@ -1177,6 +1271,7 @@ void PPDParser::parse( ::std::list< OString >& rLines )
                     // so invent that key here and have a default value
                     PPDKey* pKey = new PPDKey( aKey );
                     pKey->insertValue( aOption, eInvocation /*or what ?*/ );
+                    pKey->m_pDefaultValue = pKey->getValue( aOption );
                     insertKey( aKey, pKey );
                 }
             }
@@ -1220,15 +1315,6 @@ void PPDParser::parseOpenUI(const OString& rLine, const OString& rPPDGroup)
     pKey->m_bUIOption = true;
     m_pTranslator->insertKey( pKey->getKey(), aTranslation );
 
-    sal_Int32 nIndex = 0;
-    OString aValue = WhitespaceToSpace( rLine.getToken( 1, ':', nIndex ) );
-    if( aValue.equalsIgnoreAsciiCase("boolean"))
-        pKey->m_eUIType = PPDKey::Boolean;
-    else if (aValue.equalsIgnoreAsciiCase("pickmany"))
-        pKey->m_eUIType = PPDKey::PickMany;
-    else
-        pKey->m_eUIType = PPDKey::PickOne;
-
     pKey->m_aGroup = OStringToOUString(rPPDGroup, RTL_TEXTENCODING_MS_1252);
 }
 
@@ -1243,7 +1329,7 @@ void PPDParser::parseOrderDependency(const OString& rLine)
     OString aSetup = GetCommandLineToken( 1, aLine );
     OUString aKey(OStringToOUString(GetCommandLineToken(2, aLine), RTL_TEXTENCODING_MS_1252));
     if( aKey[ 0 ] != '*' )
-        return; // invalid order dependecy
+        return; // invalid order dependency
     aKey = aKey.replaceAt( 0, 1, "" );
 
     PPDKey* pKey;
@@ -1258,17 +1344,17 @@ void PPDParser::parseOrderDependency(const OString& rLine)
 
     pKey->m_nOrderDependency = nOrder;
     if( aSetup == "ExitServer" )
-        pKey->m_eSetupType = PPDKey::ExitServer;
+        pKey->m_eSetupType = PPDKey::SetupType::ExitServer;
     else if( aSetup == "Prolog" )
-        pKey->m_eSetupType = PPDKey::Prolog;
+        pKey->m_eSetupType = PPDKey::SetupType::Prolog;
     else if( aSetup == "DocumentSetup" )
-        pKey->m_eSetupType = PPDKey::DocumentSetup;
+        pKey->m_eSetupType = PPDKey::SetupType::DocumentSetup;
     else if( aSetup == "PageSetup" )
-        pKey->m_eSetupType = PPDKey::PageSetup;
+        pKey->m_eSetupType = PPDKey::SetupType::PageSetup;
     else if( aSetup == "JCLSetup" )
-        pKey->m_eSetupType = PPDKey::JCLSetup;
+        pKey->m_eSetupType = PPDKey::SetupType::JCLSetup;
     else
-        pKey->m_eSetupType = PPDKey::AnySetup;
+        pKey->m_eSetupType = PPDKey::SetupType::AnySetup;
 }
 
 void PPDParser::parseConstraint( const OString& rLine )
@@ -1473,20 +1559,18 @@ void PPDParser::getDefaultResolution( int& rXRes, int& rYRes ) const
     rYRes = 300;
 }
 
-OUString PPDParser::translateKey( const OUString& i_rKey,
-                                       const css::lang::Locale& i_rLocale ) const
+OUString PPDParser::translateKey( const OUString& i_rKey ) const
 {
-    OUString aResult( m_pTranslator->translateKey( i_rKey, i_rLocale ) );
+    OUString aResult( m_pTranslator->translateKey( i_rKey ) );
     if( aResult.isEmpty() )
         aResult = i_rKey;
     return aResult;
 }
 
 OUString PPDParser::translateOption( const OUString& i_rKey,
-                                          const OUString& i_rOption,
-                                          const css::lang::Locale& i_rLocale ) const
+                                          const OUString& i_rOption ) const
 {
-    OUString aResult( m_pTranslator->translateOption( i_rKey, i_rOption, i_rLocale ) );
+    OUString aResult( m_pTranslator->translateOption( i_rKey, i_rOption ) );
     if( aResult.isEmpty() )
         aResult = i_rOption;
     return aResult;
@@ -1501,9 +1585,8 @@ PPDKey::PPDKey( const OUString& rKey ) :
         m_pDefaultValue( nullptr ),
         m_bQueryValue( false ),
         m_bUIOption( false ),
-        m_eUIType( PickOne ),
         m_nOrderDependency( 100 ),
-        m_eSetupType( AnySetup )
+        m_eSetupType( SetupType::AnySetup )
 {
 }
 
@@ -1571,8 +1654,8 @@ PPDValue* PPDKey::insertValue(const OUString& rOption, PPDValueType eType, bool
  * PPDContext
  */
 
-PPDContext::PPDContext( const PPDParser* pParser ) :
-        m_pParser( pParser )
+PPDContext::PPDContext() :
+        m_pParser( nullptr )
 {
 }
 
@@ -1583,8 +1666,11 @@ PPDContext& PPDContext::operator=( const PPDContext& rCopy )
     return *this;
 }
 
-PPDContext::~PPDContext()
+PPDContext& PPDContext::operator=( PPDContext&& rCopy )
 {
+    std::swap(m_pParser, rCopy.m_pParser);
+    std::swap(m_aCurrentValues, rCopy.m_aCurrentValues);
+    return *this;
 }
 
 const PPDKey* PPDContext::getModifiedKey( int n ) const
@@ -1728,8 +1814,8 @@ bool PPDContext::checkConstraints( const PPDKey* pKey, const PPDValue* pNewValue
         pNewValue == pKey->getDefaultValue() )
         return true;
 
-    const ::std::list< PPDParser::PPDConstraint >& rConstraints( m_pParser->getConstraints() );
-    for( ::std::list< PPDParser::PPDConstraint >::const_iterator it = rConstraints.begin(); it != rConstraints.end(); ++it )
+    const ::std::vector< PPDParser::PPDConstraint >& rConstraints( m_pParser->getConstraints() );
+    for( ::std::vector< PPDParser::PPDConstraint >::const_iterator it = rConstraints.begin(); it != rConstraints.end(); ++it )
     {
         const PPDKey* pLeft     = it->m_pKey1;
         const PPDKey* pRight    = it->m_pKey2;
