@@ -25,6 +25,7 @@
 #include <svsys.h>
 
 #include <osl/module.h>
+#include <o3tl/char16_t2wchar_t.hxx>
 
 #include <tools/urlobj.hxx>
 
@@ -49,6 +50,14 @@
 
 #include <malloc.h>
 
+#include <winspool.h>
+#if defined GetDefaultPrinter
+#  undef GetDefaultPrinter
+#endif
+#if defined SetPrinterData
+#  undef SetPrinterData
+#endif
+
 #define CATCH_DRIVER_EX_BEGIN                                               \
     __try                                                                   \
     {
@@ -71,8 +80,8 @@ using namespace com::sun::star::uno;
 using namespace com::sun::star::lang;
 using namespace com::sun::star::ui::dialogs;
 
-static char aImplWindows[] = "windows";
-static char aImplDevice[]  = "device";
+static const wchar_t aImplWindows[] = L"windows";
+static const wchar_t aImplDevice[]  = L"device";
 
 static DEVMODEW const * SAL_DEVMODE_W( const ImplJobSetup* pSetupData )
 {
@@ -154,7 +163,7 @@ void WinSalInstance::GetPrinterQueueInfo( ImplPrnQueueList* pList )
             for ( i = 0; i < nInfoPrn4; i++ )
             {
                 SalPrinterQueueInfo* pInfo = new SalPrinterQueueInfo;
-                pInfo->maPrinterName = OUString( reinterpret_cast< const sal_Unicode* >(pWinInfo4[i].pPrinterName) );
+                pInfo->maPrinterName = o3tl::toU(pWinInfo4[i].pPrinterName);
                 pInfo->mnStatus      = PrintQueueFlags::NONE;
                 pInfo->mnJobs        = 0;
                 pInfo->mpSysData     = nullptr;
@@ -168,7 +177,7 @@ void WinSalInstance::GetPrinterQueueInfo( ImplPrnQueueList* pList )
 void WinSalInstance::GetPrinterQueueState( SalPrinterQueueInfo* pInfo )
 {
     HANDLE hPrinter = nullptr;
-    LPWSTR pPrnName = reinterpret_cast<LPWSTR>(const_cast<sal_Unicode*>(pInfo->maPrinterName.getStr()));
+    LPWSTR pPrnName = const_cast<LPWSTR>(o3tl::toW(pInfo->maPrinterName.getStr()));
     if( OpenPrinterW( pPrnName, &hPrinter, nullptr ) )
     {
         DWORD               nBytes = 0;
@@ -179,18 +188,18 @@ void WinSalInstance::GetPrinterQueueState( SalPrinterQueueInfo* pInfo )
             if( GetPrinterW( hPrinter, 2, reinterpret_cast<LPBYTE>(pWinInfo2), nBytes, &nBytes ) )
             {
                 if( pWinInfo2->pDriverName )
-                    pInfo->maDriver = OUString( reinterpret_cast< const sal_Unicode* >(pWinInfo2->pDriverName) );
+                    pInfo->maDriver = o3tl::toU(pWinInfo2->pDriverName);
                 OUString aPortName;
                 if ( pWinInfo2->pPortName )
-                    aPortName = OUString( reinterpret_cast< const sal_Unicode* >(pWinInfo2->pPortName) );
+                    aPortName = o3tl::toU(pWinInfo2->pPortName);
                 // pLocation can be 0 (the Windows docu doesn't describe this)
                 if ( pWinInfo2->pLocation && *pWinInfo2->pLocation )
-                    pInfo->maLocation = OUString( reinterpret_cast< const sal_Unicode* >(pWinInfo2->pLocation) );
+                    pInfo->maLocation = o3tl::toU(pWinInfo2->pLocation);
                 else
                     pInfo->maLocation = aPortName;
                 // pComment can be 0 (the Windows docu doesn't describe this)
                 if ( pWinInfo2->pComment )
-                    pInfo->maComment = OUString( reinterpret_cast< const sal_Unicode* >(pWinInfo2->pComment) );
+                    pInfo->maComment = o3tl::toU(pWinInfo2->pComment);
                 pInfo->mnStatus      = ImplWinQueueStatusToSal( pWinInfo2->Status );
                 pInfo->mnJobs        = pWinInfo2->cJobs;
                 if( ! pInfo->mpSysData )
@@ -218,7 +227,7 @@ OUString WinSalInstance::GetDefaultPrinter()
         OUString aDefPrt;
         if( GetDefaultPrinterW( pStr, &nChars ) )
         {
-            aDefPrt = OUString(reinterpret_cast<sal_Unicode* >(pStr));
+            aDefPrt = o3tl::toU(pStr);
         }
         rtl_freeMemory( pStr );
         if( !aDefPrt.isEmpty() )
@@ -226,22 +235,22 @@ OUString WinSalInstance::GetDefaultPrinter()
     }
 
     // get default printer from win.ini
-    char szBuffer[256];
-    GetProfileStringA( aImplWindows, aImplDevice, "", szBuffer, sizeof( szBuffer ) );
+    wchar_t szBuffer[256];
+    GetProfileStringW( aImplWindows, aImplDevice, L"", szBuffer, SAL_N_ELEMENTS( szBuffer ) );
     if ( szBuffer[0] )
     {
         // search for printer name
-        char* pBuf = szBuffer;
-        char* pTmp = pBuf;
+        wchar_t* pBuf = szBuffer;
+        wchar_t* pTmp = pBuf;
         while ( *pTmp && (*pTmp != ',') )
             pTmp++;
-        return ImplSalGetUniString( pBuf, static_cast<sal_Int32>(pTmp-pBuf) );
+        return OUString( o3tl::toU(pBuf), static_cast<sal_Int32>(pTmp-pBuf) );
     }
     else
         return OUString();
 }
 
-static DWORD ImplDeviceCaps( WinSalInfoPrinter* pPrinter, WORD nCaps,
+static DWORD ImplDeviceCaps( WinSalInfoPrinter const * pPrinter, WORD nCaps,
                              BYTE* pOutput, const ImplJobSetup* pSetupData )
 {
     DEVMODEW const * pDevMode;
@@ -250,12 +259,12 @@ static DWORD ImplDeviceCaps( WinSalInfoPrinter* pPrinter, WORD nCaps,
     else
         pDevMode = SAL_DEVMODE_W( pSetupData );
 
-    return DeviceCapabilitiesW( reinterpret_cast<LPCWSTR>(pPrinter->maDeviceName.getStr()),
-                                reinterpret_cast<LPCWSTR>(pPrinter->maPortName.getStr()),
+    return DeviceCapabilitiesW( o3tl::toW(pPrinter->maDeviceName.getStr()),
+                                o3tl::toW(pPrinter->maPortName.getStr()),
                                 nCaps, reinterpret_cast<LPWSTR>(pOutput), pDevMode );
 }
 
-static bool ImplTestSalJobSetup( WinSalInfoPrinter* pPrinter,
+static bool ImplTestSalJobSetup( WinSalInfoPrinter const * pPrinter,
                                  ImplJobSetup* pSetupData, bool bDelete )
 {
     if ( pSetupData && pSetupData->GetDriverData() )
@@ -280,7 +289,7 @@ static bool ImplTestSalJobSetup( WinSalInfoPrinter* pPrinter,
             // can avoid potential driver crashes as their jobsetups are often not compatible
             // #110800#, #111151#, #112381#, #i16580#, #i14173# and perhaps #112375#
             HANDLE hPrn;
-            LPWSTR pPrinterNameW = reinterpret_cast<LPWSTR>(const_cast<sal_Unicode*>(pPrinter->maDeviceName.getStr()));
+            LPWSTR pPrinterNameW = const_cast<LPWSTR>(o3tl::toW(pPrinter->maDeviceName.getStr()));
             if ( !OpenPrinterW( pPrinterNameW, &hPrn, nullptr ) )
                 return FALSE;
 
@@ -338,11 +347,11 @@ static bool ImplTestSalJobSetup( WinSalInfoPrinter* pPrinter,
     return FALSE;
 }
 
-static bool ImplUpdateSalJobSetup( WinSalInfoPrinter* pPrinter, ImplJobSetup* pSetupData,
+static bool ImplUpdateSalJobSetup( WinSalInfoPrinter const * pPrinter, ImplJobSetup* pSetupData,
                                    bool bIn, WinSalFrame* pVisibleDlgParent )
 {
     HANDLE hPrn;
-    LPWSTR pPrinterNameW = reinterpret_cast<LPWSTR>(const_cast<sal_Unicode*>(pPrinter->maDeviceName.getStr()));
+    LPWSTR pPrinterNameW = const_cast<LPWSTR>(o3tl::toW(pPrinter->maDeviceName.getStr()));
     if ( !OpenPrinterW( pPrinterNameW, &hPrn, nullptr ) )
         return FALSE;
     // #131642# hPrn==HGDI_ERROR even though OpenPrinter() succeeded!
@@ -388,16 +397,17 @@ static bool ImplUpdateSalJobSetup( WinSalInfoPrinter* pPrinter, ImplJobSetup* pS
     }
 
     // Release mutex, in the other case we don't get paints and so on
-    sal_uLong nMutexCount=0;
-    if ( pVisibleDlgParent )
-        nMutexCount = ImplSalReleaseYieldMutex();
+    sal_uInt32 nMutexCount = 0;
+    WinSalInstance* pInst = GetSalData()->mpInstance;
+    if ( pInst && pVisibleDlgParent )
+        nMutexCount = pInst->ReleaseYieldMutexAll();
 
     BYTE* pOutDevMode = (reinterpret_cast<BYTE*>(pOutBuffer) + pOutBuffer->mnDriverOffset);
     nRet = DocumentPropertiesW( hWnd, hPrn,
                                 pPrinterNameW,
                                 reinterpret_cast<LPDEVMODEW>(pOutDevMode), reinterpret_cast<LPDEVMODEW>(const_cast<BYTE *>(pInBuffer)), nMode );
-    if ( pVisibleDlgParent )
-        ImplSalAcquireYieldMutex( nMutexCount );
+    if ( pInst && pVisibleDlgParent )
+        pInst->AcquireYieldMutex( nMutexCount );
     ClosePrinter( hPrn );
 
     if( (nRet < 0) || (pVisibleDlgParent && (nRet == IDCANCEL)) )
@@ -409,13 +419,13 @@ static bool ImplUpdateSalJobSetup( WinSalInfoPrinter* pPrinter, ImplJobSetup* pS
     // fill up string buffers with 0 so they do not influence a JobSetup's memcmp
     if( reinterpret_cast<LPDEVMODEW>(pOutDevMode)->dmSize >= 64 )
     {
-        sal_Int32 nLen = rtl_ustr_getLength( SAL_U(reinterpret_cast<LPDEVMODEW>(pOutDevMode)->dmDeviceName) );
+        sal_Int32 nLen = rtl_ustr_getLength( o3tl::toU(reinterpret_cast<LPDEVMODEW>(pOutDevMode)->dmDeviceName) );
         if ( sal::static_int_cast<size_t>(nLen) < SAL_N_ELEMENTS( reinterpret_cast<LPDEVMODEW>(pOutDevMode)->dmDeviceName ) )
             memset( reinterpret_cast<LPDEVMODEW>(pOutDevMode)->dmDeviceName+nLen, 0, sizeof( reinterpret_cast<LPDEVMODEW>(pOutDevMode)->dmDeviceName )-(nLen*sizeof(sal_Unicode)) );
     }
     if( reinterpret_cast<LPDEVMODEW>(pOutDevMode)->dmSize >= 166 )
     {
-        sal_Int32 nLen = rtl_ustr_getLength( SAL_U(reinterpret_cast<LPDEVMODEW>(pOutDevMode)->dmFormName) );
+        sal_Int32 nLen = rtl_ustr_getLength( o3tl::toU(reinterpret_cast<LPDEVMODEW>(pOutDevMode)->dmFormName) );
         if ( sal::static_int_cast<size_t>(nLen) < SAL_N_ELEMENTS( reinterpret_cast<LPDEVMODEW>(pOutDevMode)->dmFormName ) )
             memset( reinterpret_cast<LPDEVMODEW>(pOutDevMode)->dmFormName+nLen, 0, sizeof( reinterpret_cast<LPDEVMODEW>(pOutDevMode)->dmFormName )-(nLen*sizeof(sal_Unicode)) );
     }
@@ -430,7 +440,7 @@ static bool ImplUpdateSalJobSetup( WinSalInfoPrinter* pPrinter, ImplJobSetup* pS
     return TRUE;
 }
 
-static void ImplDevModeToJobSetup( WinSalInfoPrinter* pPrinter, ImplJobSetup* pSetupData, JobSetFlags nFlags )
+static void ImplDevModeToJobSetup( WinSalInfoPrinter const * pPrinter, ImplJobSetup* pSetupData, JobSetFlags nFlags )
 {
     if ( !pSetupData || !pSetupData->GetDriverData() )
         return;
@@ -685,7 +695,7 @@ static void ImplDevModeToJobSetup( WinSalInfoPrinter* pPrinter, ImplJobSetup* pS
     if( nFlags & JobSetFlags::DUPLEXMODE )
     {
         DuplexMode eDuplex = DuplexMode::Unknown;
-        if( (pDevModeW->dmFields & DM_DUPLEX) )
+        if( pDevModeW->dmFields & DM_DUPLEX )
         {
             if( pDevModeW->dmDuplex == DMDUP_SIMPLEX )
                 eDuplex = DuplexMode::Off;
@@ -698,7 +708,7 @@ static void ImplDevModeToJobSetup( WinSalInfoPrinter* pPrinter, ImplJobSetup* pS
     }
 }
 
-static void ImplJobSetupToDevMode( WinSalInfoPrinter* pPrinter, const ImplJobSetup* pSetupData, JobSetFlags nFlags )
+static void ImplJobSetupToDevMode( WinSalInfoPrinter const * pPrinter, const ImplJobSetup* pSetupData, JobSetFlags nFlags )
 {
     if ( !pSetupData || !pSetupData->GetDriverData() )
         return;
@@ -996,7 +1006,7 @@ static HDC ImplCreateICW_WithCatch( LPWSTR pDriver,
     return hDC;
 }
 
-static HDC ImplCreateSalPrnIC( WinSalInfoPrinter* pPrinter, const ImplJobSetup* pSetupData )
+static HDC ImplCreateSalPrnIC( WinSalInfoPrinter const * pPrinter, const ImplJobSetup* pSetupData )
 {
     HDC hDC = nullptr;
     DEVMODEW const * pDevMode;
@@ -1014,8 +1024,8 @@ static HDC ImplCreateSalPrnIC( WinSalInfoPrinter* pPrinter, const ImplJobSetup*
     memset( pDriverName+pPrinter->maDriverName.getLength(), 0, 32 );
     memcpy( pDeviceName, pPrinter->maDeviceName.getStr(), pPrinter->maDeviceName.getLength()*sizeof(sal_Unicode));
     memset( pDeviceName+pPrinter->maDeviceName.getLength(), 0, 32 );
-    hDC = ImplCreateICW_WithCatch( reinterpret_cast< LPWSTR >(pDriverName),
-                                   reinterpret_cast< LPCWSTR >(pDeviceName),
+    hDC = ImplCreateICW_WithCatch( o3tl::toW(pDriverName),
+                                   o3tl::toW(pDeviceName),
                                    pDevMode );
     return hDC;
 }
@@ -1288,24 +1298,14 @@ BOOL CALLBACK SalPrintAbortProc( HDC hPrnDC, int /* nError */ )
 {
     SalData*    pSalData = GetSalData();
     WinSalPrinter* pPrinter;
-    bool        bWhile = TRUE;
-    int         i = 0;
+    bool        bWhile = true;
 
+    // Ensure we handle the mutex which will be released in WinSalInstance::DoYield
+    SolarMutexGuard aSolarMutexGuard;
     do
     {
         // process messages
-        MSG aMsg;
-        if ( PeekMessageW( &aMsg, nullptr, 0, 0, PM_REMOVE ) )
-        {
-            TranslateMessage( &aMsg );
-            DispatchMessageW( &aMsg );
-
-            i++;
-            if ( i > 15 )
-                bWhile = FALSE;
-        }
-        else
-            bWhile = FALSE;
+        bWhile = Application::Reschedule( true );
 
         pPrinter = pSalData->mpFirstPrinter;
         while ( pPrinter )
@@ -1405,9 +1405,8 @@ void WinSalPrinter::markInvalid()
 
 // need wrappers for StarTocW/A to use structured exception handling
 // since SEH does not mix with standard exception handling's cleanup
-static int lcl_StartDocW( HDC hDC, DOCINFOW* pInfo, WinSalPrinter* pPrt )
+static int lcl_StartDocW( HDC hDC, DOCINFOW const * pInfo, WinSalPrinter* pPrt )
 {
-    (void) pPrt;
     int nRet = 0;
     CATCH_DRIVER_EX_BEGIN;
     nRet = ::StartDocW( hDC, pInfo );
@@ -1442,8 +1441,8 @@ bool WinSalPrinter::StartJob( const OUString* pFileName,
     sal_Unicode aDevBuf[4096];
     memcpy( aDrvBuf, mpInfoPrinter->maDriverName.getStr(), (mpInfoPrinter->maDriverName.getLength()+1)*sizeof(sal_Unicode));
     memcpy( aDevBuf, mpInfoPrinter->maDeviceName.getStr(), (mpInfoPrinter->maDeviceName.getLength()+1)*sizeof(sal_Unicode));
-    hDC = CreateDCW( reinterpret_cast<LPCWSTR>(aDrvBuf),
-                     reinterpret_cast<LPCWSTR>(aDevBuf),
+    hDC = CreateDCW( o3tl::toW(aDrvBuf),
+                     o3tl::toW(aDevBuf),
                      nullptr,
                      pDevModeW );
 
@@ -1469,26 +1468,8 @@ bool WinSalPrinter::StartJob( const OUString* pFileName,
 
     // As the Telecom Balloon Fax driver tends to send messages repeatedly
     // we try to process first all, and then insert a dummy message
-    bool bWhile = TRUE;
-    int  i = 0;
-    do
-    {
-        // process messages
-        MSG aMsg;
-        if ( PeekMessageW( &aMsg, nullptr, 0, 0, PM_REMOVE ) )
-        {
-            TranslateMessage( &aMsg );
-            DispatchMessageW( &aMsg );
-
-            i++;
-            if ( i > 15 )
-                bWhile = FALSE;
-        }
-        else
-            bWhile = FALSE;
-    }
-    while ( bWhile );
-    BOOL const ret = PostMessageW(GetSalData()->mpFirstInstance->mhComWnd, SAL_MSG_DUMMY, 0, 0);
+    while ( Application::Reschedule( true ) );
+    BOOL const ret = PostMessageW(GetSalData()->mpInstance->mhComWnd, SAL_MSG_DUMMY, 0, 0);
     SAL_WARN_IF(0 == ret, "vcl", "ERROR: PostMessage() failed!");
 
     // bring up a file chooser if printing to file port but no file name given
@@ -1503,7 +1484,6 @@ bool WinSalPrinter::StartJob( const OUString* pFileName,
         {
             Sequence< OUString > aPathSeq( xFilePicker->getSelectedFiles() );
             INetURLObject aObj( aPathSeq[0] );
-            // we're using ansi calls (StartDocA) so convert the string
             aOutFileName = aObj.PathToFileName();
         }
         else
@@ -1516,12 +1496,12 @@ bool WinSalPrinter::StartJob( const OUString* pFileName,
     DOCINFOW aInfo;
     memset( &aInfo, 0, sizeof( DOCINFOW ) );
     aInfo.cbSize = sizeof( aInfo );
-    aInfo.lpszDocName = SAL_W(rJobName.getStr());
+    aInfo.lpszDocName = o3tl::toW(rJobName.getStr());
     if ( pFileName || aOutFileName.getLength() )
     {
         if ( (pFileName && !pFileName->isEmpty()) || aOutFileName.getLength() )
         {
-            aInfo.lpszOutput = SAL_W((pFileName && !pFileName->isEmpty()) ? pFileName->getStr() : aOutFileName.getStr());
+            aInfo.lpszOutput = o3tl::toW((pFileName && !pFileName->isEmpty()) ? pFileName->getStr() : aOutFileName.getStr());
         }
         else
             aInfo.lpszOutput = L"FILE:";
@@ -1545,6 +1525,14 @@ bool WinSalPrinter::StartJob( const OUString* pFileName,
     return TRUE;
 }
 
+void WinSalPrinter::DoEndDoc(HDC hDC)
+{
+    CATCH_DRIVER_EX_BEGIN;
+    if( ::EndDoc( hDC ) <= 0 )
+        GetLastError();
+    CATCH_DRIVER_EX_END( "exception in EndDoc", this );
+}
+
 bool WinSalPrinter::EndJob()
 {
     HDC hDC = mhDC;
@@ -1563,13 +1551,10 @@ bool WinSalPrinter::EndJob()
         // it should be safe to release the yield mutex over the EndDoc
         // call, however the real solution is supposed to be the threading
         // framework yet to come.
-        volatile sal_uLong nAcquire = GetSalData()->mpFirstInstance->ReleaseYieldMutex();
-        CATCH_DRIVER_EX_BEGIN;
-        if( ::EndDoc( hDC ) <= 0 )
-            GetLastError();
-        CATCH_DRIVER_EX_END( "exception in EndDoc", this );
-
-        GetSalData()->mpFirstInstance->AcquireYieldMutex( nAcquire );
+        {
+            SolarMutexReleaser aReleaser;
+            DoEndDoc( hDC );
+        }
         DeleteDC( hDC );
         mhDC = nullptr;
     }
