@@ -11,6 +11,29 @@
 #include <vcl/FilterConfigItem.hxx>
 #include "commonfuzzer.hxx"
 
+#include <config_features.h>
+#include <osl/detail/component-mapping.h>
+
+const lib_to_factory_mapping *
+lo_get_factory_map(void)
+{
+    static lib_to_factory_mapping map[] = {
+        { 0, 0 }
+    };
+
+    return map;
+}
+
+const lib_to_constructor_mapping *
+lo_get_constructor_map(void)
+{
+    static lib_to_constructor_mapping map[] = {
+        { 0, 0 }
+    };
+
+    return map;
+}
+
 extern "C" bool TestImport602(SvStream &rStream);
 
 extern "C" int LLVMFuzzerInitialize(int *argc, char ***argv)
