@@ -48,11 +48,8 @@ class FaxWizardDialogImpl(FaxWizardDialog):
     def enterStep(self, nOldStep, nNewStep):
         pass
 
-    RM_TYPESTYLE = 1
-    RM_ELEMENTS = 2
     RM_SENDERRECEIVER = 3
     RM_FOOTER = 4
-    RM_FINALSETTINGS = 5
 
     def __init__(self, xmsf):
         super(FaxWizardDialogImpl, self).__init__(xmsf)
@@ -61,28 +58,14 @@ class FaxWizardDialogImpl(FaxWizardDialog):
         self.bSaveSuccess = False
         self.filenameChanged = False
 
-    @classmethod
-    def main(self):
-        #Call the wizard remotely(see README)
-        try:
-            ConnectStr = \
-                "uno:socket,host=localhost,port=2002;urp;StarOffice.ComponentContext"
-            xLocMSF = Desktop.connect(ConnectStr)
-            lw = FaxWizardDialogImpl(xLocMSF)
-            lw.startWizard(xLocMSF)
-        except Exception as e:
-            print ("Wizard failure exception " + str(type(e)) +
-                   " message " + str(e) + " args " + str(e.args) +
-                   traceback.format_exc())
-
     def startWizard(self, xMSF):
         self.running = True
         try:
             #Number of steps on WizardDialog
             self.nMaxStep = 5
 
-            #instatiate The Document Frame for the Preview
-            self.terminateListener = TerminateListenerProcAdapter(self)
+            #instantiate The Document Frame for the Preview
+            self.terminateListener = TerminateListenerProcAdapter(self.queryTermination)
             self.myFaxDoc = FaxDocument(xMSF, self.terminateListener)
 
             #create the dialog:
@@ -148,7 +131,6 @@ class FaxWizardDialogImpl(FaxWizardDialog):
         self.switchToStep(self.getCurrentStep(), self.nMaxStep)
         endWizard = True
         try:
-            fileAccess = FileAccess(self.xMSF)
             self.sPath = self.myPathSelection.getSelectedPath()
             if not self.sPath or not os.path.exists(self.sPath):
                 self.myPathSelection.triggerPathPicker()
@@ -237,7 +219,7 @@ class FaxWizardDialogImpl(FaxWizardDialog):
     def insertRoadmap(self):
         self.addRoadmap()
         self.insertRoadMapItems(
-                [True, True, True, False, True], self.resources.RoadmapLabels)
+                self.resources.RoadmapLabels, [True, True, True, False, True])
 
         self.setRoadmapInteractive(True)
         self.setRoadmapComplete(True)
@@ -285,7 +267,7 @@ class FaxWizardDialogImpl(FaxWizardDialog):
         self.myFaxDoc.updateDateFields()
 
     def initializeSalutation(self):
-        #'Saludation' listbox
+        #'Salutation' listbox
         self.xDialogModel.lstSalutation.StringItemList = \
             tuple(self.resources.SalutationLabels)
 
