@@ -16,16 +16,17 @@
  *   except in compliance with the License. You may obtain a copy of
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
-#include <CellColorHandler.hxx>
-#include <PropertyMap.hxx>
-#include <ConversionHelper.hxx>
-#include <TDefTableHandler.hxx>
+#include "CellColorHandler.hxx"
+#include "PropertyMap.hxx"
+#include "ConversionHelper.hxx"
+#include "TDefTableHandler.hxx"
 #include <ooxml/resourceids.hxx>
 #include <com/sun/star/drawing/FillStyle.hpp>
 #include <com/sun/star/drawing/ShadingPattern.hpp>
 #include <sal/macros.h>
 #include <filter/msfilter/util.hxx>
 #include <comphelper/sequence.hxx>
+#include <tools/color.hxx>
 
 namespace writerfilter {
 namespace dmapper {
@@ -146,10 +147,7 @@ void CellColorHandler::lcl_attribute(Id rName, Value & rVal)
     }
 }
 
-void CellColorHandler::lcl_sprm(Sprm & rSprm)
-{
-    (void)rSprm;
-}
+void CellColorHandler::lcl_sprm(Sprm &) {}
 
 TablePropertyMapPtr  CellColorHandler::getProperties()
 {
@@ -281,7 +279,7 @@ TablePropertyMapPtr  CellColorHandler::getProperties()
 
         pPropertyMap->Insert(PROP_FILL_COLOR, uno::makeAny(nApplyColor));
     }
-    else
+    else if (nWW8BrushStyle || !m_bAutoFillColor)
         pPropertyMap->Insert( m_OutputFormat == Form ? PROP_BACK_COLOR
                             : PROP_CHAR_BACK_COLOR, uno::makeAny( nApplyColor ));
 
