@@ -16,13 +16,12 @@
  *   except in compliance with the License. You may obtain a copy of
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
-#include <ConversionHelper.hxx>
+#include "ConversionHelper.hxx"
 #include <com/sun/star/table/BorderLine2.hpp>
 #include <com/sun/star/table/BorderLineStyle.hpp>
 #include <com/sun/star/lang/Locale.hpp>
 #include <com/sun/star/text/HoriOrientation.hpp>
 #include <com/sun/star/style/NumberingType.hpp>
-#include <com/sun/star/text/RubyAdjust.hpp>
 #include <editeng/borderline.hxx>
 #include <ooxml/resourceids.hxx>
 #include <rtl/ustrbuf.hxx>
@@ -263,10 +262,10 @@ void MakeBorderLine( sal_Int32 nLineThickness,   sal_Int32 nLineToken,
     // thickness, or one of smaller thickness. If too small we
     // can make the deficit up in additional white space or
     // object size
-    ::editeng::SvxBorderStyle const nLineStyle(
+    SvxBorderLineStyle const nLineStyle(
             ::editeng::ConvertBorderStyleFromWord(nLineType));
-    rToFill.LineStyle = nLineStyle;
-    double const fConverted( (table::BorderLineStyle::NONE == nLineStyle) ? 0.0 :
+    rToFill.LineStyle = (sal_Int16)nLineStyle;
+    double const fConverted( (SvxBorderLineStyle::NONE == nLineStyle) ? 0.0 :
         ::editeng::ConvertBorderWidthFromWord(nLineStyle, nLineThickness,
             nLineType));
     rToFill.LineWidth = convertTwipToMM100(fConverted);
@@ -278,7 +277,7 @@ void lcl_SwapQuotesInField(OUString &rFmt)
 {
     //Swap unescaped " and ' with ' and "
     sal_Int32 nLen = rFmt.getLength();
-    OUStringBuffer aBuffer( rFmt.getStr() );
+    OUStringBuffer aBuffer( rFmt );
     const sal_Unicode* pFmt = rFmt.getStr();
     for (sal_Int32 nI = 0; nI < nLen; ++nI)
     {
@@ -289,7 +288,7 @@ void lcl_SwapQuotesInField(OUString &rFmt)
     }
     rFmt = aBuffer.makeStringAndClear();
 }
-bool lcl_IsNotAM(OUString& rFmt, sal_Int32 nPos)
+bool lcl_IsNotAM(OUString const & rFmt, sal_Int32 nPos)
 {
     return (
             (nPos == rFmt.getLength() - 1) ||
@@ -322,7 +321,7 @@ OUString ConvertMSFormatStringToSO(
         {
             ++nI;
             //While not at the end and not at an unescaped end quote
-            while ((nI < nLen) && (!(aNewFormat[nI] == '\"') && (aNewFormat[nI-1] != '\\')))
+            while ((nI < nLen) && ((aNewFormat[nI] != '\"') && (aNewFormat[nI-1] != '\\')))
                 ++nI;
         }
         else //normal unquoted section
@@ -424,9 +423,9 @@ sal_uInt32 convertTwipToMM100Unsigned(sal_Int32 _t)
     return convertTwipToMM100( _t );
 }
 
-sal_Int16 convertRubyAlign( sal_Int32 nIntValue )
+text::RubyAdjust convertRubyAlign( sal_Int32 nIntValue )
 {
-    sal_Int16 rubyAdjust = text::RubyAdjust_LEFT;
+    text::RubyAdjust rubyAdjust = text::RubyAdjust_LEFT;
     switch( nIntValue )
     {
         case NS_ooxml::LN_Value_ST_RubyAlign_center:
@@ -570,7 +569,7 @@ sal_Int16 ConvertNumberingType(sal_Int32 nFmt)
             break;
         case NS_ooxml::LN_Value_ST_NumberFormat_hebrew1:
             //91726
-            nRet = style::NumberingType::CHARS_HEBREW;
+            nRet = style::NumberingType::NUMBER_HEBREW;
             break;
         case NS_ooxml::LN_Value_ST_NumberFormat_decimalFullWidth:
         case NS_ooxml::LN_Value_ST_NumberFormat_decimalFullWidth2:
