@@ -28,6 +28,7 @@
 #include <com/sun/star/graphic/XGraphic.hpp>
 #include <com/sun/star/graphic/GraphicProvider.hpp>
 #include <com/sun/star/graphic/XGraphicProvider.hpp>
+#include <com/sun/star/io/BufferSizeExceededException.hpp>
 #include <com/sun/star/io/XInputStream.hpp>
 #include <com/sun/star/lang/XMultiServiceFactory.hpp>
 #include <com/sun/star/lang/XServiceInfo.hpp>
@@ -53,7 +54,7 @@
 
 #include <oox/drawingml/drawingmltypes.hxx>
 
-#include <DomainMapper.hxx>
+#include "DomainMapper.hxx"
 #include <dmapper/GraphicZOrderHelper.hxx>
 #include <ooxml/resourceids.hxx>
 
@@ -75,46 +76,36 @@ class XInputStreamHelper : public cppu::WeakImplHelper<io::XInputStream>
     const sal_uInt8* m_pBuffer;
     const sal_Int32  m_nLength;
     sal_Int32        m_nPosition;
-    bool             m_bBmp;
 
     const sal_uInt8* m_pBMPHeader; //default BMP-header
     sal_Int32        m_nHeaderLength;
 public:
-    XInputStreamHelper(const sal_uInt8* buf, size_t len, bool bBmp);
-    virtual ~XInputStreamHelper();
+    XInputStreamHelper(const sal_uInt8* buf, size_t len);
 
-    virtual ::sal_Int32 SAL_CALL readBytes( uno::Sequence< ::sal_Int8 >& aData, ::sal_Int32 nBytesToRead ) throw (io::NotConnectedException, io::BufferSizeExceededException, io::IOException, uno::RuntimeException, std::exception) override;
-    virtual ::sal_Int32 SAL_CALL readSomeBytes( uno::Sequence< ::sal_Int8 >& aData, ::sal_Int32 nMaxBytesToRead ) throw (io::NotConnectedException, io::BufferSizeExceededException, io::IOException, uno::RuntimeException, std::exception) override;
-    virtual void SAL_CALL skipBytes( ::sal_Int32 nBytesToSkip ) throw (io::NotConnectedException, io::BufferSizeExceededException, io::IOException, uno::RuntimeException, std::exception) override;
-    virtual ::sal_Int32 SAL_CALL available(  ) throw (io::NotConnectedException, io::IOException, uno::RuntimeException, std::exception) override;
-    virtual void SAL_CALL closeInput(  ) throw (io::NotConnectedException, io::IOException, uno::RuntimeException, std::exception) override;
+    virtual ::sal_Int32 SAL_CALL readBytes( uno::Sequence< ::sal_Int8 >& aData, ::sal_Int32 nBytesToRead ) override;
+    virtual ::sal_Int32 SAL_CALL readSomeBytes( uno::Sequence< ::sal_Int8 >& aData, ::sal_Int32 nMaxBytesToRead ) override;
+    virtual void SAL_CALL skipBytes( ::sal_Int32 nBytesToSkip ) override;
+    virtual ::sal_Int32 SAL_CALL available(  ) override;
+    virtual void SAL_CALL closeInput(  ) override;
 };
 
-XInputStreamHelper::XInputStreamHelper(const sal_uInt8* buf, size_t len, bool bBmp) :
+XInputStreamHelper::XInputStreamHelper(const sal_uInt8* buf, size_t len) :
         m_pBuffer( buf ),
         m_nLength( len ),
-        m_nPosition( 0 ),
-        m_bBmp( bBmp )
+        m_nPosition( 0 )
 {
     static const sal_uInt8 aHeader[] =
         {0x42, 0x4d, 0xe6, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x00, 0x00, 0x00 };
     m_pBMPHeader = aHeader;
-    m_nHeaderLength = m_bBmp ? sizeof( aHeader ) / sizeof(sal_uInt8) : 0;
-}
-
-
-XInputStreamHelper::~XInputStreamHelper()
-{
+    m_nHeaderLength = 0;
 }
 
 sal_Int32 XInputStreamHelper::readBytes( uno::Sequence<sal_Int8>& aData, sal_Int32 nBytesToRead )
-    throw (io::NotConnectedException, io::BufferSizeExceededException, io::IOException, uno::RuntimeException, std::exception)
 {
     return readSomeBytes( aData, nBytesToRead );
 }
 
 sal_Int32 XInputStreamHelper::readSomeBytes( uno::Sequence<sal_Int8>& aData, sal_Int32 nMaxBytesToRead )
-        throw (io::NotConnectedException, io::BufferSizeExceededException, io::IOException, uno::RuntimeException, std::exception)
 {
     sal_Int32 nRet = 0;
     if( nMaxBytesToRead > 0 )
@@ -144,7 +135,7 @@ sal_Int32 XInputStreamHelper::readSomeBytes( uno::Sequence<sal_Int8>& aData, sal
 }
 
 
-void XInputStreamHelper::skipBytes( sal_Int32 nBytesToSkip ) throw (io::NotConnectedException, io::BufferSizeExceededException, io::IOException, uno::RuntimeException, std::exception)
+void XInputStreamHelper::skipBytes( sal_Int32 nBytesToSkip )
 {
     if( nBytesToSkip < 0 || m_nPosition + nBytesToSkip > (m_nLength + m_nHeaderLength))
         throw io::BufferSizeExceededException();
@@ -152,13 +143,13 @@ void XInputStreamHelper::skipBytes( sal_Int32 nBytesToSkip ) throw (io::NotConne
 }
 
 
-sal_Int32 XInputStreamHelper::available(  ) throw (io::NotConnectedException, io::IOException, uno::RuntimeException, std::exception)
+sal_Int32 XInputStreamHelper::available(  )
 {
     return ( m_nLength + m_nHeaderLength ) - m_nPosition;
 }
 
 
-void XInputStreamHelper::closeInput(  ) throw (io::NotConnectedException, io::IOException, uno::RuntimeException, std::exception)
+void XInputStreamHelper::closeInput(  )
 {
 }
 
@@ -166,20 +157,16 @@ void XInputStreamHelper::closeInput(  ) throw (io::NotConnectedException, io::IO
 struct GraphicBorderLine
 {
     sal_Int32   nLineWidth;
-    sal_Int32   nLineColor;
-    sal_Int32   nLineDistance;
     bool        bHasShadow;
 
     GraphicBorderLine() :
         nLineWidth(0)
-        ,nLineColor(0)
-        ,nLineDistance(0)
         ,bHasShadow(false)
         {}
 
     bool isEmpty()
     {
-        return nLineWidth == 0 && nLineColor == 0 && !bHasShadow;
+        return nLineWidth == 0 && !bHasShadow;
     }
 
 };
@@ -198,17 +185,15 @@ public:
 
     sal_Int32 nLeftPosition;
     sal_Int32 nTopPosition;
-    sal_Int32 nRightPosition;
 
     bool      bUseSimplePos;
     sal_Int32 zOrder;
 
     sal_Int16 nHoriOrient;
     sal_Int16 nHoriRelation;
-    bool      bPageToggle;
     sal_Int16 nVertOrient;
     sal_Int16 nVertRelation;
-    sal_Int32 nWrap;
+    text::WrapTextMode nWrap;
     bool      bLayoutInCell;
     bool      bOpaque;
     bool      bContour;
@@ -238,10 +223,6 @@ public:
     sal_Int32           nCurrentBorderLine;
 
     bool            bIsGraphic;
-    bool            bIsBitmap;
-
-    bool            bHoriFlip;
-    bool            bVertFlip;
 
     bool            bSizeProtected;
     bool            bPositionProtected;
@@ -251,6 +232,7 @@ public:
     OUString sName;
     OUString sAlternativeText;
     OUString title;
+    OUString sHyperlinkURL;
     std::pair<OUString, OUString>& m_rPositionOffsets;
     std::pair<OUString, OUString>& m_rAligns;
     std::queue<OUString>& m_rPositivePercentages;
@@ -270,17 +252,15 @@ public:
         ,rDomainMapper( rDMapper )
         ,nLeftPosition(0)
         ,nTopPosition(0)
-        ,nRightPosition(0)
         ,bUseSimplePos(false)
         ,zOrder(-1)
         ,nHoriOrient(   text::HoriOrientation::NONE )
         ,nHoriRelation( text::RelOrientation::FRAME )
-        ,bPageToggle( false )
         ,nVertOrient(  text::VertOrientation::NONE )
         ,nVertRelation( text::RelOrientation::FRAME )
-        ,nWrap(0)
+        ,nWrap(text::WrapTextMode_NONE)
         ,bLayoutInCell(false)
-        ,bOpaque( true )
+        ,bOpaque( !rDMapper.IsInHeaderFooter() )
         ,bContour(false)
         ,bContourOutside(true)
         ,nLeftMargin(319)
@@ -299,9 +279,6 @@ public:
         ,eColorMode( drawing::ColorMode_STANDARD )
         ,nCurrentBorderLine(BORDER_TOP)
         ,bIsGraphic(false)
-        ,bIsBitmap(false)
-        ,bHoriFlip(false)
-        ,bVertFlip(false)
         ,bSizeProtected(false)
         ,bPositionProtected(false)
         ,nShapeOptionType(0)
@@ -366,7 +343,7 @@ public:
         xGraphicObjectProperties->setPropertyValue(getPropertyName( PROP_HORI_ORIENT_RELATION ),
                 uno::makeAny(nHoriRelation));
         xGraphicObjectProperties->setPropertyValue(getPropertyName( PROP_PAGE_TOGGLE ),
-                uno::makeAny(bPageToggle));
+                uno::makeAny(false));
         if (!bRelativeOnly)
             xGraphicObjectProperties->setPropertyValue(getPropertyName( PROP_VERT_ORIENT_POSITION),
                                                        uno::makeAny(nTopPosition));
@@ -374,7 +351,7 @@ public:
                 uno::makeAny(nVertRelation));
     }
 
-    void applyZOrder(uno::Reference<beans::XPropertySet>& xGraphicObjectProperties) const
+    void applyZOrder(uno::Reference<beans::XPropertySet> const & xGraphicObjectProperties) const
     {
         if (zOrder >= 0)
         {
@@ -384,7 +361,7 @@ public:
         }
     }
 
-    void applyName(uno::Reference<beans::XPropertySet>& xGraphicObjectProperties) const
+    void applyName(uno::Reference<beans::XPropertySet> const & xGraphicObjectProperties) const
     {
         try
         {
@@ -394,6 +371,9 @@ public:
             uno::Reference< container::XNamed > xNamed( xGraphicObjectProperties, uno::UNO_QUERY_THROW );
             xNamed->setName(rDomainMapper.GetGraphicNamingHelper().NameGraphic(sName));
 
+            if ( sHyperlinkURL.getLength() > 0 )
+                xGraphicObjectProperties->setPropertyValue(getPropertyName( PROP_HYPER_LINK_U_R_L ),
+                    uno::makeAny ( sHyperlinkURL ));
             xGraphicObjectProperties->setPropertyValue(getPropertyName( PROP_DESCRIPTION ),
                 uno::makeAny( sAlternativeText ));
             xGraphicObjectProperties->setPropertyValue(getPropertyName( PROP_TITLE ),
@@ -401,12 +381,12 @@ public:
         }
         catch( const uno::Exception& e )
         {
-            SAL_WARN("writerfilter", "failed. Message :" << e.Message);
+            SAL_WARN("writerfilter", "failed. Message :" << e);
         }
     }
 
     /// Getter for m_aInteropGrabBag, but also merges in the values from other members if they are set.
-    comphelper::SequenceAsHashMap getInteropGrabBag()
+    comphelper::SequenceAsHashMap const & getInteropGrabBag()
     {
         comphelper::SequenceAsHashMap aEffectExtent;
         if (m_oEffectExtentLeft)
@@ -504,6 +484,9 @@ void GraphicImport::lcl_attribute(Id nName, Value& rValue)
     sal_Int32 nIntValue = rValue.getInt();
     switch( nName )
     {
+        case NS_ooxml::LN_CT_Hyperlink_URL://90682;
+            m_pImpl->sHyperlinkURL = rValue.getString();
+        break;
         case NS_ooxml::LN_blip: //the binary graphic data in a shape
             {
             writerfilter::Reference<Properties>::Pointer_t pProperties = rValue.getProperties();
@@ -529,7 +512,6 @@ void GraphicImport::lcl_attribute(Id nName, Value& rValue)
             //graphic borders don't support different line types
         break;
         case NS_ooxml::LN_CT_Border_space:
-            m_pImpl->aBorders[m_pImpl->nCurrentBorderLine].nLineDistance = nIntValue;
         break;
         case NS_ooxml::LN_CT_Border_shadow:
             m_pImpl->aBorders[m_pImpl->nCurrentBorderLine].bHasShadow = nIntValue != 0;
@@ -540,6 +522,12 @@ void GraphicImport::lcl_attribute(Id nName, Value& rValue)
         case NS_ooxml::LN_CT_PositiveSize2D_cy:
         {
             sal_Int32 nDim = oox::drawingml::convertEmuToHmm(nIntValue);
+            // drawingML equivalent of oox::vml::ShapeType::getAbsRectangle():
+            // make sure a shape isn't hidden implicitly just because it has
+            // zero height or width.
+            if (nDim == 0)
+                nDim = 1;
+
             if( nName == NS_ooxml::LN_CT_PositiveSize2D_cx )
                 m_pImpl->setXSize(nDim);
             else
@@ -844,9 +832,8 @@ void GraphicImport::lcl_attribute(Id nName, Value& rValue)
 
                         xShapeProps->setPropertyValue("SurroundContour", uno::makeAny(m_pImpl->bContour));
                         m_pImpl->applyMargins(xShapeProps);
-                        bool bOpaque = m_pImpl->bOpaque && !m_pImpl->rDomainMapper.IsInHeaderFooter();
-                        xShapeProps->setPropertyValue("Opaque", uno::makeAny(bOpaque));
-                        xShapeProps->setPropertyValue("Surround", uno::makeAny(m_pImpl->nWrap));
+                        xShapeProps->setPropertyValue("Opaque", uno::makeAny(m_pImpl->bOpaque));
+                        xShapeProps->setPropertyValue("Surround", uno::makeAny((sal_Int32)m_pImpl->nWrap));
                         m_pImpl->applyZOrder(xShapeProps);
                         m_pImpl->applyName(xShapeProps);
 
@@ -945,7 +932,7 @@ uno::Reference<text::XTextContent> GraphicImport::GetGraphicObject()
 }
 
 
-void GraphicImport::ProcessShapeOptions(Value& rValue)
+void GraphicImport::ProcessShapeOptions(Value const & rValue)
 {
     sal_Int32 nIntValue = rValue.getInt();
     switch( m_pImpl->nShapeOptionType )
@@ -1092,8 +1079,8 @@ void GraphicImport::lcl_sprm(Sprm& rSprm)
             }
             break;
         case NS_ooxml::LN_EG_WrapType_wrapNone: // 90944; - doesn't contain attributes
-            //depending on the behindDoc attribute text wraps through behind or in fron of the object
-            m_pImpl->nWrap = text::WrapTextMode_THROUGHT;
+            //depending on the behindDoc attribute text wraps through behind or in front of the object
+            m_pImpl->nWrap = text::WrapTextMode_THROUGH;
         break;
         case NS_ooxml::LN_EG_WrapType_wrapTopAndBottom: // 90948;
             m_pImpl->nWrap = text::WrapTextMode_NONE;
@@ -1107,6 +1094,13 @@ void GraphicImport::lcl_sprm(Sprm& rSprm)
                     pProperties->resolve(*this);
             }
         break;
+        case NS_ooxml::LN_CT_NonVisualDrawingProps_a_hlinkClick: // 90689;
+            {
+                writerfilter::Reference<Properties>::Pointer_t pProperties = rSprm.getProps();
+                if( pProperties.get( ) )
+                    pProperties->resolve( *this );
+            }
+        break;
         default:
             SAL_WARN("writerfilter", "GraphicImport::lcl_sprm: unhandled token: " << nSprmId);
         break;
@@ -1150,12 +1144,12 @@ uno::Reference< text::XTextContent > GraphicImport::createGraphicObject( const b
             }
             else
             {
-                aBorderLine.Color = rBorderLine.nLineColor;
+                aBorderLine.Color = 0;
                 aBorderLine.InnerLineWidth = 0;
                 aBorderLine.OuterLineWidth = (sal_Int16)rBorderLine.nLineWidth;
                 aBorderLine.LineDistance = 0;
             }
-            PropertyIds aBorderProps[4] =
+            PropertyIds const aBorderProps[] =
             {
                 PROP_LEFT_BORDER,
                 PROP_RIGHT_BORDER,
@@ -1163,7 +1157,7 @@ uno::Reference< text::XTextContent > GraphicImport::createGraphicObject( const b
                 PROP_BOTTOM_BORDER
             };
 
-            for(PropertyIds & rBorderProp : aBorderProps)
+            for(PropertyIds const & rBorderProp : aBorderProps)
                 xGraphicObjectProperties->setPropertyValue(getPropertyName(rBorderProp), uno::makeAny(aBorderLine));
 
             // setting graphic object shadow proerties
@@ -1206,7 +1200,7 @@ uno::Reference< text::XTextContent > GraphicImport::createGraphicObject( const b
                 xGraphicObjectProperties->setPropertyValue(getPropertyName( PROP_SIZE_PROTECTED ),
                     uno::makeAny(true));
 
-            sal_Int32 nWidth = m_pImpl->nRightPosition - m_pImpl->nLeftPosition;
+            sal_Int32 nWidth = - m_pImpl->nLeftPosition;
             if (m_pImpl->eGraphicImportType == IMPORT_AS_DETECTED_ANCHOR)
             {
                 //adjust margins
@@ -1254,15 +1248,13 @@ uno::Reference< text::XTextContent > GraphicImport::createGraphicObject( const b
 
                 m_pImpl->applyPosition(xGraphicObjectProperties);
                 m_pImpl->applyRelativePosition(xGraphicObjectProperties);
-                bool bOpaque = m_pImpl->bOpaque && !m_pImpl->rDomainMapper.IsInHeaderFooter( );
-                if( !bOpaque )
+                if( !m_pImpl->bOpaque )
                 {
-                    xGraphicObjectProperties->setPropertyValue(getPropertyName( PROP_OPAQUE ),
-                        uno::makeAny(bOpaque));
+                    xGraphicObjectProperties->setPropertyValue(getPropertyName( PROP_OPAQUE ), uno::makeAny(m_pImpl->bOpaque));
                 }
                 xGraphicObjectProperties->setPropertyValue(getPropertyName( PROP_SURROUND ),
-                    uno::makeAny(m_pImpl->nWrap));
-                if( m_pImpl->bLayoutInCell && m_pImpl->nWrap != text::WrapTextMode_THROUGHT )
+                    uno::makeAny((sal_Int32)m_pImpl->nWrap));
+                if( m_pImpl->rDomainMapper.IsInTable() && m_pImpl->bLayoutInCell && m_pImpl->nWrap != text::WrapTextMode_THROUGH )
                     xGraphicObjectProperties->setPropertyValue(getPropertyName( PROP_FOLLOW_TEXT_FLOW ),
                         uno::makeAny(true));
 
@@ -1294,17 +1286,7 @@ uno::Reference< text::XTextContent > GraphicImport::createGraphicObject( const b
             if(m_pImpl->fGamma > 0. )
                 xGraphicObjectProperties->setPropertyValue(getPropertyName( PROP_GAMMA ),
                     uno::makeAny(m_pImpl->fGamma ));
-            if(m_pImpl->bHoriFlip)
-            {
-                xGraphicObjectProperties->setPropertyValue(getPropertyName( PROP_HORI_MIRRORED_ON_EVEN_PAGES ),
-                uno::makeAny( m_pImpl->bHoriFlip ));
-                xGraphicObjectProperties->setPropertyValue(getPropertyName( PROP_HORI_MIRRORED_ON_ODD_PAGES ),
-                uno::makeAny( m_pImpl->bHoriFlip ));
-            }
 
-            if( m_pImpl->bVertFlip )
-                xGraphicObjectProperties->setPropertyValue(getPropertyName( PROP_VERT_MIRRORED ),
-                    uno::makeAny( m_pImpl->bVertFlip ));
             xGraphicObjectProperties->setPropertyValue(getPropertyName( PROP_BACK_COLOR ),
                 uno::makeAny( m_pImpl->nFillColor ));
 
@@ -1352,11 +1334,22 @@ uno::Reference< text::XTextContent > GraphicImport::createGraphicObject( const b
                 m_pImpl->applyMargins(xGraphicObjectProperties);
                 m_pImpl->applyName(xGraphicObjectProperties);
             }
+
+            // Handle horizontal flip.
+            bool bMirrored = false;
+            xShapeProps->getPropertyValue("IsMirrored") >>= bMirrored;
+            if (bMirrored)
+            {
+                xGraphicObjectProperties->setPropertyValue("HoriMirroredOnEvenPages",
+                                                           uno::makeAny(true));
+                xGraphicObjectProperties->setPropertyValue("HoriMirroredOnOddPages",
+                                                           uno::makeAny(true));
+            }
         }
     }
     catch( const uno::Exception& e )
     {
-        SAL_WARN("writerfilter", "failed. Message :" << e.Message);
+        SAL_WARN("writerfilter", "failed. Message :" << e);
     }
     return xGraphicObject;
 }
@@ -1367,7 +1360,7 @@ void GraphicImport::data(const sal_uInt8* buf, size_t len, writerfilter::Referen
         beans::PropertyValues aMediaProperties( 1 );
         aMediaProperties[0].Name = getPropertyName(PROP_INPUT_STREAM);
 
-        uno::Reference< io::XInputStream > xIStream = new XInputStreamHelper( buf, len, m_pImpl->bIsBitmap );
+        uno::Reference< io::XInputStream > xIStream = new XInputStreamHelper( buf, len );
         aMediaProperties[0].Value <<= xIStream;
 
         uno::Reference<beans::XPropertySet> xPropertySet;
@@ -1429,7 +1422,6 @@ void GraphicImport::lcl_substream(Id /*name*/, ::writerfilter::Reference<Stream>
 {
 }
 
-
 void GraphicImport::lcl_info(const std::string& /*info*/)
 {
 }
