@@ -22,70 +22,53 @@
 #include "CellMarginHandler.hxx"
 #include "ConversionHelper.hxx"
 #include "MeasureHandler.hxx"
+#include "TrackChangesHandler.hxx"
 #include "TablePropertiesHandler.hxx"
 #include "TDefTableHandler.hxx"
 #include "DomainMapperTableManager.hxx"
 
 #include <ooxml/resourceids.hxx>
-#include <doctok/sprmids.hxx>
 
 #include <com/sun/star/text/SizeType.hpp>
 #include <com/sun/star/text/VertOrientation.hpp>
-#include <dmapperLoggers.hxx>
+#include <oox/token/tokens.hxx>
+#include "DomainMapper.hxx"
 
+using namespace com::sun::star;
+using namespace oox;
 
 namespace writerfilter {
 namespace dmapper {
 
-    TablePropertiesHandler::TablePropertiesHandler( bool bOOXML ) :
-        m_pCurrentInteropGrabBag(0),
-        m_pTableManager( NULL ),
-        m_bOOXML( bOOXML )
+    TablePropertiesHandler::TablePropertiesHandler() :
+        m_pCurrentInteropGrabBag(nullptr),
+        m_pTableManager( nullptr )
     {
     }
 
-
-    TablePropertiesHandler::~TablePropertiesHandler( )
-    {
-        // Do not delete the table manager... this will be done somewhere else
-        m_pTableManager = NULL;
-    }
-
     bool TablePropertiesHandler::sprm(Sprm & rSprm)
     {
-#ifdef DEBUG_DOMAINMAPPER
-        dmapper_logger->startElement("TablePropertiesHandler.sprm");
-        dmapper_logger->attribute("sprm", rSprm.toString());
+#ifdef DEBUG_WRITERFILTER
+        TagLogger::getInstance().startElement("TablePropertiesHandler.sprm");
+        TagLogger::getInstance().attribute("sprm", rSprm.toString());
 #endif
 
         bool bRet = true;
         sal_uInt32 nSprmId = rSprm.getId();
         Value::Pointer_t pValue = rSprm.getValue();
-        sal_Int32 nIntValue = ((pValue.get() != NULL) ? pValue->getInt() : 0);
+        sal_Int32 nIntValue = ((pValue.get() != nullptr) ? pValue->getInt() : 0);
         switch( nSprmId )
-       {
-            case NS_ooxml::LN_CT_TrPrBase_jc: //90706
+        {
+            case NS_ooxml::LN_CT_TrPrBase_jc:
             case NS_ooxml::LN_CT_TblPrBase_jc:
-            case 0x5400: // sprmTJc
             {
-                //table justification 0: left, 1: center, 2: right
                 sal_Int16 nOrient = ConversionHelper::convertTableJustification( nIntValue );
                 TablePropertyMapPtr pTableMap( new TablePropertyMap );
                 pTableMap->setValue( TablePropertyMap::HORI_ORIENT, nOrient );
                 insertTableProps( pTableMap );
             }
             break;
-            case 0x9601: // sprmTDxaLeft
-            break;
-            case 0x9602: // sprmTDxaGapHalf
-            {
-                //m_nGapHalf = ConversionHelper::convertTwipToMM100( nIntValue );
-                TablePropertyMapPtr pPropMap( new TablePropertyMap );
-                pPropMap->setValue( TablePropertyMap::GAP_HALF, ConversionHelper::convertTwipToMM100( nIntValue ) );
-                insertTableProps(pPropMap);
-            }
-            break;
-            case NS_ooxml::LN_CT_TrPrBase_trHeight: //90703
+            case NS_ooxml::LN_CT_TrPrBase_trHeight:
             {
                 //contains unit and value
                 writerfilter::Reference<Properties>::Pointer_t pProperties = rSprm.getProps();
@@ -100,8 +83,14 @@ namespace dmapper {
                     const int MINLAY = 23; // sw/inc/swtypes.hxx, minimal possible size of frames.
                     if (!pManager || !pManager->HasBtlrCell() || pMeasureHandler->getMeasureValue() > ConversionHelper::convertTwipToMM100(MINLAY))
                     {
-                        // In case a cell already wanted fixed size, we should not overwrite it here.
-                        if (!pManager || !pManager->IsRowSizeTypeInserted())
+                        bool bCantSplit = false;
+                        if (pManager && pManager->getRowProps())
+                        {
+                            boost::optional<PropertyMap::Property> oIsSplitAllowed = pManager->getRowProps()->getProperty(PROP_IS_SPLIT_ALLOWED);
+                            bCantSplit = oIsSplitAllowed && !oIsSplitAllowed->second.get<bool>();
+                        }
+                        // In case a cell already wanted fixed size and the row has <w:cantSplit/>, we should not overwrite it here.
+                        if (!pManager || !pManager->IsRowSizeTypeInserted() || !bCantSplit)
                             pPropMap->Insert( PROP_SIZE_TYPE, uno::makeAny( pMeasureHandler->GetRowHeightSizeType() ), false);
                         else
                             pPropMap->Insert( PROP_SIZE_TYPE, uno::makeAny(text::SizeType::FIX), false);
@@ -112,38 +101,80 @@ namespace dmapper {
                 }
             }
             break;
-            case 0x3403: // sprmTFCantSplit
-            case NS_sprm::LN_TCantSplit: // 0x3644
+            case NS_ooxml::LN_CT_TrPr_ins:
+            case NS_ooxml::LN_CT_TrPr_del:
+            {
+                writerfilter::Reference<Properties>::Pointer_t pProperties = rSprm.getProps();
+                if( pProperties.get())
+                {
+                    sal_Int32 nToken = sal_Int32();
+                    switch( nSprmId )
+                    {
+                        case NS_ooxml::LN_CT_TrPr_ins:
+                            nToken = XML_tableRowInsert;
+                            break;
+                        case NS_ooxml::LN_CT_TrPr_del:
+                            nToken = XML_tableRowDelete;
+                            break;
+                    };
+                    TrackChangesHandlerPtr pTrackChangesHandler( new TrackChangesHandler( nToken ) );
+                    pProperties->resolve(*pTrackChangesHandler);
+                    TablePropertyMapPtr pPropMap( new TablePropertyMap );
+
+                    // Add the 'track changes' properties to the 'table row' via UNO.
+                    // This way - in the SW core - when it receives this - it will create a new 'Table Redline' object for that row
+                    uno::Sequence<beans::PropertyValue> aTableRedlineProperties = pTrackChangesHandler->getRedlineProperties();
+                    pPropMap->Insert( PROP_TABLE_REDLINE_PARAMS , uno::makeAny( aTableRedlineProperties ));
+                    insertRowProps(pPropMap);
+                }
+            }
+            break;
+            case NS_ooxml::LN_CT_TcPrBase_cellIns:
+            case NS_ooxml::LN_CT_TcPrBase_cellDel:
+            {
+                writerfilter::Reference<Properties>::Pointer_t pProperties = rSprm.getProps();
+                if( pProperties.get())
+                {
+                    sal_Int32 nToken;
+                    switch( nSprmId )
+                    {
+                        case NS_ooxml::LN_CT_TcPrBase_cellIns:
+                            nToken = XML_tableCellInsert;
+                            break;
+                        case NS_ooxml::LN_CT_TcPrBase_cellDel:
+                            nToken = XML_tableCellDelete;
+                            break;
+                        default:
+                            throw lang::IllegalArgumentException("illegal redline token type", nullptr, 0);
+                            break;
+                    };
+                    TrackChangesHandlerPtr pTrackChangesHandler( new TrackChangesHandler( nToken ) );
+                    pProperties->resolve(*pTrackChangesHandler);
+                    TablePropertyMapPtr pPropMap( new TablePropertyMap );
+
+                    // Add the 'track changes' properties to the 'table row' via UNO.
+                    // This way - in the SW core - when it receives this - it will create a new 'Table Redline' object for that row
+                    uno::Sequence<beans::PropertyValue> aTableRedlineProperties = pTrackChangesHandler->getRedlineProperties();
+                    pPropMap->Insert( PROP_TABLE_REDLINE_PARAMS , uno::makeAny( aTableRedlineProperties ));
+                    cellProps(pPropMap);
+                }
+            }
+            break;
+            case NS_ooxml::LN_CT_TrPrBase_cantSplit:
             {
                 //row can't break across pages if nIntValue == 1
                 TablePropertyMapPtr pPropMap( new TablePropertyMap );
-                pPropMap->Insert( PROP_IS_SPLIT_ALLOWED, uno::makeAny(sal_Bool( nIntValue == 1 ? sal_False : sal_True ) ));
+                pPropMap->Insert( PROP_IS_SPLIT_ALLOWED, uno::makeAny( nIntValue != 1 ) );
                 insertRowProps(pPropMap);
             }
             break;
-            case 0x9407: // sprmTDyaRowHeight
-            {
-                // table row height - negative values indicate 'exact height' - positive 'at least'
-                TablePropertyMapPtr pPropMap( new TablePropertyMap );
-                bool bMinHeight = true;
-                sal_Int16 nHeight = static_cast<sal_Int16>( nIntValue );
-                if( nHeight < 0 )
-                {
-                    bMinHeight = false;
-                    nHeight *= -1;
-                }
-                pPropMap->Insert( PROP_SIZE_TYPE, uno::makeAny(bMinHeight ? text::SizeType::MIN : text::SizeType::FIX ));
-                pPropMap->Insert( PROP_HEIGHT, uno::makeAny(ConversionHelper::convertTwipToMM100( nHeight )));
-                insertRowProps(pPropMap);
-            }
-            break;
-            case NS_ooxml::LN_CT_TcPrBase_vAlign://90694
+            case NS_ooxml::LN_CT_TcPrBase_vAlign:
             {
                 sal_Int16 nVertOrient = text::VertOrientation::NONE;
-                switch( nIntValue ) //0 - top 1 - center 3 - bottom (ST_VerticalJc)
+                switch( nIntValue )
                 {
-                    case 1: nVertOrient = text::VertOrientation::CENTER; break;
-                    case 3: nVertOrient = text::VertOrientation::BOTTOM; break;
+                    case NS_ooxml::LN_Value_ST_VerticalJc_center: nVertOrient = text::VertOrientation::CENTER; break;
+                    case NS_ooxml::LN_Value_ST_VerticalJc_bottom: nVertOrient = text::VertOrientation::BOTTOM; break;
                     default:;
                 };
                 TablePropertyMapPtr pCellPropMap( new TablePropertyMap() );
@@ -155,16 +186,16 @@ namespace dmapper {
                     OUString aVertOrient;
                     switch( nIntValue )
                     {
-                        case 0: aVertOrient = "top"; break;
-                        case 1: aVertOrient = "center"; break;
-                        case 2: aVertOrient = "both"; break;
-                        case 3: aVertOrient = "bottom"; break;
+                        case NS_ooxml::LN_Value_ST_VerticalJc_top: aVertOrient = "top"; break;
+                        case NS_ooxml::LN_Value_ST_VerticalJc_center: aVertOrient = "center"; break;
+                        case NS_ooxml::LN_Value_ST_VerticalJc_both: aVertOrient = "both"; break;
+                        case NS_ooxml::LN_Value_ST_VerticalJc_bottom: aVertOrient = "bottom"; break;
                     };
                     if (!aVertOrient.isEmpty())
                     {
                         beans::PropertyValue aValue;
                         aValue.Name = "vAlign";
-                        aValue.Value = uno::makeAny(aVertOrient);
+                        aValue.Value <<= aVertOrient;
                         m_pCurrentInteropGrabBag->push_back(aValue);
                     }
                 }
@@ -175,7 +206,7 @@ namespace dmapper {
                 writerfilter::Reference<Properties>::Pointer_t pProperties = rSprm.getProps();
                 if( pProperties.get())
                 {
-                    BorderHandlerPtr pBorderHandler( new BorderHandler(m_bOOXML) );
+                    BorderHandlerPtr pBorderHandler(new BorderHandler(true));
                     if (m_pCurrentInteropGrabBag)
                         pBorderHandler->enableInteropGrabBag("tblBorders");
                     pProperties->resolve(*pBorderHandler);
@@ -184,8 +215,8 @@ namespace dmapper {
                     TablePropertyMapPtr pTablePropMap( new TablePropertyMap );
                     pTablePropMap->InsertProps(pBorderHandler->getProperties());
 
-#ifdef DEBUG_DOMAINMAPPER
-                    pTablePropMap->dumpXml( dmapper_logger );
+#ifdef DEBUG_WRITERFILTER
+                    pTablePropMap->dumpXml();
 #endif
                     insertTableProps( pTablePropMap );
                 }
@@ -205,7 +236,7 @@ namespace dmapper {
                 if( pProperties.get())
                 {
                     //in OOXML there's one set of borders at each cell (if there is any)
-                    TDefTableHandlerPtr pTDefTableHandler( new TDefTableHandler( m_bOOXML ));
+                    std::shared_ptr< TDefTableHandler > pTDefTableHandler( new TDefTableHandler());
                     if (m_pCurrentInteropGrabBag)
                         pTDefTableHandler->enableInteropGrabBag("tcBorders");
                     pProperties->resolve( *pTDefTableHandler );
@@ -218,7 +249,7 @@ namespace dmapper {
             }
             break;
             case NS_ooxml::LN_CT_TcPrBase_tcMar:
-            //
+
                 {
                     writerfilter::Reference<Properties>::Pointer_t pProperties = rSprm.getProps();
                     if (pProperties.get())
@@ -254,10 +285,6 @@ namespace dmapper {
                 }
             }
             break;
-            case 0xd61a : // sprmTCellTopColor
-            case 0xd61b : // sprmTCellLeftColor
-            case 0xd61c : // sprmTCellBottomColor
-            case 0xd61d : // sprmTCellRightColor
             case NS_ooxml::LN_CT_TcPrBase_shd:
             {
                 // each color sprm contains as much colors as cells are in a row
@@ -266,12 +293,14 @@ namespace dmapper {
                 if( pProperties.get())
                 {
                     CellColorHandlerPtr pCellColorHandler( new CellColorHandler );
-                    if (m_pCurrentInteropGrabBag)
-                        pCellColorHandler->enableInteropGrabBag("shd");
+                    pCellColorHandler->enableInteropGrabBag("shd"); //enable to store shd unsupported props in grab bag
                     pProperties->resolve( *pCellColorHandler );
+                    TablePropertyMapPtr pPropertyMap = pCellColorHandler->getProperties();
+                    beans::PropertyValue aGrabBag = pCellColorHandler->getInteropGrabBag();
                     if (m_pCurrentInteropGrabBag)
-                        m_pCurrentInteropGrabBag->push_back(pCellColorHandler->getInteropGrabBag());
-                    cellProps( pCellColorHandler->getProperties());
+                        m_pCurrentInteropGrabBag->push_back(aGrabBag);
+                    pPropertyMap->Insert( PROP_CELL_INTEROP_GRAB_BAG, aGrabBag.Value );
+                    cellProps( pPropertyMap );
                 }
             }
             break;
@@ -319,6 +348,14 @@ namespace dmapper {
                    insertTableProps(pTblIndMap);
                }
            }
+            break;
+            case NS_ooxml::LN_CT_TcPrBase_hideMark:
+            if (nIntValue)
+            {
+                TablePropertyMapPtr pPropMap(new TablePropertyMap());
+                pPropMap->Insert(PROP_CELL_HIDE_MARK, uno::makeAny(nIntValue));
+                cellProps(pPropMap);
+            }
             break;
             default:
             // Not handled here, give the next handler a chance.
@@ -332,7 +369,7 @@ namespace dmapper {
                     {
                         beans::PropertyValue aValue;
                         aValue.Name = (nSprmId == NS_ooxml::LN_CT_TblPrBase_tblStyleRowBandSize ? OUString("tblStyleRowBandSize") : OUString("tblStyleColBandSize"));
-                        aValue.Value = uno::makeAny(nIntValue);
+                        aValue.Value <<= nIntValue;
                         m_pCurrentInteropGrabBag->push_back(aValue);
                     }
                     break;
@@ -340,8 +377,8 @@ namespace dmapper {
             break;
         }
 
-#ifdef DEBUG_DOMAINMAPPER
-        dmapper_logger->endElement();
+#ifdef DEBUG_WRITERFILTER
+        TagLogger::getInstance().endElement();
 #endif
 
         return bRet;
