@@ -33,15 +33,16 @@
 #include "OOXMLFastDocumentHandler.hxx"
 #include "OOXMLPropertySet.hxx"
 
-#include <tools/resmgr.hxx>
+#include <unotools/resmgr.hxx>
 #include <vcl/svapp.hxx>
 #include <vcl/settings.hxx>
-#include <svx/dialogs.hrc>
+#include <svx/dialmgr.hxx>
+#include <svx/strings.hrc>
 #include <comphelper/sequence.hxx>
 #include <unotools/mediadescriptor.hxx>
 
 #include <iostream>
-#include "sfx2/objsh.hxx"
+#include <sfx2/objsh.hxx>
 
 // this extern variable is declared in OOXMLStreamImpl.hxx
 OUString customTarget;
@@ -55,7 +56,6 @@ OOXMLDocumentImpl::OOXMLDocumentImpl(OOXMLStream::Pointer_t const & pStream, con
     : mpStream(pStream)
     , mxStatusIndicator(xStatusIndicator)
     , mnXNoteId(0)
-    , mXNoteType(0)
     , mxThemeDom(nullptr)
     , mbIsSubstream(false)
     , mbSkipImages(bSkipImages)
@@ -84,7 +84,7 @@ void OOXMLDocumentImpl::resolveFastSubStream(Stream & rStreamHandler,
     catch (uno::Exception const& e)
     {
         SAL_INFO("writerfilter.ooxml", "resolveFastSubStream: exception while "
-                "resolving stream " << nType << " : " << e.Message);
+                "resolving stream " << nType << " : " << e);
         return;
     }
     OOXMLStream::Pointer_t savedStream = mpStream;
@@ -142,7 +142,7 @@ uno::Reference<xml::dom::XDocument> OOXMLDocumentImpl::importSubStream(OOXMLStre
     catch (uno::Exception const& e)
     {
         SAL_INFO("writerfilter.ooxml", "importSubStream: exception while "
-                "importing stream " << nType << " : " << e.Message);
+                "importing stream " << nType << " : " << e);
         return xRet;
     }
 
@@ -160,7 +160,7 @@ uno::Reference<xml::dom::XDocument> OOXMLDocumentImpl::importSubStream(OOXMLStre
         catch (uno::Exception const& e)
         {
             SAL_INFO("writerfilter.ooxml", "importSubStream: exception while "
-                     "parsing stream " << nType << " : " << e.Message);
+                     "parsing stream " << nType << " : " << e);
             return xRet;
         }
     }
@@ -169,10 +169,6 @@ uno::Reference<xml::dom::XDocument> OOXMLDocumentImpl::importSubStream(OOXMLStre
     {
         importSubStreamRelations(pStream, OOXMLStream::CUSTOMXMLPROPS);
     }
-    if(OOXMLStream::ACTIVEX == nType)
-    {
-        importSubStreamRelations(pStream, OOXMLStream::ACTIVEXBIN);
-    }
     if(OOXMLStream::CHARTS == nType)
     {
         importSubStreamRelations(pStream, OOXMLStream::EMBEDDINGS);
@@ -193,7 +189,7 @@ void OOXMLDocumentImpl::importSubStreamRelations(const OOXMLStream::Pointer_t& p
     catch (uno::Exception const& e)
     {
         SAL_WARN("writerfilter.ooxml", "importSubStreamRelations: exception while "
-            "importing stream " << nType << " : " << e.Message);
+            "importing stream " << nType << " : " << e);
         return;
     }
 
@@ -202,7 +198,7 @@ void OOXMLDocumentImpl::importSubStreamRelations(const OOXMLStream::Pointer_t& p
 
     if (xcpInputStream.is())
     {
-        // imporing itemprops files for item.xml from customXml.
+        // importing itemprops files for item.xml from customXml.
         if(OOXMLStream::CUSTOMXMLPROPS == nType)
         {
             try
@@ -214,7 +210,7 @@ void OOXMLDocumentImpl::importSubStreamRelations(const OOXMLStream::Pointer_t& p
             catch (uno::Exception const& e)
             {
                 SAL_WARN("writerfilter.ooxml", "importSubStream: exception while "
-                         "parsing stream " << nType << " : " << e.Message);
+                         "parsing stream " << nType << " : " << e);
                 mxCustomXmlProsDom = xRelation;
             }
 
@@ -223,14 +219,8 @@ void OOXMLDocumentImpl::importSubStreamRelations(const OOXMLStream::Pointer_t& p
                 mxCustomXmlProsDom = xRelation;
             }
         }
-        else if(OOXMLStream::ACTIVEXBIN == nType)
-        {
-            // imporing activex.bin files for activex.xml from activeX folder.
-            mxActiveXBin = xcpInputStream;
-        }
         else if(OOXMLStream::EMBEDDINGS == nType)
         {
-            // imporing activex.bin files for activex.xml from activeX folder.
             mxEmbeddings = xcpInputStream;
         }
         else if(OOXMLStream::CHARTS == nType)
@@ -252,9 +242,8 @@ sal_Int32 OOXMLDocumentImpl::getXNoteId() const
     return mnXNoteId;
 }
 
-void OOXMLDocumentImpl::setXNoteType(Id nId)
+void OOXMLDocumentImpl::setXNoteType(Id /*nId*/)
 {
-    mXNoteType = nId;
 }
 
 const OUString & OOXMLDocumentImpl::getTarget() const
@@ -282,7 +271,7 @@ OOXMLDocumentImpl::getXNoteStream(OOXMLStream::StreamType_t nType, Id aType,
                                   const sal_Int32 nId)
 {
     OOXMLStream::Pointer_t pStream =
-        (OOXMLDocumentFactory::createStream(mpStream, nType));
+        OOXMLDocumentFactory::createStream(mpStream, nType);
     // See above, no status indicator for the note stream, either.
     OOXMLDocumentImpl * pDocument = new OOXMLDocumentImpl(pStream, uno::Reference<task::XStatusIndicator>(), mbSkipImages, maMediaDescriptor);
     pDocument->setXNoteId(nId);
@@ -357,23 +346,15 @@ OOXMLPropertySet * OOXMLDocumentImpl::getPicturePropSet
 
     OOXMLValue::Pointer_t pPayloadValue(new OOXMLBinaryValue(pPicture));
 
-    OOXMLProperty::Pointer_t pPayloadProperty
-        (new OOXMLProperty(NS_ooxml::LN_payload, pPayloadValue,
-                               OOXMLProperty::ATTRIBUTE));
-
     OOXMLPropertySet::Pointer_t pBlipSet(new OOXMLPropertySet);
 
-    pBlipSet->add(pPayloadProperty);
+    pBlipSet->add(NS_ooxml::LN_payload, pPayloadValue, OOXMLProperty::ATTRIBUTE);
 
     OOXMLValue::Pointer_t pBlipValue(new OOXMLPropertySetValue(pBlipSet));
 
-    OOXMLProperty::Pointer_t pBlipProperty
-        (new OOXMLProperty(NS_ooxml::LN_blip, pBlipValue,
-                               OOXMLProperty::ATTRIBUTE));
-
     OOXMLPropertySet * pProps = new OOXMLPropertySet;
 
-    pProps->add(pBlipProperty);
+    pProps->add(NS_ooxml::LN_blip, pBlipValue, OOXMLProperty::ATTRIBUTE);
 
     return pProps;
 }
@@ -381,9 +362,9 @@ OOXMLPropertySet * OOXMLDocumentImpl::getPicturePropSet
 void OOXMLDocumentImpl::resolvePicture(Stream & rStream,
                                        const OUString & rId)
 {
-    OOXMLPropertySet * pProps = getPicturePropSet(rId);
+    OOXMLPropertySet::Pointer_t pProps(getPicturePropSet(rId));
 
-    rStream.props(writerfilter::Reference<Properties>::Pointer_t(pProps));
+    rStream.props(pProps);
 }
 
 OUString OOXMLDocumentImpl::getTargetForId(const OUString & rId)
@@ -436,8 +417,30 @@ void OOXMLDocumentImpl::resolveFooter(Stream & rStream,
      }
 }
 
+namespace {
+// Ensures that the indicator is reset after exiting OOXMLDocumentImpl::resolve
+class StatusIndicatorGuard{
+public:
+    explicit StatusIndicatorGuard(css::uno::Reference<css::task::XStatusIndicator>& xStatusIndicator)
+        :mxStatusIndicator(xStatusIndicator)
+    {
+    }
+
+    ~StatusIndicatorGuard()
+    {
+        if (mxStatusIndicator.is())
+                mxStatusIndicator->end();
+    }
+
+private:
+    css::uno::Reference<css::task::XStatusIndicator> mxStatusIndicator;
+};
+}
+
 void OOXMLDocumentImpl::resolve(Stream & rStream)
 {
+    StatusIndicatorGuard aStatusIndicatorGuard(mxStatusIndicator);
+
     if (utl::MediaDescriptor(maMediaDescriptor).getUnpackedValueOrDefault("ReadGlossaries", false))
     {
         resolveFastSubStream(rStream, OOXMLStream::GLOSSARY);
@@ -462,8 +465,7 @@ void OOXMLDocumentImpl::resolve(Stream & rStream)
                     // We want to care about the progress if we know the estimated paragraph count and we have given a status indicator as well.
                     // Set the end position only here, so later it's enough to check if that is non-zero in incrementProgress().
                     mnProgressEndPos = nValue;
-                    static ResMgr* pResMgr = ResMgr::CreateResMgr("svx", Application::GetSettings().GetUILanguageTag());
-                    OUString aDocLoad(ResId(RID_SVXSTR_DOC_LOAD, *pResMgr));
+                    OUString aDocLoad(SvxResId(RID_SVXSTR_DOC_LOAD));
                     mxStatusIndicator->start(aDocLoad, mnProgressEndPos);
                     mnPercentSize = mnProgressEndPos / 100;
                 }
@@ -495,8 +497,6 @@ void OOXMLDocumentImpl::resolve(Stream & rStream)
         // Custom xml's are handled as part of grab bag.
         resolveCustomXmlStream(rStream);
 
-        resolveActiveXStream(rStream);
-
         resolveFastSubStream(rStream, OOXMLStream::FONTTABLE);
         resolveFastSubStream(rStream, OOXMLStream::STYLES);
         resolveFastSubStream(rStream, OOXMLStream::NUMBERING);
@@ -527,8 +527,7 @@ void OOXMLDocumentImpl::resolve(Stream & rStream)
         // note: cannot throw anything other than SAXException out of here?
         catch (uno::Exception const& e)
         {
-            SAL_WARN("writerfilter.ooxml",
-                "OOXMLDocumentImpl::resolve(): exception: " << e.Message);
+            SAL_WARN("writerfilter.ooxml", "OOXMLDocumentImpl::resolve(): " << e);
             throw lang::WrappedTargetRuntimeException("", nullptr,
                     uno::makeAny(e));
         }
@@ -538,9 +537,6 @@ void OOXMLDocumentImpl::resolve(Stream & rStream)
                 "OOXMLDocumentImpl::resolve(): non-UNO exception");
         }
     }
-
-    if (mxStatusIndicator.is())
-        mxStatusIndicator->end();
 }
 
 void OOXMLDocumentImpl::incrementProgress()
@@ -560,12 +556,11 @@ void OOXMLDocumentImpl::resolveCustomXmlStream(Stream & rStream)
 {
     // Resolving all item[n].xml files from CustomXml folder.
     uno::Reference<embed::XRelationshipAccess> xRelationshipAccess;
-    xRelationshipAccess.set((dynamic_cast<OOXMLStreamImpl&>(*mpStream.get())).accessDocumentStream(), uno::UNO_QUERY);
+    xRelationshipAccess.set(dynamic_cast<OOXMLStreamImpl&>(*mpStream.get()).accessDocumentStream(), uno::UNO_QUERY);
     if (xRelationshipAccess.is())
     {
         static const char sCustomType[] = "http://schemas.openxmlformats.org/officeDocument/2006/relationships/customXml";
         static const char sCustomTypeStrict[] = "http://purl.oclc.org/ooxml/officeDocument/relationships/customXml";
-        OUString sTarget("Target");
         bool bFound = false;
         sal_Int32 counter = 0;
         uno::Sequence< uno::Sequence< beans::StringPair > >aSeqs = xRelationshipAccess->getAllRelationships();
@@ -582,7 +577,7 @@ void OOXMLDocumentImpl::resolveCustomXmlStream(Stream & rStream)
                 if (aPair.Second == sCustomType ||
                         aPair.Second == sCustomTypeStrict)
                     bFound = true;
-                else if(aPair.First == sTarget && bFound)
+                else if(aPair.First == "Target" && bFound)
                 {
                     // Adding value to extern variable customTarget. It will be used in ooxmlstreamimpl
                     // to ensure customxml target is visited in lcl_getTarget.
@@ -629,11 +624,11 @@ void OOXMLDocumentImpl::resolveGlossaryStream(Stream & /*rStream*/)
     catch (uno::Exception const& e)
     {
         SAL_INFO("writerfilter.ooxml", "resolveGlossaryStream: exception while "
-                 "createStream for glossary" << OOXMLStream::GLOSSARY << " : " << e.Message);
+                 "createStream for glossary" << OOXMLStream::GLOSSARY << " : " << e);
         return;
     }
     uno::Reference<embed::XRelationshipAccess> xRelationshipAccess;
-    xRelationshipAccess.set((dynamic_cast<OOXMLStreamImpl&>(*pStream.get())).accessDocumentStream(), uno::UNO_QUERY);
+    xRelationshipAccess.set(dynamic_cast<OOXMLStreamImpl&>(*pStream.get()).accessDocumentStream(), uno::UNO_QUERY);
     if (xRelationshipAccess.is())
     {
 
@@ -696,7 +691,7 @@ void OOXMLDocumentImpl::resolveGlossaryStream(Stream & /*rStream*/)
                   catch (uno::Exception const& e)
                   {
                       SAL_INFO("writerfilter.ooxml", "importSubStream: exception while "
-                      "parsing stream of Type" << nType << " : " << e.Message);
+                      "parsing stream of Type" << nType << " : " << e);
                       return;
                   }
 
@@ -720,17 +715,16 @@ void OOXMLDocumentImpl::resolveGlossaryStream(Stream & /*rStream*/)
 void OOXMLDocumentImpl::resolveEmbeddingsStream(const OOXMLStream::Pointer_t& pStream)
 {
     uno::Reference<embed::XRelationshipAccess> xRelationshipAccess;
-    xRelationshipAccess.set((dynamic_cast<OOXMLStreamImpl&>(*pStream.get())).accessDocumentStream(), uno::UNO_QUERY);
+    xRelationshipAccess.set(dynamic_cast<OOXMLStreamImpl&>(*pStream.get()).accessDocumentStream(), uno::UNO_QUERY);
     if (xRelationshipAccess.is())
     {
-        OUString sChartType("http://schemas.openxmlformats.org/officeDocument/2006/relationships/chart");
-        OUString sChartTypeStrict("http://purl.oclc.org/ooxml/officeDocument/relationships/chart");
-        OUString sFootersType("http://schemas.openxmlformats.org/officeDocument/2006/relationships/footer");
-        OUString sFootersTypeStrict("http://purl.oclc.org/ooxml/officeDocument/relationships/footer");
-        OUString sHeaderType("http://schemas.openxmlformats.org/officeDocument/2006/relationships/header");
-        OUString sHeaderTypeStrict("http://purl.oclc.org/ooxml/officeDocument/relationships/header");
+        OUString const sChartType("http://schemas.openxmlformats.org/officeDocument/2006/relationships/chart");
+        OUString const sChartTypeStrict("http://purl.oclc.org/ooxml/officeDocument/relationships/chart");
+        OUString const sFootersType("http://schemas.openxmlformats.org/officeDocument/2006/relationships/footer");
+        OUString const sFootersTypeStrict("http://purl.oclc.org/ooxml/officeDocument/relationships/footer");
+        OUString const sHeaderType("http://schemas.openxmlformats.org/officeDocument/2006/relationships/header");
+        OUString const sHeaderTypeStrict("http://purl.oclc.org/ooxml/officeDocument/relationships/header");
 
-        OUString sTarget("Target");
         bool bFound = false;
         bool bHeaderFooterFound = false;
         OOXMLStream::StreamType_t streamType = OOXMLStream::UNKNOWN;
@@ -758,14 +752,14 @@ void OOXMLDocumentImpl::resolveEmbeddingsStream(const OOXMLStream::Pointer_t& pS
                     bHeaderFooterFound = true;
                     streamType = OOXMLStream::HEADER;
                 }
-                else if(aPair.First == sTarget && ( bFound || bHeaderFooterFound ))
+                else if(aPair.First == "Target" && ( bFound || bHeaderFooterFound ))
                 {
                     // Adding value to extern variable customTarget. It will be used in ooxmlstreamimpl
                     // to ensure chart.xml target is visited in lcl_getTarget.
                     customTarget = aPair.Second;
                 }
             }
-            if(( bFound || bHeaderFooterFound))
+            if( bFound || bHeaderFooterFound)
             {
                 if(bFound)
                 {
@@ -782,7 +776,7 @@ void OOXMLDocumentImpl::resolveEmbeddingsStream(const OOXMLStream::Pointer_t& pS
                     catch (uno::Exception const& e)
                     {
                         SAL_INFO("writerfilter.ooxml", "resolveEmbeddingsStream: can't find header/footer whilst "
-                               "resolving stream " << streamType << " : " << e.Message);
+                               "resolving stream " << streamType << " : " << e);
                         return;
                     }
                 }
@@ -795,7 +789,7 @@ void OOXMLDocumentImpl::resolveEmbeddingsStream(const OOXMLStream::Pointer_t& pS
                     {
                         embeddingsTemp.Name = embeddingsTarget;
                         embeddingsTemp.Value <<= mxEmbeddings;
-                        maEmbedding.push_back(embeddingsTemp);
+                        aEmbeddings.push_back(embeddingsTemp);
                         mxEmbeddings.clear();
                     }
                 }
@@ -804,65 +798,8 @@ void OOXMLDocumentImpl::resolveEmbeddingsStream(const OOXMLStream::Pointer_t& pS
             }
         }
     }
-    if (!maEmbedding.empty())
-        mxEmbeddingsList = comphelper::containerToSequence(maEmbedding);
-}
-
-void OOXMLDocumentImpl::resolveActiveXStream(Stream & rStream)
-{
-    // Resolving all ActiveX[n].xml files from ActiveX folder.
-    uno::Reference<embed::XRelationshipAccess> xRelationshipAccess;
-    xRelationshipAccess.set((dynamic_cast<OOXMLStreamImpl&>(*mpStream.get())).accessDocumentStream(), uno::UNO_QUERY);
-    if (xRelationshipAccess.is())
-    {
-        static const char sCustomType[] = "http://schemas.openxmlformats.org/officeDocument/2006/relationships/control";
-        static const char sCustomTypeStrict[] = "http://purl.oclc.org/ooxml/officeDocument/relationships/control";
-        OUString sTarget("Target");
-        bool bFound = false;
-        sal_Int32 counter = 0;
-        uno::Sequence< uno::Sequence< beans::StringPair > > aSeqs = xRelationshipAccess->getAllRelationships();
-        uno::Sequence<uno::Reference<xml::dom::XDocument> > xActiveXDomListTemp(aSeqs.getLength());
-        uno::Sequence<uno::Reference<io::XInputStream> > xActiveXBinListTemp(aSeqs.getLength());
-        for (sal_Int32 j = 0; j < aSeqs.getLength(); j++)
-        {
-            uno::Sequence< beans::StringPair > aSeq = aSeqs[j];
-            for (sal_Int32 i = 0; i < aSeq.getLength(); i++)
-            {
-                beans::StringPair aPair = aSeq[i];
-                // Need to resolve only ActiveX files from document relationships.
-                // Skipping other files.
-                if (aPair.Second == sCustomType ||
-                        aPair.Second == sCustomTypeStrict)
-                    bFound = true;
-                else if(aPair.First == sTarget && bFound)
-                {
-                    // Adding value to extern variable customTarget. It will be used in ooxmlstreamimpl
-                    // to ensure ActiveX.xml target is visited in lcl_getTarget.
-                    customTarget = aPair.Second;
-                }
-            }
-            if(bFound)
-            {
-                uno::Reference<xml::dom::XDocument> activeXTemp = importSubStream(OOXMLStream::ACTIVEX);
-                // This will add all ActiveX[n].xml to grabbag list.
-                if(activeXTemp.is())
-                {
-                    xActiveXDomListTemp[counter] = activeXTemp;
-                    if(mxActiveXBin.is())
-                    {
-                        xActiveXBinListTemp[counter] = mxActiveXBin;
-                    }
-                    counter++;
-                    resolveFastSubStream(rStream, OOXMLStream::ACTIVEX);
-                }
-                bFound = false;
-            }
-        }
-        xActiveXDomListTemp.realloc(counter);
-        xActiveXBinListTemp.realloc(counter);
-        mxActiveXDomList = xActiveXDomListTemp;
-        mxActiveXBinList = xActiveXBinListTemp;
-    }
+    if (!aEmbeddings.empty())
+        mxEmbeddingsList = comphelper::containerToSequence(aEmbeddings);
 }
 
 uno::Reference<xml::dom::XDocument> OOXMLDocumentImpl::getGlossaryDocDom( )
@@ -947,16 +884,6 @@ uno::Sequence<uno::Reference<xml::dom::XDocument> > OOXMLDocumentImpl::getCustom
     return mxCustomXmlDomPropsList;
 }
 
-uno::Sequence<uno::Reference<xml::dom::XDocument> > OOXMLDocumentImpl::getActiveXDomList( )
-{
-    return mxActiveXDomList;
-}
-
-uno::Sequence<uno::Reference<io::XInputStream> > OOXMLDocumentImpl::getActiveXBinList( )
-{
-    return mxActiveXBinList;
-}
-
 uno::Sequence<beans::PropertyValue > OOXMLDocumentImpl::getEmbeddingsList( )
 {
     return mxEmbeddingsList;
