@@ -51,19 +51,19 @@ using namespace com::sun::star;
 
 using com::sun::star::uno::Reference;
 
-static const SvXMLEnumMapEntry aXMLAxisDimensionMap[] =
+static const SvXMLEnumMapEntry<SchXMLAxisDimension> aXMLAxisDimensionMap[] =
 {
     { XML_X,  SCH_XML_AXIS_X  },
     { XML_Y,  SCH_XML_AXIS_Y  },
     { XML_Z,  SCH_XML_AXIS_Z  },
-    { XML_TOKEN_INVALID, 0 }
+    { XML_TOKEN_INVALID, (SchXMLAxisDimension)0 }
 };
 
-static const SvXMLEnumMapEntry aXMLAxisTypeMap[] =
+static const SvXMLEnumMapEntry<sal_uInt16> aXMLAxisTypeMap[] =
 {
-    { XML_AUTO,  ::com::sun::star::chart::ChartAxisType::AUTOMATIC },
-    { XML_TEXT,  ::com::sun::star::chart::ChartAxisType::CATEGORY },
-    { XML_DATE,  ::com::sun::star::chart::ChartAxisType::DATE },
+    { XML_AUTO,  css::chart::ChartAxisType::AUTOMATIC },
+    { XML_TEXT,  css::chart::ChartAxisType::CATEGORY },
+    { XML_DATE,  css::chart::ChartAxisType::DATE },
     { XML_TOKEN_INVALID, 0 }
 };
 
@@ -77,8 +77,7 @@ public:
                                    sal_uInt16 nPrefix,
                                    const OUString& rLocalName,
                                    OUString& rAddress );
-    virtual ~SchXMLCategoriesContext();
-    virtual void StartElement( const Reference< ::com::sun::star::xml::sax::XAttributeList >& xAttrList ) override;
+    virtual void StartElement( const Reference< css::xml::sax::XAttributeList >& xAttrList ) override;
 };
 
 class DateScaleContext : public SvXMLImportContext
@@ -88,8 +87,7 @@ public:
                         sal_uInt16 nPrefix, const OUString& rLocalName,
                         const Reference< beans::XPropertySet >& rAxisProps );
 
-    virtual ~DateScaleContext();
-    virtual void StartElement( const Reference< ::com::sun::star::xml::sax::XAttributeList >& xAttrList ) override;
+    virtual void StartElement( const Reference< css::xml::sax::XAttributeList >& xAttrList ) override;
 
 private:
     Reference< beans::XPropertySet > m_xAxisProps;
@@ -97,7 +95,7 @@ private:
 
 SchXMLAxisContext::SchXMLAxisContext( SchXMLImportHelper& rImpHelper,
                                       SvXMLImport& rImport, const OUString& rLocalName,
-                                      Reference< chart::XDiagram > xDiagram,
+                                      Reference< chart::XDiagram > const & xDiagram,
                                       std::vector< SchXMLAxis >& rAxes,
                                       OUString & rCategoriesAddress,
                                       bool bAddMissingXAxisForNetCharts,
@@ -168,7 +166,7 @@ Reference< drawing::XShape > SchXMLAxisContext::getTitleShape()
             SAL_INFO("xmloff.chart", "Invalid axis" );
             break;
     }
-    xDiaProp->setPropertyValue( aPropName, uno::makeAny(sal_True) );
+    xDiaProp->setPropertyValue( aPropName, uno::makeAny(true) );
     xResult.set( xAxis->getAxisTitle(), uno::UNO_QUERY );
     return xResult;
 }
@@ -205,7 +203,7 @@ void SchXMLAxisContext::CreateGrid( const OUString& sAutoStyleName, bool bIsMajo
             SAL_INFO("xmloff.chart", "Invalid axis" );
             break;
     }
-    xDiaProp->setPropertyValue( aPropName, uno::makeAny(sal_True) );
+    xDiaProp->setPropertyValue( aPropName, uno::makeAny(true) );
 
     Reference< beans::XPropertySet > xGridProp;
     if( bIsMajor )
@@ -219,18 +217,8 @@ void SchXMLAxisContext::CreateGrid( const OUString& sAutoStyleName, bool bIsMajo
         // the line color is black as default, in the model it is a light gray
         xGridProp->setPropertyValue("LineColor",
                                      uno::makeAny( COL_BLACK ));
-        if( !sAutoStyleName.isEmpty())
-        {
-            const SvXMLStylesContext* pStylesCtxt = m_rImportHelper.GetAutoStylesContext();
-            if( pStylesCtxt )
-            {
-                const SvXMLStyleContext* pStyle = pStylesCtxt->FindStyleChildContext(
-                    SchXMLImportHelper::GetChartFamilyID(), sAutoStyleName );
-
-                if( pStyle && dynamic_cast<const XMLPropStyleContext*>( pStyle) !=  nullptr)
-                    const_cast<XMLPropStyleContext*>( static_cast< const XMLPropStyleContext* >( pStyle ))->FillPropertySet( xGridProp );
-            }
-        }
+        if (!sAutoStyleName.isEmpty())
+            m_rImportHelper.FillAutoStyle(sAutoStyleName, xGridProp);
     }
 }
 
@@ -283,9 +271,9 @@ void SchXMLAxisContext::StartElement( const Reference< xml::sax::XAttributeList
         {
             case XML_TOK_AXIS_DIMENSION:
                 {
-                    sal_uInt16 nEnumVal;
+                    SchXMLAxisDimension nEnumVal;
                     if( SvXMLUnitConverter::convertEnum( nEnumVal, aValue, aXMLAxisDimensionMap ))
-                        m_aCurrentAxis.eDimension = ( SchXMLAxisDimension )nEnumVal;
+                        m_aCurrentAxis.eDimension = nEnumVal;
                 }
                 break;
             case XML_TOK_AXIS_NAME:
@@ -361,7 +349,7 @@ bool lcl_divideBy100( uno::Any& rDoubleAny )
     if( (rDoubleAny>>=fValue) && (fValue!=0.0) )
     {
         fValue/=100.0;
-        rDoubleAny = uno::makeAny(fValue);
+        rDoubleAny <<= fValue;
         bChanged = true;
     }
     return bChanged;
@@ -412,7 +400,7 @@ void SchXMLAxisContext::CreateAxis()
     }
     try
     {
-        xDiaProp->setPropertyValue( aPropName, uno::makeAny(sal_True) );
+        xDiaProp->setPropertyValue( aPropName, uno::makeAny(true) );
     }
     catch( beans::UnknownPropertyException & )
     {
@@ -439,7 +427,7 @@ void SchXMLAxisContext::CreateAxis()
     {
         try
         {
-            xDiaProp->setPropertyValue("HasXAxis", uno::makeAny(sal_True) );
+            xDiaProp->setPropertyValue("HasXAxis", uno::makeAny(true) );
         }
         catch( beans::UnknownPropertyException & )
         {
@@ -450,8 +438,8 @@ void SchXMLAxisContext::CreateAxis()
     // set properties
     if( m_xAxisProps.is())
     {
-        uno::Any aTrueBool( uno::makeAny( sal_True ));
-        uno::Any aFalseBool( uno::makeAny( sal_False ));
+        uno::Any aTrueBool( uno::makeAny( true ));
+        uno::Any aFalseBool( uno::makeAny( false ));
 
         // #i109879# the line color is black as default, in the model it is a light gray
         m_xAxisProps->setPropertyValue("LineColor",
@@ -462,7 +450,7 @@ void SchXMLAxisContext::CreateAxis()
         // Compatibility option: starting from LibreOffice 5.1 the rotated
         // layout is preferred to staggering for axis labels.
         // So the import default value for having compatibility with ODF
-        // documents created with erlier LibreOffice versions is `true`.
+        // documents created with earlier LibreOffice versions is `true`.
         if( GetImport().getGeneratorVersion() != SvXMLImport::ProductVersionUnknown )
             m_xAxisProps->setPropertyValue("TryStaggeringFirst", aTrueBool );
 
@@ -475,17 +463,13 @@ void SchXMLAxisContext::CreateAxis()
         if( !m_aAutoStyleName.isEmpty())
         {
             const SvXMLStylesContext* pStylesCtxt = m_rImportHelper.GetAutoStylesContext();
-            if( pStylesCtxt )
+            if (pStylesCtxt)
             {
-                const SvXMLStyleContext* pStyle = pStylesCtxt->FindStyleChildContext(
-                    SchXMLImportHelper::GetChartFamilyID(), m_aAutoStyleName );
+                SvXMLStyleContext* pStyle = const_cast<SvXMLStyleContext*>(pStylesCtxt->FindStyleChildContext(SchXMLImportHelper::GetChartFamilyID(), m_aAutoStyleName));
 
-                if( pStyle && dynamic_cast<const XMLPropStyleContext*>( pStyle) !=  nullptr)
+                if (XMLPropStyleContext * pPropStyleContext = dynamic_cast<XMLPropStyleContext*>(pStyle))
                 {
-                    // note: SvXMLStyleContext::FillPropertySet is not const
-                    XMLPropStyleContext * pPropStyleContext = const_cast< XMLPropStyleContext * >( dynamic_cast< const XMLPropStyleContext * >( pStyle ));
-                    if( pPropStyleContext )
-                        pPropStyleContext->FillPropertySet( m_xAxisProps );
+                    pPropStyleContext->FillPropertySet(m_xAxisProps);
 
                     if( m_bAdaptWrongPercentScaleValues && m_aCurrentAxis.eDimension==SCH_XML_AXIS_Y )
                     {
@@ -508,7 +492,7 @@ void SchXMLAxisContext::CreateAxis()
                         if( xAxisSuppl.is() )
                         {
                             Reference< beans::XPropertySet > xXAxisProp( xAxisSuppl->getAxis(0), uno::UNO_QUERY );
-                            const_cast<XMLPropStyleContext*>( static_cast< const XMLPropStyleContext* >( pStyle ))->FillPropertySet( xXAxisProp );
+                            pPropStyleContext->FillPropertySet(xXAxisProp);
                         }
 
                         //set scale data of added x axis back to default
@@ -629,7 +613,7 @@ public:
 struct theAxisChildTokenMap : public rtl::Static< AxisChildTokenMap, theAxisChildTokenMap > {};
 }
 
-SvXMLImportContext* SchXMLAxisContext::CreateChildContext(
+SvXMLImportContextRef SchXMLAxisContext::CreateChildContext(
     sal_uInt16 p_nPrefix,
     const OUString& rLocalName,
     const Reference< xml::sax::XAttributeList >& xAttrList )
@@ -740,8 +724,8 @@ void SchXMLAxisContext::CorrectAxisPositions( const Reference< chart2::XChartDoc
                           const OUString& rODFVersionOfFile,
                           bool bAxisPositionAttributeImported )
 {
-    if( ( rODFVersionOfFile.isEmpty() || rODFVersionOfFile == "1.0" || rODFVersionOfFile == "1.1"
-        || ( rODFVersionOfFile == "1.2" && !bAxisPositionAttributeImported ) ) )
+    if( rODFVersionOfFile.isEmpty() || rODFVersionOfFile == "1.0" || rODFVersionOfFile == "1.1"
+        || ( rODFVersionOfFile == "1.2" && !bAxisPositionAttributeImported ) )
     {
         try
         {
@@ -769,7 +753,7 @@ void SchXMLAxisContext::CorrectAxisPositions( const Reference< chart2::XChartDoc
                         if( rChartTypeServiceName == "com.sun.star.chart2.ScatterChartType" )
                         {
                             xMainYAxisProp->setPropertyValue("CrossoverPosition"
-                                    , uno::makeAny( ::com::sun::star::chart::ChartAxisPosition_VALUE) );
+                                    , uno::makeAny( css::chart::ChartAxisPosition_VALUE) );
                             double fCrossoverValue = 0.0;
                             aMainXScale.Origin >>= fCrossoverValue;
                             xMainYAxisProp->setPropertyValue("CrossoverValue"
@@ -778,22 +762,22 @@ void SchXMLAxisContext::CorrectAxisPositions( const Reference< chart2::XChartDoc
                             if( aMainXScale.Orientation == chart2::AxisOrientation_REVERSE )
                             {
                                 xMainYAxisProp->setPropertyValue("LabelPosition"
-                                    , uno::makeAny( ::com::sun::star::chart::ChartAxisLabelPosition_OUTSIDE_END) );
+                                    , uno::makeAny( css::chart::ChartAxisLabelPosition_OUTSIDE_END) );
                                 xMainYAxisProp->setPropertyValue("MarkPosition"
-                                    , uno::makeAny( ::com::sun::star::chart::ChartAxisMarkPosition_AT_LABELS) );
+                                    , uno::makeAny( css::chart::ChartAxisMarkPosition_AT_LABELS) );
                                 if( xSecondaryYAxisProp.is() )
                                     xSecondaryYAxisProp->setPropertyValue("CrossoverPosition"
-                                    , uno::makeAny( ::com::sun::star::chart::ChartAxisPosition_START) );
+                                    , uno::makeAny( css::chart::ChartAxisPosition_START) );
                             }
                             else
                             {
                                 xMainYAxisProp->setPropertyValue("LabelPosition"
-                                    , uno::makeAny( ::com::sun::star::chart::ChartAxisLabelPosition_OUTSIDE_START) );
+                                    , uno::makeAny( css::chart::ChartAxisLabelPosition_OUTSIDE_START) );
                                 xMainYAxisProp->setPropertyValue("MarkPosition"
-                                    , uno::makeAny( ::com::sun::star::chart::ChartAxisMarkPosition_AT_LABELS) );
+                                    , uno::makeAny( css::chart::ChartAxisMarkPosition_AT_LABELS) );
                                 if( xSecondaryYAxisProp.is() )
                                     xSecondaryYAxisProp->setPropertyValue("CrossoverPosition"
-                                    , uno::makeAny( ::com::sun::star::chart::ChartAxisPosition_END) );
+                                    , uno::makeAny( css::chart::ChartAxisPosition_END) );
                             }
                         }
                         else
@@ -801,24 +785,24 @@ void SchXMLAxisContext::CorrectAxisPositions( const Reference< chart2::XChartDoc
                             if( aMainXScale.Orientation == chart2::AxisOrientation_REVERSE )
                             {
                                 xMainYAxisProp->setPropertyValue("CrossoverPosition"
-                                    , uno::makeAny( ::com::sun::star::chart::ChartAxisPosition_END) );
+                                    , uno::makeAny( css::chart::ChartAxisPosition_END) );
                                 if( xSecondaryYAxisProp.is() )
                                     xSecondaryYAxisProp->setPropertyValue("CrossoverPosition"
-                                        , uno::makeAny( ::com::sun::star::chart::ChartAxisPosition_START) );
+                                        , uno::makeAny( css::chart::ChartAxisPosition_START) );
                             }
                             else
                             {
                                 xMainYAxisProp->setPropertyValue("CrossoverPosition"
-                                    , uno::makeAny( ::com::sun::star::chart::ChartAxisPosition_START) );
+                                    , uno::makeAny( css::chart::ChartAxisPosition_START) );
                                 if( xSecondaryYAxisProp.is() )
                                     xSecondaryYAxisProp->setPropertyValue("CrossoverPosition"
-                                        , uno::makeAny( ::com::sun::star::chart::ChartAxisPosition_END) );
+                                        , uno::makeAny( css::chart::ChartAxisPosition_END) );
                             }
                         }
 
                         chart2::ScaleData aMainYScale = xMainYAxis->getScaleData();
                         xMainXAxisProp->setPropertyValue("CrossoverPosition"
-                                , uno::makeAny( ::com::sun::star::chart::ChartAxisPosition_VALUE) );
+                                , uno::makeAny( css::chart::ChartAxisPosition_VALUE) );
                         double fCrossoverValue = 0.0;
                         aMainYScale.Origin >>= fCrossoverValue;
                         xMainXAxisProp->setPropertyValue("CrossoverValue"
@@ -827,22 +811,22 @@ void SchXMLAxisContext::CorrectAxisPositions( const Reference< chart2::XChartDoc
                         if( aMainYScale.Orientation == chart2::AxisOrientation_REVERSE )
                         {
                             xMainXAxisProp->setPropertyValue("LabelPosition"
-                                , uno::makeAny( ::com::sun::star::chart::ChartAxisLabelPosition_OUTSIDE_END) );
+                                , uno::makeAny( css::chart::ChartAxisLabelPosition_OUTSIDE_END) );
                             xMainXAxisProp->setPropertyValue("MarkPosition"
-                                , uno::makeAny( ::com::sun::star::chart::ChartAxisMarkPosition_AT_LABELS) );
+                                , uno::makeAny( css::chart::ChartAxisMarkPosition_AT_LABELS) );
                             if( xSecondaryXAxisProp.is() )
                                 xSecondaryXAxisProp->setPropertyValue("CrossoverPosition"
-                                , uno::makeAny( ::com::sun::star::chart::ChartAxisPosition_START) );
+                                , uno::makeAny( css::chart::ChartAxisPosition_START) );
                         }
                         else
                         {
                             xMainXAxisProp->setPropertyValue("LabelPosition"
-                                , uno::makeAny( ::com::sun::star::chart::ChartAxisLabelPosition_OUTSIDE_START) );
+                                , uno::makeAny( css::chart::ChartAxisLabelPosition_OUTSIDE_START) );
                             xMainXAxisProp->setPropertyValue("MarkPosition"
-                                , uno::makeAny( ::com::sun::star::chart::ChartAxisMarkPosition_AT_LABELS) );
+                                , uno::makeAny( css::chart::ChartAxisMarkPosition_AT_LABELS) );
                             if( xSecondaryXAxisProp.is() )
                                 xSecondaryXAxisProp->setPropertyValue("CrossoverPosition"
-                                , uno::makeAny( ::com::sun::star::chart::ChartAxisPosition_END) );
+                                , uno::makeAny( css::chart::ChartAxisPosition_END) );
                         }
                     }
                 }
@@ -864,10 +848,6 @@ SchXMLCategoriesContext::SchXMLCategoriesContext(
 {
 }
 
-SchXMLCategoriesContext::~SchXMLCategoriesContext()
-{
-}
-
 void SchXMLCategoriesContext::StartElement( const Reference< xml::sax::XAttributeList >& xAttrList )
 {
     sal_Int16 nAttrCount = xAttrList.is()? xAttrList->getLength(): 0;
@@ -881,7 +861,6 @@ void SchXMLCategoriesContext::StartElement( const Reference< xml::sax::XAttribut
         if( nPrefix == XML_NAMESPACE_TABLE &&
             IsXMLToken( aLocalName, XML_CELL_RANGE_ADDRESS ) )
         {
-            Reference< chart2::XChartDocument > xNewDoc( GetImport().GetModel(), uno::UNO_QUERY );
             mrAddress = xAttrList->getValueByIndex( i );
         }
     }
@@ -897,10 +876,6 @@ DateScaleContext::DateScaleContext(
 {
 }
 
-DateScaleContext::~DateScaleContext()
-{
-}
-
 namespace
 {
 enum DateScaleAttributeTokens
@@ -933,13 +908,13 @@ struct theDateScaleAttributeTokenMap : public rtl::Static< DateScaleAttributeTok
 
 sal_Int32 lcl_getTimeUnit( const OUString& rValue )
 {
-    sal_Int32 nTimeUnit = ::com::sun::star::chart::TimeUnit::DAY;
+    sal_Int32 nTimeUnit = css::chart::TimeUnit::DAY;
     if( IsXMLToken( rValue, XML_DAYS ) )
-        nTimeUnit = ::com::sun::star::chart::TimeUnit::DAY;
+        nTimeUnit = css::chart::TimeUnit::DAY;
     else if( IsXMLToken( rValue, XML_MONTHS ) )
-        nTimeUnit = ::com::sun::star::chart::TimeUnit::MONTH;
+        nTimeUnit = css::chart::TimeUnit::MONTH;
     else if( IsXMLToken( rValue, XML_YEARS ) )
-        nTimeUnit = ::com::sun::star::chart::TimeUnit::YEAR;
+        nTimeUnit = css::chart::TimeUnit::YEAR;
     return nTimeUnit;
 }
 
@@ -969,7 +944,7 @@ void DateScaleContext::StartElement( const Reference< xml::sax::XAttributeList >
         {
             case XML_TOK_DATESCALE_BASE_TIME_UNIT:
                 {
-                    aIncrement.TimeResolution = uno::makeAny( lcl_getTimeUnit(aValue) );
+                    aIncrement.TimeResolution <<= lcl_getTimeUnit(aValue);
                     bSetNewIncrement = true;
                 }
                 break;
@@ -978,7 +953,7 @@ void DateScaleContext::StartElement( const Reference< xml::sax::XAttributeList >
                     chart::TimeInterval aInterval(1,0);
                     aIncrement.MajorTimeInterval >>= aInterval;
                     ::sax::Converter::convertNumber( aInterval.Number, aValue );
-                    aIncrement.MajorTimeInterval = uno::makeAny(aInterval);
+                    aIncrement.MajorTimeInterval <<= aInterval;
                     bSetNewIncrement = true;
                 }
                 break;
@@ -987,7 +962,7 @@ void DateScaleContext::StartElement( const Reference< xml::sax::XAttributeList >
                     chart::TimeInterval aInterval(1,0);
                     aIncrement.MajorTimeInterval >>= aInterval;
                     aInterval.TimeUnit = lcl_getTimeUnit(aValue);
-                    aIncrement.MajorTimeInterval = uno::makeAny(aInterval);
+                    aIncrement.MajorTimeInterval <<= aInterval;
                     bSetNewIncrement = true;
                 }
                 break;
@@ -996,7 +971,7 @@ void DateScaleContext::StartElement( const Reference< xml::sax::XAttributeList >
                     chart::TimeInterval aInterval(1,0);
                     aIncrement.MinorTimeInterval >>= aInterval;
                     ::sax::Converter::convertNumber( aInterval.Number, aValue );
-                    aIncrement.MinorTimeInterval = uno::makeAny(aInterval);
+                    aIncrement.MinorTimeInterval <<= aInterval;
                     bSetNewIncrement = true;
                 }
                 break;
@@ -1005,7 +980,7 @@ void DateScaleContext::StartElement( const Reference< xml::sax::XAttributeList >
                     chart::TimeInterval aInterval(1,0);
                     aIncrement.MinorTimeInterval >>= aInterval;
                     aInterval.TimeUnit = lcl_getTimeUnit(aValue);
-                    aIncrement.MinorTimeInterval = uno::makeAny(aInterval);
+                    aIncrement.MinorTimeInterval <<= aInterval;
                     bSetNewIncrement = true;
                 }
                 break;
