@@ -44,7 +44,8 @@
 #include <com/sun/star/document/NamedPropertyValues.hpp>
 #include <rtl/ustrbuf.hxx>
 #include <osl/diagnose.h>
-#include <xmlenums.hxx>
+#include <unotools/configmgr.hxx>
+#include "xmlenums.hxx"
 
 using namespace com::sun::star;
 using namespace ::xmloff::token;
@@ -54,12 +55,12 @@ class XMLMyList
     std::list<beans::PropertyValue> aProps;
     sal_uInt32                      nCount;
 
-    ::com::sun::star::uno::Reference< ::com::sun::star::uno::XComponentContext > m_xContext;
+    css::uno::Reference< css::uno::XComponentContext > m_xContext;
 
 public:
     explicit XMLMyList(const uno::Reference<uno::XComponentContext>& rxContext);
 
-    void push_back(beans::PropertyValue& aProp) { aProps.push_back(aProp); nCount++; }
+    void push_back(beans::PropertyValue const & aProp) { aProps.push_back(aProp); nCount++; }
     uno::Sequence<beans::PropertyValue> GetSequence();
     uno::Reference<container::XNameContainer> GetNameContainer();
     uno::Reference<container::XIndexContainer> GetIndexContainer();
@@ -124,13 +125,12 @@ class XMLConfigBaseContext : public SvXMLImportContext
 protected:
     XMLMyList                   maProps;
     beans::PropertyValue        maProp;
-    com::sun::star::uno::Any&   mrAny;
+    css::uno::Any&              mrAny;
     XMLConfigBaseContext*       mpBaseContext;
 public:
     XMLConfigBaseContext(SvXMLImport& rImport, sal_uInt16 nPrfx, const OUString& rLName,
-                                    com::sun::star::uno::Any& rAny,
+                                    css::uno::Any& rAny,
                                     XMLConfigBaseContext* pBaseContext);
-    virtual ~XMLConfigBaseContext();
 
     void AddPropertyValue() { maProps.push_back(maProp); }
 };
@@ -140,23 +140,20 @@ class XMLConfigItemContext : public SvXMLImportContext
     OUString               msType;
     OUString               msValue;
     uno::Sequence<sal_Int8>     maDecoded;
-    com::sun::star::uno::Any&   mrAny;
+    css::uno::Any&         mrAny;
     const OUString         mrItemName;
-    XMLConfigBaseContext*       mpBaseContext;
+    XMLConfigBaseContext*  mpBaseContext;
 
 public:
     XMLConfigItemContext(SvXMLImport& rImport, sal_uInt16 nPrfx, const OUString& rLName,
-                                    const ::com::sun::star::uno::Reference<
-                                    ::com::sun::star::xml::sax::XAttributeList>& xAttrList,
-                                    com::sun::star::uno::Any& rAny,
+                                    const css::uno::Reference< css::xml::sax::XAttributeList>& xAttrList,
+                                    css::uno::Any& rAny,
                                     const OUString& rItemName,
                                     XMLConfigBaseContext* pBaseContext);
-    virtual ~XMLConfigItemContext();
 
-    virtual SvXMLImportContext *CreateChildContext( sal_uInt16 nPrefix,
+    virtual SvXMLImportContextRef CreateChildContext( sal_uInt16 nPrefix,
                                                     const OUString& rLocalName,
-                                                    const ::com::sun::star::uno::Reference<
-                                          ::com::sun::star::xml::sax::XAttributeList>& xAttrList ) override;
+                                                    const css::uno::Reference< css::xml::sax::XAttributeList>& xAttrList ) override;
     virtual void Characters( const OUString& rChars ) override;
 
     virtual void EndElement() override;
@@ -168,16 +165,13 @@ class XMLConfigItemSetContext : public XMLConfigBaseContext
 {
 public:
     XMLConfigItemSetContext(SvXMLImport& rImport, sal_uInt16 nPrfx, const OUString& rLName,
-                                    const ::com::sun::star::uno::Reference<
-                                    ::com::sun::star::xml::sax::XAttributeList>& xAttrList,
-                                    com::sun::star::uno::Any& rAny,
+                                    const css::uno::Reference< css::xml::sax::XAttributeList>& xAttrList,
+                                    css::uno::Any& rAny,
                                     XMLConfigBaseContext* pBaseContext);
-    virtual ~XMLConfigItemSetContext();
 
-    virtual SvXMLImportContext *CreateChildContext( sal_uInt16 nPrefix,
+    virtual SvXMLImportContextRef CreateChildContext( sal_uInt16 nPrefix,
                                                     const OUString& rLocalName,
-                                                    const ::com::sun::star::uno::Reference<
-                                          ::com::sun::star::xml::sax::XAttributeList>& xAttrList ) override;
+                                                    const css::uno::Reference< css::xml::sax::XAttributeList>& xAttrList ) override;
 
     virtual void EndElement() override;
 };
@@ -186,16 +180,13 @@ class XMLConfigItemMapNamedContext : public XMLConfigBaseContext
 {
 public:
     XMLConfigItemMapNamedContext(SvXMLImport& rImport, sal_uInt16 nPrfx, const OUString& rLName,
-                                    const ::com::sun::star::uno::Reference<
-                                    ::com::sun::star::xml::sax::XAttributeList>& xAttrList,
-                                    com::sun::star::uno::Any& rAny,
+                                    const css::uno::Reference< css::xml::sax::XAttributeList>& xAttrList,
+                                    css::uno::Any& rAny,
                                     XMLConfigBaseContext* pBaseContext);
-    virtual ~XMLConfigItemMapNamedContext();
 
-    virtual SvXMLImportContext *CreateChildContext( sal_uInt16 nPrefix,
+    virtual SvXMLImportContextRef CreateChildContext( sal_uInt16 nPrefix,
                                                     const OUString& rLocalName,
-                                                    const ::com::sun::star::uno::Reference<
-                                          ::com::sun::star::xml::sax::XAttributeList>& xAttrList ) override;
+                                                    const css::uno::Reference< css::xml::sax::XAttributeList>& xAttrList ) override;
 
     virtual void EndElement() override;
 };
@@ -208,17 +199,14 @@ private:
 public:
     XMLConfigItemMapIndexedContext(SvXMLImport& rImport, sal_uInt16 nPrfx,
                                     const OUString& rLName,
-                                    const ::com::sun::star::uno::Reference<
-                                    ::com::sun::star::xml::sax::XAttributeList>& xAttrList,
-                                    com::sun::star::uno::Any& rAny,
+                                    const css::uno::Reference< css::xml::sax::XAttributeList>& xAttrList,
+                                    css::uno::Any& rAny,
                                     const OUString& rConfigItemName,
                                     XMLConfigBaseContext* pBaseContext);
-    virtual ~XMLConfigItemMapIndexedContext();
 
-    virtual SvXMLImportContext *CreateChildContext( sal_uInt16 nPrefix,
+    virtual SvXMLImportContextRef CreateChildContext( sal_uInt16 nPrefix,
                                                     const OUString& rLocalName,
-                                                    const ::com::sun::star::uno::Reference<
-                                        ::com::sun::star::xml::sax::XAttributeList>& xAttrList ) override;
+                                                    const css::uno::Reference< css::xml::sax::XAttributeList>& xAttrList ) override;
 
     virtual void EndElement() override;
 };
@@ -283,8 +271,8 @@ namespace
 
 struct XMLDocumentSettingsContext_Data
 {
-    com::sun::star::uno::Any        aViewProps;
-    com::sun::star::uno::Any        aConfigProps;
+    css::uno::Any                   aViewProps;
+    css::uno::Any                   aConfigProps;
     ::std::list< SettingsGroup >    aDocSpecificSettings;
 };
 
@@ -300,10 +288,9 @@ XMLDocumentSettingsContext::~XMLDocumentSettingsContext()
 {
 }
 
-SvXMLImportContext *XMLDocumentSettingsContext::CreateChildContext( sal_uInt16 p_nPrefix,
+SvXMLImportContextRef XMLDocumentSettingsContext::CreateChildContext( sal_uInt16 p_nPrefix,
                                      const OUString& rLocalName,
-                                     const ::com::sun::star::uno::Reference<
-                                          ::com::sun::star::xml::sax::XAttributeList>& xAttrList )
+                                     const css::uno::Reference< css::xml::sax::XAttributeList>& xAttrList )
 {
     SvXMLImportContext *pContext = nullptr;
     OUString sName;
@@ -346,7 +333,7 @@ SvXMLImportContext *XMLDocumentSettingsContext::CreateChildContext( sal_uInt16 p
                                         m_pData->aConfigProps, nullptr);
                 else
                 {
-                    m_pData->aDocSpecificSettings.push_back( SettingsGroup( aLocalConfigName, uno::Any() ) );
+                    m_pData->aDocSpecificSettings.emplace_back( aLocalConfigName, uno::Any() );
 
                     ::std::list< SettingsGroup >::reverse_iterator settingsPos =
                         m_pData->aDocSpecificSettings.rbegin();
@@ -394,7 +381,7 @@ void XMLDocumentSettingsContext::EndElement()
     uno::Sequence<beans::PropertyValue> aSeqConfigProps;
     if ( m_pData->aConfigProps >>= aSeqConfigProps )
     {
-        if (!officecfg::Office::Common::Save::Document::LoadPrinter::get())
+        if (!utl::ConfigManager::IsFuzzing() && !officecfg::Office::Common::Save::Document::LoadPrinter::get())
         {
             sal_Int32 i = aSeqConfigProps.getLength() - 1;
             int nFound = 0;
@@ -405,13 +392,13 @@ void XMLDocumentSettingsContext::EndElement()
 
                 if ( sProp == "PrinterName" )
                 {
-                    aSeqConfigProps[i].Value = uno::makeAny( OUString() );
+                    aSeqConfigProps[i].Value <<= OUString();
                     nFound++;
                 }
                 else if ( sProp == "PrinterSetup" )
                 {
                     uno::Sequence< sal_Int8 > aEmpty;
-                    aSeqConfigProps[i].Value = uno::makeAny( aEmpty );
+                    aSeqConfigProps[i].Value <<= aEmpty;
                     nFound++;
                 }
 
@@ -434,7 +421,7 @@ void XMLDocumentSettingsContext::EndElement()
 }
 
 XMLConfigBaseContext::XMLConfigBaseContext(SvXMLImport& rImport, sal_uInt16 nPrfx,
-        const OUString& rLName, com::sun::star::uno::Any& rTempAny,
+        const OUString& rLName, css::uno::Any& rTempAny,
         XMLConfigBaseContext* pTempBaseContext)
     : SvXMLImportContext( rImport, nPrfx, rLName ),
     maProps( rImport.GetComponentContext() ),
@@ -444,29 +431,19 @@ XMLConfigBaseContext::XMLConfigBaseContext(SvXMLImport& rImport, sal_uInt16 nPrf
 {
 }
 
-XMLConfigBaseContext::~XMLConfigBaseContext()
-{
-}
-
 XMLConfigItemSetContext::XMLConfigItemSetContext(SvXMLImport& rImport, sal_uInt16 nPrfx,
                                     const OUString& rLName,
-                                    const ::com::sun::star::uno::Reference<
-                                    ::com::sun::star::xml::sax::XAttributeList>&,
-                                    com::sun::star::uno::Any& rAny,
+                                    const css::uno::Reference< css::xml::sax::XAttributeList>&,
+                                    css::uno::Any& rAny,
                                     XMLConfigBaseContext* pBaseContext)
     : XMLConfigBaseContext( rImport, nPrfx, rLName, rAny, pBaseContext )
 {
     // here are no attributes
 }
 
-XMLConfigItemSetContext::~XMLConfigItemSetContext()
-{
-}
-
-SvXMLImportContext *XMLConfigItemSetContext::CreateChildContext( sal_uInt16 nPrefix,
+SvXMLImportContextRef XMLConfigItemSetContext::CreateChildContext( sal_uInt16 nPrefix,
                                      const OUString& rLocalName,
-                                     const ::com::sun::star::uno::Reference<
-                                          ::com::sun::star::xml::sax::XAttributeList>& xAttrList )
+                                     const css::uno::Reference< css::xml::sax::XAttributeList>& xAttrList )
 {
     return CreateSettingsContext(GetImport(), nPrefix, rLocalName, xAttrList, maProp, this);
 }
@@ -479,9 +456,8 @@ void XMLConfigItemSetContext::EndElement()
 }
 
 XMLConfigItemContext::XMLConfigItemContext(SvXMLImport& rImport, sal_uInt16 nPrfx, const OUString& rLName,
-                                    const ::com::sun::star::uno::Reference<
-                                    ::com::sun::star::xml::sax::XAttributeList>& xAttrList,
-                                    com::sun::star::uno::Any& rTempAny,
+                                    const css::uno::Reference< css::xml::sax::XAttributeList>& xAttrList,
+                                    css::uno::Any& rTempAny,
                                     const OUString& rTempItemName,
                                     XMLConfigBaseContext* pTempBaseContext)
     : SvXMLImportContext(rImport, nPrfx, rLName),
@@ -506,14 +482,9 @@ XMLConfigItemContext::XMLConfigItemContext(SvXMLImport& rImport, sal_uInt16 nPrf
     }
 }
 
-XMLConfigItemContext::~XMLConfigItemContext()
-{
-}
-
-SvXMLImportContext *XMLConfigItemContext::CreateChildContext( sal_uInt16 nPrefix,
+SvXMLImportContextRef XMLConfigItemContext::CreateChildContext( sal_uInt16 nPrefix,
                                                     const OUString& rLocalName,
-                                                    const ::com::sun::star::uno::Reference<
-                                          ::com::sun::star::xml::sax::XAttributeList>& )
+                                                    const css::uno::Reference< css::xml::sax::XAttributeList>& )
 {
     SvXMLImportContext* pContext = new SvXMLImportContext(GetImport(), nPrefix, rLocalName);
     return pContext;
@@ -538,7 +509,7 @@ void XMLConfigItemContext::Characters( const OUString& rChars )
                 sChars = sTrimmedChars;
             }
             uno::Sequence<sal_Int8> aBuffer((sChars.getLength() / 4) * 3 );
-			sal_Int32 const nCharsDecoded =
+            sal_Int32 const nCharsDecoded =
                 ::sax::Converter::decodeBase64SomeChars( aBuffer, sChars );
             sal_uInt32 nStartPos(maDecoded.getLength());
             sal_uInt32 nCount(aBuffer.getLength());
@@ -569,19 +540,19 @@ void XMLConfigItemContext::EndElement()
         else if (IsXMLToken(msType, XML_BYTE))
         {
             sal_Int32 nValue(0);
-			::sax::Converter::convertNumber(nValue, msValue);
+            ::sax::Converter::convertNumber(nValue, msValue);
             mrAny <<= static_cast<sal_Int8>(nValue);
         }
         else if (IsXMLToken(msType, XML_SHORT))
         {
             sal_Int32 nValue(0);
-			::sax::Converter::convertNumber(nValue, msValue);
+            ::sax::Converter::convertNumber(nValue, msValue);
             mrAny <<= static_cast<sal_Int16>(nValue);
         }
         else if (IsXMLToken(msType, XML_INT))
         {
             sal_Int32 nValue(0);
-			::sax::Converter::convertNumber(nValue, msValue);
+            ::sax::Converter::convertNumber(nValue, msValue);
             mrAny <<= nValue;
         }
         else if (IsXMLToken(msType, XML_LONG))
@@ -592,7 +563,7 @@ void XMLConfigItemContext::EndElement()
         else if (IsXMLToken(msType, XML_DOUBLE))
         {
             double fValue(0.0);
-			::sax::Converter::convertDouble(fValue, msValue);
+            ::sax::Converter::convertDouble(fValue, msValue);
             mrAny <<= fValue;
         }
         else if (IsXMLToken(msType, XML_STRING))
@@ -602,7 +573,7 @@ void XMLConfigItemContext::EndElement()
         else if (IsXMLToken(msType, XML_DATETIME))
         {
             util::DateTime aDateTime;
-            ::sax::Converter::parseDateTime(aDateTime, nullptr, msValue);
+            ::sax::Converter::parseDateTime(aDateTime, msValue);
             mrAny <<= aDateTime;
         }
         else if (IsXMLToken(msType, XML_BASE64BINARY))
@@ -657,7 +628,7 @@ void XMLConfigItemContext::ManipulateConfigItem()
 
             OUString aURL;
             mrAny >>= aURL;
-            aURL = xStringSubsitution->substituteVariables( aURL, sal_False );
+            aURL = xStringSubsitution->substituteVariables( aURL, false );
             mrAny <<= aURL;
         }
         catch( uno::Exception& )
@@ -667,22 +638,16 @@ void XMLConfigItemContext::ManipulateConfigItem()
 }
 
 XMLConfigItemMapNamedContext::XMLConfigItemMapNamedContext(SvXMLImport& rImport, sal_uInt16 nPrfx, const OUString& rLName,
-                                    const ::com::sun::star::uno::Reference<
-                                    ::com::sun::star::xml::sax::XAttributeList>&,
-                                    com::sun::star::uno::Any& rAny,
+                                    const css::uno::Reference< css::xml::sax::XAttributeList>&,
+                                    css::uno::Any& rAny,
                                     XMLConfigBaseContext* pBaseContext)
     : XMLConfigBaseContext(rImport, nPrfx, rLName, rAny, pBaseContext)
 {
 }
 
-XMLConfigItemMapNamedContext::~XMLConfigItemMapNamedContext()
-{
-}
-
-SvXMLImportContext *XMLConfigItemMapNamedContext::CreateChildContext( sal_uInt16 nPrefix,
+SvXMLImportContextRef XMLConfigItemMapNamedContext::CreateChildContext( sal_uInt16 nPrefix,
                                                     const OUString& rLocalName,
-                                                    const ::com::sun::star::uno::Reference<
-                                          ::com::sun::star::xml::sax::XAttributeList>& xAttrList )
+                                                    const css::uno::Reference< css::xml::sax::XAttributeList>& xAttrList )
 {
     return CreateSettingsContext(GetImport(), nPrefix, rLocalName, xAttrList, maProp, this);
 }
@@ -701,9 +666,8 @@ void XMLConfigItemMapNamedContext::EndElement()
 
 XMLConfigItemMapIndexedContext::XMLConfigItemMapIndexedContext(SvXMLImport& rImport, sal_uInt16 nPrfx,
                                     const OUString& rLName,
-                                    const ::com::sun::star::uno::Reference<
-                                    ::com::sun::star::xml::sax::XAttributeList>&,
-                                    com::sun::star::uno::Any& rAny,
+                                    const css::uno::Reference< css::xml::sax::XAttributeList>&,
+                                    css::uno::Any& rAny,
                                     const OUString& rConfigItemName,
                                     XMLConfigBaseContext* pBaseContext)
     : XMLConfigBaseContext(rImport, nPrfx, rLName, rAny, pBaseContext),
@@ -711,14 +675,9 @@ XMLConfigItemMapIndexedContext::XMLConfigItemMapIndexedContext(SvXMLImport& rImp
 {
 }
 
-XMLConfigItemMapIndexedContext::~XMLConfigItemMapIndexedContext()
-{
-}
-
-SvXMLImportContext *XMLConfigItemMapIndexedContext::CreateChildContext( sal_uInt16 nPrefix,
+SvXMLImportContextRef XMLConfigItemMapIndexedContext::CreateChildContext( sal_uInt16 nPrefix,
                                                     const OUString& rLocalName,
-                                                    const ::com::sun::star::uno::Reference<
-                                        ::com::sun::star::xml::sax::XAttributeList>& xAttrList )
+                                                    const css::uno::Reference< css::xml::sax::XAttributeList>& xAttrList )
 {
     return CreateSettingsContext(GetImport(), nPrefix, rLocalName, xAttrList, maProp, this);
 }
@@ -803,7 +762,7 @@ void XMLConfigItemMapIndexedContext::EndElement()
                             catch (uno::Exception const& e)
                             {
                                 SAL_WARN("xmloff.core",
-                                    "Exception while importing forbidden characters: " << e.Message);
+                                    "Exception while importing forbidden characters: " << e);
                             }
                         }
                     }
