@@ -18,16 +18,14 @@
  */
 
 
-#include "DomBuilderContext.hxx"
+#include <DomBuilderContext.hxx>
 
 #include <xmloff/nmspmap.hxx>
 #include <xmloff/xmlimp.hxx>
 #include <xmloff/xmlerror.hxx>
 
-#include <com/sun/star/lang/XMultiServiceFactory.hpp>
 #include <com/sun/star/uno/Reference.hxx>
 #include <com/sun/star/uno/Sequence.hxx>
-#include <com/sun/star/xml/dom/XAttr.hpp>
 #include <com/sun/star/xml/dom/DocumentBuilder.hpp>
 #include <com/sun/star/xml/dom/XNode.hpp>
 #include <com/sun/star/xml/dom/XElement.hpp>
@@ -35,19 +33,16 @@
 #include <com/sun/star/xml/dom/NodeType.hpp>
 
 #include <rtl/ustring.hxx>
-#include <tools/debug.hxx>
 
 #include <comphelper/processfactory.hxx>
 
 
-using com::sun::star::lang::XMultiServiceFactory;
 using com::sun::star::uno::XComponentContext;
 using com::sun::star::uno::Reference;
 using com::sun::star::uno::Sequence;
 using com::sun::star::uno::UNO_QUERY;
 using com::sun::star::uno::UNO_QUERY_THROW;
 using com::sun::star::xml::dom::DocumentBuilder;
-using com::sun::star::xml::dom::XAttr;
 using com::sun::star::xml::dom::XDocument;
 using com::sun::star::xml::dom::XDocumentBuilder;
 using com::sun::star::xml::dom::XNode;
@@ -61,7 +56,7 @@ static Reference<XNode> lcl_createDomInstance();
 static Reference<XNode> lcl_createElement( SvXMLImport& rImport,
                                     sal_uInt16 nPrefix,
                                     const OUString& rLocalName,
-                                    Reference<XNode> xParent);
+                                    const Reference<XNode>& xParent);
 
 
 DomBuilderContext::DomBuilderContext( SvXMLImport& rImport,
@@ -71,21 +66,21 @@ DomBuilderContext::DomBuilderContext( SvXMLImport& rImport,
     mxNode( lcl_createElement( rImport, nPrefix, rLocalName,
                                lcl_createDomInstance() ) )
 {
-    DBG_ASSERT( mxNode.is(), "empty XNode not allowed" );
-    DBG_ASSERT( Reference<XElement>( mxNode, UNO_QUERY ).is(), "need element" );
-    DBG_ASSERT( mxNode->getNodeType() == NodeType_ELEMENT_NODE, "need element" );
+    SAL_WARN_IF( !mxNode.is(), "xmloff", "empty XNode not allowed" );
+    SAL_WARN_IF( !Reference<XElement>( mxNode, UNO_QUERY ).is(), "xmloff", "need element" );
+    SAL_WARN_IF( mxNode->getNodeType() != NodeType_ELEMENT_NODE, "xmloff", "need element" );
 }
 
 DomBuilderContext::DomBuilderContext( SvXMLImport& rImport,
                                       sal_uInt16 nPrefix,
                                       const OUString& rLocalName,
-                                      Reference<XNode>& xParent ) :
+                                      Reference<XNode> const & xParent ) :
     SvXMLImportContext( rImport, nPrefix, rLocalName ),
     mxNode( lcl_createElement( rImport, nPrefix, rLocalName, xParent ) )
 {
-    DBG_ASSERT( mxNode.is(), "empty XNode not allowed" );
-    DBG_ASSERT( Reference<XElement>( mxNode, UNO_QUERY ).is(), "need element" );
-    DBG_ASSERT( mxNode->getNodeType() == NodeType_ELEMENT_NODE, "need element" );
+    SAL_WARN_IF( !mxNode.is(), "xmloff", "empty XNode not allowed" );
+    SAL_WARN_IF( !Reference<XElement>( mxNode, UNO_QUERY ).is(), "xmloff", "need element" );
+    SAL_WARN_IF( mxNode->getNodeType() != NodeType_ELEMENT_NODE, "xmloff", "need element" );
 }
 
 DomBuilderContext::~DomBuilderContext()
@@ -94,11 +89,11 @@ DomBuilderContext::~DomBuilderContext()
 
 Reference<XDocument> DomBuilderContext::getTree()
 {
-    DBG_ASSERT( mxNode.is(), "empty XNode not allowed" );
+    SAL_WARN_IF( !mxNode.is(), "xmloff", "empty XNode not allowed" );
     return mxNode->getOwnerDocument();
 }
 
-SvXMLImportContext* DomBuilderContext::CreateChildContext(
+SvXMLImportContextRef DomBuilderContext::CreateChildContext(
     sal_uInt16 nPrefix,
     const OUString& rLocalName,
     const Reference<XAttributeList>& )
@@ -111,8 +106,8 @@ SvXMLImportContext* DomBuilderContext::CreateChildContext(
 void DomBuilderContext::StartElement(
     const Reference<XAttributeList>& xAttrList )
 {
-    DBG_ASSERT( mxNode.is(), "empty XNode not allowed" );
-    DBG_ASSERT( mxNode->getOwnerDocument().is(), "XNode must have XDocument" );
+    SAL_WARN_IF( !mxNode.is(), "xmloff", "empty XNode not allowed" );
+    SAL_WARN_IF( !mxNode->getOwnerDocument().is(), "xmloff", "XNode must have XDocument" );
 
     // add attribute nodes to new node
     sal_Int16 nAttributeCount = xAttrList->getLength();
@@ -125,7 +120,7 @@ void DomBuilderContext::StartElement(
         // namespace handling: determine namespace & namespace key
         OUString sNamespace;
         sal_uInt16 nNamespaceKey =
-            GetImport().GetNamespaceMap()._GetKeyByAttrName(
+            GetImport().GetNamespaceMap().GetKeyByAttrName_(
                 rName, nullptr, nullptr, &sNamespace );
 
         // create attribute node and set value
@@ -165,10 +160,10 @@ void DomBuilderContext::EndElement()
 
 void DomBuilderContext::Characters( const OUString& rCharacters )
 {
-    DBG_ASSERT( mxNode.is(), "empty XNode not allowed" );
+    SAL_WARN_IF( !mxNode.is(), "xmloff", "empty XNode not allowed" );
 
     // TODO: I assume adjacent text nodes should be joined, to preserve
-    // processinf model? (I.e., if the SAX parser breaks a string into 2
+    // processing model? (I.e., if the SAX parser breaks a string into 2
     // Characters(..) calls, the DOM model would still see only one child.)
 
     // create text node and append to parent
@@ -179,14 +174,13 @@ void DomBuilderContext::Characters( const OUString& rCharacters )
 }
 
 
-
 // helper function implementations
 
 
 static Reference<XNode> lcl_createDomInstance()
 {
     Reference<XComponentContext> xContext = comphelper::getProcessComponentContext();
-    DBG_ASSERT( xContext.is(), "can't get service factory" );
+    SAL_WARN_IF( !xContext.is(), "xmloff", "can't get service factory" );
 
     Reference<XDocumentBuilder> xBuilder( DocumentBuilder::create(xContext) );
 
@@ -196,12 +190,12 @@ static Reference<XNode> lcl_createDomInstance()
 static Reference<XNode> lcl_createElement( SvXMLImport& rImport,
                                     sal_uInt16 nPrefix,
                                     const OUString& rLocalName,
-                                    Reference<XNode> xParent)
+                                    const Reference<XNode>& xParent)
 {
-    DBG_ASSERT( xParent.is(), "need parent node" );
+    SAL_WARN_IF( !xParent.is(), "xmloff", "need parent node" );
 
     Reference<XDocument> xDocument = xParent->getOwnerDocument();
-    DBG_ASSERT( xDocument.is(), "no XDocument found!" );
+    SAL_WARN_IF( !xDocument.is(), "xmloff", "no XDocument found!" );
 
     // TODO: come up with proper way of handling namespaces; re-creating the
     // namespace from the key is NOT a good idea, and will not work for
@@ -234,7 +228,7 @@ static Reference<XNode> lcl_createElement( SvXMLImport& rImport,
             rImport.GetNamespaceMap().GetQNameByKey( nPrefix, rLocalName ) );
         break;
     }
-    DBG_ASSERT( xElement.is(), "can't create element" );
+    SAL_WARN_IF( !xElement.is(), "xmloff", "can't create element" );
 
     // add new element to parent and return
     xParent->appendChild( xElement );
