@@ -17,8 +17,7 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include <tools/debug.hxx>
-#include <XMLNumberStylesExport.hxx>
+#include "XMLNumberStylesExport.hxx"
 #include <XMLNumberStylesImport.hxx>
 #include <xmloff/xmlnmspe.hxx>
 #include <xmloff/xmlimp.hxx>
@@ -38,7 +37,7 @@ struct SdXMLDataStyleNumber
     bool    mbDecimal02;
     const char* mpText;
 }
-    aSdXMLDataStyleNumbers[] =
+const aSdXMLDataStyleNumbers[] =
 {
     { XML_DAY,          false,      false,      false,      nullptr },
     { XML_DAY,          true,       false,      false,      nullptr },
@@ -286,7 +285,7 @@ const SdXMLFixedDataStyle aSdXML_TimeStyle_7 =
     }
 };
 
-const SdXMLFixedDataStyle* aSdXMLFixedDateFormats[SdXMLDateFormatCount] =
+const SdXMLFixedDataStyle* const aSdXMLFixedDateFormats[SdXMLDateFormatCount] =
 {
     &aSdXML_Standard_Short,
     &aSdXML_Standard_Long,
@@ -298,7 +297,7 @@ const SdXMLFixedDataStyle* aSdXMLFixedDateFormats[SdXMLDateFormatCount] =
     &aSdXML_DateStyle_6,
 };
 
-const SdXMLFixedDataStyle* aSdXMLFixedTimeFormats[SdXMLTimeFormatCount] =
+const SdXMLFixedDataStyle* const aSdXMLFixedTimeFormats[SdXMLTimeFormatCount] =
 {
     &aSdXML_TimeStyle_1,
     &aSdXML_TimeStyle_2,
@@ -311,7 +310,7 @@ const SdXMLFixedDataStyle* aSdXMLFixedTimeFormats[SdXMLTimeFormatCount] =
 
 // export
 
-static void SdXMLExportDataStyleNumber( SdXMLExport& rExport, SdXMLDataStyleNumber& rElement )
+static void SdXMLExportDataStyleNumber( SdXMLExport& rExport, SdXMLDataStyleNumber const & rElement )
 {
     if( rElement.mbDecimal02 )
     {
@@ -361,13 +360,13 @@ static void SdXMLExportStyle( SdXMLExport& rExport, const SdXMLFixedDataStyle* p
 
         while( *pElements )
         {
-            SdXMLDataStyleNumber& rElement = aSdXMLDataStyleNumbers[ (*pElements++) - 1 ];
+            SdXMLDataStyleNumber const & rElement = aSdXMLDataStyleNumbers[ (*pElements++) - 1 ];
             SdXMLExportDataStyleNumber( rExport, rElement );
         }
 
         if( pStyle2 )
         {
-            SdXMLDataStyleNumber& rElement = aSdXMLDataStyleNumbers[ DATA_STYLE_NUMBER_TEXT_SPACE - 1 ];
+            SdXMLDataStyleNumber const & rElement = aSdXMLDataStyleNumbers[ DATA_STYLE_NUMBER_TEXT_SPACE - 1 ];
             SdXMLExportDataStyleNumber( rExport, rElement );
         }
 
@@ -485,7 +484,7 @@ private:
     bool mbTextual;
     bool mbDecimal02;
     OUString maText;
-    std::shared_ptr< SvXMLImportContext > mpSlaveContext;
+    SvXMLImportContextRef mxSlaveContext;
 
 public:
 
@@ -494,10 +493,9 @@ public:
         const OUString& rLocalName,
         const css::uno::Reference< css::xml::sax::XAttributeList>& xAttrList,
         SdXMLNumberFormatImportContext* pParent,
-        SvXMLImportContext* pSlaveContext );
-    virtual ~SdXMLNumberFormatMemberImportContext() override;
+        const SvXMLImportContextRef& rSlaveContext );
 
-    virtual SvXMLImportContext *CreateChildContext( sal_uInt16 nPrefix,
+    virtual SvXMLImportContextRef CreateChildContext( sal_uInt16 nPrefix,
                                    const OUString& rLocalName,
                                    const css::uno::Reference< css::xml::sax::XAttributeList >& xAttrList ) override;
 
@@ -509,11 +507,11 @@ public:
 };
 
 
-SdXMLNumberFormatMemberImportContext::SdXMLNumberFormatMemberImportContext( SvXMLImport& rImport, sal_uInt16 nPrfx, const OUString& rLocalName, const css::uno::Reference< css::xml::sax::XAttributeList>& xAttrList, SdXMLNumberFormatImportContext* pParent, SvXMLImportContext* pSlaveContext )
+SdXMLNumberFormatMemberImportContext::SdXMLNumberFormatMemberImportContext( SvXMLImport& rImport, sal_uInt16 nPrfx, const OUString& rLocalName, const css::uno::Reference< css::xml::sax::XAttributeList>& xAttrList, SdXMLNumberFormatImportContext* pParent, const SvXMLImportContextRef& rSlaveContext )
 :   SvXMLImportContext(rImport, nPrfx, rLocalName),
     mpParent( pParent ),
     maNumberStyle( rLocalName ),
-    mpSlaveContext( pSlaveContext )
+    mxSlaveContext( rSlaveContext )
 {
     mbLong = false;
     mbTextual = false;
@@ -546,25 +544,21 @@ SdXMLNumberFormatMemberImportContext::SdXMLNumberFormatMemberImportContext( SvXM
 
 }
 
-SdXMLNumberFormatMemberImportContext::~SdXMLNumberFormatMemberImportContext()
-{
-}
-
-SvXMLImportContext *SdXMLNumberFormatMemberImportContext::CreateChildContext( sal_uInt16 nPrefix,
+SvXMLImportContextRef SdXMLNumberFormatMemberImportContext::CreateChildContext( sal_uInt16 nPrefix,
                            const OUString& rLocalName,
                            const css::uno::Reference< css::xml::sax::XAttributeList >& xAttrList )
 {
-    return mpSlaveContext->CreateChildContext( nPrefix, rLocalName, xAttrList );
+    return mxSlaveContext->CreateChildContext( nPrefix, rLocalName, xAttrList );
 }
 
 void SdXMLNumberFormatMemberImportContext::StartElement( const css::uno::Reference< css::xml::sax::XAttributeList >& xAttrList )
 {
-    mpSlaveContext->StartElement( xAttrList );
+    mxSlaveContext->StartElement( xAttrList );
 }
 
 void SdXMLNumberFormatMemberImportContext::EndElement()
 {
-    mpSlaveContext->EndElement();
+    mxSlaveContext->EndElement();
 
     if( mpParent )
         mpParent->add( maNumberStyle, mbLong, mbTextual, mbDecimal02, maText );
@@ -572,7 +566,7 @@ void SdXMLNumberFormatMemberImportContext::EndElement()
 
 void SdXMLNumberFormatMemberImportContext::Characters( const OUString& rChars )
 {
-    mpSlaveContext->Characters( rChars );
+    mxSlaveContext->Characters( rChars );
     maText += rChars;
 }
 
@@ -607,23 +601,20 @@ SdXMLNumberFormatImportContext::~SdXMLNumberFormatImportContext()
 {
 }
 
-void SdXMLNumberFormatImportContext::add( OUString& rNumberStyle, bool bLong, bool bTextual, bool   bDecimal02, OUString& rText )
+void SdXMLNumberFormatImportContext::add( OUString const & rNumberStyle, bool bLong, bool bTextual, bool bDecimal02, OUString const & rText )
 {
-    if( mnIndex == -1 || mnIndex == 16 )
-    {
-        mnIndex = -1;
+    if (mnIndex == 16)
         return;
-    }
 
     const SdXMLDataStyleNumber* pStyleMember = aSdXMLDataStyleNumbers;
     for( sal_uInt8 nIndex = 0; pStyleMember->meNumberStyle != XML_TOKEN_INVALID; nIndex++, pStyleMember++ )
     {
-        if( (IsXMLToken(rNumberStyle, pStyleMember->meNumberStyle) &&
+        if( IsXMLToken(rNumberStyle, pStyleMember->meNumberStyle) &&
             (pStyleMember->mbLong == bLong) &&
             (pStyleMember->mbTextual == bTextual) &&
             (pStyleMember->mbDecimal02 == bDecimal02) &&
             ( ( (pStyleMember->mpText == nullptr) && (rText.isEmpty()) ) ||
-              ( pStyleMember->mpText && (rText.equalsAscii( pStyleMember->mpText ) ) ) ) ) )
+              ( pStyleMember->mpText && (rText.equalsAscii( pStyleMember->mpText ) ) ) ) )
         {
             mnElements[mnIndex++] = nIndex + 1;
             return;
@@ -711,7 +702,7 @@ void SdXMLNumberFormatImportContext::EndElement()
     }
 }
 
-SvXMLImportContext * SdXMLNumberFormatImportContext::CreateChildContext( sal_uInt16 nPrefix, const OUString& rLocalName, const css::uno::Reference< css::xml::sax::XAttributeList>& xAttrList )
+SvXMLImportContextRef SdXMLNumberFormatImportContext::CreateChildContext( sal_uInt16 nPrefix, const OUString& rLocalName, const css::uno::Reference< css::xml::sax::XAttributeList>& xAttrList )
 {
     return new SdXMLNumberFormatMemberImportContext( GetImport(), nPrefix, rLocalName, xAttrList, this, SvXMLNumFormatContext::CreateChildContext( nPrefix, rLocalName, xAttrList ) );
 }
