@@ -33,8 +33,8 @@
 #include <xmloff/xmlnmspe.hxx>
 #include <xmloff/xmluconv.hxx>
 #include <xmloff/nmspmap.hxx>
-#include "anim.hxx"
-#include "animimp.hxx"
+#include <anim.hxx>
+#include <animimp.hxx>
 
 using namespace ::std;
 using namespace ::cppu;
@@ -48,7 +48,7 @@ using namespace ::com::sun::star::lang;
 using namespace ::com::sun::star::presentation;
 using namespace ::xmloff::token;
 
-SvXMLEnumMapEntry aXML_AnimationEffect_EnumMap[] =
+const SvXMLEnumMapEntry<XMLEffect> aXML_AnimationEffect_EnumMap[] =
 {
     { XML_NONE,         EK_none },
     { XML_FADE,         EK_fade },
@@ -67,10 +67,10 @@ SvXMLEnumMapEntry aXML_AnimationEffect_EnumMap[] =
     { XML_CHECKERBOARD, EK_checkerboard },
     { XML_ROTATE,       EK_rotate },
     { XML_STRETCH,      EK_stretch },
-    { XML_TOKEN_INVALID, 0 }
+    { XML_TOKEN_INVALID, (XMLEffect)0 }
 };
 
-SvXMLEnumMapEntry aXML_AnimationDirection_EnumMap[] =
+const SvXMLEnumMapEntry<XMLEffectDirection> aXML_AnimationDirection_EnumMap[] =
 {
     { XML_NONE,             ED_none },
     { XML_FROM_LEFT,        ED_from_left },
@@ -100,15 +100,15 @@ SvXMLEnumMapEntry aXML_AnimationDirection_EnumMap[] =
     { XML_TO_CENTER,        ED_to_center },
     { XML_CLOCKWISE,        ED_clockwise },
     { XML_COUNTER_CLOCKWISE,ED_cclockwise },
-    { XML_TOKEN_INVALID, 0 }
+    { XML_TOKEN_INVALID, (XMLEffectDirection)0 }
 };
 
-SvXMLEnumMapEntry aXML_AnimationSpeed_EnumMap[] =
+const SvXMLEnumMapEntry<AnimationSpeed> aXML_AnimationSpeed_EnumMap[] =
 {
     { XML_SLOW,     AnimationSpeed_SLOW },
     { XML_MEDIUM,   AnimationSpeed_MEDIUM },
     { XML_FAST,     AnimationSpeed_FAST },
-    { XML_TOKEN_INVALID, 0 }
+    { XML_TOKEN_INVALID, (AnimationSpeed)0 }
 };
 
 AnimationEffect ImplSdXMLgetEffect( XMLEffect eKind, XMLEffectDirection eDirection, sal_Int16 nStartScale, bool /*bIn*/ )
@@ -361,7 +361,7 @@ enum XMLActionKind
 class XMLAnimationsEffectContext : public SvXMLImportContext
 {
 public:
-    AnimImpImpl*    mpImpl;
+    std::shared_ptr<AnimImpImpl> mpImpl;
 
     XMLActionKind   meKind;
     bool        mbTextEffect;
@@ -383,12 +383,11 @@ public:
         sal_uInt16 nPrfx,
         const OUString& rLocalName,
         const Reference< XAttributeList >& xAttrList,
-        AnimImpImpl* pImpl);
-    virtual ~XMLAnimationsEffectContext();
+        const std::shared_ptr<AnimImpImpl>& pImpl);
 
     virtual void EndElement() override;
 
-    virtual SvXMLImportContext * CreateChildContext( sal_uInt16 nPrefix, const OUString& rLocalName,
+    virtual SvXMLImportContextRef CreateChildContext( sal_uInt16 nPrefix, const OUString& rLocalName,
         const Reference< XAttributeList >& xAttrList ) override;
 };
 
@@ -399,7 +398,6 @@ class XMLAnimationsSoundContext : public SvXMLImportContext
 public:
 
     XMLAnimationsSoundContext( SvXMLImport& rImport, sal_uInt16 nPrfx, const OUString& rLocalName, const Reference< XAttributeList >& xAttrList, XMLAnimationsEffectContext* pParent );
-    virtual ~XMLAnimationsSoundContext();
 };
 
 
@@ -434,12 +432,7 @@ XMLAnimationsSoundContext::XMLAnimationsSoundContext( SvXMLImport& rImport, sal_
     }
 }
 
-XMLAnimationsSoundContext::~XMLAnimationsSoundContext()
-{
-}
-
-
-XMLAnimationsEffectContext::XMLAnimationsEffectContext( SvXMLImport& rImport,  sal_uInt16 nPrfx, const OUString& rLocalName,  const Reference< XAttributeList >& xAttrList, AnimImpImpl* pImpl )
+XMLAnimationsEffectContext::XMLAnimationsEffectContext( SvXMLImport& rImport,  sal_uInt16 nPrfx, const OUString& rLocalName,  const Reference< XAttributeList >& xAttrList, const std::shared_ptr<AnimImpImpl>& pImpl )
 :   SvXMLImportContext(rImport, nPrfx, rLocalName),
     mpImpl( pImpl ),
     meKind( XMLE_SHOW ), mbTextEffect( false ),
@@ -503,15 +496,11 @@ XMLAnimationsEffectContext::XMLAnimationsEffectContext( SvXMLImport& rImport,  s
         case XML_NAMESPACE_PRESENTATION:
             if( IsXMLToken( aLocalName, XML_EFFECT ) )
             {
-                sal_uInt16 eEnum;
-                if( SvXMLUnitConverter::convertEnum( eEnum, sValue, aXML_AnimationEffect_EnumMap ) )
-                    meEffect = (XMLEffect)eEnum;
+                SvXMLUnitConverter::convertEnum( meEffect, sValue, aXML_AnimationEffect_EnumMap );
             }
             else if( IsXMLToken(aLocalName, XML_DIRECTION ) )
             {
-                sal_uInt16 eEnum;
-                if( SvXMLUnitConverter::convertEnum( eEnum, sValue, aXML_AnimationDirection_EnumMap ) )
-                    meDirection = (XMLEffectDirection)eEnum;
+                SvXMLUnitConverter::convertEnum( meDirection, sValue, aXML_AnimationDirection_EnumMap );
             }
             else if( IsXMLToken( aLocalName, XML_START_SCALE ) )
             {
@@ -521,9 +510,7 @@ XMLAnimationsEffectContext::XMLAnimationsEffectContext( SvXMLImport& rImport,  s
             }
             else if( IsXMLToken( aLocalName, XML_SPEED ) )
             {
-                sal_uInt16 eEnum;
-                if( SvXMLUnitConverter::convertEnum( eEnum, sValue, aXML_AnimationSpeed_EnumMap ) )
-                    meSpeed = (AnimationSpeed)eEnum;
+                SvXMLUnitConverter::convertEnum( meSpeed, sValue, aXML_AnimationSpeed_EnumMap );
             }
             else if( IsXMLToken( aLocalName, XML_PATH_ID ) )
             {
@@ -534,11 +521,7 @@ XMLAnimationsEffectContext::XMLAnimationsEffectContext( SvXMLImport& rImport,  s
     }
 }
 
-XMLAnimationsEffectContext::~XMLAnimationsEffectContext()
-{
-}
-
-SvXMLImportContext * XMLAnimationsEffectContext::CreateChildContext( sal_uInt16 nPrefix, const OUString& rLocalName, const Reference< XAttributeList>& xAttrList )
+SvXMLImportContextRef XMLAnimationsEffectContext::CreateChildContext( sal_uInt16 nPrefix, const OUString& rLocalName, const Reference< XAttributeList>& xAttrList )
 {
     return new XMLAnimationsSoundContext( GetImport(), nPrefix, rLocalName, xAttrList, this );
 }
@@ -550,7 +533,6 @@ void XMLAnimationsEffectContext::EndElement()
     try
     {
         rtl::Reference< XMLShapeImportHelper > xShapeImport( GetImport().GetShapeImport() );
-        Any aAny;
 
         if( !maShapeId.isEmpty() )
         {
@@ -580,16 +562,13 @@ void XMLAnimationsEffectContext::EndElement()
             {
                 if( meKind == XMLE_DIM )
                 {
-                    aAny <<= true;
-                    xSet->setPropertyValue( mpImpl->msDimPrev, aAny );
+                    xSet->setPropertyValue( mpImpl->msDimPrev, Any(true) );
 
-                    aAny <<= maDimColor;
-                    xSet->setPropertyValue( mpImpl->msDimColor, aAny );
+                    xSet->setPropertyValue( mpImpl->msDimColor, Any(maDimColor) );
                 }
                 else if( meKind == XMLE_PLAY )
                 {
-                    aAny <<= true;
-                    xSet->setPropertyValue( mpImpl->msIsAnimation, aAny );
+                    xSet->setPropertyValue( mpImpl->msIsAnimation, Any(true) );
 
                     // #i42894# speed is not supported for the old group animation fallback, so no need to set it
                     // aAny <<= meSpeed;
@@ -599,8 +578,7 @@ void XMLAnimationsEffectContext::EndElement()
                 {
                     if( meKind == XMLE_HIDE && !mbTextEffect && meEffect == EK_none )
                     {
-                        aAny <<= true;
-                        xSet->setPropertyValue( mpImpl->msDimHide, aAny );
+                        xSet->setPropertyValue( mpImpl->msDimHide, Any(true) );
                     }
                     else
                     {
@@ -622,14 +600,9 @@ void XMLAnimationsEffectContext::EndElement()
             {
                 if( xSet.is() )
                 {
-                    aAny <<= maSoundURL;
-                    xSet->setPropertyValue( mpImpl->msSound, aAny );
-
-                    aAny <<= mbPlayFull;
-                    xSet->setPropertyValue( mpImpl->msPlayFull, aAny );
-
-                    aAny <<= true;
-                    xSet->setPropertyValue( mpImpl->msSoundOn, aAny );
+                    xSet->setPropertyValue( mpImpl->msSound, Any(maSoundURL) );
+                    xSet->setPropertyValue( mpImpl->msPlayFull, Any(mbPlayFull) );
+                    xSet->setPropertyValue( mpImpl->msSoundOn, Any(true) );
                 }
                 else
                 {
@@ -646,19 +619,14 @@ void XMLAnimationsEffectContext::EndElement()
 
 
 XMLAnimationsContext::XMLAnimationsContext( SvXMLImport& rImport, sal_uInt16 nPrfx, const OUString& rLocalName,
-        const com::sun::star::uno::Reference< com::sun::star::xml::sax::XAttributeList>& )
+        const css::uno::Reference< css::xml::sax::XAttributeList>& )
 : SvXMLImportContext(rImport, nPrfx, rLocalName)
+, mpImpl(std::make_shared<AnimImpImpl>())
 {
-    mpImpl = new AnimImpImpl();
 }
 
-XMLAnimationsContext::~XMLAnimationsContext()
-{
-    delete mpImpl;
-}
-
-SvXMLImportContext * XMLAnimationsContext::CreateChildContext( sal_uInt16 nPrefix, const OUString& rLocalName,
-        const com::sun::star::uno::Reference< com::sun::star::xml::sax::XAttributeList>& xAttrList )
+SvXMLImportContextRef XMLAnimationsContext::CreateChildContext( sal_uInt16 nPrefix, const OUString& rLocalName,
+        const css::uno::Reference< css::xml::sax::XAttributeList>& xAttrList )
 {
     return new XMLAnimationsEffectContext( GetImport(), nPrefix, rLocalName,  xAttrList, mpImpl );
 }
