@@ -19,6 +19,7 @@
 
 #include "ximpbody.hxx"
 #include <xmloff/prstylei.hxx>
+#include <xmloff/xmlnmspe.hxx>
 #include "ximpnote.hxx"
 #include <com/sun/star/drawing/XDrawPage.hpp>
 #include <com/sun/star/drawing/XDrawPages.hpp>
@@ -34,17 +35,16 @@
 #include <xmloff/xmlprmap.hxx>
 #include <xmloff/families.hxx>
 #include "ximpshow.hxx"
-#include "PropertySetMerger.hxx"
-#include "animationimport.hxx"
-#include <tools/debug.hxx>
+#include <PropertySetMerger.hxx>
+#include <animationimport.hxx>
 #include <osl/diagnose.hxx>
 
 using namespace ::com::sun::star;
 
 SdXMLDrawPageContext::SdXMLDrawPageContext( SdXMLImport& rImport,
     sal_uInt16 nPrfx, const OUString& rLocalName,
-    const com::sun::star::uno::Reference< com::sun::star::xml::sax::XAttributeList>& xAttrList,
-    uno::Reference< drawing::XShapes >& rShapes)
+    const css::uno::Reference< css::xml::sax::XAttributeList>& xAttrList,
+    uno::Reference< drawing::XShapes > const & rShapes)
 :   SdXMLGenericPageContext( rImport, nPrfx, rLocalName, xAttrList, rShapes )
 ,   mbHadSMILNodes( false )
 {
@@ -65,7 +65,7 @@ SdXMLDrawPageContext::SdXMLDrawPageContext( SdXMLImport& rImport,
         {
             case XML_TOK_DRAWPAGE_NAME:
             {
-                maName = sValue;
+                maContextName = sValue;
                 break;
             }
             case XML_TOK_DRAWPAGE_STYLE_NAME:
@@ -128,13 +128,13 @@ SdXMLDrawPageContext::SdXMLDrawPageContext( SdXMLImport& rImport,
     uno::Reference< drawing::XDrawPage > xShapeDrawPage(rShapes, uno::UNO_QUERY);
 
     // set PageName?
-    if(!maName.isEmpty())
+    if(!maContextName.isEmpty())
     {
         if(xShapeDrawPage.is())
         {
             uno::Reference < container::XNamed > xNamed(xShapeDrawPage, uno::UNO_QUERY);
             if(xNamed.is())
-                xNamed->setName(maName);
+                xNamed->setName(maContextName);
         }
     }
 
@@ -143,7 +143,7 @@ SdXMLDrawPageContext::SdXMLDrawPageContext( SdXMLImport& rImport,
     {
         // #85906# Code for setting masterpage needs complete rework
         // since GetSdImport().GetMasterStylesContext() gives always ZERO
-        // because of content/style file split. Now the nechanism is to
+        // because of content/style file split. Now the mechanism is to
         // compare the wanted masterpage-name with the existing masterpages
         // which were loaded and created in the styles section loading.
         uno::Reference< drawing::XDrawPages > xMasterPages(GetSdImport().GetLocalMasterPages(), uno::UNO_QUERY);
@@ -168,7 +168,7 @@ SdXMLDrawPageContext::SdXMLDrawPageContext( SdXMLImport& rImport,
                     {
                         OUString sMasterPageName = xMasterNamed->getName();
 
-                        if(!sMasterPageName.isEmpty() && sMasterPageName.equals(sDisplayName))
+                        if(!sMasterPageName.isEmpty() && sMasterPageName == sDisplayName)
                         {
                             xDrawPage->setMasterPage(xMasterPage);
                             bDone = true;
@@ -177,7 +177,7 @@ SdXMLDrawPageContext::SdXMLDrawPageContext( SdXMLImport& rImport,
                 }
             }
 
-            DBG_ASSERT( bDone, "xmloff::SdXMLDrawPageContext::SdXMLDrawPageContext(), could not find a slide master!" );
+            SAL_WARN_IF( !bDone, "xmloff", "xmloff::SdXMLDrawPageContext::SdXMLDrawPageContext(), could not find a master slide!" );
         }
     }
 
@@ -188,7 +188,7 @@ SdXMLDrawPageContext::SdXMLDrawPageContext( SdXMLImport& rImport,
         uno::Reference< beans::XPropertySet > xProps( xShapeDrawPage, uno::UNO_QUERY );
         if( xProps.is() )
         {
-            sal_Int32 nIndex = maHREF.lastIndexOf( (sal_Unicode)'#' );
+            sal_Int32 nIndex = maHREF.lastIndexOf( '#' );
             if( nIndex != -1 )
             {
                 OUString aFileName( maHREF.copy( 0, nIndex ) );
@@ -211,11 +211,11 @@ SdXMLDrawPageContext::~SdXMLDrawPageContext()
 {
 }
 
-SvXMLImportContext *SdXMLDrawPageContext::CreateChildContext( sal_uInt16 nPrefix,
+SvXMLImportContextRef SdXMLDrawPageContext::CreateChildContext( sal_uInt16 nPrefix,
     const OUString& rLocalName,
-    const com::sun::star::uno::Reference< com::sun::star::xml::sax::XAttributeList>& xAttrList )
+    const css::uno::Reference< css::xml::sax::XAttributeList>& xAttrList )
 {
-    SvXMLImportContext *pContext = nullptr;
+    SvXMLImportContextRef xContext;
     const SvXMLTokenMap& rTokenMap = GetSdImport().GetDrawPageElemTokenMap();
 
     // some special objects inside draw:page context
@@ -236,7 +236,7 @@ SvXMLImportContext *SdXMLDrawPageContext::CreateChildContext( sal_uInt16 nPrefix
                         if(xNewShapes.is())
                         {
                             // presentation:notes inside draw:page context
-                            pContext = new SdXMLNotesContext( GetSdImport(), nPrefix, rLocalName, xAttrList, xNewShapes);
+                            xContext = new SdXMLNotesContext( GetSdImport(), nPrefix, rLocalName, xAttrList, xNewShapes);
                         }
                     }
                 }
@@ -251,7 +251,7 @@ SvXMLImportContext *SdXMLDrawPageContext::CreateChildContext( sal_uInt16 nPrefix
                 uno::Reference< animations::XAnimationNodeSupplier > xNodeSupplier(GetLocalShapesContext(), uno::UNO_QUERY);
                 if(xNodeSupplier.is())
                 {
-                    pContext = new xmloff::AnimationNodeContext( xNodeSupplier->getAnimationNode(), GetSdImport(), nPrefix, rLocalName, xAttrList );
+                    xContext = new xmloff::AnimationNodeContext( xNodeSupplier->getAnimationNode(), GetSdImport(), nPrefix, rLocalName, xAttrList );
                     mbHadSMILNodes = true;
                 }
             }
@@ -260,10 +260,10 @@ SvXMLImportContext *SdXMLDrawPageContext::CreateChildContext( sal_uInt16 nPrefix
     }
 
     // call parent when no own context was created
-    if(!pContext)
-        pContext = SdXMLGenericPageContext::CreateChildContext(nPrefix, rLocalName, xAttrList);
+    if (!xContext)
+        xContext = SdXMLGenericPageContext::CreateChildContext(nPrefix, rLocalName, xAttrList);
 
-    return pContext;
+    return xContext;
 }
 
 void SdXMLDrawPageContext::EndElement()
@@ -276,13 +276,13 @@ void SdXMLDrawPageContext::EndElement()
         uno::Reference< animations::XAnimationNodeSupplier > xNodeSupplier(GetLocalShapesContext(), uno::UNO_QUERY);
         uno::Reference< beans::XPropertySet > xPageProps( GetLocalShapesContext(), uno::UNO_QUERY );
         if(xNodeSupplier.is())
-            xmloff::AnimationNodeContext::postProcessRootNode( GetSdImport(), xNodeSupplier->getAnimationNode(), xPageProps );
+            xmloff::AnimationNodeContext::postProcessRootNode( xNodeSupplier->getAnimationNode(), xPageProps );
     }
 }
 
 SdXMLBodyContext::SdXMLBodyContext( SdXMLImport& rImport,
-    sal_uInt16 nPrfx, const OUString& rLocalName )
-:   SvXMLImportContext( rImport, nPrfx, rLocalName )
+    const OUString& rLocalName )
+:   SvXMLImportContext( rImport, XML_NAMESPACE_OFFICE, rLocalName )
 {
 }
 
@@ -290,12 +290,12 @@ SdXMLBodyContext::~SdXMLBodyContext()
 {
 }
 
-SvXMLImportContext *SdXMLBodyContext::CreateChildContext(
+SvXMLImportContextRef SdXMLBodyContext::CreateChildContext(
     sal_uInt16 nPrefix,
     const OUString& rLocalName,
     const uno::Reference< xml::sax::XAttributeList>& xAttrList )
 {
-    SvXMLImportContext *pContext = nullptr;
+    SvXMLImportContextRef xContext;
     const SvXMLTokenMap& rTokenMap = GetSdImport().GetBodyElemTokenMap();
 
     switch(rTokenMap.Get(nPrefix, rLocalName))
@@ -304,7 +304,7 @@ SvXMLImportContext *SdXMLBodyContext::CreateChildContext(
         case XML_TOK_BODY_FOOTER_DECL:
         case XML_TOK_BODY_DATE_TIME_DECL:
         {
-            pContext = new SdXMLHeaderFooterDeclContext( GetImport(), nPrefix, rLocalName, xAttrList );
+            xContext = new SdXMLHeaderFooterDeclContext( GetImport(), nPrefix, rLocalName, xAttrList );
             break;
         }
         case XML_TOK_BODY_PAGE:
@@ -340,7 +340,7 @@ SvXMLImportContext *SdXMLBodyContext::CreateChildContext(
                     if(xNewShapes.is())
                     {
                         // draw:page inside office:body context
-                        pContext = new SdXMLDrawPageContext(GetSdImport(), nPrefix, rLocalName, xAttrList,
+                        xContext = new SdXMLDrawPageContext(GetSdImport(), nPrefix, rLocalName, xAttrList,
                             xNewShapes);
                     }
                 }
@@ -349,15 +349,15 @@ SvXMLImportContext *SdXMLBodyContext::CreateChildContext(
         }
         case XML_TOK_BODY_SETTINGS:
         {
-            pContext = new SdXMLShowsContext( GetSdImport(), nPrefix, rLocalName, xAttrList );
+            xContext = new SdXMLShowsContext( GetSdImport(), nPrefix, rLocalName, xAttrList );
         }
     }
 
     // call parent when no own context was created
-    if(!pContext)
-        pContext = SvXMLImportContext::CreateChildContext(nPrefix, rLocalName, xAttrList);
+    if (!xContext)
+        xContext = SvXMLImportContext::CreateChildContext(nPrefix, rLocalName, xAttrList);
 
-    return pContext;
+    return xContext;
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
