@@ -34,7 +34,6 @@
 #include "strings.hxx"
 #include <osl/diagnose.h>
 
-#include <functional>
 #include <algorithm>
 
 namespace xmloff
@@ -71,7 +70,7 @@ namespace
             if ( xChild.is() )
                 return getTypedModelNode< TYPE >( xChild->getParent() );
             else
-                return NULL;
+                return nullptr;
         }
     }
 
@@ -80,15 +79,15 @@ namespace
         return getTypedModelNode< XModel >( _rxModelNode );
     }
 
-    struct StringCompare : public ::std::unary_function< OUString, bool >
+    struct StringCompare
     {
     private:
-        const OUString m_sReference;
+        const OUString & m_sReference;
 
     public:
         explicit StringCompare( const OUString& _rReference ) : m_sReference( _rReference ) { }
 
-        inline bool operator()( const OUString& _rCompare )
+        bool operator()( const OUString& _rCompare )
         {
             return ( _rCompare == m_sReference );
         }
@@ -113,7 +112,7 @@ bool FormCellBindingHelper::livesInSpreadsheetDocument( const Reference< XProper
     return xDocument.is();
 }
 
-bool FormCellBindingHelper::convertStringAddress( const OUString& _rAddressDescription, CellAddress& /* [out] */ _rAddress, sal_Int16 /*_nAssumeSheet*/ ) const
+bool FormCellBindingHelper::convertStringAddress( const OUString& _rAddressDescription, CellAddress& /* [out] */ _rAddress ) const
 {
     Any aAddress;
     return doConvertAddressRepresentations(
@@ -253,8 +252,8 @@ bool FormCellBindingHelper::isSpreadsheetDocumentWhichSupplies( const Reference<
                 aAvailableServices = xDocumentFactory->getAvailableServiceNames( );
 
             const OUString* pFound = ::std::find_if(
-                aAvailableServices.getConstArray(),
-                aAvailableServices.getConstArray() + aAvailableServices.getLength(),
+                aAvailableServices.begin(),
+                aAvailableServices.end(),
                 StringCompare( _rService )
             );
             if ( pFound - aAvailableServices.getConstArray() < aAvailableServices.getLength() )
