@@ -28,7 +28,7 @@
 #include <xmloff/xmlprmap.hxx>
 #include <xmloff/prstylei.hxx>
 #include <xmloff/xmlimp.hxx>
-#include "XMLEventImportHelper.hxx"
+#include <XMLEventImportHelper.hxx>
 #include <xmloff/xmlimppr.hxx>
 #include <xmloff/xmlnumfi.hxx>
 #include <com/sun/star/util/XNumberFormatsSupplier.hpp>
@@ -287,7 +287,7 @@ void OFormLayerXMLImport_Impl::registerCellValueBinding( const Reference< XPrope
 {
     OSL_ENSURE( _rxControlModel.is() && !_rCellAddress.isEmpty(),
         "OFormLayerXMLImport_Impl::registerCellValueBinding: invalid arguments!" );
-    m_aCellValueBindings.push_back( ModelStringPair( _rxControlModel, _rCellAddress ) );
+    m_aCellValueBindings.emplace_back( _rxControlModel, _rCellAddress );
 }
 
 void OFormLayerXMLImport_Impl::registerXFormsValueBinding(
@@ -297,8 +297,7 @@ void OFormLayerXMLImport_Impl::registerXFormsValueBinding(
     // TODO: is an empty binding name allowed?
     OSL_ENSURE( _rxControlModel.is(), "need  model" );
 
-    m_aXFormsValueBindings.push_back(
-        ModelStringPair( _rxControlModel, _rBindingID ) );
+    m_aXFormsValueBindings.emplace_back( _rxControlModel, _rBindingID );
 }
 
 void OFormLayerXMLImport_Impl::registerXFormsListBinding(
@@ -308,8 +307,7 @@ void OFormLayerXMLImport_Impl::registerXFormsListBinding(
     // TODO: is an empty binding name allowed?
     OSL_ENSURE( _rxControlModel.is(), "need  model" );
 
-    m_aXFormsListBindings.push_back(
-        ModelStringPair( _rxControlModel, _rBindingID ) );
+    m_aXFormsListBindings.emplace_back( _rxControlModel, _rBindingID );
 }
 
 void OFormLayerXMLImport_Impl::registerXFormsSubmission(
@@ -319,15 +317,14 @@ void OFormLayerXMLImport_Impl::registerXFormsSubmission(
     // TODO: is an empty binding name allowed?
     OSL_ENSURE( _rxControlModel.is(), "need  model" );
 
-    m_aXFormsSubmissions.push_back(
-        ModelStringPair( _rxControlModel, _rSubmissionID ) );
+    m_aXFormsSubmissions.emplace_back( _rxControlModel, _rSubmissionID );
 }
 
 void OFormLayerXMLImport_Impl::registerCellRangeListSource( const Reference< XPropertySet >& _rxControlModel, const OUString& _rCellRangeAddress )
 {
     OSL_ENSURE( _rxControlModel.is() && !_rCellRangeAddress.isEmpty(),
         "OFormLayerXMLImport_Impl::registerCellRangeListSource: invalid arguments!" );
-    m_aCellRangeListSources.push_back( ModelStringPair( _rxControlModel, _rCellRangeAddress ) );
+    m_aCellRangeListSources.emplace_back( _rxControlModel, _rCellRangeAddress );
 }
 const SvXMLStyleContext* OFormLayerXMLImport_Impl::getStyleElement(const OUString& _rStyleName) const
 {
@@ -367,7 +364,7 @@ void OFormLayerXMLImport_Impl::registerControlReferences(const Reference< XPrope
 {
     OSL_ENSURE(!_rReferringControls.isEmpty(), "OFormLayerXMLImport_Impl::registerControlReferences: invalid (empty) control id list!");
     OSL_ENSURE(_rxControl.is(), "OFormLayerXMLImport_Impl::registerControlReferences: invalid (NULL) control!");
-    m_aControlReferences.push_back( ModelStringPair( _rxControl, _rReferringControls ) );
+    m_aControlReferences.emplace_back( _rxControl, _rReferringControls );
 }
 
 void OFormLayerXMLImport_Impl::startPage(const Reference< XDrawPage >& _rxDrawPage)
@@ -382,8 +379,7 @@ void OFormLayerXMLImport_Impl::startPage(const Reference< XDrawPage >& _rxDrawPa
 
     // add a new entry to our page map
     ::std::pair< MapDrawPage2Map::iterator, bool > aPagePosition;
-    aPagePosition =
-        m_aControlIds.insert(MapDrawPage2Map::value_type(_rxDrawPage, MapString2PropertySet()));
+    aPagePosition = m_aControlIds.emplace(_rxDrawPage, MapString2PropertySet());
     OSL_ENSURE(aPagePosition.second, "OFormLayerXMLImport_Impl::startPage: already imported this page!");
     m_aCurrentPageIds = aPagePosition.first;
 }
@@ -478,9 +474,8 @@ SvXMLImportContext* OFormLayerXMLImport_Impl::createContext(const sal_uInt16 _nP
         if ( m_xCurrentPageFormsSupp.is() )
             pContext = new OFormImport(*this, *this, _nPrefix, _rLocalName, m_xCurrentPageFormsSupp->getForms() );
     }
-    else if (  ( _nPrefix == XML_NAMESPACE_XFORMS
-            && ( xmloff::token::IsXMLToken( _rLocalName, xmloff::token::XML_MODEL ) ) )
-            )
+    else if ( _nPrefix == XML_NAMESPACE_XFORMS
+              && xmloff::token::IsXMLToken( _rLocalName, xmloff::token::XML_MODEL ) )
     {
         pContext = createXFormsModelContext( m_rImporter, _nPrefix, _rLocalName );
     }
