@@ -18,6 +18,11 @@
  */
 
 #include "propertyexport.hxx"
+
+#include <memory>
+
+#include <o3tl/make_unique.hxx>
+
 #include <xmloff/xmlexp.hxx>
 #include "strings.hxx"
 #include <xmloff/xmlnmspe.hxx>
@@ -99,131 +104,122 @@ namespace xmloff
     void OPropertyExport::exportRemainingProperties()
     {
         // the properties tag (will be created if we have at least one no-default property)
-        SvXMLElementExport* pPropertiesTag = nullptr;
+        std::unique_ptr<SvXMLElementExport> pPropertiesTag;
 
-        try
+        Any aValue;
+        OUString sValue;
+
+        // loop through all the properties which are yet to be exported
+        for (   StringSet::const_iterator aProperty = m_aRemainingProps.begin();
+                aProperty != m_aRemainingProps.end();
+                ++aProperty
+            )
         {
-            Any aValue;
-            OUString sValue;
+            DBG_CHECK_PROPERTY_NO_TYPE(*aProperty);
 
-            // loop through all the properties which are yet to be exported
-            for (   StringSet::const_iterator aProperty = m_aRemainingProps.begin();
-                    aProperty != m_aRemainingProps.end();
-                    ++aProperty
-                )
+#if OSL_DEBUG_LEVEL > 0
+            const OUString sPropertyName = *aProperty; (void)sPropertyName;
+#endif
+            if ( !shouldExportProperty( *aProperty ) )
+                continue;
+
+            // now that we have the first sub-tag we need the form:properties element
+            if (!pPropertiesTag)
+                pPropertiesTag = o3tl::make_unique<SvXMLElementExport>(m_rContext.getGlobalContext(), XML_NAMESPACE_FORM, token::XML_PROPERTIES, true, true);
+
+            // add the name attribute
+            AddAttribute(XML_NAMESPACE_FORM, token::XML_PROPERTY_NAME, *aProperty);
+
+            // get the value
+            aValue = m_xProps->getPropertyValue(*aProperty);
+
+            // the type to export
+            Type aExportType;
+
+            // is it a sequence
+            bool bIsSequence = TypeClass_SEQUENCE == aValue.getValueTypeClass();
+            // the type of the property, maybe reduced to the element type of a sequence
+            if (bIsSequence)
+                aExportType = getSequenceElementType( aValue.getValueType() );
+            else
+                aExportType = aValue.getValueType();
+
+            // the type attribute
+
+            bool bIsEmptyValue = TypeClass_VOID == aValue.getValueType().getTypeClass();
+            if ( bIsEmptyValue )
             {
-                DBG_CHECK_PROPERTY_NO_TYPE(*aProperty);
+                css::beans::Property aPropDesc;
+                aPropDesc = m_xPropertyInfo->getPropertyByName( *aProperty );
+                aExportType = aPropDesc.Type;
+            }
+            token::XMLTokenEnum eValueType = implGetPropertyXMLType( aExportType );
 
-    #if OSL_DEBUG_LEVEL > 0
-                const OUString sPropertyName = *aProperty; (void)sPropertyName;
-    #endif
-                if ( !shouldExportProperty( *aProperty ) )
-                    continue;
+            if ( bIsEmptyValue )
+                AddAttribute( XML_NAMESPACE_OFFICE, token::XML_VALUE_TYPE, token::XML_VOID );
+            else
+                AddAttribute( XML_NAMESPACE_OFFICE, token::XML_VALUE_TYPE, eValueType );
 
-                // now that we have the first sub-tag we need the form:properties element
-                if (!pPropertiesTag)
-                    pPropertiesTag = new SvXMLElementExport(m_rContext.getGlobalContext(), XML_NAMESPACE_FORM, token::XML_PROPERTIES, true, true);
+            token::XMLTokenEnum eValueAttName( token::XML_VALUE );
+            switch ( eValueType )
+            {
+            case token::XML_BOOLEAN:    eValueAttName = token::XML_BOOLEAN_VALUE; break;
+            case token::XML_STRING:     eValueAttName = token::XML_STRING_VALUE;  break;
+            default:    break;
+            }
 
-                // add the name attribute
-                AddAttribute(XML_NAMESPACE_FORM, token::XML_PROPERTY_NAME, *aProperty);
+            if( !bIsSequence && !bIsEmptyValue )
+            {   // the simple case
 
-                // get the value
-                aValue = m_xProps->getPropertyValue(*aProperty);
+                sValue = implConvertAny(aValue);
+                AddAttribute(XML_NAMESPACE_OFFICE, eValueAttName, sValue );
+            }
 
-                // the type to export
-                Type aExportType;
+            // start the property tag
+            SvXMLElementExport aValueTag1(m_rContext.getGlobalContext(),
+                    XML_NAMESPACE_FORM,
+                    bIsSequence ? token::XML_LIST_PROPERTY
+                                : token::XML_PROPERTY, true, true);
 
-                // is it a sequence
-                bool bIsSequence = TypeClass_SEQUENCE == aValue.getValueTypeClass();
-                // the type of the property, maybe reduced to the element type of a sequence
-                if (bIsSequence)
-                    aExportType = getSequenceElementType( aValue.getValueType() );
-                else
-                    aExportType = aValue.getValueType();
+            if (!bIsSequence)
+                continue;
 
-                // the type attribute
-
-                bool bIsEmptyValue = TypeClass_VOID == aValue.getValueType().getTypeClass();
-                if ( bIsEmptyValue )
-                {
-                    com::sun::star::beans::Property aPropDesc;
-                    aPropDesc = m_xPropertyInfo->getPropertyByName( *aProperty );
-                    aExportType = aPropDesc.Type;
-                }
-                token::XMLTokenEnum eValueType = implGetPropertyXMLType( aExportType );
-
-                if ( bIsEmptyValue )
-                    AddAttribute( XML_NAMESPACE_OFFICE, token::XML_VALUE_TYPE, token::XML_VOID );
-                else
-                    AddAttribute( XML_NAMESPACE_OFFICE, token::XML_VALUE_TYPE, eValueType );
-
-                token::XMLTokenEnum eValueAttName( token::XML_VALUE );
-                switch ( eValueType )
-                {
-                case token::XML_BOOLEAN:    eValueAttName = token::XML_BOOLEAN_VALUE; break;
-                case token::XML_STRING:     eValueAttName = token::XML_STRING_VALUE;  break;
-                default:    break;
-                }
-
-                if( !bIsSequence && !bIsEmptyValue )
-                {   // the simple case
-
-                    sValue = implConvertAny(aValue);
-                    AddAttribute(XML_NAMESPACE_OFFICE, eValueAttName, sValue );
-                }
-
-                // start the property tag
-                SvXMLElementExport aValueTag1(m_rContext.getGlobalContext(),
-                        XML_NAMESPACE_FORM,
-                        bIsSequence ? token::XML_LIST_PROPERTY
-                                    : token::XML_PROPERTY, true, true);
-
-                if (!bIsSequence)
-                    continue;
-
-                // the not-that-simple case, we need to iterate through the sequence elements
-                switch ( aExportType.getTypeClass() )
-                {
-                    case TypeClass_STRING:
-                        exportRemainingPropertiesSequence< OUString >(
-                            aValue, eValueAttName);
-                        break;
-                    case TypeClass_DOUBLE:
-                        exportRemainingPropertiesSequence< double >(
-                            aValue, eValueAttName);
-                        break;
-                    case TypeClass_BOOLEAN:
-                        exportRemainingPropertiesSequence< sal_Bool >(
-                            aValue, eValueAttName);
-                        break;
-                    case TypeClass_BYTE:
-                        exportRemainingPropertiesSequence< sal_Int8 >(
-                            aValue, eValueAttName);
-                        break;
-                    case TypeClass_SHORT:
-                        exportRemainingPropertiesSequence< sal_Int16 >(
-                            aValue, eValueAttName);
-                        break;
-                    case TypeClass_LONG:
-                        exportRemainingPropertiesSequence< sal_Int32 >(
-                            aValue, eValueAttName);
-                        break;
-                    case TypeClass_HYPER:
-                        exportRemainingPropertiesSequence< sal_Int64 >(
-                            aValue, eValueAttName);
-                        break;
-                    default:
-                        OSL_FAIL("OPropertyExport::exportRemainingProperties: unsupported sequence tyoe !");
-                        break;
-                }
+            // the not-that-simple case, we need to iterate through the sequence elements
+            switch ( aExportType.getTypeClass() )
+            {
+                case TypeClass_STRING:
+                    exportRemainingPropertiesSequence< OUString >(
+                        aValue, eValueAttName);
+                    break;
+                case TypeClass_DOUBLE:
+                    exportRemainingPropertiesSequence< double >(
+                        aValue, eValueAttName);
+                    break;
+                case TypeClass_BOOLEAN:
+                    exportRemainingPropertiesSequence< sal_Bool >(
+                        aValue, eValueAttName);
+                    break;
+                case TypeClass_BYTE:
+                    exportRemainingPropertiesSequence< sal_Int8 >(
+                        aValue, eValueAttName);
+                    break;
+                case TypeClass_SHORT:
+                    exportRemainingPropertiesSequence< sal_Int16 >(
+                        aValue, eValueAttName);
+                    break;
+                case TypeClass_LONG:
+                    exportRemainingPropertiesSequence< sal_Int32 >(
+                        aValue, eValueAttName);
+                    break;
+                case TypeClass_HYPER:
+                    exportRemainingPropertiesSequence< sal_Int64 >(
+                        aValue, eValueAttName);
+                    break;
+                default:
+                    OSL_FAIL("OPropertyExport::exportRemainingProperties: unsupported sequence type !");
+                    break;
             }
         }
-        catch(...)
-        {
-            delete pPropertiesTag;
-            throw;
-        }
-        delete pPropertiesTag;
     }
 
     void OPropertyExport::examinePersistence()
@@ -268,14 +264,14 @@ namespace xmloff
     }
 
     void OPropertyExport::exportBooleanPropertyAttribute(const sal_uInt16 _nNamespaceKey, const sal_Char* _pAttributeName,
-            const OUString& _rPropertyName, const sal_Int8 _nBooleanAttributeFlags)
+            const OUString& _rPropertyName, const BoolAttrFlags _nBooleanAttributeFlags)
     {
         DBG_CHECK_PROPERTY_NO_TYPE( _rPropertyName );
         // no check of the property value type: this method is allowed to be called with any integer properties
         // (e.g. sal_Int32, sal_uInt16 etc)
 
-        bool bDefault = (BOOLATTR_DEFAULT_TRUE == (BOOLATTR_DEFAULT_MASK & _nBooleanAttributeFlags));
-        bool bDefaultVoid = (BOOLATTR_DEFAULT_VOID == (BOOLATTR_DEFAULT_MASK & _nBooleanAttributeFlags));
+        bool bDefault = (BoolAttrFlags::DefaultTrue == (BoolAttrFlags::DefaultMask & _nBooleanAttributeFlags));
+        bool bDefaultVoid = (BoolAttrFlags::DefaultVoid == (BoolAttrFlags::DefaultMask & _nBooleanAttributeFlags));
 
         // get the value
         bool bCurrentValue = bDefault;
@@ -285,7 +281,7 @@ namespace xmloff
             bCurrentValue = ::cppu::any2bool(aCurrentValue);
             // this will extract a boolean value even if the Any contains a int or short or something like that ...
 
-            if (_nBooleanAttributeFlags & BOOLATTR_INVERSE_SEMANTICS)
+            if (_nBooleanAttributeFlags & BoolAttrFlags::InverseSemantics)
                 bCurrentValue = !bCurrentValue;
 
             // we have a non-void current value
@@ -318,10 +314,7 @@ namespace xmloff
         if (force || _nDefault != nCurrentValue)
         {
             // let the formatter of the export context build a string
-            OUStringBuffer sBuffer;
-            ::sax::Converter::convertNumber(sBuffer, (sal_Int32)nCurrentValue);
-
-            AddAttribute(_nNamespaceKey, _pAttributeName, sBuffer.makeStringAndClear());
+            AddAttribute(_nNamespaceKey, _pAttributeName, OUString::number(nCurrentValue));
         }
 
         // the property does not need to be handled anymore
@@ -341,27 +334,24 @@ namespace xmloff
         if ( _nDefault != nCurrentValue )
         {
             // let the formatter of the export context build a string
-            OUStringBuffer sBuffer;
-            ::sax::Converter::convertNumber( sBuffer, nCurrentValue );
-
-            AddAttribute( _nNamespaceKey, _pAttributeName, sBuffer.makeStringAndClear() );
+            AddAttribute( _nNamespaceKey, _pAttributeName, OUString::number(nCurrentValue) );
         }
 
         // the property does not need to be handled anymore
         exportedProperty( _rPropertyName );
     }
 
-    void OPropertyExport::exportEnumPropertyAttribute(
+    void OPropertyExport::exportEnumPropertyAttributeImpl(
             const sal_uInt16 _nNamespaceKey, const sal_Char* _pAttributeName,
-            const OUString &rPropertyName, const SvXMLEnumMapEntry* _pValueMap,
-            const sal_Int32 _nDefault, const bool _bVoidDefault)
+            const OUString &rPropertyName, const SvXMLEnumMapEntry<sal_uInt16>* _pValueMap,
+            const sal_uInt16 _nDefault, const bool _bVoidDefault)
     {
         // get the value
-        sal_Int32 nCurrentValue(_nDefault);
         Any aValue = m_xProps->getPropertyValue(rPropertyName);
 
         if (aValue.hasValue())
         {   // we have a non-void current value
+            sal_Int32 nCurrentValue(_nDefault);
             ::cppu::enum2int(nCurrentValue, aValue);
 
             // add the attribute
@@ -378,7 +368,7 @@ namespace xmloff
         else
         {
             if (!_bVoidDefault)
-                AddAttributeASCII(_nNamespaceKey, _pAttributeName, "");
+                AddAttribute(_nNamespaceKey, _pAttributeName, OUString());
         }
 
         // the property does not need to be handled anymore
@@ -392,15 +382,15 @@ namespace xmloff
         OUString sTargetFrame = comphelper::getString(m_xProps->getPropertyValue(PROPERTY_TARGETFRAME));
         if( sTargetFrame != "_blank" )
         {   // an empty string and "_blank" have the same meaning and don't have to be written
-            AddAttribute(OAttributeMetaData::getCommonControlAttributeNamespace(CCA_TARGET_FRAME)
-                        ,OAttributeMetaData::getCommonControlAttributeName(CCA_TARGET_FRAME)
+            AddAttribute(OAttributeMetaData::getCommonControlAttributeNamespace(CCAFlags::TargetFrame)
+                        ,OAttributeMetaData::getCommonControlAttributeName(CCAFlags::TargetFrame)
                         ,sTargetFrame);
         }
 
         exportedProperty(PROPERTY_TARGETFRAME);
     }
 
-    void OPropertyExport::exportRelativeTargetLocation(const OUString& _sPropertyName,sal_Int32 _nProperty,bool _bAddType)
+    void OPropertyExport::exportRelativeTargetLocation(const OUString& _sPropertyName,CCAFlags _nProperty,bool _bAddType)
     {
         DBG_CHECK_PROPERTY( _sPropertyName, OUString );
 
@@ -463,7 +453,7 @@ namespace xmloff
             Property aProperty = m_xPropertyInfo->getPropertyByName(sPropertyName);
             if ((aProperty.Attributes & PropertyAttribute::MAYBEVOID) == 0)
                 // the string is empty, and the property is not allowed to be void
-                // -> don't need to write the attibute, 'cause missing it is unambiguous
+                // -> don't need to write the attribute, 'cause missing it is unambiguous
                 return;
         }
 
@@ -472,11 +462,11 @@ namespace xmloff
     }
 
     void OPropertyExport::exportStringSequenceAttribute(const sal_uInt16 _nAttributeNamespaceKey, const sal_Char* _pAttributeName,
-        const OUString& _rPropertyName,
-        const sal_Unicode _aQuoteCharacter, const sal_Unicode _aListSeparator)
+        const OUString& _rPropertyName)
     {
+        const sal_Unicode _aListSeparator = ',';
+        const sal_Unicode _aQuoteCharacter = '"';
         DBG_CHECK_PROPERTY( _rPropertyName, Sequence< OUString > );
-        OSL_ENSURE(_aListSeparator != 0, "OPropertyExport::exportStringSequenceAttribute: invalid separator character!");
 
         Sequence< OUString > aItems;
         m_xProps->getPropertyValue( _rPropertyName ) >>= aItems;
@@ -497,10 +487,8 @@ namespace xmloff
                 ++pItems
             )
         {
-            OSL_ENSURE(!_aQuoteCharacter || (-1 == pItems->indexOf(_aQuoteCharacter)),
+            OSL_ENSURE(-1 == pItems->indexOf(_aQuoteCharacter),
                 "OPropertyExport::exportStringSequenceAttribute: there is an item which contains the quote character!");
-            OSL_ENSURE(_aQuoteCharacter || (-1 == pItems->indexOf(_aListSeparator)),
-                "OPropertyExport::exportStringSequenceAttribute: no quote character, but there is an item containing the separator character!");
 
             if (bQuote)
                 sFinalList += sQuote;
@@ -542,29 +530,29 @@ namespace xmloff
             case TypeClass_SHORT:
             case TypeClass_LONG:
                 // let the unit converter format is as string
-                ::sax::Converter::convertNumber(aBuffer, getINT32(_rValue));
+                aBuffer.append(getINT32(_rValue));
                 break;
             case TypeClass_UNSIGNED_LONG:
             case TypeClass_HYPER:
-                ::sax::Converter::convertNumber(aBuffer, getINT64(_rValue));
+                aBuffer.append(getINT64(_rValue));
                 break;
             case TypeClass_UNSIGNED_HYPER:
-                ::sax::Converter::convertNumber(aBuffer, _rValue.get<sal_uInt64>());
+                aBuffer.append(OUString::number(_rValue.get<sal_uInt64>()));
                 break;
             case TypeClass_ENUM:
             {
                 // convert it into an int32
                 sal_Int32 nValue = 0;
                 ::cppu::enum2int(nValue, _rValue);
-                ::sax::Converter::convertNumber(aBuffer, nValue);
+                aBuffer.append(nValue);
             }
             break;
             default:
             {   // hmmm .... what else do we know?
                 double fValue = 0;
-                ::com::sun::star::util::Date aDate;
-                ::com::sun::star::util::Time aTime;
-                ::com::sun::star::util::DateTime aDateTime;
+                css::util::Date aDate;
+                css::util::Time aTime;
+                css::util::DateTime aDateTime;
                 if (_rValue >>= aDate)
                 {
                     Date aToolsDate( Date::EMPTY );
@@ -607,7 +595,7 @@ namespace xmloff
         return aBuffer.makeStringAndClear();
     }
 
-    token::XMLTokenEnum OPropertyExport::implGetPropertyXMLType(const ::com::sun::star::uno::Type& _rType)
+    token::XMLTokenEnum OPropertyExport::implGetPropertyXMLType(const css::uno::Type& _rType)
     {
         // handle the type description
         switch (_rType.getTypeClass())
@@ -646,14 +634,6 @@ namespace xmloff
         m_rContext.getGlobalContext().AddAttribute( _nPrefix, _rName, _rValue );
     }
 
-    void OPropertyExport::AddAttributeASCII(sal_uInt16 _nPrefix, const sal_Char* _pName, const sal_Char *pValue)
-    {
-        OSL_ENSURE(m_rContext.getGlobalContext().GetXAttrList()->getValueByName(OUString::createFromAscii(_pName)).isEmpty(),
-            "OPropertyExport::AddAttributeASCII: already have such an attribute");
-
-        m_rContext.getGlobalContext().AddAttributeASCII(_nPrefix, _pName, pValue);
-    }
-
     void OPropertyExport::AddAttribute(sal_uInt16 _nPrefix, ::xmloff::token::XMLTokenEnum _eName, const OUString& _rValue)
     {
         OSL_ENSURE(m_rContext.getGlobalContext().GetXAttrList()->getValueByName(::xmloff::token::GetXMLToken(_eName)).isEmpty(),
