@@ -22,8 +22,8 @@
 #include <com/sun/star/drawing/ColorMode.hpp>
 #include <com/sun/star/text/HorizontalAdjust.hpp>
 #include <com/sun/star/text/WritingMode2.hpp>
+#include <com/sun/star/text/VertOrientation.hpp>
 
-#include <tools/debug.hxx>
 
 #include <xmloff/xmltypes.hxx>
 #include <xmloff/xmltoken.hxx>
@@ -35,23 +35,23 @@
 #include "csmaphdl.hxx"
 #include "fonthdl.hxx"
 #include "kernihdl.hxx"
-#include <postuhdl.hxx>
+#include "postuhdl.hxx"
 #include "shadwhdl.hxx"
 #include "shdwdhdl.hxx"
 #include "undlihdl.hxx"
 #include "weighhdl.hxx"
 #include "breakhdl.hxx"
-#include <adjushdl.hxx>
-#include <escphdl.hxx>
-#include <chrhghdl.hxx>
-#include <chrlohdl.hxx>
-#include <lspachdl.hxx>
-#include <bordrhdl.hxx>
-#include <tabsthdl.hxx>
+#include "adjushdl.hxx"
+#include "escphdl.hxx"
+#include "chrhghdl.hxx"
+#include "chrlohdl.hxx"
+#include "lspachdl.hxx"
+#include "bordrhdl.hxx"
+#include "tabsthdl.hxx"
 #include <xmloff/EnumPropertyHdl.hxx>
-#include "AttributeContainerHandler.hxx"
+#include <AttributeContainerHandler.hxx>
 #include "durationhdl.hxx"
-#include "XMLRectangleMembersHandler.hxx"
+#include <XMLRectangleMembersHandler.hxx>
 #include "DrawAspectHdl.hxx"
 
 #include <map>
@@ -59,27 +59,27 @@
 using namespace ::com::sun::star;
 using namespace ::xmloff::token;
 
-static SvXMLEnumMapEntry const aXML_ColorMode_EnumMap[] =
+static SvXMLEnumMapEntry<drawing::ColorMode> const aXML_ColorMode_EnumMap[] =
 {
     { XML_GREYSCALE,    drawing::ColorMode_GREYS },
     { XML_MONO,         drawing::ColorMode_MONO },
     { XML_WATERMARK,    drawing::ColorMode_WATERMARK },
     { XML_STANDARD,     drawing::ColorMode_STANDARD },
-    { XML_TOKEN_INVALID, 0 }
+    { XML_TOKEN_INVALID, (drawing::ColorMode)0 }
 };
 
-static SvXMLEnumMapEntry const aXML_HorizontalAdjust_Enum[] =
+static SvXMLEnumMapEntry<text::HorizontalAdjust> const aXML_HorizontalAdjust_Enum[] =
 {
     { XML_LEFT,     text::HorizontalAdjust_LEFT },
     { XML_CENTER,   text::HorizontalAdjust_CENTER },
     { XML_RIGHT,    text::HorizontalAdjust_RIGHT },
-    { XML_TOKEN_INVALID, 0 }
+    { XML_TOKEN_INVALID, (text::HorizontalAdjust)0 }
 };
 
 // aXML_WritingDirection_Enum is used with and without 'page'
 // attribute, so you'll find uses of aXML_WritingDirection_Enum
 // directly, as well as &(aXML_WritingDirection_Enum[1])
-static SvXMLEnumMapEntry const aXML_WritingDirection_Enum[] =
+static SvXMLEnumMapEntry<sal_uInt16> const aXML_WritingDirection_Enum[] =
 {
     // aXML_WritingDirection_Enum
     { XML_PAGE,     text::WritingMode2::PAGE },
@@ -98,6 +98,22 @@ static SvXMLEnumMapEntry const aXML_WritingDirection_Enum[] =
     { XML_TOKEN_INVALID, 0 }
 };
 
+static SvXMLEnumMapEntry<sal_uInt16> const pXML_VertPos_Enum[] =
+{
+    { XML_FROM_TOP,         text::VertOrientation::NONE       },
+    { XML_TOP,              text::VertOrientation::TOP        },
+    { XML_TOP,              text::VertOrientation::CHAR_TOP   },  // export only
+    { XML_TOP,              text::VertOrientation::LINE_TOP   },  // export only
+    { XML_MIDDLE,           text::VertOrientation::CENTER     },
+    { XML_MIDDLE,           text::VertOrientation::CHAR_CENTER    },  // export only
+    { XML_MIDDLE,           text::VertOrientation::LINE_CENTER    },  // export only
+    { XML_BOTTOM,           text::VertOrientation::BOTTOM         },
+    { XML_BOTTOM,           text::VertOrientation::CHAR_BOTTOM    },  // export only
+    { XML_BOTTOM,           text::VertOrientation::LINE_BOTTOM    },  // export only
+    { XML_BELOW,            text::VertOrientation::CHAR_BOTTOM    },  // import only
+    { XML_TOKEN_INVALID, 0 }
+};
+
 typedef std::map<sal_Int32, const XMLPropertyHandler*> CacheMap;
 
 struct XMLPropertyHandlerFactory::Impl
@@ -117,7 +133,7 @@ XMLPropertyHandlerFactory::~XMLPropertyHandlerFactory()
 // Interface
 const XMLPropertyHandler* XMLPropertyHandlerFactory::GetPropertyHandler( sal_Int32 nType ) const
 {
-    DBG_ASSERT( (nType & ~((sal_uInt32)MID_FLAG_MASK)) == 0,
+    SAL_WARN_IF( (nType & ~((sal_uInt32)MID_FLAG_MASK)) != 0, "xmloff",
                 "GetPropertyHandler called with flags in type" );
     return GetBasicHandler( nType );
 }
@@ -184,7 +200,7 @@ const XMLPropertyHandler* XMLPropertyHandlerFactory::CreatePropertyHandler( sal_
             pPropHdl = new XMLPercentPropHdl( 2 );
             break;
         case XML_TYPE_DOUBLE_PERCENT :
-            pPropHdl = new XMLDoublePercentPropHdl();
+            pPropHdl = new XMLDoublePercentPropHdl;
             break;
         case XML_TYPE_NEG_PERCENT :
             pPropHdl = new XMLNegPercentPropHdl( 4 );
@@ -402,16 +418,13 @@ const XMLPropertyHandler* XMLPropertyHandlerFactory::CreatePropertyHandler( sal_
             pPropHdl = new XMLAttributeContainerHandler;
             break;
         case XML_TYPE_COLOR_MODE:
-            pPropHdl = new XMLEnumPropertyHdl( aXML_ColorMode_EnumMap,
-                            cppu::UnoType<drawing::ColorMode>::get());
+            pPropHdl = new XMLEnumPropertyHdl(aXML_ColorMode_EnumMap);
             break;
         case XML_TYPE_DURATION16_MS:
             pPropHdl = new XMLDurationMS16PropHdl_Impl;
             break;
         case XML_TYPE_TEXT_HORIZONTAL_ADJUST:
-            pPropHdl = new XMLEnumPropertyHdl(
-                aXML_HorizontalAdjust_Enum,
-                cppu::UnoType<text::HorizontalAdjust>::get());
+            pPropHdl = new XMLEnumPropertyHdl(aXML_HorizontalAdjust_Enum);
             break;
         case XML_TYPE_TEXT_DRAW_ASPECT:
             pPropHdl = new DrawAspectHdl;
@@ -444,8 +457,12 @@ const XMLPropertyHandler* XMLPropertyHandlerFactory::CreatePropertyHandler( sal_
             pPropHdl = new XMLNumberWithoutZeroPropHdl( 2 );
             break;
         case XML_TYPE_NUMBER16_AUTO:
-            pPropHdl = new XMLNumberWithAutoInsteadZeroPropHdl();
+            pPropHdl = new XMLNumberWithAutoInsteadZeroPropHdl;
             break;
+        case XML_TYPE_TEXT_VERTICAL_POS:
+            pPropHdl = new XMLConstantsPropertyHandler( pXML_VertPos_Enum, XML_TOKEN_INVALID );
+        break;
+
     }
 
     return pPropHdl;
