@@ -18,7 +18,7 @@
  */
 
 #include "XMLAutoTextEventExport.hxx"
-#include "facreg.hxx"
+#include <facreg.hxx>
 #include <com/sun/star/xml/sax/XDocumentHandler.hpp>
 #include <com/sun/star/util/MeasureUnit.hpp>
 #include <com/sun/star/lang/XMultiServiceFactory.hpp>
@@ -99,7 +99,7 @@ void XMLAutoTextEventExport::initialize(
 }
 
 
-sal_uInt32 XMLAutoTextEventExport::exportDoc( enum XMLTokenEnum )
+ErrCode XMLAutoTextEventExport::exportDoc( enum XMLTokenEnum )
 {
     if( !(getExportFlags() & SvXMLExportFlags::OASIS) )
     {
@@ -149,7 +149,7 @@ sal_uInt32 XMLAutoTextEventExport::exportDoc( enum XMLTokenEnum )
         GetDocHandler()->endDocument();
     }
 
-    return 0;
+    return ERRCODE_NONE;
 }
 
 bool XMLAutoTextEventExport::hasEvents()
