@@ -17,6 +17,7 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
+#include <memory>
 #include <com/sun/star/beans/XPropertySet.hpp>
 #include <com/sun/star/uno/Reference.h>
 
@@ -24,7 +25,6 @@
 #include "XMLPropertyBackpatcher.hxx"
 #include <xmloff/txtimp.hxx>
 
-using ::std::vector;
 using ::std::map;
 using ::com::sun::star::uno::Reference;
 using ::com::sun::star::uno::Any;
@@ -35,9 +35,6 @@ template<class A>
 XMLPropertyBackpatcher<A>::XMLPropertyBackpatcher(
     const OUString& sPropName)
 :   sPropertyName(sPropName)
-,   bDefaultHandling(false)
-,   bPreserveProperty(false)
-,   sPreservePropertyName()
 {
 }
 
@@ -45,7 +42,6 @@ XMLPropertyBackpatcher<A>::XMLPropertyBackpatcher(
 template<class A>
 XMLPropertyBackpatcher<A>::~XMLPropertyBackpatcher()
 {
-    SetDefault();
 }
 
 
@@ -71,28 +67,11 @@ void XMLPropertyBackpatcher<A>::ResolveId(
         //    (and preserve Property, if appropriate)
         Any aAny;
         aAny <<= aValue;
-        if (bPreserveProperty)
+        for(BackpatchListType::iterator aIter = pList->begin();
+            aIter != pList->end();
+            ++aIter)
         {
-            // preserve version
-            for(BackpatchListType::iterator aIter = pList->begin();
-                aIter != pList->end();
-                ++aIter)
-            {
-                Reference<XPropertySet> xProp = (*aIter);
-                Any aPres = xProp->getPropertyValue(sPreservePropertyName);
-                xProp->setPropertyValue(sPropertyName, aAny);
-                xProp->setPropertyValue(sPreservePropertyName, aPres);
-            }
-        }
-        else
-        {
-            // without preserve
-            for(BackpatchListType::iterator aIter = pList->begin();
-                aIter != pList->end();
-                ++aIter)
-            {
-                (*aIter)->setPropertyValue(sPropertyName, aAny);
-            }
+            (*aIter)->setPropertyValue(sPropertyName, aAny);
         }
 
         // c) delete list
@@ -118,9 +97,7 @@ void XMLPropertyBackpatcher<A>::SetProperty(
     if (aIDMap.count(sName))
     {
         // we know this ID -> set property
-        Any aAny;
-        aAny <<= aIDMap[sName];
-        xPropSet->setPropertyValue(sPropertyName, aAny);
+        xPropSet->setPropertyValue(sPropertyName, css::uno::Any(aIDMap[sName]));
     }
     else
     {
@@ -128,7 +105,7 @@ void XMLPropertyBackpatcher<A>::SetProperty(
         if (! aBackpatchListMap.count(sName))
         {
             // create backpatch list for this name
-            BackpatchListType* pTmp = new BackpatchListType() ;
+            BackpatchListType* pTmp = new BackpatchListType;
             aBackpatchListMap[sName] = static_cast<void*>(pTmp);
         }
 
@@ -137,15 +114,6 @@ void XMLPropertyBackpatcher<A>::SetProperty(
     }
 }
 
-template<class A>
-void XMLPropertyBackpatcher<A>::SetDefault()
-{
-    if (bDefaultHandling)
-    {
-        // not implemented yet
-    }
-}
-
 // force instantiation of templates
 template class XMLPropertyBackpatcher<sal_Int16>;
 template class XMLPropertyBackpatcher<OUString>;
@@ -168,7 +136,7 @@ std::shared_ptr<XMLTextImportHelper::BackpatcherImpl>
 XMLTextImportHelper::MakeBackpatcherImpl()
 {
     // n.b.: the shared_ptr stores the dtor!
-    return std::shared_ptr<BackpatcherImpl>(new BackpatcherImpl);
+    return std::make_shared<BackpatcherImpl>();
 }
 
 static OUString GetSequenceNumber()
@@ -212,11 +180,10 @@ XMLPropertyBackpatcher<sal_Int16>& XMLTextImportHelper::GetSequenceIdBP()
 
 XMLPropertyBackpatcher<OUString>& XMLTextImportHelper::GetSequenceNameBP()
 {
-    static const char s_SourceName[] = "SourceName";
     if (!m_xBackpatcherImpl->m_pSequenceNameBackpatcher.get())
     {
         m_xBackpatcherImpl->m_pSequenceNameBackpatcher.reset(
-            new XMLPropertyBackpatcher<OUString>(s_SourceName));
+            new XMLPropertyBackpatcher<OUString>("SourceName"));
     }
     return *m_xBackpatcherImpl->m_pSequenceNameBackpatcher;
 }
