@@ -17,7 +17,6 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include <tools/debug.hxx>
 #include <com/sun/star/container/XNameContainer.hpp>
 #include <com/sun/star/container/XIndexReplace.hpp>
 #include <com/sun/star/style/XStyle.hpp>
@@ -29,7 +28,7 @@
 #include <xmloff/xmltoken.hxx>
 #include "XMLTextListItemContext.hxx"
 #include "XMLTextListBlockContext.hxx"
-#include "txtlists.hxx"
+#include <txtlists.hxx>
 
 
 using namespace ::com::sun::star;
@@ -39,7 +38,6 @@ using namespace ::com::sun::star::style;
 using namespace ::com::sun::star::beans;
 using namespace ::xmloff::token;
 
-TYPEINIT1( XMLTextListBlockContext, SvXMLImportContext );
 
 // OD 2008-05-07 #refactorlists#
 // add optional parameter <bRestartNumberingAtSubList> and its handling
@@ -49,34 +47,34 @@ XMLTextListBlockContext::XMLTextListBlockContext(
         sal_uInt16 nPrfx,
         const OUString& rLName,
         const Reference< xml::sax::XAttributeList > & xAttrList,
-        const sal_Bool bRestartNumberingAtSubList )
+        const bool bRestartNumberingAtSubList )
 :   SvXMLImportContext( rImport, nPrfx, rLName )
 ,   mrTxtImport( rTxtImp )
 ,   msListStyleName()
 ,   mxParentListBlock( )
 ,   mnLevel( 0 )
-,   mbRestartNumbering( sal_False )
-,   mbSetDefaults( sal_False )
+,   mbRestartNumbering( false )
+,   mbSetDefaults( false )
 ,   msListId()
 ,   msContinueListId()
 {
-    static OUString s_PropNameDefaultListId("DefaultListId");
+    static const char s_PropNameDefaultListId[] = "DefaultListId";
     {
         // get the parent list block context (if any); this is a bit ugly...
-        XMLTextListBlockContext * pLB(0);
-        XMLTextListItemContext  * pLI(0);
-        XMLNumberedParaContext  * pNP(0);
+        XMLTextListBlockContext * pLB(nullptr);
+        XMLTextListItemContext  * pLI(nullptr);
+        XMLNumberedParaContext  * pNP(nullptr);
         rTxtImp.GetTextListHelper().ListContextTop(pLB, pLI, pNP);
         mxParentListBlock = pLB;
     }
     // Inherit style name from parent list, as well as the flags whether
     // numbering must be restarted and formats have to be created.
     OUString sParentListStyleName;
-    if( mxParentListBlock.Is() )
+    if( mxParentListBlock.is() )
     {
         XMLTextListBlockContext *pParent =
-                                (XMLTextListBlockContext *)&mxParentListBlock;
-        msListStyleName = pParent->GetListStyleName();
+                                static_cast<XMLTextListBlockContext *>(mxParentListBlock.get());
+        msListStyleName = pParent->msListStyleName;
         sParentListStyleName = msListStyleName;
         mxNumRules = pParent->GetNumRules();
         mnLevel = pParent->GetLevel() + 1;
@@ -127,6 +125,9 @@ XMLTextListBlockContext::XMLTextListBlockContext(
         }
     }
 
+    // Remember this list block.
+    mrTxtImport.GetTextListHelper().PushListContext( this );
+
     mxNumRules = XMLTextListsHelper::MakeNumRule(GetImport(), mxNumRules,
         sParentListStyleName, msListStyleName,
         mnLevel, &mbRestartNumbering, &mbSetDefaults );
@@ -150,8 +151,8 @@ XMLTextListBlockContext::XMLTextListBlockContext(
                 {
                     xNumRuleProps->getPropertyValue(s_PropNameDefaultListId)
                         >>= sListStyleDefaultListId;
-                    DBG_ASSERT( !sListStyleDefaultListId.isEmpty(),
-                                "no default list id found at numbering rules instance. Serious defect -> please inform OD." );
+                    SAL_WARN_IF( sListStyleDefaultListId.isEmpty(), "xmloff",
+                                "no default list id found at numbering rules instance. Serious defect." );
                 }
             }
         }
@@ -174,7 +175,7 @@ XMLTextListBlockContext::XMLTextListBlockContext(
                          !mbRestartNumbering &&
                          rTextListsHelper.IsListProcessed( msListId ) )
                     {
-                        mbRestartNumbering = sal_True;
+                        mbRestartNumbering = true;
                     }
                 }
             }
@@ -200,7 +201,7 @@ XMLTextListBlockContext::XMLTextListBlockContext(
         {
             if ( !rTextListsHelper.IsListProcessed( msContinueListId ) )
             {
-                msContinueListId = "";
+                msContinueListId.clear();
             }
             else
             {
@@ -226,9 +227,6 @@ XMLTextListBlockContext::XMLTextListBlockContext(
                 sListStyleDefaultListId );
         }
     }
-
-    // Remember this list block.
-    mrTxtImport.GetTextListHelper().PushListContext( this );
 }
 
 XMLTextListBlockContext::~XMLTextListBlockContext()
@@ -240,7 +238,7 @@ void XMLTextListBlockContext::EndElement()
     // Numbering has not to be restarted if it has been restarted within
     // a child list.
     XMLTextListBlockContext *pParent =
-                                (XMLTextListBlockContext *)&mxParentListBlock;
+                                static_cast<XMLTextListBlockContext *>(mxParentListBlock.get());
     if( pParent )
     {
         pParent->mbRestartNumbering = mbRestartNumbering;
@@ -251,23 +249,24 @@ void XMLTextListBlockContext::EndElement()
 
     // Any paragraph following the list within the same list item must not
     // be numbered.
-    mrTxtImport.GetTextListHelper().SetListItem( 0 );
+    mrTxtImport.GetTextListHelper().SetListItem( nullptr );
 }
 
-SvXMLImportContext *XMLTextListBlockContext::CreateChildContext(
+SvXMLImportContextRef XMLTextListBlockContext::CreateChildContext(
         sal_uInt16 nPrefix,
         const OUString& rLocalName,
         const Reference< xml::sax::XAttributeList > & xAttrList )
 {
-    SvXMLImportContext *pContext = 0;
+    SvXMLImportContext *pContext = nullptr;
 
     const SvXMLTokenMap& rTokenMap =
                         mrTxtImport.GetTextListBlockElemTokenMap();
-    sal_Bool bHeader = sal_False;
+    bool bHeader = false;
     switch( rTokenMap.Get( nPrefix, rLocalName ) )
     {
     case XML_TOK_TEXT_LIST_HEADER:
-        bHeader = sal_True;
+        bHeader = true;
+        SAL_FALLTHROUGH;
     case XML_TOK_TEXT_LIST_ITEM:
         pContext = new XMLTextListItemContext( GetImport(), mrTxtImport,
                                                 nPrefix, rLocalName,
@@ -281,14 +280,5 @@ SvXMLImportContext *XMLTextListBlockContext::CreateChildContext(
     return pContext;
 }
 
-const OUString& XMLTextListBlockContext::GetListId() const
-{
-    return msListId;
-}
-
-const OUString& XMLTextListBlockContext::GetContinueListId() const
-{
-    return msContinueListId;
-}
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
