@@ -17,6 +17,10 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
+#include <memory>
+#include <sal/config.h>
+
+#include <o3tl/any.hxx>
 #include <osl/thread.h>
 #include <com/sun/star/awt/FontFamily.hpp>
 #include <com/sun/star/awt/FontPitch.hpp>
@@ -178,11 +182,11 @@ void XMLTextImportPropertyMapper::FontFinished(
 
     #99928# CL */
 void XMLTextImportPropertyMapper::FontDefaultsCheck(
-                                        XMLPropertyState* pFontFamilyName,
-                                        XMLPropertyState* pFontStyleName,
-                                        XMLPropertyState* pFontFamily,
-                                        XMLPropertyState* pFontPitch,
-                                        XMLPropertyState* pFontCharSet,
+                                        XMLPropertyState const * pFontFamilyName,
+                                        XMLPropertyState const * pFontStyleName,
+                                        XMLPropertyState const * pFontFamily,
+                                        XMLPropertyState const * pFontPitch,
+                                        XMLPropertyState const * pFontCharSet,
                                         XMLPropertyState** ppNewFontStyleName,
                                         XMLPropertyState** ppNewFontFamily,
                                         XMLPropertyState** ppNewFontPitch,
@@ -206,7 +210,7 @@ void XMLTextImportPropertyMapper::FontDefaultsCheck(
 
         if( !pFontFamily )
         {
-            aAny <<= (sal_Int16)com::sun::star::awt::FontFamily::DONTKNOW;
+            aAny <<= (sal_Int16)css::awt::FontFamily::DONTKNOW;
 
     #if OSL_DEBUG_LEVEL > 0
                 sal_Int16 nTmp = getPropertySetMapper()->GetEntryContextId(
@@ -219,7 +223,7 @@ void XMLTextImportPropertyMapper::FontDefaultsCheck(
 
         if( !pFontPitch )
         {
-            aAny <<= (sal_Int16)com::sun::star::awt::FontPitch::DONTKNOW;
+            aAny <<= (sal_Int16)css::awt::FontPitch::DONTKNOW;
     #if OSL_DEBUG_LEVEL > 0
                 sal_Int16 nTmp = getPropertySetMapper()->GetEntryContextId(
                                                 pFontFamilyName->mnIndex + 3 );
@@ -254,7 +258,7 @@ namespace {
 //crock.
 
 //On import clear 100% all-margins relative sizes.
-static bool
+bool
 isNotDefaultRelSize(const XMLPropertyState* pRelState, const rtl::Reference<XMLPropertySetMapper>& rPrMap)
 {
     if (rPrMap->GetEntryContextId(pRelState->mnIndex) == CTF_PARAMARGINALL_REL)
@@ -272,10 +276,10 @@ isNotDefaultRelSize(const XMLPropertyState* pRelState, const rtl::Reference<XMLP
  * Since Writer hasn't the same compressed attributes, but has distinct ones for all
  * four side, we have to duplicate the compressed attribute during import.
 **/
-static void lcl_SeparateBorder(
-    sal_uInt16 nIndex, XMLPropertyState* pAllBorderDistance,
+void lcl_SeparateBorder(
+    sal_uInt16 nIndex, XMLPropertyState const * pAllBorderDistance,
     XMLPropertyState* pBorderDistances[4], XMLPropertyState* pNewBorderDistances[4],
-    XMLPropertyState* pAllBorder, XMLPropertyState* pBorders[4],
+    XMLPropertyState const * pAllBorder, XMLPropertyState* pBorders[4],
     XMLPropertyState* pNewBorders[4], XMLPropertyState* pAllBorderWidth,
     XMLPropertyState* pBorderWidths[4]
 #if OSL_DEBUG_LEVEL > 0
@@ -481,7 +485,7 @@ void XMLTextImportPropertyMapper::finished(
         case CTF_FRAMEHEIGHT_MIN_REL:
 //      case CTF_SYNCHEIGHT_MIN:
                                         bHasAnyMinHeight = true;
-                                        // no break here!
+                                        SAL_FALLTHROUGH;
         case CTF_FRAMEHEIGHT_ABS:
         case CTF_FRAMEHEIGHT_REL:
 //      case CTF_SYNCHEIGHT:
@@ -489,7 +493,7 @@ void XMLTextImportPropertyMapper::finished(
         case CTF_FRAMEWIDTH_MIN_ABS:
         case CTF_FRAMEWIDTH_MIN_REL:
                                         bHasAnyMinWidth = true;
-                                        // no break here!
+                                        SAL_FALLTHROUGH;
         case CTF_FRAMEWIDTH_ABS:
         case CTF_FRAMEWIDTH_REL:
                                         bHasAnyWidth = true; break;
@@ -671,7 +675,7 @@ void XMLTextImportPropertyMapper::finished(
     // #i5775# don't overwrite %transparency with binary transparency
     if( ( pBackTransparency != nullptr ) && ( pBackTransparent != nullptr ) )
     {
-        if( ! *static_cast<sal_Bool const *>(pBackTransparent->maValue.getValue()) )
+        if( ! *o3tl::doAccess<bool>(pBackTransparent->maValue) )
             pBackTransparent->mnIndex = -1;
     }
 
