@@ -85,7 +85,6 @@ static const XMLPropType aPropTypes[XML_FAMILY_TYPE_END][MAX_PROP_TYPES] =
     ENTRY1( END ),                              // XML_FAMILY_TYPE_FILL_IMAGE,
     ENTRY1( END ),                              // XML_FAMILY_TYPE_STROKE_DASH,
     ENTRY1( END ),                              // XML_FAMILY_TYPE_MARKER,
-    ENTRY1( END )                               // XML_FAMILY_TYPE_PRESENTATION_PAGE_LAYOUT,
 };
 
 static const XMLTokenEnum aPropTokens[XML_PROP_TYPE_END] =
@@ -144,22 +143,19 @@ static const sal_uInt16 aElemActionMaps[XML_PROP_TYPE_END] =
 
 class XMLTypedPropertiesOOoTContext_Impl : public XMLPersElemContentTContext
 {
-    ::com::sun::star::uno::Reference<
-        ::com::sun::star::xml::sax::XAttributeList > m_xAttrList;
+    css::uno::Reference< css::xml::sax::XAttributeList > m_xAttrList;
 
 public:
     XMLTypedPropertiesOOoTContext_Impl( XMLTransformerBase& rTransformer,
                            const OUString& rQName );
 
-    virtual ~XMLTypedPropertiesOOoTContext_Impl();
-
     using XMLPersAttrListTContext::AddAttribute;
     void AddAttribute( const OUString &sName ,
                        const OUString &sValue );
     void AddAttribute( sal_uInt16 nPrefix, XMLTokenEnum eToken,
                        const OUString &sValue );
 
-    virtual void StartElement( const ::com::sun::star::uno::Reference< ::com::sun::star::xml::sax::XAttributeList >& rAttrList ) override;
+    virtual void StartElement( const css::uno::Reference< css::xml::sax::XAttributeList >& rAttrList ) override;
 
     virtual void Export() override;
 };
@@ -172,10 +168,6 @@ XMLTypedPropertiesOOoTContext_Impl::XMLTypedPropertiesOOoTContext_Impl(
 {
 }
 
-XMLTypedPropertiesOOoTContext_Impl::~XMLTypedPropertiesOOoTContext_Impl()
-{
-}
-
 void XMLTypedPropertiesOOoTContext_Impl::AddAttribute(
     const OUString &sName ,
     const OUString &sValue )
@@ -236,15 +228,13 @@ public:
                                const XMLPropTypes& rTypes,
                                bool bPersistent );
 
-    virtual ~XMLPropertiesOOoTContext_Impl();
-
-    XMLTransformerContext *CreateChildContext(
+    rtl::Reference<XMLTransformerContext> CreateChildContext(
             sal_uInt16 nPrefix,
             const OUString& rLocalName,
             const OUString& rQName,
             const Reference< XAttributeList >& rAttrList ) override;
 
-    virtual void StartElement( const ::com::sun::star::uno::Reference< ::com::sun::star::xml::sax::XAttributeList >& rAttrList ) override;
+    virtual void StartElement( const css::uno::Reference< css::xml::sax::XAttributeList >& rAttrList ) override;
 
     virtual void EndElement() override;
 
@@ -327,22 +317,13 @@ XMLTypedPropertiesOOoTContext_Impl
                 XML_PROP_TYPE_END==m_aPropTypes[1] ||
                 (i<MAX_PROP_TYPES && XML_PROP_TYPE_END!=m_aPropTypes[i]) ) )
     {
-        OString aTmp("Didn't find property: ");
-        const OUString& rPrefix =
-            GetTransformer().GetNamespaceMap().GetPrefixByKey( nPrefix );
-        aTmp += OString( rPrefix.getStr(), rPrefix.getLength(),
-                                RTL_TEXTENCODING_ASCII_US );
-        aTmp += OString( ':' );
-        aTmp += OString( rLocalName.getStr(), rLocalName.getLength(),
-                                RTL_TEXTENCODING_ASCII_US );
-        aTmp += OString(", assuming <style:");
-        const OUString& rName =
-            ::xmloff::token::GetXMLToken( aPropTokens[m_aPropTypes[0]] );
-        aTmp += OString( rName.getStr(), rName.getLength(),
-                                RTL_TEXTENCODING_ASCII_US );
-        aTmp += OString( '>' );
-
-        OSL_FAIL(aTmp.getStr());
+        SAL_WARN("xmloff", "Didn't find property: "
+                << GetTransformer().GetNamespaceMap().GetPrefixByKey( nPrefix )
+                << ":"
+                << rLocalName
+                << ", assuming <style:"
+                << ::xmloff::token::GetXMLToken( aPropTokens[m_aPropTypes[0]] )
+                << ">" );
     }
 #endif
 
@@ -375,11 +356,7 @@ XMLPropertiesOOoTContext_Impl::XMLPropertiesOOoTContext_Impl(
     }
 }
 
-XMLPropertiesOOoTContext_Impl::~XMLPropertiesOOoTContext_Impl()
-{
-}
-
-XMLTransformerContext *XMLPropertiesOOoTContext_Impl::CreateChildContext(
+rtl::Reference<XMLTransformerContext> XMLPropertiesOOoTContext_Impl::CreateChildContext(
             sal_uInt16 nPrefix,
             const OUString& rLocalName,
             const OUString& rQName,
@@ -393,8 +370,6 @@ XMLTransformerContext *XMLPropertiesOOoTContext_Impl::CreateChildContext(
 void XMLPropertiesOOoTContext_Impl::StartElement(
         const Reference< XAttributeList >& rAttrList )
 {
-    Reference< XAttributeList > xAttrList( rAttrList );
-
     XMLTypedPropertiesOOoTContext_Impl * pIntervalMinorDivisorContext = nullptr;
     double fIntervalMajor = 0.0;
     double fIntervalMinor = 0.0;
@@ -413,11 +388,11 @@ void XMLPropertiesOOoTContext_Impl::StartElement(
     OUString aDrawMirrorAttrValue;
     XMLTypedPropertiesOOoTContext_Impl* pMirrorContext( nullptr );
 
-    sal_Int16 nAttrCount = xAttrList.is() ? xAttrList->getLength() : 0;
+    sal_Int16 nAttrCount = rAttrList.is() ? rAttrList->getLength() : 0;
     for( sal_Int16 i=0; i < nAttrCount; i++ )
     {
-        const OUString sAttrName = xAttrList->getNameByIndex( i );
-        const OUString sAttrValue = xAttrList->getValueByIndex( i );
+        const OUString sAttrName = rAttrList->getNameByIndex( i );
+        const OUString sAttrValue = rAttrList->getValueByIndex( i );
         OUString aLocalName;
         sal_uInt16 nPrefix =
             GetTransformer().GetNamespaceMap().GetKeyByAttrName( sAttrName,
@@ -507,7 +482,7 @@ void XMLPropertiesOOoTContext_Impl::StartElement(
             break;
         case XML_PTACTION_LINE_MODE:
             {
-                OUString aAttrValue( GetXMLToken(
+                const OUString& aAttrValue( GetXMLToken(
                                         IsXMLToken( sAttrValue, XML_TRUE )
                                             ? XML_CONTINUOUS
                                             : XML_SKIP_WHITE_SPACE) );
@@ -526,7 +501,7 @@ void XMLPropertiesOOoTContext_Impl::StartElement(
             break;
         case XML_PTACTION_KEEP_WITH_NEXT:
             {
-                OUString aAttrValue( GetXMLToken(
+                const OUString& aAttrValue( GetXMLToken(
                                         IsXMLToken( sAttrValue, XML_TRUE )
                                             ? XML_ALWAYS
                                             : XML_AUTO) );
@@ -813,12 +788,13 @@ void XMLPropertiesOOoTContext_Impl::StartElement(
                 XMLPersAttrListTContext *pSymbolImageContext = new XMLPersAttrListTContext(
                     GetTransformer(), GetTransformer().GetNamespaceMap().GetQNameByKey(
                         XML_NAMESPACE_CHART, GetXMLToken( XML_SYMBOL_IMAGE )));
+                rtl::Reference<XMLTransformerContext> xSymbolImageContext(pSymbolImageContext);
 
                 OUString aAttrValue( sAttrValue );
                 if( GetTransformer().ConvertURIToOASIS( aAttrValue, true ))
                 {
                     pSymbolImageContext->AddAttribute( XML_NAMESPACE_XLINK, XML_HREF, aAttrValue );
-                    pContext->AddContent( pSymbolImageContext );
+                    pContext->AddContent(xSymbolImageContext);
                 }
             }
             break;
@@ -993,7 +969,7 @@ void XMLPropertiesOOoTContext_Impl::StartElement(
             aProtectAttrValue += rSize;
         }
 
-        // coverity[var_deref_model] - pProtectContext is assigned in a superset of the enclosing if condition entry logic
+        assert(pProtectContext && "coverity[var_deref_model] - pProtectContext should be assigned in a superset of the enclosing if condition entry logic");
         pProtectContext->AddAttribute( GetTransformer().GetNamespaceMap().GetQNameByKey( XML_NAMESPACE_STYLE, GetXMLToken( XML_PROTECT ) ), aProtectAttrValue );
     }
 
@@ -1004,13 +980,11 @@ void XMLPropertiesOOoTContext_Impl::StartElement(
             sal_Int32 nIntervalMinorDivisor = static_cast< sal_Int32 >(
                 ::rtl::math::round( fIntervalMajor / fIntervalMinor ));
 
-            OUStringBuffer aBuf;
-            ::sax::Converter::convertNumber( aBuf, nIntervalMinorDivisor );
             pIntervalMinorDivisorContext->AddAttribute(
                 GetTransformer().GetNamespaceMap().GetQNameByKey(
                     XML_NAMESPACE_CHART,
                     GetXMLToken( XML_INTERVAL_MINOR_DIVISOR )),
-                aBuf.makeStringAndClear());
+                OUString::number( nIntervalMinorDivisor ));
         }
     }
 }
@@ -1029,10 +1003,10 @@ void XMLPropertiesOOoTContext_Impl::Characters( const OUString& )
 void XMLPropertiesOOoTContext_Impl::Export()
 {
 
-    for( sal_uInt16 i=0; i < MAX_PROP_TYPES; i++ )
+    for(rtl::Reference<XMLTypedPropertiesOOoTContext_Impl> & rPropContext : m_aPropContexts)
     {
-        if( m_aPropContexts[i].is() )
-            m_aPropContexts[i]->Export();
+        if( rPropContext.is() )
+            rPropContext->Export();
     }
 }
 
@@ -1068,13 +1042,13 @@ XMLStyleOOoTContext::~XMLStyleOOoTContext()
 {
 }
 
-XMLTransformerContext *XMLStyleOOoTContext::CreateChildContext(
+rtl::Reference<XMLTransformerContext> XMLStyleOOoTContext::CreateChildContext(
             sal_uInt16 nPrefix,
             const OUString& rLocalName,
             const OUString& rQName,
             const Reference< XAttributeList >& rAttrList )
 {
-    XMLTransformerContext *pContext = nullptr;
+    rtl::Reference<XMLTransformerContext> pContext;
 
     if( XML_NAMESPACE_STYLE == nPrefix &&
         IsXMLToken( rLocalName, XML_PROPERTIES ) )
@@ -1094,29 +1068,29 @@ XMLTransformerContext *XMLStyleOOoTContext::CreateChildContext(
                 aAttrActionMaps[aPropTypes[m_eFamily][0]];
             if( nActionMap < MAX_OOO_PROP_ACTIONS )
             {
-                pContext = new XMLPropertiesOOoTContext_Impl(
+                pContext.set(new XMLPropertiesOOoTContext_Impl(
                                     GetTransformer(), rQName,
-                                    aPropTypes[m_eFamily], m_bPersistent );
+                                    aPropTypes[m_eFamily], m_bPersistent ));
             }
             else
             {
                 if( m_bPersistent )
-                    pContext = new XMLPersElemContentTContext(
+                    pContext.set(new XMLPersElemContentTContext(
                                     GetTransformer(), rQName,
                                     XML_NAMESPACE_STYLE,
-                                    aPropTokens[aPropTypes[m_eFamily][0]] );
+                                    aPropTokens[aPropTypes[m_eFamily][0]] ));
                 else
-                    pContext = new XMLRenameElemTransformerContext(
+                    pContext.set(new XMLRenameElemTransformerContext(
                                     GetTransformer(), rQName,
                                     XML_NAMESPACE_STYLE,
-                                    aPropTokens[aPropTypes[m_eFamily][0]] );
+                                    aPropTokens[aPropTypes[m_eFamily][0]] ));
             }
         }
         else
         {
-            pContext = new XMLPropertiesOOoTContext_Impl(
+            pContext.set(new XMLPropertiesOOoTContext_Impl(
                                 GetTransformer(), rQName,
-                                aPropTypes[m_eFamily], m_bPersistent);
+                                aPropTypes[m_eFamily], m_bPersistent));
         }
 
         if( m_bPersistent )
@@ -1269,8 +1243,7 @@ void XMLStyleOOoTContext::StartElement(
     if( m_bPersistent )
         XMLPersElemContentTContext::StartElement( xAttrList );
     else
-        GetTransformer().GetDocHandler()->startElement( GetExportQName(),
-                                                        xAttrList );
+        GetTransformer().GetDocHandler()->startElement( GetExportQName(), xAttrList );
 }
 
 void XMLStyleOOoTContext::EndElement()
