@@ -19,18 +19,20 @@
 
 #include <sal/config.h>
 
-#include "unoservices.hxx"
-#include "xml_import.hxx"
+#include <unoservices.hxx>
+#include <xml_import.hxx>
 
 #include <cppuhelper/factory.hxx>
 #include <cppuhelper/implementationentry.hxx>
 #include <cppuhelper/implbase.hxx>
 #include <cppuhelper/supportsservice.hxx>
+#include <com/sun/star/container/NoSuchElementException.hpp>
 #include <com/sun/star/xml/input/XAttributes.hpp>
 #include <com/sun/star/lang/XInitialization.hpp>
 #include <com/sun/star/uno/XComponentContext.hpp>
 #include <com/sun/star/lang/XServiceInfo.hpp>
 #include <sal/log.hxx>
+#include <rtl/ref.hxx>
 
 #include <memory>
 #include <unordered_map>
@@ -55,35 +57,36 @@ OUString getImplementationName_DocumentHandlerImpl()
     return OUString( "com.sun.star.comp.xml.input.SaxDocumentHandler" );
 }
 
-typedef std::unordered_map< OUString, sal_Int32, OUStringHash > t_OUString2LongMap;
+typedef std::unordered_map< OUString, sal_Int32 > t_OUString2LongMap;
 
 struct PrefixEntry
 {
     ::std::vector< sal_Int32 > m_Uids;
 
-    inline PrefixEntry()
+    PrefixEntry()
         { m_Uids.reserve( 4 ); }
 };
 
 typedef std::unordered_map<
-    OUString, PrefixEntry *, OUStringHash > t_OUString2PrefixMap;
+    OUString, std::unique_ptr<PrefixEntry> > t_OUString2PrefixMap;
 
 struct ElementEntry
 {
     Reference< xml::input::XElement > m_xElement;
     ::std::vector< OUString > m_prefixes;
 
-    inline ElementEntry()
+    ElementEntry()
         { m_prefixes.reserve( 2 ); }
 };
 
 class ExtendedAttributes;
 
-struct MGuard
+class MGuard
 {
     Mutex * m_pMutex;
-    explicit MGuard( Mutex * pMutex )
-        : m_pMutex( pMutex )
+public:
+    explicit MGuard( std::unique_ptr<Mutex> const & pMutex )
+        : m_pMutex( pMutex.get() )
         { if (m_pMutex) m_pMutex->acquire(); }
     ~MGuard() throw ()
         { if (m_pMutex) m_pMutex->release(); }
@@ -93,7 +96,7 @@ class DocumentHandlerImpl :
     public ::cppu::WeakImplHelper< xml::sax::XDocumentHandler,
                                     xml::input::XNamespaceMapping,
                                     lang::XInitialization,
-                                    com::sun::star::lang::XServiceInfo >
+                                    css::lang::XServiceInfo >
 {
     friend class ExtendedAttributes;
 
@@ -115,7 +118,7 @@ class DocumentHandlerImpl :
     std::vector< ElementEntry * > m_elements;
     sal_Int32 m_nSkipElements;
 
-    Mutex * m_pMutex;
+    std::unique_ptr<Mutex> m_pMutex;
 
     inline Reference< xml::input::XElement > getCurrentElement() const;
 
@@ -133,52 +136,37 @@ public:
     DocumentHandlerImpl(
         Reference< xml::input::XRoot > const & xRoot,
         bool bSingleThreadedUse );
-    virtual ~DocumentHandlerImpl() throw ();
 
     // XServiceInfo
-    virtual OUString SAL_CALL getImplementationName()
-        throw (RuntimeException, std::exception) override;
+    virtual OUString SAL_CALL getImplementationName() override;
     virtual sal_Bool SAL_CALL supportsService(
-        OUString const & servicename )
-        throw (RuntimeException, std::exception) override;
-    virtual Sequence< OUString > SAL_CALL getSupportedServiceNames()
-        throw (RuntimeException, std::exception) override;
+        OUString const & servicename ) override;
+    virtual Sequence< OUString > SAL_CALL getSupportedServiceNames() override;
 
     // XInitialization
     virtual void SAL_CALL initialize(
-        Sequence< Any > const & arguments )
-        throw (Exception, std::exception) override;
+        Sequence< Any > const & arguments ) override;
 
     // XDocumentHandler
-    virtual void SAL_CALL startDocument()
-        throw (xml::sax::SAXException, RuntimeException, std::exception) override;
-    virtual void SAL_CALL endDocument()
-        throw (xml::sax::SAXException, RuntimeException, std::exception) override;
+    virtual void SAL_CALL startDocument() override;
+    virtual void SAL_CALL endDocument() override;
     virtual void SAL_CALL startElement(
         OUString const & rQElementName,
-        Reference< xml::sax::XAttributeList > const & xAttribs )
-        throw (xml::sax::SAXException, RuntimeException, std::exception) override;
+        Reference< xml::sax::XAttributeList > const & xAttribs ) override;
     virtual void SAL_CALL endElement(
-        OUString const & rQElementName )
-        throw (xml::sax::SAXException, RuntimeException, std::exception) override;
+        OUString const & rQElementName ) override;
     virtual void SAL_CALL characters(
-        OUString const & rChars )
-        throw (xml::sax::SAXException, RuntimeException, std::exception) override;
+        OUString const & rChars ) override;
     virtual void SAL_CALL ignorableWhitespace(
-        OUString const & rWhitespaces )
-        throw (xml::sax::SAXException, RuntimeException, std::exception) override;
+        OUString const & rWhitespaces ) override;
     virtual void SAL_CALL processingInstruction(
-        OUString const & rTarget, OUString const & rData )
-        throw (xml::sax::SAXException, RuntimeException, std::exception) override;
+        OUString const & rTarget, OUString const & rData ) override;
     virtual void SAL_CALL setDocumentLocator(
-        Reference< xml::sax::XLocator > const & xLocator )
-        throw (xml::sax::SAXException, RuntimeException, std::exception) override;
+        Reference< xml::sax::XLocator > const & xLocator ) override;
 
     // XNamespaceMapping
-    virtual sal_Int32 SAL_CALL getUidByUri( OUString const & Uri )
-        throw (RuntimeException, std::exception) override;
-    virtual OUString SAL_CALL getUriByUid( sal_Int32 Uid )
-        throw (container::NoSuchElementException, RuntimeException, std::exception) override;
+    virtual sal_Int32 SAL_CALL getUidByUri( OUString const & Uri ) override;
+    virtual OUString SAL_CALL getUriByUid( sal_Int32 Uid ) override;
 };
 
 DocumentHandlerImpl::DocumentHandlerImpl(
@@ -198,18 +186,7 @@ DocumentHandlerImpl::DocumentHandlerImpl(
     m_elements.reserve( 10 );
 
     if (! bSingleThreadedUse)
-        m_pMutex = new Mutex();
-}
-
-DocumentHandlerImpl::~DocumentHandlerImpl() throw ()
-{
-    if (m_pMutex != nullptr)
-    {
-        delete m_pMutex;
-#if OSL_DEBUG_LEVEL == 0
-        m_pMutex = 0;
-#endif
-    }
+        m_pMutex.reset(new Mutex);
 }
 
 inline Reference< xml::input::XElement >
@@ -281,13 +258,13 @@ inline void DocumentHandlerImpl::pushPrefix(
     {
         PrefixEntry * pEntry = new PrefixEntry();
         pEntry->m_Uids.push_back( nUid ); // latest id for prefix
-        m_prefixes[ rPrefix ] = pEntry;
+        m_prefixes[rPrefix].reset(pEntry);
     }
     else
     {
-        PrefixEntry * pEntry = iFind->second;
-        SAL_WARN_IF( pEntry->m_Uids.empty(), "xmlscript.xmlhelper", "pEntry->m_Uids is empty" );
-        pEntry->m_Uids.push_back( nUid );
+        PrefixEntry& rEntry = *iFind->second;
+        SAL_WARN_IF(rEntry.m_Uids.empty(), "xmlscript.xmlhelper", "pEntry->m_Uids is empty");
+        rEntry.m_Uids.push_back(nUid);
     }
 
     m_aLastPrefix_lookup = rPrefix;
@@ -300,12 +277,11 @@ inline void DocumentHandlerImpl::popPrefix(
     t_OUString2PrefixMap::iterator iFind( m_prefixes.find( rPrefix ) );
     if (iFind != m_prefixes.end()) // unused prefix
     {
-        PrefixEntry * pEntry = iFind->second;
-        pEntry->m_Uids.pop_back(); // pop last id for prefix
-        if (pEntry->m_Uids.empty()) // erase prefix key
+        PrefixEntry& rEntry = *iFind->second;
+        rEntry.m_Uids.pop_back(); // pop last id for prefix
+        if (rEntry.m_Uids.empty()) // erase prefix key
         {
-            m_prefixes.erase( iFind );
-            delete pEntry;
+            m_prefixes.erase(iFind);
         }
     }
 
@@ -316,7 +292,7 @@ inline void DocumentHandlerImpl::popPrefix(
 inline void DocumentHandlerImpl::getElementName(
     OUString const & rQName, sal_Int32 * pUid, OUString * pLocalName )
 {
-    sal_Int32 nColonPos = rQName.indexOf( (sal_Unicode)':' );
+    sal_Int32 nColonPos = rQName.indexOf( ':' );
     *pLocalName = (nColonPos >= 0 ? rQName.copy( nColonPos +1 ) : rQName);
     *pUid = getUidByPrefix(
         nColonPos >= 0 ? rQName.copy( 0, nColonPos ) : OUString() );
@@ -326,101 +302,68 @@ class ExtendedAttributes :
     public ::cppu::WeakImplHelper< xml::input::XAttributes >
 {
     sal_Int32 m_nAttributes;
-    sal_Int32 * m_pUids;
-    OUString * m_pPrefixes;
-    OUString * m_pLocalNames;
-    OUString * m_pQNames;
-    OUString * m_pValues;
-
-    DocumentHandlerImpl * m_pHandler;
+    std::unique_ptr<sal_Int32[]> m_pUids;
+    std::unique_ptr<OUString[]>  m_pLocalNames;
+    std::unique_ptr<OUString[]>  m_pQNames;
+    std::unique_ptr<OUString[]>  m_pValues;
 
 public:
     inline ExtendedAttributes(
         sal_Int32 nAttributes,
-        sal_Int32 * pUids, OUString * pPrefixes,
+        sal_Int32 * pUids,
         OUString * pLocalNames, OUString * pQNames,
-        Reference< xml::sax::XAttributeList > const & xAttributeList,
-        DocumentHandlerImpl * pHandler );
-    virtual ~ExtendedAttributes() throw ();
+        Reference< xml::sax::XAttributeList > const & xAttributeList );
 
     // XAttributes
-    virtual sal_Int32 SAL_CALL getLength()
-        throw (RuntimeException, std::exception) override;
+    virtual sal_Int32 SAL_CALL getLength() override;
     virtual sal_Int32 SAL_CALL getIndexByQName(
-        OUString const & rQName )
-        throw (RuntimeException, std::exception) override;
+        OUString const & rQName ) override;
     virtual sal_Int32 SAL_CALL getIndexByUidName(
-        sal_Int32 nUid, OUString const & rLocalName )
-        throw (RuntimeException, std::exception) override;
+        sal_Int32 nUid, OUString const & rLocalName ) override;
     virtual OUString SAL_CALL getQNameByIndex(
-        sal_Int32 nIndex )
-        throw (RuntimeException, std::exception) override;
+        sal_Int32 nIndex ) override;
     virtual sal_Int32 SAL_CALL getUidByIndex(
-        sal_Int32 nIndex )
-        throw (RuntimeException, std::exception) override;
+        sal_Int32 nIndex ) override;
     virtual OUString SAL_CALL getLocalNameByIndex(
-        sal_Int32 nIndex )
-        throw (RuntimeException, std::exception) override;
+        sal_Int32 nIndex ) override;
     virtual OUString SAL_CALL getValueByIndex(
-        sal_Int32 nIndex )
-        throw (RuntimeException, std::exception) override;
+        sal_Int32 nIndex ) override;
     virtual OUString SAL_CALL getValueByUidName(
-        sal_Int32 nUid, OUString const & rLocalName )
-        throw (RuntimeException, std::exception) override;
+        sal_Int32 nUid, OUString const & rLocalName ) override;
     virtual OUString SAL_CALL getTypeByIndex(
-        sal_Int32 nIndex )
-        throw (RuntimeException, std::exception) override;
+        sal_Int32 nIndex ) override;
 };
 
 inline ExtendedAttributes::ExtendedAttributes(
     sal_Int32 nAttributes,
-    sal_Int32 * pUids, OUString * pPrefixes,
+    sal_Int32 * pUids,
     OUString * pLocalNames, OUString * pQNames,
-    Reference< xml::sax::XAttributeList > const & xAttributeList,
-    DocumentHandlerImpl * pHandler )
+    Reference< xml::sax::XAttributeList > const & xAttributeList )
     : m_nAttributes( nAttributes )
     , m_pUids( pUids )
-    , m_pPrefixes( pPrefixes )
     , m_pLocalNames( pLocalNames )
     , m_pQNames( pQNames )
     , m_pValues( new OUString[ nAttributes ] )
-    , m_pHandler( pHandler )
 {
-    m_pHandler->acquire();
-
     for ( sal_Int32 nPos = 0; nPos < nAttributes; ++nPos )
     {
         m_pValues[ nPos ] = xAttributeList->getValueByIndex( nPos );
     }
 }
 
-ExtendedAttributes::~ExtendedAttributes() throw ()
-{
-    m_pHandler->release();
-
-    delete [] m_pUids;
-    delete [] m_pPrefixes;
-    delete [] m_pLocalNames;
-    delete [] m_pQNames;
-    delete [] m_pValues;
-}
-
 // XServiceInfo
 
 OUString DocumentHandlerImpl::getImplementationName()
-    throw (RuntimeException, std::exception)
 {
     return getImplementationName_DocumentHandlerImpl();
 }
 
 sal_Bool DocumentHandlerImpl::supportsService( OUString const & servicename )
-    throw (RuntimeException, std::exception)
 {
     return cppu::supportsService(this, servicename);
 }
 
 Sequence< OUString > DocumentHandlerImpl::getSupportedServiceNames()
-    throw (RuntimeException, std::exception)
 {
     return getSupportedServiceNames_DocumentHandlerImpl();
 }
@@ -429,26 +372,21 @@ Sequence< OUString > DocumentHandlerImpl::getSupportedServiceNames()
 
 void DocumentHandlerImpl::initialize(
     Sequence< Any > const & arguments )
-    throw (Exception, std::exception)
 {
     MGuard guard( m_pMutex );
     Reference< xml::input::XRoot > xRoot;
-    if (arguments.getLength() == 1 &&
-        (arguments[ 0 ] >>= xRoot) &&
-        xRoot.is())
-    {
-        m_xRoot = xRoot;
-    }
-    else
+    if (arguments.getLength() != 1 ||
+        !(arguments[ 0 ] >>= xRoot) ||
+        !xRoot.is())
     {
         throw RuntimeException( "missing root instance!" );
     }
+    m_xRoot = xRoot;
 }
 
 // XNamespaceMapping
 
 sal_Int32 DocumentHandlerImpl::getUidByUri( OUString const & Uri )
-    throw (RuntimeException, std::exception)
 {
     sal_Int32 uid = getUidByURI( Uri );
     SAL_WARN_IF( uid == UID_UNKNOWN, "xmlscript.xmlhelper", "uid UNKNOWN");
@@ -456,7 +394,6 @@ sal_Int32 DocumentHandlerImpl::getUidByUri( OUString const & Uri )
 }
 
 OUString DocumentHandlerImpl::getUriByUid( sal_Int32 Uid )
-    throw (container::NoSuchElementException, RuntimeException, std::exception)
 {
     MGuard guard( m_pMutex );
     t_OUString2LongMap::const_iterator iPos( m_URI2Uid.begin() );
@@ -472,13 +409,11 @@ OUString DocumentHandlerImpl::getUriByUid( sal_Int32 Uid )
 // XDocumentHandler
 
 void DocumentHandlerImpl::startDocument()
-    throw (xml::sax::SAXException, RuntimeException, std::exception)
 {
     m_xRoot->startDocument( static_cast< xml::input::XNamespaceMapping * >( this ) );
 }
 
 void DocumentHandlerImpl::endDocument()
-    throw (xml::sax::SAXException, RuntimeException, std::exception)
 {
     m_xRoot->endDocument();
 }
@@ -486,7 +421,6 @@ void DocumentHandlerImpl::endDocument()
 void DocumentHandlerImpl::startElement(
     OUString const & rQElementName,
     Reference< xml::sax::XAttributeList > const & xAttribs )
-    throw (xml::sax::SAXException, RuntimeException, std::exception)
 {
     Reference< xml::input::XElement > xCurrentElement;
     Reference< xml::input::XAttributes > xAttributes;
@@ -500,11 +434,7 @@ void DocumentHandlerImpl::startElement(
     if (m_nSkipElements > 0)
     {
         ++m_nSkipElements; // wait for another end tag
-#if OSL_DEBUG_LEVEL > 1
-        OString aQName(
-            OUStringToOString( rQElementName, RTL_TEXTENCODING_ASCII_US ) );
-        SAL_INFO("xmlscript.xmlhelper", "### no context given on createChildElement() => ignoring element \"" << aQName.getStr() << "\" ...");
-#endif
+        SAL_INFO("xmlscript.xmlhelper", " no context given on createChildElement() => ignoring element \"" << rQElementName << "\" ...");
         return;
     }
 
@@ -540,7 +470,7 @@ void DocumentHandlerImpl::startElement(
                 pPrefixes[ nPos ]      = m_sXMLNS;
                 pLocalNames[ nPos ]    = aDefNamespacePrefix;
             }
-            else if ((sal_Unicode)':' == rQAttributeName[ 5 ]) // set prefix
+            else if (':' == rQAttributeName[ 5 ]) // set prefix
             {
                 OUString aPrefix( rQAttributeName.copy( 6 ) );
                 pushPrefix( aPrefix, xAttribs->getValueByIndex( nPos ) );
@@ -562,7 +492,7 @@ void DocumentHandlerImpl::startElement(
             SAL_WARN_IF(rQAttributeName.startsWith( "xmlns:" ), "xmlscript.xmlhelper", "### unexpected xmlns!" );
 
             // collect attribute's uid and current prefix
-            sal_Int32 nColonPos = rQAttributeName.indexOf( (sal_Unicode) ':' );
+            sal_Int32 nColonPos = rQAttributeName.indexOf( ':' );
             if (nColonPos >= 0)
             {
                 pPrefixes[ nPos ] = rQAttributeName.copy( 0, nColonPos );
@@ -577,11 +507,12 @@ void DocumentHandlerImpl::startElement(
             pUids[ nPos ] = getUidByPrefix( pPrefixes[ nPos ] );
         }
     }
+    delete[] pPrefixes;
     // ownership of arrays belongs to attribute list
     xAttributes = static_cast< xml::input::XAttributes * >(
         new ExtendedAttributes(
-            nAttribs, pUids, pPrefixes, pLocalNames, pQNames,
-            xAttribs, this ) );
+            nAttribs, pUids, pLocalNames, pQNames,
+            xAttribs ) );
 
     getElementName( rQElementName, &nUid, &aLocalName );
 
@@ -610,18 +541,18 @@ void DocumentHandlerImpl::startElement(
     else
     {
         ++m_nSkipElements;
-#if OSL_DEBUG_LEVEL > 1
-        OString aQName(
-            OUStringToOString( rQElementName, RTL_TEXTENCODING_ASCII_US ) );
-        SAL_INFO("xmlscript.xmlhelper", "### no context given on createChildElement() => ignoring element \"" << aQName.getStr() << "\" ...");
-#endif
+
+        // pop prefixes
+        for (sal_Int32 nPos = elementEntry->m_prefixes.size(); nPos--;)
+            popPrefix(elementEntry->m_prefixes[nPos]);
+
+        SAL_INFO("xmlscript.xmlhelper", " no context given on createChildElement() => ignoring element \"" << rQElementName << "\" ...");
     }
     }
 }
 
 void DocumentHandlerImpl::endElement(
     OUString const & rQElementName )
-    throw (xml::sax::SAXException, RuntimeException, std::exception)
 {
     Reference< xml::input::XElement > xCurrentElement;
     {
@@ -629,12 +560,7 @@ void DocumentHandlerImpl::endElement(
     if (m_nSkipElements)
     {
         --m_nSkipElements;
-#if OSL_DEBUG_LEVEL > 1
-        OString aQName(
-            OUStringToOString( rQElementName, RTL_TEXTENCODING_ASCII_US ) );
-        SAL_INFO("xmlscript.xmlhelper", "### received endElement() for \"" << aQName.getStr() << "\".");
-#endif
-        static_cast<void>(rQElementName);
+        SAL_INFO("xmlscript.xmlhelper", "### received endElement() for \"" << rQElementName << "\".");
         return;
     }
 
@@ -663,7 +589,6 @@ void DocumentHandlerImpl::endElement(
 }
 
 void DocumentHandlerImpl::characters( OUString const & rChars )
-    throw (xml::sax::SAXException, RuntimeException, std::exception)
 {
     Reference< xml::input::XElement > xCurrentElement( getCurrentElement() );
     if (xCurrentElement.is())
@@ -672,7 +597,6 @@ void DocumentHandlerImpl::characters( OUString const & rChars )
 
 void DocumentHandlerImpl::ignorableWhitespace(
     OUString const & rWhitespaces )
-    throw (xml::sax::SAXException, RuntimeException, std::exception)
 {
     Reference< xml::input::XElement > xCurrentElement( getCurrentElement() );
     if (xCurrentElement.is())
@@ -681,7 +605,6 @@ void DocumentHandlerImpl::ignorableWhitespace(
 
 void DocumentHandlerImpl::processingInstruction(
     OUString const & rTarget, OUString const & rData )
-    throw (xml::sax::SAXException, RuntimeException, std::exception)
 {
     Reference< xml::input::XElement > xCurrentElement( getCurrentElement() );
     if (xCurrentElement.is())
@@ -692,7 +615,6 @@ void DocumentHandlerImpl::processingInstruction(
 
 void DocumentHandlerImpl::setDocumentLocator(
     Reference< xml::sax::XLocator > const & xLocator )
-    throw (xml::sax::SAXException, RuntimeException, std::exception)
 {
     m_xRoot->setDocumentLocator( xLocator );
 }
@@ -700,11 +622,10 @@ void DocumentHandlerImpl::setDocumentLocator(
 // XAttributes
 
 sal_Int32 ExtendedAttributes::getIndexByQName( OUString const & rQName )
-    throw (RuntimeException, std::exception)
 {
     for ( sal_Int32 nPos = m_nAttributes; nPos--; )
     {
-        if (m_pQNames[ nPos ].equals( rQName ))
+        if (m_pQNames[ nPos ] == rQName)
         {
             return nPos;
         }
@@ -713,13 +634,11 @@ sal_Int32 ExtendedAttributes::getIndexByQName( OUString const & rQName )
 }
 
 sal_Int32 ExtendedAttributes::getLength()
-    throw (RuntimeException, std::exception)
 {
     return m_nAttributes;
 }
 
 OUString ExtendedAttributes::getLocalNameByIndex( sal_Int32 nIndex )
-    throw (RuntimeException, std::exception)
 {
     if (nIndex < m_nAttributes)
         return m_pLocalNames[ nIndex ];
@@ -728,7 +647,6 @@ OUString ExtendedAttributes::getLocalNameByIndex( sal_Int32 nIndex )
 }
 
 OUString ExtendedAttributes::getQNameByIndex( sal_Int32 nIndex )
-    throw (RuntimeException, std::exception)
 {
     if (nIndex < m_nAttributes)
         return m_pQNames[ nIndex ];
@@ -737,15 +655,12 @@ OUString ExtendedAttributes::getQNameByIndex( sal_Int32 nIndex )
 }
 
 OUString ExtendedAttributes::getTypeByIndex( sal_Int32 nIndex )
-    throw (RuntimeException, std::exception)
 {
-    static_cast<void>(nIndex);
     SAL_WARN_IF( nIndex >= m_nAttributes , "xmlscript.xmlhelper", "nIndex is bigger then m_nAttributes");
     return OUString(); // unsupported
 }
 
 OUString ExtendedAttributes::getValueByIndex( sal_Int32 nIndex )
-    throw (RuntimeException, std::exception)
 {
     if (nIndex < m_nAttributes)
         return m_pValues[ nIndex ];
@@ -755,7 +670,6 @@ OUString ExtendedAttributes::getValueByIndex( sal_Int32 nIndex )
 
 sal_Int32 ExtendedAttributes::getIndexByUidName(
     sal_Int32 nUid, OUString const & rLocalName )
-    throw (RuntimeException, std::exception)
 {
     for ( sal_Int32 nPos = m_nAttributes; nPos--; )
     {
@@ -768,7 +682,6 @@ sal_Int32 ExtendedAttributes::getIndexByUidName(
 }
 
 sal_Int32 ExtendedAttributes::getUidByIndex( sal_Int32 nIndex )
-    throw (RuntimeException, std::exception)
 {
     if (nIndex < m_nAttributes)
         return m_pUids[ nIndex ];
@@ -778,7 +691,6 @@ sal_Int32 ExtendedAttributes::getUidByIndex( sal_Int32 nIndex )
 
 OUString ExtendedAttributes::getValueByUidName(
     sal_Int32 nUid, OUString const & rLocalName )
-    throw (RuntimeException, std::exception)
 {
     for ( sal_Int32 nPos = m_nAttributes; nPos--; )
     {
@@ -791,14 +703,13 @@ OUString ExtendedAttributes::getValueByUidName(
 }
 
 Reference< xml::sax::XDocumentHandler > SAL_CALL createDocumentHandler(
-    Reference< xml::input::XRoot > const & xRoot,
-    bool bSingleThreadedUse )
+    Reference< xml::input::XRoot > const & xRoot )
 {
     SAL_WARN_IF( !xRoot.is(), "xmlscript.xmlhelper", "xRoot is NULL" );
     if (xRoot.is())
     {
         return static_cast< xml::sax::XDocumentHandler * >(
-            new DocumentHandlerImpl( xRoot, bSingleThreadedUse ) );
+            new DocumentHandlerImpl( xRoot, true /* mt use */ ) );
     }
     return Reference< xml::sax::XDocumentHandler >();
 }
