@@ -29,7 +29,6 @@
 
 using namespace ::rtl;
 using namespace ::com::sun::star;
-using namespace ::com::sun::star::uno;
 using namespace ::com::sun::star::frame;
 
 namespace xmlscript
@@ -47,36 +46,36 @@ public:
     }
 
     // XInputStreamProvider
-    virtual Reference< io::XInputStream > SAL_CALL createInputStream() override;
+    virtual uno::Reference< io::XInputStream > SAL_CALL createInputStream() override;
 };
-Reference< io::XInputStream > InputStreamProvider::createInputStream()
+uno::Reference< io::XInputStream > InputStreamProvider::createInputStream()
 {
     return ::xmlscript::createInputStream( _bytes );
 }
 
-Reference< io::XInputStreamProvider > SAL_CALL exportDialogModel(
-    Reference< container::XNameContainer > const & xDialogModel,
-    Reference< XComponentContext > const & xContext,
-    Reference< XModel > const & xDocument )
+uno::Reference< io::XInputStreamProvider > SAL_CALL exportDialogModel(
+    uno::Reference< container::XNameContainer > const & xDialogModel,
+    uno::Reference< uno::XComponentContext > const & xContext,
+    uno::Reference< XModel > const & xDocument )
 {
-    Reference< xml::sax::XWriter > xWriter = xml::sax::Writer::create(xContext);
+    uno::Reference< xml::sax::XWriter > xWriter = xml::sax::Writer::create(xContext);
 
     std::vector<sal_Int8> aBytes;
     xWriter->setOutputStream( createOutputStream( &aBytes ) );
 
-    Reference< xml::sax::XExtendedDocumentHandler > xHandler(xWriter, UNO_QUERY_THROW);
+    uno::Reference< xml::sax::XExtendedDocumentHandler > xHandler(xWriter, uno::UNO_QUERY_THROW);
     exportDialogModel( xHandler, xDialogModel, xDocument );
 
     return new InputStreamProvider( aBytes );
 }
 
 void SAL_CALL importDialogModel(
-    Reference< io::XInputStream > const & xInput,
-    Reference< container::XNameContainer > const & xDialogModel,
-    Reference< XComponentContext > const & xContext,
-    Reference< XModel > const & xDocument )
+    uno::Reference< io::XInputStream > const & xInput,
+    uno::Reference< container::XNameContainer > const & xDialogModel,
+    uno::Reference< uno::XComponentContext > const & xContext,
+    uno::Reference< XModel > const & xDocument )
 {
-    Reference< xml::sax::XParser > xParser = xml::sax::Parser::create( xContext );
+    uno::Reference< xml::sax::XParser > xParser = xml::sax::Parser::create( xContext );
 
     // error handler, entity resolver omitted for this helper function
     xParser->setDocumentHandler( importDialogModel( xDialogModel, xContext, xDocument ) );
