@@ -29,7 +29,6 @@
 
 #include <cppuhelper/servicefactory.hxx>
 #include <cppuhelper/bootstrap.hxx>
-#include <cppuhelper/implbase2.hxx>
 
 #include <comphelper/processfactory.hxx>
 
@@ -50,7 +49,6 @@
 #include <com/sun/star/registry/XImplementationRegistration.hpp>
 #include <com/sun/star/uno/XComponentContext.hpp>
 
-using namespace ::rtl;
 using namespace ::cppu;
 using namespace ::com::sun::star;
 using namespace ::com::sun::star::uno;
@@ -67,15 +65,14 @@ Reference< XComponentContext > createInitialComponentContext(
             inst_dir.pData, &file_url.pData );
         OSL_ASSERT( osl_File_E_None == rc );
 
-        OUString unorc = file_url + ("/" LIBO_ETC_FOLDER "/" SAL_CONFIGFILE("uno") );
+        OUString unorc = file_url + ("/" LIBO_ETC_FOLDER "/" SAL_CONFIGFILE("louno") );
 
         return defaultBootstrap_InitialComponentContext( unorc );
     }
 
     catch( const Exception& rExc )
     {
-        OString aStr( OUStringToOString( rExc.Message, RTL_TEXTENCODING_ASCII_US ) );
-        OSL_FAIL( aStr.getStr() );
+        SAL_WARN( "xmlscript", rExc );
     }
 
     return xContext;
@@ -105,7 +102,7 @@ Reference< container::XNameContainer > importFile(
     }
     else
     {
-        throw Exception( "### Cannot read file!", Reference< XInterface >() );
+        throw Exception( "### Cannot read file!" );
     }
 }
 
@@ -150,7 +147,7 @@ void MyApp::Main()
 {
     if (GetCommandLineParamCount() < 2)
     {
-        OSL_FAIL( "usage: imexp inst_dir inputfile [outputfile]\n" );
+        OSL_FAIL( "usage: imexp inst_dir inputfile [outputfile]" );
         return;
     }
 
@@ -173,7 +170,7 @@ void MyApp::Main()
             importFile( aParam1.getStr(), xContext ) );
         OSL_ASSERT( xModel.is() );
 
-        Reference< awt::XUnoControlDialog > xDlg = UnoControlDialog::create( xContext );;
+        Reference< awt::XUnoControlDialog > xDlg = UnoControlDialog::create( xContext );
         xDlg->setModel( xModel );
         xDlg->createPeer( xToolkit, 0 );
         xDlg->execute();
@@ -188,19 +185,18 @@ void MyApp::Main()
     }
     catch (const xml::sax::SAXException & rExc)
     {
-        OString aStr( OUStringToOString( rExc.Message, RTL_TEXTENCODING_ASCII_US ) );
+        OUString aStr( rExc );
         uno::Exception exc;
         if (rExc.WrappedException >>= exc)
         {
-            aStr += OString( " >>> " );
-            aStr += OUStringToOString( exc.Message, RTL_TEXTENCODING_ASCII_US );
+            aStr += " >>> ";
+            aStr += exc;
         }
-        OSL_FAIL( aStr.getStr() );
+        SAL_WARN( "xmlscript", aStr );
     }
     catch (const uno::Exception & rExc)
     {
-        OString aStr( OUStringToOString( rExc.Message, RTL_TEXTENCODING_ASCII_US ) );
-        OSL_FAIL( aStr.getStr() );
+        SAL_WARN( "xmlscript", rExc );
     }
 
     Reference< lang::XComponent > xComp( xContext, UNO_QUERY );
