@@ -22,17 +22,14 @@
  * and turn off the additional virtual methods which are part of some interfaces when compiled
  * with debug
  */
-#ifdef DEBUG
 #undef DEBUG
-#endif
-
 
+#include <com/sun/star/lang/IllegalArgumentException.hpp>
 #include <com/sun/star/mozilla/XMozillaBootstrap.hpp>
 #include <com/sun/star/xml/crypto/DigestID.hpp>
 #include <com/sun/star/xml/crypto/CipherID.hpp>
-
+#include <cppuhelper/supportsservice.hxx>
 #include <officecfg/Office/Common.hxx>
-
 #include <sal/types.h>
 #include <rtl/instance.hxx>
 #include <rtl/bootstrap.hxx>
@@ -43,13 +40,12 @@
 #include <sal/log.hxx>
 
 #include "seinitializer_nssimpl.hxx"
-#include "../diagnose.hxx"
 
 #include "securityenvironment_nssimpl.hxx"
 #include "digestcontext.hxx"
 #include "ciphercontext.hxx"
 
-#include <boost/scoped_array.hpp>
+#include <memory>
 
 #include <nspr.h>
 #include <cert.h>
@@ -61,7 +57,6 @@
 namespace cssu = css::uno;
 namespace cssl = css::lang;
 
-using namespace xmlsecurity;
 using namespace com::sun::star;
 
 #define IMPLEMENTATION_NAME "com.sun.star.xml.security.bridge.xmlsec.NSSInitializer_NssImpl"
@@ -80,8 +75,8 @@ struct InitNSSInitialize
 {
     css::uno::Reference< css::uno::XComponentContext > m_xContext;
 
-    InitNSSInitialize( const css::uno::Reference< css::uno::XComponentContext > &rxContext )
-    : m_xContext( rxContext )
+    explicit InitNSSInitialize(const css::uno::Reference<css::uno::XComponentContext> &rxContext)
+        : m_xContext(rxContext)
     {
     }
 
@@ -105,9 +100,11 @@ struct GetNSSInitStaticMutex
     }
 };
 
+#ifdef XMLSEC_CRYPTO_NSS
+
 void deleteRootsModule()
 {
-    SECMODModule *RootsModule = 0;
+    SECMODModule *RootsModule = nullptr;
     SECMODModuleList *list = SECMOD_GetDefaultModuleList();
     SECMODListLock *lock = SECMOD_GetDefaultModuleListLock();
     SECMOD_GetReadLock(lock);
@@ -123,9 +120,7 @@ void deleteRootsModule()
             {
                 if (PK11_HasRootCerts(slot))
                 {
-                    xmlsec_trace("The root certifificates module \"%s"
-                              "\" is already loaded: \n%s",
-                              module->commonName,  module->dllName);
+                    SAL_INFO("xmlsecurity.xmlsec", "The root certificates module \"" << module->commonName << "\" is already loaded: " << module->dllName);
 
                     RootsModule = SECMOD_ReferenceModule(module);
                     break;
@@ -141,15 +136,14 @@ void deleteRootsModule()
         PRInt32 modType;
         if (SECSuccess == SECMOD_DeleteModule(RootsModule->commonName, &modType))
         {
-            xmlsec_trace("Deleted module \"%s\".", RootsModule->commonName);
+            SAL_INFO("xmlsecurity.xmlsec", "Deleted module \"" << RootsModule->commonName << "\".");
         }
         else
         {
-            xmlsec_trace("Failed to delete \"%s\" : \n%s",
-                      RootsModule->commonName, RootsModule->dllName);
+            SAL_INFO("xmlsecurity.xmlsec", "Failed to delete \"" << RootsModule->commonName << "\": " << RootsModule->dllName);
         }
         SECMOD_DestroyModule(RootsModule);
-        RootsModule = 0;
+        RootsModule = nullptr;
     }
 }
 
@@ -182,9 +176,7 @@ OString getMozillaCurrentProfile( const css::uno::Reference< css::uno::XComponen
     }
     catch (const uno::Exception &e)
     {
-        SAL_WARN(
-            "xmlsecurity.xmlsec",
-            "getMozillaCurrentProfile: caught exception " << e.Message);
+        SAL_WARN("xmlsecurity.xmlsec", "getMozillaCurrentProfile: caught " << e);
     }
 
     // third, dig around to see if there's one available
@@ -192,18 +184,16 @@ OString getMozillaCurrentProfile( const css::uno::Reference< css::uno::XComponen
         mozilla::MozillaProductType_Thunderbird,
         mozilla::MozillaProductType_Firefox,
         mozilla::MozillaProductType_Mozilla };
-    int nProduct = SAL_N_ELEMENTS(productTypes);
 
     uno::Reference<uno::XInterface> xInstance = rxContext->getServiceManager()->createInstanceWithContext("com.sun.star.mozilla.MozillaBootstrap", rxContext);
     OSL_ENSURE( xInstance.is(), "failed to create instance" );
 
-    uno::Reference<mozilla::XMozillaBootstrap> xMozillaBootstrap
-        =  uno::Reference<mozilla::XMozillaBootstrap>(xInstance,uno::UNO_QUERY);
+    uno::Reference<mozilla::XMozillaBootstrap> xMozillaBootstrap(xInstance,uno::UNO_QUERY);
     OSL_ENSURE( xMozillaBootstrap.is(), "failed to create instance" );
 
     if (xMozillaBootstrap.is())
     {
-        for (int i=0; i<nProduct; ++i)
+        for (int i=0; i<int(SAL_N_ELEMENTS(productTypes)); ++i)
         {
             OUString profile = xMozillaBootstrap->getDefaultProfile(productTypes[i]);
 
@@ -222,6 +212,8 @@ OString getMozillaCurrentProfile( const css::uno::Reference< css::uno::XComponen
     return OString();
 }
 
+#endif
+
 //Older versions of Firefox (FF), for example FF2, and Thunderbird (TB) 2 write
 //the roots certificate module (libnssckbi.so), which they use, into the
 //profile. This module will then already be loaded during NSS_Init (and the
@@ -242,11 +234,9 @@ OString getMozillaCurrentProfile( const css::uno::Reference< css::uno::XComponen
 //ATTENTION: DO NOT call this function directly instead use initNSS
 //return true - whole initialization was successful
 //param out_nss_init = true: at least the NSS initialization (NSS_InitReadWrite
-//was successful and therefor NSS_Shutdown should be called when terminating.
+//was successful and therefore NSS_Shutdown should be called when terminating.
 bool nsscrypto_initialize( const css::uno::Reference< css::uno::XComponentContext > &rxContext, bool & out_nss_init )
 {
-    bool return_value = true;
-
     // this method must be called only once, no need for additional lock
     OString sCertDir;
 
@@ -255,7 +245,7 @@ bool nsscrypto_initialize( const css::uno::Reference< css::uno::XComponentContex
 #else
     (void) rxContext;
 #endif
-    xmlsec_trace( "Using profile: %s", sCertDir.getStr() );
+    SAL_INFO("xmlsecurity.xmlsec",  "Using profile: " << sCertDir );
 
     PR_Init( PR_USER_THREAD, PR_PRIORITY_NORMAL, 1 ) ;
 
@@ -265,13 +255,13 @@ bool nsscrypto_initialize( const css::uno::Reference< css::uno::XComponentContex
     {
         if( NSS_InitReadWrite( sCertDir.getStr() ) != SECSuccess )
         {
-            xmlsec_trace("Initializing NSS with profile failed.");
+            SAL_INFO("xmlsecurity.xmlsec", "Initializing NSS with profile failed.");
             int errlen = PR_GetErrorTextLength();
             if(errlen > 0)
             {
-                boost::scoped_array<char> const error(new char[errlen + 1]);
+                std::unique_ptr<char[]> const error(new char[errlen + 1]);
                 PR_GetErrorText(error.get());
-                xmlsec_trace("%s", error.get());
+                SAL_INFO("xmlsecurity.xmlsec", error.get());
             }
             bSuccess = false;
         }
@@ -279,16 +269,16 @@ bool nsscrypto_initialize( const css::uno::Reference< css::uno::XComponentContex
 
     if( sCertDir.isEmpty() || !bSuccess )
     {
-        xmlsec_trace("Initializing NSS without profile.");
-        if ( NSS_NoDB_Init(NULL) != SECSuccess )
+        SAL_INFO("xmlsecurity.xmlsec", "Initializing NSS without profile.");
+        if ( NSS_NoDB_Init(nullptr) != SECSuccess )
         {
-            xmlsec_trace("Initializing NSS without profile failed.");
+            SAL_INFO("xmlsecurity.xmlsec", "Initializing NSS without profile failed.");
             int errlen = PR_GetErrorTextLength();
             if(errlen > 0)
             {
-                boost::scoped_array<char> const error(new char[errlen + 1]);
+                std::unique_ptr<char[]> const error(new char[errlen + 1]);
                 PR_GetErrorText(error.get());
-                xmlsec_trace("%s", error.get());
+                SAL_INFO("xmlsecurity.xmlsec", error.get());
             }
             return false ;
         }
@@ -296,6 +286,8 @@ bool nsscrypto_initialize( const css::uno::Reference< css::uno::XComponentContex
     out_nss_init = true;
 
 #ifdef XMLSEC_CRYPTO_NSS
+    bool return_value = true;
+
 #if defined SYSTEM_NSS
     if (!SECMOD_HasRootCerts())
 #endif
@@ -318,7 +310,7 @@ bool nsscrypto_initialize( const css::uno::Reference< css::uno::XComponentContex
             SECMODModule * RootsModule =
                 SECMOD_LoadUserModule(
                     const_cast<char*>(aStr.getStr()),
-                    0, // no parent
+                    nullptr, // no parent
                     PR_FALSE); // do not recurse
 
             if (RootsModule)
@@ -327,36 +319,36 @@ bool nsscrypto_initialize( const css::uno::Reference< css::uno::XComponentContex
                 bool found = RootsModule->loaded;
 
                 SECMOD_DestroyModule(RootsModule);
-                RootsModule = 0;
+                RootsModule = nullptr;
                 if (found)
-                    xmlsec_trace("Added new root certificate module "
-                              "\"" ROOT_CERTS "\" contained in \n%s", ospath.getStr());
+                    SAL_INFO("xmlsecurity.xmlsec", "Added new root certificate module " ROOT_CERTS " contained in " << ospath);
                 else
                 {
-                    xmlsec_trace("FAILED to load the new root certificate module "
-                              "\"" ROOT_CERTS "\" contained in \n%s", ospath.getStr());
+                    SAL_INFO("xmlsecurity.xmlsec", "FAILED to load the new root certificate module " ROOT_CERTS "contained in " << ospath);
                     return_value = false;
                 }
             }
             else
             {
-                xmlsec_trace("FAILED to add new root certifice module: "
-                          "\"" ROOT_CERTS "\" contained in \n%s", ospath.getStr());
+                SAL_INFO("xmlsecurity.xmlsec", "FAILED to add new root certificate module " ROOT_CERTS  " contained in " << ospath);
                 return_value = false;
 
             }
         }
         else
         {
-            xmlsec_trace("Adding new root certificate module failed.");
+            SAL_INFO("xmlsecurity.xmlsec", "Adding new root certificate module failed.");
             return_value = false;
         }
     }
-#endif
 
     return return_value;
+#else
+    return true;
+#endif
 }
 
+} // namespace
 
 // must be extern "C" because we pass the function pointer to atexit
 extern "C" void nsscrypto_finalize()
@@ -368,23 +360,21 @@ extern "C" void nsscrypto_finalize()
 
         if (SECSuccess == SECMOD_UnloadUserModule(RootsModule))
         {
-            xmlsec_trace("Unloaded module \"" ROOT_CERTS "\".");
+            SAL_INFO("xmlsecurity.xmlsec", "Unloaded module \"" ROOT_CERTS "\".");
         }
         else
         {
-            xmlsec_trace("Failed unloading module \"" ROOT_CERTS "\".");
+            SAL_INFO("xmlsecurity.xmlsec", "Failed unloading module \"" ROOT_CERTS "\".");
         }
         SECMOD_DestroyModule(RootsModule);
     }
     else
     {
-        xmlsec_trace("Unloading module \"" ROOT_CERTS
-                  "\" failed because it was not found.");
+        SAL_INFO("xmlsecurity.xmlsec", "Unloading module \"" ROOT_CERTS "\" failed because it was not found.");
     }
     PK11_LogoutAll();
-    NSS_Shutdown();
+    (void)NSS_Shutdown();
 }
-} // namespace
 
 ONSSInitializer::ONSSInitializer(
     const css::uno::Reference< css::uno::XComponentContext > &rxContext)
@@ -403,7 +393,6 @@ bool ONSSInitializer::initNSS( const css::uno::Reference< css::uno::XComponentCo
 }
 
 css::uno::Reference< css::xml::crypto::XDigestContext > SAL_CALL ONSSInitializer::getDigestContext( ::sal_Int32 nDigestID, const css::uno::Sequence< css::beans::NamedValue >& aParams )
-    throw (css::lang::IllegalArgumentException, css::uno::RuntimeException)
 {
     SECOidTag nNSSDigestID = SEC_OID_UNKNOWN;
     sal_Int32 nDigestLength = 0;
@@ -422,6 +411,13 @@ css::uno::Reference< css::xml::crypto::XDigestContext > SAL_CALL ONSSInitializer
         nDigestLength = 20;
         b1KData = ( nDigestID == css::xml::crypto::DigestID::SHA1_1K );
     }
+    else if ( nDigestID == css::xml::crypto::DigestID::SHA512
+           || nDigestID == css::xml::crypto::DigestID::SHA512_1K )
+    {
+        nNSSDigestID = SEC_OID_SHA512;
+        nDigestLength = 64;
+        b1KData = ( nDigestID == css::xml::crypto::DigestID::SHA512_1K );
+    }
     else
         throw css::lang::IllegalArgumentException("Unexpected digest requested.", css::uno::Reference< css::uno::XInterface >(), 1 );
 
@@ -439,25 +435,22 @@ css::uno::Reference< css::xml::crypto::XDigestContext > SAL_CALL ONSSInitializer
     return xResult;
 }
 
-css::uno::Reference< css::xml::crypto::XCipherContext > SAL_CALL ONSSInitializer::getCipherContext( ::sal_Int32 nCipherID, const css::uno::Sequence< ::sal_Int8 >& aKey, const css::uno::Sequence< ::sal_Int8 >& aInitializationVector, ::sal_Bool bEncryption, const css::uno::Sequence< css::beans::NamedValue >& aParams )
-    throw (css::lang::IllegalArgumentException, css::uno::RuntimeException)
+css::uno::Reference< css::xml::crypto::XCipherContext > SAL_CALL ONSSInitializer::getCipherContext( ::sal_Int32 nCipherID, const css::uno::Sequence< ::sal_Int8 >& aKey, const css::uno::Sequence< ::sal_Int8 >& aInitializationVector, sal_Bool bEncryption, const css::uno::Sequence< css::beans::NamedValue >& aParams )
 {
     CK_MECHANISM_TYPE nNSSCipherID = 0;
     bool bW3CPadding = false;
-    if ( nCipherID == css::xml::crypto::CipherID::AES_CBC_W3C_PADDING )
-    {
-        nNSSCipherID = CKM_AES_CBC;
-        bW3CPadding = true;
-
-        if ( aKey.getLength() != 16 && aKey.getLength() != 24 && aKey.getLength() != 32 )
-            throw css::lang::IllegalArgumentException("Unexpected key length.", css::uno::Reference< css::uno::XInterface >(), 2 );
-
-        if ( aParams.getLength() )
-            throw css::lang::IllegalArgumentException("Unexpected arguments provided for cipher creation.", css::uno::Reference< css::uno::XInterface >(), 5 );
-    }
-    else
+    if ( nCipherID != css::xml::crypto::CipherID::AES_CBC_W3C_PADDING )
         throw css::lang::IllegalArgumentException("Unexpected cipher requested.", css::uno::Reference< css::uno::XInterface >(), 1 );
 
+    nNSSCipherID = CKM_AES_CBC;
+    bW3CPadding = true;
+
+    if ( aKey.getLength() != 16 && aKey.getLength() != 24 && aKey.getLength() != 32 )
+        throw css::lang::IllegalArgumentException("Unexpected key length.", css::uno::Reference< css::uno::XInterface >(), 2 );
+
+    if ( aParams.getLength() )
+        throw css::lang::IllegalArgumentException("Unexpected arguments provided for cipher creation.", css::uno::Reference< css::uno::XInterface >(), 5 );
+
     css::uno::Reference< css::xml::crypto::XCipherContext > xResult;
     if( initNSS( m_xContext ) )
     {
@@ -471,46 +464,34 @@ css::uno::Reference< css::xml::crypto::XCipherContext > SAL_CALL ONSSInitializer
 }
 
 OUString ONSSInitializer_getImplementationName ()
-    throw (cssu::RuntimeException)
 {
 
     return OUString ( IMPLEMENTATION_NAME );
 }
 
-sal_Bool SAL_CALL ONSSInitializer_supportsService( const OUString& ServiceName )
-    throw (cssu::RuntimeException)
-{
-    return ServiceName == NSS_SERVICE_NAME;
-}
-
 cssu::Sequence< OUString > SAL_CALL ONSSInitializer_getSupportedServiceNames(  )
-    throw (cssu::RuntimeException)
 {
-    cssu::Sequence < OUString > aRet(1);
-    OUString* pArray = aRet.getArray();
-    pArray[0] =  OUString ( NSS_SERVICE_NAME );
+    cssu::Sequence<OUString> aRet { NSS_SERVICE_NAME };
     return aRet;
 }
 
 cssu::Reference< cssu::XInterface > SAL_CALL ONSSInitializer_createInstance( const cssu::Reference< cssl::XMultiServiceFactory > & rSMgr)
-    throw( cssu::Exception )
 {
-    return (cppu::OWeakObject*) new ONSSInitializer( comphelper::getComponentContext(rSMgr) );
+    return static_cast<cppu::OWeakObject*>(new ONSSInitializer( comphelper::getComponentContext(rSMgr) ));
 }
 
 /* XServiceInfo */
 OUString SAL_CALL ONSSInitializer::getImplementationName()
-    throw (cssu::RuntimeException)
 {
     return ONSSInitializer_getImplementationName();
 }
+
 sal_Bool SAL_CALL ONSSInitializer::supportsService( const OUString& rServiceName )
-    throw (cssu::RuntimeException)
 {
-    return ONSSInitializer_supportsService( rServiceName );
+    return cppu::supportsService(this, rServiceName);
 }
+
 cssu::Sequence< OUString > SAL_CALL ONSSInitializer::getSupportedServiceNames(  )
-    throw (cssu::RuntimeException)
 {
     return ONSSInitializer_getSupportedServiceNames();
 }
