@@ -18,12 +18,12 @@
  */
 
 
-#include "secerr.h"
+#include <secerr.h>
 #include "secerror.hxx"
-#include "sslerr.h"
-#include "nspr.h"
-#include "nss.h"
-#include "certt.h"
+#include <sslerr.h>
+#include <nspr.h>
+#include <nss.h>
+#include <certt.h>
 #include <sal/log.hxx>
 #include <sal/macros.h>
 #include <sal/types.h>
@@ -34,7 +34,6 @@ struct ErrDesc {
 };
 
 
-
 const ErrDesc allDesc[] = {
 
 #include "certerrors.h"
@@ -42,22 +41,19 @@ const ErrDesc allDesc[] = {
 };
 
 
-
 /* Returns a UTF-8 encoded constant error string for "errNum".
  * Returns NULL of errNum is unknown.
  */
 const char *
 getCertError(PRErrorCode errNum)
 {
-    static const char sEmpty[] = "";
-    const int numDesc = SAL_N_ELEMENTS(allDesc);
-    for (int i = 0; i < numDesc; i++)
+    for (const ErrDesc& i : allDesc)
     {
-        if (allDesc[i].errNum == errNum)
-            return  allDesc[i].errString;
+        if (i.errNum == errNum)
+            return i.errString;
     }
 
-    return sEmpty;
+    return "";
 }
 
 void
